%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v23.07     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                         23 - July - 2023                         %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   This is an entirely synthetic power system network model that covers the
%   geographic footprint of the US Eastern Interconnection states (Arkansas,
%   Louisiana, Missouri, Connecticut, Maine, Massachusetts, New Hampshire,
%   Rhode Island, Vermont, Alabama, Kentucky, Mississippi, Tennessee, New York,
%   New Jersey, Pennsylvania, Washington DC, Delaware, Maryland, North Carolina,
%   Virginia, West Virginia, Illinois, Iowa, Minnesota, Wisconsin, Indiana,
%   Michigan, Ohio, Florida, Georgia, South Carolina, Kansas, Nebraska,
%   North Dakota, Oklahoma, South Dakota and Texas). The full geographic area
%   of each state is included in this model, resulting in the State of Texas
%   being fully modeled as part of the Eastern Grid Model. The case is designed
%   with a 765, 500, 345, 230, 138 and 69 kV transmission network to serve a
%   load that roughly mimics the actual population of its geographic footprint.
%   The synthetic transmission system was designed by algorithms described in
%   [1] to be statistically similar to actual transmission system models but
%   without modeling any actual lines.
%
%   One-line diagrams and other data formats available at:
%   https://github.com/WISPO-POP/SyntheticElectricNetworkModels
%   https://electricgrids.engr.tamu.edu
%
%   This synthetic dateset was developed as part of the ARPA-E GRID DATA
%   program as part of the EPIGRIDS project.
%
%   When publishing results based on this data, please cite:
%
%   [1] J. M. Snodgrass, "Tractable Algorithms for Constructing Electric Power Network Models,"
%      Ph.D. Thesis, The University of Wisconsin - Madison, 2021.
%
%   Copyright (c) 2022 by J. Snodgrass, S. Greene, B. Lesieutre, C. DeMarco
%   Licensed under the Creative Commons Attribution 4.0
%   International license, http://creativecommons.org/licenses/by/4.0/
%

function mpc = pglib_opf_case78484_epigrids
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	1	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	4	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	5	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	6	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	7	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11	 2	 25.58	 10.3	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	33	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	34	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	35	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	37	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	38	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	78	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	85	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	96	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	97	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	98	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	99	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	100	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	101	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	102	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	103	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	104	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	105	 2	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	106	 2	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	107	 2	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	108	 2	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	109	 2	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	110	 2	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	111	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	112	 2	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	113	 2	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	114	 2	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	115	 2	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	116	 2	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	117	 2	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	118	 2	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	119	 2	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	120	 2	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	121	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	122	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	123	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	124	 2	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	125	 2	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	126	 2	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	127	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	128	 2	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	129	 2	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	130	 2	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	131	 2	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	132	 1	 12.59	 6.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	133	 1	 4.26	 1.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	134	 1	 7.14	 3.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	135	 1	 3.82	 2.11	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	136	 1	 9.32	 4.95	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	137	 1	 3.77	 1.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	138	 1	 6.06	 2.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	139	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	140	 1	 3.73	 1.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	141	 1	 6.35	 2.63	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	142	 1	 3.47	 1.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	143	 1	 6.49	 2.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	144	 1	 6.03	 3.26	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	145	 1	 4.76	 2.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	146	 1	 2.97	 1.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	147	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	148	 1	 2.63	 1.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	149	 1	 5.18	 2.82	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	150	 1	 2.75	 1.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	151	 1	 3.49	 1.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	152	 1	 5.88	 3.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	153	 1	 5.06	 2.79	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	154	 1	 5.23	 2.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	155	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	156	 1	 2.89	 1.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	157	 1	 6.82	 2.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	158	 1	 5.33	 2.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	159	 1	 12.75	 6.79	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	160	 1	 28.9	 14.65	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	161	 1	 7.04	 3.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	162	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	163	 1	 10.55	 4.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	164	 1	 4.46	 2.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	165	 1	 7.31	 3.63	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	166	 1	 4.07	 1.76	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	167	 1	 3.28	 1.67	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	168	 1	 11.47	 5.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	169	 1	 10.13	 4.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	170	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	171	 1	 1.7	 0.73	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	172	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	173	 1	 5.41	 2.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	174	 1	 3.03	 1.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	175	 1	 4.83	 2.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	176	 1	 4.43	 2.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	177	 1	 15.66	 6.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	178	 1	 2.36	 1.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	179	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	180	 1	 3.62	 1.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	181	 1	 3.24	 1.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	182	 1	 7.63	 3.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	183	 1	 8.08	 3.73	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	184	 1	 4.07	 1.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	185	 1	 1.18	 0.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	186	 1	 3.77	 2.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	187	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	188	 1	 2.97	 1.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	189	 1	 2.28	 1.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	190	 1	 6.36	 2.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	191	 1	 3.42	 1.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	192	 1	 2.19	 1.16	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	193	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	194	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	195	 1	 3.89	 2.2	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	196	 1	 4.45	 2.11	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	197	 1	 4.17	 2.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	198	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	199	 1	 3.25	 1.49	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	200	 1	 8.07	 3.15	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	201	 1	 5.0	 2.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	202	 1	 2.53	 1.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	203	 1	 2.97	 1.41	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	204	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	205	 1	 5.65	 2.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	206	 1	 1.75	 0.85	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	207	 1	 5.26	 2.17	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	208	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	209	 1	 4.03	 2.34	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	210	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	211	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	212	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	213	 1	 2.39	 1.12	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	214	 1	 4.33	 2.23	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	215	 1	 3.12	 1.75	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	216	 1	 2.96	 1.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	217	 1	 10.41	 4.94	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	218	 1	 2.91	 1.65	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	219	 1	 3.17	 1.76	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	220	 1	 2.02	 1.2	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	221	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	222	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	223	 1	 1.52	 0.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	224	 1	 1.74	 1.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	225	 1	 5.85	 3.09	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	226	 1	 5.82	 2.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	227	 1	 1.56	 0.77	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	228	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	229	 1	 6.1	 2.27	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	230	 1	 5.89	 2.94	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	231	 1	 5.3	 2.6	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	232	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	233	 1	 5.85	 3.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	234	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	235	 1	 7.05	 2.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	236	 1	 2.78	 1.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	237	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	238	 1	 4.42	 1.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	239	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	240	 1	 5.61	 2.71	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	241	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	242	 1	 2.94	 1.63	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	243	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	244	 1	 3.01	 1.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	245	 1	 4.23	 2.26	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	246	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	247	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	248	 1	 2.73	 1.37	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	249	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	250	 1	 3.2	 1.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	251	 1	 5.26	 2.46	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	252	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	253	 1	 5.0	 2.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	254	 1	 4.68	 2.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	255	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	256	 1	 2.92	 1.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	257	 1	 13.34	 7.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	258	 1	 2.93	 1.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	259	 1	 2.39	 1.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	260	 1	 7.95	 3.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	261	 1	 2.46	 1.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	262	 1	 1.64	 0.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	263	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	264	 1	 4.55	 2.41	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	265	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	266	 1	 4.25	 1.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	267	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	268	 1	 14.43	 6.46	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	269	 1	 5.8	 2.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	270	 1	 4.88	 2.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	271	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	272	 1	 33.52	 16.26	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	273	 1	 36.34	 18.77	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	274	 1	 10.66	 5.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	275	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	276	 1	 4.93	 2.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	277	 1	 4.68	 2.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	278	 1	 5.7	 3.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	279	 1	 6.08	 3.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	280	 1	 8.75	 4.4	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	281	 1	 4.32	 2.25	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	282	 1	 6.76	 3.95	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	283	 1	 3.84	 2.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	284	 1	 5.78	 3.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	285	 1	 6.94	 3.02	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	286	 1	 2.49	 1.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	287	 1	 5.37	 2.73	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	288	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	289	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	290	 1	 5.86	 2.96	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	291	 1	 2.9	 1.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	292	 1	 2.43	 1.3	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	293	 1	 5.99	 2.06	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	294	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	295	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	296	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	297	 1	 7.73	 3.54	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	298	 1	 3.5	 1.81	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	299	 1	 4.22	 2.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	300	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	301	 1	 6.5	 3.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	302	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	303	 1	 7.13	 3.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	304	 1	 7.13	 3.19	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	305	 1	 4.37	 1.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	306	 1	 5.17	 2.15	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	307	 1	 11.2	 5.01	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	308	 1	 8.44	 3.84	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	309	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	310	 1	 6.34	 3.46	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	311	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	312	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	313	 1	 11.46	 5.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	314	 1	 4.64	 2.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	315	 1	 5.96	 2.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	316	 1	 6.31	 2.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	317	 1	 5.44	 2.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	318	 1	 8.38	 3.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	319	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	320	 1	 4.5	 2.27	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	321	 1	 2.59	 1.19	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	322	 1	 7.3	 3.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	323	 1	 3.7	 1.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	324	 1	 3.49	 1.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	325	 1	 2.7	 1.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	326	 1	 6.22	 3.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	327	 1	 5.3	 2.82	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	328	 1	 4.21	 1.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	329	 1	 4.25	 2.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	330	 1	 5.46	 2.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	331	 1	 10.17	 4.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	332	 1	 4.18	 1.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	333	 1	 6.77	 3.7	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	334	 1	 2.05	 0.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	335	 1	 4.54	 2.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	336	 1	 7.9	 3.57	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	337	 1	 2.36	 1.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	338	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	339	 1	 6.47	 3.04	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	340	 1	 2.55	 1.2	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	341	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	342	 1	 1.51	 0.65	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	343	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	344	 1	 4.79	 2.61	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	345	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	346	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	347	 1	 8.95	 2.94	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	348	 1	 7.12	 3.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	349	 1	 5.56	 2.56	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	350	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	351	 1	 6.84	 3.1	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	352	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	353	 1	 1.58	 0.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	354	 1	 7.59	 3.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	355	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	356	 1	 4.06	 1.8	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	357	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	358	 1	 6.9	 3.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	359	 1	 3.93	 1.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	360	 1	 8.96	 3.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	361	 1	 3.62	 1.26	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	362	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	363	 1	 4.4	 2.11	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	364	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	365	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	366	 1	 3.69	 1.79	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	367	 1	 3.52	 1.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	368	 1	 3.22	 1.69	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	369	 1	 3.43	 1.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	370	 1	 4.95	 2.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	371	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	372	 1	 5.03	 2.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	373	 1	 4.53	 2.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	374	 1	 5.2	 2.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	375	 1	 4.68	 2.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	376	 1	 4.5	 2.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	377	 1	 4.23	 2.01	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	378	 1	 1.48	 0.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	379	 1	 7.8	 3.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	380	 1	 3.08	 1.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	381	 1	 5.33	 2.16	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	382	 1	 9.1	 3.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	383	 1	 6.34	 3.07	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	384	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	385	 1	 2.73	 1.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	386	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	387	 1	 4.2	 1.73	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	388	 1	 5.31	 2.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	389	 1	 3.0	 1.63	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	390	 1	 2.56	 1.43	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	391	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	392	 1	 9.1	 3.06	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	393	 1	 6.78	 2.73	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	394	 1	 15.35	 7.26	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	395	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	396	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	397	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	398	 1	 2.71	 1.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	399	 1	 10.78	 3.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	400	 1	 3.74	 2.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	401	 1	 2.94	 1.25	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	402	 1	 4.16	 1.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	403	 1	 3.02	 1.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	404	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	405	 1	 1.92	 1.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	406	 1	 4.11	 2.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	407	 1	 6.98	 3.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	408	 1	 6.45	 2.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	409	 1	 8.05	 4.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	410	 1	 1.87	 0.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	411	 1	 4.55	 2.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	412	 1	 7.38	 3.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	413	 1	 1.72	 0.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	414	 1	 5.32	 2.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	415	 1	 3.5	 1.69	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	416	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	417	 1	 2.79	 1.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	418	 1	 9.61	 4.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	419	 1	 8.42	 3.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	420	 1	 3.93	 2.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	421	 1	 20.52	 6.65	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	422	 1	 5.23	 2.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	423	 1	 2.64	 1.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	424	 1	 50.23	 23.6	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	425	 1	 3.7	 1.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	426	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	427	 1	 2.79	 1.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	428	 1	 11.78	 5.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	429	 1	 1.91	 0.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	430	 1	 11.45	 6.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	431	 1	 3.19	 1.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	432	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	433	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	434	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	435	 1	 2.3	 1.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	436	 1	 1.6	 0.82	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	437	 1	 2.66	 1.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	438	 1	 4.28	 1.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	439	 1	 5.1	 2.85	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	440	 1	 3.14	 1.5	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	441	 1	 14.05	 7.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	442	 1	 4.82	 2.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	443	 1	 3.0	 1.63	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	444	 1	 2.84	 1.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	445	 1	 2.88	 1.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	446	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	447	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	448	 1	 4.36	 1.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	449	 1	 5.31	 2.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	450	 1	 3.25	 1.62	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	451	 1	 2.61	 1.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	452	 1	 5.48	 2.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	453	 1	 10.96	 4.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	454	 1	 8.89	 4.62	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	455	 1	 9.42	 4.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	456	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	457	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	458	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	459	 1	 5.71	 2.76	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	460	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	461	 1	 2.45	 1.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	462	 1	 8.17	 4.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	463	 1	 7.02	 3.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	464	 1	 6.93	 3.25	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	465	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	466	 1	 4.02	 1.79	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	467	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	468	 1	 8.03	 3.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	469	 1	 9.14	 3.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	470	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	471	 1	 3.86	 2.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	472	 1	 3.32	 1.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	473	 1	 2.11	 1.04	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	474	 1	 3.1	 1.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	475	 1	 2.54	 1.16	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	476	 1	 4.4	 2.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	477	 1	 2.51	 1.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	478	 1	 8.82	 4.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	479	 1	 3.09	 1.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	480	 1	 2.9	 1.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	481	 1	 3.38	 1.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	482	 1	 6.26	 3.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	483	 1	 3.52	 1.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	484	 1	 2.74	 1.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	485	 1	 2.06	 0.94	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	486	 1	 3.73	 1.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	487	 1	 7.23	 3.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	488	 1	 1.66	 0.79	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	489	 1	 12.64	 4.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	490	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	491	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	492	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	493	 1	 3.67	 1.84	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	494	 1	 2.5	 1.15	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	495	 1	 3.59	 1.62	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	496	 1	 3.06	 1.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	497	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	498	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	499	 1	 2.82	 1.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	500	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	501	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	502	 1	 5.1	 2.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	503	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	504	 1	 3.91	 1.84	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	505	 1	 6.67	 3.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	506	 1	 2.34	 1.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	507	 1	 4.83	 2.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	508	 1	 7.9	 3.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	509	 1	 8.08	 4.14	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	510	 1	 1.7	 0.84	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	511	 1	 1.16	 0.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	512	 1	 5.32	 2.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	513	 1	 5.24	 2.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	514	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	515	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	516	 1	 1.32	 0.69	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	517	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	518	 1	 6.34	 2.69	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	519	 1	 3.42	 1.75	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	520	 1	 3.25	 1.67	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	521	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	522	 1	 1.59	 0.69	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	523	 1	 5.16	 2.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	524	 1	 5.78	 3.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	525	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	526	 1	 3.94	 1.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	527	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	528	 1	 3.73	 1.77	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	529	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	530	 1	 2.62	 1.43	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	531	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	532	 1	 2.95	 1.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	533	 1	 2.4	 1.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	534	 1	 3.28	 1.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	535	 1	 4.41	 1.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	536	 1	 5.13	 2.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	537	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	538	 1	 6.78	 2.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	539	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	540	 1	 7.97	 4.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	541	 1	 5.66	 2.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	542	 1	 3.75	 2.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	543	 1	 3.92	 1.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	544	 1	 3.18	 1.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	545	 1	 2.64	 1.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	546	 1	 3.65	 1.81	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	547	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	548	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	549	 1	 2.43	 1.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	550	 1	 4.15	 1.91	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	551	 1	 2.66	 1.41	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	552	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	553	 1	 5.1	 1.93	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	554	 1	 7.91	 3.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	555	 1	 5.5	 3.11	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	556	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	557	 1	 5.54	 2.35	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	558	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	559	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	560	 1	 5.01	 2.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	561	 1	 2.12	 1.02	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	562	 1	 1.93	 0.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	563	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	564	 1	 5.72	 2.77	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	565	 1	 10.68	 4.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	566	 1	 1.23	 0.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	567	 1	 8.38	 3.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	568	 1	 5.29	 2.67	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	569	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	570	 1	 8.89	 4.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	571	 1	 5.14	 2.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	572	 1	 12.95	 5.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	573	 1	 8.32	 1.85	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	574	 1	 8.15	 1.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	575	 1	 6.09	 -4.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	576	 1	 1.4	 0.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	577	 1	 1.04	 0.5	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	578	 1	 2.54	 1.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	579	 1	 2.75	 1.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	580	 1	 1.81	 0.77	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	581	 1	 3.36	 0.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	582	 1	 1.06	 0.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	583	 1	 2.32	 0.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	584	 1	 4.65	 2.19	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	585	 1	 2.29	 1.07	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	586	 1	 4.47	 1.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	587	 1	 4.22	 2.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	588	 1	 2.82	 1.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	589	 1	 2.09	 1.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	590	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	591	 1	 6.42	 2.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	592	 1	 6.09	 2.02	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	593	 1	 1.88	 1.01	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	594	 1	 1.88	 0.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	595	 1	 1.29	 0.62	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	596	 1	 3.5	 1.35	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	597	 1	 5.83	 2.62	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	598	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	599	 1	 4.2	 1.69	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	600	 1	 7.07	 3.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	601	 1	 2.08	 0.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	602	 1	 13.11	 2.94	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	603	 1	 5.55	 1.26	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	604	 1	 3.72	 1.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	605	 1	 10.92	 4.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	606	 1	 6.77	 2.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	607	 1	 8.32	 3.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	608	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	609	 1	 7.08	 3.05	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	610	 1	 7.79	 3.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	611	 1	 2.96	 1.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	612	 1	 6.15	 3.17	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	613	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	614	 1	 5.24	 2.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	615	 1	 5.82	 2.12	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	616	 1	 2.31	 0.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	617	 1	 1.93	 0.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	618	 1	 7.68	 3.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	619	 1	 4.42	 2.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	620	 1	 12.72	 5.63	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	621	 1	 6.84	 3.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	622	 1	 2.89	 1.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	623	 1	 4.23	 1.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	624	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	625	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	626	 1	 4.88	 2.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	627	 1	 4.09	 2.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	628	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	629	 1	 2.91	 1.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	630	 1	 3.79	 1.73	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	631	 1	 6.49	 2.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	632	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	633	 1	 9.45	 4.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	634	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	635	 1	 4.7	 1.98	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	636	 1	 3.46	 1.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	637	 1	 10.51	 4.01	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	638	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	639	 1	 3.34	 1.89	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	640	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	641	 1	 3.93	 1.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	642	 1	 4.17	 1.94	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	643	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	644	 1	 3.2	 1.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	645	 1	 2.41	 1.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	646	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	647	 1	 7.96	 3.53	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	648	 1	 4.65	 2.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	649	 1	 6.15	 2.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	650	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	651	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	652	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	653	 1	 4.79	 2.82	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	654	 1	 6.83	 3.19	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	655	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	656	 1	 7.52	 4.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	657	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	658	 1	 4.74	 1.6	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	659	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	660	 1	 2.22	 1.23	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	661	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	662	 1	 6.65	 3.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	663	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	664	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	665	 1	 4.86	 2.41	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	666	 1	 3.02	 1.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	667	 1	 3.38	 1.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	668	 1	 5.38	 2.25	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	669	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	670	 1	 4.36	 2.41	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	671	 1	 2.66	 1.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	672	 1	 1.98	 1.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	673	 1	 5.31	 2.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	674	 1	 6.71	 3.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	675	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	676	 1	 4.9	 2.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	677	 1	 4.86	 2.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	678	 1	 8.56	 4.37	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	679	 1	 5.71	 2.4	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	680	 1	 6.14	 3.34	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	681	 1	 3.61	 1.37	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	682	 1	 7.32	 2.73	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	683	 1	 10.98	 4.86	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	684	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	685	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	686	 1	 7.06	 3.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	687	 1	 4.0	 1.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	688	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	689	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	690	 1	 3.65	 1.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	691	 1	 7.93	 3.76	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	692	 1	 7.31	 4.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	693	 1	 4.72	 2.17	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	694	 1	 3.05	 1.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	695	 1	 3.07	 1.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	696	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	697	 1	 4.28	 2.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	698	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	699	 1	 5.96	 2.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	700	 1	 2.94	 1.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	701	 1	 8.41	 4.74	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	702	 1	 3.44	 1.52	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	703	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	704	 1	 7.77	 4.18	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	705	 1	 4.41	 2.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	706	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	707	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	708	 1	 3.66	 1.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	709	 1	 4.57	 2.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	710	 1	 5.53	 3.06	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	711	 1	 2.42	 1.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	712	 1	 8.8	 3.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	713	 1	 2.73	 1.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	714	 1	 3.93	 1.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	715	 1	 3.0	 1.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	716	 1	 2.45	 1.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	717	 1	 5.96	 2.63	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	718	 1	 6.11	 2.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	719	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	720	 1	 1.77	 0.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	721	 1	 2.01	 0.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	722	 1	 7.0	 2.74	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	723	 1	 6.32	 2.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	724	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	725	 1	 3.55	 1.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	726	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	727	 1	 2.91	 1.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	728	 1	 6.66	 3.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	729	 1	 5.13	 2.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	730	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	731	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	732	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	733	 1	 12.28	 5.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	734	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	735	 1	 4.56	 2.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	736	 1	 3.0	 1.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	737	 1	 3.49	 1.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	738	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	739	 1	 5.86	 2.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	740	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	741	 1	 1.85	 0.91	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	742	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	743	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	744	 1	 2.9	 1.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	745	 1	 6.98	 3.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	746	 1	 12.63	 6.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	747	 1	 4.59	 2.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	748	 1	 4.01	 2.19	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	749	 1	 4.66	 2.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	750	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	751	 1	 6.12	 2.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	752	 1	 4.29	 2.22	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	753	 1	 2.58	 1.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	754	 1	 8.76	 3.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	755	 1	 38.85	 12.85	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	756	 1	 7.98	 4.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	757	 1	 8.86	 4.32	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	758	 1	 2.11	 1.14	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	759	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	760	 1	 4.96	 2.25	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	761	 1	 9.15	 4.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	762	 1	 5.5	 2.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	763	 1	 7.91	 3.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	764	 1	 3.93	 1.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	765	 1	 10.73	 5.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	766	 1	 4.34	 2.28	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	767	 1	 2.64	 1.25	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	768	 1	 2.72	 1.31	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	769	 1	 9.16	 4.91	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	770	 1	 4.12	 1.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	771	 1	 3.05	 1.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	772	 1	 2.37	 1.19	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	773	 1	 1.99	 1.02	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	774	 1	 2.92	 1.37	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	775	 1	 17.07	 7.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	776	 1	 9.02	 4.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	777	 1	 8.05	 4.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	778	 1	 5.0	 2.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	779	 1	 2.4	 1.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	780	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	781	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	782	 1	 2.45	 1.22	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	783	 1	 5.53	 3.06	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	784	 1	 5.58	 2.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	785	 1	 3.76	 2.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	786	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	787	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	788	 1	 3.97	 2.17	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	789	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	790	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	791	 1	 7.15	 3.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	792	 1	 6.1	 3.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	793	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	794	 1	 12.87	 5.18	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	795	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	796	 1	 3.01	 1.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	797	 1	 12.63	 5.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	798	 1	 7.85	 3.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	799	 1	 4.76	 2.58	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	800	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	801	 1	 4.81	 2.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	802	 1	 3.93	 1.77	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	803	 1	 2.49	 1.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	804	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	805	 1	 5.66	 2.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	806	 1	 4.96	 2.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	807	 1	 5.62	 3.01	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	808	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	809	 1	 2.62	 1.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	810	 1	 1.4	 0.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	811	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	812	 1	 3.65	 1.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	813	 1	 4.76	 1.91	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	814	 1	 1.42	 0.74	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	815	 1	 3.01	 1.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	816	 1	 5.37	 2.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	817	 1	 3.33	 1.37	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	818	 1	 5.12	 2.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	819	 1	 3.15	 1.74	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	820	 1	 6.52	 2.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	821	 1	 2.34	 1.06	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	822	 1	 9.64	 4.2	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	823	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	824	 1	 7.34	 3.99	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	825	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	826	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	827	 1	 3.42	 1.84	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	828	 1	 10.29	 4.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	829	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	830	 1	 2.45	 1.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	831	 1	 3.12	 1.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	832	 1	 4.42	 1.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	833	 1	 4.84	 1.74	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	834	 1	 5.69	 2.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	835	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	836	 1	 7.57	 3.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	837	 1	 5.22	 2.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	838	 1	 4.88	 2.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	839	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	840	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	841	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	842	 1	 2.89	 1.57	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	843	 1	 2.98	 1.37	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	844	 1	 3.42	 1.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	845	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	846	 1	 2.64	 1.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	847	 1	 4.39	 2.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	848	 1	 2.1	 0.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	849	 1	 8.45	 4.27	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	850	 1	 3.67	 2.1	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	851	 1	 4.69	 2.82	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	852	 1	 5.27	 2.73	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	853	 1	 5.65	 2.94	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	854	 1	 2.0	 1.04	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	855	 1	 7.76	 3.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	856	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	857	 1	 4.77	 2.68	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	858	 1	 3.83	 1.97	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	859	 1	 9.22	 3.04	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	860	 1	 5.36	 2.86	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	861	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	862	 1	 8.89	 4.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	863	 1	 5.53	 2.82	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	864	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	865	 1	 2.83	 1.35	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	866	 1	 3.56	 1.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	867	 1	 13.84	 6.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	868	 1	 7.24	 3.66	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	869	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	870	 1	 4.06	 1.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	871	 1	 1.54	 0.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	872	 1	 2.51	 1.16	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	873	 1	 6.97	 3.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	874	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	875	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	876	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	877	 1	 3.4	 1.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	878	 1	 2.79	 1.33	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	879	 1	 5.99	 2.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	880	 1	 4.2	 2.22	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	881	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	882	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	883	 1	 2.06	 0.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	884	 1	 4.11	 2.16	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	885	 1	 2.44	 1.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	886	 1	 4.9	 2.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	887	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	888	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	889	 1	 6.72	 2.65	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	890	 1	 4.94	 1.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	891	 1	 3.65	 1.48	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	892	 1	 4.49	 1.82	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	893	 1	 5.46	 2.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	894	 1	 5.93	 3.27	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	895	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	896	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	897	 1	 5.18	 2.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	898	 1	 5.6	 2.52	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	899	 1	 5.72	 3.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	900	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	901	 1	 12.85	 6.42	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	902	 1	 10.19	 4.65	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	903	 1	 5.84	 3.04	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	904	 1	 1.25	 0.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	905	 1	 4.27	 2.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	906	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	907	 1	 3.5	 1.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	908	 1	 3.6	 1.79	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	909	 1	 2.35	 1.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	910	 1	 4.97	 2.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	911	 1	 2.81	 1.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	912	 1	 6.62	 2.73	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	913	 1	 7.47	 3.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	914	 1	 6.22	 2.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	915	 1	 2.75	 1.35	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	916	 1	 2.89	 1.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	917	 1	 1.99	 1.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	918	 1	 6.64	 2.88	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	919	 1	 4.09	 2.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	920	 1	 8.71	 3.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	921	 1	 5.37	 2.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	922	 1	 1.67	 0.85	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	923	 1	 8.45	 3.73	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	924	 1	 2.99	 1.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	925	 1	 5.92	 2.62	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	926	 1	 4.51	 1.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	927	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	928	 1	 3.91	 1.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	929	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	930	 1	 10.34	 5.29	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	931	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	932	 1	 4.46	 2.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	933	 1	 4.82	 1.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	934	 1	 3.69	 1.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	935	 1	 13.11	 6.5	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	936	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	937	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	938	 1	 8.41	 3.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	939	 1	 4.65	 2.17	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	940	 1	 5.16	 2.73	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	941	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	942	 1	 1.33	 0.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	943	 1	 1.23	 0.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	944	 1	 3.27	 1.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	945	 1	 4.42	 2.43	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	946	 1	 3.74	 2.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	947	 1	 7.9	 3.16	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	948	 1	 2.56	 1.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	949	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	950	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	951	 1	 8.61	 3.78	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	952	 1	 6.89	 3.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	953	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	954	 1	 8.2	 3.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	955	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	956	 1	 8.94	 3.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	957	 1	 5.83	 2.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	958	 1	 6.03	 2.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	959	 1	 8.75	 4.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	960	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	961	 1	 1.78	 1.02	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	962	 1	 11.86	 5.13	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	963	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	964	 1	 2.08	 1.08	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	965	 1	 1.89	 1.11	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	966	 1	 11.2	 4.67	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	967	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	968	 1	 3.72	 1.88	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	969	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	970	 1	 8.6	 3.57	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	971	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	972	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	973	 1	 6.84	 3.54	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	974	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	975	 1	 5.43	 2.88	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	976	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	977	 1	 4.84	 2.65	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	978	 1	 11.29	 4.91	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	979	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	980	 1	 4.0	 2.21	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	981	 1	 10.54	 3.83	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	982	 1	 6.73	 2.89	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	983	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	984	 1	 2.16	 1.05	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	985	 1	 3.48	 1.93	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	986	 1	 3.57	 1.78	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	987	 1	 4.3	 2.48	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	988	 1	 6.55	 2.88	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	989	 1	 3.15	 1.43	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	990	 1	 3.78	 1.9	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	991	 1	 12.03	 5.22	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	992	 1	 2.24	 1.24	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	993	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	994	 1	 2.96	 1.74	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	995	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	996	 1	 3.82	 1.96	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	997	 1	 2.86	 1.68	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	998	 1	 3.87	 2.04	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	999	 1	 8.54	 4.27	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1000	 1	 5.79	 2.2	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1001	 1	 16.23	 8.64	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1002	 1	 30.77	 13.81	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1003	 1	 11.32	 5.94	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1004	 1	 7.72	 4.27	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1005	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	1006	 1	 9.06	 3.54	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1007	 1	 3.3	 1.8	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1008	 1	 9.65	 5.07	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1009	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1010	 1	 8.4	 3.74	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1011	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1012	 1	 3.11	 1.52	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1013	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1014	 1	 2.6	 1.31	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1015	 1	 11.97	 5.89	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1016	 1	 4.19	 1.86	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1017	 1	 6.89	 2.95	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1018	 1	 4.04	 1.76	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1019	 1	 4.39	 2.34	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1020	 1	 1.29	 0.59	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1021	 1	 12.12	 6.1	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1022	 1	 7.93	 4.11	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1023	 1	 5.03	 2.72	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1024	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1025	 1	 5.8	 2.68	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1026	 1	 8.47	 3.89	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1027	 1	 11.7	 5.81	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1028	 1	 8.11	 3.82	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1029	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1030	 1	 10.21	 4.73	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1031	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1032	 1	 1.38	 0.8	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1033	 1	 5.8	 3.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1034	 1	 8.33	 4.21	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1035	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1036	 1	 6.92	 3.69	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1037	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1038	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	1039	 1	 58.86	 21.47	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1040	 1	 56.89	 25.75	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1041	 1	 6.63	 3.43	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1042	 1	 7.76	 4.05	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1043	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1044	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1045	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1046	 1	 6.4	 3.48	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1047	 1	 7.06	 2.67	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1048	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1049	 1	 5.97	 2.86	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1050	 1	 7.45	 4.17	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1051	 1	 4.83	 2.69	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1052	 1	 6.58	 3.51	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1053	 1	 3.32	 1.5	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1054	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1055	 1	 3.84	 2.1	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1056	 1	 2.01	 1.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1057	 1	 7.45	 4.05	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1058	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1059	 1	 4.36	 1.98	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1060	 1	 6.94	 3.14	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1061	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1062	 1	 10.61	 4.41	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1063	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1064	 1	 2.94	 1.6	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1065	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1066	 1	 11.56	 4.71	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1067	 1	 4.44	 2.03	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1068	 1	 8.44	 4.41	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1069	 1	 2.65	 1.45	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1070	 1	 10.67	 4.35	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1071	 1	 4.66	 1.91	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1072	 1	 8.17	 3.92	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1073	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1074	 1	 2.03	 1.12	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1075	 1	 4.34	 1.87	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1076	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	1077	 1	 14.7	 6.17	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1078	 1	 8.32	 4.36	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1079	 1	 7.98	 3.46	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1080	 1	 3.04	 0.95	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1081	 1	 1.99	 1.09	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1082	 1	 2.2	 1.15	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1083	 1	 7.32	 3.46	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1084	 1	 2.78	 1.22	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1085	 1	 13.39	 6.79	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1086	 1	 4.83	 2.68	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1087	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1088	 1	 4.13	 1.72	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1089	 1	 2.19	 1.2	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1090	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1091	 1	 3.03	 1.69	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1092	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1093	 1	 4.38	 2.13	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1094	 1	 4.45	 1.87	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1095	 1	 6.23	 2.7	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1096	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1097	 1	 3.76	 1.44	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1098	 1	 6.25	 2.7	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1099	 1	 2.6	 0.59	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1100	 1	 10.57	 5.01	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1101	 1	 6.29	 3.11	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1102	 1	 4.3	 1.98	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1103	 1	 3.33	 1.62	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1104	 1	 13.17	 4.12	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1105	 1	 9.39	 3.42	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1106	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1107	 1	 8.56	 3.65	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1108	 1	 8.35	 4.23	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1109	 1	 9.1	 4.57	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1110	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1111	 1	 2.53	 1.11	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1112	 1	 2.61	 1.23	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1113	 1	 7.79	 1.77	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1114	 1	 1.93	 0.43	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1115	 1	 6.38	 1.44	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1116	 1	 4.0	 1.99	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1117	 1	 11.07	 3.74	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1118	 1	 7.29	 3.05	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1119	 1	 2.17	 1.05	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1120	 1	 3.8	 1.94	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1121	 1	 3.42	 1.85	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1122	 1	 3.94	 1.81	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1123	 1	 6.16	 2.76	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1124	 1	 4.84	 1.97	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1125	 1	 2.48	 1.26	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1126	 1	 4.18	 2.23	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1127	 1	 1.94	 0.91	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1128	 1	 3.85	 1.69	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1129	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1130	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1131	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1132	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1133	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1134	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1135	 1	 8.28	 3.86	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1136	 1	 7.9	 3.2	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1137	 1	 8.21	 3.61	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1138	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1139	 1	 7.15	 2.99	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1140	 1	 15.93	 3.61	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1141	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1142	 1	 4.7	 1.06	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1143	 1	 2.42	 0.54	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1144	 1	 2.5	 1.08	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1145	 1	 3.24	 1.63	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1146	 1	 5.74	 2.57	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1147	 1	 8.33	 3.63	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1148	 1	 4.2	 1.94	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1149	 1	 4.04	 2.02	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1150	 1	 10.58	 5.08	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1151	 1	 5.47	 2.45	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1152	 1	 1.87	 0.78	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1153	 1	 7.31	 3.5	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1154	 1	 9.81	 4.16	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1155	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1156	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1157	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1158	 1	 8.85	 4.18	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1159	 1	 5.54	 2.31	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1160	 1	 3.77	 1.93	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1161	 1	 6.84	 2.89	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1162	 1	 4.33	 2.06	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1163	 1	 1.77	 0.89	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1164	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1165	 1	 3.7	 1.55	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1166	 1	 8.42	 4.27	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1167	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1168	 1	 6.21	 2.82	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1169	 1	 4.9	 2.3	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1170	 1	 2.77	 0.61	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1171	 1	 3.17	 0.71	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1172	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1173	 1	 18.88	 9.29	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1174	 1	 6.04	 3.04	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1175	 1	 4.23	 2.31	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1176	 1	 2.75	 1.56	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1177	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1178	 1	 8.45	 4.47	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1179	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1180	 1	 14.44	 7.17	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1181	 1	 7.66	 3.83	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1182	 1	 6.77	 2.92	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1183	 1	 7.37	 3.75	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1184	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1185	 1	 5.51	 2.44	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1186	 1	 6.77	 3.05	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1187	 1	 10.6	 5.51	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1188	 1	 25.47	 10.75	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1189	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1190	 1	 6.7	 3.46	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1191	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1192	 1	 8.81	 4.76	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1193	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1194	 1	 1.55	 0.82	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1195	 1	 8.61	 3.48	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1196	 1	 9.77	 3.53	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1197	 1	 2.28	 1.17	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1198	 1	 3.12	 1.55	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1199	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1200	 1	 2.05	 1.07	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1201	 1	 2.86	 1.41	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1202	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1203	 1	 1.87	 1.02	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1204	 1	 2.13	 0.92	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1205	 1	 2.85	 1.59	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1206	 1	 2.39	 0.98	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1207	 1	 3.34	 1.66	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1208	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1209	 1	 4.01	 1.88	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1210	 1	 1.28	 0.71	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1211	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1212	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1213	 1	 16.53	 7.1	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1214	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1215	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1216	 1	 7.93	 3.67	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1217	 1	 0.57	 0.28	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1218	 1	 3.0	 1.32	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1219	 1	 0.9	 0.5	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1220	 1	 3.26	 1.47	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1221	 1	 1.72	 0.73	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1222	 1	 9.25	 2.78	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1223	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1224	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1225	 1	 1.62	 0.85	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1226	 1	 4.26	 0.95	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1227	 1	 6.42	 3.15	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1228	 1	 11.83	 5.66	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1229	 1	 5.71	 2.87	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1230	 1	 8.81	 3.97	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1231	 1	 12.69	 6.9	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1232	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1233	 1	 4.62	 1.96	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1234	 1	 3.37	 1.34	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1235	 1	 2.22	 1.15	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1236	 1	 4.74	 1.84	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1237	 1	 3.27	 1.55	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1238	 1	 3.04	 1.55	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1239	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1240	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1241	 1	 3.35	 1.62	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1242	 1	 3.32	 1.18	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1243	 1	 2.34	 0.98	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1244	 1	 5.38	 2.06	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1245	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1246	 1	 5.74	 2.43	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1247	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1248	 1	 10.5	 4.71	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1249	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1250	 1	 2.39	 1.08	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1251	 1	 4.27	 2.19	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1252	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1253	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1254	 1	 5.49	 2.61	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1255	 1	 9.47	 4.78	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1256	 1	 2.14	 0.96	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1257	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1258	 1	 5.13	 2.92	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1259	 1	 3.31	 1.9	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1260	 1	 2.6	 1.49	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1261	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1262	 1	 9.65	 4.54	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1263	 1	 2.58	 1.41	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1264	 1	 3.48	 1.61	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1265	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1266	 1	 3.38	 1.79	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1267	 1	 3.57	 1.97	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1268	 1	 8.81	 3.74	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1269	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1270	 1	 4.79	 2.47	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1271	 1	 9.75	 4.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1272	 1	 4.82	 2.47	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1273	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1274	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1275	 1	 2.98	 1.61	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1276	 1	 5.66	 2.46	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1277	 1	 7.98	 3.87	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1278	 1	 8.01	 4.12	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1279	 1	 4.91	 2.34	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1280	 1	 3.75	 1.78	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1281	 1	 3.55	 1.54	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1282	 1	 4.3	 2.18	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1283	 1	 6.51	 3.57	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1284	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1285	 1	 6.88	 3.61	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1286	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1287	 1	 5.65	 2.45	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1288	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1289	 1	 2.73	 1.41	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1290	 1	 7.47	 3.94	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1291	 1	 4.27	 2.4	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1292	 1	 4.38	 2.13	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1293	 1	 5.83	 2.3	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1294	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1295	 1	 4.17	 2.24	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1296	 1	 5.08	 2.18	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1297	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1298	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1299	 1	 4.72	 2.55	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1300	 1	 21.01	 5.67	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1301	 1	 6.76	 3.61	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1302	 1	 16.66	 6.2	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1303	 1	 15.82	 6.32	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1304	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1305	 1	 6.58	 3.11	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1306	 1	 7.37	 3.51	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1307	 1	 13.44	 5.97	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1308	 1	 6.19	 3.33	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1309	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1310	 1	 37.48	 16.83	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1311	 1	 4.81	 2.46	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1312	 1	 2.99	 1.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1313	 1	 2.25	 0.5	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1314	 1	 2.18	 1.07	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1315	 1	 1.97	 0.44	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1316	 1	 5.11	 1.16	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1317	 1	 9.42	 2.16	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1318	 1	 3.01	 0.69	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1319	 1	 4.76	 2.36	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1320	 1	 3.45	 1.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1321	 1	 5.57	 2.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1322	 1	 3.81	 1.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1323	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1324	 1	 6.76	 2.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1325	 1	 2.53	 1.03	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1326	 1	 2.57	 1.19	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1327	 1	 3.9	 2.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1328	 1	 5.45	 1.96	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1329	 1	 3.02	 1.26	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1330	 1	 1.22	 0.6	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1331	 1	 3.13	 1.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1332	 1	 3.28	 1.43	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1333	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1334	 1	 3.53	 1.57	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1335	 1	 5.43	 2.36	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1336	 1	 4.44	 2.28	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1337	 1	 4.29	 1.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1338	 1	 3.89	 1.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1339	 1	 5.26	 2.63	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1340	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1341	 1	 3.79	 2.02	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1342	 1	 3.51	 1.72	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1343	 1	 3.26	 1.64	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1344	 1	 4.15	 1.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1345	 1	 4.39	 2.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1346	 1	 4.63	 1.88	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1347	 1	 3.67	 1.89	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1348	 1	 5.41	 2.76	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1349	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1350	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1351	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1352	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1353	 1	 14.38	 6.67	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1354	 1	 7.14	 2.85	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1355	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1356	 1	 3.42	 1.31	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1357	 1	 8.97	 4.26	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1358	 1	 4.27	 2.03	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1359	 1	 3.32	 1.81	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1360	 1	 4.41	 1.89	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1361	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1362	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1363	 1	 3.2	 1.65	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1364	 1	 2.8	 1.43	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1365	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1366	 1	 1.35	 0.66	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1367	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1368	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1369	 1	 7.93	 3.99	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1370	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1371	 1	 5.59	 2.84	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1372	 1	 8.31	 3.31	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1373	 1	 4.94	 2.65	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1374	 1	 3.15	 1.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1375	 1	 7.29	 3.67	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1376	 1	 5.79	 2.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1377	 1	 13.49	 6.51	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1378	 1	 4.51	 2.07	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1379	 1	 9.16	 3.58	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1380	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1381	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1382	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1383	 1	 8.11	 3.6	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1384	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1385	 1	 7.87	 3.6	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1386	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1387	 1	 2.83	 1.33	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1388	 1	 11.25	 5.07	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1389	 1	 7.11	 2.66	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1390	 1	 5.43	 2.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1391	 1	 1.83	 0.76	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1392	 1	 11.18	 2.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1393	 1	 5.8	 1.3	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1394	 1	 1.11	 0.6	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1395	 1	 0.94	 0.5	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1396	 1	 1.2	 0.59	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1397	 1	 1.83	 0.99	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1398	 1	 1.95	 0.86	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1399	 1	 0.84	 0.19	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1400	 1	 0.98	 0.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1401	 1	 1.65	 0.38	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1402	 1	 0.85	 0.39	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1403	 1	 1.86	 0.42	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1404	 1	 2.33	 1.1	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1405	 1	 38.17	 16.83	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1406	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1407	 1	 6.45	 2.7	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1408	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1409	 1	 6.69	 3.06	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1410	 1	 3.92	 2.13	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1411	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1412	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1413	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1414	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1415	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1416	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1417	 1	 12.72	 4.51	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1418	 1	 5.95	 2.88	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1419	 1	 8.8	 3.8	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1420	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1421	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1422	 1	 5.03	 2.61	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1423	 1	 5.94	 2.67	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1424	 1	 5.38	 2.12	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1425	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1426	 1	 12.68	 6.69	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1427	 1	 2.39	 1.38	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1428	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1429	 1	 7.11	 3.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1430	 1	 12.57	 5.22	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1431	 1	 8.28	 3.4	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1432	 1	 12.99	 4.88	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1433	 1	 6.27	 3.33	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1434	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1435	 1	 6.85	 3.4	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1436	 1	 3.42	 1.34	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1437	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1438	 1	 26.32	 12.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1439	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1440	 1	 11.43	 4.69	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1441	 1	 16.39	 6.63	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1442	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1443	 1	 8.95	 4.45	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1444	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1445	 1	 9.54	 3.32	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1446	 1	 10.02	 3.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1447	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1448	 1	 10.73	 5.38	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1449	 1	 7.97	 4.31	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1450	 1	 16.83	 8.3	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1451	 1	 4.46	 2.46	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1452	 1	 6.03	 3.03	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1453	 1	 9.45	 5.25	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1454	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1455	 1	 5.8	 2.46	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1456	 1	 4.09	 2.1	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1457	 1	 10.45	 3.82	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1458	 1	 3.66	 1.99	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1459	 1	 2.52	 1.25	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1460	 1	 14.08	 4.55	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1461	 1	 3.56	 1.89	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1462	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1463	 1	 2.96	 1.35	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1464	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1465	 1	 5.73	 2.35	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1466	 1	 5.93	 2.41	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1467	 1	 3.32	 1.8	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1468	 1	 1.52	 0.74	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1469	 1	 8.47	 3.83	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1470	 1	 1.66	 0.75	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1471	 1	 2.99	 1.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1472	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1473	 1	 8.78	 4.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1474	 1	 5.79	 2.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1475	 1	 3.56	 1.89	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1476	 1	 3.12	 1.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1477	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1478	 1	 7.19	 3.21	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1479	 1	 5.11	 2.38	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1480	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1481	 1	 3.42	 1.77	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1482	 1	 7.02	 3.81	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1483	 1	 6.22	 3.15	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1484	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1485	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1486	 1	 1.8	 0.85	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1487	 1	 8.55	 4.4	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1488	 1	 14.25	 5.89	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1489	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1490	 1	 6.87	 3.01	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1491	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1492	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1493	 1	 4.16	 1.88	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1494	 1	 5.31	 2.03	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1495	 1	 4.85	 2.25	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1496	 1	 3.42	 1.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1497	 1	 5.91	 2.61	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1498	 1	 2.8	 1.11	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1499	 1	 6.26	 2.8	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1500	 1	 2.81	 1.46	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1501	 1	 8.48	 3.29	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1502	 1	 5.75	 2.68	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1503	 1	 2.16	 0.93	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1504	 1	 3.54	 1.76	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1505	 1	 3.35	 1.59	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1506	 1	 5.56	 2.55	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1507	 1	 8.77	 4.05	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1508	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1509	 1	 2.2	 1.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1510	 1	 1.84	 0.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1511	 1	 4.42	 1.81	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1512	 1	 2.25	 1.16	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1513	 1	 3.0	 1.16	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1514	 1	 2.32	 1.03	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1515	 1	 3.16	 1.27	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1516	 1	 7.45	 2.83	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1517	 1	 4.73	 1.72	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1518	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1519	 1	 13.57	 5.85	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1520	 1	 6.53	 2.76	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1521	 1	 4.61	 2.03	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1522	 1	 4.55	 1.85	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1523	 1	 3.16	 1.6	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1524	 1	 6.76	 2.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1525	 1	 4.6	 1.92	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1526	 1	 8.41	 3.61	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1527	 1	 7.06	 3.25	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1528	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1529	 1	 4.26	 1.78	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1530	 1	 3.66	 1.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1531	 1	 6.71	 3.31	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1532	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1533	 1	 6.71	 3.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1534	 1	 4.85	 1.1	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1535	 1	 3.92	 0.89	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1536	 1	 2.22	 1.04	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1537	 1	 1.78	 0.85	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1538	 1	 6.01	 2.92	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1539	 1	 4.09	 2.1	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1540	 1	 4.61	 2.48	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1541	 1	 4.48	 1.84	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1542	 1	 3.4	 1.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1543	 1	 3.25	 1.7	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1544	 1	 6.06	 2.61	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1545	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1546	 1	 4.25	 1.87	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1547	 1	 4.23	 1.58	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1548	 1	 5.6	 2.41	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1549	 1	 4.7	 2.03	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1550	 1	 7.28	 2.67	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1551	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1552	 1	 7.23	 3.46	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1553	 1	 4.24	 1.72	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1554	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1555	 1	 2.93	 1.28	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1556	 1	 6.43	 3.32	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1557	 1	 3.76	 1.68	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1558	 1	 2.53	 1.18	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1559	 1	 3.1	 1.57	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1560	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1561	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1562	 1	 2.19	 1.15	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1563	 1	 3.78	 1.91	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1564	 1	 3.43	 1.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1565	 1	 2.52	 1.36	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1566	 1	 4.24	 2.24	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1567	 1	 5.26	 2.06	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1568	 1	 4.65	 2.29	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1569	 1	 2.91	 1.29	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1570	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1571	 1	 4.15	 2.03	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1572	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1573	 1	 3.67	 1.99	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1574	 1	 15.52	 6.17	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1575	 1	 3.53	 1.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1576	 1	 11.32	 5.22	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1577	 1	 5.25	 2.4	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1578	 1	 10.12	 4.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1579	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1580	 1	 7.23	 2.95	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1581	 1	 5.1	 2.64	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1582	 1	 7.57	 3.45	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1583	 1	 7.02	 2.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1584	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1585	 1	 20.8	 9.1	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1586	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1587	 1	 7.0	 2.55	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1588	 1	 3.04	 1.26	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1589	 1	 9.39	 4.02	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1590	 1	 2.78	 1.41	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1591	 1	 13.28	 4.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1592	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1593	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1594	 1	 5.86	 2.5	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1595	 1	 17.48	 8.85	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1596	 1	 9.54	 4.18	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1597	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1598	 1	 6.73	 2.96	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1599	 1	 7.02	 3.11	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1600	 1	 1.93	 1.09	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1601	 1	 6.09	 2.54	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1602	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1603	 1	 2.75	 1.17	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1604	 1	 2.29	 0.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1605	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1606	 1	 6.33	 2.75	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1607	 1	 4.23	 1.95	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1608	 1	 6.35	 2.89	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1609	 1	 6.32	 3.16	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1610	 1	 5.5	 2.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1611	 1	 2.46	 1.09	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1612	 1	 2.79	 1.4	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1613	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1614	 1	 2.6	 1.06	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1615	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1616	 1	 3.2	 1.13	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1617	 1	 4.32	 2.01	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1618	 1	 2.79	 1.26	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1619	 1	 4.48	 1.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1620	 1	 3.0	 1.44	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1621	 1	 4.35	 2.09	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1622	 1	 4.58	 2.18	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1623	 1	 4.97	 2.51	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1624	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1625	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1626	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1627	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1628	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1629	 1	 2.99	 1.33	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1630	 1	 3.65	 1.93	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1631	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1632	 1	 12.34	 6.29	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1633	 1	 1.43	 0.66	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1634	 1	 1.16	 0.6	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1635	 1	 2.84	 1.22	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1636	 1	 2.7	 1.2	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1637	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1638	 1	 5.3	 2.38	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1639	 1	 10.79	 4.57	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1640	 1	 9.2	 4.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1641	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1642	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1643	 1	 3.1	 1.41	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1644	 1	 4.33	 1.69	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1645	 1	 3.76	 1.92	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1646	 1	 3.24	 1.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1647	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1648	 1	 4.07	 2.13	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1649	 1	 3.22	 1.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1650	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1651	 1	 5.15	 2.25	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1652	 1	 5.62	 2.24	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1653	 1	 2.16	 1.08	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1654	 1	 6.73	 2.85	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1655	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1656	 1	 7.47	 3.86	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1657	 1	 9.43	 4.61	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1658	 1	 12.91	 4.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1659	 1	 2.83	 1.28	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1660	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1661	 1	 5.59	 2.44	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1662	 1	 18.72	 7.06	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1663	 1	 3.18	 1.36	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1664	 1	 7.56	 3.62	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1665	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1666	 1	 2.51	 1.17	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1667	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1668	 1	 3.62	 1.52	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1669	 1	 7.18	 3.45	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1670	 1	 3.02	 1.42	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1671	 1	 6.9	 3.22	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1672	 1	 5.45	 2.48	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1673	 1	 2.6	 1.31	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1674	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1675	 1	 6.8	 2.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1676	 1	 4.65	 2.52	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1677	 1	 6.7	 3.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1678	 1	 4.51	 1.84	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1679	 1	 9.01	 4.29	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1680	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1681	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1682	 1	 8.85	 3.6	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1683	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1684	 1	 5.29	 2.58	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1685	 1	 5.86	 2.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1686	 1	 12.41	 4.9	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1687	 1	 3.73	 2.13	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1688	 1	 14.4	 7.33	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1689	 1	 5.45	 1.9	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1690	 1	 2.64	 1.36	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1691	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1692	 1	 1.8	 0.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1693	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1694	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1695	 1	 3.7	 1.92	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1696	 1	 7.33	 4.1	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1697	 1	 7.49	 3.37	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1698	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1699	 1	 7.81	 4.21	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1700	 1	 5.13	 2.06	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1701	 1	 5.8	 2.51	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1702	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1703	 1	 9.98	 4.49	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1704	 1	 3.01	 1.63	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1705	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1706	 1	 6.74	 2.84	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1707	 1	 5.41	 2.02	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1708	 1	 16.14	 8.29	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1709	 1	 5.59	 2.73	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1710	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1711	 1	 6.47	 2.67	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1712	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1713	 1	 5.99	 2.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1714	 1	 3.47	 1.55	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1715	 1	 5.06	 2.28	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1716	 1	 6.09	 3.3	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1717	 1	 7.6	 3.59	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1718	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1719	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1720	 1	 4.18	 2.27	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1721	 1	 7.04	 3.27	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1722	 1	 8.34	 4.45	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1723	 1	 5.6	 2.74	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1724	 1	 7.16	 2.67	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1725	 1	 3.81	 1.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1726	 1	 7.95	 3.3	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1727	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1728	 1	 3.32	 1.8	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1729	 1	 7.74	 3.78	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1730	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1731	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1732	 1	 4.01	 1.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1733	 1	 6.82	 3.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1734	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1735	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1736	 1	 6.94	 2.91	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1737	 1	 7.91	 3.43	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1738	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1739	 1	 2.46	 1.19	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1740	 1	 5.2	 2.66	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1741	 1	 8.81	 4.08	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1742	 1	 4.66	 2.08	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1743	 1	 3.46	 1.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1744	 1	 8.25	 4.28	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1745	 1	 6.07	 2.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1746	 1	 5.03	 2.5	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1747	 1	 3.47	 1.92	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1748	 1	 11.63	 4.64	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1749	 1	 3.06	 1.58	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1750	 1	 5.05	 2.55	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1751	 1	 6.35	 2.91	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1752	 1	 1.24	 0.61	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1753	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1754	 1	 4.87	 1.82	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1755	 1	 7.31	 3.39	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1756	 1	 9.49	 4.66	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1757	 1	 3.1	 1.44	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1758	 1	 5.81	 2.68	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1759	 1	 12.46	 5.19	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1760	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1761	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	1762	 1	 4.95	 2.38	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1763	 1	 5.95	 2.81	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1764	 1	 6.01	 2.67	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1765	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1766	 1	 5.19	 2.76	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1767	 1	 9.91	 4.6	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1768	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1769	 1	 5.57	 2.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1770	 1	 8.22	 4.46	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1771	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1772	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1773	 1	 8.85	 3.3	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1774	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1775	 1	 5.72	 2.52	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1776	 1	 5.4	 2.68	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1777	 1	 5.64	 2.88	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1778	 1	 5.1	 2.75	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1779	 1	 6.1	 3.18	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1780	 1	 11.48	 6.01	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1781	 1	 16.23	 5.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1782	 1	 7.92	 3.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1783	 1	 15.07	 6.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1784	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1785	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1786	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1787	 1	 4.05	 2.04	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1788	 1	 5.54	 2.36	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1789	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1790	 1	 10.89	 5.25	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1791	 1	 7.05	 2.81	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1792	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1793	 1	 19.4	 7.87	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1794	 1	 8.54	 3.84	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1795	 1	 7.71	 3.73	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1796	 1	 2.69	 1.12	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1797	 1	 8.02	 4.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1798	 1	 9.17	 4.39	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1799	 1	 4.43	 1.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1800	 1	 2.62	 1.22	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1801	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1802	 1	 4.08	 2.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1803	 1	 10.9	 4.92	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1804	 1	 2.47	 1.15	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1805	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1806	 1	 6.17	 3.39	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1807	 1	 3.43	 1.67	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1808	 1	 4.4	 2.09	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1809	 1	 7.54	 2.87	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1810	 1	 10.29	 5.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1811	 1	 9.49	 4.51	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1812	 1	 4.8	 2.3	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1813	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1814	 1	 5.59	 2.96	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1815	 1	 4.63	 1.78	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1816	 1	 8.49	 3.68	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1817	 1	 3.76	 1.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1818	 1	 3.06	 1.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1819	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1820	 1	 8.02	 3.91	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1821	 1	 0.86	 0.42	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1822	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1823	 1	 5.01	 2.64	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1824	 1	 5.2	 2.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1825	 1	 9.01	 4.83	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1826	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1827	 1	 5.17	 2.27	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1828	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1829	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1830	 1	 3.26	 1.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1831	 1	 9.78	 4.41	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1832	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1833	 1	 10.83	 4.26	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1834	 1	 5.28	 2.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1835	 1	 4.53	 2.29	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1836	 1	 11.45	 5.07	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1837	 1	 10.18	 4.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1838	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1839	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1840	 1	 10.17	 4.07	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1841	 1	 4.91	 2.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1842	 1	 5.31	 2.48	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1843	 1	 4.2	 1.72	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1844	 1	 5.12	 2.34	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1845	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1846	 1	 4.97	 2.45	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1847	 1	 4.03	 1.75	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1848	 1	 12.16	 4.75	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1849	 1	 5.06	 2.69	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1850	 1	 2.71	 1.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1851	 1	 2.37	 0.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1852	 1	 0.8	 0.44	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1853	 1	 3.2	 1.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1854	 1	 2.38	 1.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1855	 1	 2.01	 0.91	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1856	 1	 6.66	 3.12	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1857	 1	 5.74	 2.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1858	 1	 16.62	 7.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1859	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1860	 1	 4.55	 2.07	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1861	 1	 2.68	 1.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1862	 1	 4.32	 1.76	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1863	 1	 15.82	 5.85	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1864	 1	 7.94	 3.17	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1865	 1	 7.06	 2.88	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1866	 1	 6.08	 2.59	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1867	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1868	 1	 3.28	 1.43	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1869	 1	 16.29	 5.65	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1870	 1	 1.94	 1.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1871	 1	 13.62	 4.91	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1872	 1	 5.46	 2.21	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1873	 1	 5.44	 2.58	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1874	 1	 4.15	 1.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1875	 1	 1.98	 0.83	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1876	 1	 5.24	 2.43	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1877	 1	 13.96	 5.43	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1878	 1	 8.89	 3.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1879	 1	 5.48	 2.35	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1880	 1	 3.92	 1.69	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1881	 1	 3.71	 1.83	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1882	 1	 8.41	 3.93	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1883	 1	 4.41	 2.15	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1884	 1	 3.95	 1.64	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1885	 1	 6.23	 3.09	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1886	 1	 6.64	 3.18	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1887	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1888	 1	 5.69	 2.09	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1889	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1890	 1	 13.23	 5.93	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1891	 1	 4.69	 2.32	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1892	 1	 6.81	 2.6	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1893	 1	 2.45	 1.11	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1894	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1895	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1896	 1	 11.21	 5.36	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1897	 1	 9.84	 4.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1898	 1	 10.23	 4.86	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1899	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1900	 1	 11.63	 4.88	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1901	 1	 21.43	 9.89	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1902	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1903	 1	 12.03	 4.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1904	 1	 3.19	 1.33	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1905	 1	 1.86	 0.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1906	 1	 2.21	 1.13	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1907	 1	 5.78	 2.76	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1908	 1	 8.77	 3.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1909	 1	 6.85	 3.21	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1910	 1	 5.73	 2.44	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1911	 1	 5.84	 2.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1912	 1	 4.9	 2.13	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1913	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1914	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1915	 1	 3.89	 1.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1916	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1917	 1	 11.64	 5.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1918	 1	 8.35	 3.39	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1919	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1920	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1921	 1	 6.59	 3.16	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1922	 1	 6.28	 2.7	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1923	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1924	 1	 9.8	 4.21	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1925	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1926	 1	 5.26	 2.6	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1927	 1	 7.61	 3.3	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1928	 1	 9.02	 4.34	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1929	 1	 11.07	 3.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1930	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1931	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1932	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1933	 1	 3.88	 1.61	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1934	 1	 4.78	 2.02	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1935	 1	 3.59	 1.73	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1936	 1	 2.32	 0.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1937	 1	 6.56	 3.41	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1938	 1	 14.78	 5.99	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1939	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1940	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1941	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1942	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1943	 1	 4.84	 2.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1944	 1	 12.27	 6.1	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1945	 1	 8.42	 3.77	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1946	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1947	 1	 6.02	 3.06	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1948	 1	 8.89	 4.18	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1949	 1	 5.13	 1.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1950	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1951	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1952	 1	 3.32	 1.7	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1953	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	1954	 1	 6.46	 3.35	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1955	 1	 3.78	 1.52	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1956	 1	 9.1	 3.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1957	 1	 13.38	 6.85	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1958	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1959	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1960	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1961	 1	 14.01	 5.73	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1962	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1963	 1	 5.34	 2.49	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1964	 1	 6.08	 3.26	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1965	 1	 6.43	 3.1	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1966	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1967	 1	 4.1	 2.19	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1968	 1	 2.33	 1.21	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1969	 1	 5.36	 2.63	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1970	 1	 2.71	 1.12	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1971	 1	 7.62	 3.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1972	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1973	 1	 5.07	 2.05	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1974	 1	 8.91	 4.03	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1975	 1	 2.89	 1.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1976	 1	 3.75	 1.67	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1977	 1	 5.86	 2.5	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1978	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1979	 1	 7.44	 3.15	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1980	 1	 2.39	 1.32	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1981	 1	 5.81	 2.5	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1982	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1983	 1	 3.95	 1.91	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1984	 1	 8.63	 3.97	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1985	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	1986	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	1987	 1	 5.54	 2.67	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1988	 1	 2.69	 1.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1989	 1	 4.48	 2.07	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1990	 1	 2.77	 1.24	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1991	 1	 7.21	 3.7	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1992	 1	 6.82	 3.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1993	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1994	 1	 7.83	 3.64	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1995	 1	 4.63	 1.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1996	 1	 5.8	 3.11	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	1997	 1	 3.49	 1.7	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1998	 1	 8.96	 4.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	1999	 1	 2.47	 1.24	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2000	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2001	 1	 4.48	 1.95	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2002	 1	 4.72	 2.37	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2003	 1	 3.63	 1.73	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2004	 1	 2.83	 1.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2005	 1	 6.05	 2.92	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2006	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2007	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2008	 1	 4.51	 2.07	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2009	 1	 3.89	 1.57	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2010	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2011	 1	 5.5	 2.5	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2012	 1	 6.1	 3.23	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2013	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2014	 1	 1.06	 0.49	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2015	 1	 3.48	 1.48	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2016	 1	 4.95	 2.65	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2017	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2018	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2019	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2020	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2021	 1	 2.83	 1.45	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2022	 1	 6.14	 2.64	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2023	 1	 5.96	 2.85	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2024	 1	 3.02	 1.41	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2025	 1	 5.05	 2.59	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2026	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2027	 1	 2.21	 1.11	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2028	 1	 8.92	 3.78	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2029	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2030	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	2031	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2032	 1	 3.22	 1.73	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2033	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2034	 1	 2.61	 1.08	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2035	 1	 1.38	 0.74	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2036	 1	 4.8	 2.22	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2037	 1	 5.85	 2.97	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2038	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2039	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2040	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2041	 1	 4.27	 1.93	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2042	 1	 14.7	 6.07	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2043	 1	 2.32	 1.15	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2044	 1	 7.23	 3.85	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2045	 1	 6.74	 2.96	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2046	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2047	 1	 4.88	 2.6	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2048	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2049	 1	 4.28	 1.81	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2050	 1	 6.1	 3.29	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2051	 1	 3.63	 1.84	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2052	 1	 1.33	 0.57	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2053	 1	 1.52	 0.69	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2054	 1	 15.21	 7.54	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2055	 1	 2.15	 1.01	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2056	 1	 1.24	 0.64	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2057	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2058	 1	 2.5	 1.11	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2059	 1	 3.41	 1.82	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2060	 1	 5.8	 2.8	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2061	 1	 7.61	 3.93	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2062	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2063	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2064	 1	 4.85	 1.96	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2065	 1	 5.0	 2.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2066	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2067	 1	 3.07	 1.59	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2068	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2069	 1	 2.38	 1.3	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2070	 1	 1.53	 0.86	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2071	 1	 2.14	 0.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2072	 1	 1.71	 0.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2073	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2074	 1	 3.44	 1.6	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2075	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2076	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2077	 1	 9.54	 3.75	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2078	 1	 3.74	 1.88	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2079	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2080	 1	 3.94	 1.76	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2081	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2082	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2083	 1	 4.1	 1.73	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2084	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2085	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2086	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2087	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2088	 1	 3.29	 1.38	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2089	 1	 10.54	 5.19	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2090	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2091	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2092	 1	 2.6	 1.21	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2093	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2094	 1	 7.95	 3.15	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2095	 1	 6.5	 3.26	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2096	 1	 6.67	 2.88	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2097	 1	 4.68	 2.18	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2098	 1	 7.56	 3.19	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2099	 1	 3.94	 1.7	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2100	 1	 2.35	 1.06	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2101	 1	 7.46	 3.42	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2102	 1	 2.65	 1.18	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2103	 1	 12.69	 4.95	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2104	 1	 8.01	 3.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2105	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2106	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2107	 1	 7.69	 3.76	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2108	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2109	 1	 2.69	 1.15	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2110	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2111	 1	 5.11	 1.78	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2112	 1	 8.43	 3.06	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2113	 1	 6.63	 3.17	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2114	 1	 7.91	 3.38	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2115	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2116	 1	 14.64	 5.86	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2117	 1	 4.23	 1.8	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2118	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2119	 1	 2.83	 1.53	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2120	 1	 4.02	 1.77	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2121	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2122	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2123	 1	 6.3	 3.02	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2124	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2125	 1	 4.71	 1.93	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2126	 1	 4.86	 2.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2127	 1	 6.61	 2.89	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2128	 1	 10.08	 4.02	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2129	 1	 5.61	 2.35	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2130	 1	 8.19	 3.33	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2131	 1	 5.66	 2.52	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2132	 1	 4.67	 1.99	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2133	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2134	 1	 4.81	 2.55	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2135	 1	 5.23	 2.44	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2136	 1	 4.0	 1.74	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2137	 1	 4.63	 2.05	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2138	 1	 3.37	 1.61	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2139	 1	 5.39	 2.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2140	 1	 4.72	 2.44	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2141	 1	 5.53	 2.6	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2142	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2143	 1	 7.52	 3.17	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2144	 1	 6.4	 2.95	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2145	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2146	 1	 3.38	 1.59	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2147	 1	 14.18	 5.57	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2148	 1	 12.5	 5.68	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2149	 1	 16.2	 8.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2150	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2151	 1	 6.79	 3.13	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2152	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2153	 1	 6.33	 2.87	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2154	 1	 5.85	 2.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2155	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2156	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2157	 1	 4.06	 1.63	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2158	 1	 8.55	 4.7	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2159	 1	 6.31	 3.17	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2160	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2161	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2162	 1	 7.07	 3.04	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2163	 1	 3.89	 2.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2164	 1	 14.21	 5.64	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2165	 1	 3.44	 1.46	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2166	 1	 9.23	 3.43	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2167	 1	 11.43	 4.58	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2168	 1	 2.84	 1.54	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2169	 1	 9.46	 4.03	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2170	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2171	 1	 6.56	 2.84	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2172	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2173	 1	 3.68	 1.84	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2174	 1	 1.66	 0.65	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2175	 1	 3.86	 1.51	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2176	 1	 1.01	 0.51	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2177	 1	 8.26	 3.95	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2178	 1	 5.72	 3.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2179	 1	 2.93	 1.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2180	 1	 5.06	 2.34	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2181	 1	 3.69	 1.75	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2182	 1	 5.64	 2.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2183	 1	 5.23	 2.27	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2184	 1	 4.68	 2.1	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2185	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2186	 1	 2.31	 1.1	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2187	 1	 3.21	 1.62	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2188	 1	 9.6	 4.46	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2189	 1	 3.56	 1.78	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2190	 1	 5.79	 2.73	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2191	 1	 2.63	 1.3	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2192	 1	 3.71	 1.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2193	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2194	 1	 10.06	 4.33	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2195	 1	 4.7	 2.51	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2196	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2197	 1	 7.62	 3.61	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2198	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2199	 1	 9.66	 4.45	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2200	 1	 4.02	 1.65	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2201	 1	 5.89	 2.63	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2202	 1	 3.59	 1.52	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2203	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2204	 1	 10.43	 5.04	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2205	 1	 5.59	 2.67	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2206	 1	 7.49	 3.17	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2207	 1	 6.96	 3.65	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2208	 1	 11.0	 4.79	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2209	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2210	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	2211	 1	 11.39	 5.51	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2212	 1	 5.71	 2.13	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2213	 1	 12.99	 6.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2214	 1	 4.2	 2.04	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2215	 1	 7.13	 3.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2216	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2217	 1	 11.85	 5.46	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2218	 1	 4.73	 2.39	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2219	 1	 13.55	 6.57	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2220	 1	 8.08	 3.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2221	 1	 4.53	 1.99	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2222	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2223	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2224	 1	 14.05	 7.03	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2225	 1	 3.42	 1.5	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2226	 1	 5.2	 2.05	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2227	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2228	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2229	 1	 9.17	 4.67	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2230	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2231	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2232	 1	 11.06	 4.81	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2233	 1	 13.32	 6.63	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2234	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2235	 1	 11.26	 4.88	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2236	 1	 4.91	 2.09	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2237	 1	 2.99	 1.34	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2238	 1	 5.34	 2.75	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2239	 1	 6.22	 3.28	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2240	 1	 6.53	 3.64	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2241	 1	 4.04	 2.1	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2242	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2243	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2244	 1	 1.92	 0.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2245	 1	 4.08	 1.78	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2246	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2247	 1	 6.59	 3.55	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2248	 1	 8.25	 3.72	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2249	 1	 8.74	 3.75	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2250	 1	 4.19	 2.18	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2251	 1	 3.8	 2.11	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2252	 1	 2.06	 1.12	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2253	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2254	 1	 3.13	 1.4	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2255	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2256	 1	 5.07	 2.32	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2257	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2258	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2259	 1	 2.52	 1.25	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2260	 1	 8.94	 4.62	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2261	 1	 16.06	 7.31	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2262	 1	 4.14	 2.09	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2263	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2264	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2265	 1	 2.07	 1.11	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2266	 1	 6.67	 3.53	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2267	 1	 3.91	 1.95	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2268	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2269	 1	 10.19	 4.81	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2270	 1	 3.29	 1.35	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2271	 1	 7.33	 3.57	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2272	 1	 9.25	 4.05	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2273	 1	 10.68	 5.4	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2274	 1	 8.2	 3.62	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2275	 1	 9.34	 3.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2276	 1	 5.9	 2.57	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2277	 1	 16.42	 6.68	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2278	 1	 3.77	 1.99	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2279	 1	 16.73	 6.43	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2280	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2281	 1	 4.72	 2.34	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2282	 1	 7.52	 3.92	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2283	 1	 6.36	 2.89	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2284	 1	 4.39	 1.99	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2285	 1	 5.02	 2.52	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2286	 1	 11.18	 5.17	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2287	 1	 17.36	 6.34	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2288	 1	 3.0	 1.28	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2289	 1	 4.55	 2.42	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2290	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2291	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2292	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2293	 1	 4.53	 2.34	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2294	 1	 7.45	 3.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2295	 1	 11.18	 5.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2296	 1	 18.93	 7.65	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2297	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2298	 1	 9.16	 3.36	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2299	 1	 8.12	 4.4	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2300	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2301	 1	 15.53	 7.06	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2302	 1	 5.82	 2.62	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2303	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2304	 1	 10.85	 5.21	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2305	 1	 18.17	 6.51	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2306	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2307	 1	 5.11	 2.65	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2308	 1	 1.5	 0.68	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2309	 1	 3.11	 1.48	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2310	 1	 2.97	 1.36	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2311	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2312	 1	 2.96	 1.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2313	 1	 12.23	 5.24	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2314	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2315	 1	 9.84	 4.88	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2316	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2317	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2318	 1	 14.59	 6.45	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2319	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2320	 1	 4.54	 2.1	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2321	 1	 5.91	 2.61	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2322	 1	 6.2	 2.76	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2323	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2324	 1	 5.82	 2.38	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2325	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2326	 1	 3.65	 1.48	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2327	 1	 7.36	 3.26	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2328	 1	 3.24	 1.77	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2329	 1	 3.6	 1.73	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2330	 1	 6.41	 2.74	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2331	 1	 6.15	 3.13	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2332	 1	 7.71	 3.02	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2333	 1	 5.27	 2.42	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2334	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2335	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2336	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2337	 1	 3.5	 1.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2338	 1	 7.96	 3.84	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2339	 1	 3.11	 1.33	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2340	 1	 4.08	 1.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2341	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2342	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2343	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2344	 1	 4.43	 1.92	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2345	 1	 4.94	 2.18	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2346	 1	 5.29	 2.66	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2347	 1	 11.44	 4.92	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2348	 1	 10.93	 4.4	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2349	 1	 8.43	 3.32	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2350	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2351	 1	 7.14	 3.38	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2352	 1	 2.3	 1.05	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2353	 1	 3.38	 1.62	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2354	 1	 3.56	 1.62	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2355	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2356	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2357	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2358	 1	 8.09	 4.13	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2359	 1	 7.61	 3.09	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2360	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2361	 1	 6.45	 3.32	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2362	 1	 3.99	 1.87	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2363	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2364	 1	 3.27	 1.55	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2365	 1	 4.29	 2.05	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2366	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2367	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2368	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2369	 1	 7.36	 3.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2370	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2371	 1	 4.16	 1.76	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2372	 1	 14.75	 6.8	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2373	 1	 8.32	 3.99	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2374	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2375	 1	 3.23	 1.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2376	 1	 7.49	 3.1	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2377	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2378	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2379	 1	 5.64	 2.13	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2380	 1	 6.08	 2.42	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2381	 1	 3.99	 1.78	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2382	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2383	 1	 7.47	 3.21	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2384	 1	 3.65	 1.95	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2385	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2386	 1	 3.25	 1.58	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2387	 1	 5.43	 2.78	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2388	 1	 3.92	 1.83	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2389	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2390	 1	 1.68	 0.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2391	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2392	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2393	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2394	 1	 5.75	 2.66	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2395	 1	 8.47	 3.25	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2396	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2397	 1	 5.1	 2.57	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2398	 1	 6.31	 3.03	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2399	 1	 6.15	 2.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2400	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2401	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2402	 1	 3.95	 1.7	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2403	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2404	 1	 6.63	 3.37	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2405	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2406	 1	 3.17	 1.35	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2407	 1	 16.81	 6.5	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2408	 1	 2.51	 1.25	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2409	 1	 3.91	 2.06	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2410	 1	 3.07	 1.24	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2411	 1	 2.05	 1.12	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2412	 1	 4.49	 2.24	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2413	 1	 3.38	 1.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2414	 1	 4.86	 2.45	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2415	 1	 1.44	 0.75	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2416	 1	 3.5	 1.84	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2417	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2418	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2419	 1	 3.28	 1.55	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2420	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2421	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2422	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2423	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2424	 1	 4.36	 2.2	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2425	 1	 6.08	 3.11	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2426	 1	 8.96	 3.76	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2427	 1	 7.98	 4.01	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2428	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2429	 1	 3.28	 1.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2430	 1	 4.55	 2.35	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2431	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2432	 1	 0.93	 0.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2433	 1	 9.01	 3.67	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2434	 1	 10.48	 4.52	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2435	 1	 2.74	 1.22	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2436	 1	 6.02	 3.07	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2437	 1	 1.82	 0.82	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2438	 1	 3.0	 1.41	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2439	 1	 2.77	 1.53	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2440	 1	 2.88	 1.25	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2441	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2442	 1	 1.15	 0.61	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2443	 1	 8.88	 3.65	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2444	 1	 1.27	 0.62	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2445	 1	 2.34	 1.07	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2446	 1	 33.13	 15.52	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2447	 1	 2.41	 1.01	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2448	 1	 15.73	 7.62	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2449	 1	 1.41	 0.77	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2450	 1	 2.05	 0.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2451	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2452	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2453	 1	 13.53	 5.3	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2454	 1	 7.74	 3.52	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2455	 1	 3.46	 1.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2456	 1	 4.42	 2.08	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2457	 1	 6.17	 2.96	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2458	 1	 3.93	 1.95	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2459	 1	 1.21	 0.52	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2460	 1	 2.1	 0.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2461	 1	 2.94	 1.33	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2462	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2463	 1	 3.47	 1.8	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2464	 1	 7.1	 3.01	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2465	 1	 6.46	 3.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2466	 1	 2.91	 1.55	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2467	 1	 1.25	 0.59	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2468	 1	 2.01	 0.95	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2469	 1	 4.26	 2.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2470	 1	 9.86	 4.41	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2471	 1	 26.43	 13.03	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2472	 1	 1.49	 0.77	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2473	 1	 3.76	 1.74	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2474	 1	 3.28	 1.63	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2475	 1	 2.46	 1.18	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2476	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2477	 1	 42.05	 21.83	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2478	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2479	 1	 10.01	 4.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2480	 1	 7.99	 3.29	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2481	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2482	 1	 2.46	 1.29	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2483	 1	 3.88	 1.7	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2484	 1	 2.43	 1.06	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2485	 1	 2.42	 1.08	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2486	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2487	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2488	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2489	 1	 1.22	 0.63	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2490	 1	 3.8	 2.06	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2491	 1	 3.65	 1.88	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2492	 1	 3.93	 1.74	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2493	 1	 3.75	 1.61	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2494	 1	 3.43	 1.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2495	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2496	 1	 7.8	 3.46	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2497	 1	 2.44	 1.27	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2498	 1	 5.36	 2.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2499	 1	 3.59	 1.83	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2500	 1	 2.96	 1.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2501	 1	 5.09	 2.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2502	 1	 2.52	 1.11	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2503	 1	 2.17	 1.19	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2504	 1	 1.9	 0.85	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2505	 1	 3.31	 1.77	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2506	 1	 2.98	 1.66	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2507	 1	 2.02	 0.92	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2508	 1	 2.58	 1.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2509	 1	 2.39	 1.1	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2510	 1	 2.64	 1.09	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2511	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2512	 1	 9.52	 4.57	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2513	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2514	 1	 3.17	 1.74	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2515	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2516	 1	 3.26	 1.58	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2517	 1	 1.91	 0.96	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2518	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2519	 1	 3.87	 1.87	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2520	 1	 2.63	 1.25	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2521	 1	 2.57	 1.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2522	 1	 2.52	 1.15	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2523	 1	 4.24	 2.32	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2524	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2525	 1	 2.44	 1.15	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2526	 1	 2.39	 1.29	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2527	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2528	 1	 4.86	 2.09	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2529	 1	 3.14	 1.51	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2530	 1	 2.53	 1.11	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2531	 1	 3.17	 1.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2532	 1	 4.79	 2.34	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2533	 1	 3.36	 1.62	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2534	 1	 4.36	 1.96	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2535	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2536	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2537	 1	 5.6	 2.75	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2538	 1	 5.23	 2.53	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2539	 1	 4.56	 2.32	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2540	 1	 2.31	 1.18	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2541	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2542	 1	 12.22	 5.62	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2543	 1	 1.59	 0.85	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2544	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2545	 1	 2.33	 1.01	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2546	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2547	 1	 2.69	 1.19	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2548	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2549	 1	 3.44	 1.38	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2550	 1	 8.2	 4.27	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2551	 1	 1.36	 0.72	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2552	 1	 1.74	 0.95	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2553	 1	 1.59	 0.75	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2554	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2555	 1	 4.38	 2.11	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2556	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2557	 1	 2.09	 1.05	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2558	 1	 1.52	 0.72	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2559	 1	 9.34	 4.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2560	 1	 5.73	 2.8	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2561	 1	 5.32	 2.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2562	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2563	 1	 14.58	 7.08	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2564	 1	 2.51	 1.01	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2565	 1	 3.65	 1.89	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2566	 1	 10.06	 4.44	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2567	 1	 2.72	 1.18	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2568	 1	 3.06	 1.25	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2569	 1	 1.65	 0.82	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2570	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2571	 1	 3.67	 1.58	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2572	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2573	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2574	 1	 6.64	 3.07	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2575	 1	 2.64	 1.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2576	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2577	 1	 10.79	 3.95	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2578	 1	 3.69	 2.08	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2579	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2580	 1	 4.52	 2.02	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2581	 1	 4.52	 2.46	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2582	 1	 5.53	 2.51	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2583	 1	 4.8	 2.02	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2584	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2585	 1	 6.95	 2.76	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2586	 1	 3.49	 1.43	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2587	 1	 5.29	 2.4	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2588	 1	 5.84	 3.08	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2589	 1	 11.59	 6.22	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2590	 1	 4.76	 2.42	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2591	 1	 3.34	 1.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2592	 1	 3.86	 1.77	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2593	 1	 6.38	 3.07	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2594	 1	 2.73	 1.36	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2595	 1	 1.12	 0.6	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2596	 1	 2.78	 1.41	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2597	 1	 0.66	 0.28	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2598	 1	 1.47	 0.69	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2599	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2600	 1	 4.4	 1.76	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2601	 1	 2.42	 0.96	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2602	 1	 1.82	 0.91	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2603	 1	 19.83	 8.21	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2604	 1	 17.68	 7.97	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2605	 1	 0.01	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2606	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2607	 1	 0.81	 0.35	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2608	 1	 0.31	 0.09	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2609	 1	 3.69	 1.83	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2610	 1	 0.56	 0.25	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2611	 1	 8.41	 4.17	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2612	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2613	 1	 2.9	 1.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2614	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2615	 1	 10.25	 4.55	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2616	 1	 5.74	 2.93	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2617	 1	 2.78	 1.22	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2618	 1	 12.41	 5.85	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2619	 1	 2.92	 1.5	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2620	 1	 9.08	 4.42	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2621	 1	 10.2	 4.06	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2622	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2623	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2624	 1	 13.14	 6.22	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2625	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2626	 1	 6.67	 3.15	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2627	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2628	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2629	 1	 7.44	 2.44	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2630	 1	 11.86	 4.96	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2631	 1	 9.08	 4.28	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2632	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2633	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2634	 1	 7.69	 3.58	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2635	 1	 16.3	 6.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2636	 1	 6.47	 2.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2637	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2638	 1	 4.16	 1.86	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2639	 1	 4.26	 1.63	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2640	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2641	 1	 5.03	 1.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2642	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2643	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2644	 1	 6.23	 2.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2645	 1	 7.66	 3.07	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2646	 1	 7.8	 2.57	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2647	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2648	 1	 6.33	 2.78	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2649	 1	 9.09	 4.29	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2650	 1	 9.68	 3.41	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2651	 1	 4.73	 1.82	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2652	 1	 4.28	 2.13	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2653	 1	 6.35	 3.16	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2654	 1	 8.57	 3.41	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2655	 1	 2.23	 1.12	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2656	 1	 1.3	 0.58	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2657	 1	 5.58	 2.33	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2658	 1	 13.55	 6.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2659	 1	 5.55	 2.35	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2660	 1	 11.91	 4.3	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2661	 1	 5.48	 2.38	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2662	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2663	 1	 6.38	 2.88	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2664	 1	 8.03	 3.02	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2665	 1	 11.95	 5.57	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2666	 1	 2.67	 1.28	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2667	 1	 5.97	 2.84	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2668	 1	 5.99	 2.87	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2669	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2670	 1	 6.22	 3.2	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2671	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2672	 1	 4.03	 1.93	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2673	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2674	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2675	 1	 5.57	 2.62	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2676	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2677	 1	 8.87	 3.6	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2678	 1	 7.95	 3.36	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2679	 1	 2.39	 1.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2680	 1	 1.33	 0.63	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2681	 1	 2.22	 0.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2682	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2683	 1	 10.16	 4.78	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2684	 1	 5.88	 2.6	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2685	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2686	 1	 3.38	 1.38	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2687	 1	 4.17	 1.62	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2688	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2689	 1	 4.08	 1.75	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2690	 1	 4.64	 1.77	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2691	 1	 4.89	 2.52	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2692	 1	 7.91	 3.62	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2693	 1	 8.17	 3.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2694	 1	 18.51	 7.15	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2695	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2696	 1	 15.45	 7.75	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2697	 1	 9.23	 4.32	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2698	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2699	 1	 2.78	 1.16	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2700	 1	 4.5	 2.08	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2701	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2702	 1	 5.47	 2.82	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2703	 1	 2.8	 1.38	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2704	 1	 7.54	 3.7	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2705	 1	 9.18	 4.21	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2706	 1	 3.03	 1.53	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2707	 1	 3.77	 1.7	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2708	 1	 6.38	 2.86	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2709	 1	 5.82	 2.3	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2710	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2711	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2712	 1	 10.4	 3.78	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2713	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2714	 1	 5.0	 2.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2715	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2716	 1	 5.74	 2.46	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2717	 1	 8.09	 4.16	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2718	 1	 2.68	 1.24	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2719	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2720	 1	 2.25	 1.08	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2721	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2722	 1	 9.2	 4.12	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2723	 1	 3.85	 1.61	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2724	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2725	 1	 6.06	 2.61	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2726	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2727	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2728	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2729	 1	 7.96	 3.28	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2730	 1	 4.85	 2.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2731	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2732	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2733	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2734	 1	 14.51	 5.83	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2735	 1	 3.99	 1.88	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2736	 1	 9.63	 4.2	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2737	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2738	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2739	 1	 3.54	 1.96	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2740	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2741	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2742	 1	 6.3	 3.43	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2743	 1	 3.95	 1.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2744	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2745	 1	 4.2	 2.18	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2746	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2747	 1	 5.75	 2.69	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2748	 1	 9.0	 4.21	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2749	 1	 4.16	 1.81	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2750	 1	 4.69	 2.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2751	 1	 2.33	 1.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2752	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2753	 1	 7.38	 3.19	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2754	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2755	 1	 8.46	 3.75	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2756	 1	 4.33	 1.97	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2757	 1	 8.53	 3.86	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2758	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2759	 1	 6.79	 3.6	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2760	 1	 11.61	 4.36	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2761	 1	 12.85	 5.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2762	 1	 11.63	 5.46	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2763	 1	 8.28	 4.11	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2764	 1	 5.55	 2.53	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2765	 1	 2.76	 1.44	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2766	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2767	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2768	 1	 12.19	 5.01	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2769	 1	 10.18	 5.17	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2770	 1	 17.44	 8.73	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2771	 1	 4.69	 1.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2772	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2773	 1	 4.13	 1.83	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2774	 1	 6.53	 3.36	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2775	 1	 2.33	 1.22	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2776	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2777	 1	 2.49	 1.02	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2778	 1	 3.17	 1.45	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2779	 1	 11.96	 5.73	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2780	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2781	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2782	 1	 16.01	 7.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2783	 1	 5.05	 1.17	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2784	 1	 3.09	 0.7	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2785	 1	 3.71	 1.74	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2786	 1	 2.62	 1.15	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2787	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2788	 1	 3.1	 1.27	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2789	 1	 4.48	 2.06	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2790	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2791	 1	 7.11	 2.99	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2792	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2793	 1	 6.07	 2.92	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2794	 1	 4.04	 0.93	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2795	 1	 6.78	 1.57	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2796	 1	 6.82	 1.57	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2797	 1	 6.46	 3.08	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2798	 1	 5.98	 2.58	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2799	 1	 10.07	 4.18	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2800	 1	 6.84	 3.2	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2801	 1	 4.33	 1.75	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2802	 1	 6.17	 2.69	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2803	 1	 2.34	 0.53	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2804	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2805	 1	 4.53	 1.91	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2806	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2807	 1	 4.1	 0.91	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2808	 1	 2.76	 0.63	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2809	 1	 3.58	 1.77	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2810	 1	 7.82	 3.38	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2811	 1	 6.33	 1.43	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2812	 1	 14.03	 5.06	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2813	 1	 7.2	 3.37	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2814	 1	 4.46	 2.1	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2815	 1	 8.84	 4.39	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2816	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2817	 1	 8.53	 4.14	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2818	 1	 11.45	 5.41	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2819	 1	 4.93	 2.41	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2820	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2821	 1	 8.13	 3.92	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2822	 1	 6.78	 3.52	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2823	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2824	 1	 5.9	 2.61	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2825	 1	 1.58	 0.69	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2826	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2827	 1	 2.49	 1.25	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2828	 1	 8.32	 3.81	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2829	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2830	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2831	 1	 3.09	 1.76	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2832	 1	 4.89	 2.32	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2833	 1	 7.21	 3.61	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2834	 1	 4.81	 2.43	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2835	 1	 4.01	 1.75	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2836	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2837	 1	 13.53	 5.49	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2838	 1	 6.08	 1.39	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2839	 1	 9.17	 4.07	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2840	 1	 4.05	 0.89	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2841	 1	 8.64	 3.46	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2842	 1	 3.77	 0.87	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2843	 1	 6.65	 1.5	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2844	 1	 2.83	 1.31	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2845	 1	 13.0	 3.01	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2846	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2847	 1	 8.59	 1.96	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2848	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2849	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2850	 1	 4.67	 2.37	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2851	 1	 4.42	 2.03	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2852	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2853	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2854	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2855	 1	 2.47	 1.23	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2856	 1	 4.85	 2.14	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2857	 1	 2.12	 1.07	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2858	 1	 3.19	 1.64	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2859	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2860	 1	 4.92	 2.26	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2861	 1	 2.53	 1.2	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2862	 1	 3.02	 1.61	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2863	 1	 1.76	 0.83	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2864	 1	 10.23	 4.21	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2865	 1	 4.32	 2.26	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2866	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2867	 1	 5.68	 2.9	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2868	 1	 2.28	 1.12	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2869	 1	 4.39	 2.27	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2870	 1	 2.49	 1.17	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2871	 1	 2.83	 1.29	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2872	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2873	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2874	 1	 6.37	 2.97	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2875	 1	 15.08	 7.18	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2876	 1	 2.41	 0.96	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2877	 1	 7.7	 3.41	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2878	 1	 2.7	 1.42	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2879	 1	 4.33	 1.89	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2880	 1	 9.03	 4.35	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2881	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2882	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2883	 1	 3.58	 1.5	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2884	 1	 5.52	 2.6	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2885	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2886	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2887	 1	 9.06	 4.39	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2888	 1	 6.64	 2.75	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2889	 1	 4.96	 2.06	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2890	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2891	 1	 3.58	 1.54	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2892	 1	 3.88	 1.88	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2893	 1	 5.51	 2.45	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2894	 1	 8.42	 2.63	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2895	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2896	 1	 7.63	 3.65	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2897	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2898	 1	 7.05	 3.58	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2899	 1	 6.56	 3.52	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2900	 1	 2.32	 1.03	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2901	 1	 19.27	 7.41	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2902	 1	 7.93	 3.69	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2903	 1	 6.58	 3.36	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2904	 1	 9.23	 4.3	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2905	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2906	 1	 4.57	 2.25	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2907	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2908	 1	 10.11	 3.79	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2909	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2910	 1	 7.93	 3.64	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2911	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2912	 1	 4.45	 1.93	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2913	 1	 4.74	 2.37	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2914	 1	 12.21	 4.99	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2915	 1	 4.31	 2.13	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2916	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2917	 1	 2.87	 1.46	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2918	 1	 13.12	 5.94	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2919	 1	 14.76	 4.12	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2920	 1	 8.33	 3.46	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2921	 1	 4.21	 2.03	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2922	 1	 3.99	 0.91	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2923	 1	 1.23	 0.62	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2924	 1	 9.62	 2.15	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2925	 1	 1.55	 0.74	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2926	 1	 1.89	 0.93	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2927	 1	 11.46	 4.55	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2928	 1	 7.53	 3.03	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2929	 1	 7.63	 3.28	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2930	 1	 6.38	 2.92	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2931	 1	 11.05	 2.51	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2932	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2933	 1	 2.15	 0.87	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2934	 1	 2.46	 0.56	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2935	 1	 10.53	 2.42	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2936	 1	 5.17	 2.53	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2937	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2938	 1	 4.24	 1.93	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2939	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2940	 1	 9.15	 2.19	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2941	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2942	 1	 6.4	 3.34	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2943	 1	 6.17	 3.21	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2944	 1	 13.58	 6.63	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2945	 1	 3.27	 1.54	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2946	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2947	 1	 5.76	 2.39	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2948	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2949	 1	 6.17	 2.5	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2950	 1	 6.15	 2.56	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2951	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2952	 1	 14.95	 6.08	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2953	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2954	 1	 2.0	 1.05	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2955	 1	 5.69	 2.57	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2956	 1	 12.29	 5.06	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2957	 1	 9.02	 4.35	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2958	 1	 3.72	 1.82	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2959	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2960	 1	 6.2	 3.1	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2961	 1	 9.08	 3.62	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2962	 1	 2.15	 0.91	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2963	 1	 5.68	 2.32	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2964	 1	 5.77	 2.69	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2965	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2966	 1	 6.51	 2.61	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2967	 1	 6.62	 1.49	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2968	 1	 5.15	 2.52	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2969	 1	 4.11	 2.23	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2970	 1	 5.39	 2.74	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2971	 1	 13.6	 5.92	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2972	 1	 12.51	 6.02	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2973	 1	 7.19	 2.5	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2974	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	2975	 1	 6.72	 2.79	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2976	 1	 3.67	 1.71	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2977	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2978	 1	 5.47	 2.83	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2979	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2980	 1	 8.64	 3.7	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2981	 1	 6.86	 2.83	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2982	 1	 5.27	 2.28	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2983	 1	 7.77	 3.84	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2984	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2985	 1	 3.54	 1.97	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2986	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2987	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2988	 1	 3.01	 1.53	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2989	 1	 5.43	 2.95	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2990	 1	 5.4	 2.61	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2991	 1	 4.46	 2.2	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2992	 1	 4.64	 2.25	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2993	 1	 3.61	 1.69	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2994	 1	 3.88	 2.06	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2995	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2996	 1	 5.52	 2.82	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2997	 1	 3.37	 1.67	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	2998	 1	 6.39	 2.75	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	2999	 1	 4.54	 2.1	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3000	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3001	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3002	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3003	 1	 2.54	 1.28	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3004	 1	 3.54	 1.5	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3005	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3006	 1	 7.74	 3.39	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3007	 1	 2.35	 1.33	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3008	 1	 18.59	 9.3	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3009	 1	 1.83	 0.86	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3010	 1	 1.13	 0.57	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3011	 1	 4.7	 1.47	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3012	 1	 3.03	 1.43	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3013	 1	 8.28	 3.43	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3014	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3015	 1	 10.75	 4.67	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3016	 1	 3.89	 1.88	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3017	 1	 4.96	 2.55	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3018	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3019	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3020	 1	 5.15	 2.46	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3021	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3022	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3023	 1	 6.5	 2.96	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3024	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3025	 1	 9.0	 3.74	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3026	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3027	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3028	 1	 4.01	 2.11	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3029	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3030	 1	 6.81	 2.83	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3031	 1	 3.57	 1.64	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3032	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3033	 1	 8.6	 3.71	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3034	 1	 6.02	 3.23	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3035	 1	 12.31	 5.35	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3036	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3037	 1	 7.28	 3.59	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3038	 1	 13.08	 5.73	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3039	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3040	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3041	 1	 8.89	 3.47	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3042	 1	 2.52	 1.29	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3043	 1	 4.73	 2.46	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3044	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3045	 1	 3.63	 1.82	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3046	 1	 10.6	 4.64	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3047	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3048	 1	 5.49	 2.88	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3049	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3050	 1	 4.51	 1.46	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3051	 1	 10.51	 4.89	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3052	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3053	 1	 3.84	 1.56	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3054	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3055	 1	 12.28	 6.01	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3056	 1	 6.31	 3.18	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3057	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3058	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3059	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3060	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3061	 1	 4.75	 2.35	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3062	 1	 9.55	 3.96	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3063	 1	 3.37	 1.68	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3064	 1	 7.69	 3.11	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3065	 1	 6.64	 1.52	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3066	 1	 5.02	 1.12	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3067	 1	 4.1	 1.93	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3068	 1	 6.39	 2.37	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3069	 1	 3.08	 1.48	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3070	 1	 15.24	 5.58	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3071	 1	 3.83	 1.67	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3072	 1	 4.26	 0.96	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3073	 1	 9.03	 2.08	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3074	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3075	 1	 6.78	 3.31	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3076	 1	 6.96	 3.16	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3077	 1	 3.38	 1.67	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3078	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3079	 1	 4.13	 2.4	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3080	 1	 2.55	 1.32	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3081	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3082	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3083	 1	 4.82	 2.18	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3084	 1	 4.24	 2.0	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3085	 1	 12.35	 5.53	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3086	 1	 6.34	 3.3	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3087	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3088	 1	 7.02	 3.25	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3089	 1	 6.22	 3.45	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3090	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3091	 1	 5.33	 2.99	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3092	 1	 3.34	 1.55	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3093	 1	 7.97	 3.8	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3094	 1	 4.73	 2.29	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3095	 1	 9.09	 4.48	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3096	 1	 6.55	 2.95	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3097	 1	 7.13	 3.63	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3098	 1	 1.66	 0.78	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3099	 1	 3.25	 1.55	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3100	 1	 7.26	 4.07	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3101	 1	 5.79	 2.96	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3102	 1	 3.58	 1.72	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3103	 1	 14.94	 7.67	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3104	 1	 2.99	 1.41	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3105	 1	 2.8	 1.31	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3106	 1	 6.3	 2.44	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3107	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3108	 1	 3.49	 1.56	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3109	 1	 3.44	 1.72	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3110	 1	 5.18	 2.87	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3111	 1	 2.26	 1.09	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3112	 1	 1.84	 1.12	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3113	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3114	 1	 1.29	 0.63	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3115	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3116	 1	 2.94	 1.7	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3117	 1	 2.63	 1.48	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3118	 1	 2.82	 1.23	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3119	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3120	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3121	 1	 16.24	 8.19	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3122	 1	 5.7	 3.19	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3123	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3124	 1	 9.15	 4.86	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3125	 1	 1.36	 0.71	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3126	 1	 1.93	 0.87	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3127	 1	 4.48	 2.26	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3128	 1	 6.21	 3.09	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3129	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3130	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3131	 1	 3.13	 1.36	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3132	 1	 2.8	 1.63	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3133	 1	 7.59	 3.15	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3134	 1	 7.08	 3.14	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3135	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3136	 1	 6.43	 2.98	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3137	 1	 2.19	 1.11	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3138	 1	 2.0	 1.11	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3139	 1	 4.39	 1.91	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3140	 1	 3.59	 1.75	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3141	 1	 1.65	 0.88	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3142	 1	 1.09	 0.51	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3143	 1	 4.25	 1.82	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3144	 1	 2.17	 1.26	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3145	 1	 3.33	 1.82	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3146	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3147	 1	 3.68	 1.71	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3148	 1	 5.08	 2.54	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3149	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3150	 1	 4.87	 2.32	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3151	 1	 6.76	 3.36	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3152	 1	 7.57	 3.53	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3153	 1	 2.6	 1.26	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3154	 1	 2.35	 1.25	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3155	 1	 42.56	 23.66	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3156	 1	 4.77	 2.74	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3157	 1	 11.98	 7.09	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3158	 1	 2.53	 1.13	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3159	 1	 1.97	 1.02	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3160	 1	 2.88	 1.43	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3161	 1	 6.21	 3.17	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3162	 1	 2.73	 1.66	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3163	 1	 5.89	 2.85	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3164	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3165	 1	 6.08	 3.03	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3166	 1	 2.45	 1.29	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3167	 1	 6.71	 3.1	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3168	 1	 5.44	 2.48	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3169	 1	 4.23	 2.47	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3170	 1	 2.04	 0.96	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3171	 1	 4.06	 2.17	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3172	 1	 4.6	 2.67	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3173	 1	 8.44	 4.65	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3174	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3175	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3176	 1	 4.33	 2.0	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3177	 1	 4.66	 2.61	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3178	 1	 4.95	 2.24	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3179	 1	 15.39	 7.32	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3180	 1	 5.42	 2.62	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3181	 1	 2.16	 1.17	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3182	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3183	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3184	 1	 6.46	 2.99	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3185	 1	 12.51	 6.45	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3186	 1	 6.87	 4.16	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3187	 1	 3.38	 1.89	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3188	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3189	 1	 4.07	 1.62	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3190	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3191	 1	 11.71	 6.11	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3192	 1	 8.04	 4.66	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3193	 1	 6.57	 3.68	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3194	 1	 12.26	 5.88	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3195	 1	 5.47	 3.22	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3196	 1	 2.49	 1.35	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3197	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3198	 1	 4.49	 2.05	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3199	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3200	 1	 3.74	 2.04	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3201	 1	 2.98	 1.53	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3202	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3203	 1	 10.64	 4.84	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3204	 1	 2.76	 1.42	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3205	 1	 7.62	 3.77	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3206	 1	 3.13	 1.75	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3207	 1	 4.97	 2.74	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3208	 1	 7.33	 3.46	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3209	 1	 14.75	 5.7	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3210	 1	 4.21	 2.29	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3211	 1	 3.85	 1.8	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3212	 1	 6.4	 3.55	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3213	 1	 3.1	 1.55	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3214	 1	 5.1	 2.94	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3215	 1	 7.93	 4.53	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3216	 1	 3.55	 1.49	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3217	 1	 1.71	 1.03	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3218	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3219	 1	 13.41	 7.41	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3220	 1	 9.0	 3.95	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3221	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3222	 1	 2.55	 1.32	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3223	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3224	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3225	 1	 12.52	 5.86	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3226	 1	 5.32	 2.96	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3227	 1	 7.96	 3.94	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3228	 1	 5.48	 3.18	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3229	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3230	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3231	 1	 4.24	 2.6	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3232	 1	 9.04	 5.14	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3233	 1	 16.15	 8.82	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3234	 1	 4.03	 1.84	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3235	 1	 4.35	 2.15	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3236	 1	 4.58	 2.47	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3237	 1	 4.09	 2.07	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3238	 1	 3.07	 1.86	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3239	 1	 5.82	 2.59	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3240	 1	 4.92	 2.52	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3241	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3242	 1	 4.97	 2.81	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3243	 1	 3.84	 2.08	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3244	 1	 3.87	 1.92	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3245	 1	 4.15	 2.01	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3246	 1	 10.29	 4.97	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3247	 1	 7.81	 4.15	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3248	 1	 12.03	 5.96	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3249	 1	 3.85	 2.2	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3250	 1	 3.65	 1.72	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3251	 1	 3.05	 1.81	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3252	 1	 3.31	 1.48	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3253	 1	 8.37	 4.97	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3254	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3255	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3256	 1	 7.0	 3.24	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3257	 1	 6.83	 3.61	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3258	 1	 3.24	 1.52	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3259	 1	 2.06	 1.15	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3260	 1	 2.28	 1.36	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3261	 1	 3.04	 1.8	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3262	 1	 3.18	 1.42	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3263	 1	 3.11	 1.54	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3264	 1	 2.82	 1.45	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3265	 1	 3.59	 1.96	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3266	 1	 3.62	 2.02	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3267	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3268	 1	 2.87	 1.15	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3269	 1	 5.1	 2.5	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3270	 1	 5.56	 2.82	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3271	 1	 1.45	 0.77	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3272	 1	 6.76	 3.2	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3273	 1	 3.91	 1.94	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3274	 1	 1.87	 0.99	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3275	 1	 4.72	 2.09	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3276	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3277	 1	 2.45	 1.24	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3278	 1	 3.95	 1.99	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3279	 1	 2.54	 1.22	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3280	 1	 1.91	 1.01	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3281	 1	 2.2	 1.11	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3282	 1	 2.0	 1.12	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3283	 1	 3.45	 1.4	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3284	 1	 6.2	 2.47	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3285	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3286	 1	 1.55	 0.88	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3287	 1	 1.57	 0.91	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3288	 1	 6.11	 3.56	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3289	 1	 11.04	 4.57	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3290	 1	 3.23	 1.48	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3291	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3292	 1	 19.55	 9.42	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3293	 1	 2.55	 1.5	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3294	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3295	 1	 3.37	 1.77	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3296	 1	 4.53	 2.5	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3297	 1	 1.74	 0.97	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3298	 1	 5.12	 2.67	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3299	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3300	 1	 8.0	 3.56	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3301	 1	 6.0	 2.86	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3302	 1	 7.52	 3.27	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3303	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3304	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3305	 1	 1.88	 0.86	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3306	 1	 4.21	 2.42	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3307	 1	 2.65	 1.22	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3308	 1	 4.39	 2.39	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3309	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3310	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3311	 1	 1.28	 0.63	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3312	 1	 2.98	 1.32	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3313	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3314	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3315	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3316	 1	 3.66	 1.66	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3317	 1	 4.08	 2.3	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3318	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3319	 1	 2.26	 1.1	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3320	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3321	 1	 6.42	 3.2	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3322	 1	 3.3	 1.82	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3323	 1	 4.66	 1.93	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3324	 1	 8.82	 3.08	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3325	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3326	 1	 5.41	 2.65	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3327	 1	 1.74	 0.89	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3328	 1	 3.49	 1.28	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3329	 1	 0.78	 0.42	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3330	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3331	 1	 1.36	 0.55	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3332	 1	 3.01	 1.27	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3333	 1	 6.41	 1.95	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3334	 1	 3.78	 1.92	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3335	 1	 4.78	 2.14	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3336	 1	 12.03	 4.92	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3337	 1	 6.04	 2.86	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3338	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3339	 1	 4.36	 1.58	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3340	 1	 3.28	 0.77	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3341	 1	 1.56	 0.83	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3342	 1	 5.8	 2.08	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3343	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3344	 1	 7.91	 1.81	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3345	 1	 7.87	 1.8	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3346	 1	 2.0	 0.46	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3347	 1	 2.73	 0.63	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3348	 1	 2.73	 0.63	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3349	 1	 4.23	 0.97	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3350	 1	 3.23	 1.77	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3351	 1	 5.12	 2.31	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3352	 1	 3.37	 1.54	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3353	 1	 2.28	 1.09	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3354	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3355	 1	 4.75	 2.76	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3356	 1	 3.39	 1.49	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3357	 1	 2.68	 1.38	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3358	 1	 12.99	 5.66	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3359	 1	 9.88	 3.49	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3360	 1	 2.01	 1.14	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3361	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3362	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3363	 1	 1.82	 0.85	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3364	 1	 7.46	 3.71	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3365	 1	 4.96	 1.98	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3366	 1	 3.73	 2.03	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3367	 1	 5.54	 2.67	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3368	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3369	 1	 7.53	 4.09	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3370	 1	 8.08	 3.12	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3371	 1	 5.99	 2.72	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3372	 1	 4.73	 2.53	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3373	 1	 3.41	 1.44	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3374	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3375	 1	 3.96	 1.87	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3376	 1	 9.68	 5.04	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3377	 1	 12.51	 5.02	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3378	 1	 3.61	 1.66	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3379	 1	 7.23	 3.11	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3380	 1	 1.58	 0.67	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3381	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3382	 1	 8.27	 4.04	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3383	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3384	 1	 1.03	 0.53	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3385	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3386	 1	 3.04	 1.12	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3387	 1	 5.71	 1.82	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3388	 1	 10.19	 2.36	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3389	 1	 4.92	 1.11	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3390	 1	 5.85	 1.34	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3391	 1	 2.15	 1.13	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3392	 1	 12.75	 2.99	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3393	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3394	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3395	 1	 3.06	 1.65	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3396	 1	 6.89	 3.19	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3397	 1	 5.58	 2.55	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3398	 1	 5.81	 1.33	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3399	 1	 3.66	 1.78	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3400	 1	 1.81	 0.42	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3401	 1	 3.99	 1.62	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3402	 1	 5.11	 1.2	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3403	 1	 3.07	 0.71	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3404	 1	 1.92	 0.45	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3405	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3406	 1	 8.67	 2.03	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3407	 1	 1.82	 0.77	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3408	 1	 1.85	 0.8	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3409	 1	 1.93	 1.02	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3410	 1	 5.11	 2.26	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3411	 1	 1.88	 0.81	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3412	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3413	 1	 4.25	 0.98	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3414	 1	 2.79	 1.31	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3415	 1	 3.66	 1.38	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3416	 1	 5.54	 2.57	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3417	 1	 1.75	 0.41	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3418	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3419	 1	 2.95	 0.68	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3420	 1	 7.06	 1.64	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3421	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3422	 1	 4.19	 0.96	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3423	 1	 3.93	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3424	 1	 7.18	 1.61	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3425	 1	 6.5	 1.47	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3426	 1	 1.69	 0.39	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3427	 1	 2.86	 1.0	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3428	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3429	 1	 2.42	 1.07	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3430	 1	 3.86	 1.62	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3431	 1	 1.53	 0.79	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3432	 1	 4.79	 2.41	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3433	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3434	 1	 5.06	 2.52	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3435	 1	 5.66	 2.81	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3436	 1	 3.19	 1.45	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3437	 1	 9.08	 2.9	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3438	 1	 13.22	 4.63	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3439	 1	 4.56	 1.81	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3440	 1	 1.28	 0.56	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3441	 1	 4.45	 2.46	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3442	 1	 5.23	 1.85	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3443	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3444	 1	 3.34	 1.64	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3445	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3446	 1	 1.28	 0.66	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3447	 1	 7.02	 1.64	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3448	 1	 1.7	 0.4	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3449	 1	 2.51	 0.6	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3450	 1	 8.74	 2.07	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3451	 1	 3.77	 1.53	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3452	 1	 9.87	 3.82	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3453	 1	 2.95	 1.38	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3454	 1	 2.04	 0.9	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3455	 1	 2.3	 0.95	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3456	 1	 4.77	 2.09	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3457	 1	 2.49	 1.28	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3458	 1	 4.64	 2.46	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3459	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3460	 1	 2.86	 1.21	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3461	 1	 6.8	 3.24	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3462	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3463	 1	 3.75	 1.69	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3464	 1	 2.62	 1.07	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3465	 1	 0.92	 0.4	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3466	 1	 6.36	 2.98	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3467	 1	 4.11	 2.01	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3468	 1	 3.1	 1.36	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3469	 1	 1.18	 0.52	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3470	 1	 1.19	 0.62	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3471	 1	 1.15	 0.65	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3472	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3473	 1	 5.72	 1.76	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3474	 1	 1.6	 0.85	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3475	 1	 2.27	 1.27	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3476	 1	 3.58	 1.74	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3477	 1	 0.92	 0.43	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3478	 1	 1.76	 1.01	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3479	 1	 1.97	 0.91	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3480	 1	 3.33	 1.63	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3481	 1	 16.41	 7.32	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3482	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	3483	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3484	 1	 2.56	 1.44	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3485	 1	 2.54	 1.28	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3486	 1	 4.68	 1.92	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3487	 1	 0.56	 0.25	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3488	 1	 2.76	 1.43	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3489	 1	 3.52	 1.69	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3490	 1	 4.01	 2.15	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3491	 1	 9.6	 4.82	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3492	 1	 2.85	 1.26	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3493	 1	 5.04	 2.51	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3494	 1	 2.94	 1.52	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3495	 1	 5.05	 1.8	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3496	 1	 2.2	 1.0	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3497	 1	 5.18	 1.18	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3498	 1	 4.95	 1.11	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3499	 1	 3.55	 0.81	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3500	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3501	 1	 6.71	 1.56	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3502	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3503	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3504	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3505	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	3506	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3507	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	3508	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3509	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3510	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3511	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3512	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3513	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3514	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3515	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	3516	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3517	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3518	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3519	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3520	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3521	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3522	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3523	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3524	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	3525	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3526	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3527	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3528	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3529	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3530	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3531	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3532	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3533	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3534	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3535	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3536	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3537	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3538	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3539	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3540	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3541	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3542	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3543	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3544	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3545	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3546	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3547	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3548	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3549	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3550	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3551	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3552	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3553	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3554	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3555	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3556	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3557	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3558	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	3559	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3560	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3561	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3562	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3563	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3564	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	3565	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3566	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3567	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3568	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3569	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3570	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3571	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3572	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3573	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3574	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3575	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3576	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3577	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3578	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3579	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3580	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3581	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3582	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3583	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3584	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3585	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3586	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3587	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3588	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3589	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3590	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3591	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3592	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3593	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3594	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3595	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3596	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3597	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3598	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3599	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3600	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3601	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3602	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3603	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3604	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3605	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3606	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3607	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3608	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3609	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3610	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3611	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3612	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	3613	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3614	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3615	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3616	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3617	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3618	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3619	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3620	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3621	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3622	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3623	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3624	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3625	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3626	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3627	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3628	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3629	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3630	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3631	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3632	 1	 13.75	 5.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3633	 1	 20.05	 4.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3634	 1	 13.72	 6.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3635	 1	 10.93	 4.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3636	 1	 4.92	 2.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3637	 1	 3.74	 1.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3638	 1	 3.07	 1.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3639	 1	 5.01	 2.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3640	 1	 3.35	 1.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3641	 1	 6.86	 3.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3642	 1	 7.8	 4.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3643	 1	 4.19	 1.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3644	 1	 2.4	 1.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3645	 1	 6.26	 3.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3646	 1	 3.7	 1.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3647	 1	 2.95	 1.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3648	 1	 1.46	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3649	 1	 2.05	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3650	 1	 5.24	 2.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3651	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3652	 1	 2.92	 1.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3653	 1	 1.15	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3654	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3655	 1	 47.65	 26.68	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3656	 1	 1.98	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3657	 1	 6.67	 1.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3658	 1	 4.24	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3659	 1	 4.88	 1.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3660	 1	 13.23	 3.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3661	 1	 3.0	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3662	 1	 7.51	 1.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3663	 1	 21.83	 5.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3664	 1	 45.18	 10.63	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3665	 1	 5.73	 1.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3666	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3667	 1	 9.05	 2.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3668	 1	 5.68	 1.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3669	 1	 17.44	 4.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3670	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3671	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3672	 1	 5.73	 1.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3673	 1	 2.2	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3674	 1	 10.21	 2.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3675	 1	 15.56	 6.57	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3676	 1	 2.47	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3677	 1	 4.24	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3678	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3679	 1	 24.84	 5.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3680	 1	 6.73	 2.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3681	 1	 3.58	 2.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3682	 1	 10.51	 5.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3683	 1	 4.94	 2.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3684	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3685	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3686	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3687	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3688	 1	 2.7	 1.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3689	 1	 2.94	 1.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3690	 1	 3.56	 1.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3691	 1	 3.81	 1.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3692	 1	 4.07	 2.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3693	 1	 6.1	 3.08	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3694	 1	 6.85	 3.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3695	 1	 4.21	 2.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3696	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3697	 1	 1.17	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3698	 1	 5.28	 2.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3699	 1	 5.54	 2.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3700	 1	 3.94	 1.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3701	 1	 2.31	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3702	 1	 2.37	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3703	 1	 1.64	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3704	 1	 3.32	 1.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3705	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3706	 1	 1.61	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3707	 1	 3.97	 2.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3708	 1	 3.71	 2.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3709	 1	 10.39	 4.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3710	 1	 22.22	 5.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3711	 1	 6.32	 1.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3712	 1	 7.6	 1.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3713	 1	 10.05	 2.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3714	 1	 9.52	 2.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3715	 1	 4.57	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3716	 1	 4.69	 1.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3717	 1	 3.45	 1.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3718	 1	 18.84	 4.63	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3719	 1	 2.44	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3720	 1	 4.09	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3721	 1	 11.77	 2.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3722	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	3723	 1	 8.51	 2.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3724	 1	 4.17	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3725	 1	 0.55	 0.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3726	 1	 8.49	 2.07	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3727	 1	 4.95	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3728	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3729	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3730	 1	 5.62	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3731	 1	 2.52	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3732	 1	 6.72	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3733	 1	 0.34	 0.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3734	 1	 0.91	 0.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3735	 1	 9.84	 2.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3736	 1	 1.0	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3737	 1	 7.85	 1.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3738	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3739	 1	 5.64	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3740	 1	 4.5	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3741	 1	 3.08	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3742	 1	 3.58	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3743	 1	 2.88	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3744	 1	 6.67	 1.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3745	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3746	 1	 2.4	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3747	 1	 4.43	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3748	 1	 7.81	 1.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3749	 1	 1.92	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3750	 1	 8.45	 2.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3751	 1	 5.57	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3752	 1	 3.29	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3753	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3754	 1	 12.87	 3.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3755	 1	 3.43	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3756	 1	 8.2	 1.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3757	 1	 10.33	 2.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3758	 1	 3.83	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3759	 1	 5.65	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3760	 1	 6.38	 1.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3761	 1	 2.47	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3762	 1	 4.85	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3763	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3764	 1	 7.29	 1.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3765	 1	 6.94	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3766	 1	 3.32	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3767	 1	 1.68	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3768	 1	 7.21	 1.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3769	 1	 5.79	 1.41	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3770	 1	 7.26	 1.77	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3771	 1	 1.33	 0.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3772	 1	 6.67	 1.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3773	 1	 2.95	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3774	 1	 5.87	 1.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3775	 1	 3.59	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3776	 1	 14.54	 3.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3777	 1	 4.82	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3778	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3779	 1	 9.42	 2.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3780	 1	 8.43	 2.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3781	 1	 0.89	 0.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3782	 1	 5.32	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3783	 1	 3.2	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3784	 1	 8.06	 1.94	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3785	 1	 5.0	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3786	 1	 1.74	 0.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3787	 1	 2.52	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3788	 1	 3.33	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3789	 1	 2.2	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3790	 1	 2.47	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3791	 1	 3.46	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3792	 1	 0.78	 0.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3793	 1	 3.87	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3794	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3795	 1	 5.79	 1.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3796	 1	 3.21	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3797	 1	 6.71	 1.61	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3798	 1	 2.53	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3799	 1	 1.42	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3800	 1	 4.71	 1.13	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3801	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3802	 1	 11.15	 2.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3803	 1	 4.07	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3804	 1	 12.39	 2.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3805	 1	 3.84	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3806	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3807	 1	 3.67	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3808	 1	 4.29	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3809	 1	 4.81	 1.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3810	 1	 3.48	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3811	 1	 2.02	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3812	 1	 3.72	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3813	 1	 6.39	 1.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3814	 1	 1.2	 0.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3815	 1	 2.24	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3816	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3817	 1	 1.22	 0.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3818	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3819	 1	 1.33	 0.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3820	 1	 5.17	 1.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3821	 1	 9.09	 2.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3822	 1	 4.01	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3823	 1	 4.3	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3824	 1	 5.63	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3825	 1	 2.22	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3826	 1	 1.86	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3827	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3828	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3829	 1	 4.25	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3830	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3831	 1	 11.4	 2.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3832	 1	 17.34	 4.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3833	 1	 8.27	 1.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3834	 1	 1.67	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3835	 1	 8.56	 2.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3836	 1	 11.22	 2.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3837	 1	 6.58	 1.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3838	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3839	 1	 4.06	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3840	 1	 1.81	 0.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3841	 1	 7.48	 1.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3842	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3843	 1	 5.39	 1.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3844	 1	 2.12	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3845	 1	 7.05	 1.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3846	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3847	 1	 4.04	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3848	 1	 4.53	 1.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3849	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3850	 1	 2.48	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3851	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3852	 1	 5.37	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3853	 1	 5.0	 1.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3854	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3855	 1	 3.64	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3856	 1	 6.8	 1.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3857	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3858	 1	 4.17	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3859	 1	 4.44	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3860	 1	 2.36	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3861	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3862	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3863	 1	 6.84	 1.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3864	 1	 3.12	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3865	 1	 5.39	 1.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3866	 1	 5.34	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3867	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3868	 1	 4.52	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3869	 1	 2.56	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3870	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3871	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3872	 1	 4.62	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3873	 1	 3.64	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3874	 1	 4.66	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3875	 1	 0.86	 0.21	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3876	 1	 1.49	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3877	 1	 4.06	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3878	 1	 1.92	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3879	 1	 5.68	 1.37	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3880	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3881	 1	 2.67	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3882	 1	 2.1	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3883	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3884	 1	 4.71	 1.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3885	 1	 2.87	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3886	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3887	 1	 4.38	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3888	 1	 8.08	 1.94	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3889	 1	 3.2	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3890	 1	 4.19	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3891	 1	 3.93	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3892	 1	 4.05	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3893	 1	 2.36	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3894	 1	 3.39	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3895	 1	 5.29	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3896	 1	 2.2	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3897	 1	 1.34	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3898	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3899	 1	 3.08	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3900	 1	 8.16	 1.97	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3901	 1	 1.1	 0.27	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3902	 1	 6.67	 1.61	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3903	 1	 1.53	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3904	 1	 2.67	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3905	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3906	 1	 5.93	 1.43	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3907	 1	 4.37	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3908	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3909	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3910	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3911	 1	 3.87	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3912	 1	 5.56	 1.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3913	 1	 2.52	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3914	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3915	 1	 2.69	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3916	 1	 2.1	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3917	 1	 1.07	 0.26	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3918	 1	 5.31	 1.29	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3919	 1	 7.52	 1.82	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3920	 1	 5.93	 1.43	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3921	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3922	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3923	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3924	 1	 1.47	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3925	 1	 4.59	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3926	 1	 2.34	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3927	 1	 7.93	 1.91	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3928	 1	 5.66	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3929	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3930	 1	 6.38	 1.55	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3931	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3932	 1	 17.4	 4.21	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3933	 1	 5.88	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3934	 1	 0.73	 0.17	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3935	 1	 7.0	 1.7	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3936	 1	 9.43	 2.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3937	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3938	 1	 3.08	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3939	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3940	 1	 1.5	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3941	 1	 1.05	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3942	 1	 1.02	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3943	 1	 3.62	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3944	 1	 10.96	 2.66	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3945	 1	 7.86	 1.9	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3946	 1	 2.57	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3947	 1	 3.64	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3948	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3949	 1	 7.32	 1.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3950	 1	 6.54	 1.58	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3951	 1	 10.96	 2.64	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3952	 1	 4.23	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3953	 1	 9.68	 2.33	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3954	 1	 4.13	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3955	 1	 3.75	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3956	 1	 2.79	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3957	 1	 2.74	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3958	 1	 1.73	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3959	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3960	 1	 3.4	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3961	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3962	 1	 2.68	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3963	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3964	 1	 1.74	 0.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3965	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3966	 1	 2.36	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3967	 1	 1.52	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3968	 1	 7.98	 1.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3969	 1	 7.02	 1.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3970	 1	 4.64	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3971	 1	 2.83	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3972	 1	 1.36	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3973	 1	 1.66	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3974	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3975	 1	 3.93	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3976	 1	 2.79	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3977	 1	 1.29	 0.31	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3978	 1	 4.78	 1.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3979	 1	 7.25	 1.75	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3980	 1	 3.79	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3981	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3982	 1	 3.47	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3983	 1	 2.21	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3984	 1	 3.11	 0.75	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3985	 1	 5.66	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3986	 1	 7.78	 1.87	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3987	 1	 6.39	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3988	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3989	 1	 2.9	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3990	 1	 4.43	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3991	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3992	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3993	 1	 4.81	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3994	 1	 1.46	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	3995	 1	 3.19	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3996	 1	 3.87	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3997	 1	 6.73	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3998	 1	 1.2	 0.29	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	3999	 1	 4.58	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4000	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4001	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4002	 1	 3.71	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4003	 1	 9.88	 2.38	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4004	 1	 2.94	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4005	 1	 2.94	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4006	 1	 6.17	 1.48	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4007	 1	 3.78	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4008	 1	 3.67	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4009	 1	 5.52	 1.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4010	 1	 3.53	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4011	 1	 2.5	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4012	 1	 4.47	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4013	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4014	 1	 3.76	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4015	 1	 1.88	 0.45	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4016	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4017	 1	 2.6	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4018	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4019	 1	 8.05	 1.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4020	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4021	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4022	 1	 7.47	 1.8	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4023	 1	 7.08	 1.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4024	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4025	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4026	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4027	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4028	 1	 2.5	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4029	 1	 1.79	 0.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4030	 1	 6.62	 1.59	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4031	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4032	 1	 3.82	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4033	 1	 2.12	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4034	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4035	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4036	 1	 16.64	 3.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4037	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4038	 1	 3.42	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4039	 1	 1.54	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4040	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4041	 1	 2.38	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4042	 1	 1.14	 0.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4043	 1	 1.42	 0.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4044	 1	 3.1	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4045	 1	 1.13	 0.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4046	 1	 2.46	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4047	 1	 6.31	 1.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4048	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4049	 1	 3.14	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4050	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	4051	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	4052	 1	 6.14	 1.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4053	 1	 1.02	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4054	 1	 9.47	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4055	 1	 5.84	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4056	 1	 6.18	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4057	 1	 2.25	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4058	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4059	 1	 14.27	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4060	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4061	 1	 3.62	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4062	 1	 1.96	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4063	 1	 3.77	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4064	 1	 2.93	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4065	 1	 4.05	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4066	 1	 9.43	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4067	 1	 4.14	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4068	 1	 2.5	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4069	 1	 4.4	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4070	 1	 4.28	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4071	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4072	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4073	 1	 1.55	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4074	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4075	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4076	 1	 2.86	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4077	 1	 7.32	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4078	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4079	 1	 5.03	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4080	 1	 3.34	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4081	 1	 3.15	 1.8	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4082	 1	 5.33	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4083	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4084	 1	 13.35	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4085	 1	 2.78	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4086	 1	 4.03	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4087	 1	 2.63	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4088	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4089	 1	 9.03	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4090	 1	 1.87	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4091	 1	 3.59	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4092	 1	 4.13	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4093	 1	 2.36	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4094	 1	 3.79	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4095	 1	 7.27	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4096	 1	 5.45	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4097	 1	 8.98	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4098	 1	 7.26	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4099	 1	 7.1	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4100	 1	 3.22	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4101	 1	 2.95	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4102	 1	 2.46	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4103	 1	 4.16	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4104	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4105	 1	 13.64	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4106	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4107	 1	 2.26	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4108	 1	 3.36	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4109	 1	 0.18	 0.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4110	 1	 9.06	 3.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4111	 1	 2.58	 1.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4112	 1	 4.84	 2.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4113	 1	 23.0	 5.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4114	 1	 8.1	 3.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4115	 1	 7.59	 3.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4116	 1	 9.4	 2.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4117	 1	 8.4	 1.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4118	 1	 4.66	 1.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4119	 1	 12.43	 5.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4120	 1	 4.35	 1.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4121	 1	 6.62	 2.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4122	 1	 8.37	 4.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4123	 1	 4.61	 2.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4124	 1	 11.63	 5.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4125	 1	 4.78	 2.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4126	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4127	 1	 5.47	 2.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4128	 1	 2.08	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4129	 1	 3.1	 1.87	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4130	 1	 3.04	 1.8	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4131	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4132	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4133	 1	 3.07	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4134	 1	 16.25	 3.81	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4135	 1	 2.33	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4136	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4137	 1	 2.28	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4138	 1	 6.61	 3.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4139	 1	 2.44	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4140	 1	 11.22	 2.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4141	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4142	 1	 6.52	 1.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4143	 1	 1.83	 0.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4144	 1	 1.63	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4145	 1	 3.64	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4146	 1	 3.23	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4147	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4148	 1	 20.57	 7.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4149	 1	 2.38	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4150	 1	 8.64	 4.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4151	 1	 3.6	 1.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4152	 1	 6.57	 3.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4153	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4154	 1	 3.18	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4155	 1	 2.75	 1.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4156	 1	 4.3	 2.23	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4157	 1	 4.27	 1.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4158	 1	 3.19	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4159	 1	 6.5	 3.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4160	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4161	 1	 5.21	 2.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4162	 1	 5.42	 2.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4163	 1	 2.83	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4164	 1	 3.16	 1.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4165	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4166	 1	 3.34	 1.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4167	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4168	 1	 5.14	 1.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4169	 1	 3.7	 1.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4170	 1	 9.85	 3.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4171	 1	 3.18	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4172	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4173	 1	 2.77	 1.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4174	 1	 16.49	 8.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4175	 1	 2.33	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4176	 1	 8.12	 2.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4177	 1	 7.07	 2.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4178	 1	 7.33	 3.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4179	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4180	 1	 5.86	 2.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4181	 1	 19.37	 4.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4182	 1	 7.29	 3.36	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4183	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4184	 1	 3.64	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4185	 1	 1.0	 0.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4186	 1	 5.64	 1.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4187	 1	 2.94	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4188	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4189	 1	 11.45	 2.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4190	 1	 3.25	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4191	 1	 2.68	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4192	 1	 2.19	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4193	 1	 2.38	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4194	 1	 3.99	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4195	 1	 15.17	 3.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4196	 1	 3.42	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4197	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4198	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4199	 1	 5.89	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4200	 1	 14.12	 3.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4201	 1	 3.07	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4202	 1	 16.23	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4203	 1	 8.85	 2.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4204	 1	 7.83	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4205	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4206	 1	 6.72	 3.38	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4207	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	4208	 1	 5.07	 2.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4209	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4210	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4211	 1	 2.54	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4212	 1	 3.35	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4213	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4214	 1	 3.89	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4215	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4216	 1	 7.51	 1.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4217	 1	 17.11	 6.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4218	 1	 9.01	 4.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4219	 1	 8.44	 4.9	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4220	 1	 6.64	 3.14	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4221	 1	 6.98	 4.31	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4222	 1	 3.39	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4223	 1	 4.52	 2.42	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4224	 1	 9.78	 3.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4225	 1	 9.38	 4.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4226	 1	 2.87	 1.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4227	 1	 4.5	 2.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4228	 1	 2.48	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4229	 1	 7.45	 2.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4230	 1	 15.82	 7.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4231	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4232	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4233	 1	 2.17	 1.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4234	 1	 13.07	 6.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4235	 1	 6.15	 2.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4236	 1	 5.19	 1.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4237	 1	 1.62	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4238	 1	 8.47	 3.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4239	 1	 1.72	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4240	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4241	 1	 1.91	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4242	 1	 5.37	 2.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4243	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4244	 1	 0.99	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4245	 1	 1.28	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4246	 1	 5.7	 2.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4247	 1	 8.41	 4.05	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4248	 1	 4.63	 2.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4249	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4250	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4251	 1	 0.94	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4252	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4253	 1	 2.41	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4254	 1	 0.94	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4255	 1	 1.11	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4256	 1	 1.7	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4257	 1	 2.49	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4258	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4259	 1	 4.76	 1.13	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4260	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4261	 1	 5.19	 1.23	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4262	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4263	 1	 8.44	 1.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4264	 1	 1.93	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4265	 1	 8.36	 1.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4266	 1	 15.7	 3.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4267	 1	 4.55	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4268	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4269	 1	 6.79	 1.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4270	 1	 3.0	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4271	 1	 2.47	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4272	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	4273	 1	 7.31	 3.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4274	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	4275	 1	 3.88	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4276	 1	 12.12	 2.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4277	 1	 0.96	 0.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4278	 1	 3.81	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4279	 1	 3.21	 1.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4280	 1	 5.71	 2.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4281	 1	 4.77	 2.14	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	4282	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4283	 1	 11.22	 5.53	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4284	 1	 2.79	 1.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4285	 1	 2.01	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4286	 1	 3.65	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4287	 1	 3.94	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4288	 1	 6.13	 3.31	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4289	 1	 5.04	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4290	 1	 2.22	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4291	 1	 4.33	 2.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4292	 1	 15.9	 7.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4293	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4294	 1	 2.47	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4295	 1	 3.47	 1.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4296	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4297	 1	 2.95	 1.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4298	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4299	 1	 2.55	 1.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4300	 1	 1.23	 0.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4301	 1	 10.25	 5.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4302	 1	 3.32	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4303	 1	 4.21	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4304	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4305	 1	 4.57	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4306	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4307	 1	 4.39	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4308	 1	 2.96	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4309	 1	 6.47	 3.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4310	 1	 3.67	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4311	 1	 1.53	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4312	 1	 7.26	 3.53	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4313	 1	 2.86	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4314	 1	 3.75	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4315	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4316	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4317	 1	 5.48	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4318	 1	 0.98	 0.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4319	 1	 3.31	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4320	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4321	 1	 10.01	 2.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4322	 1	 10.37	 2.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4323	 1	 3.94	 1.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4324	 1	 13.89	 4.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4325	 1	 4.38	 2.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4326	 1	 7.18	 3.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4327	 1	 3.21	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4328	 1	 3.9	 1.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4329	 1	 2.23	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4330	 1	 2.45	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4331	 1	 4.76	 2.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4332	 1	 3.1	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4333	 1	 2.22	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4334	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4335	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4336	 1	 4.54	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4337	 1	 3.18	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4338	 1	 3.17	 1.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4339	 1	 2.23	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4340	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4341	 1	 2.13	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4342	 1	 3.77	 2.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4343	 1	 3.41	 1.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4344	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4345	 1	 1.82	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4346	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4347	 1	 6.8	 3.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4348	 1	 3.61	 1.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4349	 1	 5.39	 2.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4350	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4351	 1	 6.15	 2.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4352	 1	 4.07	 2.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4353	 1	 2.69	 1.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4354	 1	 4.2	 2.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4355	 1	 2.05	 1.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4356	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4357	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4358	 1	 7.24	 1.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4359	 1	 1.37	 0.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4360	 1	 1.87	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4361	 1	 12.54	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4362	 1	 4.69	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4363	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4364	 1	 6.07	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4365	 1	 4.32	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4366	 1	 4.44	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4367	 1	 1.73	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4368	 1	 5.82	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4369	 1	 2.09	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4370	 1	 3.95	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4371	 1	 1.63	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4372	 1	 5.05	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4373	 1	 13.59	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4374	 1	 4.97	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4375	 1	 2.31	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4376	 1	 2.85	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4377	 1	 6.54	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4378	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4379	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4380	 1	 1.59	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4381	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4382	 1	 9.73	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4383	 1	 2.82	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4384	 1	 7.76	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4385	 1	 6.06	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4386	 1	 7.57	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4387	 1	 4.88	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4388	 1	 4.51	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4389	 1	 1.75	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4390	 1	 1.56	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4391	 1	 7.2	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4392	 1	 3.13	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4393	 1	 5.01	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4394	 1	 3.56	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4395	 1	 5.54	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4396	 1	 3.77	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4397	 1	 8.4	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4398	 1	 6.78	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4399	 1	 7.78	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4400	 1	 5.57	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4401	 1	 2.75	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4402	 1	 4.36	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4403	 1	 5.51	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4404	 1	 4.88	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4405	 1	 9.1	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4406	 1	 4.64	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4407	 1	 1.62	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4408	 1	 4.62	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4409	 1	 12.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4410	 1	 14.04	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4411	 1	 9.22	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4412	 1	 2.09	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4413	 1	 4.94	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4414	 1	 3.23	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4415	 1	 13.85	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4416	 1	 8.93	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4417	 1	 2.85	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4418	 1	 1.86	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4419	 1	 1.82	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4420	 1	 1.37	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4421	 1	 1.99	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4422	 1	 4.14	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4423	 1	 6.81	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4424	 1	 2.5	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4425	 1	 2.12	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4426	 1	 3.22	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4427	 1	 3.86	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4428	 1	 2.65	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4429	 1	 3.91	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4430	 1	 2.12	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4431	 1	 24.94	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4432	 1	 7.67	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4433	 1	 4.62	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4434	 1	 5.82	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4435	 1	 5.05	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4436	 1	 7.15	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4437	 1	 1.85	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4438	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4439	 1	 2.3	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4440	 1	 2.13	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4441	 1	 3.55	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4442	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4443	 1	 5.5	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4444	 1	 4.34	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4445	 1	 4.16	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4446	 1	 6.32	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4447	 1	 2.71	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4448	 1	 3.79	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4449	 1	 15.23	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4450	 1	 123.76	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4451	 1	 2.05	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4452	 1	 2.9	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4453	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4454	 1	 10.75	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4455	 1	 6.37	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4456	 1	 1.95	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4457	 1	 6.3	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4458	 1	 6.9	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4459	 1	 5.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4460	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4461	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4462	 1	 2.53	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4463	 1	 1.7	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4464	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4465	 1	 2.97	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4466	 1	 4.43	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4467	 1	 4.04	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4468	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4469	 1	 3.94	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4470	 1	 2.89	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4471	 1	 4.74	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4472	 1	 8.8	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4473	 1	 5.38	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4474	 1	 3.48	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4475	 1	 5.87	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4476	 1	 4.63	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4477	 1	 7.67	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4478	 1	 6.56	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4479	 1	 14.55	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4480	 1	 7.62	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4481	 1	 4.32	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4482	 1	 3.68	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4483	 1	 2.78	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4484	 1	 6.03	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4485	 1	 6.86	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4486	 1	 3.34	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4487	 1	 2.61	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4488	 1	 4.08	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4489	 1	 2.17	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4490	 1	 4.38	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4491	 1	 4.65	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4492	 1	 0.95	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4493	 1	 1.28	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4494	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4495	 1	 2.86	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4496	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4497	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	4498	 1	 2.29	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4499	 1	 3.8	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4500	 1	 3.82	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4501	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4502	 1	 1.92	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4503	 1	 8.01	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4504	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4505	 1	 1.08	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4506	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4507	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4508	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4509	 1	 1.38	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4510	 1	 3.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4511	 1	 3.86	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4512	 1	 6.51	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4513	 1	 4.71	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4514	 1	 3.51	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4515	 1	 2.56	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4516	 1	 2.72	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4517	 1	 2.7	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4518	 1	 1.73	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4519	 1	 3.64	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4520	 1	 1.26	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4521	 1	 3.48	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4522	 1	 8.24	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4523	 1	 8.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4524	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4525	 1	 3.89	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4526	 1	 6.27	 3.03	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4527	 1	 5.5	 2.59	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4528	 1	 3.51	 2.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4529	 1	 5.54	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4530	 1	 3.69	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4531	 1	 13.71	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4532	 1	 5.29	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4533	 1	 4.26	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4534	 1	 2.5	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4535	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4536	 1	 7.79	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4537	 1	 11.36	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4538	 1	 2.19	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4539	 1	 6.95	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4540	 1	 7.98	 3.88	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4541	 1	 11.11	 4.45	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4542	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4543	 1	 3.94	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4544	 1	 5.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4545	 1	 16.8	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4546	 1	 3.07	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4547	 1	 3.65	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4548	 1	 6.48	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4549	 1	 3.71	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4550	 1	 6.55	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4551	 1	 8.88	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4552	 1	 3.38	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4553	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4554	 1	 3.75	 1.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4555	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4556	 1	 5.39	 2.78	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4557	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4558	 1	 4.46	 1.89	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4559	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4560	 1	 2.74	 1.49	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4561	 1	 3.19	 1.8	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4562	 1	 2.09	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4563	 1	 6.19	 2.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4564	 1	 2.75	 1.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4565	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4566	 1	 1.73	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4567	 1	 3.78	 1.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4568	 1	 5.86	 2.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4569	 1	 10.96	 5.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4570	 1	 1.9	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4571	 1	 3.45	 1.93	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4572	 1	 1.4	 0.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4573	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4574	 1	 2.17	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4575	 1	 2.08	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4576	 1	 5.02	 1.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4577	 1	 10.74	 5.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4578	 1	 6.95	 3.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4579	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4580	 1	 5.32	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4581	 1	 69.94	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4582	 1	 16.43	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4583	 1	 22.62	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4584	 1	 1.75	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4585	 1	 6.4	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4586	 1	 9.28	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4587	 1	 7.04	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4588	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4589	 1	 13.94	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4590	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4591	 1	 7.48	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4592	 1	 19.66	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4593	 1	 1.65	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4594	 1	 5.36	 2.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4595	 1	 1.83	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4596	 1	 0.02	 0.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4597	 1	 1.97	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4598	 1	 1.61	 0.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4599	 1	 2.67	 1.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4600	 1	 3.25	 1.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4601	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4602	 1	 2.73	 1.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4603	 1	 1.37	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4604	 1	 7.57	 3.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4605	 1	 5.5	 3.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4606	 1	 2.71	 1.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4607	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4608	 1	 2.13	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4609	 1	 2.44	 1.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4610	 1	 1.81	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4611	 1	 4.7	 2.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4612	 1	 12.85	 7.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4613	 1	 3.72	 1.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4614	 1	 7.15	 3.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4615	 1	 5.56	 3.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4616	 1	 21.45	 10.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4617	 1	 2.91	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4618	 1	 2.43	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4619	 1	 3.05	 1.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4620	 1	 5.19	 2.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4621	 1	 3.0	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4622	 1	 4.82	 2.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4623	 1	 1.12	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4624	 1	 2.22	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4625	 1	 1.84	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4626	 1	 2.33	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4627	 1	 2.98	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4628	 1	 5.41	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4629	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4630	 1	 6.72	 1.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4631	 1	 12.43	 2.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4632	 1	 3.06	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4633	 1	 4.68	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4634	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4635	 1	 15.24	 3.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4636	 1	 16.01	 3.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4637	 1	 3.85	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4638	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4639	 1	 0.47	 0.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4640	 1	 9.55	 4.6	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4641	 1	 18.08	 4.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4642	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4643	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4644	 1	 4.1	 2.37	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4645	 1	 3.09	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4646	 1	 7.5	 4.1	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4647	 1	 1.63	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4648	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4649	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4650	 1	 6.0	 1.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4651	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4652	 1	 3.91	 2.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4653	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4654	 1	 3.35	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4655	 1	 3.56	 1.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4656	 1	 8.96	 3.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4657	 1	 4.19	 2.06	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4658	 1	 2.14	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4659	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4660	 1	 2.31	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4661	 1	 3.64	 2.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4662	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4663	 1	 6.28	 3.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4664	 1	 7.96	 4.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4665	 1	 9.31	 3.76	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4666	 1	 7.52	 3.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4667	 1	 3.63	 1.69	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4668	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4669	 1	 1.99	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4670	 1	 1.82	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4671	 1	 0.97	 0.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4672	 1	 2.32	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4673	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4674	 1	 7.25	 1.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4675	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4676	 1	 2.93	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4677	 1	 7.25	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4678	 1	 4.0	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4679	 1	 1.55	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4680	 1	 8.76	 2.04	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4681	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4682	 1	 2.7	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4683	 1	 5.9	 1.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4684	 1	 1.81	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4685	 1	 2.75	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4686	 1	 11.52	 2.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4687	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4688	 1	 3.27	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4689	 1	 4.04	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4690	 1	 1.96	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4691	 1	 3.27	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4692	 1	 5.72	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4693	 1	 7.87	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4694	 1	 3.55	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4695	 1	 3.81	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4696	 1	 8.09	 1.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4697	 1	 6.02	 1.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4698	 1	 2.82	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4699	 1	 20.28	 4.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4700	 1	 4.44	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4701	 1	 15.54	 3.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4702	 1	 5.25	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4703	 1	 4.26	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4704	 1	 3.01	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4705	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4706	 1	 3.63	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4707	 1	 10.66	 2.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4708	 1	 15.78	 3.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4709	 1	 1.36	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4710	 1	 14.06	 3.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4711	 1	 6.56	 1.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4712	 1	 15.79	 3.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4713	 1	 2.52	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4714	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4715	 1	 3.88	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4716	 1	 0.61	 0.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4717	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4718	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4719	 1	 4.99	 1.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4720	 1	 5.99	 1.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4721	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4722	 1	 2.86	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4723	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4724	 1	 11.65	 2.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4725	 1	 7.68	 1.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4726	 1	 5.64	 1.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4727	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	4728	 1	 2.92	 0.71	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4729	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4730	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4731	 1	 3.79	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4732	 1	 2.41	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4733	 1	 0.97	 0.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4734	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4735	 1	 5.11	 1.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4736	 1	 3.51	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4737	 1	 5.48	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4738	 1	 3.34	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4739	 1	 6.02	 1.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4740	 1	 0.84	 0.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4741	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4742	 1	 4.82	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4743	 1	 5.53	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4744	 1	 1.32	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4745	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4746	 1	 2.28	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4747	 1	 4.01	 0.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4748	 1	 3.42	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4749	 1	 1.48	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4750	 1	 2.62	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4751	 1	 4.03	 0.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4752	 1	 2.2	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4753	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4754	 1	 4.77	 1.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4755	 1	 2.21	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4756	 1	 2.69	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4757	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4758	 1	 12.3	 3.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4759	 1	 3.79	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4760	 1	 1.8	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4761	 1	 3.86	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4762	 1	 4.56	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4763	 1	 4.52	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4764	 1	 5.86	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4765	 1	 3.66	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4766	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4767	 1	 7.59	 1.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4768	 1	 2.75	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4769	 1	 4.79	 1.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4770	 1	 2.69	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4771	 1	 3.26	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4772	 1	 4.13	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4773	 1	 4.08	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4774	 1	 9.07	 2.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4775	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4776	 1	 3.14	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4777	 1	 3.13	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4778	 1	 4.46	 1.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4779	 1	 7.91	 1.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4780	 1	 0.4	 0.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4781	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4782	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4783	 1	 4.03	 0.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4784	 1	 3.52	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4785	 1	 3.44	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4786	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4787	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4788	 1	 6.01	 1.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4789	 1	 3.56	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4790	 1	 3.72	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4791	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4792	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4793	 1	 4.37	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4794	 1	 5.22	 1.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4795	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4796	 1	 2.71	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4797	 1	 6.71	 1.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4798	 1	 1.5	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4799	 1	 12.83	 3.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4800	 1	 4.11	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4801	 1	 2.23	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4802	 1	 4.6	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4803	 1	 2.29	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4804	 1	 6.54	 1.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4805	 1	 1.59	 0.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4806	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4807	 1	 3.1	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4808	 1	 6.49	 1.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4809	 1	 3.95	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4810	 1	 3.06	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4811	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4812	 1	 4.26	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4813	 1	 2.22	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4814	 1	 4.21	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4815	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4816	 1	 2.98	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4817	 1	 4.16	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4818	 1	 1.23	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4819	 1	 2.1	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4820	 1	 3.41	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4821	 1	 3.37	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4822	 1	 3.15	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4823	 1	 1.37	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4824	 1	 0.68	 0.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4825	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4826	 1	 0.88	 0.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4827	 1	 5.21	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4828	 1	 2.5	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4829	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4830	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4831	 1	 3.04	 0.75	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4832	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4833	 1	 7.03	 1.73	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4834	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4835	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4836	 1	 4.97	 1.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4837	 1	 4.44	 1.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4838	 1	 0.43	 0.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4839	 1	 3.49	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4840	 1	 1.16	 0.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4841	 1	 5.01	 1.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4842	 1	 1.05	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4843	 1	 5.13	 1.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4844	 1	 2.03	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4845	 1	 2.51	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4846	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4847	 1	 1.01	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4848	 1	 1.8	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4849	 1	 1.69	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4850	 1	 1.4	 0.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4851	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4852	 1	 4.84	 1.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4853	 1	 3.8	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4854	 1	 4.61	 1.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4855	 1	 2.38	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4856	 1	 1.81	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4857	 1	 1.53	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4858	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4859	 1	 1.2	 0.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4860	 1	 3.39	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4861	 1	 1.48	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4862	 1	 4.29	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4863	 1	 2.0	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4864	 1	 1.82	 0.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4865	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4866	 1	 2.46	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4867	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4868	 1	 3.45	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4869	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4870	 1	 4.96	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4871	 1	 7.25	 1.78	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4872	 1	 1.87	 0.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4873	 1	 2.72	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4874	 1	 1.05	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4875	 1	 1.27	 0.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4876	 1	 0.96	 0.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4877	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4878	 1	 3.85	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4879	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4880	 1	 1.71	 0.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4881	 1	 9.63	 2.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4882	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4883	 1	 4.01	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4884	 1	 7.37	 1.8	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4885	 1	 1.61	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4886	 1	 4.18	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4887	 1	 2.26	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4888	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4889	 1	 4.11	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4890	 1	 3.62	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4891	 1	 5.98	 1.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4892	 1	 2.63	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4893	 1	 2.84	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4894	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4895	 1	 3.62	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4896	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4897	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4898	 1	 2.11	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4899	 1	 2.54	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4900	 1	 3.5	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4901	 1	 5.6	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4902	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4903	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4904	 1	 3.01	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4905	 1	 3.95	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4906	 1	 4.18	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4907	 1	 2.75	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4908	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4909	 1	 1.68	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4910	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4911	 1	 2.02	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4912	 1	 3.82	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4913	 1	 2.63	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4914	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4915	 1	 5.92	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4916	 1	 3.95	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4917	 1	 5.6	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4918	 1	 2.14	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4919	 1	 3.69	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4920	 1	 1.95	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4921	 1	 2.37	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4922	 1	 3.47	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4923	 1	 1.92	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4924	 1	 2.4	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4925	 1	 5.38	 1.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4926	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4927	 1	 1.92	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4928	 1	 2.05	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4929	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4930	 1	 1.33	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4931	 1	 1.05	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4932	 1	 3.38	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4933	 1	 2.76	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4934	 1	 2.3	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4935	 1	 2.4	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4936	 1	 2.35	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4937	 1	 2.56	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4938	 1	 2.58	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4939	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4940	 1	 1.95	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4941	 1	 4.38	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4942	 1	 2.5	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4943	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4944	 1	 5.25	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4945	 1	 3.82	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4946	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4947	 1	 2.26	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4948	 1	 0.99	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4949	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4950	 1	 4.26	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4951	 1	 3.1	 0.75	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4952	 1	 3.05	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4953	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4954	 1	 2.58	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4955	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4956	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4957	 1	 4.34	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4958	 1	 4.39	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4959	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4960	 1	 4.14	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4961	 1	 1.43	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4962	 1	 2.35	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4963	 1	 2.5	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4964	 1	 3.53	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4965	 1	 4.32	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4966	 1	 4.68	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4967	 1	 5.69	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4968	 1	 3.25	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4969	 1	 2.71	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4970	 1	 3.75	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4971	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4972	 1	 6.91	 1.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4973	 1	 10.01	 2.41	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4974	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4975	 1	 1.73	 0.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4976	 1	 4.99	 1.2	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4977	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4978	 1	 1.99	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4979	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4980	 1	 3.07	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4981	 1	 4.35	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4982	 1	 6.91	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4983	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4984	 1	 3.89	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4985	 1	 2.97	 0.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4986	 1	 6.21	 1.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4987	 1	 4.6	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4988	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4989	 1	 9.11	 2.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4990	 1	 2.84	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4991	 1	 2.76	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4992	 1	 6.94	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4993	 1	 5.7	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4994	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4995	 1	 3.9	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4996	 1	 3.36	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4997	 1	 2.67	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	4998	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	4999	 1	 4.86	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5000	 1	 2.86	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5001	 1	 2.07	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5002	 1	 6.66	 1.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5003	 1	 4.57	 1.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5004	 1	 3.69	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5005	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5006	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5007	 1	 4.64	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5008	 1	 5.05	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5009	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5010	 1	 1.1	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5011	 1	 3.7	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5012	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5013	 1	 6.35	 1.52	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5014	 1	 1.64	 0.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5015	 1	 8.77	 2.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5016	 1	 3.01	 0.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5017	 1	 3.6	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5018	 1	 2.41	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5019	 1	 2.81	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5020	 1	 1.47	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5021	 1	 4.96	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5022	 1	 4.31	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5023	 1	 1.95	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5024	 1	 5.08	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5025	 1	 1.51	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5026	 1	 3.08	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5027	 1	 1.4	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5028	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5029	 1	 13.5	 3.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5030	 1	 2.52	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5031	 1	 3.33	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5032	 1	 4.22	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5033	 1	 9.17	 2.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5034	 1	 1.83	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5035	 1	 2.66	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5036	 1	 5.08	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5037	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5038	 1	 3.74	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5039	 1	 2.21	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5040	 1	 2.32	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5041	 1	 7.67	 1.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5042	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5043	 1	 4.96	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5044	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5045	 1	 1.48	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5046	 1	 1.35	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5047	 1	 1.55	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5048	 1	 3.2	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5049	 1	 1.57	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5050	 1	 2.3	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5051	 1	 1.2	 0.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5052	 1	 2.5	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5053	 1	 2.75	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5054	 1	 3.41	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5055	 1	 3.33	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5056	 1	 7.58	 1.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5057	 1	 2.74	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5058	 1	 3.91	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5059	 1	 1.83	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5060	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5061	 1	 1.79	 0.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5062	 1	 2.41	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5063	 1	 2.41	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5064	 1	 2.94	 0.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5065	 1	 1.0	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5066	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5067	 1	 1.65	 0.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5068	 1	 4.15	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5069	 1	 1.16	 0.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5070	 1	 2.11	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5071	 1	 2.48	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5072	 1	 1.31	 0.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5073	 1	 3.03	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5074	 1	 3.33	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5075	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5076	 1	 2.47	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5077	 1	 2.2	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5078	 1	 3.61	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5079	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5080	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5081	 1	 2.43	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5082	 1	 2.72	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5083	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5084	 1	 2.77	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5085	 1	 3.96	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5086	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5087	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5088	 1	 3.79	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5089	 1	 4.08	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5090	 1	 1.93	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5091	 1	 3.11	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5092	 1	 4.54	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5093	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5094	 1	 2.03	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5095	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5096	 1	 2.62	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5097	 1	 4.17	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5098	 1	 1.73	 0.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5099	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5100	 1	 3.68	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5101	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5102	 1	 3.07	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5103	 1	 3.88	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5104	 1	 3.28	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5105	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	5106	 1	 0.38	 0.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5107	 1	 1.52	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5108	 1	 5.77	 1.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5109	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5110	 1	 1.92	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5111	 1	 2.04	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5112	 1	 3.3	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5113	 1	 2.71	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5114	 1	 1.62	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5115	 1	 3.4	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5116	 1	 1.75	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5117	 1	 1.62	 0.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5118	 1	 3.17	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5119	 1	 3.67	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5120	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5121	 1	 5.07	 1.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5122	 1	 5.33	 1.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5123	 1	 4.04	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5124	 1	 2.56	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5125	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5126	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5127	 1	 7.67	 1.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5128	 1	 2.41	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5129	 1	 4.67	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5130	 1	 3.67	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5131	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5132	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5133	 1	 2.56	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5134	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5135	 1	 2.98	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5136	 1	 4.66	 1.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5137	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5138	 1	 4.33	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5139	 1	 5.98	 1.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5140	 1	 3.45	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5141	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5142	 1	 4.37	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5143	 1	 1.44	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5144	 1	 1.45	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5145	 1	 3.46	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5146	 1	 4.94	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5147	 1	 7.58	 1.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5148	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5149	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5150	 1	 3.99	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5151	 1	 4.11	 0.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5152	 1	 3.39	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5153	 1	 2.21	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5154	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5155	 1	 5.87	 1.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5156	 1	 4.6	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5157	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5158	 1	 7.94	 1.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5159	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5160	 1	 4.82	 1.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5161	 1	 4.46	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5162	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5163	 1	 3.52	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5164	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5165	 1	 6.5	 1.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5166	 1	 5.87	 1.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5167	 1	 6.37	 1.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5168	 1	 4.45	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5169	 1	 4.53	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5170	 1	 1.22	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5171	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5172	 1	 1.95	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5173	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5174	 1	 4.05	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5175	 1	 3.69	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5176	 1	 4.26	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5177	 1	 5.45	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5178	 1	 2.07	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5179	 1	 2.92	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5180	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5181	 1	 3.1	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5182	 1	 7.79	 1.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5183	 1	 1.91	 0.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5184	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5185	 1	 2.84	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5186	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5187	 1	 1.12	 0.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5188	 1	 8.22	 2.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5189	 1	 3.6	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5190	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5191	 1	 4.37	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5192	 1	 2.46	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5193	 1	 2.77	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5194	 1	 11.44	 2.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5195	 1	 2.29	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5196	 1	 1.94	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5197	 1	 2.94	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5198	 1	 1.96	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5199	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5200	 1	 1.13	 0.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5201	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5202	 1	 5.18	 1.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5203	 1	 4.5	 1.09	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5204	 1	 4.96	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5205	 1	 0.74	 0.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5206	 1	 1.03	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5207	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5208	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5209	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5210	 1	 2.7	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5211	 1	 2.09	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5212	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5213	 1	 2.44	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5214	 1	 2.38	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5215	 1	 40.01	 9.75	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5216	 1	 3.49	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5217	 1	 4.07	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5218	 1	 4.64	 1.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5219	 1	 3.42	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5220	 1	 4.42	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5221	 1	 19.71	 4.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5222	 1	 2.13	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5223	 1	 2.2	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5224	 1	 5.03	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5225	 1	 11.51	 2.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5226	 1	 5.09	 1.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5227	 1	 3.36	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5228	 1	 3.7	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5229	 1	 2.33	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5230	 1	 11.01	 2.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5231	 1	 3.75	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5232	 1	 5.81	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5233	 1	 6.94	 1.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5234	 1	 2.12	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5235	 1	 6.61	 1.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5236	 1	 1.2	 0.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5237	 1	 6.13	 1.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5238	 1	 2.84	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5239	 1	 1.83	 0.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5240	 1	 1.97	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5241	 1	 3.34	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5242	 1	 1.21	 0.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5243	 1	 0.69	 0.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5244	 1	 1.06	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5245	 1	 2.9	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5246	 1	 4.02	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5247	 1	 2.02	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5248	 1	 3.23	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5249	 1	 1.09	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5250	 1	 2.38	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5251	 1	 1.09	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5252	 1	 0.9	 0.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5253	 1	 0.96	 0.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5254	 1	 2.19	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5255	 1	 1.0	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5256	 1	 2.19	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5257	 1	 1.6	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5258	 1	 3.31	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5259	 1	 5.2	 1.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5260	 1	 1.1	 0.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5261	 1	 0.93	 0.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5262	 1	 2.09	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5263	 1	 1.82	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5264	 1	 2.97	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5265	 1	 1.66	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5266	 1	 0.91	 0.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5267	 1	 4.21	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5268	 1	 2.34	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5269	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5270	 1	 7.17	 1.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5271	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5272	 1	 1.76	 0.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5273	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5274	 1	 1.42	 0.34	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5275	 1	 1.52	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5276	 1	 2.42	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5277	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5278	 1	 2.39	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5279	 1	 1.78	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5280	 1	 3.85	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5281	 1	 1.51	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5282	 1	 1.18	 0.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5283	 1	 1.06	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5284	 1	 3.29	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5285	 1	 3.61	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5286	 1	 3.59	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5287	 1	 2.85	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5288	 1	 1.4	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5289	 1	 3.33	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5290	 1	 2.73	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5291	 1	 4.9	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5292	 1	 0.64	 0.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5293	 1	 1.04	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5294	 1	 3.52	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5295	 1	 2.62	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5296	 1	 1.56	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5297	 1	 2.38	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5298	 1	 2.16	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5299	 1	 1.16	 0.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5300	 1	 3.52	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5301	 1	 1.93	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5302	 1	 10.91	 2.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5303	 1	 4.82	 1.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5304	 1	 5.75	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5305	 1	 1.18	 0.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5306	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5307	 1	 3.12	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5308	 1	 4.79	 1.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5309	 1	 3.52	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5310	 1	 2.86	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5311	 1	 5.66	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5312	 1	 5.85	 1.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5313	 1	 3.08	 0.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5314	 1	 4.71	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5315	 1	 1.71	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5316	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5317	 1	 3.96	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5318	 1	 5.02	 1.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5319	 1	 4.63	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5320	 1	 4.9	 1.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5321	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5322	 1	 4.69	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5323	 1	 2.08	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5324	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5325	 1	 5.76	 1.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5326	 1	 12.17	 2.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5327	 1	 6.09	 1.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5328	 1	 6.06	 1.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5329	 1	 5.1	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5330	 1	 4.14	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5331	 1	 8.97	 2.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5332	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5333	 1	 1.15	 0.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5334	 1	 5.35	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5335	 1	 3.63	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5336	 1	 2.16	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5337	 1	 2.9	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5338	 1	 0.98	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5339	 1	 1.97	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5340	 1	 0.02	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5341	 1	 1.15	 0.28	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5342	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5343	 1	 2.17	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5344	 1	 6.13	 1.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5345	 1	 2.88	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5346	 1	 1.63	 0.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5347	 1	 3.37	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5348	 1	 3.77	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5349	 1	 3.8	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5350	 1	 6.61	 1.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5351	 1	 3.97	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5352	 1	 2.98	 0.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5353	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5354	 1	 4.47	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5355	 1	 8.19	 1.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5356	 1	 4.94	 1.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5357	 1	 5.29	 1.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5358	 1	 2.21	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5359	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5360	 1	 4.65	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5361	 1	 2.33	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5362	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5363	 1	 1.37	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5364	 1	 5.1	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5365	 1	 3.74	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5366	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5367	 1	 8.1	 1.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5368	 1	 6.15	 1.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5369	 1	 6.63	 1.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5370	 1	 3.43	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5371	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5372	 1	 3.37	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5373	 1	 4.18	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5374	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5375	 1	 1.89	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5376	 1	 5.03	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5377	 1	 7.17	 1.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5378	 1	 2.21	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5379	 1	 2.52	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5380	 1	 1.74	 0.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5381	 1	 6.58	 1.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5382	 1	 1.62	 0.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5383	 1	 2.23	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5384	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5385	 1	 3.39	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5386	 1	 6.47	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5387	 1	 4.54	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5388	 1	 6.65	 1.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5389	 1	 2.22	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5390	 1	 2.53	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5391	 1	 1.22	 0.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5392	 1	 2.63	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5393	 1	 1.18	 0.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5394	 1	 1.79	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5395	 1	 3.86	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5396	 1	 1.11	 0.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5397	 1	 2.61	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5398	 1	 4.12	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5399	 1	 0.8	 0.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5400	 1	 1.03	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5401	 1	 1.11	 0.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5402	 1	 2.84	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5403	 1	 2.73	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5404	 1	 1.39	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5405	 1	 1.5	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5406	 1	 1.09	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5407	 1	 1.21	 0.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5408	 1	 0.82	 0.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5409	 1	 1.24	 0.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5410	 1	 1.08	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5411	 1	 3.17	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5412	 1	 1.19	 0.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5413	 1	 4.29	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5414	 1	 5.6	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5415	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5416	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5417	 1	 5.5	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5418	 1	 14.46	 3.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5419	 1	 7.89	 1.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5420	 1	 11.27	 2.69	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5421	 1	 7.02	 1.68	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5422	 1	 2.01	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5423	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5424	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5425	 1	 5.37	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5426	 1	 1.9	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5427	 1	 2.52	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5428	 1	 3.5	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5429	 1	 3.95	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5430	 1	 4.19	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5431	 1	 1.15	 0.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5432	 1	 2.0	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5433	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5434	 1	 1.55	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5435	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5436	 1	 2.49	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5437	 1	 2.26	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5438	 1	 6.0	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5439	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5440	 1	 2.28	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5441	 1	 1.43	 0.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5442	 1	 1.41	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5443	 1	 2.04	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5444	 1	 4.03	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5445	 1	 2.31	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5446	 1	 3.86	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5447	 1	 2.12	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5448	 1	 2.4	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5449	 1	 2.83	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5450	 1	 1.74	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5451	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5452	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5453	 1	 0.12	 0.03	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5454	 1	 1.69	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5455	 1	 1.93	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5456	 1	 4.65	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5457	 1	 1.87	 0.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5458	 1	 2.61	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5459	 1	 2.2	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5460	 1	 4.09	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5461	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5462	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5463	 1	 5.13	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5464	 1	 3.81	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5465	 1	 1.27	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5466	 1	 10.43	 2.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5467	 1	 2.27	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5468	 1	 3.04	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5469	 1	 5.49	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5470	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5471	 1	 2.16	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5472	 1	 2.46	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5473	 1	 2.71	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5474	 1	 8.31	 1.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5475	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5476	 1	 1.61	 0.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5477	 1	 2.58	 1.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5478	 1	 9.75	 4.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5479	 1	 6.0	 2.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5480	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5481	 1	 21.56	 5.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5482	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5483	 1	 9.28	 2.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5484	 1	 3.59	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5485	 1	 8.71	 2.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5486	 1	 4.61	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5487	 1	 6.05	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5488	 1	 8.3	 2.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5489	 1	 3.54	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5490	 1	 1.97	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5491	 1	 2.76	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5492	 1	 2.62	 1.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5493	 1	 4.78	 1.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5494	 1	 9.51	 2.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5495	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5496	 1	 2.26	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5497	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5498	 1	 5.25	 1.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5499	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5500	 1	 3.8	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5501	 1	 1.43	 0.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5502	 1	 3.57	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5503	 1	 9.66	 2.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5504	 1	 5.22	 1.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5505	 1	 10.34	 2.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5506	 1	 8.89	 2.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5507	 1	 5.65	 1.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5508	 1	 7.66	 3.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5509	 1	 15.11	 3.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5510	 1	 2.33	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5511	 1	 12.6	 3.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5512	 1	 2.08	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5513	 1	 6.14	 1.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5514	 1	 1.44	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5515	 1	 0.97	 0.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5516	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5517	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5518	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5519	 1	 2.68	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5520	 1	 2.91	 1.4	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5521	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5522	 1	 2.41	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5523	 1	 0.86	 0.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5524	 1	 4.1	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5525	 1	 1.68	 0.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5526	 1	 3.4	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5527	 1	 2.43	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5528	 1	 0.93	 0.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5529	 1	 1.61	 0.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5530	 1	 4.05	 0.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5531	 1	 1.72	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5532	 1	 2.13	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5533	 1	 1.3	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5534	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5535	 1	 1.35	 0.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5536	 1	 0.95	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5537	 1	 1.09	 0.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5538	 1	 3.04	 0.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5539	 1	 2.11	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5540	 1	 3.74	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5541	 1	 1.37	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5542	 1	 1.87	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5543	 1	 1.2	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5544	 1	 4.61	 1.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5545	 1	 1.1	 0.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5546	 1	 1.12	 0.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5547	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5548	 1	 1.31	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5549	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5550	 1	 1.09	 0.27	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5551	 1	 2.24	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5552	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5553	 1	 2.32	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5554	 1	 1.32	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5555	 1	 5.53	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5556	 1	 3.13	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5557	 1	 1.66	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5558	 1	 1.51	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5559	 1	 1.71	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5560	 1	 1.92	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5561	 1	 13.15	 3.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5562	 1	 1.27	 0.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5563	 1	 3.27	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5564	 1	 1.99	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5565	 1	 4.5	 1.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5566	 1	 3.93	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5567	 1	 5.51	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5568	 1	 2.51	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5569	 1	 3.36	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5570	 1	 2.17	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5571	 1	 2.57	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5572	 1	 9.07	 2.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5573	 1	 1.73	 0.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5574	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5575	 1	 3.87	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5576	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5577	 1	 5.7	 1.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5578	 1	 20.13	 4.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5579	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5580	 1	 9.71	 2.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5581	 1	 10.11	 2.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5582	 1	 12.42	 3.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5583	 1	 2.02	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5584	 1	 12.3	 2.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5585	 1	 5.47	 1.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5586	 1	 2.34	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5587	 1	 4.74	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5588	 1	 2.87	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5589	 1	 0.83	 0.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5590	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5591	 1	 2.41	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5592	 1	 2.13	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5593	 1	 3.44	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5594	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5595	 1	 6.09	 1.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5596	 1	 4.67	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5597	 1	 1.94	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5598	 1	 1.89	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5599	 1	 4.37	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5600	 1	 2.26	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5601	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5602	 1	 2.31	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5603	 1	 2.85	 1.52	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5604	 1	 1.17	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5605	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5606	 1	 3.78	 2.01	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5607	 1	 6.95	 3.4	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5608	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5609	 1	 3.45	 1.91	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5610	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5611	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5612	 1	 6.21	 1.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5613	 1	 4.15	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5614	 1	 4.41	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5615	 1	 4.85	 1.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5616	 1	 6.03	 1.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5617	 1	 1.83	 0.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5618	 1	 2.49	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5619	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5620	 1	 5.9	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5621	 1	 3.48	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5622	 1	 3.87	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5623	 1	 2.42	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5624	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5625	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5626	 1	 5.7	 1.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5627	 1	 3.4	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5628	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5629	 1	 9.8	 2.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5630	 1	 2.03	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5631	 1	 8.1	 1.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5632	 1	 2.37	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5633	 1	 2.35	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5634	 1	 3.04	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5635	 1	 8.51	 2.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5636	 1	 6.17	 1.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5637	 1	 2.9	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5638	 1	 2.77	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5639	 1	 3.57	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5640	 1	 2.55	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5641	 1	 9.37	 2.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5642	 1	 11.45	 2.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5643	 1	 3.7	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5644	 1	 22.71	 5.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5645	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5646	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	5647	 1	 4.3	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5648	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5649	 1	 10.71	 2.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5650	 1	 3.82	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5651	 1	 5.21	 1.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5652	 1	 4.28	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5653	 1	 2.34	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5654	 1	 3.14	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5655	 1	 2.88	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5656	 1	 6.08	 1.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5657	 1	 3.7	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5658	 1	 2.26	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5659	 1	 3.47	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5660	 1	 3.48	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5661	 1	 3.41	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5662	 1	 1.23	 0.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5663	 1	 2.52	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5664	 1	 3.92	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5665	 1	 6.46	 1.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5666	 1	 2.96	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5667	 1	 3.23	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5668	 1	 3.42	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5669	 1	 2.25	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5670	 1	 4.55	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5671	 1	 2.7	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5672	 1	 6.4	 1.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5673	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5674	 1	 5.17	 1.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5675	 1	 1.52	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5676	 1	 5.23	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5677	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5678	 1	 14.48	 3.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5679	 1	 3.23	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5680	 1	 2.01	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5681	 1	 8.47	 2.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5682	 1	 5.49	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5683	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5684	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5685	 1	 15.47	 3.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5686	 1	 5.08	 1.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5687	 1	 2.28	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5688	 1	 4.8	 1.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5689	 1	 6.33	 1.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5690	 1	 3.26	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5691	 1	 3.23	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5692	 1	 3.79	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5693	 1	 15.63	 3.82	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5694	 1	 2.91	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5695	 1	 2.77	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5696	 1	 5.99	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5697	 1	 5.04	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5698	 1	 7.58	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5699	 1	 10.31	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5700	 1	 6.35	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5701	 1	 5.44	 1.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5702	 1	 0.01	 0.01	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5703	 1	 2.54	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5704	 1	 1.83	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5705	 1	 4.31	 0.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5706	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5707	 1	 3.41	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5708	 1	 3.22	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5709	 1	 10.75	 2.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5710	 1	 7.54	 1.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5711	 1	 17.92	 4.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5712	 1	 7.69	 1.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5713	 1	 3.82	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5714	 1	 6.54	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5715	 1	 11.83	 2.76	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5716	 1	 7.54	 1.76	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5717	 1	 9.48	 2.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5718	 1	 5.13	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5719	 1	 14.82	 3.63	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5720	 1	 4.17	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5721	 1	 9.86	 2.4	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5722	 1	 8.89	 2.16	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5723	 1	 4.22	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5724	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5725	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5726	 1	 11.29	 2.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5727	 1	 8.2	 2.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5728	 1	 7.04	 1.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5729	 1	 5.65	 1.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5730	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5731	 1	 14.55	 3.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5732	 1	 8.79	 3.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5733	 1	 1.93	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5734	 1	 4.62	 2.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5735	 1	 1.91	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5736	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5737	 1	 2.29	 1.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5738	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5739	 1	 6.16	 1.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5740	 1	 5.69	 1.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5741	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5742	 1	 3.16	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5743	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5744	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5745	 1	 6.84	 1.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5746	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5747	 1	 4.63	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5748	 1	 7.72	 1.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5749	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5750	 1	 8.03	 1.95	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5751	 1	 5.62	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5752	 1	 3.21	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5753	 1	 5.47	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5754	 1	 6.25	 1.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5755	 1	 7.38	 1.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5756	 1	 4.92	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5757	 1	 3.24	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5758	 1	 7.5	 1.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5759	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5760	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5761	 1	 13.99	 3.47	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5762	 1	 4.2	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5763	 1	 2.24	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5764	 1	 9.41	 2.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5765	 1	 5.43	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5766	 1	 21.02	 5.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5767	 1	 3.12	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5768	 1	 3.13	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5769	 1	 2.91	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5770	 1	 2.98	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5771	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5772	 1	 2.7	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5773	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5774	 1	 8.18	 1.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5775	 1	 3.13	 0.75	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5776	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5777	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5778	 1	 8.8	 2.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5779	 1	 3.45	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5780	 1	 3.4	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5781	 1	 5.73	 1.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5782	 1	 7.65	 1.85	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5783	 1	 4.04	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5784	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5785	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5786	 1	 6.66	 1.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5787	 1	 9.54	 2.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5788	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5789	 1	 1.76	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5790	 1	 4.44	 1.09	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5791	 1	 1.74	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5792	 1	 7.47	 1.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5793	 1	 5.35	 1.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5794	 1	 10.99	 2.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5795	 1	 8.03	 1.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5796	 1	 4.53	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5797	 1	 8.34	 2.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5798	 1	 6.57	 1.61	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5799	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5800	 1	 3.14	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5801	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5802	 1	 6.69	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5803	 1	 4.91	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5804	 1	 3.49	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5805	 1	 2.78	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5806	 1	 2.47	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5807	 1	 2.04	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5808	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	5809	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5810	 1	 5.72	 1.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5811	 1	 3.62	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5812	 1	 5.74	 1.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5813	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5814	 1	 7.04	 1.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5815	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5816	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5817	 1	 4.54	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5818	 1	 4.82	 1.18	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5819	 1	 5.36	 1.31	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5820	 1	 6.42	 1.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5821	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5822	 1	 6.78	 1.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5823	 1	 4.63	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5824	 1	 3.46	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5825	 1	 4.11	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5826	 1	 2.76	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5827	 1	 8.04	 1.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5828	 1	 8.01	 1.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5829	 1	 6.61	 1.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5830	 1	 3.75	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5831	 1	 8.26	 2.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5832	 1	 5.01	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5833	 1	 4.94	 1.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5834	 1	 2.26	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5835	 1	 6.16	 1.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5836	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5837	 1	 7.48	 1.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5838	 1	 6.38	 1.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5839	 1	 4.29	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5840	 1	 5.57	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5841	 1	 5.95	 1.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5842	 1	 6.4	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5843	 1	 7.01	 1.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5844	 1	 9.37	 2.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5845	 1	 8.85	 2.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5846	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5847	 1	 4.88	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5848	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5849	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5850	 1	 4.62	 1.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5851	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5852	 1	 12.54	 2.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5853	 1	 4.84	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5854	 1	 8.85	 2.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5855	 1	 1.83	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5856	 1	 6.64	 1.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5857	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5858	 1	 8.45	 2.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5859	 1	 1.9	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5860	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5861	 1	 4.79	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5862	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5863	 1	 6.52	 1.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5864	 1	 6.05	 1.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5865	 1	 4.02	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5866	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5867	 1	 4.01	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5868	 1	 2.08	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5869	 1	 2.23	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5870	 1	 6.02	 1.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5871	 1	 3.35	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5872	 1	 6.03	 1.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5873	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5874	 1	 6.83	 1.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5875	 1	 19.66	 4.91	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5876	 1	 5.85	 1.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5877	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	5878	 1	 8.54	 2.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5879	 1	 5.05	 1.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5880	 1	 10.17	 2.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5881	 1	 4.76	 1.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5882	 1	 2.19	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5883	 1	 8.95	 2.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5884	 1	 3.65	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5885	 1	 3.05	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5886	 1	 3.88	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5887	 1	 3.09	 0.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5888	 1	 2.55	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5889	 1	 4.37	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5890	 1	 3.08	 0.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5891	 1	 3.51	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5892	 1	 21.46	 5.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5893	 1	 4.77	 1.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5894	 1	 5.19	 1.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5895	 1	 2.09	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5896	 1	 3.38	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5897	 1	 11.52	 2.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5898	 1	 6.03	 1.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5899	 1	 5.77	 1.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5900	 1	 4.54	 1.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5901	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5902	 1	 5.92	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5903	 1	 4.89	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5904	 1	 6.6	 1.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5905	 1	 6.34	 1.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5906	 1	 5.9	 1.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5907	 1	 1.67	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5908	 1	 6.9	 1.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5909	 1	 10.23	 2.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5910	 1	 6.6	 1.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5911	 1	 6.85	 1.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5912	 1	 7.45	 1.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5913	 1	 5.15	 1.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5914	 1	 4.02	 1.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5915	 1	 2.62	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5916	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5917	 1	 2.03	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5918	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5919	 1	 7.03	 1.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5920	 1	 4.03	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5921	 1	 2.94	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5922	 1	 3.18	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5923	 1	 3.65	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5924	 1	 10.04	 2.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5925	 1	 2.24	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5926	 1	 11.15	 2.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5927	 1	 3.93	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5928	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5929	 1	 6.9	 1.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5930	 1	 3.01	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5931	 1	 4.27	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5932	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5933	 1	 5.83	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5934	 1	 12.49	 7.07	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5935	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5936	 1	 2.79	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5937	 1	 6.72	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5938	 1	 2.6	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5939	 1	 2.41	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5940	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5941	 1	 6.98	 1.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5942	 1	 4.49	 2.68	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5943	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5944	 1	 7.92	 3.87	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5945	 1	 12.78	 3.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5946	 1	 9.87	 4.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5947	 1	 9.64	 2.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5948	 1	 2.45	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5949	 1	 5.42	 1.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5950	 1	 13.68	 3.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5951	 1	 3.41	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5952	 1	 19.44	 4.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5953	 1	 9.38	 4.65	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5954	 1	 5.23	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5955	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5956	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5957	 1	 2.81	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5958	 1	 5.9	 1.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5959	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5960	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5961	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5962	 1	 2.04	 1.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5963	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5964	 1	 5.18	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5965	 1	 7.19	 1.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5966	 1	 3.4	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5967	 1	 17.18	 8.29	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5968	 1	 5.42	 2.97	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5969	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5970	 1	 2.89	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5971	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5972	 1	 5.74	 1.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5973	 1	 7.95	 1.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5974	 1	 3.06	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5975	 1	 4.96	 1.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5976	 1	 6.03	 1.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5977	 1	 5.23	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5978	 1	 5.57	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5979	 1	 8.54	 2.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5980	 1	 5.72	 1.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5981	 1	 2.9	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5982	 1	 7.58	 1.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5983	 1	 3.51	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5984	 1	 4.31	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5985	 1	 5.29	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5986	 1	 2.62	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5987	 1	 2.97	 0.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5988	 1	 1.9	 0.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5989	 1	 7.07	 1.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5990	 1	 3.24	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5991	 1	 7.83	 1.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5992	 1	 3.56	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5993	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5994	 1	 3.7	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5995	 1	 0.67	 0.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5996	 1	 0.83	 0.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5997	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	5998	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	5999	 1	 2.32	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6000	 1	 6.11	 1.52	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6001	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6002	 1	 11.96	 2.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6003	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6004	 1	 16.13	 3.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6005	 1	 1.21	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6006	 1	 6.28	 1.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6007	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6008	 1	 11.01	 2.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6009	 1	 1.89	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6010	 1	 3.76	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6011	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6012	 1	 9.8	 2.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6013	 1	 6.37	 1.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6014	 1	 7.67	 1.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6015	 1	 2.96	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6016	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6017	 1	 4.4	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6018	 1	 1.43	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6019	 1	 5.66	 1.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6020	 1	 3.94	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6021	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6022	 1	 5.18	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6023	 1	 2.71	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6024	 1	 5.2	 2.93	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6025	 1	 13.0	 3.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6026	 1	 3.5	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6027	 1	 6.35	 1.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6028	 1	 7.04	 1.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6029	 1	 8.03	 1.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6030	 1	 14.0	 3.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6031	 1	 8.52	 2.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6032	 1	 4.71	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6033	 1	 2.17	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6034	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6035	 1	 10.19	 2.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6036	 1	 8.73	 2.14	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6037	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6038	 1	 5.39	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6039	 1	 8.49	 2.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6040	 1	 6.72	 1.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6041	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6042	 1	 1.56	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6043	 1	 3.4	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6044	 1	 15.67	 3.9	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6045	 1	 4.5	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6046	 1	 11.64	 2.88	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6047	 1	 9.09	 2.25	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6048	 1	 12.33	 3.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6049	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6050	 1	 3.21	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6051	 1	 13.53	 3.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6052	 1	 8.17	 2.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6053	 1	 13.32	 3.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6054	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6055	 1	 2.74	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6056	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6057	 1	 18.9	 4.74	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6058	 1	 15.79	 3.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6059	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6060	 1	 11.89	 2.94	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6061	 1	 14.06	 3.5	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6062	 1	 5.73	 1.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6063	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	6064	 1	 7.47	 1.84	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6065	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6066	 1	 8.51	 2.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6067	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	6068	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6069	 1	 18.83	 4.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6070	 1	 4.14	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6071	 1	 9.12	 2.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6072	 1	 9.41	 2.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6073	 1	 8.92	 2.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6074	 1	 9.25	 2.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6075	 1	 11.34	 2.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6076	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6077	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	6078	 1	 6.77	 1.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6079	 1	 9.61	 2.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6080	 1	 5.07	 1.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6081	 1	 10.7	 2.64	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6082	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6083	 1	 17.55	 4.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6084	 1	 8.21	 1.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6085	 1	 21.04	 5.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6086	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6087	 1	 6.08	 1.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6088	 1	 20.25	 4.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6089	 1	 5.86	 1.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6090	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6091	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	6092	 1	 3.54	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6093	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6094	 1	 17.34	 4.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6095	 1	 13.78	 3.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6096	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6097	 1	 6.48	 1.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6098	 1	 5.23	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6099	 1	 7.78	 1.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6100	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6101	 1	 11.02	 2.72	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6102	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6103	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6104	 1	 10.43	 2.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6105	 1	 8.64	 2.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6106	 1	 6.28	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6107	 1	 3.51	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6108	 1	 2.19	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6109	 1	 17.99	 4.44	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6110	 1	 4.6	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6111	 1	 5.35	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6112	 1	 6.75	 1.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6113	 1	 14.0	 3.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6114	 1	 10.25	 2.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6115	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6116	 1	 8.15	 1.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6117	 1	 11.29	 2.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6118	 1	 11.01	 2.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6119	 1	 9.25	 2.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6120	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6121	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6122	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6123	 1	 9.7	 2.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6124	 1	 16.33	 3.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6125	 1	 19.12	 4.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6126	 1	 11.96	 2.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6127	 1	 14.51	 3.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6128	 1	 18.96	 4.67	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6129	 1	 11.95	 2.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6130	 1	 16.48	 4.05	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6131	 1	 14.56	 3.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6132	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	6133	 1	 24.68	 5.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6134	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	6135	 1	 23.41	 5.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6136	 1	 21.0	 5.16	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6137	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6138	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6139	 1	 13.14	 3.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6140	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6141	 1	 6.52	 1.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6142	 1	 6.8	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6143	 1	 17.85	 4.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6144	 1	 4.04	 0.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6145	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6146	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6147	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6148	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6149	 1	 22.66	 5.51	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6150	 1	 6.47	 1.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6151	 1	 10.09	 2.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6152	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6153	 1	 16.33	 3.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6154	 1	 7.86	 1.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6155	 1	 4.4	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6156	 1	 1.29	 0.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6157	 1	 14.65	 3.56	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6158	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6159	 1	 6.88	 1.67	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6160	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6161	 1	 12.51	 3.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6162	 1	 10.16	 2.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6163	 1	 8.62	 2.09	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6164	 1	 9.63	 2.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6165	 1	 17.13	 4.17	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6166	 1	 6.64	 1.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6167	 1	 14.8	 3.6	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6168	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6169	 1	 17.89	 4.36	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6170	 1	 9.99	 2.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6171	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6172	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6173	 1	 14.66	 3.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6174	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6175	 1	 11.23	 2.73	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6176	 1	 7.75	 1.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6177	 1	 1.18	 0.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6178	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6179	 1	 16.55	 4.03	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6180	 1	 8.4	 2.06	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6181	 1	 12.23	 2.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6182	 1	 8.6	 2.1	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6183	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6184	 1	 7.21	 1.76	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6185	 1	 18.08	 4.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6186	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6187	 1	 6.96	 1.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6188	 1	 4.4	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6189	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6190	 1	 9.38	 2.29	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6191	 1	 15.69	 3.82	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6192	 1	 2.53	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6193	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6194	 1	 4.22	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6195	 1	 7.86	 1.92	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6196	 1	 6.69	 1.63	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6197	 1	 12.41	 2.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6198	 1	 6.81	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6199	 1	 1.36	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6200	 1	 2.37	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6201	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6202	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6203	 1	 4.25	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6204	 1	 3.97	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6205	 1	 2.17	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6206	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6207	 1	 10.39	 2.53	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6208	 1	 4.11	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6209	 1	 4.47	 1.09	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6210	 1	 6.58	 1.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6211	 1	 3.26	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6212	 1	 8.53	 2.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6213	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6214	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6215	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6216	 1	 3.09	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6217	 1	 3.93	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6218	 1	 10.25	 2.5	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6219	 1	 7.21	 1.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6220	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6221	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6222	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6223	 1	 2.22	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6224	 1	 4.49	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6225	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6226	 1	 5.3	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6227	 1	 5.21	 1.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6228	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6229	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6230	 1	 4.13	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6231	 1	 3.75	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6232	 1	 9.27	 2.26	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6233	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6234	 1	 6.3	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6235	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6236	 1	 8.07	 1.97	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6237	 1	 4.11	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6238	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6239	 1	 1.02	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6240	 1	 7.8	 1.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6241	 1	 6.03	 1.47	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6242	 1	 2.13	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6243	 1	 5.53	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6244	 1	 6.9	 1.67	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6245	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6246	 1	 6.22	 1.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6247	 1	 7.94	 1.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6248	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6249	 1	 7.78	 1.89	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6250	 1	 3.82	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6251	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	6252	 1	 13.32	 3.24	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6253	 1	 16.25	 3.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6254	 1	 5.58	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6255	 1	 5.77	 1.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6256	 1	 10.4	 2.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6257	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6258	 1	 10.75	 2.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6259	 1	 2.22	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6260	 1	 9.54	 2.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6261	 1	 7.61	 1.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6262	 1	 12.58	 3.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6263	 1	 2.8	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6264	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	6265	 1	 13.59	 3.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6266	 1	 4.61	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6267	 1	 7.29	 1.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6268	 1	 7.86	 1.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6269	 1	 4.47	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6270	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6271	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6272	 1	 6.1	 1.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6273	 1	 1.69	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6274	 1	 9.36	 2.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6275	 1	 11.11	 2.69	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6276	 1	 3.33	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6277	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6278	 1	 1.0	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6279	 1	 7.33	 1.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6280	 1	 15.0	 3.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6281	 1	 0.21	 0.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6282	 1	 3.81	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6283	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6284	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6285	 1	 1.08	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6286	 1	 3.88	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6287	 1	 0.81	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6288	 1	 1.56	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6289	 1	 1.98	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6290	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6291	 1	 2.7	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6292	 1	 12.34	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6293	 1	 1.37	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6294	 1	 1.11	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6295	 1	 68.29	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6296	 1	 69.77	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6297	 1	 5.4	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6298	 1	 3.77	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6299	 1	 3.22	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6300	 1	 2.07	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6301	 1	 1.86	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6302	 1	 7.43	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6303	 1	 19.72	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6304	 1	 5.05	 2.34	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6305	 1	 40.92	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6306	 1	 11.92	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6307	 1	 4.52	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6308	 1	 5.24	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6309	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6310	 1	 3.61	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6311	 1	 1.31	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6312	 1	 4.49	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6313	 1	 5.87	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6314	 1	 4.82	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6315	 1	 10.77	 5.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6316	 1	 3.79	 1.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6317	 1	 3.52	 1.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6318	 1	 4.5	 2.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6319	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6320	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6321	 1	 3.28	 1.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6322	 1	 4.89	 2.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6323	 1	 6.42	 3.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6324	 1	 3.18	 1.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6325	 1	 6.83	 3.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6326	 1	 5.53	 2.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6327	 1	 2.83	 1.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6328	 1	 2.4	 1.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6329	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6330	 1	 4.15	 1.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6331	 1	 1.44	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6332	 1	 3.18	 1.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6333	 1	 18.24	 8.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6334	 1	 4.52	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6335	 1	 3.3	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6336	 1	 17.59	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6337	 1	 3.54	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6338	 1	 2.56	 1.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6339	 1	 98.88	 42.06	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6340	 1	 3.48	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6341	 1	 1.25	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6342	 1	 3.13	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6343	 1	 3.52	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6344	 1	 1.58	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6345	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6346	 1	 2.39	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6347	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6348	 1	 1.23	 0.29	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6349	 1	 1.05	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6350	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6351	 1	 1.51	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6352	 1	 1.22	 0.28	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6353	 1	 1.61	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6354	 1	 8.01	 1.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6355	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6356	 1	 2.31	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6357	 1	 1.7	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6358	 1	 4.98	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6359	 1	 1.46	 0.34	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6360	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6361	 1	 3.49	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6362	 1	 5.85	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6363	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6364	 1	 4.21	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6365	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6366	 1	 1.57	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6367	 1	 3.87	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6368	 1	 3.06	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6369	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6370	 1	 2.76	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6371	 1	 4.88	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6372	 1	 11.68	 2.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6373	 1	 5.34	 1.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6374	 1	 6.7	 1.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6375	 1	 3.92	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6376	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	6377	 1	 1.29	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6378	 1	 7.98	 1.89	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6379	 1	 2.41	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6380	 1	 1.29	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6381	 1	 1.51	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6382	 1	 3.85	 2.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6383	 1	 1.26	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6384	 1	 2.1	 1.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6385	 1	 9.35	 2.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6386	 1	 2.42	 1.29	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6387	 1	 2.24	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6388	 1	 9.66	 2.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6389	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6390	 1	 7.86	 3.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6391	 1	 3.86	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6392	 1	 6.14	 1.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6393	 1	 3.07	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6394	 1	 3.71	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6395	 1	 16.58	 3.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6396	 1	 6.36	 1.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6397	 1	 4.57	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6398	 1	 6.39	 1.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6399	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6400	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6401	 1	 0.86	 0.2	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6402	 1	 2.61	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6403	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6404	 1	 31.57	 7.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6405	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6406	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6407	 1	 5.56	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6408	 1	 5.64	 1.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6409	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6410	 1	 14.2	 6.28	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6411	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6412	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6413	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6414	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6415	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6416	 1	 25.45	 6.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6417	 1	 4.25	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6418	 1	 1.28	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6419	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6420	 1	 4.5	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6421	 1	 2.79	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6422	 1	 1.04	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6423	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6424	 1	 1.73	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6425	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6426	 1	 1.94	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6427	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6428	 1	 2.68	 1.4	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6429	 1	 1.55	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6430	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6431	 1	 1.51	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6432	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6433	 1	 2.38	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6434	 1	 8.53	 2.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6435	 1	 3.73	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6436	 1	 3.16	 1.64	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6437	 1	 1.66	 0.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6438	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6439	 1	 6.45	 1.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6440	 1	 5.93	 1.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6441	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6442	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6443	 1	 4.94	 1.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6444	 1	 3.43	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6445	 1	 1.42	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6446	 1	 2.03	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6447	 1	 1.29	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6448	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6449	 1	 2.45	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6450	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6451	 1	 1.36	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6452	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6453	 1	 5.28	 2.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6454	 1	 2.84	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6455	 1	 0.89	 0.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6456	 1	 1.54	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6457	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6458	 1	 1.4	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6459	 1	 3.11	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6460	 1	 1.95	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6461	 1	 5.86	 2.38	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6462	 1	 2.03	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6463	 1	 1.4	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6464	 1	 2.3	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6465	 1	 1.41	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6466	 1	 1.23	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6467	 1	 2.25	 1.25	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6468	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6469	 1	 1.99	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6470	 1	 1.43	 0.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6471	 1	 2.79	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6472	 1	 5.17	 2.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6473	 1	 10.85	 4.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6474	 1	 1.57	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6475	 1	 2.97	 1.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6476	 1	 5.91	 1.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6477	 1	 2.78	 1.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6478	 1	 4.98	 2.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6479	 1	 1.58	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6480	 1	 6.5	 1.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6481	 1	 8.61	 2.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6482	 1	 3.3	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6483	 1	 2.72	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6484	 1	 1.66	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6485	 1	 2.28	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6486	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6487	 1	 12.51	 4.76	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6488	 1	 3.21	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6489	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6490	 1	 2.91	 1.51	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6491	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6492	 1	 1.41	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6493	 1	 3.71	 1.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6494	 1	 5.08	 2.9	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6495	 1	 11.41	 4.87	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6496	 1	 4.82	 2.06	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6497	 1	 4.67	 2.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6498	 1	 10.3	 4.98	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6499	 1	 3.29	 1.49	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6500	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6501	 1	 8.9	 3.9	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6502	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6503	 1	 4.53	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6504	 1	 1.58	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6505	 1	 2.34	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6506	 1	 6.61	 1.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6507	 1	 2.54	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6508	 1	 5.65	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6509	 1	 3.11	 1.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6510	 1	 14.37	 6.53	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6511	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6512	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6513	 1	 3.5	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6514	 1	 2.46	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6515	 1	 1.72	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6516	 1	 3.29	 1.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6517	 1	 8.77	 2.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6518	 1	 3.68	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6519	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6520	 1	 3.63	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6521	 1	 3.59	 1.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6522	 1	 3.15	 1.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6523	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6524	 1	 15.58	 5.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6525	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	6526	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6527	 1	 22.9	 12.2	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6528	 1	 5.73	 2.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6529	 1	 4.37	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6530	 1	 2.33	 1.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6531	 1	 4.54	 2.05	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6532	 1	 4.49	 2.19	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6533	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6534	 1	 2.64	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6535	 1	 4.16	 2.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6536	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	6537	 1	 1.79	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6538	 1	 3.24	 1.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6539	 1	 4.21	 2.19	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6540	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6541	 1	 1.91	 0.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6542	 1	 1.67	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6543	 1	 16.19	 8.65	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6544	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6545	 1	 11.95	 2.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6546	 1	 3.55	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6547	 1	 1.65	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6548	 1	 4.02	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6549	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6550	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6551	 1	 0.95	 0.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6552	 1	 2.03	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6553	 1	 2.51	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6554	 1	 1.5	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6555	 1	 0.86	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6556	 1	 15.64	 3.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6557	 1	 6.31	 1.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6558	 1	 5.52	 1.33	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6559	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6560	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6561	 1	 4.99	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6562	 1	 9.64	 2.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6563	 1	 10.99	 2.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6564	 1	 5.88	 -4.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6565	 1	 19.15	 4.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6566	 1	 5.04	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6567	 1	 2.11	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6568	 1	 4.21	 0.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6569	 1	 6.37	 1.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6570	 1	 11.11	 2.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6571	 1	 3.3	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6572	 1	 10.93	 2.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6573	 1	 4.85	 1.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6574	 1	 3.05	 0.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6575	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6576	 1	 4.47	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6577	 1	 4.03	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6578	 1	 4.75	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6579	 1	 5.71	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6580	 1	 2.97	 -4.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6581	 1	 4.3	 1.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6582	 1	 2.91	 1.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6583	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6584	 1	 6.59	 3.75	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6585	 1	 3.4	 1.87	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6586	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6587	 1	 7.95	 3.53	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6588	 1	 5.04	 2.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6589	 1	 6.3	 2.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6590	 1	 2.83	 1.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6591	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6592	 1	 7.15	 4.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6593	 1	 4.93	 1.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6594	 1	 5.74	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6595	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6596	 1	 3.08	 1.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6597	 1	 4.13	 2.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6598	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6599	 1	 7.87	 3.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6600	 1	 11.75	 5.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6601	 1	 6.9	 3.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6602	 1	 4.63	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6603	 1	 12.24	 2.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6604	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6605	 1	 4.14	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6606	 1	 4.31	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6607	 1	 4.83	 2.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6608	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6609	 1	 2.22	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6610	 1	 2.46	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6611	 1	 10.61	 5.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6612	 1	 9.75	 4.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6613	 1	 3.49	 1.94	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6614	 1	 12.07	 6.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6615	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6616	 1	 4.1	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6617	 1	 3.26	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6618	 1	 5.12	 1.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6619	 1	 10.47	 5.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6620	 1	 1.76	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6621	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	6622	 1	 14.91	 6.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6623	 1	 3.4	 1.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6624	 1	 4.0	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6625	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6626	 1	 4.97	 2.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6627	 1	 7.99	 2.86	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6628	 1	 39.4	 19.39	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6629	 1	 2.19	 1.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6630	 1	 8.14	 3.55	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6631	 1	 4.53	 2.18	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6632	 1	 5.68	 2.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6633	 1	 3.17	 1.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6634	 1	 4.82	 2.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6635	 1	 3.86	 1.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6636	 1	 4.67	 2.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6637	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6638	 1	 3.34	 1.83	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6639	 1	 3.48	 1.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6640	 1	 6.69	 3.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6641	 1	 13.68	 6.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6642	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	6643	 1	 2.19	 1.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6644	 1	 3.65	 1.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6645	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6646	 1	 6.2	 3.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6647	 1	 9.96	 4.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6648	 1	 4.43	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6649	 1	 5.69	 2.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6650	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6651	 1	 5.4	 2.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6652	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6653	 1	 4.11	 1.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6654	 1	 2.04	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6655	 1	 3.83	 2.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6656	 1	 2.34	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6657	 1	 3.73	 1.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6658	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6659	 1	 26.79	 13.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6660	 1	 4.75	 1.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6661	 1	 7.53	 3.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6662	 1	 6.92	 2.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6663	 1	 3.56	 1.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6664	 1	 7.38	 1.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6665	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6666	 1	 11.42	 2.77	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6667	 1	 3.88	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6668	 1	 2.26	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6669	 1	 2.94	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6670	 1	 2.37	 1.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6671	 1	 3.27	 1.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6672	 1	 4.76	 2.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6673	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6674	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6675	 1	 4.43	 2.34	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6676	 1	 3.63	 1.73	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6677	 1	 2.39	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6678	 1	 6.77	 3.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6679	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6680	 1	 2.86	 1.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6681	 1	 1.74	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6682	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6683	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6684	 1	 4.6	 2.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6685	 1	 5.53	 2.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6686	 1	 2.06	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6687	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6688	 1	 4.03	 2.21	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6689	 1	 4.33	 2.63	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6690	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	6691	 1	 0.93	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6692	 1	 1.61	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6693	 1	 14.64	 7.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6694	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	6695	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	6696	 1	 2.18	 1.25	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6697	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6698	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	6699	 1	 4.04	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6700	 1	 3.59	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6701	 1	 6.6	 1.54	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6702	 1	 6.01	 1.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6703	 1	 4.92	 1.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6704	 1	 3.83	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6705	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6706	 1	 2.92	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6707	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6708	 1	 2.93	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6709	 1	 3.59	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6710	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6711	 1	 1.78	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6712	 1	 1.41	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6713	 1	 7.67	 1.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6714	 1	 6.68	 1.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6715	 1	 5.1	 2.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6716	 1	 2.16	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6717	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6718	 1	 2.98	 1.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6719	 1	 1.87	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6720	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6721	 1	 4.27	 2.33	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6722	 1	 3.86	 2.2	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6723	 1	 1.94	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6724	 1	 6.54	 3.04	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6725	 1	 2.47	 1.4	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6726	 1	 3.55	 1.59	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6727	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6728	 1	 3.78	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6729	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6730	 1	 8.71	 1.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6731	 1	 9.53	 2.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6732	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6733	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6734	 1	 14.51	 3.39	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6735	 1	 20.23	 4.94	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6736	 1	 1.79	 0.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6737	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6738	 1	 2.1	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6739	 1	 15.11	 3.7	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6740	 1	 2.69	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6741	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6742	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6743	 1	 2.07	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6744	 1	 2.59	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6745	 1	 4.05	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6746	 1	 20.23	 4.96	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6747	 1	 1.21	 0.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6748	 1	 2.77	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6749	 1	 1.41	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6750	 1	 6.46	 1.58	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6751	 1	 2.75	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6752	 1	 1.7	 0.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6753	 1	 0.79	 0.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6754	 1	 5.82	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6755	 1	 1.05	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6756	 1	 23.02	 5.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6757	 1	 1.24	 0.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6758	 1	 1.85	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6759	 1	 0.2	 0.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6760	 1	 1.89	 0.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6761	 1	 2.21	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6762	 1	 1.6	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6763	 1	 2.77	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6764	 1	 4.52	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6765	 1	 5.43	 1.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6766	 1	 4.77	 1.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6767	 1	 12.55	 3.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6768	 1	 3.84	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6769	 1	 0.02	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6770	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6771	 1	 1.55	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6772	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6773	 1	 6.57	 1.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6774	 1	 4.48	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6775	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6776	 1	 5.44	 1.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6777	 1	 5.34	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6778	 1	 5.17	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6779	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6780	 1	 7.32	 1.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6781	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6782	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6783	 1	 2.37	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6784	 1	 2.59	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6785	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6786	 1	 3.58	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6787	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6788	 1	 1.29	 0.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6789	 1	 3.42	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6790	 1	 1.55	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6791	 1	 2.66	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6792	 1	 8.56	 2.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6793	 1	 1.78	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6794	 1	 5.35	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6795	 1	 4.34	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6796	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6797	 1	 4.39	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6798	 1	 1.69	 0.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6799	 1	 3.16	 0.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6800	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6801	 1	 4.71	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6802	 1	 0.4	 0.1	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6803	 1	 4.61	 1.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6804	 1	 3.24	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6805	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6806	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	6807	 1	 1.77	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6808	 1	 2.79	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6809	 1	 1.93	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6810	 1	 4.12	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6811	 1	 1.67	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6812	 1	 1.93	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6813	 1	 2.31	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6814	 1	 3.85	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6815	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6816	 1	 5.01	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6817	 1	 4.31	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6818	 1	 2.83	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6819	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	6820	 1	 2.08	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6821	 1	 1.33	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6822	 1	 1.4	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6823	 1	 1.94	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6824	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6825	 1	 26.9	 6.61	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6826	 1	 3.24	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6827	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6828	 1	 3.76	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6829	 1	 1.65	 0.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6830	 1	 2.94	 0.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6831	 1	 0.98	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6832	 1	 2.8	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6833	 1	 9.48	 2.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6834	 1	 3.1	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6835	 1	 2.71	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6836	 1	 1.69	 0.41	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6837	 1	 2.03	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6838	 1	 2.74	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6839	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6840	 1	 5.04	 1.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6841	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6842	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	6843	 1	 2.39	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6844	 1	 1.26	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6845	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	6846	 1	 4.47	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6847	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6848	 1	 1.38	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6849	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6850	 1	 1.53	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6851	 1	 1.61	 0.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6852	 1	 2.51	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6853	 1	 3.67	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6854	 1	 2.61	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6855	 1	 2.47	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6856	 1	 2.1	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6857	 1	 6.87	 1.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6858	 1	 6.18	 1.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6859	 1	 1.34	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6860	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	6861	 1	 1.86	 0.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6862	 1	 2.44	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6863	 1	 1.51	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6864	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6865	 1	 3.26	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6866	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6867	 1	 2.78	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6868	 1	 1.66	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6869	 1	 2.0	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6870	 1	 1.08	 0.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6871	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6872	 1	 0.61	 0.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6873	 1	 3.3	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6874	 1	 6.41	 1.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6875	 1	 1.47	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6876	 1	 5.59	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6877	 1	 2.96	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6878	 1	 1.45	 0.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6879	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6880	 1	 5.24	 1.28	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6881	 1	 0.91	 0.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6882	 1	 1.94	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6883	 1	 0.69	 0.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6884	 1	 3.32	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6885	 1	 1.11	 0.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6886	 1	 1.07	 0.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6887	 1	 2.08	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6888	 1	 2.69	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6889	 1	 1.85	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6890	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6891	 1	 1.18	 0.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6892	 1	 4.44	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6893	 1	 3.79	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6894	 1	 2.36	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6895	 1	 6.48	 1.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6896	 1	 3.38	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6897	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6898	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6899	 1	 10.06	 2.43	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6900	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6901	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6902	 1	 1.62	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6903	 1	 2.81	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6904	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6905	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6906	 1	 8.49	 2.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6907	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6908	 1	 3.67	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6909	 1	 5.26	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6910	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6911	 1	 2.2	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6912	 1	 0.85	 0.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6913	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6914	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6915	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6916	 1	 4.02	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6917	 1	 11.42	 2.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6918	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	6919	 1	 3.51	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6920	 1	 2.31	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6921	 1	 3.95	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6922	 1	 1.51	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6923	 1	 6.28	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6924	 1	 1.02	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6925	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6926	 1	 1.27	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6927	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6928	 1	 1.39	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6929	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6930	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6931	 1	 2.9	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6932	 1	 2.73	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6933	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6934	 1	 1.04	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6935	 1	 7.85	 1.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6936	 1	 0.98	 0.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6937	 1	 5.87	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6938	 1	 1.25	 0.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6939	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6940	 1	 1.67	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6941	 1	 5.95	 1.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6942	 1	 0.87	 0.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6943	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6944	 1	 1.07	 0.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6945	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6946	 1	 3.93	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6947	 1	 7.46	 1.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6948	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6949	 1	 5.58	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6950	 1	 5.91	 1.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6951	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6952	 1	 5.74	 1.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6953	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6954	 1	 11.07	 2.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6955	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6956	 1	 4.17	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6957	 1	 5.89	 1.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6958	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6959	 1	 6.38	 1.57	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6960	 1	 7.46	 1.83	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6961	 1	 6.41	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6962	 1	 2.39	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6963	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6964	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6965	 1	 5.07	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6966	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6967	 1	 2.96	 0.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6968	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6969	 1	 2.04	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6970	 1	 2.51	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6971	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6972	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6973	 1	 3.71	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6974	 1	 1.91	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6975	 1	 2.98	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6976	 1	 2.21	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6977	 1	 2.16	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6978	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6979	 1	 2.18	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6980	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6981	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6982	 1	 2.53	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6983	 1	 0.9	 0.21	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6984	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6985	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6986	 1	 3.95	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6987	 1	 2.37	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6988	 1	 4.29	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6989	 1	 6.43	 1.56	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6990	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6991	 1	 7.49	 1.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6992	 1	 1.31	 0.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6993	 1	 1.58	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6994	 1	 1.13	 0.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6995	 1	 2.32	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6996	 1	 0.71	 0.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6997	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6998	 1	 0.77	 0.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	6999	 1	 4.01	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7000	 1	 2.4	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7001	 1	 5.06	 1.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7002	 1	 6.62	 1.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7003	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7004	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7005	 1	 2.91	 0.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7006	 1	 3.07	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7007	 1	 2.41	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7008	 1	 1.41	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7009	 1	 2.72	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7010	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7011	 1	 2.26	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7012	 1	 1.1	 0.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7013	 1	 3.42	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7014	 1	 5.24	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7015	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7016	 1	 3.85	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7017	 1	 2.27	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7018	 1	 6.54	 1.58	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7019	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7020	 1	 5.89	 1.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7021	 1	 7.59	 1.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7022	 1	 3.25	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7023	 1	 1.09	 0.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7024	 1	 2.51	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7025	 1	 2.88	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7026	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7027	 1	 0.75	 0.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7028	 1	 2.08	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7029	 1	 4.33	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7030	 1	 2.23	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7031	 1	 7.98	 1.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7032	 1	 1.74	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7033	 1	 5.9	 1.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7034	 1	 3.21	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7035	 1	 0.92	 0.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7036	 1	 2.59	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7037	 1	 4.32	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7038	 1	 4.8	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7039	 1	 4.55	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7040	 1	 5.42	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7041	 1	 3.95	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7042	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7043	 1	 3.91	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7044	 1	 2.25	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7045	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7046	 1	 0.74	 0.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7047	 1	 7.38	 1.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7048	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7049	 1	 3.81	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7050	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7051	 1	 1.62	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7052	 1	 4.88	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7053	 1	 3.2	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7054	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7055	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7056	 1	 4.67	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7057	 1	 1.2	 0.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7058	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7059	 1	 0.76	 0.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7060	 1	 1.7	 0.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7061	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7062	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7063	 1	 6.23	 1.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7064	 1	 0.99	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7065	 1	 0.76	 0.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7066	 1	 1.03	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7067	 1	 0.93	 0.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7068	 1	 0.87	 0.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7069	 1	 2.13	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7070	 1	 2.03	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7071	 1	 1.07	 0.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7072	 1	 1.18	 0.28	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7073	 1	 1.87	 0.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7074	 1	 1.93	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7075	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7076	 1	 1.05	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7077	 1	 1.9	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7078	 1	 1.08	 0.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7079	 1	 1.45	 0.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7080	 1	 2.71	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7081	 1	 0.86	 0.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7082	 1	 2.78	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7083	 1	 1.53	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7084	 1	 1.01	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7085	 1	 2.81	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7086	 1	 1.52	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7087	 1	 3.55	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7088	 1	 0.94	 0.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7089	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7090	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7091	 1	 0.89	 0.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7092	 1	 0.99	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7093	 1	 5.62	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7094	 1	 3.37	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7095	 1	 6.05	 1.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7096	 1	 2.09	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7097	 1	 2.81	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7098	 1	 1.3	 0.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7099	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7100	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7101	 1	 3.92	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7102	 1	 1.78	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7103	 1	 1.29	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7104	 1	 1.47	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7105	 1	 1.21	 0.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7106	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7107	 1	 0.97	 0.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7108	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7109	 1	 1.32	 0.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7110	 1	 0.04	 0.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7111	 1	 0.85	 0.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7112	 1	 4.0	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7113	 1	 0.88	 0.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7114	 1	 0.84	 0.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7115	 1	 2.77	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7116	 1	 8.76	 2.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7117	 1	 2.04	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7118	 1	 0.9	 0.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7119	 1	 2.25	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7120	 1	 2.3	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7121	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7122	 1	 3.43	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7123	 1	 4.08	 0.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7124	 1	 3.85	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7125	 1	 2.56	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7126	 1	 0.8	 0.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7127	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7128	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7129	 1	 4.78	 1.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7130	 1	 0.86	 0.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7131	 1	 4.04	 0.98	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7132	 1	 0.93	 0.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7133	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7134	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7135	 1	 2.39	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7136	 1	 1.79	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7137	 1	 0.96	 0.23	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7138	 1	 0.78	 0.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7139	 1	 0.82	 0.19	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7140	 1	 0.79	 0.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7141	 1	 0.71	 0.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7142	 1	 0.9	 0.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7143	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7144	 1	 2.01	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7145	 1	 1.49	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7146	 1	 1.23	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7147	 1	 1.05	 0.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7148	 1	 0.89	 0.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7149	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7150	 1	 0.81	 0.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7151	 1	 2.34	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7152	 1	 2.71	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7153	 1	 2.81	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7154	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7155	 1	 1.78	 0.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7156	 1	 2.07	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7157	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7158	 1	 2.16	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7159	 1	 2.49	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7160	 1	 4.0	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7161	 1	 0.99	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7162	 1	 1.43	 0.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7163	 1	 1.41	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7164	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7165	 1	 2.12	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7166	 1	 3.14	 0.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7167	 1	 1.7	 0.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7168	 1	 2.04	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7169	 1	 3.51	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7170	 1	 1.79	 0.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7171	 1	 1.49	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7172	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7173	 1	 1.0	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7174	 1	 3.73	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7175	 1	 0.94	 0.23	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7176	 1	 2.86	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7177	 1	 0.94	 0.22	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7178	 1	 2.02	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7179	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7180	 1	 2.66	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7181	 1	 10.41	 2.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7182	 1	 1.84	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7183	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7184	 1	 1.36	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7185	 1	 2.78	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7186	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7187	 1	 2.7	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7188	 1	 3.45	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7189	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7190	 1	 8.37	 2.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7191	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7192	 1	 4.83	 1.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7193	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7194	 1	 2.06	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7195	 1	 2.8	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7196	 1	 3.03	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7197	 1	 4.2	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7198	 1	 1.13	 0.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7199	 1	 2.89	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7200	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7201	 1	 4.36	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7202	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7203	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7204	 1	 10.34	 2.5	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7205	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7206	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7207	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7208	 1	 9.81	 2.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7209	 1	 4.28	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7210	 1	 5.99	 1.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7211	 1	 2.6	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7212	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7213	 1	 0.85	 0.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7214	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7215	 1	 7.63	 1.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7216	 1	 3.7	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7217	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7218	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7219	 1	 1.9	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7220	 1	 2.62	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7221	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7222	 1	 5.52	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7223	 1	 8.48	 2.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7224	 1	 2.37	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7225	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7226	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7227	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7228	 1	 4.27	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7229	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7230	 1	 1.58	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7231	 1	 3.04	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7232	 1	 3.4	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7233	 1	 2.71	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7234	 1	 1.42	 0.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7235	 1	 1.43	 0.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7236	 1	 1.28	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7237	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7238	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7239	 1	 3.33	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7240	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	7241	 1	 4.86	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7242	 1	 2.97	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7243	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7244	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7245	 1	 1.95	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7246	 1	 5.23	 1.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7247	 1	 2.79	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7248	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7249	 1	 5.59	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7250	 1	 1.53	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7251	 1	 2.39	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7252	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7253	 1	 8.04	 1.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7254	 1	 10.74	 2.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7255	 1	 9.35	 2.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7256	 1	 11.1	 2.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7257	 1	 4.33	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7258	 1	 7.29	 1.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7259	 1	 2.28	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7260	 1	 4.94	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7261	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7262	 1	 4.39	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7263	 1	 8.73	 2.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7264	 1	 14.29	 3.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7265	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7266	 1	 14.02	 3.4	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7267	 1	 2.69	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7268	 1	 0.41	 0.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7269	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7270	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7271	 1	 4.05	 0.98	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7272	 1	 2.83	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7273	 1	 10.42	 2.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7274	 1	 4.53	 1.09	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7275	 1	 5.06	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7276	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7277	 1	 3.07	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7278	 1	 3.3	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7279	 1	 6.24	 1.51	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7280	 1	 11.42	 2.77	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7281	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7282	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7283	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7284	 1	 4.27	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7285	 1	 1.77	 0.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7286	 1	 5.06	 1.23	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7287	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7288	 1	 1.13	 0.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7289	 1	 5.3	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7290	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7291	 1	 4.66	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7292	 1	 3.74	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7293	 1	 6.3	 1.51	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7294	 1	 5.19	 1.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7295	 1	 5.66	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7296	 1	 3.08	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7297	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7298	 1	 5.37	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7299	 1	 4.6	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7300	 1	 1.71	 0.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7301	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7302	 1	 9.99	 2.45	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7303	 1	 4.93	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7304	 1	 5.6	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7305	 1	 3.87	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7306	 1	 8.03	 1.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7307	 1	 10.49	 2.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7308	 1	 2.31	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7309	 1	 3.86	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7310	 1	 9.91	 2.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7311	 1	 2.4	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7312	 1	 1.97	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7313	 1	 7.87	 1.88	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7314	 1	 5.91	 1.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7315	 1	 6.86	 1.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7316	 1	 4.84	 1.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7317	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7318	 1	 3.98	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7319	 1	 1.26	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7320	 1	 1.87	 0.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7321	 1	 3.67	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7322	 1	 4.15	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7323	 1	 0.94	 0.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7324	 1	 0.63	 0.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7325	 1	 2.79	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7326	 1	 3.1	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7327	 1	 3.44	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7328	 1	 7.58	 1.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7329	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7330	 1	 3.76	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7331	 1	 4.34	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7332	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7333	 1	 1.69	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7334	 1	 1.19	 0.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7335	 1	 1.42	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7336	 1	 3.79	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7337	 1	 2.04	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7338	 1	 1.47	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7339	 1	 0.76	 0.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7340	 1	 0.85	 0.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7341	 1	 0.94	 0.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7342	 1	 0.92	 0.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7343	 1	 2.7	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7344	 1	 2.57	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7345	 1	 5.71	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7346	 1	 3.59	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7347	 1	 11.73	 2.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7348	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7349	 1	 2.59	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7350	 1	 2.0	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7351	 1	 3.0	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7352	 1	 1.73	 0.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7353	 1	 9.08	 2.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7354	 1	 14.25	 3.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7355	 1	 1.24	 0.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7356	 1	 2.28	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7357	 1	 12.41	 2.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7358	 1	 5.11	 1.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7359	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7360	 1	 3.13	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7361	 1	 2.33	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7362	 1	 8.23	 1.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7363	 1	 13.38	 3.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7364	 1	 4.9	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7365	 1	 7.11	 1.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7366	 1	 5.07	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7367	 1	 0.04	 0.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7368	 1	 1.98	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7369	 1	 1.29	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7370	 1	 0.71	 0.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7371	 1	 1.46	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7372	 1	 4.52	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7373	 1	 2.04	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7374	 1	 2.84	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7375	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7376	 1	 4.85	 1.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7377	 1	 0.77	 0.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7378	 1	 3.59	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7379	 1	 3.96	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7380	 1	 3.89	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7381	 1	 4.34	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7382	 1	 5.88	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7383	 1	 7.39	 1.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7384	 1	 3.81	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7385	 1	 1.85	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7386	 1	 3.79	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7387	 1	 10.8	 2.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7388	 1	 6.28	 1.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7389	 1	 5.02	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7390	 1	 17.61	 4.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7391	 1	 2.01	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7392	 1	 7.46	 1.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7393	 1	 1.12	 0.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7394	 1	 2.9	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7395	 1	 4.16	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7396	 1	 3.42	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7397	 1	 4.42	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7398	 1	 5.48	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7399	 1	 3.58	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7400	 1	 5.61	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7401	 1	 3.63	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7402	 1	 1.43	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7403	 1	 3.46	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7404	 1	 6.03	 1.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7405	 1	 5.22	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7406	 1	 1.42	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7407	 1	 1.63	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7408	 1	 4.64	 1.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7409	 1	 10.06	 2.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7410	 1	 4.18	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7411	 1	 5.97	 1.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7412	 1	 2.39	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7413	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	7414	 1	 5.2	 2.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7415	 1	 4.88	 2.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7416	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7417	 1	 3.48	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7418	 1	 4.01	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7419	 1	 2.54	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7420	 1	 2.0	 0.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7421	 1	 5.99	 1.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7422	 1	 4.23	 0.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7423	 1	 1.4	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7424	 1	 5.83	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7425	 1	 3.3	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7426	 1	 5.34	 1.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7427	 1	 4.08	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7428	 1	 1.48	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7429	 1	 6.28	 1.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7430	 1	 0.69	 0.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7431	 1	 5.78	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7432	 1	 1.56	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7433	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7434	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7435	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7436	 1	 8.38	 4.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7437	 1	 8.13	 4.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7438	 1	 4.61	 1.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7439	 1	 1.84	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7440	 1	 2.23	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7441	 1	 8.89	 2.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7442	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7443	 1	 6.56	 3.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7444	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7445	 1	 2.99	 1.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7446	 1	 3.64	 1.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7447	 1	 1.0	 0.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7448	 1	 0.41	 0.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7449	 1	 2.41	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7450	 1	 3.43	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7451	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7452	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7453	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7454	 1	 5.51	 2.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7455	 1	 1.41	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7456	 1	 2.63	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7457	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7458	 1	 4.17	 1.87	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7459	 1	 6.16	 3.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7460	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7461	 1	 9.2	 4.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7462	 1	 1.75	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7463	 1	 9.19	 4.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7464	 1	 4.44	 2.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7465	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7466	 1	 0.86	 0.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7467	 1	 5.42	 2.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7468	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7469	 1	 3.55	 1.84	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7470	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7471	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7472	 1	 8.64	 4.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7473	 1	 6.61	 3.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7474	 1	 5.33	 2.73	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7475	 1	 7.74	 4.55	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7476	 1	 2.92	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7477	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7478	 1	 1.65	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7479	 1	 8.6	 3.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7480	 1	 1.78	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7481	 1	 6.55	 3.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7482	 1	 0.88	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7483	 1	 4.05	 2.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7484	 1	 5.72	 2.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7485	 1	 2.92	 1.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7486	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7487	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7488	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7489	 1	 3.71	 1.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7490	 1	 10.41	 4.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7491	 1	 4.16	 2.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7492	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7493	 1	 2.96	 1.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7494	 1	 3.17	 1.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7495	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7496	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7497	 1	 5.76	 2.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7498	 1	 2.47	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7499	 1	 4.4	 1.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7500	 1	 3.07	 1.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7501	 1	 10.14	 5.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7502	 1	 4.79	 2.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7503	 1	 4.15	 2.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7504	 1	 2.42	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7505	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7506	 1	 4.16	 2.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7507	 1	 4.61	 2.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7508	 1	 2.62	 1.23	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7509	 1	 2.71	 1.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7510	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7511	 1	 4.67	 2.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7512	 1	 2.82	 1.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7513	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7514	 1	 9.6	 5.15	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7515	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7516	 1	 1.05	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7517	 1	 16.95	 8.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7518	 1	 4.81	 2.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7519	 1	 22.44	 10.09	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7520	 1	 9.25	 4.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7521	 1	 4.63	 2.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7522	 1	 2.99	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7523	 1	 5.82	 3.27	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7524	 1	 6.03	 2.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7525	 1	 48.55	 22.01	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7526	 1	 7.66	 3.41	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7527	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7528	 1	 5.83	 3.26	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7529	 1	 4.07	 2.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7530	 1	 2.39	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7531	 1	 3.72	 2.14	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7532	 1	 11.48	 6.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7533	 1	 4.61	 2.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7534	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7535	 1	 4.06	 2.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7536	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7537	 1	 2.31	 1.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7538	 1	 3.81	 2.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7539	 1	 4.66	 2.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7540	 1	 3.2	 1.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7541	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	7542	 1	 8.07	 4.34	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7543	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7544	 1	 3.37	 1.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7545	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7546	 1	 4.04	 2.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7547	 1	 8.28	 4.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7548	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7549	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	7550	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	7551	 1	 7.98	 4.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7552	 1	 4.46	 2.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7553	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7554	 1	 3.35	 1.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7555	 1	 3.19	 1.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7556	 1	 11.51	 6.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7557	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7558	 1	 6.88	 4.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7559	 1	 6.34	 3.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7560	 1	 4.67	 2.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7561	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7562	 1	 7.34	 3.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7563	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7564	 1	 5.07	 2.31	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7565	 1	 11.08	 5.63	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7566	 1	 1.16	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7567	 1	 8.83	 4.73	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7568	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	7569	 1	 13.99	 6.55	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7570	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7571	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7572	 1	 17.89	 9.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7573	 1	 2.32	 1.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7574	 1	 8.34	 3.96	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7575	 1	 2.45	 1.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7576	 1	 2.21	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7577	 1	 7.9	 4.51	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7578	 1	 7.09	 3.64	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7579	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7580	 1	 1.84	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7581	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7582	 1	 4.03	 2.04	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7583	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7584	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7585	 1	 3.49	 1.78	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7586	 1	 0.97	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7587	 1	 2.15	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7588	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7589	 1	 2.11	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7590	 1	 3.1	 1.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7591	 1	 4.2	 2.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7592	 1	 4.39	 1.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7593	 1	 2.84	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7594	 1	 9.59	 4.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7595	 1	 5.57	 2.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7596	 1	 1.86	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7597	 1	 1.96	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7598	 1	 8.25	 3.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7599	 1	 5.6	 3.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7600	 1	 4.19	 2.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7601	 1	 7.3	 3.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7602	 1	 10.33	 4.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7603	 1	 19.92	 7.36	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7604	 1	 5.36	 2.54	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7605	 1	 14.45	 6.82	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7606	 1	 28.7	 12.46	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7607	 1	 23.42	 12.12	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7608	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	7609	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	7610	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	7611	 1	 3.27	 1.68	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	7612	 1	 8.8	 4.4	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7613	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	7614	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7615	 1	 5.27	 2.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7616	 1	 33.88	 14.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7617	 1	 1.77	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7618	 1	 3.05	 1.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7619	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7620	 1	 3.99	 2.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7621	 1	 4.02	 1.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7622	 1	 4.15	 2.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7623	 1	 10.16	 3.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7624	 1	 6.81	 3.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7625	 1	 5.22	 2.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7626	 1	 3.51	 2.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7627	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7628	 1	 6.49	 3.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7629	 1	 2.54	 1.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7630	 1	 9.25	 2.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7631	 1	 9.42	 2.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7632	 1	 3.82	 1.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7633	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7634	 1	 2.38	 1.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7635	 1	 4.47	 2.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7636	 1	 6.53	 2.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7637	 1	 5.07	 1.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7638	 1	 5.54	 3.31	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7639	 1	 15.81	 3.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7640	 1	 1.68	 0.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7641	 1	 2.16	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7642	 1	 12.29	 6.95	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7643	 1	 8.62	 3.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7644	 1	 14.56	 6.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7645	 1	 2.69	 1.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7646	 1	 5.86	 2.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7647	 1	 1.35	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7648	 1	 1.37	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7649	 1	 2.98	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7650	 1	 1.73	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7651	 1	 7.05	 3.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7652	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7653	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7654	 1	 5.23	 2.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7655	 1	 2.59	 1.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7656	 1	 3.1	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7657	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7658	 1	 7.52	 3.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7659	 1	 11.54	 6.32	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7660	 1	 3.19	 1.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7661	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7662	 1	 1.07	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7663	 1	 14.28	 7.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7664	 1	 3.93	 2.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7665	 1	 2.34	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7666	 1	 2.19	 1.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7667	 1	 2.78	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7668	 1	 4.27	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7669	 1	 4.6	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7670	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7671	 1	 5.5	 2.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7672	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7673	 1	 7.55	 3.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7674	 1	 1.14	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7675	 1	 3.52	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7676	 1	 1.6	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7677	 1	 6.66	 1.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7678	 1	 6.58	 1.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7679	 1	 11.44	 2.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7680	 1	 2.96	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7681	 1	 3.46	 1.77	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7682	 1	 3.4	 1.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7683	 1	 6.62	 1.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7684	 1	 7.22	 1.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7685	 1	 2.99	 1.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7686	 1	 7.62	 1.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7687	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7688	 1	 1.39	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7689	 1	 4.18	 1.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7690	 1	 53.22	 12.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7691	 1	 1.52	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7692	 1	 2.09	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7693	 1	 1.79	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7694	 1	 7.94	 1.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7695	 1	 4.01	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7696	 1	 2.76	 1.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7697	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7698	 1	 4.3	 1.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7699	 1	 3.28	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7700	 1	 3.09	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7701	 1	 3.37	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7702	 1	 2.07	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7703	 1	 2.52	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7704	 1	 2.69	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7705	 1	 5.81	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7706	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7707	 1	 5.8	 2.43	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7708	 1	 9.41	 2.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7709	 1	 8.58	 2.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7710	 1	 6.8	 3.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7711	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	7712	 1	 1.28	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7713	 1	 6.78	 1.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7714	 1	 2.57	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7715	 1	 10.11	 2.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7716	 1	 7.79	 1.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7717	 1	 6.24	 1.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7718	 1	 2.94	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7719	 1	 5.07	 1.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7720	 1	 1.66	 0.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7721	 1	 4.77	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7722	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7723	 1	 4.28	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7724	 1	 2.81	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7725	 1	 3.79	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7726	 1	 1.29	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7727	 1	 3.43	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7728	 1	 4.81	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7729	 1	 1.39	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7730	 1	 5.42	 1.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7731	 1	 1.93	 0.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7732	 1	 2.24	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7733	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7734	 1	 7.69	 1.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7735	 1	 6.36	 1.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7736	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7737	 1	 1.11	 0.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7738	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7739	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7740	 1	 4.42	 2.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7741	 1	 8.96	 2.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7742	 1	 1.89	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7743	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7744	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7745	 1	 2.0	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7746	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7747	 1	 7.1	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7748	 1	 1.58	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7749	 1	 6.44	 1.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7750	 1	 3.59	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7751	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7752	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7753	 1	 5.64	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7754	 1	 3.89	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7755	 1	 18.72	 4.66	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7756	 1	 6.37	 3.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7757	 1	 1.53	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7758	 1	 0.72	 0.18	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7759	 1	 2.69	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7760	 1	 2.59	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7761	 1	 12.13	 3.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7762	 1	 2.2	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7763	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7764	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7765	 1	 4.71	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7766	 1	 3.09	 0.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7767	 1	 6.36	 1.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7768	 1	 25.76	 6.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7769	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7770	 1	 5.1	 1.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7771	 1	 4.52	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7772	 1	 1.27	 0.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7773	 1	 1.36	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7774	 1	 8.58	 2.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7775	 1	 2.72	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7776	 1	 3.16	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7777	 1	 3.49	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7778	 1	 9.57	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7779	 1	 2.52	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7780	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7781	 1	 2.37	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7782	 1	 2.94	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7783	 1	 4.43	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7784	 1	 8.19	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7785	 1	 16.06	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7786	 1	 2.19	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7787	 1	 2.93	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7788	 1	 2.46	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7789	 1	 6.65	 3.77	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7790	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7791	 1	 13.35	 7.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7792	 1	 1.71	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7793	 1	 1.99	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7794	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7795	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7796	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	7797	 1	 1.17	 0.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7798	 1	 11.76	 5.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7799	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7800	 1	 3.57	 1.78	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7801	 1	 1.37	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7802	 1	 11.73	 6.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7803	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7804	 1	 4.19	 1.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7805	 1	 6.64	 3.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7806	 1	 9.01	 4.71	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7807	 1	 1.2	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7808	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7809	 1	 2.63	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7810	 1	 0.98	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7811	 1	 4.82	 2.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7812	 1	 5.99	 2.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7813	 1	 3.62	 1.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7814	 1	 1.83	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7815	 1	 6.19	 3.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7816	 1	 13.29	 6.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7817	 1	 2.23	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7818	 1	 13.26	 7.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7819	 1	 2.65	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7820	 1	 1.53	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7821	 1	 3.35	 1.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7822	 1	 8.55	 4.01	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7823	 1	 6.91	 3.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7824	 1	 6.85	 2.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7825	 1	 2.23	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7826	 1	 15.33	 7.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7827	 1	 6.38	 2.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7828	 1	 9.49	 4.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7829	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	7830	 1	 7.16	 3.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7831	 1	 2.92	 1.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7832	 1	 4.35	 2.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7833	 1	 3.08	 1.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7834	 1	 6.54	 3.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7835	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7836	 1	 55.01	 27.34	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7837	 1	 3.68	 1.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7838	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7839	 1	 6.01	 3.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7840	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7841	 1	 6.71	 2.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7842	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7843	 1	 2.61	 1.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7844	 1	 6.99	 3.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7845	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7846	 1	 4.63	 2.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7847	 1	 4.76	 2.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7848	 1	 3.53	 1.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7849	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7850	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7851	 1	 4.89	 2.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7852	 1	 4.1	 2.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7853	 1	 5.14	 2.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7854	 1	 8.83	 4.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7855	 1	 2.64	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7856	 1	 3.44	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7857	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7858	 1	 10.39	 4.43	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7859	 1	 5.77	 1.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7860	 1	 2.11	 0.52	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7861	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7862	 1	 10.74	 6.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7863	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7864	 1	 2.72	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7865	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7866	 1	 9.34	 2.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7867	 1	 4.14	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7868	 1	 2.04	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7869	 1	 5.72	 1.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7870	 1	 2.55	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7871	 1	 3.64	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7872	 1	 3.55	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7873	 1	 5.64	 1.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7874	 1	 5.32	 1.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7875	 1	 12.83	 3.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7876	 1	 4.45	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7877	 1	 6.34	 1.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7878	 1	 3.0	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7879	 1	 2.0	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7880	 1	 6.3	 1.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7881	 1	 7.34	 3.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7882	 1	 5.22	 2.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7883	 1	 3.7	 1.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7884	 1	 4.47	 2.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7885	 1	 1.14	 0.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7886	 1	 15.81	 7.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7887	 1	 9.32	 4.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7888	 1	 3.53	 1.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7889	 1	 9.16	 4.45	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7890	 1	 9.64	 4.87	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7891	 1	 2.01	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7892	 1	 4.07	 1.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7893	 1	 2.62	 1.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7894	 1	 5.49	 2.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7895	 1	 4.13	 2.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7896	 1	 3.75	 1.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7897	 1	 5.78	 2.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7898	 1	 4.91	 2.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7899	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7900	 1	 2.33	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7901	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	7902	 1	 5.69	 2.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7903	 1	 9.09	 3.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7904	 1	 3.37	 1.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7905	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7906	 1	 4.12	 2.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7907	 1	 6.64	 3.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7908	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7909	 1	 11.96	 4.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7910	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7911	 1	 2.88	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7912	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	7913	 1	 3.73	 2.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7914	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7915	 1	 7.71	 3.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7916	 1	 15.37	 7.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7917	 1	 15.18	 6.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7918	 1	 3.86	 1.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7919	 1	 2.49	 1.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7920	 1	 3.81	 1.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7921	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7922	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7923	 1	 7.33	 3.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7924	 1	 4.96	 2.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7925	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7926	 1	 7.63	 1.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7927	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7928	 1	 2.32	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7929	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7930	 1	 3.58	 1.75	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7931	 1	 4.87	 2.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7932	 1	 3.14	 1.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7933	 1	 7.32	 3.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7934	 1	 4.39	 2.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7935	 1	 1.54	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7936	 1	 1.35	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7937	 1	 4.55	 1.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7938	 1	 6.77	 3.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7939	 1	 3.19	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7940	 1	 4.53	 2.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7941	 1	 4.03	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7942	 1	 10.1	 4.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7943	 1	 20.1	 8.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7944	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7945	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7946	 1	 6.56	 2.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7947	 1	 3.01	 1.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7948	 1	 4.48	 1.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7949	 1	 5.9	 3.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7950	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7951	 1	 5.67	 3.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7952	 1	 4.72	 2.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7953	 1	 1.13	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7954	 1	 3.55	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7955	 1	 1.91	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7956	 1	 4.38	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7957	 1	 11.1	 2.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7958	 1	 7.82	 1.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7959	 1	 2.48	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7960	 1	 5.45	 1.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7961	 1	 0.98	 0.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7962	 1	 6.75	 1.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7963	 1	 11.81	 2.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7964	 1	 8.02	 1.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7965	 1	 10.29	 2.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7966	 1	 4.67	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7967	 1	 8.22	 1.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7968	 1	 8.32	 1.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7969	 1	 1.01	 0.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7970	 1	 2.27	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7971	 1	 9.62	 5.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7972	 1	 6.6	 3.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7973	 1	 6.22	 2.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7974	 1	 6.6	 3.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7975	 1	 2.92	 1.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7976	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7977	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7978	 1	 2.46	 1.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7979	 1	 6.08	 3.43	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7980	 1	 7.55	 3.45	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7981	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7982	 1	 11.51	 5.32	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7983	 1	 1.54	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7984	 1	 2.09	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7985	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7986	 1	 4.97	 2.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7987	 1	 4.93	 2.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7988	 1	 5.33	 3.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7989	 1	 3.54	 2.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7990	 1	 2.05	 1.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7991	 1	 3.68	 2.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7992	 1	 3.25	 1.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7993	 1	 8.39	 4.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7994	 1	 2.25	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7995	 1	 3.59	 2.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7996	 1	 1.31	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7997	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7998	 1	 0.9	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	7999	 1	 1.9	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8000	 1	 11.04	 6.26	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8001	 1	 3.68	 2.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8002	 1	 5.9	 3.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8003	 1	 4.76	 2.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8004	 1	 11.02	 5.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8005	 1	 3.69	 1.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8006	 1	 3.09	 1.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8007	 1	 2.8	 1.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8008	 1	 3.27	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8009	 1	 4.14	 2.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8010	 1	 2.3	 1.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8011	 1	 5.71	 2.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8012	 1	 5.88	 3.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8013	 1	 1.24	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8014	 1	 9.15	 5.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8015	 1	 2.94	 1.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8016	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8017	 1	 2.82	 1.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8018	 1	 4.61	 2.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8019	 1	 3.35	 1.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8020	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8021	 1	 2.24	 1.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8022	 1	 1.97	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8023	 1	 10.89	 4.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8024	 1	 5.07	 2.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8025	 1	 1.47	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8026	 1	 7.47	 3.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8027	 1	 6.28	 2.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8028	 1	 5.38	 2.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8029	 1	 4.71	 2.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8030	 1	 5.05	 2.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8031	 1	 2.25	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8032	 1	 9.78	 5.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8033	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8034	 1	 5.99	 2.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8035	 1	 6.84	 3.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8036	 1	 4.69	 2.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8037	 1	 7.54	 3.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8038	 1	 10.73	 4.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8039	 1	 2.87	 1.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8040	 1	 3.34	 1.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8041	 1	 7.56	 4.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8042	 1	 1.39	 0.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8043	 1	 54.89	 27.48	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8044	 1	 4.77	 2.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8045	 1	 11.6	 5.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8046	 1	 3.48	 1.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8047	 1	 7.24	 4.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8048	 1	 8.99	 4.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8049	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8050	 1	 3.78	 1.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8051	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8052	 1	 7.6	 4.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8053	 1	 6.83	 4.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8054	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8055	 1	 4.08	 2.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8056	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8057	 1	 3.79	 1.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8058	 1	 3.5	 1.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8059	 1	 2.37	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8060	 1	 2.57	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8061	 1	 5.09	 2.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8062	 1	 5.12	 2.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8063	 1	 7.52	 3.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8064	 1	 5.73	 2.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8065	 1	 7.6	 3.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8066	 1	 2.7	 1.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8067	 1	 4.46	 2.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8068	 1	 4.9	 2.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8069	 1	 13.35	 6.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8070	 1	 4.6	 2.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8071	 1	 2.17	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8072	 1	 0.05	 0.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8073	 1	 3.78	 2.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8074	 1	 1.3	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8075	 1	 7.87	 3.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8076	 1	 4.59	 2.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8077	 1	 8.94	 5.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8078	 1	 1.12	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8079	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8080	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8081	 1	 10.04	 5.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8082	 1	 15.54	 8.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8083	 1	 12.74	 5.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8084	 1	 6.27	 2.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8085	 1	 6.7	 3.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8086	 1	 4.16	 1.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8087	 1	 19.67	 10.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8088	 1	 2.34	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8089	 1	 6.74	 3.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8090	 1	 6.89	 2.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8091	 1	 3.48	 1.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8092	 1	 7.98	 4.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8093	 1	 3.49	 2.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8094	 1	 1.84	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8095	 1	 3.69	 1.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8096	 1	 5.37	 2.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8097	 1	 3.47	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8098	 1	 5.74	 3.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8099	 1	 4.17	 2.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8100	 1	 4.1	 1.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8101	 1	 2.83	 1.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8102	 1	 1.65	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8103	 1	 14.95	 8.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8104	 1	 6.21	 2.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8105	 1	 5.18	 2.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8106	 1	 4.71	 2.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8107	 1	 7.03	 3.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8108	 1	 4.27	 1.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8109	 1	 14.5	 6.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8110	 1	 2.8	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8111	 1	 4.32	 2.54	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8112	 1	 1.56	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8113	 1	 2.92	 1.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8114	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8115	 1	 1.02	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8116	 1	 5.66	 3.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8117	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8118	 1	 2.21	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8119	 1	 1.72	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8120	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8121	 1	 5.31	 2.59	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8122	 1	 3.73	 2.06	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8123	 1	 1.8	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8124	 1	 4.23	 1.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8125	 1	 4.56	 2.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8126	 1	 18.07	 9.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8127	 1	 2.64	 1.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8128	 1	 2.05	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8129	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8130	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8131	 1	 1.45	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8132	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8133	 1	 1.39	 0.64	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8134	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8135	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8136	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8137	 1	 5.16	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8138	 1	 2.21	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8139	 1	 5.94	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8140	 1	 8.94	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8141	 1	 2.37	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8142	 1	 7.82	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8143	 1	 7.42	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8144	 1	 3.63	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8145	 1	 3.13	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8146	 1	 10.94	 2.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8147	 1	 2.74	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8148	 1	 4.51	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8149	 1	 4.09	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8150	 1	 4.89	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8151	 1	 4.53	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8152	 1	 2.64	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8153	 1	 8.55	 2.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8154	 1	 8.66	 2.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8155	 1	 3.1	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8156	 1	 4.09	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8157	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8158	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8159	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8160	 1	 3.49	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8161	 1	 4.03	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8162	 1	 4.18	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8163	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8164	 1	 2.91	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8165	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8166	 1	 3.76	 2.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8167	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8168	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8169	 1	 3.23	 1.88	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8170	 1	 3.66	 1.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8171	 1	 6.91	 2.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8172	 1	 2.72	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8173	 1	 1.35	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8174	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8175	 1	 1.44	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8176	 1	 2.8	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8177	 1	 3.39	 1.67	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8178	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8179	 1	 5.58	 1.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8180	 1	 1.39	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8181	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8182	 1	 1.58	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8183	 1	 3.85	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8184	 1	 1.66	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8185	 1	 3.35	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8186	 1	 3.4	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8187	 1	 1.74	 0.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8188	 1	 6.2	 1.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8189	 1	 3.92	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8190	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8191	 1	 2.62	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8192	 1	 4.39	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8193	 1	 5.39	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8194	 1	 1.24	 0.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8195	 1	 3.08	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8196	 1	 4.68	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8197	 1	 14.12	 3.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8198	 1	 7.14	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8199	 1	 7.83	 1.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8200	 1	 11.83	 5.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8201	 1	 3.53	 1.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8202	 1	 4.42	 2.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8203	 1	 3.46	 1.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8204	 1	 5.01	 2.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8205	 1	 7.27	 1.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8206	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8207	 1	 0.97	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8208	 1	 1.15	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8209	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8210	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8211	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8212	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8213	 1	 9.1	 3.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8214	 1	 8.71	 4.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8215	 1	 1.31	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8216	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8217	 1	 6.14	 3.13	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8218	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8219	 1	 23.03	 10.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8220	 1	 0.83	 0.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8221	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8222	 1	 4.49	 2.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8223	 1	 7.97	 4.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8224	 1	 2.75	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8225	 1	 2.88	 1.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8226	 1	 3.98	 2.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8227	 1	 7.11	 3.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8228	 1	 3.89	 1.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8229	 1	 2.35	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8230	 1	 6.1	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8231	 1	 1.37	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8232	 1	 2.71	 1.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8233	 1	 18.76	 9.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8234	 1	 2.91	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8235	 1	 15.98	 8.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8236	 1	 7.48	 3.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8237	 1	 8.58	 2.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8238	 1	 0.71	 0.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8239	 1	 16.23	 3.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8240	 1	 3.93	 1.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8241	 1	 1.04	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8242	 1	 5.69	 2.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8243	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8244	 1	 8.95	 4.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8245	 1	 3.62	 1.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8246	 1	 1.41	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8247	 1	 3.98	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8248	 1	 4.34	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8249	 1	 5.79	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8250	 1	 4.71	 2.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8251	 1	 4.6	 2.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8252	 1	 4.16	 2.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8253	 1	 2.66	 1.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8254	 1	 9.03	 2.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8255	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8256	 1	 4.25	 2.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8257	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8258	 1	 7.8	 3.28	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8259	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8260	 1	 3.09	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8261	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8262	 1	 9.79	 4.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8263	 1	 10.13	 2.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8264	 1	 8.98	 2.15	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8265	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8266	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8267	 1	 1.57	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8268	 1	 6.9	 3.32	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8269	 1	 4.71	 2.59	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8270	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8271	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8272	 1	 6.38	 1.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8273	 1	 4.46	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8274	 1	 3.1	 0.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8275	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8276	 1	 7.55	 1.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8277	 1	 4.27	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8278	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8279	 1	 12.91	 3.16	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8280	 1	 16.46	 4.02	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8281	 1	 6.4	 1.57	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8282	 1	 7.38	 1.81	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8283	 1	 1.95	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8284	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8285	 1	 10.39	 2.55	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8286	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8287	 1	 5.01	 1.22	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8288	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8289	 1	 2.82	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8290	 1	 2.19	 0.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8291	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8292	 1	 5.56	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8293	 1	 3.09	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8294	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8295	 1	 5.23	 1.28	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8296	 1	 4.85	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8297	 1	 1.53	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8298	 1	 4.34	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8299	 1	 5.22	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8300	 1	 2.8	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8301	 1	 6.01	 1.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8302	 1	 4.2	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8303	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8304	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8305	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8306	 1	 0.91	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8307	 1	 3.62	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8308	 1	 3.29	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8309	 1	 1.97	 0.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8310	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8311	 1	 2.97	 0.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8312	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8313	 1	 1.17	 0.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8314	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8315	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8316	 1	 1.7	 0.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8317	 1	 5.57	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8318	 1	 7.58	 1.85	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8319	 1	 2.75	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8320	 1	 6.69	 1.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8321	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8322	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8323	 1	 4.26	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8324	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8325	 1	 2.74	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8326	 1	 1.45	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8327	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8328	 1	 4.44	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8329	 1	 1.68	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8330	 1	 1.8	 0.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8331	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8332	 1	 2.94	 0.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8333	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8334	 1	 6.7	 1.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8335	 1	 2.68	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8336	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8337	 1	 3.74	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8338	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8339	 1	 5.66	 1.38	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8340	 1	 3.04	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8341	 1	 1.35	 0.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8342	 1	 2.69	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8343	 1	 1.23	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8344	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8345	 1	 1.99	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8346	 1	 11.17	 2.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8347	 1	 4.41	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8348	 1	 5.81	 1.4	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8349	 1	 10.22	 2.47	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8350	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8351	 1	 3.7	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8352	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8353	 1	 2.63	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8354	 1	 15.95	 3.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8355	 1	 6.09	 1.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8356	 1	 6.46	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8357	 1	 6.39	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8358	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8359	 1	 9.57	 2.28	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8360	 1	 7.37	 1.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8361	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8362	 1	 7.02	 1.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8363	 1	 7.21	 1.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8364	 1	 5.29	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8365	 1	 14.38	 3.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8366	 1	 4.84	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8367	 1	 2.81	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8368	 1	 6.05	 1.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8369	 1	 10.45	 2.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8370	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8371	 1	 7.62	 1.83	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8372	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8373	 1	 12.86	 3.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8374	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8375	 1	 2.8	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8376	 1	 4.6	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8377	 1	 2.99	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8378	 1	 3.52	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8379	 1	 17.79	 4.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8380	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8381	 1	 11.12	 2.67	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8382	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8383	 1	 8.8	 2.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8384	 1	 5.9	 1.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8385	 1	 12.12	 2.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8386	 1	 15.15	 3.65	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8387	 1	 3.2	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8388	 1	 2.05	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8389	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8390	 1	 4.11	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8391	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8392	 1	 3.19	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8393	 1	 6.33	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8394	 1	 8.42	 2.04	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8395	 1	 3.57	 0.86	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8396	 1	 7.82	 1.89	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8397	 1	 5.44	 1.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8398	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8399	 1	 8.38	 2.02	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8400	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8401	 1	 4.68	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8402	 1	 4.67	 1.13	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8403	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8404	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8405	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8406	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8407	 1	 1.87	 0.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8408	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8409	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8410	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8411	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8412	 1	 5.0	 2.46	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8413	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8414	 1	 14.09	 3.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8415	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8416	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8417	 1	 2.68	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8418	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8419	 1	 4.61	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8420	 1	 3.83	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8421	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8422	 1	 9.95	 2.42	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8423	 1	 10.64	 2.58	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8424	 1	 9.66	 5.69	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8425	 1	 1.54	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8426	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8427	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8428	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8429	 1	 10.64	 4.83	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8430	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8431	 1	 1.65	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8432	 1	 9.56	 5.19	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8433	 1	 11.08	 5.84	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8434	 1	 5.32	 2.5	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8435	 1	 5.37	 1.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8436	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8437	 1	 17.84	 10.37	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8438	 1	 6.83	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8439	 1	 12.09	 6.41	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8440	 1	 2.75	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8441	 1	 6.99	 3.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8442	 1	 2.72	 1.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8443	 1	 4.56	 2.52	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8444	 1	 2.5	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8445	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8446	 1	 3.44	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8447	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8448	 1	 11.69	 2.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8449	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8450	 1	 9.62	 4.46	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8451	 1	 4.74	 2.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8452	 1	 3.57	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8453	 1	 6.86	 3.21	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8454	 1	 7.6	 4.06	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8455	 1	 9.0	 4.77	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8456	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8457	 1	 5.38	 2.55	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8458	 1	 4.55	 2.22	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8459	 1	 9.82	 4.09	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8460	 1	 8.04	 3.79	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8461	 1	 3.03	 1.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8462	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8463	 1	 7.58	 3.26	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8464	 1	 32.52	 18.03	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8465	 1	 4.78	 2.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8466	 1	 5.42	 2.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8467	 1	 6.74	 3.22	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8468	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8469	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8470	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8471	 1	 4.04	 2.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8472	 1	 2.97	 1.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8473	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8474	 1	 6.23	 3.1	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8475	 1	 1.85	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8476	 1	 10.11	 5.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8477	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8478	 1	 9.44	 4.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8479	 1	 2.81	 1.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8480	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8481	 1	 1.17	 0.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8482	 1	 3.54	 1.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8483	 1	 6.24	 3.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8484	 1	 2.4	 0.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8485	 1	 3.28	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8486	 1	 2.22	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8487	 1	 1.66	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8488	 1	 3.67	 1.74	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8489	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8490	 1	 0.98	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8491	 1	 12.64	 5.23	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8492	 1	 0.85	 0.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8493	 1	 9.42	 2.27	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8494	 1	 7.03	 3.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8495	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8496	 1	 2.69	 1.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8497	 1	 3.03	 1.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8498	 1	 6.92	 3.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8499	 1	 3.37	 1.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8500	 1	 4.49	 2.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8501	 1	 12.98	 4.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8502	 1	 2.93	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8503	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8504	 1	 1.54	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8505	 1	 8.59	 2.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8506	 1	 6.46	 1.64	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8507	 1	 3.26	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8508	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8509	 1	 4.87	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8510	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8511	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8512	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8513	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8514	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8515	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8516	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8517	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8518	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8519	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8520	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8521	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8522	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8523	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8524	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8525	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8526	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8527	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8528	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8529	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8530	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8531	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8532	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8533	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8534	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8535	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8536	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8537	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8538	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8539	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8540	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8541	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8542	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8543	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8544	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8545	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8546	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8547	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8548	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8549	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8550	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8551	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8552	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8553	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8554	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8555	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8556	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8557	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8558	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8559	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8560	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8561	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8562	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8563	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8564	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8565	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8566	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8567	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8568	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8569	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8570	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8571	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8572	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8573	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8574	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8575	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8576	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8577	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8578	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8579	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8580	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8581	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8582	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8583	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8584	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8585	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8586	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8587	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8588	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8589	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8590	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8591	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8592	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8593	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8594	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8595	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8596	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8597	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8598	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8599	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8600	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8601	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8602	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8603	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8604	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8605	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8606	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8607	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8608	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8609	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8610	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8611	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8612	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8613	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8614	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8615	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8616	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8617	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8618	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8619	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8620	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8621	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8622	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8623	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8624	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8625	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8626	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8627	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8628	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8629	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8630	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8631	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8632	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8633	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8634	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8635	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8636	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8637	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8638	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8639	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8640	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8641	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8642	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8643	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8644	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8645	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8646	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8647	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8648	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8649	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8650	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8651	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8652	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8653	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8654	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8655	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8656	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8657	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	8658	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8659	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8660	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8661	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8662	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8663	 1	 8.79	 5.39	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8664	 1	 2.13	 1.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8665	 1	 2.71	 1.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8666	 1	 3.76	 2.28	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8667	 1	 3.31	 2.23	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8668	 1	 2.09	 1.29	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8669	 1	 1.97	 1.19	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8670	 1	 2.66	 1.9	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8671	 1	 6.47	 5.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8672	 1	 1.75	 1.14	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8673	 1	 1.69	 1.26	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8674	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8675	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8676	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8677	 1	 2.17	 1.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8678	 1	 1.48	 0.91	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8679	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8680	 1	 2.57	 1.67	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8681	 1	 5.08	 3.02	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8682	 1	 4.8	 3.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8683	 1	 4.92	 3.02	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8684	 1	 5.33	 3.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8685	 1	 6.67	 4.47	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8686	 1	 6.21	 3.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8687	 1	 2.6	 1.84	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8688	 1	 5.53	 4.18	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8689	 1	 8.26	 5.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8690	 1	 5.35	 3.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8691	 1	 4.21	 2.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8692	 1	 8.22	 5.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8693	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8694	 1	 3.78	 2.38	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8695	 1	 2.82	 1.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8696	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8697	 1	 6.8	 4.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8698	 1	 5.12	 3.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8699	 1	 7.02	 4.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8700	 1	 9.39	 6.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8701	 1	 4.84	 2.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8702	 1	 3.41	 1.95	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8703	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8704	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8705	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8706	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8707	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8708	 1	 1.44	 1.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8709	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8710	 1	 5.95	 4.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8711	 1	 2.09	 1.39	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8712	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8713	 1	 3.59	 2.26	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8714	 1	 3.73	 2.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8715	 1	 1.92	 1.35	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8716	 1	 3.24	 2.07	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8717	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8718	 1	 0.88	 0.65	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8719	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8720	 1	 1.39	 1.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8721	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8722	 1	 3.2	 2.15	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8723	 1	 3.24	 2.28	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8724	 1	 0.88	 0.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8725	 1	 1.67	 1.17	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8726	 1	 2.07	 1.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8727	 1	 2.06	 1.41	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8728	 1	 1.8	 1.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8729	 1	 1.69	 1.15	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8730	 1	 1.8	 1.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8731	 1	 2.07	 1.3	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8732	 1	 8.69	 2.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8733	 1	 2.72	 0.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8734	 1	 15.99	 3.86	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8735	 1	 7.82	 1.89	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8736	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8737	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8738	 1	 4.1	 1.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8739	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8740	 1	 3.95	 0.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8741	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8742	 1	 2.42	 0.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8743	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8744	 1	 47.75	 23.19	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8745	 1	 4.48	 1.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8746	 1	 3.93	 0.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8747	 1	 2.91	 0.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8748	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8749	 1	 4.32	 1.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8750	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8751	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8752	 1	 3.45	 0.84	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8753	 1	 2.38	 0.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8754	 1	 5.86	 1.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8755	 1	 4.11	 1.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8756	 1	 6.29	 1.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8757	 1	 5.49	 1.35	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8758	 1	 3.26	 0.81	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8759	 1	 6.88	 1.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8760	 1	 16.07	 3.96	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8761	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8762	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8763	 1	 17.89	 4.41	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8764	 1	 4.91	 1.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8765	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8766	 1	 1.52	 0.37	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8767	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8768	 1	 4.08	 1.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8769	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8770	 1	 3.82	 0.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8771	 1	 9.2	 2.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8772	 1	 4.65	 1.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8773	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	8774	 1	 5.78	 1.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8775	 1	 5.07	 1.24	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8776	 1	 12.16	 2.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8777	 1	 6.09	 1.5	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8778	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8779	 1	 4.77	 1.18	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8780	 1	 4.47	 1.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8781	 1	 3.44	 0.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8782	 1	 2.83	 0.7	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8783	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8784	 1	 5.15	 1.28	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8785	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8786	 1	 1.86	 0.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8787	 1	 4.84	 1.2	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8788	 1	 1.9	 0.46	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8789	 1	 6.18	 1.5	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8790	 1	 4.89	 1.17	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8791	 1	 4.28	 1.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8792	 1	 10.49	 2.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8793	 1	 3.42	 0.85	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8794	 1	 3.27	 0.81	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8795	 1	 8.1	 1.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8796	 1	 4.55	 1.13	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8797	 1	 3.77	 0.92	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8798	 1	 6.28	 1.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8799	 1	 15.46	 3.83	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8800	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8801	 1	 2.0	 0.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8802	 1	 3.77	 0.93	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8803	 1	 2.55	 0.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8804	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8805	 1	 4.51	 1.12	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8806	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8807	 1	 9.67	 2.4	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8808	 1	 6.72	 1.67	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8809	 1	 5.85	 1.41	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8810	 1	 3.32	 0.8	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8811	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8812	 1	 5.41	 1.34	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8813	 1	 3.01	 0.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8814	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8815	 1	 3.67	 0.89	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8816	 1	 6.16	 1.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8817	 1	 2.34	 0.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8818	 1	 4.0	 1.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8819	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8820	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8821	 1	 6.21	 1.54	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8822	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8823	 1	 8.54	 2.12	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8824	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8825	 1	 6.32	 1.54	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8826	 1	 4.6	 1.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8827	 1	 5.43	 1.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8828	 1	 4.64	 1.12	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8829	 1	 5.44	 1.3	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8830	 1	 7.56	 1.8	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8831	 1	 4.51	 1.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8832	 1	 8.82	 2.1	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8833	 1	 2.24	 0.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8834	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8835	 1	 2.7	 0.67	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8836	 1	 8.3	 2.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8837	 1	 14.73	 3.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8838	 1	 8.41	 2.02	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8839	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8840	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8841	 1	 4.13	 1.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8842	 1	 2.55	 0.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8843	 1	 5.6	 1.38	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8844	 1	 13.83	 9.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8845	 1	 2.83	 1.81	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8846	 1	 3.83	 2.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8847	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8848	 1	 3.59	 0.86	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8849	 1	 7.5	 1.82	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8850	 1	 2.75	 0.67	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8851	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8852	 1	 5.83	 4.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8853	 1	 2.9	 2.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8854	 1	 3.92	 2.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8855	 1	 2.72	 1.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8856	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8857	 1	 6.43	 1.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8858	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8859	 1	 10.35	 2.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8860	 1	 10.77	 2.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8861	 1	 2.45	 0.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8862	 1	 5.13	 1.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8863	 1	 6.01	 1.45	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8864	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8865	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8866	 1	 5.92	 1.47	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8867	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8868	 1	 3.08	 0.77	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8869	 1	 10.41	 2.59	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8870	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8871	 1	 7.6	 1.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8872	 1	 3.23	 0.78	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8873	 1	 3.29	 0.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8874	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8875	 1	 5.08	 1.24	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8876	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8877	 1	 4.8	 1.18	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8878	 1	 2.83	 0.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8879	 1	 4.74	 1.15	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8880	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8881	 1	 6.09	 3.6	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8882	 1	 1.93	 0.47	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8883	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8884	 1	 6.28	 4.18	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8885	 1	 10.1	 2.47	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8886	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8887	 1	 2.1	 0.5	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8888	 1	 7.15	 1.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8889	 1	 6.9	 1.7	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8890	 1	 4.17	 1.02	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8891	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8892	 1	 9.15	 2.27	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8893	 1	 5.9	 1.46	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8894	 1	 7.06	 1.75	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8895	 1	 6.41	 1.56	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8896	 1	 7.97	 1.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8897	 1	 3.6	 0.86	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8898	 1	 5.17	 1.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8899	 1	 11.03	 2.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8900	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8901	 1	 2.11	 0.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8902	 1	 2.73	 0.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8903	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8904	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8905	 1	 4.63	 1.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8906	 1	 8.55	 2.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8907	 1	 3.33	 0.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8908	 1	 4.5	 1.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8909	 1	 3.15	 0.77	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8910	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8911	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8912	 1	 1.76	 1.01	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8913	 1	 2.47	 1.74	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8914	 1	 4.61	 2.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8915	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8916	 1	 1.52	 0.93	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8917	 1	 6.35	 4.67	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8918	 1	 4.72	 3.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8919	 1	 1.72	 1.24	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8920	 1	 2.86	 1.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8921	 1	 2.07	 1.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8922	 1	 2.92	 1.86	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8923	 1	 1.59	 1.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8924	 1	 8.79	 5.77	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8925	 1	 3.36	 1.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8926	 1	 8.97	 5.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8927	 1	 8.45	 5.33	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8928	 1	 5.33	 3.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8929	 1	 4.37	 2.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8930	 1	 5.07	 3.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8931	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8932	 1	 7.91	 5.14	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8933	 1	 4.67	 2.81	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8934	 1	 3.76	 2.26	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8935	 1	 2.44	 1.81	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8936	 1	 2.33	 1.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8937	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8938	 1	 2.27	 1.47	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8939	 1	 5.56	 4.38	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8940	 1	 4.35	 3.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8941	 1	 5.86	 4.46	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8942	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8943	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	8944	 1	 11.41	 7.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8945	 1	 2.77	 2.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8946	 1	 3.23	 2.12	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8947	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8948	 1	 2.41	 1.77	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8949	 1	 5.08	 3.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8950	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8951	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8952	 1	 6.56	 4.29	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8953	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8954	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8955	 1	 5.44	 3.54	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8956	 1	 1.93	 1.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8957	 1	 2.05	 1.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8958	 1	 9.64	 5.88	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8959	 1	 1.16	 0.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8960	 1	 2.71	 1.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8961	 1	 5.23	 3.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8962	 1	 1.9	 1.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8963	 1	 5.01	 3.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8964	 1	 1.02	 0.74	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8965	 1	 7.95	 5.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8966	 1	 5.33	 3.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8967	 1	 3.94	 2.46	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8968	 1	 2.59	 1.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8969	 1	 16.87	 12.21	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8970	 1	 1.57	 1.15	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8971	 1	 2.39	 1.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8972	 1	 2.44	 1.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8973	 1	 1.64	 1.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8974	 1	 2.65	 1.47	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8975	 1	 2.64	 1.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8976	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8977	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8978	 1	 1.01	 0.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8979	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8980	 1	 2.77	 1.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8981	 1	 3.98	 2.38	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8982	 1	 5.19	 3.28	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8983	 1	 1.82	 1.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8984	 1	 2.88	 1.56	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8985	 1	 7.85	 5.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8986	 1	 6.47	 4.43	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8987	 1	 2.73	 1.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8988	 1	 3.75	 2.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8989	 1	 4.64	 3.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8990	 1	 1.61	 0.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8991	 1	 1.05	 0.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8992	 1	 13.63	 9.56	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8993	 1	 3.47	 2.37	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8994	 1	 3.81	 2.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8995	 1	 7.36	 5.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8996	 1	 3.0	 1.64	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8997	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	8998	 1	 2.55	 1.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	8999	 1	 6.77	 4.56	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9000	 1	 4.78	 1.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9001	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9002	 1	 5.42	 2.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9003	 1	 3.03	 1.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9004	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9005	 1	 3.14	 2.13	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9006	 1	 6.09	 4.37	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9007	 1	 3.04	 1.81	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9008	 1	 5.38	 3.38	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9009	 1	 5.31	 3.67	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9010	 1	 3.99	 2.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9011	 1	 4.69	 2.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9012	 1	 2.09	 1.15	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9013	 1	 3.79	 2.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9014	 1	 4.35	 2.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9015	 1	 5.15	 3.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9016	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9017	 1	 4.86	 3.14	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9018	 1	 5.16	 3.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9019	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9020	 1	 6.56	 3.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9021	 1	 3.49	 1.96	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9022	 1	 30.91	 23.52	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9023	 1	 3.2	 2.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9024	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9025	 1	 5.76	 3.27	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9026	 1	 3.07	 1.8	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9027	 1	 2.1	 1.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9028	 1	 4.31	 2.46	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9029	 1	 6.82	 3.74	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9030	 1	 4.39	 2.72	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9031	 1	 3.6	 2.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9032	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9033	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9034	 1	 10.73	 7.86	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9035	 1	 3.73	 2.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9036	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9037	 1	 2.58	 1.81	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9038	 1	 2.11	 1.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9039	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9040	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9041	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9042	 1	 3.48	 2.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9043	 1	 5.09	 3.57	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9044	 1	 1.82	 1.23	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9045	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9046	 1	 3.01	 2.14	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9047	 1	 2.59	 1.7	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9048	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9049	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9050	 1	 15.62	 9.47	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9051	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9052	 1	 4.39	 2.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9053	 1	 2.53	 1.77	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9054	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9055	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9056	 1	 3.89	 2.4	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9057	 1	 1.95	 1.27	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9058	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9059	 1	 4.24	 2.74	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9060	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9061	 1	 3.33	 2.29	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9062	 1	 1.58	 0.94	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9063	 1	 1.8	 1.19	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9064	 1	 2.8	 1.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9065	 1	 5.27	 3.94	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9066	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9067	 1	 3.54	 2.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9068	 1	 2.99	 2.29	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9069	 1	 3.67	 2.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9070	 1	 2.87	 2.11	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9071	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9072	 1	 2.45	 1.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9073	 1	 1.63	 0.95	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9074	 1	 1.97	 1.29	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9075	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9076	 1	 2.24	 1.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9077	 1	 2.36	 1.51	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9078	 1	 2.75	 1.77	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9079	 1	 3.09	 1.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9080	 1	 2.22	 1.26	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9081	 1	 2.45	 1.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9082	 1	 4.24	 2.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9083	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9084	 1	 3.33	 1.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9085	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9086	 1	 2.47	 1.47	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9087	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9088	 1	 4.89	 3.19	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9089	 1	 4.05	 2.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9090	 1	 3.62	 2.27	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9091	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9092	 1	 3.85	 2.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9093	 1	 6.27	 4.51	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9094	 1	 3.69	 2.27	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9095	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9096	 1	 3.21	 2.1	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9097	 1	 8.27	 5.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9098	 1	 5.48	 3.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9099	 1	 5.78	 4.24	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9100	 1	 3.37	 2.15	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9101	 1	 2.02	 1.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9102	 1	 4.83	 3.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9103	 1	 3.94	 2.84	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9104	 1	 4.74	 2.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9105	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9106	 1	 4.04	 2.24	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9107	 1	 1.57	 1.02	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9108	 1	 1.47	 0.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9109	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9110	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9111	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9112	 1	 2.35	 1.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9113	 1	 2.48	 1.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9114	 1	 5.25	 3.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9115	 1	 4.51	 2.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9116	 1	 5.01	 3.02	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9117	 1	 2.14	 1.54	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9118	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9119	 1	 4.43	 2.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9120	 1	 2.28	 1.39	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9121	 1	 5.94	 4.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9122	 1	 5.33	 3.14	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9123	 1	 1.72	 1.2	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9124	 1	 1.8	 0.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9125	 1	 4.1	 2.82	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9126	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9127	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9128	 1	 6.68	 1.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9129	 1	 2.18	 0.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9130	 1	 1.73	 1.19	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9131	 1	 3.87	 2.24	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9132	 1	 7.17	 1.64	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9133	 1	 3.21	 1.91	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9134	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9135	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9136	 1	 2.64	 1.43	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9137	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9138	 1	 8.89	 5.72	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9139	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9140	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	9141	 1	 5.84	 4.01	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9142	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9143	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9144	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9145	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9146	 1	 3.73	 2.18	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9147	 1	 4.2	 2.88	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9148	 1	 4.56	 2.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9149	 1	 7.93	 5.43	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9150	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9151	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9152	 1	 4.82	 2.9	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9153	 1	 2.91	 2.27	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9154	 1	 0.82	 0.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9155	 1	 2.42	 1.89	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9156	 1	 0.72	 0.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9157	 1	 1.57	 1.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9158	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9159	 1	 3.73	 2.43	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9160	 1	 4.37	 3.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9161	 1	 6.68	 5.19	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9162	 1	 1.86	 1.27	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9163	 1	 3.95	 2.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9164	 1	 2.45	 1.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9165	 1	 1.11	 0.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9166	 1	 2.4	 1.64	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9167	 1	 5.54	 4.36	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9168	 1	 2.87	 1.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9169	 1	 11.38	 7.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9170	 1	 4.22	 3.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9171	 1	 3.76	 2.17	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9172	 1	 4.09	 2.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9173	 1	 3.17	 1.95	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9174	 1	 2.94	 1.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9175	 1	 3.46	 2.5	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9176	 1	 4.15	 3.19	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9177	 1	 5.19	 3.21	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9178	 1	 4.13	 2.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9179	 1	 2.9	 1.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9180	 1	 2.47	 1.46	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9181	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9182	 1	 0.99	 0.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9183	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9184	 1	 6.44	 4.38	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9185	 1	 2.87	 1.81	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9186	 1	 4.13	 2.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9187	 1	 2.21	 1.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9188	 1	 2.01	 1.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9189	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9190	 1	 4.07	 3.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9191	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9192	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9193	 1	 9.21	 5.43	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9194	 1	 10.63	 7.77	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9195	 1	 2.46	 1.54	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9196	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9197	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9198	 1	 5.67	 3.46	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9199	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9200	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9201	 1	 2.62	 1.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9202	 1	 3.67	 2.54	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9203	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9204	 1	 13.0	 9.33	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9205	 1	 6.87	 4.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9206	 1	 6.21	 4.18	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9207	 1	 5.28	 3.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9208	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9209	 1	 6.78	 5.33	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9210	 1	 9.07	 6.28	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9211	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9212	 1	 4.47	 3.38	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9213	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	9214	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9215	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9216	 1	 13.67	 8.18	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9217	 1	 4.83	 3.21	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9218	 1	 2.29	 1.71	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9219	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9220	 1	 2.3	 1.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9221	 1	 1.79	 1.17	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9222	 1	 2.93	 2.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9223	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9224	 1	 5.46	 3.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9225	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9226	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9227	 1	 5.18	 3.15	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9228	 1	 1.45	 0.86	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9229	 1	 1.75	 1.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9230	 1	 5.66	 3.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9231	 1	 1.37	 0.92	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9232	 1	 1.72	 1.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9233	 1	 1.53	 1.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9234	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9235	 1	 4.13	 2.85	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9236	 1	 3.01	 1.79	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9237	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9238	 1	 2.66	 1.54	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9239	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9240	 1	 2.14	 1.19	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9241	 1	 2.27	 1.36	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9242	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9243	 1	 1.07	 0.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9244	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9245	 1	 1.73	 1.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9246	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9247	 1	 1.71	 1.14	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9248	 1	 0.91	 0.65	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9249	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9250	 1	 1.9	 1.38	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9251	 1	 1.73	 0.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9252	 1	 1.06	 0.64	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9253	 1	 2.46	 1.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9254	 1	 2.12	 1.3	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9255	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9256	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9257	 1	 9.45	 6.14	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9258	 1	 4.26	 3.32	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9259	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9260	 1	 1.37	 0.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9261	 1	 1.09	 0.74	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9262	 1	 1.91	 1.17	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9263	 1	 2.43	 1.43	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9264	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9265	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9266	 1	 0.61	 0.37	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9267	 1	 0.81	 0.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9268	 1	 2.98	 2.24	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9269	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	9270	 1	 3.64	 2.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9271	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9272	 1	 3.64	 2.32	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9273	 1	 2.66	 1.97	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9274	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9275	 1	 65.6	 40.94	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9276	 1	 49.39	 38.57	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9277	 1	 36.35	 24.74	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9278	 1	 3.11	 2.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9279	 1	 1.73	 1.16	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9280	 1	 4.51	 2.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9281	 1	 5.2	 3.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9282	 1	 9.52	 6.35	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9283	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9284	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9285	 1	 4.0	 2.37	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9286	 1	 1.52	 1.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9287	 1	 2.11	 1.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9288	 1	 1.61	 1.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9289	 1	 2.64	 1.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9290	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9291	 1	 4.69	 2.92	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9292	 1	 4.47	 3.11	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9293	 1	 5.46	 3.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9294	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9295	 1	 3.32	 2.07	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9296	 1	 2.65	 1.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9297	 1	 2.72	 1.84	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9298	 1	 3.29	 2.35	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9299	 1	 4.15	 2.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9300	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9301	 1	 4.81	 2.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9302	 1	 5.36	 3.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9303	 1	 6.34	 3.89	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9304	 1	 2.77	 1.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9305	 1	 1.41	 0.81	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9306	 1	 3.18	 2.19	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9307	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9308	 1	 3.31	 2.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9309	 1	 5.05	 3.71	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9310	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9311	 1	 2.62	 1.56	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9312	 1	 1.92	 1.39	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9313	 1	 3.54	 2.54	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9314	 1	 2.05	 1.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9315	 1	 2.2	 1.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9316	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9317	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9318	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9319	 1	 3.56	 2.22	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9320	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9321	 1	 2.63	 1.52	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9322	 1	 2.84	 2.04	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9323	 1	 4.36	 3.16	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9324	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9325	 1	 2.89	 1.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9326	 1	 1.35	 0.9	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9327	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9328	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9329	 1	 2.92	 1.71	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9330	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9331	 1	 5.58	 2.96	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9332	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9333	 1	 4.63	 1.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9334	 1	 4.26	 2.67	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9335	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9336	 1	 3.58	 2.1	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9337	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9338	 1	 2.35	 1.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9339	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9340	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9341	 1	 3.02	 2.25	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9342	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9343	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9344	 1	 4.33	 1.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9345	 1	 3.64	 0.89	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9346	 1	 2.37	 1.54	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9347	 1	 3.29	 2.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9348	 1	 2.89	 0.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9349	 1	 2.84	 0.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9350	 1	 8.49	 2.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9351	 1	 3.87	 2.35	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9352	 1	 3.66	 2.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9353	 1	 5.16	 3.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9354	 1	 5.07	 3.2	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9355	 1	 7.22	 4.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9356	 1	 7.52	 1.81	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9357	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9358	 1	 2.43	 0.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9359	 1	 4.27	 1.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9360	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9361	 1	 4.02	 2.47	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9362	 1	 3.15	 2.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9363	 1	 4.89	 1.18	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9364	 1	 7.33	 5.01	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9365	 1	 3.25	 0.78	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9366	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9367	 1	 1.94	 0.47	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9368	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9369	 1	 4.16	 2.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9370	 1	 8.32	 5.75	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9371	 1	 6.85	 4.19	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9372	 1	 5.32	 3.96	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9373	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9374	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9375	 1	 3.82	 2.17	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9376	 1	 3.44	 2.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9377	 1	 6.08	 3.74	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9378	 1	 3.34	 2.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9379	 1	 3.56	 2.26	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9380	 1	 5.0	 3.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9381	 1	 2.28	 1.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9382	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9383	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9384	 1	 4.64	 3.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9385	 1	 5.93	 3.74	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9386	 1	 2.95	 1.88	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9387	 1	 3.25	 1.96	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9388	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9389	 1	 5.84	 3.39	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9390	 1	 2.13	 1.41	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9391	 1	 4.6	 2.86	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9392	 1	 3.92	 2.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9393	 1	 7.5	 4.84	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9394	 1	 1.95	 1.3	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9395	 1	 3.11	 1.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9396	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9397	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9398	 1	 4.66	 3.28	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9399	 1	 6.71	 4.2	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9400	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9401	 1	 6.89	 4.21	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9402	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9403	 1	 3.9	 2.84	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9404	 1	 6.25	 3.77	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9405	 1	 1.6	 1.16	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9406	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9407	 1	 3.99	 2.85	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9408	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9409	 1	 4.64	 2.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9410	 1	 9.56	 5.51	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9411	 1	 6.05	 3.97	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9412	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	9413	 1	 3.89	 2.48	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9414	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9415	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9416	 1	 1.8	 1.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9417	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	9418	 1	 3.42	 2.29	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9419	 1	 2.58	 1.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9420	 1	 1.9	 1.36	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9421	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9422	 1	 3.48	 2.33	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9423	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9424	 1	 2.57	 1.78	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9425	 1	 5.66	 3.41	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9426	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	9427	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9428	 1	 32.44	 21.91	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9429	 1	 3.21	 2.32	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9430	 1	 4.68	 2.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9431	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	9432	 1	 9.38	 5.49	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9433	 1	 1.88	 1.16	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9434	 1	 18.32	 11.02	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9435	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	9436	 1	 9.81	 6.58	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9437	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9438	 1	 6.83	 3.83	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9439	 1	 2.31	 1.33	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9440	 1	 1.7	 1.18	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9441	 1	 3.31	 2.38	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9442	 1	 3.21	 2.28	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9443	 1	 4.56	 3.15	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9444	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9445	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9446	 1	 7.6	 5.94	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9447	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	9448	 1	 2.26	 1.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9449	 1	 3.13	 1.8	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9450	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9451	 1	 3.01	 1.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9452	 1	 7.45	 5.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9453	 1	 3.54	 2.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9454	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9455	 1	 5.54	 3.28	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9456	 1	 6.27	 4.75	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9457	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9458	 1	 2.61	 1.49	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9459	 1	 6.8	 3.87	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9460	 1	 2.72	 1.77	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9461	 1	 2.72	 1.55	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9462	 1	 3.52	 2.21	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9463	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9464	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9465	 1	 2.26	 1.67	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9466	 1	 3.9	 2.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9467	 1	 3.49	 2.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9468	 1	 11.66	 9.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9469	 1	 2.68	 1.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9470	 1	 4.59	 2.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9471	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9472	 1	 6.06	 3.7	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9473	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9474	 1	 4.24	 2.37	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9475	 1	 5.14	 3.23	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9476	 1	 4.03	 2.46	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9477	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9478	 1	 3.33	 2.2	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9479	 1	 2.19	 1.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9480	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9481	 1	 3.82	 2.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9482	 1	 4.43	 3.44	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9483	 1	 6.62	 4.2	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9484	 1	 3.92	 2.54	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9485	 1	 6.77	 4.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9486	 1	 2.26	 1.59	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9487	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9488	 1	 2.25	 1.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9489	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	9490	 1	 4.05	 0.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9491	 1	 3.49	 2.17	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9492	 1	 3.76	 2.66	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9493	 1	 4.39	 3.03	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9494	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9495	 1	 4.71	 3.4	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9496	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9497	 1	 2.42	 1.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9498	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9499	 1	 1.37	 0.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9500	 1	 3.64	 2.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9501	 1	 1.62	 1.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9502	 1	 1.13	 0.78	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9503	 1	 5.73	 4.36	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9504	 1	 2.75	 1.65	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9505	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	9506	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9507	 1	 3.66	 2.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9508	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9509	 1	 1.33	 0.93	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9510	 1	 2.75	 1.77	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9511	 1	 3.43	 2.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9512	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	9513	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9514	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9515	 1	 2.53	 1.81	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9516	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9517	 1	 2.91	 0.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9518	 1	 4.72	 3.35	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9519	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9520	 1	 4.21	 2.91	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9521	 1	 5.87	 4.36	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9522	 1	 2.26	 1.37	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9523	 1	 1.78	 1.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9524	 1	 3.06	 2.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9525	 1	 6.57	 4.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9526	 1	 3.24	 2.41	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9527	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9528	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9529	 1	 4.71	 3.55	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9530	 1	 2.05	 1.47	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9531	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9532	 1	 1.83	 1.27	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9533	 1	 3.15	 2.18	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9534	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9535	 1	 13.16	 10.29	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9536	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9537	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9538	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9539	 1	 6.26	 4.25	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9540	 1	 3.8	 2.21	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9541	 1	 1.94	 0.47	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9542	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9543	 1	 2.59	 1.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9544	 1	 3.36	 2.33	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9545	 1	 2.36	 1.78	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9546	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	9547	 1	 2.73	 1.96	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9548	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9549	 1	 2.73	 1.65	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9550	 1	 3.54	 0.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9551	 1	 6.54	 1.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9552	 1	 6.49	 1.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9553	 1	 8.39	 2.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9554	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9555	 1	 5.54	 3.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9556	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9557	 1	 2.81	 1.65	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9558	 1	 4.44	 3.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9559	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9560	 1	 3.51	 2.28	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9561	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9562	 1	 5.29	 3.91	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9563	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	9564	 1	 2.69	 2.02	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9565	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9566	 1	 4.13	 2.78	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9567	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9568	 1	 3.38	 2.37	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9569	 1	 7.29	 5.33	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9570	 1	 7.55	 5.47	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9571	 1	 4.46	 3.26	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9572	 1	 1.8	 1.16	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9573	 1	 4.55	 3.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9574	 1	 2.9	 1.77	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9575	 1	 3.72	 2.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9576	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	9577	 1	 12.33	 8.94	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9578	 1	 2.43	 1.77	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9579	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9580	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9581	 1	 3.21	 2.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9582	 1	 5.8	 4.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9583	 1	 14.27	 8.29	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9584	 1	 3.15	 1.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9585	 1	 1.9	 1.28	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9586	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9587	 1	 5.49	 2.29	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9588	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9589	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9590	 1	 3.78	 0.93	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9591	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9592	 1	 6.01	 1.48	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9593	 1	 5.45	 1.33	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9594	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9595	 1	 4.75	 1.17	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9596	 1	 4.14	 1.02	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9597	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9598	 1	 5.16	 1.27	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9599	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	9600	 1	 2.5	 0.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9601	 1	 1.78	 0.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9602	 1	 4.79	 1.18	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9603	 1	 3.76	 0.92	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9604	 1	 1.84	 0.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9605	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9606	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9607	 1	 3.77	 0.92	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9608	 1	 3.29	 0.81	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9609	 1	 4.11	 1.01	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9610	 1	 2.41	 0.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9611	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9612	 1	 6.08	 1.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9613	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9614	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9615	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9616	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9617	 1	 3.53	 0.87	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9618	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9619	 1	 3.6	 0.88	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9620	 1	 2.66	 0.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9621	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9622	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9623	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9624	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9625	 1	 1.99	 0.49	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9626	 1	 1.47	 0.37	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9627	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9628	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9629	 1	 1.91	 0.47	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9630	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9631	 1	 5.74	 1.41	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9632	 1	 6.15	 1.51	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9633	 1	 3.6	 0.89	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9634	 1	 3.34	 0.82	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9635	 1	 4.24	 1.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9636	 1	 4.14	 1.01	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9637	 1	 4.22	 1.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9638	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9639	 1	 6.52	 4.82	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9640	 1	 3.75	 0.92	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9641	 1	 3.96	 0.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9642	 1	 3.6	 0.88	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9643	 1	 9.02	 2.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9644	 1	 4.49	 3.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9645	 1	 6.61	 5.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9646	 1	 3.01	 1.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9647	 1	 3.69	 2.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9648	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9649	 1	 5.91	 1.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9650	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9651	 1	 13.8	 9.5	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9652	 1	 10.83	 6.9	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9653	 1	 4.49	 3.15	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9654	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9655	 1	 5.08	 3.93	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9656	 1	 5.88	 3.76	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9657	 1	 7.55	 5.9	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9658	 1	 4.07	 2.34	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9659	 1	 3.54	 2.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9660	 1	 7.26	 4.31	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9661	 1	 5.73	 3.39	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9662	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9663	 1	 3.45	 2.27	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9664	 1	 2.35	 1.47	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9665	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9666	 1	 3.27	 2.35	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9667	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9668	 1	 9.74	 6.91	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9669	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9670	 1	 4.63	 3.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9671	 1	 2.87	 1.95	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9672	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9673	 1	 7.91	 4.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9674	 1	 4.09	 2.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9675	 1	 4.03	 2.19	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9676	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9677	 1	 6.54	 4.02	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9678	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9679	 1	 3.49	 2.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9680	 1	 7.74	 4.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9681	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9682	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9683	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9684	 1	 3.07	 1.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9685	 1	 4.13	 2.96	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9686	 1	 3.19	 2.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9687	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9688	 1	 2.01	 1.27	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9689	 1	 3.74	 2.97	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9690	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9691	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9692	 1	 3.79	 2.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9693	 1	 2.52	 1.71	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9694	 1	 2.84	 1.65	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9695	 1	 7.47	 5.81	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9696	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9697	 1	 3.52	 2.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9698	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9699	 1	 0.84	 0.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9700	 1	 5.62	 4.29	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9701	 1	 8.3	 5.61	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9702	 1	 4.26	 3.1	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9703	 1	 5.01	 3.82	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9704	 1	 4.7	 2.78	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9705	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9706	 1	 1.32	 0.83	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9707	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9708	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9709	 1	 3.93	 2.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9710	 1	 5.78	 4.08	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9711	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9712	 1	 6.88	 4.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9713	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9714	 1	 4.18	 2.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9715	 1	 5.89	 4.1	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9716	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9717	 1	 4.3	 3.32	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9718	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	9719	 1	 4.14	 2.81	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9720	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9721	 1	 2.28	 1.36	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9722	 1	 5.87	 3.98	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9723	 1	 6.24	 3.95	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9724	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9725	 1	 7.63	 4.38	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9726	 1	 11.71	 6.63	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9727	 1	 4.98	 3.43	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9728	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9729	 1	 12.91	 8.77	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9730	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9731	 1	 4.51	 2.91	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9732	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9733	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9734	 1	 2.04	 1.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9735	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9736	 1	 2.55	 1.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9737	 1	 8.07	 4.54	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9738	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9739	 1	 3.6	 2.46	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9740	 1	 4.39	 2.5	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9741	 1	 8.02	 5.84	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9742	 1	 6.78	 4.95	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9743	 1	 6.14	 4.24	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9744	 1	 4.77	 3.3	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9745	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9746	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9747	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9748	 1	 5.17	 3.45	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9749	 1	 6.46	 4.95	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9750	 1	 5.9	 3.78	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9751	 1	 6.97	 4.95	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9752	 1	 8.22	 4.82	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9753	 1	 9.57	 6.39	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9754	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9755	 1	 9.16	 7.15	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9756	 1	 5.22	 3.54	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9757	 1	 4.56	 3.33	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9758	 1	 1.85	 1.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9759	 1	 29.11	 19.59	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9760	 1	 9.11	 5.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9761	 1	 6.91	 4.75	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9762	 1	 7.89	 4.86	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9763	 1	 3.42	 2.24	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9764	 1	 6.54	 4.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9765	 1	 5.7	 3.91	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9766	 1	 6.84	 4.54	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9767	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	9768	 1	 10.19	 7.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9769	 1	 1.01	 0.64	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9770	 1	 3.61	 1.95	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9771	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9772	 1	 2.3	 1.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9773	 1	 2.14	 1.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9774	 1	 2.69	 2.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9775	 1	 4.43	 2.65	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9776	 1	 7.25	 4.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9777	 1	 69.59	 52.22	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9778	 1	 5.6	 4.16	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9779	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9780	 1	 3.45	 2.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9781	 1	 3.79	 2.6	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9782	 1	 2.8	 1.8	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9783	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9784	 1	 2.61	 1.67	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9785	 1	 5.47	 3.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9786	 1	 4.07	 2.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9787	 1	 6.56	 4.29	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9788	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9789	 1	 3.32	 2.39	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9790	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9791	 1	 14.67	 10.78	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9792	 1	 11.53	 8.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9793	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9794	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9795	 1	 13.51	 9.51	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9796	 1	 4.98	 3.14	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9797	 1	 6.16	 3.8	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9798	 1	 3.28	 2.36	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9799	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9800	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9801	 1	 2.89	 1.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9802	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9803	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9804	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9805	 1	 2.48	 1.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9806	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9807	 1	 2.93	 2.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9808	 1	 2.51	 1.74	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9809	 1	 3.5	 2.17	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9810	 1	 1.49	 1.01	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9811	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9812	 1	 4.16	 2.77	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9813	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9814	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9815	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9816	 1	 6.53	 4.96	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9817	 1	 3.1	 2.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9818	 1	 4.07	 2.88	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9819	 1	 4.86	 3.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9820	 1	 3.53	 2.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9821	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9822	 1	 5.47	 3.31	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9823	 1	 3.76	 2.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9824	 1	 2.82	 2.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9825	 1	 3.79	 2.8	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9826	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9827	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	9828	 1	 8.7	 5.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9829	 1	 88.31	 73.56	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9830	 1	 7.46	 4.17	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9831	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	9832	 1	 7.03	 3.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9833	 1	 2.86	 2.18	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9834	 1	 2.54	 1.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9835	 1	 2.94	 1.9	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9836	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9837	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	9838	 1	 5.14	 3.56	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9839	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9840	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9841	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9842	 1	 3.43	 2.36	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9843	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9844	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9845	 1	 4.73	 3.69	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9846	 1	 32.39	 23.29	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9847	 1	 3.05	 2.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9848	 1	 6.05	 4.58	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9849	 1	 4.98	 3.14	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9850	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9851	 1	 1.32	 0.87	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9852	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9853	 1	 8.9	 5.95	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9854	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9855	 1	 7.71	 5.18	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9856	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9857	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9858	 1	 7.19	 5.23	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9859	 1	 2.14	 1.26	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9860	 1	 6.92	 4.87	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9861	 1	 6.62	 4.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9862	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9863	 1	 5.79	 3.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9864	 1	 1.43	 0.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9865	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9866	 1	 2.48	 1.42	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9867	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9868	 1	 1.81	 1.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9869	 1	 3.17	 2.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9870	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9871	 1	 5.24	 3.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9872	 1	 3.8	 2.37	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9873	 1	 4.37	 3.5	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9874	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9875	 1	 2.89	 1.93	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9876	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9877	 1	 18.56	 10.71	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9878	 1	 4.31	 3.17	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9879	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9880	 1	 2.25	 1.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9881	 1	 2.55	 1.91	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9882	 1	 5.74	 3.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9883	 1	 4.61	 2.95	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9884	 1	 3.29	 2.57	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9885	 1	 3.5	 2.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9886	 1	 4.58	 2.91	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9887	 1	 3.24	 2.36	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9888	 1	 2.56	 1.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9889	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	9890	 1	 4.49	 2.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9891	 1	 3.03	 2.24	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9892	 1	 3.3	 2.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9893	 1	 1.47	 0.92	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9894	 1	 1.44	 0.9	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9895	 1	 2.18	 1.67	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9896	 1	 3.1	 2.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9897	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9898	 1	 3.3	 1.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9899	 1	 2.37	 1.63	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9900	 1	 6.44	 4.91	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9901	 1	 5.57	 3.8	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9902	 1	 5.41	 2.92	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9903	 1	 3.67	 2.17	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9904	 1	 1.38	 0.92	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9905	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9906	 1	 3.5	 2.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9907	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9908	 1	 3.71	 2.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9909	 1	 1.53	 1.06	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9910	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9911	 1	 2.47	 1.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9912	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9913	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9914	 1	 2.69	 1.93	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9915	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9916	 1	 1.57	 1.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9917	 1	 9.05	 5.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9918	 1	 28.35	 16.11	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9919	 1	 9.03	 5.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9920	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9921	 1	 14.92	 8.79	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9922	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9923	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9924	 1	 2.25	 1.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9925	 1	 2.74	 1.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9926	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	9927	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9928	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	9929	 1	 55.87	 38.68	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9930	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	9931	 1	 16.58	 10.55	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9932	 1	 8.32	 5.89	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9933	 1	 16.8	 10.78	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9934	 1	 3.82	 2.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9935	 1	 5.0	 3.14	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9936	 1	 3.39	 1.92	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9937	 1	 2.92	 1.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9938	 1	 4.11	 2.84	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9939	 1	 3.05	 1.91	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9940	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9941	 1	 3.79	 2.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9942	 1	 7.01	 4.75	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9943	 1	 4.45	 2.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9944	 1	 3.73	 2.74	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9945	 1	 3.24	 2.02	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9946	 1	 2.54	 1.79	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9947	 1	 4.03	 2.44	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9948	 1	 3.31	 2.29	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9949	 1	 11.52	 8.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9950	 1	 4.99	 3.01	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9951	 1	 3.13	 2.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9952	 1	 7.29	 4.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9953	 1	 3.2	 1.89	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9954	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9955	 1	 7.15	 4.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9956	 1	 3.19	 2.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9957	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9958	 1	 5.32	 3.38	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9959	 1	 2.12	 1.29	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9960	 1	 5.62	 3.4	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9961	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9962	 1	 3.69	 2.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9963	 1	 1.28	 0.81	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9964	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9965	 1	 2.57	 1.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9966	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9967	 1	 4.7	 2.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9968	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9969	 1	 5.17	 2.86	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9970	 1	 2.23	 1.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9971	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9972	 1	 5.37	 3.28	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9973	 1	 2.26	 1.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9974	 1	 3.73	 2.78	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9975	 1	 2.46	 1.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9976	 1	 7.13	 5.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9977	 1	 7.3	 4.4	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9978	 1	 3.9	 2.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9979	 1	 0.44	 0.3	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9980	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9981	 1	 14.09	 8.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9982	 1	 6.78	 4.81	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9983	 1	 4.41	 2.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9984	 1	 3.77	 2.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9985	 1	 5.48	 2.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9986	 1	 4.29	 2.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9987	 1	 2.52	 1.5	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9988	 1	 10.66	 7.67	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9989	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9990	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9991	 1	 2.2	 1.26	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9992	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9993	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9994	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9995	 1	 4.41	 3.26	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	9996	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9997	 1	 3.61	 2.48	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9998	 1	 3.15	 2.09	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	9999	 1	 6.38	 4.24	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10000	 1	 5.16	 3.05	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10001	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10002	 1	 2.2	 1.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10003	 1	 3.56	 2.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10004	 1	 2.65	 1.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10005	 1	 3.27	 2.24	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10006	 1	 2.36	 1.63	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10007	 1	 4.99	 3.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10008	 1	 5.32	 4.01	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10009	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10010	 1	 2.75	 1.99	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10011	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10012	 1	 2.58	 1.47	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10013	 1	 2.65	 1.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10014	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10015	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10016	 1	 1.75	 1.23	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10017	 1	 3.25	 2.41	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10018	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10019	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10020	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10021	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10022	 1	 3.2	 2.28	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10023	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10024	 1	 3.49	 2.01	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10025	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10026	 1	 2.71	 2.07	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10027	 1	 1.59	 0.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10028	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10029	 1	 1.8	 1.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10030	 1	 4.24	 2.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10031	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10032	 1	 7.17	 4.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10033	 1	 5.45	 4.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10034	 1	 7.2	 5.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10035	 1	 2.79	 1.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10036	 1	 4.64	 3.14	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10037	 1	 3.95	 2.93	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10038	 1	 3.98	 2.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10039	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10040	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10041	 1	 2.39	 1.35	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10042	 1	 3.63	 2.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10043	 1	 3.08	 1.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10044	 1	 3.87	 2.29	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10045	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10046	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10047	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10048	 1	 4.02	 2.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10049	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10050	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10051	 1	 9.4	 7.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10052	 1	 8.97	 5.29	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10053	 1	 8.02	 4.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10054	 1	 2.55	 1.71	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10055	 1	 6.08	 3.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10056	 1	 3.5	 2.01	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10057	 1	 3.09	 1.96	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10058	 1	 4.13	 2.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10059	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10060	 1	 7.4	 4.35	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10061	 1	 4.1	 2.67	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10062	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10063	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10064	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10065	 1	 2.64	 1.72	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10066	 1	 3.97	 2.68	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10067	 1	 4.2	 2.72	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10068	 1	 4.13	 2.84	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10069	 1	 6.26	 4.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10070	 1	 1.7	 1.24	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10071	 1	 10.78	 7.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10072	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10073	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10074	 1	 2.26	 1.27	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10075	 1	 5.79	 3.68	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10076	 1	 4.95	 2.92	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10077	 1	 3.3	 0.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10078	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10079	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10080	 1	 6.67	 1.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10081	 1	 9.4	 2.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10082	 1	 5.99	 1.43	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10083	 1	 4.66	 1.1	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10084	 1	 4.86	 1.17	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10085	 1	 2.77	 0.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10086	 1	 3.42	 0.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10087	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10088	 1	 2.77	 0.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10089	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10090	 1	 7.23	 1.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10091	 1	 7.65	 1.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10092	 1	 2.3	 0.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10093	 1	 5.16	 3.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10094	 1	 6.93	 4.67	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10095	 1	 9.66	 5.66	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10096	 1	 8.68	 5.99	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10097	 1	 9.59	 5.52	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10098	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10099	 1	 6.1	 1.46	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10100	 1	 4.28	 2.51	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10101	 1	 5.37	 1.29	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10102	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10103	 1	 13.56	 9.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10104	 1	 3.17	 2.49	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10105	 1	 8.26	 1.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10106	 1	 3.01	 0.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10107	 1	 4.25	 2.84	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10108	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10109	 1	 11.75	 7.01	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10110	 1	 19.78	 11.71	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10111	 1	 10.89	 7.1	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10112	 1	 14.92	 10.4	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10113	 1	 14.78	 8.34	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10114	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10115	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10116	 1	 3.63	 2.59	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10117	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10118	 1	 5.89	 3.4	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10119	 1	 6.54	 4.02	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10120	 1	 3.15	 2.14	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10121	 1	 6.38	 4.34	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10122	 1	 2.8	 2.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10123	 1	 12.53	 7.8	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10124	 1	 12.58	 8.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10125	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10126	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10127	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10128	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10129	 1	 4.85	 3.65	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10130	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10131	 1	 2.89	 1.82	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10132	 1	 5.41	 3.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10133	 1	 3.23	 2.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10134	 1	 5.83	 4.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10135	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10136	 1	 5.97	 4.06	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10137	 1	 4.54	 2.79	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10138	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10139	 1	 29.91	 20.46	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10140	 1	 7.46	 5.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10141	 1	 2.81	 1.8	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10142	 1	 7.37	 4.77	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10143	 1	 6.8	 4.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10144	 1	 4.75	 1.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10145	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10146	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10147	 1	 6.18	 3.65	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10148	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10149	 1	 5.41	 3.91	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10150	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10151	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10152	 1	 2.95	 2.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10153	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10154	 1	 5.07	 2.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10155	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10156	 1	 4.24	 2.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10157	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10158	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10159	 1	 3.87	 2.24	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10160	 1	 5.29	 3.86	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10161	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10162	 1	 4.27	 2.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10163	 1	 4.21	 2.97	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10164	 1	 2.75	 1.68	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10165	 1	 5.92	 3.66	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10166	 1	 3.04	 1.8	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10167	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10168	 1	 6.47	 4.71	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10169	 1	 8.05	 5.98	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10170	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10171	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10172	 1	 3.56	 1.92	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10173	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10174	 1	 5.08	 3.6	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10175	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10176	 1	 3.55	 2.54	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10177	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10178	 1	 3.39	 2.44	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10179	 1	 3.89	 2.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10180	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10181	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10182	 1	 1.5	 1.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10183	 1	 3.26	 1.86	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10184	 1	 5.92	 4.37	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10185	 1	 2.08	 1.39	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10186	 1	 2.42	 1.56	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10187	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10188	 1	 2.92	 1.73	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10189	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10190	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10191	 1	 3.14	 2.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10192	 1	 2.33	 1.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10193	 1	 1.89	 1.33	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10194	 1	 3.5	 2.51	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10195	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10196	 1	 4.72	 3.39	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10197	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10198	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10199	 1	 2.42	 1.48	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10200	 1	 0.46	 0.31	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10201	 1	 17.93	 13.91	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10202	 1	 10.13	 6.11	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10203	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10204	 1	 7.26	 5.09	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10205	 1	 4.15	 2.67	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10206	 1	 3.89	 2.87	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10207	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10208	 1	 6.93	 4.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10209	 1	 8.86	 5.18	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10210	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10211	 1	 1.38	 0.9	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10212	 1	 2.87	 2.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10213	 1	 2.76	 1.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10214	 1	 2.36	 1.41	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10215	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10216	 1	 6.58	 4.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10217	 1	 3.69	 2.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10218	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10219	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10220	 1	 4.74	 3.21	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10221	 1	 4.65	 3.14	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10222	 1	 8.11	 5.25	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10223	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10224	 1	 3.31	 2.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10225	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10226	 1	 2.67	 1.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10227	 1	 3.84	 2.41	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10228	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10229	 1	 2.78	 1.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10230	 1	 3.75	 2.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10231	 1	 2.1	 1.23	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10232	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10233	 1	 2.85	 1.75	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10234	 1	 3.83	 2.3	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10235	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10236	 1	 5.89	 3.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10237	 1	 2.39	 1.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10238	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10239	 1	 3.46	 2.16	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10240	 1	 3.02	 2.1	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10241	 1	 0.92	 0.7	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10242	 1	 2.04	 1.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10243	 1	 4.78	 3.72	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10244	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10245	 1	 4.98	 3.78	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10246	 1	 4.45	 2.56	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10247	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10248	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10249	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10250	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10251	 1	 2.72	 1.93	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10252	 1	 1.73	 1.3	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10253	 1	 2.13	 1.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10254	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10255	 1	 2.36	 1.49	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10256	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10257	 1	 2.0	 1.4	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10258	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10259	 1	 1.86	 1.48	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10260	 1	 1.89	 1.14	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10261	 1	 3.86	 2.91	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10262	 1	 1.25	 0.84	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10263	 1	 1.32	 0.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10264	 1	 3.21	 1.88	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10265	 1	 3.64	 2.67	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10266	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10267	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10268	 1	 2.64	 1.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10269	 1	 2.69	 1.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10270	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10271	 1	 1.18	 0.71	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10272	 1	 3.68	 2.92	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10273	 1	 1.87	 1.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10274	 1	 2.19	 1.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10275	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10276	 1	 14.89	 10.4	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10277	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10278	 1	 1.65	 1.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10279	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10280	 1	 6.88	 5.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10281	 1	 7.56	 5.67	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10282	 1	 7.91	 5.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10283	 1	 5.49	 3.8	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10284	 1	 4.16	 2.95	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10285	 1	 8.56	 5.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10286	 1	 2.63	 1.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10287	 1	 2.82	 2.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10288	 1	 8.74	 5.8	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10289	 1	 2.49	 1.74	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10290	 1	 1.28	 0.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10291	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10292	 1	 5.07	 3.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10293	 1	 2.49	 1.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10294	 1	 4.22	 2.75	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10295	 1	 1.81	 1.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10296	 1	 1.85	 1.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10297	 1	 1.52	 1.2	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10298	 1	 3.32	 2.19	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10299	 1	 13.24	 7.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10300	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10301	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10302	 1	 7.27	 1.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10303	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10304	 1	 5.04	 3.38	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10305	 1	 3.06	 0.74	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10306	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10307	 1	 6.47	 1.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10308	 1	 2.19	 0.54	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10309	 1	 10.23	 2.5	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10310	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10311	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10312	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10313	 1	 4.55	 1.12	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10314	 1	 6.95	 1.71	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10315	 1	 5.8	 1.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10316	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10317	 1	 4.89	 1.2	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10318	 1	 3.46	 0.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10319	 1	 5.05	 1.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10320	 1	 3.94	 0.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10321	 1	 7.6	 1.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10322	 1	 6.53	 1.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10323	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10324	 1	 8.43	 6.03	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10325	 1	 6.58	 1.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10326	 1	 6.83	 1.67	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10327	 1	 3.93	 0.96	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10328	 1	 2.46	 0.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10329	 1	 72.21	 17.82	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10330	 1	 5.04	 1.24	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10331	 1	 6.26	 1.54	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10332	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10333	 1	 1.88	 0.46	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10334	 1	 9.03	 2.21	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10335	 1	 5.69	 2.88	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10336	 1	 5.34	 1.3	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10337	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10338	 1	 4.25	 1.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10339	 1	 5.59	 1.37	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10340	 1	 6.28	 1.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10341	 1	 5.83	 1.43	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10342	 1	 3.86	 0.95	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10343	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10344	 1	 6.77	 1.65	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10345	 1	 3.11	 0.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10346	 1	 4.0	 0.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10347	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10348	 1	 7.21	 1.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10349	 1	 7.72	 1.89	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10350	 1	 5.58	 1.37	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10351	 1	 4.24	 1.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10352	 1	 4.67	 1.14	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10353	 1	 2.85	 0.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10354	 1	 2.85	 0.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10355	 1	 4.3	 1.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10356	 1	 4.41	 1.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10357	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10358	 1	 2.01	 0.49	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10359	 1	 2.96	 0.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10360	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10361	 1	 2.31	 0.57	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10362	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10363	 1	 6.32	 1.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10364	 1	 7.63	 1.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10365	 1	 16.32	 4.01	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10366	 1	 7.14	 1.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10367	 1	 4.16	 1.02	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10368	 1	 7.68	 1.88	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10369	 1	 8.08	 1.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10370	 1	 3.64	 0.89	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10371	 1	 9.87	 2.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10372	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10373	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10374	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10375	 1	 4.58	 1.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10376	 1	 7.73	 1.82	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10377	 1	 3.66	 0.87	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10378	 1	 2.48	 0.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10379	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10380	 1	 1.34	 0.33	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10381	 1	 5.58	 1.34	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10382	 1	 7.69	 1.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10383	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10384	 1	 2.2	 0.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10385	 1	 7.12	 1.71	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10386	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10387	 1	 1.71	 0.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10388	 1	 6.96	 5.36	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10389	 1	 3.04	 0.74	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10390	 1	 7.22	 1.75	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10391	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10392	 1	 5.35	 3.23	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10393	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10394	 1	 3.15	 0.75	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10395	 1	 4.69	 1.12	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10396	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10397	 1	 4.93	 1.17	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10398	 1	 6.79	 1.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10399	 1	 3.53	 0.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10400	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10401	 1	 5.35	 1.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10402	 1	 16.48	 12.14	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10403	 1	 1.49	 1.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10404	 1	 4.6	 3.33	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10405	 1	 2.34	 1.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10406	 1	 2.27	 1.4	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10407	 1	 5.12	 3.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10408	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10409	 1	 2.46	 1.59	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10410	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10411	 1	 3.29	 2.63	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10412	 1	 3.77	 2.5	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10413	 1	 3.84	 2.7	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10414	 1	 5.57	 4.22	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10415	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10416	 1	 5.8	 4.02	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10417	 1	 2.53	 1.92	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10418	 1	 41.44	 24.97	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10419	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10420	 1	 1.71	 1.08	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10421	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10422	 1	 1.4	 0.93	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10423	 1	 1.91	 1.1	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10424	 1	 1.24	 0.92	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10425	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10426	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10427	 1	 2.61	 1.75	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10428	 1	 6.6	 4.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10429	 1	 7.22	 3.93	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10430	 1	 4.72	 2.84	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10431	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10432	 1	 3.79	 2.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10433	 1	 6.54	 4.81	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10434	 1	 21.58	 12.22	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10435	 1	 3.63	 2.06	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10436	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10437	 1	 3.59	 2.28	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10438	 1	 3.69	 2.34	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10439	 1	 3.98	 2.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10440	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10441	 1	 5.86	 4.27	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10442	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10443	 1	 2.17	 1.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10444	 1	 3.8	 2.62	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10445	 1	 2.79	 1.66	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10446	 1	 5.07	 2.94	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10447	 1	 5.8	 4.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10448	 1	 2.71	 1.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10449	 1	 2.58	 1.67	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10450	 1	 2.78	 1.89	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10451	 1	 4.52	 3.19	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10452	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10453	 1	 5.73	 3.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10454	 1	 3.91	 2.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10455	 1	 8.38	 6.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10456	 1	 8.44	 5.93	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10457	 1	 5.68	 3.58	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10458	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10459	 1	 2.95	 1.97	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10460	 1	 10.89	 7.65	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10461	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10462	 1	 0.57	 0.37	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10463	 1	 5.17	 3.09	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10464	 1	 4.19	 2.84	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10465	 1	 4.11	 2.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10466	 1	 2.7	 1.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10467	 1	 3.04	 1.75	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10468	 1	 5.08	 3.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10469	 1	 5.03	 3.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10470	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10471	 1	 5.15	 3.43	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10472	 1	 4.48	 2.77	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10473	 1	 10.65	 6.95	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10474	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10475	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10476	 1	 8.5	 5.64	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10477	 1	 21.94	 13.31	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10478	 1	 4.0	 2.38	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10479	 1	 1.86	 1.16	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10480	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10481	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10482	 1	 3.2	 1.96	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10483	 1	 0.97	 0.58	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10484	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10485	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10486	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10487	 1	 1.18	 0.86	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10488	 1	 3.61	 2.43	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10489	 1	 4.55	 3.1	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10490	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10491	 1	 8.56	 5.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10492	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10493	 1	 10.45	 7.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10494	 1	 2.97	 0.69	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10495	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10496	 1	 2.06	 0.49	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10497	 1	 2.35	 0.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10498	 1	 3.06	 0.72	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10499	 1	 3.35	 0.8	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10500	 1	 2.41	 0.57	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10501	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10502	 1	 3.57	 0.84	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10503	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10504	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10505	 1	 2.82	 0.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10506	 1	 5.4	 1.27	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10507	 1	 1.73	 0.4	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10508	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10509	 1	 5.41	 1.26	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10510	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10511	 1	 3.59	 0.84	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10512	 1	 4.33	 1.01	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10513	 1	 3.16	 0.75	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10514	 1	 2.9	 0.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10515	 1	 2.0	 0.47	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10516	 1	 9.3	 2.19	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10517	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10518	 1	 4.59	 2.86	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10519	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10520	 1	 3.65	 2.55	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10521	 1	 2.89	 0.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10522	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10523	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10524	 1	 2.54	 0.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10525	 1	 3.52	 0.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10526	 1	 3.02	 2.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10527	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10528	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10529	 1	 1.51	 0.91	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10530	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10531	 1	 2.57	 1.46	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10532	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10533	 1	 4.51	 2.98	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10534	 1	 2.68	 1.81	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10535	 1	 2.24	 1.58	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10536	 1	 3.76	 2.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10537	 1	 30.6	 19.02	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10538	 1	 21.96	 17.52	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10539	 1	 1.63	 1.19	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10540	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10541	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10542	 1	 4.33	 2.66	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10543	 1	 3.17	 2.23	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10544	 1	 4.47	 2.84	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10545	 1	 14.89	 8.74	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10546	 1	 7.91	 6.11	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10547	 1	 3.86	 2.7	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10548	 1	 4.21	 2.71	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10549	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10550	 1	 4.55	 3.21	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10551	 1	 4.29	 2.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10552	 1	 3.83	 2.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10553	 1	 2.68	 1.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10554	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10555	 1	 3.0	 1.95	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10556	 1	 6.84	 3.93	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10557	 1	 3.25	 1.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10558	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10559	 1	 3.76	 2.18	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10560	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10561	 1	 5.89	 4.27	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10562	 1	 7.9	 4.82	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10563	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10564	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10565	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10566	 1	 4.5	 3.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10567	 1	 5.74	 2.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10568	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10569	 1	 9.15	 7.17	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10570	 1	 3.48	 2.61	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10571	 1	 3.86	 2.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10572	 1	 2.99	 0.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10573	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10574	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10575	 1	 3.82	 2.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10576	 1	 3.94	 2.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10577	 1	 4.97	 2.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10578	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10579	 1	 2.55	 1.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10580	 1	 2.74	 1.92	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10581	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10582	 1	 4.74	 3.29	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10583	 1	 4.8	 3.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10584	 1	 3.45	 2.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10585	 1	 3.73	 2.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10586	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10587	 1	 5.3	 4.04	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10588	 1	 15.95	 9.8	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10589	 1	 8.76	 6.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10590	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10591	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10592	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10593	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10594	 1	 3.35	 1.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10595	 1	 7.53	 4.67	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10596	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10597	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10598	 1	 10.28	 8.2	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10599	 1	 0.91	 0.56	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10600	 1	 5.19	 3.84	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10601	 1	 13.92	 8.78	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10602	 1	 2.34	 1.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10603	 1	 5.04	 3.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10604	 1	 3.44	 2.06	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10605	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10606	 1	 6.83	 4.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10607	 1	 5.06	 3.21	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10608	 1	 8.27	 6.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10609	 1	 4.93	 2.84	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10610	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10611	 1	 8.36	 4.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10612	 1	 5.93	 4.38	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10613	 1	 3.31	 2.2	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10614	 1	 6.1	 4.24	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10615	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10616	 1	 8.65	 5.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10617	 1	 6.32	 3.77	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10618	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10619	 1	 4.62	 3.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10620	 1	 11.75	 8.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10621	 1	 2.61	 1.65	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10622	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10623	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10624	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10625	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10626	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10627	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10628	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10629	 1	 2.62	 1.86	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10630	 1	 7.87	 5.52	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10631	 1	 4.2	 2.59	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10632	 1	 3.89	 2.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10633	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10634	 1	 2.1	 1.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10635	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10636	 1	 6.59	 3.92	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10637	 1	 4.31	 2.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10638	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10639	 1	 2.56	 1.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10640	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10641	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10642	 1	 4.62	 3.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10643	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10644	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10645	 1	 3.05	 2.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10646	 1	 5.24	 2.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10647	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10648	 1	 2.95	 0.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10649	 1	 6.8	 5.06	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10650	 1	 6.23	 3.36	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10651	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10652	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10653	 1	 7.26	 4.62	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10654	 1	 11.05	 6.57	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10655	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10656	 1	 4.43	 3.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10657	 1	 5.05	 3.05	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10658	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10659	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10660	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10661	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10662	 1	 8.76	 6.32	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10663	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10664	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10665	 1	 3.91	 2.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10666	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10667	 1	 6.74	 2.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10668	 1	 26.12	 6.62	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10669	 1	 12.58	 4.58	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10670	 1	 7.36	 3.13	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10671	 1	 18.65	 5.98	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10672	 1	 22.84	 7.19	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10673	 1	 7.4	 2.66	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10674	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10675	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10676	 1	 14.96	 3.2	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10677	 1	 9.38	 3.14	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10678	 1	 12.13	 2.82	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10679	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10680	 1	 2.74	 1.24	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10681	 1	 3.38	 1.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10682	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10683	 1	 12.06	 3.55	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10684	 1	 4.9	 1.32	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10685	 1	 8.71	 2.86	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10686	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10687	 1	 10.42	 4.01	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10688	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10689	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10690	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10691	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10692	 1	 8.08	 1.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10693	 1	 10.93	 2.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10694	 1	 8.75	 2.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10695	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10696	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10697	 1	 9.66	 2.8	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10698	 1	 4.11	 1.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10699	 1	 4.21	 1.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10700	 1	 2.5	 0.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10701	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10702	 1	 1.96	 0.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10703	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10704	 1	 3.83	 1.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10705	 1	 3.88	 1.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10706	 1	 6.23	 1.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10707	 1	 2.39	 1.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10708	 1	 11.36	 2.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10709	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10710	 1	 4.77	 1.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10711	 1	 7.25	 1.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10712	 1	 1.86	 0.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10713	 1	 2.35	 0.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10714	 1	 10.39	 2.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10715	 1	 13.17	 3.07	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10716	 1	 9.81	 2.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10717	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10718	 1	 1.93	 0.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10719	 1	 25.82	 5.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10720	 1	 7.94	 2.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10721	 1	 2.17	 0.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10722	 1	 2.28	 0.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10723	 1	 3.26	 1.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10724	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10725	 1	 4.07	 1.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10726	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10727	 1	 2.18	 0.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10728	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10729	 1	 1.53	 0.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10730	 1	 0.81	 0.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10731	 1	 6.05	 1.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10732	 1	 14.35	 2.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10733	 1	 1.77	 0.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10734	 1	 5.41	 1.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10735	 1	 4.52	 1.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10736	 1	 6.97	 1.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10737	 1	 4.78	 1.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10738	 1	 6.92	 2.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10739	 1	 2.5	 1.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10740	 1	 11.71	 3.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10741	 1	 5.82	 1.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10742	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10743	 1	 3.71	 1.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10744	 1	 16.88	 4.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10745	 1	 1.78	 0.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10746	 1	 1.26	 0.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10747	 1	 13.09	 3.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10748	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10749	 1	 3.11	 1.12	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10750	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10751	 1	 4.79	 1.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10752	 1	 12.1	 2.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10753	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10754	 1	 4.49	 1.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10755	 1	 3.47	 1.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10756	 1	 1.87	 0.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10757	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10758	 1	 3.17	 1.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10759	 1	 4.21	 1.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10760	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10761	 1	 7.21	 2.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10762	 1	 8.26	 2.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10763	 1	 15.99	 4.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10764	 1	 5.48	 1.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10765	 1	 5.72	 1.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10766	 1	 2.38	 1.02	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10767	 1	 14.66	 4.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10768	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10769	 1	 3.08	 1.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10770	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10771	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10772	 1	 1.01	 0.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10773	 1	 3.93	 0.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10774	 1	 2.34	 0.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10775	 1	 3.96	 1.33	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10776	 1	 1.62	 0.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10777	 1	 2.05	 0.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10778	 1	 2.59	 0.85	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10779	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10780	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10781	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10782	 1	 3.84	 1.34	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10783	 1	 5.03	 1.61	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10784	 1	 3.3	 0.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10785	 1	 4.07	 1.39	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10786	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10787	 1	 4.48	 1.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10788	 1	 1.36	 0.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10789	 1	 4.73	 1.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10790	 1	 9.18	 3.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10791	 1	 7.44	 2.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10792	 1	 5.09	 1.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10793	 1	 6.68	 2.34	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10794	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10795	 1	 2.54	 0.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10796	 1	 3.02	 0.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10797	 1	 1.53	 0.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10798	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10799	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10800	 1	 9.22	 2.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10801	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10802	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10803	 1	 21.59	 5.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10804	 1	 9.13	 2.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10805	 1	 2.44	 1.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10806	 1	 11.69	 3.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10807	 1	 10.02	 3.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10808	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10809	 1	 15.43	 4.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10810	 1	 27.7	 8.75	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10811	 1	 1.09	 0.51	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10812	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10813	 1	 8.91	 3.4	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10814	 1	 5.67	 2.42	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10815	 1	 23.16	 6.32	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10816	 1	 13.59	 3.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10817	 1	 2.89	 1.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10818	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10819	 1	 7.94	 2.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10820	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10821	 1	 10.49	 3.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10822	 1	 11.82	 3.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10823	 1	 16.69	 5.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10824	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10825	 1	 4.2	 1.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10826	 1	 19.05	 4.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10827	 1	 7.97	 2.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10828	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10829	 1	 4.6	 1.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10830	 1	 46.99	 12.28	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10831	 1	 13.73	 3.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10832	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10833	 1	 6.29	 2.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10834	 1	 7.76	 2.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10835	 1	 11.79	 2.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10836	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10837	 1	 8.02	 2.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10838	 1	 6.64	 2.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10839	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10840	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10841	 1	 6.36	 2.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10842	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10843	 1	 7.41	 2.41	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10844	 1	 6.39	 2.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10845	 1	 2.07	 0.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10846	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10847	 1	 14.75	 3.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10848	 1	 7.22	 2.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10849	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10850	 1	 6.85	 2.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10851	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10852	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10853	 1	 4.1	 1.44	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10854	 1	 7.03	 1.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10855	 1	 4.71	 1.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10856	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10857	 1	 4.75	 1.59	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10858	 1	 2.69	 0.87	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10859	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10860	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10861	 1	 3.43	 1.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10862	 1	 1.65	 0.74	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10863	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10864	 1	 19.14	 5.2	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10865	 1	 2.89	 1.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10866	 1	 17.13	 4.34	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10867	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10868	 1	 4.97	 1.67	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10869	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10870	 1	 3.37	 1.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10871	 1	 6.59	 2.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10872	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10873	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10874	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10875	 1	 3.33	 1.71	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10876	 1	 20.0	 6.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10877	 1	 50.34	 13.87	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10878	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10879	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10880	 1	 28.09	 6.68	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10881	 1	 4.57	 1.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10882	 1	 6.25	 1.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10883	 1	 18.53	 4.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10884	 1	 21.9	 6.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10885	 1	 4.09	 1.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10886	 1	 12.2	 2.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10887	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10888	 1	 6.88	 2.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10889	 1	 11.69	 3.43	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10890	 1	 55.89	 15.29	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10891	 1	 0.61	 0.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10892	 1	 7.85	 2.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10893	 1	 12.84	 3.32	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10894	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	10895	 1	 21.93	 4.59	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10896	 1	 10.37	 3.02	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10897	 1	 9.72	 2.98	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10898	 1	 4.01	 1.34	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10899	 1	 18.59	 4.14	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10900	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10901	 1	 5.39	 2.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10902	 1	 6.92	 1.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10903	 1	 3.31	 1.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10904	 1	 6.95	 1.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10905	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10906	 1	 6.87	 2.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10907	 1	 5.72	 1.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10908	 1	 11.49	 2.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10909	 1	 8.51	 2.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10910	 1	 9.3	 3.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10911	 1	 8.52	 1.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10912	 1	 8.56	 2.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10913	 1	 3.91	 1.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10914	 1	 2.79	 0.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10915	 1	 9.29	 2.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10916	 1	 7.61	 2.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10917	 1	 6.07	 1.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10918	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10919	 1	 5.75	 1.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10920	 1	 4.32	 1.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10921	 1	 10.78	 3.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10922	 1	 14.35	 3.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10923	 1	 12.09	 3.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10924	 1	 3.34	 1.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10925	 1	 21.37	 6.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10926	 1	 2.41	 1.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10927	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10928	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10929	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10930	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10931	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10932	 1	 17.11	 5.31	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10933	 1	 5.61	 1.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10934	 1	 7.58	 2.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10935	 1	 11.34	 3.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10936	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10937	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10938	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10939	 1	 4.77	 1.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10940	 1	 8.44	 2.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10941	 1	 8.47	 3.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10942	 1	 5.56	 2.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10943	 1	 18.11	 4.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10944	 1	 4.61	 1.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10945	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10946	 1	 4.49	 1.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10947	 1	 3.87	 1.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10948	 1	 3.17	 1.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10949	 1	 4.74	 1.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10950	 1	 4.54	 1.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10951	 1	 11.54	 3.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10952	 1	 5.01	 1.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10953	 1	 17.87	 3.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10954	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10955	 1	 8.77	 2.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10956	 1	 1.64	 0.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10957	 1	 4.14	 1.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10958	 1	 2.84	 0.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10959	 1	 3.12	 1.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10960	 1	 24.54	 4.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10961	 1	 2.14	 0.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10962	 1	 6.09	 2.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10963	 1	 13.97	 2.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10964	 1	 8.51	 2.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10965	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	10966	 1	 23.66	 5.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10967	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10968	 1	 23.71	 5.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10969	 1	 7.22	 2.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10970	 1	 6.95	 1.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10971	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10972	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10973	 1	 6.04	 1.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10974	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10975	 1	 7.4	 2.12	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10976	 1	 1.99	 0.88	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10977	 1	 5.53	 1.51	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10978	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10979	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10980	 1	 11.19	 3.59	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10981	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10982	 1	 6.29	 1.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10983	 1	 7.88	 2.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10984	 1	 3.3	 1.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10985	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10986	 1	 3.52	 1.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10987	 1	 2.1	 0.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10988	 1	 16.6	 4.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10989	 1	 9.47	 2.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10990	 1	 4.27	 1.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10991	 1	 7.88	 1.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10992	 1	 22.64	 5.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10993	 1	 6.28	 1.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10994	 1	 2.15	 0.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10995	 1	 7.03	 1.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10996	 1	 1.08	 0.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10997	 1	 37.61	 10.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10998	 1	 7.93	 2.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	10999	 1	 14.49	 3.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11000	 1	 1.97	 0.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11001	 1	 11.95	 2.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11002	 1	 17.52	 4.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11003	 1	 3.13	 1.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11004	 1	 3.9	 1.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11005	 1	 2.21	 0.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11006	 1	 4.99	 1.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11007	 1	 16.14	 4.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11008	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11009	 1	 10.96	 3.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11010	 1	 4.62	 1.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11011	 1	 19.91	 4.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11012	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11013	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11014	 1	 11.74	 3.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11015	 1	 4.08	 1.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11016	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11017	 1	 5.82	 1.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11018	 1	 5.96	 2.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11019	 1	 14.46	 4.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11020	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11021	 1	 21.41	 5.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11022	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11023	 1	 4.88	 1.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11024	 1	 6.45	 2.16	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11025	 1	 4.8	 1.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11026	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11027	 1	 4.55	 2.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11028	 1	 8.15	 2.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11029	 1	 3.05	 1.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11030	 1	 19.31	 3.88	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11031	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11032	 1	 18.91	 5.71	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11033	 1	 1.97	 0.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11034	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11035	 1	 13.08	 3.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11036	 1	 5.19	 2.21	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11037	 1	 14.08	 3.84	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11038	 1	 5.55	 1.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11039	 1	 5.43	 2.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11040	 1	 4.28	 1.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11041	 1	 17.92	 4.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11042	 1	 8.07	 2.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11043	 1	 2.26	 0.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11044	 1	 7.93	 2.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11045	 1	 2.95	 1.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11046	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11047	 1	 2.83	 0.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11048	 1	 2.02	 0.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11049	 1	 8.13	 1.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11050	 1	 9.27	 2.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11051	 1	 3.55	 1.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11052	 1	 3.31	 0.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11053	 1	 8.76	 3.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11054	 1	 4.29	 1.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11055	 1	 2.88	 0.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11056	 1	 1.59	 0.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11057	 1	 14.5	 3.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11058	 1	 17.97	 4.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11059	 1	 8.74	 2.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11060	 1	 8.75	 2.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11061	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11062	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11063	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11064	 1	 7.7	 2.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11065	 1	 14.29	 3.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11066	 1	 9.54	 2.83	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11067	 1	 6.4	 2.38	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11068	 1	 10.77	 2.6	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11069	 1	 3.42	 1.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11070	 1	 5.6	 2.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11071	 1	 6.52	 1.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11072	 1	 9.22	 2.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11073	 1	 1.97	 0.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11074	 1	 6.67	 1.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11075	 1	 16.26	 5.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11076	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11077	 1	 10.16	 2.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11078	 1	 0.02	 0.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11079	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11080	 1	 0.02	 0.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11081	 1	 0.03	 0.01	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11082	 1	 10.71	 2.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11083	 1	 0.48	 0.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11084	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11085	 1	 19.23	 4.16	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11086	 1	 2.88	 0.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11087	 1	 0.93	 0.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11088	 1	 1.58	 0.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11089	 1	 7.92	 2.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11090	 1	 5.3	 2.39	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11091	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11092	 1	 4.37	 1.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11093	 1	 7.6	 2.18	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11094	 1	 18.04	 5.39	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11095	 1	 7.62	 2.77	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11096	 1	 8.32	 2.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11097	 1	 7.06	 2.63	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11098	 1	 12.47	 3.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11099	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11100	 1	 11.8	 4.33	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11101	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11102	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11103	 1	 6.67	 2.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11104	 1	 4.8	 1.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11105	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11106	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11107	 1	 4.41	 1.73	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11108	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11109	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11110	 1	 3.9	 1.34	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11111	 1	 13.05	 4.43	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11112	 1	 3.63	 1.74	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11113	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11114	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11115	 1	 4.94	 1.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11116	 1	 3.12	 1.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11117	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11118	 1	 3.51	 1.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11119	 1	 13.39	 5.1	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11120	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11121	 1	 2.37	 1.17	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11122	 1	 3.45	 1.3	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11123	 1	 24.38	 6.81	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11124	 1	 4.35	 2.09	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11125	 1	 7.89	 2.93	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11126	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11127	 1	 3.56	 1.74	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11128	 1	 14.27	 3.29	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11129	 1	 9.57	 2.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11130	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11131	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11132	 1	 7.0	 2.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11133	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11134	 1	 8.7	 2.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11135	 1	 3.63	 1.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11136	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11137	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11138	 1	 2.8	 1.16	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11139	 1	 4.05	 1.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11140	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11141	 1	 3.41	 1.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11142	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11143	 1	 9.08	 2.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11144	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11145	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11146	 1	 1.84	 0.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11147	 1	 4.79	 2.05	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11148	 1	 4.1	 1.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11149	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11150	 1	 3.47	 1.44	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11151	 1	 4.0	 1.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11152	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11153	 1	 4.96	 1.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11154	 1	 23.05	 5.7	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11155	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11156	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11157	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11158	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11159	 1	 12.58	 3.54	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11160	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11161	 1	 6.3	 2.04	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11162	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11163	 1	 6.63	 2.62	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11164	 1	 11.49	 3.59	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11165	 1	 8.59	 2.8	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11166	 1	 11.72	 3.11	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11167	 1	 70.54	 16.13	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11168	 1	 10.21	 2.99	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11169	 1	 26.39	 6.18	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11170	 1	 4.97	 1.96	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11171	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11172	 1	 13.9	 4.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11173	 1	 18.9	 4.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11174	 1	 22.48	 6.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11175	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11176	 1	 4.17	 1.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11177	 1	 4.81	 2.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11178	 1	 4.32	 1.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11179	 1	 2.62	 1.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11180	 1	 3.01	 1.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11181	 1	 4.34	 1.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11182	 1	 1.61	 0.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11183	 1	 8.38	 2.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11184	 1	 10.5	 3.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11185	 1	 3.69	 1.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11186	 1	 2.48	 1.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11187	 1	 7.46	 2.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11188	 1	 2.67	 1.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11189	 1	 2.82	 1.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11190	 1	 15.49	 4.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11191	 1	 2.58	 1.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11192	 1	 9.46	 2.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11193	 1	 13.03	 3.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11194	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11195	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11196	 1	 10.87	 2.59	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11197	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11198	 1	 18.34	 5.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11199	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11200	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11201	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11202	 1	 10.1	 2.86	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11203	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11204	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11205	 1	 17.25	 6.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11206	 1	 12.37	 4.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11207	 1	 19.16	 6.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11208	 1	 1.79	 0.78	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11209	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11210	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11211	 1	 10.47	 3.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11212	 1	 3.81	 1.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11213	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11214	 1	 6.1	 2.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11215	 1	 14.72	 4.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11216	 1	 6.22	 2.84	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11217	 1	 13.57	 4.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11218	 1	 5.89	 2.2	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11219	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11220	 1	 5.24	 1.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11221	 1	 8.8	 3.22	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11222	 1	 9.67	 3.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11223	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11224	 1	 21.87	 6.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11225	 1	 4.25	 1.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11226	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11227	 1	 6.39	 2.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11228	 1	 3.94	 1.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11229	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11230	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11231	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11232	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11233	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11234	 1	 3.3	 1.39	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11235	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11236	 1	 10.27	 4.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11237	 1	 5.67	 1.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11238	 1	 5.73	 2.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11239	 1	 22.32	 5.87	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11240	 1	 30.82	 8.37	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11241	 1	 6.27	 2.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11242	 1	 27.68	 10.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11243	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11244	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11245	 1	 16.38	 5.39	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11246	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11247	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11248	 1	 4.85	 1.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11249	 1	 21.16	 5.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11250	 1	 9.85	 3.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11251	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11252	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11253	 1	 10.22	 3.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11254	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11255	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11256	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11257	 1	 12.72	 4.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11258	 1	 22.44	 5.37	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11259	 1	 14.1	 5.43	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11260	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11261	 1	 9.2	 3.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11262	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11263	 1	 72.1	 17.22	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11264	 1	 1.7	 0.8	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11265	 1	 13.61	 3.66	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11266	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11267	 1	 3.88	 1.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11268	 1	 31.83	 7.51	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11269	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11270	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11271	 1	 5.08	 2.29	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11272	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11273	 1	 12.01	 3.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11274	 1	 13.76	 4.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11275	 1	 13.55	 3.76	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11276	 1	 21.76	 4.15	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11277	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11278	 1	 20.06	 6.31	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11279	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11280	 1	 9.05	 2.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11281	 1	 3.02	 1.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11282	 1	 3.48	 1.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11283	 1	 3.06	 1.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11284	 1	 16.52	 3.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11285	 1	 3.16	 1.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11286	 1	 6.25	 2.13	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11287	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11288	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11289	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11290	 1	 7.25	 2.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11291	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11292	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11293	 1	 12.42	 2.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11294	 1	 5.86	 1.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11295	 1	 6.03	 1.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11296	 1	 6.24	 1.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11297	 1	 21.27	 4.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11298	 1	 18.06	 4.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11299	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11300	 1	 5.02	 1.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11301	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11302	 1	 5.74	 1.33	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11303	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	11304	 1	 3.63	 1.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11305	 1	 36.14	 9.73	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11306	 1	 5.81	 2.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11307	 1	 7.89	 1.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11308	 1	 6.83	 1.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11309	 1	 38.02	 10.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11310	 1	 10.51	 2.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11311	 1	 4.17	 1.72	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11312	 1	 9.5	 2.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11313	 1	 23.73	 5.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11314	 1	 19.22	 4.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11315	 1	 11.88	 3.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11316	 1	 33.45	 9.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11317	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11318	 1	 13.42	 4.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11319	 1	 8.07	 3.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11320	 1	 6.71	 2.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11321	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11322	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11323	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11324	 1	 3.2	 1.53	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11325	 1	 5.35	 2.19	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11326	 1	 17.01	 5.37	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11327	 1	 12.56	 4.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11328	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11329	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11330	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11331	 1	 1.21	 0.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11332	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11333	 1	 7.31	 2.4	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11334	 1	 4.96	 2.13	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11335	 1	 9.04	 2.38	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11336	 1	 10.12	 3.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11337	 1	 3.62	 1.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11338	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11339	 1	 18.5	 5.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11340	 1	 11.32	 3.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11341	 1	 7.88	 3.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11342	 1	 4.22	 2.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11343	 1	 25.88	 7.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11344	 1	 6.07	 1.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11345	 1	 21.1	 5.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11346	 1	 6.31	 2.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11347	 1	 11.32	 2.98	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11348	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11349	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11350	 1	 4.46	 1.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11351	 1	 3.09	 1.27	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11352	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11353	 1	 9.18	 2.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11354	 1	 7.38	 1.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11355	 1	 9.37	 3.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11356	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11357	 1	 9.85	 2.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11358	 1	 12.38	 4.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11359	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11360	 1	 20.99	 6.91	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11361	 1	 2.14	 0.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11362	 1	 3.77	 1.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11363	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11364	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11365	 1	 3.22	 1.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11366	 1	 35.75	 7.98	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11367	 1	 5.47	 2.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11368	 1	 4.28	 1.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11369	 1	 31.26	 9.42	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11370	 1	 11.05	 4.06	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11371	 1	 13.94	 4.98	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11372	 1	 16.22	 5.55	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11373	 1	 27.18	 7.89	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11374	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11375	 1	 32.94	 8.49	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11376	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11377	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11378	 1	 14.93	 3.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11379	 1	 21.55	 5.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11380	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11381	 1	 5.82	 2.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11382	 1	 8.25	 2.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11383	 1	 1.18	 0.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11384	 1	 5.55	 1.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11385	 1	 8.4	 3.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11386	 1	 7.64	 2.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11387	 1	 5.81	 1.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11388	 1	 13.69	 3.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11389	 1	 9.06	 2.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11390	 1	 3.16	 1.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11391	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11392	 1	 1.85	 0.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11393	 1	 6.72	 2.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11394	 1	 8.52	 3.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11395	 1	 10.28	 3.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11396	 1	 5.97	 2.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11397	 1	 2.37	 0.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11398	 1	 9.6	 3.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11399	 1	 6.7	 2.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11400	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11401	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11402	 1	 4.41	 1.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11403	 1	 6.55	 2.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11404	 1	 5.68	 1.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11405	 1	 10.11	 3.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11406	 1	 8.8	 3.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11407	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11408	 1	 5.65	 2.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11409	 1	 9.04	 2.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11410	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11411	 1	 3.25	 1.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11412	 1	 5.1	 1.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11413	 1	 3.3	 1.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11414	 1	 6.28	 1.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11415	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11416	 1	 3.81	 1.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11417	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11418	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11419	 1	 4.49	 2.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11420	 1	 4.43	 1.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11421	 1	 2.65	 1.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11422	 1	 7.38	 1.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11423	 1	 7.6	 3.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11424	 1	 3.69	 1.83	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11425	 1	 5.48	 2.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11426	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11427	 1	 3.44	 1.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11428	 1	 4.21	 1.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11429	 1	 4.87	 1.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11430	 1	 3.89	 1.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11431	 1	 3.41	 1.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11432	 1	 8.08	 2.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11433	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11434	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11435	 1	 95.62	 23.39	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11436	 1	 3.2	 1.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11437	 1	 9.58	 2.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11438	 1	 19.21	 6.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11439	 1	 5.6	 1.59	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11440	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11441	 1	 1.84	 0.7	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11442	 1	 13.01	 2.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11443	 1	 3.94	 1.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11444	 1	 3.3	 1.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11445	 1	 28.81	 9.41	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11446	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11447	 1	 17.12	 6.05	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11448	 1	 18.64	 6.64	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11449	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11450	 1	 1.87	 0.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11451	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11452	 1	 2.12	 1.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11453	 1	 2.29	 0.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11454	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11455	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11456	 1	 6.87	 1.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11457	 1	 11.53	 3.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11458	 1	 1.95	 0.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11459	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11460	 1	 7.68	 2.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11461	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11462	 1	 3.56	 1.22	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11463	 1	 98.29	 18.14	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11464	 1	 5.92	 2.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11465	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11466	 1	 7.19	 1.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11467	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11468	 1	 1.76	 0.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11469	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11470	 1	 3.23	 1.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11471	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11472	 1	 6.99	 2.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11473	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11474	 1	 7.35	 2.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11475	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11476	 1	 6.3	 2.5	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11477	 1	 23.1	 7.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11478	 1	 13.48	 5.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11479	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11480	 1	 6.55	 2.31	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11481	 1	 35.8	 7.24	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11482	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11483	 1	 15.95	 3.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11484	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11485	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11486	 1	 3.68	 1.67	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11487	 1	 3.16	 1.18	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11488	 1	 10.65	 2.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11489	 1	 12.11	 3.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11490	 1	 4.98	 1.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11491	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11492	 1	 14.71	 4.96	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11493	 1	 42.09	 10.24	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11494	 1	 12.86	 4.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11495	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11496	 1	 9.19	 2.75	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11497	 1	 1.58	 0.52	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11498	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11499	 1	 2.72	 0.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11500	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11501	 1	 13.3	 3.49	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11502	 1	 5.75	 2.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11503	 1	 11.28	 3.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11504	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11505	 1	 3.55	 1.31	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11506	 1	 4.47	 1.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11507	 1	 2.86	 1.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11508	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11509	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11510	 1	 3.58	 1.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11511	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11512	 1	 3.96	 1.22	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11513	 1	 5.27	 2.59	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11514	 1	 10.33	 2.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11515	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11516	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11517	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11518	 1	 10.1	 3.5	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11519	 1	 13.69	 4.2	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11520	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11521	 1	 2.51	 1.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11522	 1	 7.02	 2.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11523	 1	 5.37	 2.2	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11524	 1	 5.71	 2.18	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11525	 1	 29.57	 9.9	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11526	 1	 8.63	 2.52	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11527	 1	 4.33	 1.65	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11528	 1	 24.76	 6.33	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11529	 1	 6.71	 2.35	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11530	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11531	 1	 2.5	 1.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11532	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11533	 1	 8.99	 3.26	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11534	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11535	 1	 4.25	 1.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11536	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11537	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11538	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11539	 1	 8.42	 1.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11540	 1	 6.28	 2.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11541	 1	 3.37	 1.48	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11542	 1	 5.52	 2.25	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11543	 1	 2.09	 0.87	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11544	 1	 23.37	 8.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11545	 1	 30.01	 10.45	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11546	 1	 10.08	 2.79	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11547	 1	 15.87	 5.8	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11548	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11549	 1	 6.44	 2.51	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11550	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11551	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11552	 1	 5.02	 1.68	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11553	 1	 7.67	 2.61	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11554	 1	 7.78	 2.44	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11555	 1	 7.47	 2.01	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11556	 1	 5.85	 2.32	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11557	 1	 9.33	 3.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11558	 1	 8.24	 2.56	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11559	 1	 12.47	 4.02	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11560	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11561	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11562	 1	 14.01	 4.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11563	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11564	 1	 15.19	 4.49	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11565	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11566	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11567	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11568	 1	 18.18	 5.33	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11569	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11570	 1	 5.44	 2.21	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11571	 1	 2.48	 0.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11572	 1	 14.74	 4.53	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11573	 1	 7.34	 2.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11574	 1	 6.41	 2.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11575	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11576	 1	 2.17	 0.82	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11577	 1	 6.28	 2.03	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11578	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11579	 1	 6.89	 1.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11580	 1	 3.84	 1.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11581	 1	 4.53	 2.09	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11582	 1	 5.54	 1.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11583	 1	 5.53	 1.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11584	 1	 12.0	 3.21	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11585	 1	 22.27	 5.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11586	 1	 12.77	 3.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11587	 1	 8.74	 3.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11588	 1	 18.31	 6.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11589	 1	 3.36	 1.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11590	 1	 19.51	 4.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11591	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11592	 1	 3.86	 1.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11593	 1	 3.44	 1.39	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11594	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11595	 1	 5.54	 2.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11596	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11597	 1	 8.9	 2.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11598	 1	 5.82	 2.58	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11599	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11600	 1	 11.62	 3.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11601	 1	 4.57	 1.54	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11602	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11603	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11604	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11605	 1	 9.04	 3.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11606	 1	 14.35	 4.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11607	 1	 2.42	 1.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11608	 1	 2.33	 0.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11609	 1	 2.13	 0.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11610	 1	 5.16	 2.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11611	 1	 3.96	 1.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11612	 1	 13.2	 3.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11613	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	11614	 1	 7.72	 2.67	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11615	 1	 67.34	 16.78	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11616	 1	 6.76	 2.78	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11617	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11618	 1	 4.09	 1.6	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11619	 1	 6.03	 2.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11620	 1	 4.36	 1.88	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11621	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11622	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11623	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11624	 1	 6.09	 2.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11625	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11626	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11627	 1	 11.5	 3.96	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11628	 1	 1.81	 0.89	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11629	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11630	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11631	 1	 7.2	 2.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11632	 1	 9.52	 3.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11633	 1	 11.32	 3.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11634	 1	 5.98	 2.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11635	 1	 7.02	 1.96	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11636	 1	 7.59	 2.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11637	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11638	 1	 5.94	 1.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11639	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11640	 1	 3.74	 1.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11641	 1	 6.86	 2.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11642	 1	 13.12	 3.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11643	 1	 4.31	 1.99	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11644	 1	 9.06	 3.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11645	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11646	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11647	 1	 4.14	 1.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11648	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11649	 1	 8.78	 3.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11650	 1	 32.71	 9.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11651	 1	 15.67	 4.37	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11652	 1	 7.93	 3.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11653	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11654	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11655	 1	 9.7	 2.63	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11656	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11657	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11658	 1	 1.59	 0.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11659	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11660	 1	 7.14	 2.37	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11661	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11662	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11663	 1	 5.46	 2.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11664	 1	 6.18	 1.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11665	 1	 2.91	 1.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11666	 1	 8.4	 3.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11667	 1	 2.65	 1.12	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11668	 1	 6.26	 2.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11669	 1	 5.44	 1.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11670	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11671	 1	 3.83	 1.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11672	 1	 4.04	 1.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11673	 1	 2.02	 0.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11674	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11675	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11676	 1	 5.68	 1.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11677	 1	 1.18	 0.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11678	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11679	 1	 8.17	 2.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11680	 1	 12.35	 3.83	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11681	 1	 2.53	 0.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11682	 1	 10.23	 3.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11683	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11684	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11685	 1	 7.7	 2.49	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11686	 1	 5.86	 2.08	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11687	 1	 5.92	 2.34	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11688	 1	 15.53	 5.1	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11689	 1	 6.57	 2.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11690	 1	 2.18	 0.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11691	 1	 8.83	 2.9	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11692	 1	 26.66	 7.74	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11693	 1	 3.83	 1.4	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11694	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11695	 1	 10.71	 2.61	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11696	 1	 13.06	 2.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11697	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11698	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11699	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11700	 1	 8.84	 2.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11701	 1	 11.81	 3.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11702	 1	 30.24	 7.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11703	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11704	 1	 7.23	 2.38	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11705	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11706	 1	 6.84	 2.72	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11707	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11708	 1	 6.79	 2.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11709	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11710	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11711	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11712	 1	 7.38	 2.96	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11713	 1	 15.52	 4.53	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11714	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11715	 1	 10.29	 2.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11716	 1	 8.13	 3.16	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11717	 1	 15.99	 5.77	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11718	 1	 7.72	 3.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11719	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11720	 1	 5.21	 1.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11721	 1	 9.98	 2.87	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11722	 1	 4.24	 1.81	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11723	 1	 16.5	 4.88	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11724	 1	 2.72	 1.06	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11725	 1	 3.04	 1.24	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11726	 1	 12.83	 4.39	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11727	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11728	 1	 4.73	 1.62	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11729	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11730	 1	 65.75	 15.66	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11731	 1	 7.63	 1.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11732	 1	 10.21	 2.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11733	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11734	 1	 11.51	 2.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11735	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11736	 1	 11.28	 2.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11737	 1	 3.64	 0.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11738	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11739	 1	 8.6	 3.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11740	 1	 11.73	 3.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11741	 1	 5.51	 1.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11742	 1	 10.5	 2.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11743	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11744	 1	 14.88	 4.14	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11745	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11746	 1	 17.97	 4.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11747	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11748	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11749	 1	 12.55	 2.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11750	 1	 5.88	 1.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11751	 1	 2.86	 1.28	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11752	 1	 6.07	 2.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11753	 1	 10.72	 2.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11754	 1	 4.75	 1.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11755	 1	 14.01	 3.99	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11756	 1	 6.63	 1.49	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11757	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11758	 1	 2.99	 0.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11759	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11760	 1	 7.2	 -4.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11761	 1	 32.49	 7.34	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11762	 1	 6.64	 2.26	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11763	 1	 5.17	 1.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11764	 1	 11.29	 2.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11765	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11766	 1	 9.75	 2.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11767	 1	 15.81	 3.65	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11768	 1	 13.27	 3.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11769	 1	 10.44	 2.35	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11770	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11771	 1	 10.33	 2.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11772	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11773	 1	 17.17	 3.85	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11774	 1	 4.66	 1.05	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11775	 1	 2.58	 0.58	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11776	 1	 17.33	 4.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11777	 1	 4.79	 2.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11778	 1	 7.56	 2.25	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11779	 1	 5.24	 2.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11780	 1	 4.3	 1.6	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11781	 1	 6.7	 2.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11782	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11783	 1	 19.28	 5.17	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11784	 1	 3.72	 1.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11785	 1	 7.17	 2.69	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11786	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11787	 1	 3.84	 1.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11788	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11789	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11790	 1	 1.46	 0.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11791	 1	 5.53	 2.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11792	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11793	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11794	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11795	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	11796	 1	 19.69	 5.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11797	 1	 8.51	 3.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11798	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11799	 1	 3.65	 1.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11800	 1	 9.62	 3.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11801	 1	 13.57	 4.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11802	 1	 23.96	 6.22	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11803	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11804	 1	 45.29	 12.05	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11805	 1	 6.73	 2.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11806	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11807	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11808	 1	 12.73	 3.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11809	 1	 6.16	 1.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11810	 1	 6.63	 1.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11811	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11812	 1	 23.94	 6.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11813	 1	 9.02	 2.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11814	 1	 43.71	 14.16	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11815	 1	 6.69	 2.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11816	 1	 6.46	 2.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11817	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11818	 1	 1.68	 0.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11819	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11820	 1	 21.33	 6.04	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11821	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11822	 1	 21.46	 7.29	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11823	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11824	 1	 3.22	 1.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11825	 1	 24.64	 7.66	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11826	 1	 5.29	 1.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11827	 1	 1.5	 0.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11828	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11829	 1	 1.53	 0.58	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11830	 1	 5.99	 1.68	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11831	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11832	 1	 14.05	 4.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11833	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11834	 1	 2.7	 1.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11835	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11836	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11837	 1	 7.12	 2.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11838	 1	 4.81	 1.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11839	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11840	 1	 3.05	 1.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11841	 1	 6.62	 2.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11842	 1	 12.9	 4.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11843	 1	 6.27	 2.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11844	 1	 9.65	 2.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11845	 1	 10.97	 3.37	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11846	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11847	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11848	 1	 3.9	 1.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11849	 1	 15.85	 5.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11850	 1	 6.68	 2.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11851	 1	 18.6	 5.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11852	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11853	 1	 5.63	 2.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11854	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11855	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11856	 1	 4.97	 2.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11857	 1	 4.14	 1.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11858	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11859	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11860	 1	 4.68	 1.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11861	 1	 4.21	 1.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11862	 1	 5.7	 2.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11863	 1	 28.41	 6.99	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11864	 1	 5.32	 2.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11865	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11866	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11867	 1	 1.42	 0.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11868	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11869	 1	 7.09	 2.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11870	 1	 11.91	 3.51	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11871	 1	 2.78	 1.28	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11872	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11873	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11874	 1	 5.64	 2.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11875	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11876	 1	 7.2	 1.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11877	 1	 7.33	 2.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11878	 1	 5.13	 2.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11879	 1	 15.89	 4.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11880	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11881	 1	 27.08	 8.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11882	 1	 6.95	 2.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11883	 1	 19.92	 5.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11884	 1	 2.89	 0.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11885	 1	 13.11	 3.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11886	 1	 5.96	 2.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11887	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11888	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11889	 1	 10.64	 2.36	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11890	 1	 12.64	 4.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11891	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11892	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11893	 1	 5.2	 1.97	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11894	 1	 6.81	 2.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11895	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11896	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11897	 1	 6.58	 2.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11898	 1	 7.5	 2.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11899	 1	 1.47	 0.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11900	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11901	 1	 3.17	 1.22	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11902	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11903	 1	 3.84	 1.72	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11904	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11905	 1	 1.5	 0.63	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11906	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11907	 1	 2.08	 0.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11908	 1	 7.46	 2.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11909	 1	 4.6	 1.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11910	 1	 11.93	 4.21	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11911	 1	 1.69	 0.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11912	 1	 2.48	 1.18	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11913	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11914	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11915	 1	 5.38	 1.56	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11916	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11917	 1	 9.26	 2.6	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11918	 1	 3.08	 1.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11919	 1	 3.32	 1.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11920	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11921	 1	 4.99	 1.71	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11922	 1	 2.82	 1.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11923	 1	 8.28	 3.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11924	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11925	 1	 2.79	 1.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11926	 1	 2.59	 1.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11927	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11928	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11929	 1	 3.35	 1.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11930	 1	 4.2	 1.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11931	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11932	 1	 4.65	 1.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11933	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	11934	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11935	 1	 8.19	 2.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11936	 1	 3.79	 1.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11937	 1	 1.79	 0.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11938	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	11939	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	11940	 1	 5.88	 1.51	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11941	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11942	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11943	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11944	 1	 11.78	 4.55	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11945	 1	 13.15	 4.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11946	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11947	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	11948	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	11949	 1	 1.5	 0.63	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11950	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11951	 1	 2.31	 1.11	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11952	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11953	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	11954	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	11955	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11956	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11957	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	11958	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	11959	 1	 3.17	 1.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11960	 1	 2.16	 1.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11961	 1	 9.84	 3.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11962	 1	 5.53	 2.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11963	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	11964	 1	 2.65	 1.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11965	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11966	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	11967	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	11968	 1	 27.12	 6.79	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11969	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11970	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11971	 1	 8.44	 3.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11972	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11973	 1	 9.04	 3.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11974	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11975	 1	 2.81	 1.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11976	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11977	 1	 3.05	 1.35	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11978	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11979	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11980	 1	 10.67	 3.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11981	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11982	 1	 6.77	 2.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11983	 1	 22.33	 5.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11984	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11985	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11986	 1	 5.54	 2.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11987	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11988	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11989	 1	 4.18	 1.74	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11990	 1	 2.03	 0.83	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11991	 1	 3.1	 1.16	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11992	 1	 5.04	 1.99	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11993	 1	 5.55	 1.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11994	 1	 3.42	 1.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11995	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11996	 1	 3.8	 1.77	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11997	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11998	 1	 5.93	 1.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	11999	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12000	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12001	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12002	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12003	 1	 4.44	 1.86	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12004	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12005	 1	 6.28	 2.31	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12006	 1	 2.95	 1.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12007	 1	 5.06	 2.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12008	 1	 3.88	 1.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12009	 1	 7.21	 2.52	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12010	 1	 2.65	 1.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12011	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12012	 1	 4.21	 1.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12013	 1	 8.17	 2.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12014	 1	 4.65	 1.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12015	 1	 10.23	 3.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12016	 1	 12.6	 3.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12017	 1	 15.27	 4.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12018	 1	 21.94	 7.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12019	 1	 10.92	 3.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12020	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12021	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12022	 1	 4.16	 1.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12023	 1	 8.83	 3.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12024	 1	 15.12	 3.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12025	 1	 21.47	 5.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12026	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12027	 1	 18.5	 7.25	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12028	 1	 5.63	 2.6	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12029	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12030	 1	 6.14	 2.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12031	 1	 78.92	 18.39	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12032	 1	 7.28	 3.33	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12033	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12034	 1	 4.73	 1.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12035	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12036	 1	 16.17	 4.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12037	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12038	 1	 7.18	 1.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12039	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12040	 1	 45.61	 13.93	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12041	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12042	 1	 27.74	 6.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12043	 1	 5.82	 1.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12044	 1	 9.42	 2.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12045	 1	 7.13	 2.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12046	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12047	 1	 4.3	 0.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12048	 1	 18.75	 4.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12049	 1	 3.23	 0.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12050	 1	 5.31	 1.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12051	 1	 5.06	 2.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12052	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12053	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	12054	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12055	 1	 8.31	 1.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12056	 1	 2.61	 0.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12057	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12058	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12059	 1	 3.02	 0.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12060	 1	 2.8	 0.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12061	 1	 4.74	 1.27	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12062	 1	 5.73	 1.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12063	 1	 4.54	 1.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12064	 1	 6.34	 1.95	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12065	 1	 2.97	 1.33	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12066	 1	 3.84	 1.64	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12067	 1	 4.63	 1.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12068	 1	 4.96	 1.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12069	 1	 17.81	 3.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12070	 1	 10.84	 2.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12071	 1	 9.08	 2.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12072	 1	 10.74	 3.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12073	 1	 3.64	 0.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12074	 1	 2.85	 0.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12075	 1	 3.3	 0.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12076	 1	 3.01	 0.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12077	 1	 18.21	 4.13	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12078	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12079	 1	 6.75	 1.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12080	 1	 35.46	 8.13	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12081	 1	 6.04	 1.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12082	 1	 10.46	 2.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12083	 1	 10.27	 2.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12084	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12085	 1	 25.59	 7.2	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12086	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12087	 1	 7.62	 1.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12088	 1	 4.5	 1.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12089	 1	 7.71	 2.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12090	 1	 15.47	 3.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12091	 1	 5.47	 1.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12092	 1	 13.4	 3.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12093	 1	 7.35	 1.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12094	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12095	 1	 5.62	 1.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12096	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12097	 1	 7.93	 1.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12098	 1	 3.12	 0.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12099	 1	 9.57	 2.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12100	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12101	 1	 16.11	 4.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12102	 1	 7.05	 1.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12103	 1	 3.66	 0.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12104	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12105	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12106	 1	 5.63	 1.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12107	 1	 28.19	 6.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12108	 1	 11.94	 2.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12109	 1	 11.96	 2.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12110	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12111	 1	 11.37	 2.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12112	 1	 16.38	 3.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12113	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12114	 1	 5.42	 2.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12115	 1	 4.48	 1.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12116	 1	 9.49	 3.3	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12117	 1	 5.44	 1.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12118	 1	 6.08	 1.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12119	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12120	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12121	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12122	 1	 7.51	 2.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12123	 1	 7.57	 2.3	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12124	 1	 2.35	 1.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12125	 1	 9.37	 2.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12126	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12127	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12128	 1	 2.34	 1.13	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12129	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12130	 1	 6.2	 2.18	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12131	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12132	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12133	 1	 7.27	 2.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12134	 1	 7.14	 2.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12135	 1	 11.7	 3.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12136	 1	 4.18	 1.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12137	 1	 6.63	 1.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12138	 1	 4.6	 1.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12139	 1	 4.04	 1.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12140	 1	 17.6	 4.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12141	 1	 4.39	 1.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12142	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12143	 1	 4.75	 1.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12144	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12145	 1	 13.94	 3.96	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12146	 1	 5.85	 2.11	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12147	 1	 6.6	 3.22	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12148	 1	 3.32	 1.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12149	 1	 1.51	 0.66	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12150	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12151	 1	 2.05	 0.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12152	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12153	 1	 4.56	 1.89	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12154	 1	 4.61	 2.08	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12155	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12156	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	12157	 1	 18.64	 5.63	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12158	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12159	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12160	 1	 22.09	 5.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12161	 1	 19.51	 5.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12162	 1	 15.69	 4.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12163	 1	 14.16	 4.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12164	 1	 3.67	 1.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12165	 1	 13.25	 3.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12166	 1	 5.96	 2.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12167	 1	 11.47	 3.25	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12168	 1	 18.63	 5.89	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12169	 1	 12.35	 4.08	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12170	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12171	 1	 14.38	 4.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12172	 1	 17.94	 4.4	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12173	 1	 15.45	 5.08	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12174	 1	 4.42	 1.66	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12175	 1	 3.27	 1.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12176	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12177	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12178	 1	 13.04	 4.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12179	 1	 6.68	 2.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12180	 1	 31.78	 7.69	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12181	 1	 6.62	 2.45	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12182	 1	 10.72	 3.54	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12183	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	12184	 1	 6.32	 1.93	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	12185	 1	 4.39	 1.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12186	 1	 15.26	 4.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12187	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12188	 1	 14.96	 4.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12189	 1	 5.95	 2.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12190	 1	 12.52	 3.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12191	 1	 4.82	 2.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12192	 1	 3.39	 1.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12193	 1	 3.32	 1.55	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12194	 1	 24.2	 7.77	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12195	 1	 32.38	 8.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12196	 1	 10.39	 3.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12197	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12198	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12199	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12200	 1	 14.17	 3.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12201	 1	 4.55	 1.59	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12202	 1	 4.8	 1.87	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12203	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12204	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12205	 1	 9.32	 3.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12206	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12207	 1	 13.8	 4.3	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12208	 1	 7.12	 2.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12209	 1	 5.79	 2.39	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12210	 1	 16.52	 5.69	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12211	 1	 16.5	 5.77	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12212	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12213	 1	 11.11	 3.57	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12214	 1	 18.64	 6.12	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12215	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12216	 1	 6.51	 1.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12217	 1	 5.89	 2.54	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12218	 1	 3.35	 1.35	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12219	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	12220	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12221	 1	 10.63	 2.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12222	 1	 1.65	 0.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12223	 1	 11.67	 3.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12224	 1	 9.36	 3.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12225	 1	 11.55	 3.88	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12226	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12227	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12228	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12229	 1	 37.49	 10.71	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12230	 1	 8.79	 2.14	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12231	 1	 12.31	 2.87	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12232	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12233	 1	 9.33	 3.17	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	12234	 1	 5.8	 2.16	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	12235	 1	 4.93	 2.26	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12236	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	12237	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12238	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12239	 1	 7.19	 2.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12240	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12241	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	12242	 1	 13.42	 2.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12243	 1	 19.07	 4.04	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12244	 1	 4.04	 1.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12245	 1	 15.45	 3.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12246	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12247	 1	 6.15	 1.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12248	 1	 2.18	 0.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12249	 1	 23.77	 5.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12250	 1	 3.56	 0.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12251	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12252	 1	 4.05	 0.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12253	 1	 3.09	 0.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12254	 1	 11.07	 2.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12255	 1	 2.95	 0.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12256	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12257	 1	 2.34	 0.53	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12258	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12259	 1	 14.42	 3.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12260	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12261	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12262	 1	 2.26	 0.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12263	 1	 5.38	 1.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12264	 1	 4.43	 1.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12265	 1	 13.18	 3.02	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12266	 1	 3.18	 0.72	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12267	 1	 7.84	 1.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12268	 1	 3.3	 0.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12269	 1	 6.16	 1.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12270	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12271	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12272	 1	 4.79	 1.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12273	 1	 5.8	 1.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12274	 1	 8.81	 2.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12275	 1	 3.74	 0.86	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12276	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12277	 1	 6.5	 1.49	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12278	 1	 14.83	 3.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12279	 1	 15.52	 3.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12280	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	12281	 1	 11.95	 2.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12282	 1	 5.61	 1.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12283	 1	 5.75	 1.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12284	 1	 4.77	 1.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12285	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12286	 1	 9.77	 2.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12287	 1	 11.0	 2.57	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12288	 1	 12.36	 2.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12289	 1	 5.76	 1.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12290	 1	 10.46	 2.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12291	 1	 13.68	 3.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12292	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12293	 1	 23.21	 5.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12294	 1	 12.79	 2.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12295	 1	 3.78	 0.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12296	 1	 13.02	 2.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12297	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12298	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12299	 1	 9.9	 2.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12300	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12301	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12302	 1	 5.26	 1.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12303	 1	 8.96	 2.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12304	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12305	 1	 11.33	 3.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12306	 1	 6.6	 2.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12307	 1	 15.4	 3.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12308	 1	 5.08	 1.98	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12309	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12310	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12311	 1	 9.73	 3.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12312	 1	 3.72	 1.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12313	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12314	 1	 3.82	 1.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12315	 1	 6.43	 2.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12316	 1	 7.0	 2.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12317	 1	 11.81	 3.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12318	 1	 7.49	 2.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12319	 1	 6.27	 2.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12320	 1	 5.26	 1.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12321	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12322	 1	 21.84	 5.97	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12323	 1	 10.44	 3.15	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12324	 1	 16.13	 4.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12325	 1	 28.91	 7.22	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12326	 1	 8.9	 3.32	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12327	 1	 28.72	 8.55	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12328	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12329	 1	 8.72	 2.63	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12330	 1	 57.23	 13.79	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12331	 1	 16.97	 3.65	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12332	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12333	 1	 15.11	 4.07	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12334	 1	 7.86	 2.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12335	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12336	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12337	 1	 19.59	 4.67	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12338	 1	 10.17	 4.1	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12339	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12340	 1	 66.4	 13.47	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12341	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12342	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12343	 1	 5.48	 2.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12344	 1	 2.81	 1.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12345	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12346	 1	 11.3	 4.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12347	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12348	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12349	 1	 8.3	 2.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12350	 1	 13.32	 3.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12351	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12352	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12353	 1	 14.31	 4.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12354	 1	 9.21	 2.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12355	 1	 9.77	 3.69	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12356	 1	 13.94	 4.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12357	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12358	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12359	 1	 3.96	 1.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12360	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12361	 1	 24.12	 7.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12362	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12363	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12364	 1	 21.35	 6.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12365	 1	 7.63	 2.48	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12366	 1	 40.26	 13.14	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12367	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12368	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12369	 1	 31.07	 8.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12370	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12371	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12372	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12373	 1	 27.91	 6.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12374	 1	 17.4	 5.44	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12375	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12376	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12377	 1	 9.44	 3.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12378	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12379	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12380	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12381	 1	 3.22	 1.06	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12382	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12383	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12384	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12385	 1	 11.97	 4.05	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12386	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12387	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12388	 1	 4.88	 1.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12389	 1	 7.64	 3.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12390	 1	 6.57	 1.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12391	 1	 9.69	 2.68	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12392	 1	 40.35	 9.91	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12393	 1	 6.97	 2.83	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12394	 1	 12.86	 3.91	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12395	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12396	 1	 10.43	 3.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12397	 1	 7.81	 3.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12398	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12399	 1	 8.57	 2.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12400	 1	 12.02	 4.01	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12401	 1	 7.92	 3.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12402	 1	 4.05	 1.52	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12403	 1	 6.43	 1.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12404	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12405	 1	 9.08	 2.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12406	 1	 1.19	 0.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12407	 1	 3.84	 1.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12408	 1	 3.83	 1.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12409	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12410	 1	 16.73	 4.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12411	 1	 12.45	 2.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12412	 1	 8.88	 2.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12413	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12414	 1	 2.75	 0.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12415	 1	 9.4	 2.46	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12416	 1	 8.61	 2.74	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12417	 1	 8.73	 2.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12418	 1	 5.42	 1.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12419	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12420	 1	 3.51	 1.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12421	 1	 18.79	 5.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12422	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12423	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12424	 1	 4.51	 1.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12425	 1	 19.15	 5.25	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12426	 1	 4.57	 1.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12427	 1	 4.07	 1.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12428	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12429	 1	 16.83	 4.84	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12430	 1	 7.34	 2.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12431	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12432	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12433	 1	 3.68	 1.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12434	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12435	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12436	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12437	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12438	 1	 6.91	 2.87	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12439	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	12440	 1	 24.94	 7.09	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12441	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12442	 1	 5.83	 1.66	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12443	 1	 30.41	 9.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12444	 1	 8.7	 2.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12445	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12446	 1	 16.02	 4.17	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12447	 1	 9.04	 3.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12448	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12449	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12450	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12451	 1	 6.19	 2.06	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12452	 1	 18.54	 5.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12453	 1	 11.38	 3.85	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12454	 1	 8.38	 2.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12455	 1	 9.21	 3.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12456	 1	 9.92	 3.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12457	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12458	 1	 12.93	 4.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12459	 1	 2.82	 1.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12460	 1	 6.45	 2.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12461	 1	 46.54	 12.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12462	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12463	 1	 15.9	 3.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12464	 1	 6.59	 1.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12465	 1	 5.79	 2.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12466	 1	 4.57	 1.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12467	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12468	 1	 6.32	 1.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12469	 1	 3.38	 1.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12470	 1	 4.36	 1.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12471	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12472	 1	 30.47	 9.2	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12473	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12474	 1	 7.06	 3.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12475	 1	 3.89	 1.88	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12476	 1	 4.52	 1.81	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12477	 1	 4.63	 2.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12478	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12479	 1	 6.62	 2.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12480	 1	 6.75	 2.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12481	 1	 8.67	 3.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12482	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12483	 1	 6.62	 2.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12484	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12485	 1	 5.77	 1.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12486	 1	 8.44	 3.21	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12487	 1	 5.93	 1.84	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12488	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12489	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12490	 1	 9.17	 3.51	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12491	 1	 4.49	 2.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12492	 1	 6.07	 2.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12493	 1	 3.49	 1.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12494	 1	 8.58	 3.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12495	 1	 20.84	 5.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12496	 1	 25.51	 7.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12497	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12498	 1	 3.65	 1.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12499	 1	 4.81	 1.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12500	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12501	 1	 5.03	 2.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12502	 1	 10.67	 4.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12503	 1	 27.32	 6.64	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12504	 1	 18.64	 5.34	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12505	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12506	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12507	 1	 7.57	 3.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12508	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12509	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12510	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	12511	 1	 24.65	 6.39	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12512	 1	 26.94	 7.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12513	 1	 10.21	 3.67	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12514	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12515	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12516	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12517	 1	 4.77	 1.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12518	 1	 6.4	 2.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12519	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12520	 1	 6.99	 2.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12521	 1	 4.79	 1.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12522	 1	 6.27	 2.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12523	 1	 18.96	 4.91	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12524	 1	 14.16	 3.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12525	 1	 6.7	 2.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12526	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12527	 1	 5.16	 2.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12528	 1	 3.68	 1.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12529	 1	 3.73	 1.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12530	 1	 41.3	 7.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12531	 1	 3.5	 1.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12532	 1	 7.95	 2.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12533	 1	 5.75	 2.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12534	 1	 4.31	 2.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12535	 1	 9.57	 3.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12536	 1	 5.37	 1.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12537	 1	 11.29	 3.03	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12538	 1	 8.54	 2.24	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12539	 1	 5.25	 1.78	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12540	 1	 3.72	 1.45	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12541	 1	 5.61	 2.03	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12542	 1	 2.03	 0.86	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12543	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12544	 1	 3.44	 1.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12545	 1	 3.87	 1.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12546	 1	 2.34	 1.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12547	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12548	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12549	 1	 4.6	 1.5	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12550	 1	 2.56	 0.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12551	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12552	 1	 14.32	 4.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12553	 1	 35.11	 8.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12554	 1	 7.81	 1.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12555	 1	 4.77	 1.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12556	 1	 2.67	 0.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12557	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12558	 1	 3.87	 0.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12559	 1	 4.69	 1.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12560	 1	 4.8	 1.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12561	 1	 1.41	 0.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12562	 1	 12.68	 2.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12563	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12564	 1	 2.44	 0.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12565	 1	 6.05	 1.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12566	 1	 3.01	 0.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12567	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12568	 1	 3.41	 0.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12569	 1	 9.25	 2.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12570	 1	 5.77	 2.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12571	 1	 2.59	 0.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12572	 1	 1.9	 0.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12573	 1	 6.95	 3.21	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12574	 1	 3.9	 0.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12575	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12576	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12577	 1	 3.21	 1.05	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12578	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12579	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12580	 1	 2.48	 0.93	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12581	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12582	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12583	 1	 5.63	 1.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12584	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12585	 1	 4.2	 1.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12586	 1	 1.74	 0.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12587	 1	 5.56	 1.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12588	 1	 10.33	 2.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12589	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12590	 1	 3.43	 1.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12591	 1	 5.53	 2.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12592	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12593	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12594	 1	 1.95	 0.7	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12595	 1	 4.44	 1.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12596	 1	 1.43	 0.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12597	 1	 3.27	 1.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12598	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12599	 1	 1.88	 0.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12600	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12601	 1	 3.18	 1.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12602	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12603	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12604	 1	 1.46	 0.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12605	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12606	 1	 14.83	 4.45	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12607	 1	 6.1	 2.44	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12608	 1	 3.04	 1.11	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12609	 1	 13.05	 3.8	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12610	 1	 59.01	 15.14	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12611	 1	 3.55	 1.31	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12612	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12613	 1	 4.99	 2.34	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12614	 1	 7.33	 2.07	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12615	 1	 1.89	 0.79	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12616	 1	 2.73	 1.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12617	 1	 4.4	 1.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12618	 1	 3.31	 0.93	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12619	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	12620	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	12621	 1	 1.87	 0.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12622	 1	 1.78	 0.87	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	12623	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	12624	 1	 10.4	 4.33	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12625	 1	 4.89	 1.7	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12626	 1	 15.96	 3.87	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12627	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12628	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	12629	 1	 3.82	 1.42	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12630	 1	 3.76	 1.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12631	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12632	 1	 19.93	 6.67	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12633	 1	 7.12	 2.41	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12634	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12635	 1	 2.77	 1.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12636	 1	 6.59	 2.69	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12637	 1	 3.39	 1.64	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12638	 1	 5.64	 2.41	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12639	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12640	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	12641	 1	 11.47	 3.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12642	 1	 2.11	 1.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12643	 1	 24.71	 7.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12644	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12645	 1	 10.05	 2.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12646	 1	 4.15	 1.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12647	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12648	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	12649	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12650	 1	 4.24	 0.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12651	 1	 1.89	 0.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12652	 1	 12.09	 3.36	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12653	 1	 10.95	 2.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12654	 1	 5.95	 2.55	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12655	 1	 5.63	 2.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12656	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12657	 1	 40.78	 9.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12658	 1	 8.57	 2.83	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12659	 1	 17.95	 5.62	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12660	 1	 32.14	 8.49	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12661	 1	 10.84	 3.13	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12662	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12663	 1	 13.54	 4.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12664	 1	 8.23	 2.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12665	 1	 1.35	 0.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12666	 1	 20.98	 5.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12667	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12668	 1	 4.87	 1.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12669	 1	 15.08	 3.77	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12670	 1	 5.24	 2.08	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12671	 1	 8.49	 3.09	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12672	 1	 6.43	 2.23	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12673	 1	 88.85	 21.29	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12674	 1	 6.76	 1.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12675	 1	 8.26	 3.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12676	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12677	 1	 38.38	 8.56	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12678	 1	 24.87	 5.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12679	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12680	 1	 10.55	 2.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12681	 1	 10.94	 2.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12682	 1	 2.29	 0.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12683	 1	 8.37	 1.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12684	 1	 5.49	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12685	 1	 2.71	 0.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12686	 1	 6.41	 1.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12687	 1	 29.44	 6.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12688	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12689	 1	 7.84	 1.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12690	 1	 10.76	 2.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12691	 1	 2.33	 0.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12692	 1	 16.92	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12693	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12694	 1	 18.52	 4.21	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12695	 1	 9.63	 -4.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12696	 1	 4.49	 -4.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12697	 1	 6.54	 -4.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12698	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12699	 1	 15.07	 -7.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12700	 1	 3.6	 0.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12701	 1	 25.21	 5.81	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12702	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12703	 1	 15.58	 3.62	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12704	 1	 9.59	 2.21	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12705	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12706	 1	 11.16	 2.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12707	 1	 9.13	 2.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12708	 1	 12.74	 3.51	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12709	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12710	 1	 14.18	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12711	 1	 54.32	 12.23	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12712	 1	 8.05	 2.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12713	 1	 4.91	 1.83	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12714	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12715	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12716	 1	 4.71	 2.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12717	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12718	 1	 7.44	 1.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12719	 1	 9.08	 2.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12720	 1	 10.55	 2.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12721	 1	 14.3	 4.2	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12722	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12723	 1	 7.17	 1.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12724	 1	 3.32	 0.77	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12725	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12726	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12727	 1	 10.04	 2.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12728	 1	 11.93	 4.02	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12729	 1	 6.53	 2.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12730	 1	 5.56	 1.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12731	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12732	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12733	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12734	 1	 1.94	 0.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12735	 1	 3.39	 1.21	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12736	 1	 12.09	 2.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12737	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12738	 1	 6.53	 2.55	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12739	 1	 23.27	 4.73	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12740	 1	 5.34	 1.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12741	 1	 18.49	 5.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12742	 1	 17.07	 5.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12743	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12744	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12745	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12746	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12747	 1	 6.99	 2.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12748	 1	 5.1	 2.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12749	 1	 5.12	 2.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12750	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12751	 1	 3.92	 1.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12752	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12753	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12754	 1	 2.7	 1.24	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12755	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12756	 1	 4.45	 1.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12757	 1	 5.22	 1.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12758	 1	 7.24	 2.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12759	 1	 10.85	 3.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12760	 1	 2.87	 1.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12761	 1	 2.77	 0.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12762	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12763	 1	 2.12	 0.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12764	 1	 15.8	 3.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12765	 1	 3.99	 1.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12766	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12767	 1	 2.47	 1.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12768	 1	 5.05	 1.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12769	 1	 12.58	 3.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12770	 1	 12.31	 3.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12771	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12772	 1	 13.77	 3.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12773	 1	 19.04	 6.07	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12774	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12775	 1	 21.63	 6.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12776	 1	 28.24	 8.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12777	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12778	 1	 46.58	 12.86	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12779	 1	 3.49	 1.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12780	 1	 4.33	 1.83	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12781	 1	 8.74	 2.64	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12782	 1	 16.89	 4.42	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12783	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	12784	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12785	 1	 8.32	 2.86	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12786	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12787	 1	 3.01	 0.82	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12788	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12789	 1	 5.88	 1.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12790	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12791	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12792	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12793	 1	 20.87	 7.21	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12794	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12795	 1	 6.42	 1.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12796	 1	 7.48	 2.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12797	 1	 7.28	 2.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12798	 1	 21.44	 5.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12799	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12800	 1	 4.5	 1.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12801	 1	 13.08	 3.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12802	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12803	 1	 10.14	 3.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12804	 1	 2.41	 1.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12805	 1	 4.26	 1.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12806	 1	 6.58	 2.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12807	 1	 5.56	 1.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12808	 1	 6.04	 1.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12809	 1	 7.59	 2.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12810	 1	 1.77	 0.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12811	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12812	 1	 3.13	 1.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12813	 1	 5.64	 1.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12814	 1	 4.8	 1.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12815	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12816	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12817	 1	 6.91	 1.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12818	 1	 7.24	 1.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12819	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12820	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12821	 1	 6.95	 2.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12822	 1	 12.67	 3.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12823	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12824	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12825	 1	 9.05	 2.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12826	 1	 6.41	 2.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12827	 1	 2.79	 1.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12828	 1	 5.62	 2.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12829	 1	 1.95	 0.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12830	 1	 4.45	 1.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12831	 1	 7.8	 2.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12832	 1	 7.62	 2.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12833	 1	 3.12	 1.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12834	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12835	 1	 6.09	 1.54	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12836	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12837	 1	 11.73	 3.03	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12838	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12839	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12840	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12841	 1	 12.66	 3.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12842	 1	 15.52	 4.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12843	 1	 2.16	 0.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12844	 1	 7.16	 2.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12845	 1	 5.89	 2.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12846	 1	 8.24	 3.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12847	 1	 20.42	 5.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12848	 1	 4.88	 1.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12849	 1	 8.24	 3.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12850	 1	 17.7	 6.04	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12851	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12852	 1	 8.63	 3.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12853	 1	 4.85	 1.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12854	 1	 8.9	 2.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12855	 1	 18.46	 4.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12856	 1	 4.59	 1.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12857	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12858	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12859	 1	 6.09	 2.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12860	 1	 18.01	 4.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12861	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	12862	 1	 15.21	 3.52	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12863	 1	 15.95	 4.66	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12864	 1	 4.44	 1.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12865	 1	 3.43	 1.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12866	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12867	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12868	 1	 3.98	 1.19	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12869	 1	 6.52	 2.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12870	 1	 18.76	 4.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12871	 1	 4.87	 1.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12872	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12873	 1	 2.25	 0.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12874	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12875	 1	 6.61	 2.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12876	 1	 8.95	 2.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12877	 1	 2.34	 1.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12878	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12879	 1	 8.63	 2.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12880	 1	 4.26	 1.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12881	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12882	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12883	 1	 3.31	 1.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12884	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12885	 1	 4.46	 1.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12886	 1	 13.76	 3.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12887	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	12888	 1	 7.22	 2.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12889	 1	 7.53	 1.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12890	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12891	 1	 12.3	 3.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12892	 1	 5.14	 1.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12893	 1	 2.52	 1.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12894	 1	 1.99	 0.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12895	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12896	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12897	 1	 11.69	 3.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12898	 1	 7.3	 2.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12899	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12900	 1	 6.89	 3.09	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12901	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12902	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12903	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12904	 1	 4.22	 1.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12905	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12906	 1	 4.35	 1.54	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12907	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12908	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12909	 1	 8.59	 3.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12910	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12911	 1	 1.51	 0.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12912	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12913	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12914	 1	 6.37	 2.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12915	 1	 26.09	 7.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12916	 1	 9.04	 2.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12917	 1	 10.2	 3.63	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12918	 1	 46.92	 14.52	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12919	 1	 4.44	 2.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12920	 1	 2.74	 1.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12921	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12922	 1	 6.37	 2.03	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12923	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12924	 1	 38.05	 9.89	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12925	 1	 4.03	 1.86	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12926	 1	 4.33	 1.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12927	 1	 5.43	 1.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12928	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12929	 1	 2.93	 1.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12930	 1	 3.01	 1.38	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12931	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	12932	 1	 8.47	 2.87	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12933	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12934	 1	 4.4	 1.67	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12935	 1	 9.32	 2.85	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12936	 1	 10.31	 3.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12937	 1	 3.41	 1.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12938	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12939	 1	 7.97	 2.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12940	 1	 4.29	 1.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12941	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12942	 1	 4.88	 1.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12943	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	12944	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	12945	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	12946	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	12947	 1	 6.44	 2.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12948	 1	 3.58	 1.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12949	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12950	 1	 6.6	 1.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12951	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12952	 1	 6.27	 1.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12953	 1	 12.44	 4.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12954	 1	 4.9	 1.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12955	 1	 2.4	 1.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12956	 1	 4.11	 1.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12957	 1	 17.02	 4.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12958	 1	 5.74	 2.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12959	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12960	 1	 3.5	 1.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12961	 1	 7.04	 2.57	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12962	 1	 2.58	 1.13	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12963	 1	 13.99	 4.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12964	 1	 8.18	 3.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12965	 1	 12.2	 3.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12966	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12967	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12968	 1	 21.93	 5.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12969	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12970	 1	 20.91	 6.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12971	 1	 8.37	 2.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12972	 1	 3.47	 1.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12973	 1	 3.96	 1.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12974	 1	 4.31	 1.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12975	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12976	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12977	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12978	 1	 5.36	 2.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12979	 1	 3.82	 1.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12980	 1	 3.38	 1.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12981	 1	 12.71	 3.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12982	 1	 2.98	 1.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12983	 1	 5.58	 2.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12984	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12985	 1	 11.86	 4.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12986	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12987	 1	 4.88	 2.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12988	 1	 6.15	 2.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12989	 1	 2.7	 1.15	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12990	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12991	 1	 2.34	 1.19	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12992	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12993	 1	 12.34	 4.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12994	 1	 33.71	 8.39	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12995	 1	 13.29	 4.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12996	 1	 4.95	 1.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	12997	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12998	 1	 4.96	 2.03	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	12999	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13000	 1	 7.26	 2.89	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13001	 1	 3.99	 1.54	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13002	 1	 9.9	 4.02	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13003	 1	 10.55	 3.86	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13004	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13005	 1	 14.02	 3.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13006	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13007	 1	 2.64	 1.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13008	 1	 10.87	 3.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13009	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13010	 1	 5.72	 2.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13011	 1	 28.14	 8.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13012	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13013	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13014	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13015	 1	 29.3	 6.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13016	 1	 8.92	 3.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13017	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13018	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13019	 1	 4.9	 1.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13020	 1	 22.31	 8.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13021	 1	 3.61	 1.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13022	 1	 10.75	 3.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13023	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13024	 1	 4.62	 1.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13025	 1	 6.67	 2.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13026	 1	 22.73	 6.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13027	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13028	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13029	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13030	 1	 3.75	 1.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13031	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13032	 1	 2.44	 1.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13033	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13034	 1	 4.96	 1.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13035	 1	 11.96	 4.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13036	 1	 6.2	 2.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13037	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13038	 1	 10.52	 3.36	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13039	 1	 9.9	 3.18	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13040	 1	 17.91	 5.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13041	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13042	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13043	 1	 7.41	 2.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13044	 1	 21.68	 6.72	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13045	 1	 17.63	 4.7	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13046	 1	 53.7	 16.81	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13047	 1	 14.48	 5.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13048	 1	 13.11	 3.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13049	 1	 7.33	 2.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13050	 1	 2.73	 1.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13051	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13052	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13053	 1	 1.96	 0.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13054	 1	 4.18	 1.47	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13055	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13056	 1	 3.5	 1.33	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13057	 1	 7.98	 2.67	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13058	 1	 13.77	 4.61	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13059	 1	 15.43	 4.4	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13060	 1	 6.06	 1.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13061	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13062	 1	 5.1	 2.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13063	 1	 3.63	 1.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13064	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13065	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13066	 1	 7.55	 2.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13067	 1	 13.61	 4.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13068	 1	 6.23	 2.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13069	 1	 5.93	 2.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13070	 1	 16.17	 4.35	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13071	 1	 7.13	 2.74	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13072	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13073	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13074	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13075	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13076	 1	 13.07	 3.74	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13077	 1	 4.04	 1.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13078	 1	 10.94	 3.23	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13079	 1	 10.56	 3.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13080	 1	 6.25	 1.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13081	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13082	 1	 3.87	 1.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13083	 1	 3.57	 1.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13084	 1	 6.34	 2.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13085	 1	 3.26	 1.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13086	 1	 3.26	 1.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13087	 1	 4.6	 1.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13088	 1	 10.95	 3.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13089	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13090	 1	 4.31	 1.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13091	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13092	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13093	 1	 4.59	 2.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13094	 1	 5.05	 2.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13095	 1	 3.55	 1.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13096	 1	 9.05	 2.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13097	 1	 2.46	 1.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13098	 1	 3.59	 1.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13099	 1	 6.21	 2.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13100	 1	 6.98	 2.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13101	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13102	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13103	 1	 5.25	 1.53	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13104	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13105	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13106	 1	 4.52	 1.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13107	 1	 3.31	 1.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13108	 1	 5.85	 2.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13109	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13110	 1	 7.99	 2.8	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13111	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13112	 1	 4.81	 1.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13113	 1	 6.42	 2.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13114	 1	 6.36	 2.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13115	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13116	 1	 23.96	 6.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13117	 1	 12.0	 4.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13118	 1	 4.59	 1.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13119	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13120	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13121	 1	 6.26	 2.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13122	 1	 4.64	 2.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13123	 1	 19.83	 5.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13124	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13125	 1	 10.04	 3.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13126	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13127	 1	 6.07	 2.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13128	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13129	 1	 1.22	 0.59	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13130	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13131	 1	 3.56	 1.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13132	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13133	 1	 3.59	 1.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13134	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13135	 1	 4.62	 1.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13136	 1	 5.88	 2.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13137	 1	 5.31	 2.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13138	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13139	 1	 8.77	 3.77	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13140	 1	 3.73	 1.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13141	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13142	 1	 5.13	 1.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13143	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13144	 1	 6.26	 2.09	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13145	 1	 4.02	 1.43	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13146	 1	 5.41	 2.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13147	 1	 7.38	 2.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13148	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13149	 1	 4.22	 1.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13150	 1	 8.27	 3.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13151	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13152	 1	 4.9	 1.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13153	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13154	 1	 3.79	 1.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13155	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13156	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13157	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13158	 1	 4.58	 1.81	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13159	 1	 11.42	 3.48	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13160	 1	 4.77	 1.83	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13161	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13162	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13163	 1	 7.17	 2.95	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13164	 1	 10.24	 3.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13165	 1	 7.2	 2.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13166	 1	 4.52	 1.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13167	 1	 5.3	 1.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13168	 1	 3.55	 1.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13169	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13170	 1	 4.85	 2.08	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13171	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13172	 1	 5.54	 2.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13173	 1	 8.42	 2.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13174	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13175	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13176	 1	 2.27	 1.06	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13177	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13178	 1	 4.97	 2.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13179	 1	 1.83	 0.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13180	 1	 6.07	 1.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13181	 1	 3.35	 1.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13182	 1	 3.07	 1.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13183	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13184	 1	 18.28	 4.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13185	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13186	 1	 6.04	 2.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13187	 1	 7.53	 3.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13188	 1	 3.97	 1.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13189	 1	 6.4	 1.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13190	 1	 7.52	 3.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13191	 1	 10.81	 3.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13192	 1	 2.73	 1.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13193	 1	 9.96	 3.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13194	 1	 5.69	 2.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13195	 1	 1.73	 0.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13196	 1	 3.77	 1.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13197	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13198	 1	 3.26	 0.92	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13199	 1	 6.85	 1.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13200	 1	 4.14	 1.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13201	 1	 7.88	 2.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13202	 1	 3.63	 1.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13203	 1	 2.99	 1.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13204	 1	 3.4	 1.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13205	 1	 3.25	 1.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13206	 1	 5.15	 2.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13207	 1	 2.83	 1.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13208	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13209	 1	 6.59	 2.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13210	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13211	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13212	 1	 5.48	 1.55	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13213	 1	 4.95	 1.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13214	 1	 2.63	 1.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13215	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13216	 1	 5.04	 1.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13217	 1	 0.73	 0.34	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13218	 1	 4.14	 1.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13219	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13220	 1	 5.11	 1.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13221	 1	 7.53	 2.55	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13222	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13223	 1	 2.77	 1.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13224	 1	 2.56	 1.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13225	 1	 8.72	 3.6	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13226	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13227	 1	 11.61	 3.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13228	 1	 9.65	 2.8	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13229	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13230	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13231	 1	 4.98	 1.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13232	 1	 1.66	 0.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13233	 1	 2.83	 1.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13234	 1	 6.49	 1.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13235	 1	 10.21	 3.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13236	 1	 7.59	 2.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13237	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13238	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13239	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13240	 1	 6.88	 2.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13241	 1	 4.34	 1.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13242	 1	 8.21	 3.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13243	 1	 3.86	 1.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13244	 1	 12.49	 4.59	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13245	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13246	 1	 4.55	 1.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13247	 1	 4.36	 1.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13248	 1	 9.31	 2.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13249	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13250	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13251	 1	 3.32	 1.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13252	 1	 5.52	 2.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13253	 1	 11.01	 3.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13254	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13255	 1	 17.26	 5.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13256	 1	 12.06	 4.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13257	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13258	 1	 10.38	 3.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13259	 1	 4.8	 1.86	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13260	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13261	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13262	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13263	 1	 9.74	 3.43	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13264	 1	 3.02	 1.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13265	 1	 6.05	 1.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13266	 1	 3.11	 1.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13267	 1	 6.89	 2.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13268	 1	 8.21	 2.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13269	 1	 3.18	 1.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13270	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13271	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13272	 1	 7.95	 2.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13273	 1	 1.83	 0.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13274	 1	 2.7	 1.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13275	 1	 19.49	 4.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13276	 1	 4.0	 1.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13277	 1	 6.23	 1.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13278	 1	 4.44	 1.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13279	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13280	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13281	 1	 10.3	 3.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13282	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13283	 1	 5.79	 1.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13284	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13285	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13286	 1	 1.86	 0.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13287	 1	 1.08	 0.42	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13288	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13289	 1	 9.76	 2.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13290	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13291	 1	 1.65	 0.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13292	 1	 6.31	 2.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13293	 1	 4.21	 1.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13294	 1	 8.07	 2.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13295	 1	 3.63	 1.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13296	 1	 2.9	 1.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13297	 1	 6.51	 2.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13298	 1	 6.54	 1.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13299	 1	 13.89	 3.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13300	 1	 1.75	 0.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13301	 1	 3.07	 1.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13302	 1	 8.33	 3.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13303	 1	 5.09	 1.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13304	 1	 3.64	 1.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13305	 1	 2.38	 0.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13306	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13307	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13308	 1	 1.67	 0.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13309	 1	 19.14	 4.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13310	 1	 5.35	 1.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13311	 1	 10.14	 3.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13312	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13313	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13314	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13315	 1	 6.01	 2.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13316	 1	 5.87	 2.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13317	 1	 8.49	 3.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13318	 1	 15.76	 4.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13319	 1	 8.22	 2.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13320	 1	 4.34	 1.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13321	 1	 3.08	 1.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13322	 1	 9.64	 2.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13323	 1	 6.5	 2.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13324	 1	 8.39	 2.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13325	 1	 4.13	 1.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13326	 1	 8.15	 3.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13327	 1	 5.43	 2.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13328	 1	 6.56	 2.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13329	 1	 5.36	 2.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13330	 1	 13.59	 3.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13331	 1	 3.55	 1.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13332	 1	 14.18	 4.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13333	 1	 7.07	 2.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13334	 1	 4.25	 1.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13335	 1	 13.75	 3.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13336	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13337	 1	 4.71	 1.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13338	 1	 3.58	 1.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13339	 1	 10.41	 3.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13340	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13341	 1	 7.85	 2.53	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13342	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13343	 1	 5.86	 2.82	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13344	 1	 8.94	 3.66	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13345	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13346	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13347	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13348	 1	 8.19	 2.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13349	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13350	 1	 5.28	 2.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13351	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13352	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13353	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13354	 1	 4.85	 2.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13355	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13356	 1	 11.43	 4.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13357	 1	 4.15	 1.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13358	 1	 4.52	 1.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13359	 1	 6.93	 2.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13360	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13361	 1	 7.54	 2.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13362	 1	 5.06	 1.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13363	 1	 5.26	 1.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13364	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13365	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13366	 1	 5.19	 1.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13367	 1	 8.3	 3.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13368	 1	 5.34	 1.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13369	 1	 12.05	 3.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13370	 1	 9.34	 3.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13371	 1	 5.11	 1.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13372	 1	 6.22	 2.29	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13373	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13374	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13375	 1	 4.13	 1.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13376	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13377	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13378	 1	 4.48	 1.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13379	 1	 8.01	 2.88	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13380	 1	 9.39	 2.7	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13381	 1	 5.0	 2.09	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13382	 1	 15.43	 4.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13383	 1	 9.92	 3.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13384	 1	 9.23	 2.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13385	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13386	 1	 8.67	 3.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13387	 1	 6.6	 2.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13388	 1	 6.18	 2.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13389	 1	 10.66	 3.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13390	 1	 15.83	 3.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13391	 1	 3.59	 1.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13392	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13393	 1	 3.15	 1.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13394	 1	 17.24	 6.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13395	 1	 3.13	 1.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13396	 1	 7.21	 2.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13397	 1	 4.96	 1.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13398	 1	 11.46	 4.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13399	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13400	 1	 13.43	 4.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13401	 1	 12.55	 4.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13402	 1	 5.22	 2.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13403	 1	 13.41	 4.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13404	 1	 9.41	 2.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13405	 1	 5.08	 2.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13406	 1	 11.59	 3.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13407	 1	 7.36	 2.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13408	 1	 19.63	 5.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13409	 1	 9.19	 2.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13410	 1	 6.68	 2.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13411	 1	 7.16	 2.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13412	 1	 5.92	 2.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13413	 1	 10.12	 3.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13414	 1	 14.13	 3.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13415	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13416	 1	 7.92	 2.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13417	 1	 5.32	 2.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13418	 1	 6.62	 2.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13419	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13420	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13421	 1	 3.29	 1.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13422	 1	 7.16	 2.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13423	 1	 8.57	 1.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13424	 1	 11.6	 3.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13425	 1	 4.7	 1.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13426	 1	 3.6	 1.01	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13427	 1	 7.42	 2.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13428	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13429	 1	 4.86	 2.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13430	 1	 9.13	 3.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13431	 1	 4.42	 1.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13432	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13433	 1	 6.15	 2.28	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13434	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13435	 1	 29.07	 8.3	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13436	 1	 6.45	 2.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13437	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13438	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13439	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13440	 1	 6.63	 2.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13441	 1	 5.43	 1.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13442	 1	 1.23	 0.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13443	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13444	 1	 5.29	 2.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13445	 1	 11.6	 2.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13446	 1	 21.72	 5.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13447	 1	 5.85	 1.65	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13448	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13449	 1	 2.31	 0.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13450	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13451	 1	 4.14	 0.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13452	 1	 2.76	 0.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13453	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13454	 1	 0.47	 0.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13455	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13456	 1	 8.35	 3.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13457	 1	 2.76	 0.64	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13458	 1	 2.29	 0.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13459	 1	 2.62	 0.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13460	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13461	 1	 1.62	 0.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13462	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13463	 1	 0.68	 0.16	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13464	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13465	 1	 3.4	 0.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13466	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13467	 1	 1.18	 0.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13468	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13469	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13470	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13471	 1	 3.32	 0.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13472	 1	 4.9	 1.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13473	 1	 5.0	 1.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13474	 1	 5.04	 1.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13475	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13476	 1	 15.24	 -7.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13477	 1	 17.88	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13478	 1	 14.7	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13479	 1	 17.2	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13480	 1	 6.29	 2.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13481	 1	 3.51	 1.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13482	 1	 69.61	 13.41	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13483	 1	 11.88	 4.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13484	 1	 7.54	 2.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13485	 1	 8.23	 2.43	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13486	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13487	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13488	 1	 11.1	 3.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13489	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13490	 1	 19.58	 4.29	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13491	 1	 8.36	 2.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13492	 1	 10.27	 3.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13493	 1	 12.01	 2.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13494	 1	 6.56	 1.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13495	 1	 7.07	 2.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13496	 1	 27.69	 7.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13497	 1	 5.02	 1.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13498	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13499	 1	 12.55	 3.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13500	 1	 20.18	 5.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13501	 1	 2.76	 0.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13502	 1	 5.08	 1.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13503	 1	 6.46	 2.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13504	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13505	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13506	 1	 7.03	 2.51	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13507	 1	 3.81	 1.58	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13508	 1	 3.27	 1.24	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13509	 1	 7.26	 2.6	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13510	 1	 19.67	 6.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13511	 1	 3.68	 1.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13512	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13513	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13514	 1	 3.16	 1.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13515	 1	 5.66	 2.19	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13516	 1	 2.81	 1.25	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13517	 1	 10.89	 3.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13518	 1	 9.49	 2.62	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13519	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13520	 1	 16.66	 5.54	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13521	 1	 26.89	 8.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13522	 1	 13.74	 4.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13523	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13524	 1	 11.78	 3.85	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13525	 1	 8.7	 3.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13526	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13527	 1	 14.21	 4.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13528	 1	 7.68	 2.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13529	 1	 13.52	 3.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13530	 1	 12.15	 4.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13531	 1	 11.2	 3.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13532	 1	 15.47	 5.06	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13533	 1	 18.51	 5.41	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13534	 1	 11.74	 4.35	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13535	 1	 6.64	 2.13	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13536	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13537	 1	 27.22	 6.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13538	 1	 21.45	 4.73	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13539	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13540	 1	 5.54	 1.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13541	 1	 5.51	 1.92	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13542	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13543	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13544	 1	 3.98	 1.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13545	 1	 4.47	 1.89	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13546	 1	 9.98	 3.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13547	 1	 2.51	 1.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13548	 1	 6.54	 1.85	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13549	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13550	 1	 2.67	 1.2	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13551	 1	 3.06	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13552	 1	 3.66	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13553	 1	 6.23	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13554	 1	 6.57	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13555	 1	 5.16	 1.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13556	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13557	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13558	 1	 4.16	 0.97	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13559	 1	 5.59	 1.3	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13560	 1	 7.48	 1.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13561	 1	 4.42	 1.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13562	 1	 16.99	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13563	 1	 11.94	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13564	 1	 7.33	 1.65	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13565	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13566	 1	 5.95	 1.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13567	 1	 16.63	 3.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13568	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13569	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13570	 1	 12.89	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13571	 1	 4.03	 0.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13572	 1	 23.39	 6.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13573	 1	 6.91	 2.93	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13574	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13575	 1	 9.56	 2.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13576	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13577	 1	 16.11	 5.24	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13578	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13579	 1	 8.2	 2.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13580	 1	 1.71	 0.79	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13581	 1	 9.78	 3.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13582	 1	 6.29	 1.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13583	 1	 4.33	 1.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13584	 1	 16.32	 5.11	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13585	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13586	 1	 3.98	 1.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13587	 1	 8.14	 2.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13588	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13589	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13590	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13591	 1	 5.08	 1.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13592	 1	 12.76	 4.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13593	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13594	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13595	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13596	 1	 17.54	 5.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13597	 1	 8.85	 3.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13598	 1	 7.8	 1.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13599	 1	 6.89	 2.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13600	 1	 8.6	 3.5	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13601	 1	 11.41	 2.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13602	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13603	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13604	 1	 3.35	 1.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13605	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13606	 1	 75.61	 16.55	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13607	 1	 7.44	 1.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13608	 1	 8.06	 2.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13609	 1	 13.09	 3.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13610	 1	 2.43	 0.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13611	 1	 9.37	 2.4	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13612	 1	 4.36	 1.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13613	 1	 4.05	 1.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13614	 1	 17.69	 4.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13615	 1	 10.1	 2.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13616	 1	 3.25	 1.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13617	 1	 11.27	 3.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13618	 1	 5.56	 1.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13619	 1	 7.34	 2.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13620	 1	 3.33	 1.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13621	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13622	 1	 12.28	 3.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13623	 1	 32.92	 9.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13624	 1	 12.66	 2.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13625	 1	 1.2	 0.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13626	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13627	 1	 8.95	 2.86	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13628	 1	 17.82	 5.7	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13629	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13630	 1	 6.57	 2.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13631	 1	 14.73	 3.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13632	 1	 8.74	 2.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13633	 1	 7.35	 2.97	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13634	 1	 11.73	 4.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13635	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13636	 1	 7.93	 2.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13637	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13638	 1	 10.22	 2.88	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13639	 1	 3.86	 1.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13640	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13641	 1	 5.48	 1.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13642	 1	 1.78	 0.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13643	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13644	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13645	 1	 4.63	 1.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13646	 1	 8.46	 2.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13647	 1	 2.94	 1.44	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13648	 1	 2.16	 0.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13649	 1	 7.95	 2.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13650	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13651	 1	 4.14	 1.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13652	 1	 16.94	 4.62	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13653	 1	 11.28	 3.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13654	 1	 1.34	 0.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13655	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13656	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13657	 1	 11.66	 3.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13658	 1	 19.42	 5.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13659	 1	 1.22	 0.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13660	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13661	 1	 5.68	 1.45	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13662	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13663	 1	 1.47	 0.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13664	 1	 5.82	 2.15	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13665	 1	 3.25	 1.51	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13666	 1	 2.87	 1.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13667	 1	 9.48	 2.66	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13668	 1	 4.41	 2.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13669	 1	 9.32	 3.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13670	 1	 1.26	 0.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13671	 1	 3.83	 0.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13672	 1	 2.14	 0.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13673	 1	 4.04	 0.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13674	 1	 3.4	 0.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13675	 1	 9.81	 2.29	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13676	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13677	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13678	 1	 12.08	 2.84	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13679	 1	 7.88	 1.84	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13680	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13681	 1	 9.95	 2.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13682	 1	 2.89	 0.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13683	 1	 1.74	 0.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13684	 1	 6.49	 2.23	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13685	 1	 1.32	 0.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13686	 1	 3.73	 1.55	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13687	 1	 3.52	 1.01	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13688	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13689	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13690	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13691	 1	 2.34	 0.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13692	 1	 2.95	 1.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13693	 1	 3.71	 1.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13694	 1	 4.5	 1.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13695	 1	 12.7	 4.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13696	 1	 9.05	 2.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13697	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13698	 1	 1.99	 0.89	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13699	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13700	 1	 2.81	 0.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13701	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13702	 1	 9.01	 3.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13703	 1	 4.05	 1.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13704	 1	 8.49	 3.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13705	 1	 64.47	 18.51	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13706	 1	 4.48	 1.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13707	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13708	 1	 5.99	 2.5	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13709	 1	 11.16	 3.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13710	 1	 8.47	 2.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13711	 1	 6.57	 2.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13712	 1	 11.15	 3.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13713	 1	 2.89	 1.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13714	 1	 10.29	 3.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13715	 1	 19.77	 4.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13716	 1	 13.42	 3.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13717	 1	 8.64	 1.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13718	 1	 6.58	 1.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13719	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13720	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13721	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13722	 1	 9.9	 3.23	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13723	 1	 5.17	 1.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13724	 1	 6.45	 2.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13725	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13726	 1	 3.07	 1.19	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13727	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13728	 1	 7.26	 2.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13729	 1	 5.39	 1.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13730	 1	 7.09	 1.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13731	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13732	 1	 3.4	 0.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13733	 1	 9.12	 2.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13734	 1	 3.41	 0.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13735	 1	 8.46	 1.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13736	 1	 8.63	 1.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13737	 1	 6.37	 1.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13738	 1	 4.37	 0.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13739	 1	 5.15	 1.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13740	 1	 7.16	 1.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13741	 1	 8.34	 1.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13742	 1	 2.92	 0.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13743	 1	 12.31	 2.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13744	 1	 4.35	 0.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13745	 1	 28.08	 6.78	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13746	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13747	 1	 4.91	 2.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13748	 1	 2.6	 0.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13749	 1	 1.95	 0.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13750	 1	 18.33	 4.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13751	 1	 5.82	 1.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13752	 1	 2.29	 0.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13753	 1	 8.94	 2.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13754	 1	 5.68	 1.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13755	 1	 11.1	 3.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13756	 1	 3.36	 1.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13757	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13758	 1	 2.85	 1.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13759	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13760	 1	 11.29	 2.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13761	 1	 12.95	 2.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13762	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13763	 1	 2.89	 0.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13764	 1	 1.93	 0.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13765	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13766	 1	 5.12	 1.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13767	 1	 3.1	 0.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13768	 1	 13.26	 2.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13769	 1	 21.19	 4.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13770	 1	 2.04	 0.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13771	 1	 34.08	 7.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13772	 1	 15.1	 3.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13773	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13774	 1	 6.19	 2.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13775	 1	 15.62	 4.33	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13776	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13777	 1	 12.2	 3.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13778	 1	 6.63	 1.91	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13779	 1	 8.17	 3.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13780	 1	 4.22	 1.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13781	 1	 6.21	 2.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13782	 1	 1.46	 0.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13783	 1	 7.42	 1.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13784	 1	 3.58	 1.66	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13785	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13786	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13787	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13788	 1	 4.15	 0.97	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13789	 1	 9.67	 2.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13790	 1	 4.51	 1.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13791	 1	 3.49	 1.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13792	 1	 3.89	 1.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13793	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13794	 1	 9.24	 3.05	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13795	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13796	 1	 5.54	 1.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13797	 1	 4.05	 1.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13798	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13799	 1	 3.69	 1.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13800	 1	 7.97	 2.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13801	 1	 8.56	 2.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13802	 1	 4.12	 1.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13803	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13804	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13805	 1	 5.31	 1.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13806	 1	 5.22	 1.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13807	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13808	 1	 32.88	 9.05	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13809	 1	 4.72	 1.73	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13810	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13811	 1	 8.05	 3.3	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13812	 1	 18.29	 4.67	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13813	 1	 19.97	 6.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13814	 1	 17.17	 5.98	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13815	 1	 2.14	 1.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13816	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13817	 1	 5.4	 2.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13818	 1	 43.09	 11.38	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13819	 1	 4.86	 1.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13820	 1	 8.42	 2.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13821	 1	 13.91	 4.38	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13822	 1	 7.09	 3.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13823	 1	 11.57	 4.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13824	 1	 4.18	 1.67	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13825	 1	 54.96	 12.06	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13826	 1	 3.79	 1.46	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13827	 1	 7.4	 2.84	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13828	 1	 7.66	 2.62	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13829	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13830	 1	 18.59	 5.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13831	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13832	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13833	 1	 3.61	 1.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13834	 1	 18.08	 4.43	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13835	 1	 23.85	 6.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13836	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13837	 1	 16.68	 4.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13838	 1	 11.44	 4.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13839	 1	 10.49	 3.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13840	 1	 22.42	 6.15	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13841	 1	 7.03	 3.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13842	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13843	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13844	 1	 4.58	 1.57	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13845	 1	 11.0	 4.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13846	 1	 4.96	 1.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13847	 1	 5.58	 2.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13848	 1	 41.4	 9.08	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13849	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13850	 1	 3.82	 1.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13851	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13852	 1	 31.74	 6.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13853	 1	 25.89	 6.28	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13854	 1	 3.82	 1.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13855	 1	 8.11	 3.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13856	 1	 5.71	 1.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13857	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13858	 1	 9.31	 3.39	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13859	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13860	 1	 21.51	 5.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13861	 1	 7.61	 2.28	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13862	 1	 12.63	 3.3	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13863	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13864	 1	 16.42	 4.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13865	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13866	 1	 10.27	 2.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13867	 1	 9.4	 2.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13868	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13869	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13870	 1	 4.72	 2.04	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13871	 1	 5.02	 1.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13872	 1	 6.59	 2.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13873	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13874	 1	 8.71	 2.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13875	 1	 5.07	 2.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13876	 1	 13.29	 4.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13877	 1	 17.77	 4.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13878	 1	 2.72	 1.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13879	 1	 21.71	 6.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13880	 1	 3.29	 1.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13881	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13882	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13883	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13884	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13885	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13886	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13887	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13888	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13889	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13890	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13891	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13892	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13893	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13894	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13895	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13896	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13897	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13898	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13899	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13900	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13901	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13902	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13903	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13904	 2	 4.83	 2.27	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13905	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13906	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13907	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13908	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13909	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13910	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13911	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13912	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13913	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13914	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13915	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13916	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13917	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13918	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13919	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13920	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13921	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13922	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13923	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13924	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13925	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13926	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13927	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13928	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13929	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13930	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13931	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13932	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13933	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13934	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13935	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13936	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13937	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13938	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13939	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13940	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13941	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13942	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13943	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13944	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13945	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13946	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13947	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13948	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13949	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13950	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13951	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13952	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13953	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13954	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13955	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13956	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13957	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13958	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13959	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13960	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13961	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13962	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13963	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13964	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13965	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13966	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13967	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13968	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13969	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13970	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13971	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13972	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13973	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13974	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13975	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13976	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13977	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	13978	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13979	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13980	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13981	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13982	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13983	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13984	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13985	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13986	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13987	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13988	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13989	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13990	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13991	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13992	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13993	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13994	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13995	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	13996	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13997	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	13998	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13999	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14000	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14001	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14002	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14003	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14004	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14005	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14006	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14007	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14008	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14009	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14010	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14011	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14012	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14013	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14014	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14015	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14016	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14017	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14018	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14019	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14020	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14021	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14022	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14023	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14024	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14025	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14026	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14027	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14028	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14029	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14030	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14031	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14032	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14033	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14034	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14035	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14036	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14037	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14038	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14039	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14040	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14041	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14042	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14043	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14044	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14045	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14046	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14047	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14048	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14049	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14050	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14051	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14052	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14053	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14054	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14055	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14056	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14057	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14058	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14059	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14060	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14061	 1	 7.72	 3.54	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14062	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14063	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14064	 1	 9.1	 3.55	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14065	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14066	 1	 2.35	 1.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14067	 1	 8.86	 3.73	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14068	 1	 10.45	 4.6	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14069	 1	 14.09	 6.3	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14070	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14071	 1	 9.13	 3.86	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14072	 1	 11.95	 4.81	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14073	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14074	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14075	 1	 2.64	 1.09	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14076	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14077	 1	 5.24	 2.89	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14078	 1	 19.79	 7.04	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14079	 1	 6.89	 3.32	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14080	 1	 6.3	 2.8	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14081	 1	 13.44	 6.15	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14082	 1	 4.31	 1.88	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14083	 1	 11.09	 6.17	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14084	 1	 9.95	 4.97	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14085	 1	 10.33	 4.08	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14086	 1	 8.95	 3.63	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14087	 1	 5.86	 2.63	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14088	 1	 16.66	 7.3	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14089	 1	 3.77	 1.51	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14090	 1	 11.27	 4.63	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14091	 1	 17.18	 5.59	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14092	 1	 14.45	 6.48	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14093	 1	 9.52	 4.8	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14094	 1	 3.78	 2.04	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14095	 1	 3.45	 1.64	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14096	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14097	 1	 5.84	 2.66	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14098	 1	 10.94	 5.07	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14099	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14100	 1	 4.34	 1.75	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14101	 1	 4.33	 1.95	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14102	 1	 7.57	 3.41	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14103	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14104	 1	 3.04	 1.33	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14105	 1	 2.82	 1.32	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14106	 1	 57.58	 21.33	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14107	 1	 2.69	 1.19	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14108	 1	 3.91	 1.95	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14109	 1	 5.33	 2.53	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14110	 1	 13.18	 5.46	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14111	 1	 3.54	 1.66	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14112	 1	 5.43	 2.45	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14113	 1	 11.3	 5.27	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14114	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14115	 1	 11.61	 4.99	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14116	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14117	 1	 12.66	 5.26	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14118	 1	 17.19	 5.73	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14119	 1	 2.19	 0.96	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14120	 1	 10.35	 4.13	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14121	 1	 9.8	 4.59	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14122	 1	 11.01	 5.18	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14123	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14124	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14125	 1	 3.35	 1.48	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14126	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14127	 1	 3.05	 1.5	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14128	 1	 7.88	 2.93	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14129	 1	 6.38	 3.02	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14130	 1	 8.91	 4.24	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14131	 1	 4.81	 2.3	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14132	 1	 2.37	 1.23	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14133	 1	 5.39	 2.75	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14134	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14135	 1	 5.91	 2.54	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14136	 1	 10.16	 3.65	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14137	 1	 8.37	 3.66	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14138	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14139	 1	 7.77	 3.48	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14140	 1	 4.63	 1.84	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14141	 1	 20.36	 6.73	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14142	 1	 4.2	 1.94	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14143	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14144	 1	 3.62	 1.88	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14145	 1	 13.41	 5.6	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14146	 1	 6.67	 3.3	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14147	 1	 6.7	 2.66	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14148	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14149	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14150	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14151	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14152	 1	 6.2	 2.68	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14153	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14154	 1	 4.74	 2.09	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14155	 1	 16.84	 6.11	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14156	 1	 17.55	 8.01	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14157	 1	 3.48	 1.53	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14158	 1	 5.35	 2.6	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14159	 1	 6.48	 2.52	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14160	 1	 17.31	 6.62	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14161	 1	 2.14	 0.89	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14162	 1	 20.19	 7.71	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14163	 1	 8.42	 3.41	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14164	 1	 6.81	 3.04	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14165	 1	 8.35	 3.43	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14166	 1	 8.72	 3.88	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14167	 1	 11.07	 4.49	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14168	 1	 9.42	 4.58	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14169	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14170	 1	 5.71	 2.76	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14171	 1	 5.51	 2.62	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14172	 1	 13.65	 5.61	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14173	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14174	 1	 6.64	 3.4	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14175	 1	 18.42	 6.6	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14176	 1	 11.43	 4.54	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14177	 1	 10.91	 4.56	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14178	 1	 6.81	 2.67	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14179	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14180	 1	 8.99	 4.11	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14181	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14182	 1	 17.47	 5.75	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14183	 1	 8.57	 3.39	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14184	 1	 17.84	 7.64	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14185	 1	 9.27	 3.57	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14186	 1	 8.68	 3.96	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14187	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14188	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14189	 1	 13.0	 6.07	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14190	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14191	 1	 9.01	 3.97	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14192	 1	 9.58	 4.43	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14193	 1	 6.63	 3.27	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14194	 1	 8.35	 4.18	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14195	 1	 5.65	 2.48	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14196	 1	 2.44	 1.23	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14197	 1	 13.35	 5.18	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14198	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14199	 1	 11.99	 5.49	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14200	 1	 26.39	 10.68	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14201	 1	 11.62	 3.95	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14202	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14203	 1	 3.07	 1.54	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14204	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14205	 1	 5.29	 2.13	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14206	 1	 10.04	 3.5	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14207	 1	 3.98	 1.62	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14208	 1	 9.86	 4.35	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14209	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14210	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14211	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14212	 1	 9.16	 4.5	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14213	 1	 113.19	 34.16	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14214	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14215	 1	 10.69	 4.32	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14216	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14217	 1	 7.51	 3.39	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14218	 1	 7.75	 3.81	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14219	 1	 9.22	 4.62	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14220	 1	 3.43	 1.68	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14221	 1	 12.55	 5.73	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14222	 1	 30.97	 12.99	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14223	 1	 5.1	 2.35	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14224	 1	 6.87	 3.02	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14225	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14226	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14227	 1	 3.53	 1.85	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14228	 1	 14.46	 6.24	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14229	 1	 7.04	 3.31	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14230	 1	 10.52	 4.18	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14231	 1	 11.8	 4.53	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14232	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14233	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14234	 1	 7.71	 3.47	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14235	 1	 8.78	 4.4	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14236	 1	 6.12	 2.82	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14237	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14238	 1	 14.57	 6.58	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14239	 1	 5.9	 2.64	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14240	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14241	 1	 9.2	 3.09	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14242	 1	 2.43	 1.31	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14243	 1	 4.35	 2.31	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14244	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14245	 1	 1.67	 0.84	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14246	 1	 4.19	 2.25	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14247	 1	 10.64	 4.18	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14248	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14249	 1	 4.48	 2.18	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14250	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14251	 1	 7.11	 3.35	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14252	 1	 6.2	 3.04	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14253	 1	 4.65	 2.25	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14254	 1	 3.48	 1.44	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14255	 1	 5.02	 2.17	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14256	 1	 1.88	 0.83	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14257	 1	 1.29	 0.57	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14258	 1	 1.46	 0.61	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14259	 1	 1.4	 0.64	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14260	 1	 1.27	 0.65	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14261	 1	 3.88	 1.79	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14262	 1	 1.25	 0.57	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14263	 1	 0.86	 0.41	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14264	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14265	 1	 3.19	 1.34	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14266	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14267	 1	 3.37	 1.5	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14268	 1	 2.68	 1.3	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14269	 1	 7.95	 3.28	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14270	 1	 8.53	 3.58	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14271	 1	 8.91	 3.43	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14272	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14273	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14274	 1	 5.43	 2.85	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14275	 1	 8.1	 3.81	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14276	 1	 17.9	 8.6	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14277	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14278	 1	 15.79	 8.25	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14279	 1	 6.2	 2.83	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14280	 1	 5.54	 2.52	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14281	 1	 20.48	 8.39	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14282	 1	 4.86	 2.61	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14283	 1	 4.03	 0.91	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14284	 1	 6.74	 1.51	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14285	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14286	 1	 11.0	 2.47	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14287	 1	 4.36	 1.91	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14288	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14289	 1	 4.74	 2.2	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14290	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14291	 1	 17.07	 3.84	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14292	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14293	 1	 7.73	 1.73	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14294	 1	 4.34	 0.97	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14295	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14296	 1	 3.55	 0.8	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14297	 1	 5.54	 1.25	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14298	 1	 3.99	 0.9	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14299	 1	 3.24	 1.59	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14300	 1	 9.98	 2.23	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14301	 1	 3.0	 0.68	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14302	 1	 8.38	 1.89	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14303	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14304	 1	 2.84	 0.64	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14305	 1	 1.27	 0.29	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14306	 1	 6.3	 1.41	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14307	 1	 7.27	 1.64	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14308	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14309	 1	 6.1	 1.37	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14310	 1	 3.24	 1.42	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14311	 1	 2.4	 1.36	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14312	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14313	 1	 7.29	 3.54	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14314	 1	 5.86	 2.48	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14315	 1	 12.64	 6.9	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14316	 1	 2.43	 0.55	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14317	 1	 3.46	 1.94	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14318	 1	 4.24	 2.5	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14319	 1	 5.34	 2.97	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14320	 1	 4.98	 2.72	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14321	 1	 2.62	 1.31	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14322	 1	 4.35	 2.33	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14323	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14324	 1	 4.23	 2.33	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14325	 1	 1.89	 1.07	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14326	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14327	 1	 6.9	 3.9	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14328	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14329	 1	 4.94	 2.16	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14330	 1	 3.44	 1.89	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14331	 1	 7.24	 3.65	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14332	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14333	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14334	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14335	 1	 7.11	 3.39	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14336	 1	 9.02	 3.93	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14337	 1	 3.47	 1.49	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14338	 1	 9.29	 4.6	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14339	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14340	 1	 2.74	 1.41	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14341	 1	 5.61	 2.73	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14342	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14343	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14344	 1	 2.05	 1.02	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14345	 1	 2.23	 1.21	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14346	 1	 7.88	 4.24	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14347	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14348	 1	 8.43	 3.87	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14349	 1	 8.78	 3.86	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14350	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14351	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14352	 1	 17.03	 8.97	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14353	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14354	 1	 14.42	 6.79	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14355	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14356	 1	 10.94	 5.28	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14357	 1	 9.52	 5.06	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14358	 1	 4.8	 2.53	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14359	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14360	 1	 1.06	 0.51	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14361	 1	 6.77	 3.65	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14362	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14363	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14364	 1	 9.99	 4.9	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14365	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14366	 1	 18.39	 8.22	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14367	 1	 21.85	 8.84	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14368	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14369	 1	 2.72	 1.18	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14370	 1	 1.55	 0.92	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14371	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14372	 1	 1.82	 0.95	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14373	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14374	 1	 1.8	 0.9	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14375	 1	 2.05	 1.14	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14376	 1	 6.38	 3.18	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14377	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14378	 1	 1.96	 1.17	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14379	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14380	 1	 7.05	 3.39	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14381	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14382	 1	 2.34	 1.32	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14383	 1	 2.97	 1.48	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14384	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14385	 1	 2.6	 1.19	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14386	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14387	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14388	 1	 5.32	 2.45	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14389	 1	 3.0	 1.61	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14390	 1	 2.57	 1.38	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14391	 1	 4.33	 1.88	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14392	 1	 3.62	 1.85	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14393	 1	 6.46	 2.9	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14394	 1	 3.94	 2.06	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14395	 1	 10.48	 2.8	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14396	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14397	 1	 2.52	 1.19	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14398	 1	 8.34	 3.76	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14399	 1	 6.09	 2.85	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14400	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14401	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14402	 1	 5.2	 2.31	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14403	 1	 2.85	 1.59	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14404	 1	 12.17	 6.2	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14405	 1	 5.21	 2.97	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14406	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14407	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14408	 1	 6.6	 2.81	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14409	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14410	 1	 2.73	 1.59	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14411	 1	 13.16	 6.34	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14412	 1	 3.58	 1.61	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14413	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14414	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14415	 1	 6.25	 3.21	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14416	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14417	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14418	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14419	 1	 7.85	 3.74	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14420	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14421	 1	 7.01	 3.13	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14422	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14423	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14424	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14425	 1	 5.56	 2.66	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14426	 1	 3.97	 2.24	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14427	 1	 8.41	 4.21	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14428	 1	 3.73	 1.97	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14429	 1	 1.72	 1.07	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14430	 1	 1.01	 0.57	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14431	 1	 1.07	 0.64	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14432	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14433	 1	 3.69	 1.77	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14434	 1	 4.02	 2.04	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14435	 1	 3.4	 1.45	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14436	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14437	 1	 3.57	 1.48	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14438	 1	 5.49	 2.73	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14439	 1	 1.0	 0.53	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14440	 1	 1.53	 0.71	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14441	 1	 1.67	 1.01	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14442	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14443	 1	 1.69	 0.96	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14444	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14445	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14446	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14447	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14448	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14449	 1	 16.28	 8.68	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14450	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14451	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14452	 1	 14.2	 7.31	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14453	 1	 9.27	 3.77	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14454	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14455	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14456	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14457	 1	 4.08	 2.12	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14458	 1	 6.98	 3.36	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14459	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14460	 1	 4.44	 2.18	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14461	 1	 5.36	 2.88	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14462	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14463	 1	 7.33	 2.9	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14464	 1	 4.9	 2.58	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14465	 1	 7.26	 3.66	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14466	 1	 5.14	 3.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14467	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14468	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14469	 1	 5.17	 2.65	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14470	 1	 3.31	 1.34	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14471	 1	 2.8	 1.12	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14472	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14473	 1	 9.88	 4.65	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14474	 1	 7.48	 3.33	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14475	 1	 10.55	 4.34	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14476	 1	 3.81	 2.04	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14477	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14478	 1	 8.63	 3.66	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14479	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14480	 1	 12.4	 6.25	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14481	 1	 17.16	 8.62	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14482	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14483	 1	 8.81	 3.76	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14484	 1	 5.37	 2.62	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14485	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14486	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14487	 1	 6.75	 2.78	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14488	 1	 6.31	 2.74	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14489	 1	 5.9	 3.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14490	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14491	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14492	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14493	 1	 6.3	 3.46	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14494	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14495	 1	 7.07	 3.51	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14496	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14497	 1	 8.62	 4.13	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14498	 1	 5.53	 2.45	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14499	 1	 7.32	 3.4	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14500	 1	 3.58	 1.9	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14501	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14502	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14503	 1	 5.18	 2.58	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14504	 1	 9.89	 4.92	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14505	 1	 8.67	 3.98	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14506	 1	 5.93	 3.12	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14507	 1	 7.31	 3.74	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14508	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14509	 1	 8.7	 3.63	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14510	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14511	 1	 4.88	 2.26	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14512	 1	 12.61	 5.2	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14513	 1	 7.54	 3.47	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14514	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14515	 1	 9.8	 5.19	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14516	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14517	 1	 6.38	 3.17	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14518	 1	 10.5	 4.5	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14519	 1	 5.25	 2.06	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14520	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14521	 1	 16.83	 6.78	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14522	 1	 4.71	 1.97	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14523	 1	 8.66	 3.48	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14524	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14525	 1	 6.75	 3.42	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14526	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14527	 1	 5.32	 2.6	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14528	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14529	 1	 11.26	 5.41	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14530	 1	 4.86	 2.57	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14531	 1	 4.78	 2.51	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14532	 1	 9.05	 4.05	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14533	 1	 11.04	 5.36	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14534	 1	 9.95	 5.05	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14535	 1	 16.5	 7.54	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14536	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14537	 1	 9.06	 4.29	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14538	 1	 12.16	 5.92	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14539	 1	 5.13	 2.41	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14540	 1	 8.89	 4.19	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14541	 1	 7.07	 3.13	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14542	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14543	 1	 13.1	 5.37	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14544	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14545	 1	 7.91	 3.48	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14546	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14547	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14548	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14549	 1	 9.18	 3.45	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14550	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14551	 1	 11.08	 5.73	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14552	 1	 8.0	 3.56	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14553	 1	 14.34	 6.16	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14554	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14555	 1	 6.88	 3.24	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14556	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14557	 1	 6.63	 3.18	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14558	 1	 13.51	 5.4	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14559	 1	 15.53	 5.29	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14560	 1	 12.67	 5.43	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14561	 1	 6.8	 3.23	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14562	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14563	 1	 4.75	 2.34	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14564	 1	 6.5	 2.7	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14565	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14566	 1	 10.76	 3.83	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14567	 1	 10.56	 4.62	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14568	 1	 6.24	 2.85	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14569	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14570	 1	 7.0	 3.53	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14571	 1	 13.42	 4.66	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14572	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14573	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14574	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14575	 1	 6.92	 2.91	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14576	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14577	 1	 12.63	 4.88	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14578	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14579	 1	 10.98	 4.62	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14580	 1	 5.45	 2.14	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14581	 1	 11.08	 4.22	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14582	 1	 6.12	 3.09	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14583	 1	 2.54	 1.29	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14584	 1	 18.11	 6.41	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14585	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14586	 1	 4.1	 2.04	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14587	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14588	 1	 3.47	 1.36	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14589	 1	 7.61	 2.99	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14590	 1	 3.28	 0.75	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14591	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14592	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14593	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14594	 1	 3.88	 1.78	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14595	 1	 9.71	 4.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14596	 1	 2.84	 1.38	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14597	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14598	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14599	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14600	 1	 6.7	 2.6	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14601	 1	 4.99	 1.13	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14602	 1	 14.76	 3.35	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14603	 1	 7.36	 2.79	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14604	 1	 3.0	 0.68	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14605	 1	 9.55	 3.66	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14606	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14607	 1	 6.69	 3.27	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14608	 1	 4.07	 1.65	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14609	 1	 4.1	 1.99	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14610	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14611	 1	 5.35	 2.03	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14612	 1	 7.78	 3.24	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14613	 1	 5.29	 1.2	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14614	 1	 5.75	 1.31	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14615	 1	 6.69	 1.52	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14616	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14617	 1	 4.68	 1.9	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14618	 1	 4.55	 1.87	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14619	 1	 8.51	 3.87	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14620	 1	 7.83	 3.47	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14621	 1	 6.4	 2.96	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14622	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14623	 1	 6.0	 2.75	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14624	 1	 3.05	 1.26	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14625	 1	 5.23	 2.44	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14626	 1	 3.46	 1.4	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14627	 1	 4.6	 1.92	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14628	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14629	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14630	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14631	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14632	 1	 8.08	 3.25	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14633	 1	 11.52	 4.48	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14634	 1	 11.45	 2.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14635	 1	 4.43	 2.12	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14636	 1	 6.49	 2.62	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14637	 1	 5.09	 2.4	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14638	 1	 10.83	 4.3	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14639	 1	 11.39	 4.69	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14640	 1	 6.47	 2.81	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14641	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14642	 1	 8.78	 3.69	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14643	 1	 9.59	 4.41	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14644	 1	 9.84	 4.64	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14645	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14646	 1	 6.69	 3.28	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14647	 1	 5.22	 2.26	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14648	 1	 2.35	 1.2	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14649	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14650	 1	 5.43	 2.24	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14651	 1	 7.49	 3.53	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14652	 1	 5.52	 2.42	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14653	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14654	 1	 15.67	 6.17	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14655	 1	 2.07	 1.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14656	 1	 5.62	 2.52	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14657	 1	 3.96	 1.76	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14658	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14659	 1	 48.93	 17.58	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14660	 1	 8.25	 3.57	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14661	 1	 10.59	 4.96	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14662	 1	 14.91	 6.47	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14663	 1	 6.53	 2.7	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14664	 1	 8.78	 4.36	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14665	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14666	 1	 6.63	 3.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14667	 1	 3.96	 1.93	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14668	 1	 6.36	 3.28	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14669	 1	 6.75	 3.49	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14670	 1	 13.63	 5.41	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14671	 1	 8.76	 3.47	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14672	 1	 8.01	 4.2	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14673	 1	 7.88	 3.47	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14674	 1	 3.0	 1.53	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14675	 1	 5.04	 2.57	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14676	 1	 5.28	 2.14	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14677	 1	 5.04	 2.19	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14678	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14679	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14680	 1	 4.93	 2.35	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14681	 1	 4.1	 2.08	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14682	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14683	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14684	 1	 4.84	 2.21	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14685	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14686	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14687	 1	 8.1	 3.74	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14688	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14689	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14690	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14691	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14692	 1	 4.34	 2.09	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14693	 1	 3.51	 1.81	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14694	 1	 3.88	 1.71	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14695	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14696	 1	 4.13	 2.21	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14697	 1	 5.27	 2.68	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14698	 1	 6.92	 3.28	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14699	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14700	 1	 3.08	 1.25	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14701	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14702	 1	 8.48	 4.23	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14703	 1	 4.03	 1.76	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14704	 1	 6.04	 2.39	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14705	 1	 4.21	 2.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14706	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14707	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14708	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14709	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14710	 1	 6.48	 3.11	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14711	 1	 9.35	 4.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14712	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14713	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14714	 1	 4.41	 2.23	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14715	 1	 8.84	 3.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14716	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14717	 1	 7.05	 3.23	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14718	 1	 2.44	 1.3	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14719	 1	 2.89	 1.33	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14720	 1	 9.37	 3.61	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14721	 1	 7.16	 3.07	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14722	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14723	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14724	 1	 5.92	 2.72	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14725	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14726	 1	 7.37	 3.68	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14727	 1	 4.53	 1.87	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14728	 1	 7.0	 2.84	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14729	 1	 6.54	 3.12	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14730	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14731	 1	 5.52	 2.55	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14732	 1	 10.57	 4.13	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14733	 1	 4.57	 2.32	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14734	 1	 3.89	 1.57	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14735	 1	 5.46	 2.52	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14736	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14737	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14738	 1	 7.58	 3.39	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14739	 1	 3.67	 1.51	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14740	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14741	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14742	 1	 9.57	 4.61	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14743	 1	 4.33	 2.29	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14744	 1	 4.87	 2.41	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14745	 1	 4.38	 2.29	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14746	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14747	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14748	 1	 2.08	 0.98	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14749	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14750	 1	 10.76	 5.37	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14751	 1	 6.07	 3.25	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14752	 1	 5.95	 2.65	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14753	 1	 4.39	 1.95	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14754	 1	 10.29	 4.01	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14755	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14756	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14757	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14758	 1	 8.01	 3.58	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14759	 1	 6.26	 2.94	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14760	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14761	 1	 13.23	 5.01	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14762	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14763	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14764	 1	 3.88	 1.56	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14765	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14766	 1	 5.38	 2.58	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14767	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14768	 1	 9.57	 4.1	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14769	 1	 16.19	 7.33	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14770	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14771	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14772	 1	 3.23	 1.52	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14773	 1	 7.86	 3.67	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14774	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14775	 1	 6.97	 2.48	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14776	 1	 4.32	 2.06	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14777	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14778	 1	 4.0	 1.73	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14779	 1	 5.73	 2.84	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14780	 1	 7.32	 2.95	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14781	 1	 8.46	 3.42	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14782	 1	 3.63	 1.86	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14783	 1	 3.29	 1.22	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14784	 1	 5.36	 2.6	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14785	 1	 9.12	 3.86	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14786	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14787	 1	 9.64	 3.86	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14788	 1	 8.9	 4.26	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14789	 1	 6.9	 2.99	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14790	 1	 7.74	 3.15	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14791	 1	 6.97	 3.16	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14792	 1	 4.34	 2.13	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14793	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14794	 1	 2.02	 0.92	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14795	 1	 3.72	 1.02	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14796	 1	 4.08	 2.1	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14797	 1	 5.0	 2.28	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14798	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14799	 1	 6.42	 2.98	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14800	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14801	 1	 4.52	 2.42	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14802	 1	 6.29	 3.14	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14803	 1	 2.65	 1.28	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14804	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14805	 1	 8.16	 3.26	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14806	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14807	 1	 7.29	 2.94	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14808	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14809	 1	 5.6	 2.82	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14810	 1	 16.03	 7.64	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14811	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14812	 1	 8.02	 3.6	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14813	 1	 6.68	 3.4	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14814	 1	 3.22	 1.66	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14815	 1	 5.5	 2.3	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14816	 1	 10.55	 3.74	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14817	 1	 4.47	 1.65	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14818	 1	 4.04	 1.95	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14819	 1	 6.93	 3.29	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14820	 1	 2.92	 1.42	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14821	 1	 4.7	 2.13	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14822	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14823	 1	 5.83	 3.09	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14824	 1	 11.09	 5.16	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14825	 1	 5.03	 2.1	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14826	 1	 5.54	 2.88	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14827	 1	 19.94	 7.8	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14828	 1	 11.45	 5.7	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14829	 1	 7.95	 3.8	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14830	 1	 5.46	 2.16	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14831	 1	 9.73	 3.79	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14832	 1	 7.31	 2.95	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14833	 1	 3.57	 1.77	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14834	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14835	 1	 7.65	 3.05	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14836	 1	 9.36	 3.48	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14837	 1	 4.49	 1.94	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14838	 1	 3.79	 1.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14839	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14840	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14841	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14842	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14843	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14844	 1	 2.91	 1.57	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14845	 1	 6.18	 2.77	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14846	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14847	 1	 7.6	 3.76	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14848	 1	 5.26	 2.78	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14849	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14850	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14851	 1	 7.02	 3.52	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14852	 1	 3.25	 1.46	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14853	 1	 2.85	 1.35	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14854	 1	 5.33	 2.29	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14855	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14856	 1	 11.51	 5.24	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14857	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14858	 1	 9.61	 3.5	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14859	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14860	 1	 3.45	 1.76	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14861	 1	 7.05	 3.3	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14862	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14863	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14864	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14865	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14866	 1	 6.24	 2.76	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14867	 1	 10.55	 5.78	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14868	 1	 9.43	 4.21	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14869	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14870	 1	 5.79	 2.76	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14871	 1	 11.58	 4.94	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14872	 1	 7.4	 3.21	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14873	 1	 8.31	 3.71	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14874	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14875	 1	 10.11	 4.98	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14876	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14877	 1	 7.28	 3.72	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14878	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14879	 1	 5.62	 2.4	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14880	 1	 5.54	 2.49	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14881	 1	 4.79	 2.46	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14882	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14883	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14884	 1	 5.09	 2.35	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14885	 1	 4.03	 1.97	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14886	 1	 3.02	 1.38	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14887	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14888	 1	 7.13	 3.24	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14889	 1	 4.65	 2.1	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14890	 1	 9.05	 4.38	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14891	 1	 5.14	 2.22	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14892	 1	 5.7	 2.41	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14893	 1	 5.68	 3.19	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14894	 1	 5.96	 3.02	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14895	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14896	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14897	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14898	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14899	 1	 8.05	 3.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14900	 1	 3.89	 2.1	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14901	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14902	 1	 5.22	 2.32	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14903	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14904	 1	 4.08	 1.82	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14905	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14906	 1	 4.14	 1.95	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14907	 1	 5.32	 2.75	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14908	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14909	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14910	 1	 4.82	 2.08	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14911	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14912	 1	 10.93	 4.95	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14913	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14914	 1	 4.48	 2.12	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14915	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14916	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14917	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14918	 1	 3.09	 1.23	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14919	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14920	 1	 3.97	 1.65	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14921	 1	 8.61	 3.12	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14922	 1	 4.65	 1.99	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14923	 1	 9.63	 4.23	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14924	 1	 12.81	 5.46	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14925	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14926	 1	 5.27	 2.37	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14927	 1	 10.99	 4.06	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14928	 1	 7.63	 3.47	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14929	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14930	 1	 7.99	 3.72	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14931	 1	 4.92	 2.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14932	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14933	 1	 1.22	 0.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14934	 1	 5.07	 2.26	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14935	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14936	 1	 6.04	 2.52	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14937	 1	 8.05	 3.2	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14938	 1	 6.29	 2.86	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14939	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14940	 1	 4.64	 2.1	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14941	 1	 5.41	 2.35	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14942	 1	 3.04	 1.49	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14943	 1	 4.22	 1.87	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14944	 1	 6.23	 3.03	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14945	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14946	 1	 4.83	 2.22	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14947	 1	 3.76	 1.73	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14948	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14949	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14950	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14951	 1	 7.48	 3.67	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14952	 1	 4.56	 1.89	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14953	 1	 9.23	 4.21	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14954	 1	 2.81	 1.29	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14955	 1	 3.45	 1.85	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14956	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14957	 1	 8.19	 3.83	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14958	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14959	 1	 5.27	 2.39	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14960	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14961	 1	 3.46	 1.79	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14962	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14963	 1	 3.26	 1.72	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14964	 1	 4.2	 2.15	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14965	 1	 2.77	 1.33	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14966	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14967	 1	 5.28	 2.55	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14968	 1	 8.64	 3.49	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14969	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14970	 1	 10.49	 4.05	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14971	 1	 11.03	 4.58	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14972	 1	 4.84	 2.28	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14973	 1	 5.8	 2.08	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14974	 1	 3.78	 1.96	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14975	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14976	 1	 4.51	 2.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14977	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14978	 1	 4.98	 2.7	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14979	 1	 3.6	 1.96	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14980	 1	 10.31	 4.39	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14981	 1	 11.8	 6.07	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14982	 1	 5.14	 2.56	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14983	 1	 4.23	 2.33	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14984	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14985	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14986	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	14987	 1	 5.29	 2.35	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14988	 1	 4.45	 2.12	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14989	 1	 5.35	 2.72	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14990	 1	 5.37	 2.22	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14991	 1	 3.4	 1.91	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14992	 1	 4.43	 2.2	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	14993	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14994	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14995	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14996	 1	 25.24	 8.55	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14997	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	14998	 1	 12.2	 6.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14999	 1	 3.88	 2.01	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15000	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15001	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	15002	 1	 23.66	 10.2	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15003	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15004	 1	 4.11	 1.88	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15005	 1	 2.7	 1.24	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15006	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15007	 1	 11.08	 4.83	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15008	 1	 4.63	 1.98	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15009	 1	 13.18	 5.99	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15010	 1	 8.75	 4.3	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15011	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15012	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15013	 1	 6.42	 2.5	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15014	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15015	 1	 6.65	 3.08	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15016	 1	 5.1	 2.12	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15017	 1	 1.3	 0.69	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15018	 1	 3.81	 1.65	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15019	 1	 8.76	 3.62	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15020	 1	 16.11	 6.12	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15021	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15022	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15023	 1	 3.47	 1.55	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15024	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15025	 1	 7.43	 3.93	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15026	 1	 2.96	 1.61	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15027	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15028	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15029	 1	 2.67	 1.29	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15030	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15031	 1	 4.26	 1.7	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15032	 1	 5.43	 2.25	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15033	 1	 4.94	 2.25	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15034	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15035	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15036	 1	 18.16	 8.08	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15037	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15038	 1	 2.82	 1.21	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15039	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15040	 1	 6.8	 2.54	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15041	 1	 8.2	 2.9	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15042	 1	 6.17	 2.72	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15043	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15044	 1	 5.83	 1.33	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15045	 1	 5.07	 2.75	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15046	 1	 4.27	 0.97	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15047	 1	 4.46	 1.01	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15048	 1	 5.31	 1.21	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15049	 1	 15.59	 7.01	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15050	 1	 15.87	 5.97	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15051	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15052	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15053	 1	 3.45	 1.79	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15054	 1	 7.57	 2.91	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15055	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15056	 1	 6.96	 1.57	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15057	 1	 4.92	 1.11	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15058	 1	 3.23	 0.73	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15059	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15060	 1	 10.48	 2.38	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15061	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15062	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15063	 1	 7.58	 1.71	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15064	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15065	 1	 5.95	 2.33	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15066	 1	 13.89	 3.15	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15067	 1	 8.8	 4.12	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15068	 1	 10.58	 4.09	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15069	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15070	 1	 6.48	 3.24	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15071	 1	 10.19	 2.29	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15072	 1	 4.59	 1.03	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15073	 1	 12.41	 2.79	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15074	 1	 4.94	 1.11	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15075	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15076	 1	 3.92	 0.89	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15077	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15078	 1	 5.34	 1.21	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15079	 1	 14.95	 3.37	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15080	 1	 2.59	 0.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15081	 1	 15.08	 3.4	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15082	 1	 6.76	 1.53	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15083	 1	 7.2	 1.63	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15084	 1	 4.36	 0.99	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15085	 1	 3.53	 0.8	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15086	 1	 9.56	 2.17	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15087	 1	 5.17	 1.17	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15088	 1	 7.06	 1.6	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15089	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	15090	 1	 8.08	 1.83	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15091	 1	 2.95	 0.67	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15092	 1	 3.65	 1.74	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15093	 1	 9.66	 3.99	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15094	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	15095	 1	 5.29	 2.48	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15096	 1	 18.33	 6.52	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15097	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15098	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15099	 1	 7.04	 2.75	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15100	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15101	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15102	 1	 5.05	 2.21	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15103	 1	 5.53	 2.33	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15104	 1	 4.75	 2.52	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15105	 1	 14.73	 6.84	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15106	 1	 4.71	 2.41	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15107	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15108	 1	 1.87	 0.98	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15109	 1	 6.94	 3.36	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15110	 1	 5.81	 3.17	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15111	 1	 7.48	 3.42	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15112	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15113	 1	 11.27	 4.52	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15114	 1	 8.29	 4.26	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15115	 1	 5.03	 2.24	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15116	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15117	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	15118	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15119	 1	 8.1	 3.48	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15120	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15121	 1	 18.8	 6.84	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15122	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15123	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15124	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15125	 1	 5.25	 2.67	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15126	 1	 2.41	 1.23	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15127	 1	 5.59	 2.5	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15128	 1	 8.33	 3.95	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15129	 1	 5.2	 2.39	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15130	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15131	 1	 4.9	 2.38	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15132	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15133	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15134	 1	 8.33	 3.66	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15135	 1	 9.55	 3.64	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15136	 1	 8.66	 3.91	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15137	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15138	 1	 9.07	 4.1	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15139	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15140	 1	 13.96	 4.99	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15141	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15142	 1	 3.08	 1.33	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15143	 1	 3.19	 1.67	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15144	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15145	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15146	 1	 5.83	 2.76	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15147	 1	 4.59	 1.95	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15148	 1	 4.98	 2.61	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15149	 1	 5.0	 2.5	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15150	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15151	 1	 7.52	 4.13	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15152	 1	 9.54	 4.84	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15153	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15154	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15155	 1	 5.85	 3.11	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15156	 1	 3.23	 1.42	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15157	 1	 4.96	 2.02	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15158	 1	 4.62	 2.06	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15159	 1	 3.48	 1.74	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15160	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15161	 1	 2.93	 1.24	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15162	 1	 17.71	 7.37	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15163	 1	 5.99	 2.69	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15164	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15165	 1	 5.63	 2.63	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15166	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15167	 1	 4.82	 2.02	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15168	 1	 17.22	 6.86	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15169	 1	 14.65	 6.17	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15170	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15171	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15172	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15173	 1	 6.85	 2.89	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15174	 1	 7.14	 2.87	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15175	 1	 7.22	 2.82	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15176	 1	 5.5	 2.42	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15177	 1	 10.35	 4.25	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15178	 1	 7.65	 2.73	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15179	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15180	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15181	 1	 9.07	 4.33	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15182	 1	 6.13	 2.92	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15183	 1	 4.21	 1.92	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15184	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15185	 1	 3.47	 1.86	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15186	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15187	 1	 4.84	 2.27	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15188	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15189	 1	 5.31	 2.18	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15190	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15191	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15192	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15193	 1	 19.88	 9.11	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15194	 1	 3.5	 1.84	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15195	 1	 6.97	 3.13	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15196	 1	 4.27	 0.97	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15197	 1	 6.57	 3.04	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15198	 1	 2.83	 1.44	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15199	 1	 5.67	 2.13	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15200	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15201	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15202	 1	 4.45	 2.16	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15203	 1	 5.47	 2.63	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15204	 1	 8.87	 3.52	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15205	 1	 10.22	 4.84	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15206	 1	 4.36	 0.99	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15207	 1	 6.0	 1.36	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15208	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15209	 1	 6.72	 3.21	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15210	 1	 7.96	 3.22	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15211	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15212	 1	 9.31	 4.42	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15213	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15214	 1	 2.91	 1.54	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15215	 1	 7.78	 3.35	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15216	 1	 13.64	 5.5	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15217	 1	 3.39	 1.76	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15218	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15219	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15220	 1	 14.4	 6.54	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15221	 1	 10.27	 4.39	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15222	 1	 6.75	 1.53	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15223	 1	 6.58	 3.19	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15224	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15225	 1	 2.84	 1.1	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15226	 1	 9.7	 3.87	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15227	 1	 7.84	 3.29	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15228	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15229	 1	 4.55	 1.82	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15230	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15231	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15232	 1	 5.21	 1.98	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15233	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15234	 1	 7.05	 3.43	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15235	 1	 4.95	 2.28	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15236	 1	 4.51	 2.3	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15237	 1	 7.24	 2.79	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15238	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15239	 1	 5.68	 2.47	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15240	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15241	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15242	 1	 10.32	 3.88	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15243	 1	 7.16	 3.04	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15244	 1	 14.41	 6.09	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15245	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15246	 1	 12.77	 5.39	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15247	 1	 3.5	 1.56	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15248	 1	 8.44	 3.95	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15249	 1	 7.79	 3.05	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15250	 1	 7.5	 1.68	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15251	 1	 7.94	 3.74	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15252	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	15253	 1	 7.06	 3.44	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15254	 1	 10.97	 5.14	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15255	 1	 3.9	 2.01	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15256	 1	 9.22	 4.62	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15257	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15258	 1	 8.24	 1.86	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15259	 1	 4.72	 1.07	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15260	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15261	 1	 2.62	 0.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15262	 1	 3.37	 0.76	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15263	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15264	 1	 4.52	 1.02	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15265	 1	 8.48	 4.09	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15266	 1	 6.4	 3.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15267	 1	 8.36	 4.07	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15268	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15269	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15270	 1	 2.85	 1.43	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15271	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15272	 1	 3.9	 1.79	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15273	 1	 7.53	 2.92	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15274	 1	 4.52	 1.76	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15275	 1	 5.0	 2.28	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15276	 1	 4.53	 1.83	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15277	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15278	 1	 7.64	 2.67	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15279	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15280	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15281	 1	 6.37	 2.46	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15282	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15283	 1	 7.28	 3.23	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15284	 1	 4.73	 1.92	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15285	 1	 1.33	 0.65	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15286	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15287	 1	 5.3	 2.24	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15288	 1	 5.13	 2.46	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15289	 1	 5.6	 2.54	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15290	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15291	 1	 6.17	 1.39	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15292	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15293	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15294	 1	 9.7	 4.48	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15295	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15296	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15297	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15298	 1	 3.44	 1.68	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15299	 1	 3.05	 0.68	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15300	 1	 4.37	 1.97	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15301	 1	 4.96	 1.11	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15302	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15303	 1	 8.68	 1.94	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15304	 1	 8.18	 1.83	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15305	 1	 12.18	 2.75	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15306	 1	 6.44	 1.44	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15307	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15308	 1	 6.11	 2.79	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15309	 1	 5.74	 2.87	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15310	 1	 8.22	 3.32	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15311	 1	 11.84	 4.85	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15312	 1	 7.19	 3.36	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15313	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15314	 1	 7.32	 3.33	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15315	 1	 2.66	 1.34	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15316	 1	 6.42	 3.26	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15317	 1	 9.74	 3.4	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15318	 1	 3.57	 1.52	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15319	 1	 7.41	 2.71	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15320	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15321	 1	 3.74	 1.79	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15322	 1	 5.48	 2.11	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15323	 1	 5.52	 2.14	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15324	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15325	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15326	 1	 5.27	 2.12	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15327	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	15328	 1	 3.96	 2.12	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15329	 1	 3.61	 1.89	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15330	 1	 4.92	 1.94	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15331	 1	 7.61	 3.42	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15332	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15333	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15334	 1	 2.97	 1.21	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15335	 1	 3.8	 1.44	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15336	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15337	 1	 7.96	 1.8	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15338	 1	 9.04	 2.04	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15339	 1	 7.93	 1.79	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15340	 1	 7.99	 1.81	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15341	 1	 14.65	 3.3	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15342	 1	 7.92	 1.79	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15343	 1	 7.36	 1.66	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15344	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15345	 1	 4.38	 1.67	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15346	 1	 13.29	 4.37	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15347	 1	 9.16	 3.74	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15348	 1	 8.46	 3.79	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15349	 1	 7.35	 2.88	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15350	 1	 5.5	 1.23	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15351	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15352	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15353	 1	 8.71	 4.1	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15354	 1	 7.77	 3.07	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15355	 1	 5.7	 2.88	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15356	 1	 1.69	 0.76	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15357	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15358	 1	 1.66	 0.76	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15359	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15360	 1	 4.71	 2.11	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15361	 1	 9.96	 3.94	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15362	 1	 7.0	 3.38	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15363	 1	 8.11	 3.65	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15364	 1	 9.28	 4.2	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15365	 1	 5.6	 2.5	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15366	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15367	 1	 4.35	 1.93	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15368	 1	 3.49	 1.71	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15369	 1	 6.51	 3.11	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15370	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	15371	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15372	 1	 3.78	 1.83	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15373	 1	 3.42	 1.87	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15374	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15375	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15376	 1	 4.47	 2.32	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15377	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15378	 1	 6.05	 2.19	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15379	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15380	 1	 7.58	 3.59	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15381	 1	 7.59	 3.37	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15382	 1	 9.41	 4.26	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15383	 1	 2.1	 1.09	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15384	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15385	 1	 10.76	 5.09	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15386	 1	 5.68	 2.28	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15387	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15388	 1	 4.78	 2.45	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15389	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15390	 1	 3.57	 1.84	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15391	 1	 10.13	 4.12	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15392	 1	 7.76	 4.17	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15393	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15394	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15395	 1	 6.07	 2.41	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15396	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15397	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15398	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15399	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15400	 1	 7.46	 3.65	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15401	 1	 4.61	 1.93	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15402	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15403	 1	 8.44	 3.25	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15404	 1	 4.24	 1.64	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15405	 1	 7.85	 3.38	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15406	 1	 4.42	 2.04	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15407	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15408	 1	 1.34	 0.71	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15409	 1	 9.09	 3.88	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15410	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15411	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15412	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15413	 1	 1.78	 0.83	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15414	 1	 6.71	 3.04	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15415	 1	 7.27	 2.89	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15416	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15417	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15418	 1	 10.93	 4.65	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15419	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15420	 1	 5.81	 2.07	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15421	 1	 15.48	 5.68	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15422	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15423	 1	 12.76	 5.15	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15424	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15425	 1	 8.69	 3.95	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15426	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15427	 1	 5.92	 2.93	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15428	 1	 3.51	 1.83	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15429	 1	 8.64	 3.44	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15430	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15431	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15432	 1	 10.54	 4.12	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15433	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15434	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15435	 1	 3.78	 1.56	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15436	 1	 9.99	 4.43	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15437	 1	 2.07	 0.95	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15438	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15439	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15440	 1	 9.75	 4.27	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15441	 1	 4.56	 2.23	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15442	 1	 7.76	 3.71	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15443	 1	 14.33	 5.66	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15444	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15445	 1	 10.57	 3.79	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15446	 1	 3.85	 0.86	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15447	 1	 4.1	 0.92	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15448	 1	 12.94	 5.6	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15449	 1	 7.09	 3.03	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15450	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15451	 1	 1.67	 0.38	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15452	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15453	 1	 7.12	 1.61	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15454	 1	 9.67	 3.92	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15455	 1	 6.24	 2.92	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15456	 1	 6.07	 2.94	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15457	 1	 5.74	 2.24	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15458	 1	 4.19	 0.95	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15459	 1	 4.94	 1.11	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15460	 1	 4.17	 0.94	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15461	 1	 6.24	 2.6	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15462	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15463	 1	 3.57	 1.86	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15464	 1	 4.54	 2.13	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15465	 1	 4.32	 0.97	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15466	 1	 6.09	 2.71	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15467	 1	 7.37	 3.33	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15468	 1	 3.59	 1.42	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15469	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	15470	 1	 8.91	 2.01	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15471	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15472	 1	 8.35	 1.89	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15473	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15474	 1	 3.46	 0.78	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15475	 1	 12.15	 5.4	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15476	 1	 12.08	 4.26	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15477	 1	 3.94	 1.78	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15478	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15479	 1	 10.13	 4.76	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15480	 1	 5.55	 2.58	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15481	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15482	 1	 16.99	 7.19	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15483	 1	 5.64	 2.68	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15484	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15485	 1	 11.42	 4.81	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15486	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15487	 1	 5.53	 2.09	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15488	 1	 7.18	 2.7	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15489	 1	 7.51	 3.35	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15490	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15491	 1	 5.38	 2.61	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15492	 1	 7.0	 2.83	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15493	 1	 17.76	 7.04	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15494	 1	 7.44	 2.93	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15495	 1	 7.03	 2.63	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15496	 1	 5.44	 2.3	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15497	 1	 9.99	 4.36	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15498	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15499	 1	 5.59	 2.67	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15500	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15501	 1	 7.84	 3.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15502	 1	 4.94	 1.96	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15503	 1	 5.61	 2.73	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15504	 1	 6.45	 2.55	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15505	 1	 3.99	 1.93	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15506	 1	 6.28	 2.82	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15507	 1	 6.58	 2.5	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15508	 1	 13.05	 5.38	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15509	 1	 7.32	 2.82	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15510	 1	 7.86	 3.4	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15511	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15512	 1	 6.02	 2.32	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15513	 1	 17.77	 6.64	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15514	 1	 9.81	 4.11	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15515	 1	 9.7	 4.52	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15516	 1	 7.96	 3.35	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15517	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15518	 1	 7.02	 1.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15519	 1	 7.05	 1.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15520	 1	 10.87	 2.45	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15521	 1	 9.87	 3.85	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15522	 1	 5.68	 2.5	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15523	 1	 5.4	 2.52	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15524	 1	 6.22	 3.07	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15525	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15526	 1	 14.88	 6.5	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15527	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15528	 1	 3.9	 1.7	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15529	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15530	 1	 5.75	 2.7	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15531	 1	 38.87	 14.72	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15532	 1	 10.32	 4.68	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15533	 1	 9.0	 4.21	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15534	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15535	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15536	 1	 6.12	 2.77	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15537	 1	 3.64	 1.41	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15538	 1	 4.22	 1.92	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15539	 1	 6.48	 3.23	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15540	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15541	 1	 7.11	 2.91	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15542	 1	 8.19	 3.91	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15543	 1	 4.96	 2.57	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15544	 1	 7.68	 3.6	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15545	 1	 7.04	 3.59	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15546	 1	 3.22	 1.79	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15547	 1	 5.69	 2.59	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15548	 1	 5.81	 2.75	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15549	 1	 9.35	 3.8	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15550	 1	 5.27	 2.58	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15551	 1	 5.19	 2.92	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15552	 1	 3.38	 1.8	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15553	 1	 9.37	 4.1	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15554	 1	 13.59	 6.53	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15555	 1	 8.1	 3.85	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15556	 1	 7.28	 3.22	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15557	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15558	 1	 4.75	 2.25	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15559	 1	 8.36	 4.28	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15560	 1	 9.56	 4.52	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15561	 1	 6.22	 2.93	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15562	 1	 9.89	 4.72	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15563	 1	 10.18	 4.51	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15564	 1	 8.47	 4.13	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15565	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15566	 1	 5.07	 2.21	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15567	 1	 2.49	 1.07	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15568	 1	 5.87	 2.42	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15569	 1	 7.03	 2.79	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15570	 1	 8.28	 3.89	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15571	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15572	 1	 7.48	 3.22	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15573	 1	 6.34	 3.05	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15574	 1	 10.54	 5.44	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15575	 1	 12.15	 5.4	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15576	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15577	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15578	 1	 1.57	 0.92	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15579	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15580	 1	 2.54	 1.34	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15581	 1	 6.42	 3.46	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15582	 1	 2.79	 1.54	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15583	 1	 7.74	 3.82	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15584	 1	 7.25	 3.68	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15585	 1	 4.12	 2.08	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15586	 1	 10.58	 3.57	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15587	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15588	 1	 6.72	 2.88	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15589	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15590	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15591	 1	 3.74	 1.77	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15592	 1	 11.61	 4.56	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15593	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15594	 1	 6.01	 2.94	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15595	 1	 2.42	 1.23	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15596	 1	 6.47	 2.74	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15597	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15598	 1	 11.83	 5.73	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15599	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15600	 1	 6.95	 3.3	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15601	 1	 11.45	 4.46	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15602	 1	 12.46	 4.69	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15603	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15604	 1	 12.16	 5.67	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15605	 1	 9.45	 4.45	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15606	 1	 14.2	 6.99	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15607	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15608	 1	 6.48	 2.97	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15609	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15610	 1	 4.99	 2.05	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15611	 1	 10.52	 4.35	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15612	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	15613	 1	 3.18	 1.79	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15614	 1	 9.84	 4.64	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15615	 1	 9.02	 3.94	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15616	 1	 4.1	 1.74	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15617	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15618	 1	 6.43	 3.01	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15619	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15620	 1	 3.7	 1.94	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15621	 1	 7.73	 3.76	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15622	 1	 18.41	 8.43	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15623	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15624	 1	 4.84	 2.61	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15625	 1	 11.52	 5.57	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15626	 1	 13.96	 6.12	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15627	 1	 6.21	 2.83	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15628	 1	 3.93	 2.09	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15629	 1	 7.63	 3.48	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15630	 1	 5.59	 2.54	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15631	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15632	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15633	 1	 2.76	 1.46	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15634	 1	 3.35	 1.67	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15635	 1	 4.66	 2.23	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15636	 1	 3.69	 1.81	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15637	 1	 2.69	 1.42	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15638	 1	 2.23	 1.13	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15639	 1	 9.44	 4.27	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15640	 1	 5.49	 2.09	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15641	 1	 11.0	 5.14	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15642	 1	 7.12	 3.18	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15643	 1	 6.13	 3.03	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15644	 1	 6.15	 2.8	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15645	 1	 4.21	 1.98	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15646	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15647	 1	 5.58	 2.19	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15648	 1	 3.8	 1.98	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15649	 1	 4.5	 2.18	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15650	 1	 3.52	 1.38	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15651	 1	 4.56	 2.02	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15652	 1	 2.03	 0.99	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15653	 1	 2.11	 1.11	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15654	 1	 5.31	 2.31	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15655	 1	 9.54	 3.3	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15656	 1	 6.96	 2.89	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15657	 1	 7.95	 2.76	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15658	 1	 21.15	 7.99	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15659	 1	 10.5	 3.65	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15660	 1	 3.47	 1.81	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15661	 1	 5.01	 2.06	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15662	 1	 1.58	 0.76	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15663	 1	 6.33	 2.27	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15664	 1	 3.44	 1.58	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15665	 1	 4.69	 2.36	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15666	 1	 3.28	 1.4	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15667	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15668	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15669	 1	 5.11	 2.25	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15670	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15671	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15672	 1	 3.54	 1.62	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15673	 1	 3.71	 1.71	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15674	 1	 4.14	 2.03	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15675	 1	 2.55	 1.16	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15676	 1	 2.54	 1.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15677	 1	 3.39	 1.39	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15678	 1	 6.32	 3.16	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15679	 1	 6.63	 2.94	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15680	 1	 6.34	 2.73	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15681	 1	 6.67	 2.56	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15682	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15683	 1	 3.37	 1.63	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15684	 1	 4.85	 1.91	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15685	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15686	 1	 5.62	 2.35	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15687	 1	 4.83	 2.32	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15688	 1	 3.51	 1.44	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15689	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15690	 1	 12.82	 5.83	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15691	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15692	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15693	 1	 4.91	 1.9	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15694	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	15695	 1	 4.77	 1.93	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15696	 1	 7.75	 3.27	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15697	 1	 8.57	 3.73	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15698	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15699	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	15700	 1	 6.71	 3.09	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15701	 1	 4.14	 2.1	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15702	 1	 5.35	 2.39	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15703	 1	 3.62	 1.74	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15704	 1	 13.25	 4.08	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15705	 1	 14.75	 6.96	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15706	 1	 4.69	 2.2	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15707	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15708	 1	 2.15	 0.84	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15709	 1	 8.33	 3.6	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15710	 1	 10.61	 4.55	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15711	 1	 4.53	 1.89	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15712	 1	 5.45	 2.3	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15713	 1	 4.97	 2.44	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15714	 1	 5.27	 2.24	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15715	 1	 3.06	 1.26	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15716	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15717	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15718	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15719	 1	 3.76	 1.55	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15720	 1	 3.21	 1.33	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15721	 1	 5.6	 2.61	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15722	 1	 4.33	 1.94	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15723	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15724	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15725	 1	 4.09	 2.21	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15726	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15727	 1	 5.12	 2.42	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15728	 1	 4.48	 2.15	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15729	 1	 3.21	 1.21	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15730	 1	 3.99	 1.94	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15731	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15732	 1	 8.65	 3.87	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15733	 1	 7.59	 3.69	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15734	 1	 4.65	 1.78	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15735	 1	 3.06	 1.38	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15736	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15737	 1	 11.3	 4.99	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15738	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15739	 1	 2.27	 1.08	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15740	 1	 2.75	 1.12	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15741	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15742	 1	 5.51	 2.17	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15743	 1	 3.39	 1.23	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15744	 1	 4.26	 1.67	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15745	 1	 4.21	 1.93	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15746	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15747	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15748	 1	 5.51	 2.17	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15749	 1	 8.24	 3.63	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15750	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15751	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15752	 1	 1.25	 0.55	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15753	 1	 8.18	 2.99	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15754	 1	 22.77	 9.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15755	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15756	 1	 12.19	 5.97	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15757	 1	 5.14	 1.89	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15758	 1	 5.12	 2.52	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15759	 1	 10.03	 3.67	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15760	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15761	 1	 7.52	 2.78	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15762	 1	 3.4	 1.78	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15763	 1	 6.74	 3.18	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15764	 1	 3.32	 1.78	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15765	 1	 6.72	 2.82	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15766	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15767	 1	 5.37	 2.4	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15768	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15769	 1	 12.62	 5.75	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15770	 1	 25.36	 10.79	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15771	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15772	 1	 11.0	 3.92	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15773	 1	 7.56	 3.04	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15774	 1	 11.12	 5.11	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15775	 1	 6.23	 2.56	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15776	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15777	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15778	 1	 11.37	 4.8	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15779	 1	 8.16	 3.97	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15780	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15781	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15782	 1	 4.51	 2.05	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15783	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15784	 1	 6.96	 3.56	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15785	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15786	 1	 11.28	 4.86	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15787	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15788	 1	 3.76	 1.27	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15789	 1	 31.53	 12.76	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15790	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15791	 1	 1.29	 0.69	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15792	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15793	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15794	 1	 4.5	 2.22	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15795	 1	 8.75	 3.3	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15796	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15797	 1	 4.82	 2.02	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15798	 1	 1.63	 0.83	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15799	 1	 4.43	 1.81	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15800	 1	 3.26	 1.54	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15801	 1	 4.66	 2.22	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15802	 1	 2.56	 1.27	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15803	 1	 7.97	 3.11	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15804	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15805	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15806	 1	 6.67	 3.34	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15807	 1	 5.7	 2.27	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15808	 1	 2.65	 1.32	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15809	 1	 6.21	 2.78	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15810	 1	 3.88	 1.69	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15811	 1	 4.82	 2.02	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15812	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15813	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15814	 1	 4.55	 1.73	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15815	 1	 11.11	 5.2	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15816	 1	 3.93	 1.69	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15817	 1	 6.45	 3.2	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15818	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15819	 1	 4.29	 1.87	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15820	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15821	 1	 4.32	 1.65	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15822	 1	 5.37	 2.58	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15823	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15824	 1	 14.11	 6.36	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15825	 1	 7.82	 3.78	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15826	 1	 9.16	 3.95	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15827	 1	 1.13	 0.51	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15828	 1	 7.88	 3.35	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15829	 1	 15.55	 7.15	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15830	 1	 8.51	 3.44	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15831	 1	 8.25	 3.43	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15832	 1	 8.48	 3.69	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15833	 1	 7.76	 3.39	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15834	 1	 8.75	 4.09	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15835	 1	 6.67	 3.15	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15836	 1	 7.85	 3.48	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15837	 1	 13.16	 4.79	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15838	 1	 23.97	 10.06	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15839	 1	 17.67	 6.96	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15840	 1	 9.48	 3.97	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15841	 1	 7.39	 2.72	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15842	 1	 3.74	 1.65	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15843	 1	 4.52	 2.27	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15844	 1	 3.15	 1.28	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15845	 1	 9.75	 4.74	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15846	 1	 5.08	 2.35	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15847	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15848	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15849	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15850	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15851	 1	 5.34	 2.69	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15852	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15853	 1	 15.22	 6.25	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15854	 1	 11.86	 2.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15855	 1	 7.26	 1.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15856	 1	 8.8	 1.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15857	 1	 11.02	 2.48	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15858	 1	 12.93	 2.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15859	 1	 10.55	 2.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15860	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15861	 1	 2.87	 0.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15862	 1	 8.48	 1.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15863	 1	 4.68	 1.05	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15864	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15865	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15866	 1	 8.52	 1.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15867	 1	 9.7	 2.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15868	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15869	 1	 6.77	 1.52	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15870	 1	 6.88	 3.82	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15871	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15872	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15873	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15874	 1	 2.75	 0.62	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15875	 1	 10.68	 2.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15876	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15877	 1	 3.77	 0.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15878	 1	 4.32	 0.95	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15879	 1	 6.46	 1.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15880	 1	 5.4	 1.19	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15881	 1	 5.24	 -4.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15882	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15883	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15884	 1	 4.19	 0.94	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15885	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15886	 1	 4.76	 1.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15887	 1	 23.68	 5.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15888	 1	 17.18	 3.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15889	 1	 13.73	 4.36	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15890	 1	 11.95	 5.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15891	 1	 5.13	 2.01	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15892	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15893	 1	 3.53	 1.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15894	 1	 5.99	 2.94	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15895	 1	 3.83	 1.73	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15896	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15897	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15898	 1	 10.85	 4.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15899	 1	 4.71	 2.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15900	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15901	 1	 2.1	 1.3	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15902	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15903	 1	 17.79	 5.63	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15904	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15905	 1	 8.1	 1.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15906	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15907	 1	 4.79	 2.1	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15908	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	15909	 1	 2.72	 1.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15910	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15911	 1	 13.46	 3.1	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15912	 1	 9.27	 2.14	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15913	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15914	 1	 17.23	 3.85	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15915	 1	 4.55	 1.02	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15916	 1	 6.17	 1.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15917	 1	 2.74	 0.63	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15918	 1	 2.57	 1.21	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15919	 1	 23.51	 5.76	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15920	 1	 3.32	 0.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15921	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15922	 1	 4.83	 2.52	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15923	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15924	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15925	 1	 14.64	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15926	 1	 6.39	 3.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15927	 1	 4.16	 2.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15928	 1	 54.76	 15.17	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15929	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15930	 1	 16.77	 5.83	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15931	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15932	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15933	 1	 15.52	 5.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15934	 1	 27.31	 8.95	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15935	 1	 7.29	 3.76	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15936	 1	 7.14	 3.01	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15937	 1	 12.3	 5.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15938	 1	 2.14	 1.17	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15939	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15940	 1	 2.74	 1.55	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15941	 1	 6.66	 2.96	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15942	 1	 5.88	 2.99	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15943	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	15944	 1	 0.13	 0.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15945	 1	 1.4	 0.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15946	 1	 2.32	 1.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15947	 1	 1.83	 1.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15948	 1	 2.01	 1.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15949	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15950	 1	 3.06	 1.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15951	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15952	 1	 1.23	 0.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15953	 1	 4.86	 2.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15954	 1	 7.82	 3.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15955	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15956	 1	 1.91	 0.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15957	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15958	 1	 3.57	 1.44	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15959	 1	 2.13	 1.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15960	 1	 0.56	 0.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15961	 1	 7.1	 3.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15962	 1	 17.94	 7.55	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15963	 1	 5.6	 2.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15964	 1	 8.13	 1.82	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15965	 1	 2.83	 0.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15966	 1	 7.91	 1.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15967	 1	 5.81	 1.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15968	 1	 3.51	 0.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15969	 1	 8.81	 1.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15970	 1	 3.57	 0.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15971	 1	 11.24	 2.52	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15972	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15973	 1	 5.36	 1.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15974	 1	 3.74	 0.83	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15975	 1	 7.87	 1.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15976	 1	 6.7	 1.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15977	 1	 19.42	 4.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15978	 1	 2.64	 0.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15979	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15980	 1	 2.06	 0.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15981	 1	 3.58	 0.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15982	 1	 11.47	 2.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15983	 1	 6.37	 1.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15984	 1	 11.07	 2.48	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15985	 1	 5.51	 1.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15986	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15987	 1	 17.32	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15988	 1	 12.25	 2.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15989	 1	 8.61	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15990	 1	 7.92	 1.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15991	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15992	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	15993	 1	 3.39	 0.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15994	 1	 3.97	 0.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15995	 1	 3.79	 0.85	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15996	 1	 3.86	 0.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15997	 1	 8.1	 1.83	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15998	 1	 5.35	 1.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	15999	 1	 3.03	 0.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16000	 1	 5.56	 1.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16001	 1	 4.7	 1.06	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16002	 1	 3.23	 0.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16003	 1	 3.53	 0.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16004	 1	 6.98	 1.59	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16005	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16006	 1	 5.15	 1.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16007	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16008	 1	 4.25	 0.99	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16009	 1	 3.94	 0.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16010	 1	 8.61	 1.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16011	 1	 12.61	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16012	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16013	 1	 8.97	 1.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16014	 1	 6.37	 1.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16015	 1	 2.34	 0.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16016	 1	 4.61	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16017	 1	 4.88	 1.11	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16018	 1	 4.62	 1.06	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16019	 1	 1.3	 0.3	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16020	 1	 5.9	 1.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16021	 1	 5.62	 1.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16022	 1	 9.77	 2.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16023	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16024	 1	 9.61	 2.15	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16025	 1	 3.39	 0.76	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16026	 1	 22.3	 4.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16027	 1	 8.0	 1.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16028	 1	 7.35	 1.63	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16029	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16030	 1	 6.36	 1.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16031	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16032	 1	 5.48	 1.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16033	 1	 7.23	 1.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16034	 1	 4.98	 1.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16035	 1	 13.86	 3.1	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16036	 1	 4.18	 0.92	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16037	 1	 64.77	 14.5	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16038	 1	 11.86	 5.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16039	 1	 6.12	 3.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16040	 1	 1.41	 0.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16041	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16042	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16043	 1	 4.22	 2.51	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16044	 1	 6.34	 2.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16045	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16046	 1	 5.81	 3.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16047	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16048	 1	 5.35	 2.95	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16049	 1	 11.07	 4.72	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16050	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16051	 1	 52.24	 18.96	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16052	 1	 6.02	 3.43	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16053	 1	 3.84	 2.1	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16054	 1	 17.03	 6.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16055	 1	 2.7	 1.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16056	 1	 7.35	 3.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16057	 1	 2.78	 1.36	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16058	 1	 8.12	 2.52	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16059	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16060	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16061	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16062	 1	 4.75	 2.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16063	 1	 10.4	 5.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16064	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16065	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16066	 1	 8.04	 3.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16067	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16068	 1	 4.56	 1.69	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16069	 1	 4.89	 2.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16070	 1	 2.21	 1.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16071	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16072	 1	 6.75	 2.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16073	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16074	 1	 5.2	 2.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16075	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16076	 1	 22.78	 5.19	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16077	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16078	 1	 44.0	 9.76	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16079	 1	 7.55	 1.72	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16080	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16081	 1	 15.83	 3.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16082	 1	 9.72	 2.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16083	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16084	 1	 3.14	 1.46	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16085	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16086	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16087	 1	 12.87	 2.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16088	 1	 10.1	 4.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16089	 1	 7.1	 1.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16090	 1	 5.64	 1.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16091	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16092	 1	 5.51	 2.32	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16093	 1	 9.6	 3.9	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16094	 1	 2.33	 -4.39	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16095	 1	 4.39	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16096	 1	 2.59	 0.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16097	 1	 1.03	 0.23	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16098	 1	 14.39	 3.15	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16099	 1	 2.66	 0.59	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16100	 1	 6.66	 1.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16101	 1	 8.34	 1.82	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16102	 1	 12.13	 2.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16103	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16104	 1	 11.41	 2.52	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16105	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16106	 1	 1.64	 0.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16107	 1	 1.89	 0.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16108	 1	 1.51	 0.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16109	 1	 1.11	 0.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16110	 1	 0.87	 0.53	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16111	 1	 1.52	 0.79	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16112	 1	 2.21	 0.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16113	 1	 3.66	 0.82	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16114	 1	 1.63	 0.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16115	 1	 3.43	 0.78	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16116	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16117	 1	 5.93	 1.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16118	 1	 2.01	 0.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16119	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16120	 1	 1.68	 0.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16121	 1	 4.33	 0.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16122	 1	 2.93	 0.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16123	 1	 0.98	 0.23	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16124	 1	 1.96	 0.89	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16125	 1	 1.03	 0.56	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16126	 1	 0.3	 0.17	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16127	 1	 1.14	 0.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16128	 1	 1.25	 0.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16129	 1	 3.07	 0.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16130	 1	 3.37	 1.88	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16131	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16132	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16133	 1	 2.25	 1.45	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16134	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16135	 1	 4.07	 2.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16136	 1	 7.05	 3.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16137	 1	 20.76	 7.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16138	 1	 4.09	 2.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16139	 1	 70.96	 23.78	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16140	 1	 5.09	 2.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16141	 1	 5.88	 2.82	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16142	 1	 4.66	 2.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16143	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16144	 1	 9.51	 3.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16145	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16146	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16147	 1	 3.18	 1.61	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16148	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16149	 1	 11.02	 3.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16150	 1	 10.12	 4.3	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16151	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	16152	 1	 10.02	 3.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16153	 1	 13.2	 5.55	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16154	 1	 21.46	 7.56	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16155	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16156	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16157	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16158	 1	 9.05	 3.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16159	 1	 14.04	 4.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16160	 1	 5.82	 3.36	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16161	 1	 8.26	 2.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16162	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16163	 1	 9.88	 3.35	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16164	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16165	 1	 5.72	 3.09	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16166	 1	 9.94	 2.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16167	 1	 6.53	 3.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16168	 1	 3.97	 2.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16169	 1	 2.48	 0.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16170	 1	 3.28	 0.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16171	 1	 9.42	 2.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16172	 1	 5.96	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16173	 1	 10.22	 2.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16174	 1	 14.75	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16175	 1	 10.17	 3.45	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16176	 1	 17.6	 7.19	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16177	 1	 4.17	 2.15	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16178	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16179	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16180	 1	 9.33	 4.62	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16181	 1	 15.41	 4.69	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16182	 1	 2.07	 1.38	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16183	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16184	 1	 4.86	 2.39	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16185	 1	 5.76	 2.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16186	 1	 6.43	 2.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16187	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16188	 1	 8.04	 1.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16189	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16190	 1	 5.66	 2.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16191	 1	 11.43	 4.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16192	 1	 5.12	 2.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16193	 1	 2.37	 1.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16194	 1	 5.01	 2.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16195	 1	 4.27	 2.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16196	 1	 4.95	 2.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16197	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16198	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16199	 1	 10.44	 4.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16200	 1	 15.56	 5.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16201	 1	 16.64	 6.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16202	 1	 8.85	 2.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16203	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16204	 1	 10.04	 3.69	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16205	 1	 9.16	 2.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16206	 1	 11.34	 5.82	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16207	 1	 15.7	 6.02	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16208	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16209	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16210	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16211	 1	 2.53	 1.6	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16212	 1	 3.73	 1.85	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16213	 1	 12.44	 4.85	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16214	 1	 55.89	 14.57	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16215	 1	 2.28	 1.1	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16216	 1	 2.84	 1.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16217	 1	 3.45	 2.09	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16218	 1	 3.86	 1.97	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16219	 1	 12.34	 2.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16220	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16221	 1	 6.64	 1.51	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16222	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16223	 1	 16.97	 3.83	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16224	 1	 4.61	 1.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16225	 1	 13.75	 3.04	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16226	 1	 5.24	 1.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16227	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16228	 1	 7.53	 3.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16229	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16230	 1	 15.23	 3.48	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16231	 1	 6.46	 3.47	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16232	 1	 3.7	 2.1	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16233	 1	 3.97	 1.78	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16234	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16235	 1	 19.33	 6.1	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16236	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16237	 1	 1.57	 0.76	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16238	 1	 4.0	 1.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16239	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16240	 1	 10.29	 5.38	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16241	 1	 4.66	 2.18	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16242	 1	 9.86	 5.09	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16243	 1	 3.48	 1.92	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16244	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	16245	 1	 4.64	 2.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16246	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16247	 1	 3.22	 1.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16248	 1	 8.88	 3.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16249	 1	 14.38	 5.43	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16250	 1	 6.18	 2.97	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16251	 1	 9.23	 3.99	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16252	 1	 6.32	 2.69	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16253	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16254	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16255	 1	 4.82	 2.2	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16256	 1	 4.91	 2.85	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16257	 1	 22.86	 10.26	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16258	 1	 32.48	 11.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16259	 1	 18.5	 6.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16260	 1	 8.23	 3.79	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16261	 1	 9.14	 3.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16262	 1	 10.58	 5.47	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16263	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16264	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16265	 1	 2.74	 1.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16266	 1	 6.72	 3.26	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16267	 1	 3.68	 1.95	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16268	 1	 8.83	 3.86	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16269	 1	 7.3	 3.18	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16270	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16271	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16272	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16273	 1	 3.93	 1.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16274	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16275	 1	 10.07	 4.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16276	 1	 9.49	 4.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16277	 1	 7.51	 4.06	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16278	 1	 5.21	 3.15	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16279	 1	 11.5	 4.69	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16280	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16281	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16282	 1	 3.88	 2.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16283	 1	 13.58	 7.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16284	 1	 3.27	 1.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16285	 1	 4.28	 2.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16286	 1	 4.53	 2.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16287	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16288	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16289	 1	 6.3	 3.03	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16290	 1	 7.72	 3.94	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16291	 1	 5.82	 2.94	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16292	 1	 5.97	 3.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16293	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16294	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16295	 1	 6.76	 2.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16296	 1	 6.51	 3.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16297	 1	 4.67	 2.85	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16298	 1	 3.21	 1.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16299	 1	 5.93	 2.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16300	 1	 6.27	 3.62	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16301	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16302	 1	 28.13	 9.75	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16303	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	16304	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16305	 1	 0.93	 0.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16306	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16307	 1	 2.6	 1.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16308	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16309	 1	 4.02	 2.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16310	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16311	 1	 8.75	 4.1	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16312	 1	 13.2	 5.04	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16313	 1	 53.13	 17.44	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16314	 1	 0.37	 0.1	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16315	 1	 0.86	 0.44	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16316	 1	 0.9	 0.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16317	 1	 1.31	 0.3	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16318	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16319	 1	 3.61	 0.83	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16320	 1	 13.01	 4.74	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16321	 1	 2.91	 0.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16322	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16323	 1	 4.42	 1.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16324	 1	 6.76	 2.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16325	 1	 5.24	 2.69	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16326	 1	 8.06	 4.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16327	 1	 4.97	 1.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16328	 1	 5.95	 1.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16329	 1	 5.4	 1.29	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16330	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16331	 1	 1.74	 0.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16332	 1	 4.79	 2.46	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16333	 1	 7.99	 4.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16334	 1	 8.93	 3.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16335	 1	 2.06	 1.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16336	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16337	 1	 5.15	 2.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16338	 1	 3.88	 2.26	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16339	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16340	 1	 7.99	 3.32	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16341	 1	 5.45	 3.23	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16342	 1	 8.51	 4.21	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16343	 1	 9.19	 3.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16344	 1	 2.86	 1.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16345	 1	 6.9	 2.92	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16346	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16347	 1	 11.57	 4.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16348	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16349	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16350	 1	 10.97	 4.96	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16351	 1	 2.43	 1.48	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16352	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16353	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16354	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16355	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16356	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16357	 1	 8.5	 4.39	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16358	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16359	 1	 7.21	 3.93	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16360	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	16361	 1	 6.79	 3.37	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16362	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16363	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16364	 1	 8.43	 4.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16365	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16366	 1	 10.79	 5.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16367	 1	 7.83	 4.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16368	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16369	 1	 5.25	 2.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16370	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16371	 1	 13.31	 5.04	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16372	 1	 7.47	 4.09	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16373	 1	 13.37	 7.12	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16374	 1	 7.83	 3.26	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16375	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16376	 1	 13.23	 5.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16377	 1	 6.05	 2.98	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16378	 1	 3.92	 2.15	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16379	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16380	 1	 4.33	 2.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16381	 1	 9.48	 4.15	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16382	 1	 3.54	 1.82	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16383	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16384	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16385	 1	 3.85	 2.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16386	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16387	 1	 2.13	 1.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16388	 1	 3.78	 1.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16389	 1	 3.45	 1.65	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16390	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16391	 1	 5.77	 2.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16392	 1	 15.68	 5.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16393	 1	 9.28	 3.87	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16394	 1	 5.01	 2.24	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16395	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16396	 1	 7.68	 3.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16397	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16398	 1	 3.13	 1.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16399	 1	 12.23	 4.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16400	 1	 3.04	 1.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16401	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16402	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16403	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16404	 1	 1.65	 0.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16405	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16406	 1	 5.76	 3.15	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16407	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16408	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16409	 1	 4.98	 2.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16410	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16411	 1	 3.39	 2.12	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16412	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16413	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16414	 1	 10.77	 4.78	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16415	 1	 25.93	 10.91	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16416	 1	 17.25	 6.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16417	 1	 6.99	 3.34	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16418	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16419	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16420	 1	 18.85	 8.03	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16421	 1	 2.42	 1.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16422	 1	 6.29	 3.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16423	 1	 2.9	 1.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16424	 1	 13.4	 5.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16425	 1	 3.81	 1.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16426	 1	 10.86	 4.92	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16427	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16428	 1	 7.39	 1.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16429	 1	 8.96	 4.85	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16430	 1	 18.93	 4.32	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16431	 1	 5.01	 2.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16432	 1	 5.07	 2.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16433	 1	 7.13	 2.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16434	 1	 3.25	 1.69	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16435	 1	 4.97	 2.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16436	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16437	 1	 6.24	 3.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16438	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16439	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	16440	 1	 20.19	 7.37	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16441	 1	 15.84	 5.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16442	 1	 2.0	 1.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16443	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	16444	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16445	 1	 13.67	 3.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16446	 1	 10.29	 2.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16447	 1	 15.25	 3.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16448	 1	 2.3	 0.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16449	 1	 3.16	 0.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16450	 1	 2.5	 0.55	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16451	 1	 4.57	 1.02	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16452	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16453	 1	 19.07	 4.23	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16454	 1	 22.2	 4.94	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16455	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16456	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16457	 1	 2.46	 0.56	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16458	 1	 13.39	 5.72	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16459	 1	 8.18	 2.68	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16460	 1	 1.53	 0.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16461	 1	 3.31	 1.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16462	 1	 4.0	 1.76	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16463	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16464	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16465	 1	 12.65	 5.35	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16466	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16467	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16468	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16469	 1	 11.33	 4.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16470	 1	 4.52	 2.09	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16471	 1	 2.53	 1.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16472	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16473	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	16474	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	16475	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16476	 1	 9.36	 3.92	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16477	 1	 12.74	 4.59	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16478	 1	 5.37	 2.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16479	 1	 3.79	 1.58	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16480	 1	 3.86	 1.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16481	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16482	 1	 2.61	 1.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16483	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16484	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16485	 1	 2.2	 1.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16486	 1	 2.35	 1.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16487	 1	 4.28	 1.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16488	 1	 10.77	 4.62	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16489	 1	 6.78	 3.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16490	 1	 5.42	 3.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16491	 1	 9.28	 3.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16492	 1	 12.68	 5.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16493	 1	 5.39	 2.59	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16494	 1	 3.96	 1.85	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16495	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16496	 1	 4.28	 2.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16497	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16498	 1	 3.57	 1.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16499	 1	 5.8	 2.99	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16500	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	16501	 1	 1.83	 0.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16502	 1	 10.15	 4.83	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16503	 1	 9.27	 3.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16504	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16505	 1	 16.36	 7.77	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16506	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	16507	 1	 2.63	 1.38	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	16508	 1	 14.56	 6.09	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16509	 1	 11.21	 4.93	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16510	 1	 10.99	 4.54	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16511	 1	 12.11	 4.16	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16512	 1	 7.23	 3.72	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16513	 1	 6.7	 3.41	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16514	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16515	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16516	 1	 3.86	 1.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16517	 1	 3.16	 1.44	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16518	 1	 3.78	 1.54	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16519	 1	 2.7	 1.69	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16520	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16521	 1	 5.69	 2.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16522	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16523	 1	 9.83	 3.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16524	 1	 19.43	 6.98	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16525	 1	 10.89	 4.97	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16526	 1	 12.78	 6.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16527	 1	 3.84	 1.92	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16528	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16529	 1	 4.32	 2.36	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16530	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16531	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16532	 1	 2.99	 1.44	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16533	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16534	 1	 14.13	 5.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16535	 1	 3.93	 1.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16536	 1	 2.92	 1.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16537	 1	 3.06	 1.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16538	 1	 4.57	 2.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16539	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16540	 1	 6.47	 3.09	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16541	 1	 4.1	 2.23	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16542	 1	 3.75	 1.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16543	 1	 6.04	 3.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16544	 1	 6.94	 3.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16545	 1	 3.49	 1.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16546	 1	 5.72	 2.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16547	 1	 3.54	 1.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16548	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16549	 1	 2.96	 1.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16550	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16551	 1	 3.96	 2.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16552	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16553	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16554	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16555	 1	 2.51	 1.4	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16556	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16557	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16558	 1	 13.65	 5.99	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16559	 1	 8.6	 4.7	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16560	 1	 4.0	 1.91	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16561	 1	 5.43	 2.17	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16562	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16563	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16564	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16565	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16566	 1	 5.64	 2.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16567	 1	 4.57	 2.07	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16568	 1	 15.21	 5.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16569	 1	 2.64	 1.33	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16570	 1	 3.75	 1.87	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16571	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16572	 1	 4.9	 1.59	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16573	 1	 4.82	 2.02	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16574	 1	 4.71	 1.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16575	 1	 2.19	 1.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16576	 1	 9.12	 2.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16577	 1	 2.06	 1.01	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16578	 1	 5.38	 2.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16579	 1	 4.53	 2.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16580	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16581	 1	 2.44	 1.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16582	 1	 6.38	 2.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16583	 1	 3.97	 1.61	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16584	 1	 7.11	 2.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16585	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16586	 1	 3.05	 1.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16587	 1	 5.2	 1.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16588	 1	 7.89	 3.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16589	 1	 14.06	 5.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16590	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16591	 1	 2.0	 1.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16592	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16593	 1	 14.83	 4.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16594	 1	 6.64	 2.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16595	 1	 2.74	 1.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16596	 1	 4.0	 1.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16597	 1	 7.02	 2.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16598	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16599	 1	 10.55	 3.67	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16600	 1	 17.53	 7.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16601	 1	 6.23	 2.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16602	 1	 4.81	 2.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16603	 1	 11.2	 4.73	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16604	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16605	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16606	 1	 3.11	 1.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16607	 1	 2.8	 1.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16608	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16609	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16610	 1	 2.33	 1.39	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16611	 1	 7.59	 2.95	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16612	 1	 4.81	 1.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16613	 1	 2.95	 1.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16614	 1	 3.81	 2.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16615	 1	 19.92	 6.01	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16616	 1	 10.32	 3.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16617	 1	 7.67	 3.55	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16618	 1	 11.97	 4.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16619	 1	 2.07	 1.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16620	 1	 3.22	 1.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16621	 1	 2.72	 1.73	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16622	 1	 6.94	 3.51	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16623	 1	 3.35	 2.05	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16624	 1	 2.26	 0.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16625	 1	 1.76	 1.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16626	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16627	 1	 5.26	 3.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16628	 1	 4.48	 2.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16629	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16630	 1	 13.25	 5.65	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16631	 1	 2.05	 1.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16632	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16633	 1	 11.58	 3.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16634	 1	 4.48	 2.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16635	 1	 3.5	 2.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16636	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16637	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16638	 1	 6.34	 3.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16639	 1	 6.48	 2.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16640	 1	 6.3	 3.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16641	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16642	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	16643	 1	 5.52	 2.54	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16644	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16645	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16646	 1	 4.42	 2.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16647	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16648	 1	 4.47	 0.99	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16649	 1	 4.43	 2.63	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16650	 1	 17.54	 3.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16651	 1	 1.45	 0.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16652	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16653	 1	 11.66	 4.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16654	 1	 3.65	 1.48	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16655	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16656	 1	 2.13	 1.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16657	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16658	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16659	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16660	 1	 2.06	 0.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16661	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16662	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16663	 1	 3.87	 1.85	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16664	 1	 17.24	 7.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16665	 1	 9.0	 3.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16666	 1	 2.21	 1.02	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16667	 1	 6.38	 3.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16668	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16669	 1	 7.22	 3.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16670	 1	 6.05	 2.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16671	 1	 4.69	 2.3	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16672	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16673	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16674	 1	 4.32	 2.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16675	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16676	 1	 12.73	 5.92	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16677	 1	 5.43	 2.34	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16678	 1	 21.94	 8.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16679	 1	 4.74	 1.85	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16680	 1	 3.93	 1.68	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16681	 1	 4.22	 2.3	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16682	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16683	 1	 17.18	 7.69	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16684	 1	 5.36	 1.87	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16685	 1	 8.54	 3.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16686	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16687	 1	 4.85	 2.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16688	 1	 4.59	 2.09	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16689	 1	 18.92	 8.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16690	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16691	 1	 6.17	 2.8	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16692	 1	 2.73	 1.37	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16693	 1	 3.45	 1.99	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16694	 1	 3.12	 1.73	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16695	 1	 13.96	 5.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16696	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16697	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16698	 1	 12.43	 4.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16699	 1	 8.27	 3.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16700	 1	 9.09	 3.17	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16701	 1	 14.79	 5.3	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16702	 1	 5.28	 2.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16703	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16704	 1	 29.07	 10.12	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16705	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16706	 1	 36.26	 7.82	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16707	 1	 6.0	 2.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16708	 1	 24.06	 10.48	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16709	 1	 8.03	 2.92	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16710	 1	 2.89	 1.59	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16711	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16712	 1	 8.42	 3.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16713	 1	 2.2	 1.06	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16714	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16715	 1	 25.66	 6.99	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16716	 1	 9.54	 3.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16717	 1	 4.35	 2.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16718	 1	 8.39	 4.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16719	 1	 8.79	 4.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16720	 1	 10.27	 4.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16721	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16722	 1	 28.65	 11.27	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16723	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16724	 1	 6.72	 3.39	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16725	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16726	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16727	 1	 4.93	 2.8	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16728	 1	 5.62	 3.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16729	 1	 7.65	 3.67	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16730	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16731	 1	 3.5	 2.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16732	 1	 6.69	 3.44	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16733	 1	 1.46	 0.79	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16734	 1	 3.18	 1.73	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16735	 1	 5.12	 2.91	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16736	 1	 7.22	 3.57	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16737	 1	 10.55	 4.62	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16738	 1	 2.28	 1.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16739	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	16740	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16741	 1	 18.88	 6.15	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16742	 1	 6.59	 2.6	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16743	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16744	 1	 3.47	 1.89	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16745	 1	 14.34	 3.89	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16746	 1	 5.05	 2.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16747	 1	 2.82	 1.51	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16748	 1	 3.19	 1.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16749	 1	 4.49	 2.36	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16750	 1	 4.69	 2.63	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16751	 1	 33.58	 11.1	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16752	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	16753	 1	 4.32	 2.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16754	 1	 1.66	 0.95	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16755	 1	 9.2	 4.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16756	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16757	 1	 33.03	 10.62	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16758	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16759	 1	 4.31	 2.3	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16760	 1	 5.47	 2.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16761	 1	 7.75	 2.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16762	 1	 8.75	 4.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16763	 1	 2.99	 1.61	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16764	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16765	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16766	 1	 5.14	 1.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16767	 1	 11.25	 2.51	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16768	 1	 19.17	 4.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16769	 1	 12.99	 4.56	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16770	 1	 13.3	 5.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16771	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16772	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16773	 1	 8.97	 3.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16774	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16775	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16776	 1	 5.65	 2.76	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16777	 1	 3.93	 2.12	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16778	 1	 6.0	 2.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16779	 1	 11.11	 4.23	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16780	 1	 12.62	 4.68	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16781	 1	 14.2	 3.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16782	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16783	 1	 6.67	 2.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16784	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16785	 1	 3.37	 1.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16786	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16787	 1	 10.79	 5.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16788	 1	 4.15	 2.33	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16789	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16790	 1	 2.81	 1.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16791	 1	 13.89	 5.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16792	 1	 4.54	 1.63	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16793	 1	 2.28	 1.32	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16794	 1	 1.93	 1.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16795	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16796	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16797	 1	 2.64	 1.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16798	 1	 3.08	 1.82	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16799	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16800	 1	 1.92	 1.24	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16801	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16802	 1	 1.13	 0.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16803	 1	 3.88	 2.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16804	 1	 3.27	 1.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16805	 1	 5.33	 2.73	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16806	 1	 6.56	 3.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16807	 1	 3.32	 1.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16808	 1	 7.99	 4.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16809	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16810	 1	 3.25	 2.04	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16811	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16812	 1	 4.96	 2.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16813	 1	 3.43	 1.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16814	 1	 5.28	 3.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16815	 1	 6.42	 3.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16816	 1	 2.71	 1.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16817	 1	 2.58	 1.63	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16818	 1	 6.71	 2.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16819	 1	 5.79	 2.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16820	 1	 2.1	 1.06	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16821	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16822	 1	 3.55	 2.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16823	 1	 5.48	 1.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16824	 1	 0.01	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16825	 1	 3.81	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16826	 1	 7.63	 1.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16827	 1	 6.56	 1.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16828	 1	 3.53	 0.78	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16829	 1	 2.21	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16830	 1	 8.62	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16831	 1	 11.64	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16832	 1	 11.58	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16833	 1	 8.4	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16834	 1	 5.13	 1.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16835	 1	 5.67	 1.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16836	 1	 14.8	 3.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16837	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16838	 1	 11.02	 2.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16839	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16840	 1	 10.94	 2.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16841	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16842	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16843	 1	 3.45	 0.78	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16844	 1	 4.03	 0.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16845	 1	 2.29	 0.51	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16846	 1	 2.54	 0.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16847	 1	 4.24	 0.94	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16848	 1	 3.41	 0.76	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16849	 1	 2.49	 0.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16850	 1	 3.86	 0.87	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16851	 1	 15.97	 6.15	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16852	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16853	 1	 4.98	 1.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16854	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16855	 1	 19.42	 6.69	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16856	 1	 9.86	 4.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16857	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16858	 1	 7.4	 4.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16859	 1	 8.71	 3.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16860	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16861	 1	 27.79	 9.87	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16862	 1	 4.82	 1.82	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16863	 1	 2.59	 1.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16864	 1	 11.56	 2.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16865	 1	 13.66	 5.48	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16866	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16867	 1	 9.41	 2.47	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16868	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16869	 1	 10.43	 4.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16870	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16871	 1	 1.68	 0.82	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16872	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16873	 1	 19.23	 7.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16874	 1	 3.92	 2.43	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16875	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16876	 1	 3.02	 1.53	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16877	 1	 10.32	 3.83	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16878	 1	 7.1	 1.59	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16879	 1	 5.44	 1.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16880	 1	 6.75	 2.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16881	 1	 9.52	 3.76	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16882	 1	 9.04	 3.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16883	 1	 2.7	 1.32	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16884	 1	 6.58	 2.32	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16885	 1	 7.05	 2.59	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16886	 1	 7.61	 2.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16887	 1	 5.26	 2.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16888	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16889	 1	 6.44	 2.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16890	 1	 3.06	 1.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16891	 1	 3.05	 1.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16892	 1	 2.3	 1.47	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16893	 1	 4.19	 2.16	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16894	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16895	 1	 7.83	 3.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16896	 1	 4.01	 2.36	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16897	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16898	 1	 8.36	 3.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16899	 1	 14.72	 6.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16900	 1	 3.87	 2.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16901	 1	 3.62	 2.13	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16902	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16903	 1	 4.74	 2.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16904	 1	 5.31	 2.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16905	 1	 4.8	 2.01	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16906	 1	 3.58	 2.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16907	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16908	 1	 10.97	 5.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16909	 1	 13.7	 5.42	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16910	 1	 1.49	 0.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16911	 1	 12.5	 5.81	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16912	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16913	 1	 9.06	 3.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16914	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16915	 1	 2.41	 1.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16916	 1	 1.68	 1.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16917	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16918	 1	 11.1	 4.69	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16919	 1	 5.39	 1.23	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16920	 1	 5.51	 2.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16921	 1	 13.9	 7.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16922	 1	 11.74	 4.25	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16923	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16924	 1	 3.75	 2.18	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16925	 1	 8.12	 4.26	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16926	 1	 16.03	 5.75	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16927	 1	 18.36	 6.59	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16928	 1	 6.85	 3.01	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16929	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16930	 1	 12.97	 5.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16931	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16932	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16933	 1	 7.19	 1.63	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16934	 1	 12.15	 6.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16935	 1	 11.23	 5.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16936	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16937	 1	 7.25	 3.62	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16938	 1	 5.9	 2.79	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16939	 1	 15.53	 5.36	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16940	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16941	 1	 5.93	 3.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16942	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16943	 1	 6.15	 2.86	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16944	 1	 4.28	 0.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16945	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16946	 1	 6.13	 2.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16947	 1	 10.21	 4.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16948	 1	 8.6	 2.52	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16949	 1	 6.47	 3.05	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16950	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16951	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16952	 1	 5.46	 2.61	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16953	 1	 2.23	 1.3	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16954	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16955	 1	 12.76	 4.63	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16956	 1	 4.44	 2.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16957	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16958	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	16959	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16960	 1	 7.37	 1.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16961	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16962	 1	 1.72	 0.39	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16963	 1	 4.96	 1.11	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16964	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16965	 1	 10.74	 2.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16966	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16967	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16968	 1	 14.88	 4.5	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16969	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16970	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16971	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16972	 1	 10.61	 4.23	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16973	 1	 7.17	 1.62	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16974	 1	 7.63	 2.96	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16975	 1	 23.6	 8.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16976	 1	 6.75	 3.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16977	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16978	 1	 11.59	 4.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16979	 1	 8.08	 3.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16980	 1	 3.9	 0.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16981	 1	 2.95	 1.32	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16982	 1	 16.53	 3.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16983	 1	 3.12	 1.59	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16984	 1	 5.82	 2.89	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16985	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16986	 1	 2.28	 1.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16987	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16988	 1	 7.98	 3.37	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16989	 1	 3.33	 1.29	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16990	 1	 3.11	 1.86	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16991	 1	 6.64	 3.32	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16992	 1	 17.83	 4.01	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16993	 1	 4.92	 1.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16994	 1	 4.38	 1.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16995	 1	 4.09	 0.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	16996	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16997	 1	 13.83	 3.2	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16998	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16999	 1	 3.59	 0.82	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17000	 1	 7.18	 1.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17001	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17002	 1	 2.28	 1.42	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17003	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17004	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17005	 1	 11.68	 5.02	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17006	 1	 4.2	 2.56	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17007	 1	 11.63	 4.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17008	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17009	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17010	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17011	 1	 2.16	 0.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17012	 1	 1.95	 1.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17013	 1	 1.62	 0.96	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17014	 1	 6.69	 1.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17015	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17016	 1	 2.44	 0.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17017	 1	 25.92	 5.97	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17018	 1	 15.04	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17019	 1	 9.86	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17020	 1	 4.17	 0.94	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17021	 1	 5.02	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17022	 1	 7.81	 1.75	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17023	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17024	 1	 2.08	 0.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17025	 1	 8.9	 3.05	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17026	 1	 9.04	 3.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17027	 1	 6.4	 2.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17028	 1	 4.59	 1.76	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17029	 1	 4.23	 2.05	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17030	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17031	 1	 2.4	 1.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17032	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17033	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17034	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17035	 1	 2.4	 1.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17036	 1	 5.44	 3.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17037	 1	 4.12	 1.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17038	 1	 5.57	 2.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17039	 1	 5.59	 2.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17040	 1	 8.84	 3.39	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17041	 1	 3.02	 1.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17042	 1	 4.78	 2.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17043	 1	 3.24	 1.28	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17044	 1	 3.65	 1.82	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17045	 1	 2.22	 1.11	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17046	 1	 3.34	 2.02	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17047	 1	 2.94	 1.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17048	 1	 3.19	 1.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17049	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17050	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17051	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17052	 1	 5.65	 2.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17053	 1	 4.62	 2.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17054	 1	 9.05	 4.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17055	 1	 5.56	 2.83	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17056	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17057	 1	 4.03	 2.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17058	 1	 3.9	 2.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17059	 1	 7.33	 3.05	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17060	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17061	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17062	 1	 4.29	 1.85	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17063	 1	 7.4	 3.32	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17064	 1	 4.37	 2.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17065	 1	 6.6	 3.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17066	 1	 5.02	 2.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17067	 1	 4.19	 2.27	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17068	 1	 3.53	 1.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17069	 1	 6.3	 3.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17070	 1	 3.68	 1.87	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17071	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17072	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17073	 1	 1.13	 0.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17074	 1	 2.31	 1.15	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17075	 1	 5.43	 2.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17076	 1	 3.95	 1.83	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17077	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17078	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17079	 1	 3.04	 1.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17080	 1	 4.67	 2.25	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17081	 1	 3.34	 1.76	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17082	 1	 6.45	 3.19	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17083	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17084	 1	 5.06	 3.06	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17085	 1	 3.61	 2.32	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17086	 1	 4.35	 2.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17087	 1	 3.88	 2.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17088	 1	 3.87	 2.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17089	 1	 2.86	 1.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17090	 1	 2.67	 1.61	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17091	 1	 12.38	 5.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17092	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17093	 1	 2.96	 1.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17094	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17095	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17096	 1	 3.37	 2.04	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17097	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17098	 1	 2.07	 1.1	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17099	 1	 5.56	 2.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17100	 1	 5.1	 2.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17101	 1	 7.1	 2.96	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17102	 1	 14.56	 5.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17103	 1	 5.98	 2.63	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17104	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17105	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17106	 1	 5.52	 2.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17107	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17108	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17109	 1	 4.09	 2.72	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17110	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17111	 1	 7.79	 3.48	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17112	 1	 44.11	 14.85	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17113	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17114	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17115	 1	 12.27	 5.16	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17116	 1	 2.61	 1.63	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17117	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17118	 1	 9.08	 4.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17119	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17120	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17121	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17122	 1	 6.1	 2.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17123	 1	 2.91	 1.63	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17124	 1	 1.06	 0.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17125	 1	 1.14	 0.59	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17126	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17127	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17128	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17129	 1	 4.25	 2.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17130	 1	 6.9	 2.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17131	 1	 2.68	 1.44	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17132	 1	 2.46	 1.47	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17133	 1	 9.35	 4.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17134	 1	 3.44	 1.86	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17135	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17136	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17137	 1	 5.09	 2.44	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17138	 1	 20.83	 9.13	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17139	 1	 3.46	 1.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17140	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17141	 1	 3.35	 1.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17142	 1	 5.97	 3.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17143	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17144	 1	 1.5	 0.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17145	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17146	 1	 5.63	 3.09	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17147	 1	 4.01	 2.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17148	 1	 3.82	 2.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17149	 1	 8.46	 3.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17150	 1	 3.94	 2.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17151	 1	 8.71	 4.2	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17152	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17153	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17154	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17155	 1	 3.58	 2.01	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17156	 1	 2.88	 1.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17157	 1	 3.76	 1.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17158	 1	 4.28	 2.27	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17159	 1	 2.91	 1.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17160	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17161	 1	 1.06	 0.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17162	 1	 1.5	 0.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17163	 1	 2.51	 1.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17164	 1	 2.68	 1.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17165	 1	 3.36	 2.06	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17166	 1	 6.3	 3.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17167	 1	 5.22	 2.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17168	 1	 7.81	 4.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17169	 1	 4.7	 2.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17170	 1	 4.69	 2.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17171	 1	 7.84	 4.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17172	 1	 3.09	 1.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17173	 1	 3.51	 1.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17174	 1	 4.47	 2.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17175	 1	 2.15	 1.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17176	 1	 3.79	 2.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17177	 1	 7.21	 3.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17178	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17179	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17180	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17181	 1	 4.16	 2.11	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17182	 1	 3.83	 2.36	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17183	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17184	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17185	 1	 3.67	 2.06	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17186	 1	 5.45	 2.73	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17187	 1	 3.75	 1.85	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17188	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17189	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17190	 1	 3.12	 1.61	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17191	 1	 4.24	 2.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17192	 1	 2.39	 1.47	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17193	 1	 3.95	 2.48	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17194	 1	 8.29	 2.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17195	 1	 7.87	 3.23	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17196	 1	 3.41	 1.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17197	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17198	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17199	 1	 2.02	 1.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17200	 1	 1.75	 0.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17201	 1	 7.0	 3.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17202	 1	 5.05	 2.51	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17203	 1	 3.46	 1.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17204	 1	 5.56	 2.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17205	 1	 4.69	 2.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17206	 1	 3.42	 1.96	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17207	 1	 3.82	 1.9	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17208	 1	 4.45	 2.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17209	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17210	 1	 3.59	 2.35	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17211	 1	 1.3	 0.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17212	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17213	 1	 3.59	 2.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17214	 1	 3.5	 1.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17215	 1	 8.24	 3.39	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17216	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17217	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17218	 1	 2.57	 1.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17219	 1	 7.07	 2.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17220	 1	 5.87	 3.39	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17221	 1	 5.52	 3.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17222	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17223	 1	 8.49	 4.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17224	 1	 7.57	 4.06	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17225	 1	 3.09	 1.99	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17226	 1	 69.56	 27.73	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17227	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17228	 1	 4.11	 2.55	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17229	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17230	 1	 5.31	 2.77	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17231	 1	 3.89	 1.94	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17232	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17233	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17234	 1	 8.74	 3.62	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17235	 1	 5.62	 3.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17236	 1	 12.68	 6.96	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17237	 1	 5.14	 2.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17238	 1	 3.69	 2.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17239	 1	 5.29	 2.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17240	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17241	 1	 4.44	 2.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17242	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17243	 1	 3.46	 2.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17244	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17245	 1	 9.21	 4.68	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17246	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17247	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17248	 1	 14.98	 6.6	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17249	 1	 4.21	 2.67	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17250	 1	 2.62	 1.48	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17251	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17252	 1	 4.43	 2.43	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17253	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17254	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17255	 1	 2.17	 0.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17256	 1	 2.11	 0.48	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17257	 1	 3.68	 0.85	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17258	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17259	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17260	 1	 24.01	 7.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17261	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17262	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17263	 1	 7.25	 2.01	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17264	 1	 9.38	 3.73	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17265	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17266	 1	 3.05	 1.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17267	 1	 9.82	 4.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17268	 1	 6.58	 2.94	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17269	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17270	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17271	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17272	 1	 6.34	 3.13	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17273	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17274	 1	 4.07	 2.01	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17275	 1	 13.01	 5.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17276	 1	 4.29	 2.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17277	 1	 2.63	 1.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17278	 1	 7.49	 2.95	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17279	 1	 5.21	 2.17	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17280	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17281	 1	 5.24	 2.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17282	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17283	 1	 4.45	 2.04	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17284	 1	 8.4	 1.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17285	 1	 7.38	 1.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17286	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17287	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17288	 1	 3.26	 0.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17289	 1	 6.8	 1.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17290	 1	 3.19	 0.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17291	 1	 22.22	 5.11	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17292	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17293	 1	 7.04	 3.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17294	 1	 5.29	 2.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17295	 1	 12.87	 4.37	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17296	 1	 7.63	 1.77	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17297	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17298	 1	 6.29	 1.43	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17299	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17300	 1	 5.7	 1.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17301	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17302	 1	 2.14	 1.23	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17303	 1	 5.47	 2.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17304	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17305	 1	 2.47	 1.55	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17306	 1	 10.62	 4.24	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17307	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17308	 1	 8.66	 4.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17309	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17310	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17311	 1	 81.08	 33.8	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17312	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17313	 1	 5.49	 2.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17314	 1	 3.14	 1.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17315	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17316	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17317	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17318	 1	 10.84	 5.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17319	 1	 7.72	 4.22	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17320	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17321	 1	 10.92	 5.66	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17322	 1	 31.39	 10.34	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17323	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17324	 1	 3.23	 1.74	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17325	 1	 7.7	 3.69	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17326	 1	 2.54	 1.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17327	 1	 12.08	 5.82	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17328	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17329	 1	 2.86	 1.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17330	 1	 10.3	 4.87	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17331	 1	 3.1	 1.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17332	 1	 4.59	 2.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17333	 1	 3.34	 1.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17334	 1	 5.48	 2.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17335	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17336	 1	 4.11	 2.44	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17337	 1	 7.84	 4.82	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17338	 1	 4.53	 2.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17339	 1	 8.54	 4.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17340	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17341	 1	 4.87	 2.47	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17342	 1	 2.59	 1.43	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17343	 1	 1.71	 1.05	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17344	 1	 6.96	 3.56	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17345	 1	 4.39	 1.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17346	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17347	 1	 5.79	 1.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17348	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17349	 1	 7.24	 3.43	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17350	 1	 1.27	 0.85	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17351	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17352	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17353	 1	 9.58	 2.18	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17354	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17355	 1	 5.52	 2.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17356	 1	 8.11	 4.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17357	 1	 10.0	 4.05	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17358	 1	 5.14	 2.52	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17359	 1	 0.88	 0.52	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17360	 1	 1.97	 0.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17361	 1	 12.73	 6.26	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17362	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17363	 1	 0.95	 0.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17364	 1	 5.2	 2.73	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17365	 1	 5.09	 1.15	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17366	 1	 10.03	 2.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17367	 1	 8.72	 1.96	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17368	 1	 8.62	 5.15	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17369	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17370	 1	 3.97	 0.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17371	 1	 4.21	 0.95	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17372	 1	 3.51	 0.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17373	 1	 6.84	 1.55	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17374	 1	 6.62	 3.75	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17375	 1	 4.46	 2.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17376	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17377	 1	 3.87	 1.99	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17378	 1	 8.38	 3.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17379	 1	 3.58	 1.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17380	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17381	 1	 11.95	 2.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17382	 1	 2.11	 0.47	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17383	 1	 8.62	 1.96	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17384	 1	 4.8	 1.09	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17385	 1	 7.54	 1.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17386	 1	 2.72	 0.62	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17387	 1	 4.27	 2.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17388	 1	 6.55	 2.68	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17389	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17390	 1	 6.12	 2.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17391	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17392	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17393	 1	 5.83	 1.32	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17394	 1	 27.97	 5.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17395	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17396	 1	 2.71	 1.4	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17397	 1	 6.42	 3.04	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17398	 1	 2.49	 0.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17399	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17400	 1	 1.54	 0.36	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17401	 1	 2.43	 0.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17402	 1	 14.89	 3.39	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17403	 1	 17.87	 4.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17404	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17405	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17406	 1	 4.22	 0.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17407	 1	 17.26	 7.61	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17408	 1	 3.48	 0.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17409	 1	 4.78	 1.09	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17410	 1	 2.93	 1.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17411	 1	 7.74	 3.3	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17412	 1	 3.3	 1.91	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17413	 1	 3.2	 1.62	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17414	 1	 5.93	 1.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17415	 1	 4.4	 2.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17416	 1	 4.69	 1.95	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17417	 1	 7.73	 1.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17418	 1	 8.29	 2.91	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17419	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17420	 1	 16.74	 6.96	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17421	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17422	 1	 9.9	 2.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17423	 1	 0.31	 0.2	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17424	 1	 0.93	 0.55	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17425	 1	 3.4	 1.98	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17426	 1	 4.83	 2.64	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17427	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17428	 1	 4.58	 2.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17429	 1	 2.33	 1.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17430	 1	 4.15	 2.02	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17431	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17432	 1	 3.07	 1.83	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17433	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17434	 1	 3.94	 2.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17435	 1	 2.76	 1.51	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17436	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17437	 1	 17.53	 7.51	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17438	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17439	 1	 2.4	 0.55	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17440	 1	 15.35	 3.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17441	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17442	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17443	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17444	 1	 6.82	 3.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17445	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17446	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17447	 1	 5.04	 2.61	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17448	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17449	 1	 5.51	 1.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17450	 1	 3.1	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17451	 1	 2.69	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17452	 1	 10.57	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17453	 1	 5.58	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17454	 1	 16.89	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17455	 1	 12.64	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17456	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17457	 1	 5.86	 1.3	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17458	 1	 12.97	 2.85	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17459	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17460	 1	 6.17	 1.36	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17461	 1	 30.5	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17462	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17463	 1	 1.9	 0.43	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17464	 1	 6.03	 1.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17465	 1	 4.48	 1.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17466	 1	 5.23	 1.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17467	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17468	 1	 7.88	 1.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17469	 1	 4.83	 1.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17470	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17471	 1	 12.68	 2.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17472	 1	 2.26	 0.51	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17473	 1	 2.82	 0.61	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17474	 1	 19.68	 4.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17475	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17476	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17477	 1	 2.7	 0.61	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17478	 1	 8.37	 1.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17479	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17480	 1	 4.04	 1.73	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17481	 1	 5.38	 2.61	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17482	 1	 4.14	 1.99	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17483	 1	 4.74	 2.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17484	 1	 1.35	 0.58	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17485	 1	 1.65	 0.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17486	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17487	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17488	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17489	 1	 11.92	 2.68	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17490	 1	 9.86	 2.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17491	 1	 3.02	 0.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17492	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17493	 1	 4.34	 0.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17494	 1	 8.56	 1.94	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17495	 1	 5.88	 2.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17496	 1	 13.04	 2.94	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17497	 1	 7.33	 3.04	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17498	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17499	 1	 11.53	 4.91	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17500	 1	 3.38	 1.8	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17501	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17502	 1	 13.05	 2.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17503	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17504	 1	 3.72	 0.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17505	 1	 8.2	 1.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17506	 1	 4.59	 1.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17507	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17508	 1	 52.44	 11.68	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17509	 1	 7.14	 3.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17510	 1	 3.43	 1.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17511	 1	 15.08	 5.62	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17512	 1	 4.19	 0.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17513	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17514	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17515	 1	 4.11	 1.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17516	 1	 4.19	 2.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17517	 1	 15.08	 6.45	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17518	 1	 5.45	 3.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17519	 1	 3.43	 1.54	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17520	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17521	 1	 5.01	 2.6	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17522	 1	 9.24	 4.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17523	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17524	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17525	 1	 6.94	 3.46	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17526	 1	 17.81	 6.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17527	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17528	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17529	 1	 3.96	 2.25	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17530	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17531	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17532	 1	 5.19	 2.62	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17533	 1	 2.9	 1.47	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17534	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17535	 1	 2.06	 0.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17536	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17537	 1	 5.08	 2.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17538	 1	 3.05	 1.55	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17539	 1	 16.28	 4.78	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17540	 1	 4.52	 2.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17541	 1	 5.85	 2.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17542	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17543	 1	 8.41	 2.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17544	 1	 2.47	 1.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17545	 1	 4.24	 2.71	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17546	 1	 8.71	 4.61	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17547	 1	 3.26	 1.84	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17548	 1	 4.96	 2.72	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17549	 1	 4.02	 2.1	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17550	 1	 3.67	 1.95	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17551	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17552	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17553	 1	 8.37	 3.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17554	 1	 4.8	 2.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17555	 1	 4.51	 1.98	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17556	 1	 2.74	 1.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17557	 1	 3.48	 2.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17558	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17559	 1	 19.68	 5.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17560	 1	 20.3	 6.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17561	 1	 8.07	 4.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17562	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17563	 1	 2.44	 1.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17564	 1	 6.32	 2.89	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17565	 1	 13.52	 5.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17566	 1	 9.16	 3.02	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17567	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17568	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17569	 1	 6.12	 3.19	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17570	 1	 23.22	 9.65	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17571	 1	 6.77	 4.04	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17572	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17573	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17574	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17575	 1	 19.58	 8.92	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17576	 1	 23.92	 10.96	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17577	 1	 7.26	 3.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17578	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17579	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17580	 1	 5.79	 3.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17581	 1	 5.83	 2.94	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17582	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17583	 1	 10.01	 4.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17584	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17585	 1	 5.87	 2.41	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17586	 1	 7.21	 4.09	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17587	 1	 3.74	 1.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17588	 1	 19.91	 6.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17589	 1	 5.0	 3.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17590	 1	 9.11	 4.78	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17591	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17592	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17593	 1	 5.9	 2.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17594	 1	 10.49	 3.95	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17595	 1	 2.17	 1.26	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17596	 1	 5.16	 3.11	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17597	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17598	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17599	 1	 7.07	 3.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17600	 1	 3.6	 2.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17601	 1	 10.84	 3.96	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17602	 1	 11.41	 5.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17603	 1	 4.39	 2.52	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17604	 1	 5.62	 2.55	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17605	 1	 15.56	 4.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17606	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17607	 1	 7.04	 3.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17608	 1	 11.2	 5.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17609	 1	 8.77	 4.04	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17610	 1	 2.66	 1.56	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17611	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17612	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17613	 1	 23.34	 7.82	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17614	 1	 7.74	 3.73	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17615	 1	 14.02	 6.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17616	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17617	 1	 6.56	 3.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17618	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17619	 1	 6.24	 2.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17620	 1	 7.48	 3.82	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17621	 1	 11.66	 5.36	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17622	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17623	 1	 7.98	 4.26	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17624	 1	 5.91	 3.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17625	 1	 6.74	 2.97	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17626	 1	 73.5	 31.27	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17627	 1	 26.98	 11.3	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17628	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17629	 1	 13.22	 5.69	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17630	 1	 3.86	 1.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17631	 1	 5.23	 3.06	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17632	 1	 3.5	 2.05	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17633	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17634	 1	 8.81	 3.34	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17635	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17636	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17637	 1	 9.03	 4.69	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17638	 1	 18.48	 8.16	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17639	 1	 8.88	 3.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17640	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17641	 1	 12.45	 5.04	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17642	 1	 7.3	 2.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17643	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17644	 1	 8.3	 3.95	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17645	 1	 9.17	 3.85	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17646	 1	 8.25	 2.71	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17647	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17648	 1	 29.19	 11.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17649	 1	 10.39	 4.51	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17650	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17651	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17652	 1	 7.81	 3.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17653	 1	 7.38	 2.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17654	 1	 5.94	 1.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17655	 1	 4.54	 1.02	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17656	 1	 13.28	 6.43	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17657	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17658	 1	 2.88	 1.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17659	 1	 4.81	 2.23	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17660	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17661	 1	 1.78	 0.4	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17662	 1	 14.72	 3.32	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17663	 1	 5.18	 1.17	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17664	 1	 19.73	 4.46	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17665	 1	 3.41	 0.76	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17666	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17667	 1	 7.14	 1.59	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17668	 1	 6.35	 1.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17669	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17670	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17671	 1	 5.06	 2.25	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17672	 1	 5.29	 2.96	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17673	 1	 3.13	 1.57	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17674	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17675	 1	 16.08	 3.59	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17676	 1	 2.16	 0.48	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17677	 1	 13.66	 3.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17678	 1	 7.94	 1.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17679	 1	 2.44	 0.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17680	 1	 4.04	 0.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17681	 1	 1.57	 0.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17682	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17683	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17684	 1	 5.0	 2.58	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17685	 1	 14.49	 5.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17686	 1	 2.39	 1.39	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17687	 1	 6.89	 1.55	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17688	 1	 8.71	 1.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17689	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17690	 1	 3.51	 0.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17691	 1	 9.76	 2.19	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17692	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17693	 1	 2.87	 0.66	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17694	 1	 3.75	 0.85	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17695	 1	 7.06	 3.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17696	 1	 5.97	 3.76	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17697	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17698	 1	 5.74	 2.81	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17699	 1	 3.96	 2.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17700	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17701	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17702	 1	 4.58	 2.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17703	 1	 1.99	 1.08	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17704	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17705	 1	 6.38	 3.1	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17706	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17707	 1	 6.83	 2.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17708	 1	 4.0	 2.15	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17709	 1	 5.14	 2.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17710	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17711	 1	 7.15	 3.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17712	 1	 16.26	 5.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17713	 1	 6.8	 3.55	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17714	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17715	 1	 9.04	 3.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17716	 1	 3.76	 2.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17717	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17718	 1	 8.07	 3.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17719	 1	 9.9	 4.99	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17720	 1	 3.86	 2.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17721	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17722	 1	 4.79	 2.78	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17723	 1	 5.47	 3.11	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17724	 1	 4.15	 2.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17725	 1	 5.48	 2.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17726	 1	 6.16	 3.3	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17727	 1	 5.75	 3.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17728	 1	 6.68	 4.01	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17729	 1	 4.26	 1.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17730	 1	 5.93	 3.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17731	 1	 6.88	 3.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17732	 1	 3.04	 1.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17733	 1	 5.64	 2.39	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17734	 1	 2.3	 1.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17735	 1	 4.74	 2.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17736	 1	 6.81	 2.86	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17737	 1	 3.54	 2.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17738	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17739	 1	 3.37	 1.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17740	 1	 9.23	 4.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17741	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17742	 1	 7.54	 3.86	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17743	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17744	 1	 10.31	 4.87	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17745	 1	 14.08	 5.25	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17746	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17747	 1	 3.85	 1.56	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17748	 1	 16.78	 3.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17749	 1	 13.47	 3.04	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17750	 1	 8.45	 1.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17751	 1	 3.54	 0.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17752	 1	 5.86	 1.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17753	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17754	 1	 3.45	 0.78	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17755	 1	 12.47	 4.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17756	 1	 17.06	 3.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17757	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17758	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17759	 1	 2.73	 1.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17760	 1	 2.52	 1.15	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17761	 1	 4.71	 1.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17762	 1	 2.73	 0.62	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17763	 1	 8.79	 1.99	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17764	 1	 6.29	 1.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17765	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17766	 1	 4.17	 0.94	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17767	 1	 13.97	 3.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17768	 1	 9.62	 2.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17769	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17770	 1	 32.84	 14.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17771	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17772	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17773	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17774	 1	 13.1	 5.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17775	 1	 4.65	 2.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17776	 1	 4.43	 1.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17777	 1	 8.47	 3.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17778	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17779	 1	 4.38	 2.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17780	 1	 3.95	 1.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17781	 1	 5.17	 2.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17782	 1	 3.46	 1.62	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17783	 1	 8.37	 3.85	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17784	 1	 2.81	 0.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17785	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17786	 1	 14.47	 3.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17787	 1	 14.31	 3.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17788	 1	 12.63	 2.87	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17789	 1	 11.59	 2.63	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17790	 1	 5.2	 3.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17791	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17792	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17793	 1	 11.69	 6.92	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17794	 1	 7.44	 3.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17795	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17796	 1	 7.34	 2.41	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17797	 1	 2.44	 1.19	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17798	 1	 4.68	 2.52	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17799	 1	 2.48	 1.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17800	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17801	 1	 9.04	 3.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17802	 1	 3.52	 1.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17803	 1	 4.23	 2.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17804	 1	 2.67	 1.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17805	 1	 2.44	 1.36	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17806	 1	 7.06	 3.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17807	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17808	 1	 8.63	 3.96	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17809	 1	 3.39	 1.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17810	 1	 10.3	 4.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17811	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17812	 1	 9.48	 4.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17813	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17814	 1	 5.75	 3.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17815	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17816	 1	 3.6	 2.17	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17817	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17818	 1	 4.16	 2.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17819	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17820	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17821	 1	 7.95	 3.84	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17822	 1	 6.95	 3.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17823	 1	 3.3	 2.02	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17824	 1	 5.68	 3.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17825	 1	 3.88	 1.92	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17826	 1	 6.27	 3.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17827	 1	 5.57	 3.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17828	 1	 4.37	 2.14	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17829	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17830	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17831	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17832	 1	 2.94	 1.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17833	 1	 9.13	 4.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17834	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17835	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17836	 1	 4.64	 2.15	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17837	 1	 2.09	 1.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17838	 1	 7.48	 3.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17839	 1	 3.85	 2.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17840	 1	 4.96	 2.44	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17841	 1	 3.94	 2.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17842	 1	 12.46	 5.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17843	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17844	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17845	 1	 8.9	 3.79	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17846	 1	 4.67	 2.59	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17847	 1	 5.13	 2.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17848	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17849	 1	 4.41	 2.36	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17850	 1	 4.87	 2.44	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17851	 1	 5.75	 2.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17852	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17853	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17854	 1	 7.33	 3.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17855	 1	 4.04	 1.95	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17856	 1	 2.48	 1.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17857	 1	 4.55	 2.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17858	 1	 9.83	 3.99	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17859	 1	 4.9	 2.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17860	 1	 3.46	 1.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17861	 1	 1.99	 1.06	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17862	 1	 2.21	 1.11	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17863	 1	 6.66	 3.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17864	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17865	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17866	 1	 16.12	 7.7	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17867	 1	 7.1	 3.61	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17868	 1	 6.58	 3.07	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17869	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17870	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17871	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17872	 1	 9.6	 4.11	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17873	 1	 3.01	 1.61	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17874	 1	 4.38	 2.17	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17875	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17876	 1	 5.79	 2.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17877	 1	 3.22	 1.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17878	 1	 3.72	 2.09	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17879	 1	 4.23	 2.41	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17880	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17881	 1	 4.61	 2.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17882	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	17883	 1	 4.32	 2.43	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17884	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17885	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17886	 1	 2.82	 1.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17887	 1	 1.75	 0.83	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17888	 1	 3.34	 1.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17889	 1	 6.64	 3.01	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17890	 1	 5.07	 2.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17891	 1	 6.46	 3.51	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17892	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17893	 1	 14.76	 5.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17894	 1	 7.28	 3.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17895	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17896	 1	 10.52	 2.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17897	 1	 2.86	 1.59	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17898	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17899	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17900	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17901	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17902	 1	 10.62	 5.19	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17903	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17904	 1	 24.4	 5.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17905	 1	 9.09	 5.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17906	 1	 10.82	 5.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17907	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17908	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17909	 1	 2.71	 1.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17910	 1	 7.09	 1.62	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17911	 1	 1.72	 0.39	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17912	 1	 3.92	 0.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17913	 1	 5.96	 1.36	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17914	 1	 4.46	 2.31	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17915	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17916	 1	 6.52	 2.89	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17917	 1	 3.68	 1.92	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17918	 1	 6.06	 3.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17919	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17920	 1	 8.73	 4.2	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17921	 1	 14.12	 6.53	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17922	 1	 9.1	 2.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17923	 1	 7.88	 1.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17924	 1	 7.51	 1.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17925	 1	 6.1	 1.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17926	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17927	 1	 4.72	 1.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17928	 1	 5.59	 2.17	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17929	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17930	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17931	 1	 7.12	 2.29	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17932	 1	 0.03	 0.01	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17933	 1	 2.81	 1.33	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17934	 1	 1.15	 0.68	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17935	 1	 2.7	 1.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17936	 1	 8.46	 4.46	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17937	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17938	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17939	 1	 12.23	 2.81	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17940	 1	 18.87	 4.33	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17941	 1	 7.31	 1.68	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17942	 1	 8.97	 4.01	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17943	 1	 3.44	 2.15	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17944	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17945	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17946	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17947	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17948	 1	 3.47	 1.36	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17949	 1	 2.02	 1.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17950	 1	 2.92	 1.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17951	 1	 8.47	 3.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17952	 1	 3.8	 1.89	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17953	 1	 3.74	 1.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17954	 1	 0.33	 0.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17955	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17956	 1	 8.08	 4.48	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17957	 1	 2.79	 1.35	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17958	 1	 7.34	 3.85	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17959	 1	 5.81	 3.63	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17960	 1	 6.83	 3.56	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17961	 1	 9.48	 4.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17962	 1	 10.65	 5.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17963	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	17964	 1	 7.89	 3.14	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17965	 1	 16.59	 6.94	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17966	 1	 10.87	 4.11	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17967	 1	 8.64	 3.63	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17968	 1	 9.95	 3.76	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17969	 1	 19.25	 8.41	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17970	 1	 5.33	 2.36	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17971	 1	 7.51	 4.59	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17972	 1	 9.21	 4.32	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17973	 1	 17.01	 6.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17974	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17975	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17976	 1	 6.12	 3.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17977	 1	 24.42	 8.76	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17978	 1	 15.57	 5.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17979	 1	 5.96	 2.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17980	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17981	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17982	 1	 3.26	 0.75	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17983	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17984	 1	 7.61	 4.08	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17985	 1	 10.89	 2.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17986	 1	 14.74	 3.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17987	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17988	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17989	 1	 8.42	 1.91	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17990	 1	 4.37	 1.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17991	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	17992	 1	 8.1	 1.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17993	 1	 15.87	 3.52	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17994	 1	 10.3	 2.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17995	 1	 5.03	 1.15	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17996	 1	 9.76	 2.23	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17997	 1	 2.44	 0.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17998	 1	 24.36	 5.52	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	17999	 1	 4.34	 0.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18000	 1	 4.81	 1.09	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18001	 1	 11.83	 2.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18002	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18003	 1	 1.64	 0.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18004	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18005	 1	 9.58	 3.01	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18006	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18007	 1	 1.42	 0.32	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18008	 1	 3.42	 0.78	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18009	 1	 9.2	 2.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18010	 1	 15.84	 3.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18011	 1	 20.24	 4.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18012	 1	 3.08	 1.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18013	 1	 3.64	 2.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18014	 1	 5.69	 3.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18015	 1	 3.46	 0.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18016	 1	 7.68	 1.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18017	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18018	 1	 12.53	 4.56	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18019	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18020	 1	 6.7	 3.23	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18021	 1	 4.47	 1.03	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18022	 1	 1.63	 0.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18023	 1	 5.66	 1.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18024	 1	 6.03	 1.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18025	 1	 8.24	 1.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18026	 1	 5.97	 2.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18027	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18028	 1	 7.17	 2.36	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18029	 1	 16.88	 7.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18030	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18031	 1	 12.16	 6.01	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18032	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18033	 1	 5.37	 2.28	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18034	 1	 10.03	 3.29	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18035	 1	 4.71	 2.22	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18036	 1	 14.59	 4.64	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18037	 1	 4.95	 2.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18038	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18039	 1	 10.39	 4.52	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18040	 1	 8.78	 3.22	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18041	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18042	 1	 9.52	 5.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18043	 1	 2.45	 1.37	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18044	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18045	 1	 13.85	 5.8	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18046	 1	 1.72	 0.93	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18047	 1	 5.16	 2.54	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18048	 1	 5.31	 2.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18049	 1	 10.71	 5.32	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18050	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18051	 1	 13.17	 4.78	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18052	 1	 11.08	 3.86	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18053	 1	 6.95	 3.22	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18054	 1	 3.41	 1.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18055	 1	 10.38	 4.06	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18056	 1	 11.34	 3.76	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18057	 1	 15.29	 6.63	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18058	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18059	 1	 17.68	 7.25	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18060	 1	 5.37	 2.85	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18061	 1	 4.58	 1.77	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18062	 1	 2.63	 1.29	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18063	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18064	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18065	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18066	 1	 34.11	 10.83	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18067	 1	 3.15	 1.68	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18068	 1	 6.81	 1.96	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18069	 1	 9.19	 4.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18070	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18071	 1	 5.17	 1.85	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18072	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18073	 1	 3.91	 1.6	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18074	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18075	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18076	 1	 8.46	 3.5	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18077	 1	 10.61	 4.56	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18078	 1	 11.6	 2.61	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18079	 1	 9.42	 3.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18080	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18081	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18082	 1	 7.91	 3.19	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18083	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18084	 1	 2.72	 1.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18085	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18086	 1	 6.37	 2.91	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18087	 1	 6.41	 3.11	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18088	 1	 5.7	 2.66	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18089	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18090	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18091	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18092	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18093	 1	 7.52	 3.05	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18094	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18095	 1	 2.29	 0.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18096	 1	 2.42	 1.13	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18097	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18098	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18099	 1	 11.32	 2.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18100	 1	 2.11	 0.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18101	 1	 5.95	 2.65	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18102	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18103	 1	 9.72	 3.94	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18104	 1	 8.82	 3.26	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18105	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18106	 1	 3.52	 1.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18107	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18108	 1	 4.49	 1.94	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18109	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18110	 1	 3.7	 1.31	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18111	 1	 9.79	 4.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18112	 1	 7.62	 3.57	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18113	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18114	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18115	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18116	 1	 2.82	 1.14	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18117	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18118	 1	 4.63	 1.98	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18119	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18120	 1	 5.05	 2.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18121	 1	 4.01	 1.71	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18122	 1	 8.2	 3.75	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18123	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18124	 1	 6.9	 2.73	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18125	 1	 5.64	 1.76	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18126	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18127	 1	 5.57	 2.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18128	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18129	 1	 11.61	 3.86	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18130	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18131	 1	 6.09	 2.62	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18132	 1	 3.33	 1.49	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18133	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18134	 1	 4.93	 1.56	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18135	 1	 12.58	 3.54	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18136	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18137	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18138	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18139	 1	 7.81	 3.2	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18140	 1	 5.58	 2.71	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18141	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18142	 1	 19.84	 6.96	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18143	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18144	 1	 15.82	 7.37	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18145	 1	 11.83	 5.97	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18146	 1	 9.3	 4.99	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18147	 1	 14.06	 4.17	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18148	 1	 10.39	 4.35	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18149	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18150	 1	 9.9	 5.02	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18151	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18152	 1	 4.8	 2.59	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18153	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18154	 1	 12.51	 6.39	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18155	 1	 7.52	 1.83	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18156	 1	 7.69	 2.79	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18157	 1	 18.16	 8.37	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18158	 1	 7.13	 3.25	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18159	 1	 5.18	 2.37	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18160	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18161	 1	 4.25	 2.29	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18162	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18163	 1	 5.76	 2.23	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18164	 1	 2.44	 1.35	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18165	 1	 17.1	 5.72	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18166	 1	 13.1	 4.66	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18167	 1	 9.6	 3.58	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18168	 1	 10.46	 4.02	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18169	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18170	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18171	 1	 19.34	 7.09	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18172	 1	 12.03	 3.65	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18173	 1	 22.99	 6.83	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18174	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18175	 1	 8.03	 1.82	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18176	 1	 4.3	 2.07	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18177	 1	 5.41	 2.6	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18178	 1	 2.98	 1.15	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18179	 1	 22.44	 7.73	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18180	 1	 8.14	 3.37	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18181	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18182	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18183	 1	 6.26	 1.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18184	 1	 11.26	 2.52	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18185	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18186	 1	 29.12	 6.6	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18187	 1	 8.1	 1.8	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18188	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18189	 1	 11.76	 2.43	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18190	 1	 18.88	 7.92	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18191	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18192	 1	 19.14	 6.31	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18193	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18194	 1	 25.55	 8.88	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18195	 1	 5.73	 2.95	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18196	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18197	 1	 2.64	 1.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18198	 1	 5.89	 2.69	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18199	 1	 20.09	 10.21	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18200	 1	 5.95	 2.43	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18201	 1	 26.88	 6.93	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18202	 1	 10.26	 4.25	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18203	 1	 17.15	 6.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18204	 1	 13.96	 4.94	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18205	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18206	 1	 1.74	 0.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18207	 1	 19.55	 7.17	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18208	 1	 2.7	 1.3	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18209	 1	 14.56	 8.6	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18210	 1	 6.87	 2.78	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18211	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18212	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18213	 1	 9.14	 4.46	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18214	 1	 10.37	 4.7	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18215	 1	 11.87	 2.69	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18216	 1	 4.18	 1.92	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18217	 1	 8.12	 1.81	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18218	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18219	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18220	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18221	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18222	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18223	 1	 9.47	 3.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18224	 1	 4.06	 1.64	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18225	 1	 8.93	 3.98	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18226	 1	 6.6	 3.52	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18227	 1	 11.12	 4.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18228	 1	 2.34	 1.34	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18229	 1	 12.32	 6.46	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18230	 1	 5.75	 2.68	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18231	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18232	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18233	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18234	 1	 3.41	 1.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18235	 1	 4.05	 1.65	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18236	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18237	 1	 9.72	 4.81	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18238	 1	 4.42	 2.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18239	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18240	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18241	 1	 6.32	 2.99	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18242	 1	 7.52	 4.18	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18243	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18244	 1	 2.94	 1.65	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18245	 1	 5.89	 3.07	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18246	 1	 7.54	 3.62	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18247	 1	 4.89	 2.47	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18248	 1	 7.95	 3.67	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18249	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18250	 1	 5.56	 3.24	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18251	 1	 4.52	 2.74	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18252	 1	 1.37	 0.82	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18253	 1	 7.26	 3.25	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18254	 1	 3.2	 1.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18255	 1	 3.6	 1.98	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18256	 1	 4.2	 2.19	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18257	 1	 17.8	 8.29	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18258	 1	 3.42	 1.67	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18259	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18260	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18261	 1	 12.5	 5.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18262	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18263	 1	 5.58	 2.68	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18264	 1	 5.86	 2.89	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18265	 1	 7.23	 2.73	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18266	 1	 4.85	 2.47	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18267	 1	 6.96	 2.88	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18268	 1	 12.71	 5.65	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18269	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18270	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18271	 1	 7.76	 3.52	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18272	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18273	 1	 3.5	 1.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18274	 1	 8.27	 3.64	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18275	 1	 12.24	 5.84	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18276	 1	 8.72	 3.67	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18277	 1	 5.8	 2.69	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18278	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18279	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18280	 1	 5.86	 2.61	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18281	 1	 4.39	 1.99	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18282	 1	 2.47	 1.09	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18283	 1	 9.75	 5.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18284	 1	 3.37	 1.47	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18285	 1	 3.51	 1.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18286	 1	 5.37	 2.23	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18287	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18288	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18289	 1	 4.73	 2.57	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18290	 1	 6.27	 2.99	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18291	 1	 8.5	 4.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18292	 1	 4.91	 2.19	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18293	 1	 8.03	 4.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18294	 1	 2.98	 1.43	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18295	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18296	 1	 9.9	 3.82	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18297	 1	 3.92	 1.63	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18298	 1	 10.85	 4.66	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18299	 1	 4.87	 2.5	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18300	 1	 10.46	 6.15	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18301	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18302	 1	 7.38	 3.46	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18303	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18304	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18305	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18306	 1	 18.91	 6.14	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18307	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18308	 1	 9.06	 4.35	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18309	 1	 8.56	 1.94	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18310	 1	 4.87	 1.11	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18311	 1	 11.25	 4.15	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18312	 1	 27.03	 10.11	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18313	 1	 17.54	 7.69	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18314	 1	 12.27	 4.36	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18315	 1	 16.27	 5.04	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18316	 1	 2.11	 0.62	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18317	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18318	 1	 19.95	 7.83	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18319	 1	 3.5	 1.9	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18320	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18321	 1	 4.68	 2.65	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18322	 1	 7.82	 3.46	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18323	 1	 9.7	 3.69	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18324	 1	 3.41	 1.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18325	 1	 9.35	 4.69	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18326	 1	 7.3	 3.13	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18327	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18328	 1	 2.39	 1.36	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18329	 1	 4.67	 2.44	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18330	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18331	 1	 4.07	 1.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18332	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18333	 1	 9.31	 3.47	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18334	 1	 13.21	 5.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18335	 1	 3.19	 1.3	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18336	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18337	 1	 7.05	 3.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18338	 1	 1.76	 0.89	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18339	 1	 8.31	 3.09	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18340	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18341	 1	 7.18	 2.93	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18342	 1	 1.43	 0.65	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18343	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18344	 1	 5.76	 2.53	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18345	 1	 8.89	 3.89	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18346	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18347	 1	 5.63	 2.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18348	 1	 6.83	 3.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18349	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18350	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18351	 1	 3.97	 2.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18352	 1	 10.28	 5.17	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18353	 1	 2.96	 1.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18354	 1	 5.61	 2.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18355	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18356	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18357	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18358	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18359	 1	 3.68	 1.99	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18360	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18361	 1	 8.88	 3.28	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18362	 1	 26.56	 8.48	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18363	 1	 9.36	 4.85	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18364	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18365	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18366	 1	 10.5	 5.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18367	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18368	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18369	 1	 2.24	 1.05	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18370	 1	 5.79	 2.69	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18371	 1	 3.79	 1.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18372	 1	 8.96	 3.51	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18373	 1	 2.66	 1.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18374	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18375	 1	 11.84	 4.75	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18376	 1	 3.57	 1.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18377	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18378	 1	 1.53	 0.8	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18379	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18380	 1	 2.47	 1.27	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18381	 1	 11.14	 5.1	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18382	 1	 6.3	 2.62	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18383	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18384	 1	 5.4	 2.17	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18385	 1	 11.74	 5.29	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18386	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18387	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18388	 1	 5.09	 2.35	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18389	 1	 8.48	 4.26	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18390	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18391	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18392	 1	 4.3	 1.97	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18393	 1	 2.89	 1.47	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18394	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18395	 1	 3.19	 1.58	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18396	 1	 7.62	 2.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18397	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18398	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18399	 1	 4.34	 2.36	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18400	 1	 5.54	 2.67	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18401	 1	 6.19	 2.89	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18402	 1	 4.34	 2.13	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18403	 1	 2.91	 1.4	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18404	 1	 6.56	 3.18	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18405	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18406	 1	 10.08	 4.55	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18407	 1	 16.53	 6.86	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18408	 1	 15.85	 5.45	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18409	 1	 6.93	 2.98	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18410	 1	 10.87	 4.61	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18411	 1	 13.45	 5.32	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18412	 1	 3.79	 1.61	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18413	 1	 3.61	 1.54	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18414	 1	 5.74	 2.87	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18415	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18416	 1	 15.9	 6.55	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18417	 1	 10.42	 4.44	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18418	 1	 7.9	 3.41	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18419	 1	 9.13	 3.34	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18420	 1	 6.4	 2.69	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18421	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18422	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18423	 1	 2.52	 1.16	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18424	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18425	 1	 5.58	 2.35	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18426	 1	 2.75	 1.17	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18427	 1	 2.46	 1.06	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18428	 1	 3.28	 1.63	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18429	 1	 2.76	 1.34	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18430	 1	 4.6	 2.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18431	 1	 9.94	 3.65	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18432	 1	 10.17	 4.94	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18433	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18434	 1	 9.25	 4.18	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18435	 1	 6.19	 2.35	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18436	 1	 7.89	 3.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18437	 1	 12.01	 4.45	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18438	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18439	 1	 12.99	 4.88	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18440	 1	 3.83	 1.79	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18441	 1	 12.3	 4.4	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18442	 1	 4.33	 2.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18443	 1	 7.74	 3.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18444	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18445	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18446	 1	 7.22	 2.84	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18447	 1	 15.9	 6.2	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18448	 1	 10.88	 4.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18449	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18450	 1	 2.66	 1.33	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18451	 1	 6.14	 2.54	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18452	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18453	 1	 3.77	 1.62	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18454	 1	 17.31	 7.65	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18455	 1	 14.41	 5.37	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18456	 1	 14.2	 5.36	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18457	 1	 6.93	 1.56	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18458	 1	 5.44	 1.22	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18459	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18460	 1	 13.57	 5.7	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18461	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18462	 1	 7.97	 3.09	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18463	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18464	 1	 6.16	 2.62	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18465	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18466	 1	 7.99	 3.51	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18467	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18468	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18469	 1	 18.67	 6.42	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18470	 1	 1.24	 0.63	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18471	 1	 5.96	 2.44	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18472	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18473	 1	 1.61	 0.78	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18474	 1	 4.81	 2.08	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18475	 1	 7.39	 1.66	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18476	 1	 13.91	 3.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18477	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18478	 1	 9.1	 3.71	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18479	 1	 5.95	 1.34	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18480	 1	 6.29	 1.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18481	 1	 10.31	 2.32	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18482	 1	 4.26	 1.95	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18483	 1	 8.21	 3.85	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18484	 1	 5.98	 2.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18485	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18486	 1	 7.08	 3.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18487	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18488	 1	 3.86	 1.32	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18489	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18490	 1	 12.42	 4.01	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18491	 1	 11.0	 3.87	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18492	 1	 5.37	 1.2	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18493	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18494	 1	 6.54	 1.46	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18495	 1	 13.26	 6.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18496	 1	 9.73	 4.35	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18497	 1	 7.8	 2.95	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18498	 1	 9.9	 3.89	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18499	 1	 7.54	 3.82	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18500	 1	 4.36	 2.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18501	 1	 2.94	 1.47	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18502	 1	 4.81	 2.61	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18503	 1	 11.02	 4.22	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18504	 1	 19.01	 6.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18505	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18506	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18507	 1	 5.21	 2.56	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18508	 1	 5.3	 2.91	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18509	 1	 2.77	 1.02	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18510	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18511	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18512	 1	 2.33	 1.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18513	 1	 5.02	 2.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18514	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18515	 1	 1.11	 0.6	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18516	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18517	 1	 10.2	 5.09	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18518	 1	 3.16	 1.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18519	 1	 3.08	 1.32	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18520	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18521	 1	 4.93	 2.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18522	 1	 11.81	 4.29	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18523	 1	 5.33	 2.25	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18524	 1	 6.7	 2.93	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18525	 1	 2.94	 1.47	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18526	 1	 2.97	 1.56	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18527	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18528	 1	 14.34	 5.99	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18529	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18530	 1	 4.16	 2.32	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18531	 1	 8.13	 3.34	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18532	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18533	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18534	 1	 3.87	 2.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18535	 1	 7.82	 3.18	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18536	 1	 4.91	 2.64	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18537	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18538	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18539	 1	 9.5	 3.59	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18540	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18541	 1	 9.22	 3.64	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18542	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18543	 1	 4.17	 1.78	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18544	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18545	 1	 5.47	 2.6	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18546	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18547	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18548	 1	 1.4	 0.79	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18549	 1	 9.64	 4.2	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18550	 1	 7.22	 3.35	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18551	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18552	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18553	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18554	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18555	 1	 3.59	 1.87	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18556	 1	 2.53	 1.42	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18557	 1	 9.77	 4.88	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18558	 1	 8.47	 3.9	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18559	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18560	 1	 5.93	 2.79	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18561	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18562	 1	 10.87	 5.37	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18563	 1	 6.22	 2.68	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18564	 1	 6.69	 3.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18565	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18566	 1	 9.47	 3.98	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18567	 1	 4.9	 2.38	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18568	 1	 9.93	 4.23	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18569	 1	 5.85	 3.01	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18570	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18571	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18572	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18573	 1	 5.86	 2.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18574	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18575	 1	 4.17	 2.35	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18576	 1	 6.04	 2.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18577	 1	 1.28	 0.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18578	 1	 1.28	 0.48	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18579	 1	 1.27	 0.36	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18580	 1	 17.15	 7.47	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18581	 1	 2.45	 1.43	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18582	 1	 5.37	 2.29	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18583	 1	 2.51	 1.31	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18584	 1	 3.05	 1.58	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18585	 1	 11.13	 4.41	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18586	 1	 44.15	 15.38	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18587	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18588	 1	 4.04	 2.19	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18589	 1	 12.54	 5.09	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18590	 1	 5.18	 2.81	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18591	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18592	 1	 2.29	 1.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18593	 1	 11.63	 5.45	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18594	 1	 12.62	 4.95	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18595	 1	 19.99	 8.58	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18596	 1	 3.03	 1.67	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18597	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18598	 1	 8.16	 1.84	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18599	 1	 9.87	 2.23	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18600	 1	 12.91	 6.09	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18601	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18602	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18603	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18604	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18605	 1	 4.53	 1.87	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18606	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18607	 1	 7.46	 3.75	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18608	 1	 15.06	 6.29	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18609	 1	 15.4	 3.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18610	 1	 3.42	 1.62	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18611	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18612	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18613	 1	 19.42	 8.08	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18614	 1	 20.21	 5.66	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18615	 1	 21.49	 7.07	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18616	 1	 11.07	 5.53	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18617	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18618	 1	 12.18	 6.01	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18619	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18620	 1	 7.52	 2.34	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18621	 1	 4.5	 2.17	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18622	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18623	 1	 6.28	 2.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18624	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18625	 1	 10.73	 4.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18626	 1	 8.62	 3.89	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18627	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18628	 1	 5.15	 2.01	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18629	 1	 7.41	 2.03	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18630	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18631	 1	 16.67	 7.93	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18632	 1	 18.62	 8.37	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18633	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18634	 1	 6.63	 3.13	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18635	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18636	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18637	 1	 7.32	 3.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18638	 1	 3.57	 1.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18639	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18640	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18641	 1	 9.48	 4.23	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18642	 1	 7.8	 2.99	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18643	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18644	 1	 8.16	 4.3	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18645	 1	 6.27	 2.75	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18646	 1	 12.69	 5.51	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18647	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18648	 1	 16.76	 6.61	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18649	 1	 6.62	 2.78	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18650	 1	 8.14	 3.89	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18651	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18652	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18653	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18654	 1	 2.97	 1.61	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18655	 1	 14.68	 5.31	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18656	 1	 5.98	 3.13	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18657	 1	 6.04	 3.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18658	 1	 3.26	 1.63	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18659	 1	 9.05	 3.35	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18660	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18661	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18662	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18663	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18664	 1	 29.66	 11.03	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18665	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18666	 1	 10.88	 4.47	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18667	 1	 6.83	 3.58	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18668	 1	 23.38	 6.78	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18669	 1	 8.39	 3.25	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18670	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18671	 1	 18.16	 5.68	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18672	 1	 5.89	 2.82	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18673	 1	 8.95	 3.47	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18674	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18675	 1	 5.76	 2.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18676	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18677	 1	 3.64	 1.79	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18678	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18679	 1	 9.99	 4.42	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18680	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18681	 1	 10.68	 4.71	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18682	 1	 10.46	 4.2	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18683	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18684	 1	 10.82	 5.34	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18685	 1	 1.91	 1.08	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18686	 1	 7.68	 3.18	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18687	 1	 2.59	 1.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18688	 1	 9.93	 4.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18689	 1	 10.93	 5.62	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18690	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18691	 1	 10.75	 4.5	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18692	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18693	 1	 3.3	 1.85	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18694	 1	 6.94	 3.76	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18695	 1	 6.16	 3.32	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18696	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18697	 1	 13.33	 6.94	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18698	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18699	 1	 3.97	 2.13	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18700	 1	 2.75	 1.47	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18701	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18702	 1	 3.53	 2.02	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18703	 1	 9.55	 3.88	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18704	 1	 4.91	 2.74	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18705	 1	 10.81	 5.64	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18706	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18707	 1	 6.47	 3.22	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18708	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18709	 1	 6.04	 3.11	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18710	 1	 6.06	 2.5	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18711	 1	 7.93	 3.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18712	 1	 13.69	 5.82	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18713	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18714	 1	 4.67	 1.98	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18715	 1	 9.34	 4.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18716	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18717	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18718	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18719	 1	 6.13	 2.76	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18720	 1	 8.05	 3.44	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18721	 1	 4.14	 2.21	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18722	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18723	 1	 7.51	 3.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18724	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18725	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18726	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18727	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18728	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18729	 1	 7.56	 3.67	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18730	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18731	 1	 14.69	 5.96	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18732	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18733	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18734	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18735	 1	 8.28	 3.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18736	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18737	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18738	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18739	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18740	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18741	 1	 9.66	 3.97	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18742	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18743	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18744	 1	 6.16	 3.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18745	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18746	 1	 56.58	 22.45	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18747	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18748	 1	 2.86	 1.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18749	 1	 18.17	 8.3	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18750	 1	 10.64	 4.3	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18751	 1	 24.26	 8.02	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18752	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18753	 1	 10.43	 4.6	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18754	 1	 30.36	 7.58	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18755	 1	 9.04	 3.9	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18756	 1	 10.3	 4.08	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18757	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18758	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18759	 1	 11.01	 4.23	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18760	 1	 18.76	 5.1	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18761	 1	 5.39	 2.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18762	 1	 6.88	 3.69	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18763	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18764	 1	 4.4	 1.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18765	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18766	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18767	 1	 9.13	 2.6	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18768	 1	 7.04	 3.77	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18769	 1	 4.04	 2.33	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18770	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18771	 1	 4.56	 1.98	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18772	 1	 12.09	 5.71	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18773	 1	 19.26	 8.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18774	 1	 24.78	 8.22	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18775	 1	 12.83	 4.79	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18776	 1	 17.26	 5.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18777	 1	 8.15	 3.64	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18778	 1	 4.16	 2.17	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18779	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18780	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18781	 1	 11.23	 5.6	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18782	 1	 10.94	 5.11	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18783	 1	 5.13	 2.78	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18784	 1	 13.18	 5.83	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18785	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18786	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18787	 1	 8.73	 3.32	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18788	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18789	 1	 5.82	 2.81	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18790	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18791	 1	 8.65	 4.23	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18792	 1	 4.76	 2.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18793	 1	 15.63	 6.39	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18794	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18795	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18796	 1	 23.72	 7.56	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18797	 1	 6.92	 3.39	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18798	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18799	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18800	 1	 11.62	 2.56	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18801	 1	 11.67	 2.62	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18802	 1	 13.57	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18803	 1	 6.28	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18804	 1	 14.7	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18805	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18806	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18807	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18808	 1	 10.26	 5.32	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18809	 1	 6.3	 3.24	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18810	 1	 7.22	 3.56	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18811	 1	 10.8	 4.15	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18812	 1	 10.91	 4.65	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18813	 1	 11.57	 4.91	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18814	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18815	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18816	 1	 5.72	 2.84	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18817	 1	 10.89	 4.59	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18818	 1	 2.94	 1.66	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18819	 1	 10.63	 4.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18820	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18821	 1	 6.45	 3.16	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18822	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18823	 1	 10.32	 5.1	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18824	 1	 13.07	 6.09	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18825	 1	 8.04	 3.26	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18826	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18827	 1	 7.25	 4.1	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18828	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18829	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18830	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18831	 1	 1.47	 0.82	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18832	 1	 4.11	 2.27	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18833	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18834	 1	 3.59	 1.82	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18835	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18836	 1	 3.05	 1.69	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18837	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18838	 1	 2.85	 1.33	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18839	 1	 5.56	 1.66	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18840	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18841	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18842	 1	 4.58	 2.36	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18843	 1	 5.32	 2.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18844	 1	 5.21	 2.83	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18845	 1	 13.28	 5.55	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18846	 1	 5.3	 2.49	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18847	 1	 4.93	 2.15	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18848	 1	 15.07	 5.77	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18849	 1	 5.28	 2.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18850	 1	 7.38	 3.02	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18851	 1	 14.23	 5.96	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18852	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18853	 1	 5.84	 2.81	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18854	 1	 3.86	 1.64	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18855	 1	 6.87	 3.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18856	 1	 7.65	 3.69	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18857	 1	 4.78	 2.11	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18858	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18859	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18860	 1	 11.71	 4.85	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18861	 1	 4.47	 2.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18862	 1	 34.58	 11.77	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18863	 1	 10.61	 4.85	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18864	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18865	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18866	 1	 18.62	 6.64	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18867	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18868	 1	 8.33	 3.98	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18869	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18870	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18871	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18872	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18873	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18874	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18875	 1	 5.57	 3.29	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18876	 1	 7.56	 4.58	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18877	 1	 17.95	 6.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18878	 1	 20.15	 8.62	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18879	 1	 4.49	 2.15	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18880	 1	 10.62	 5.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18881	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18882	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18883	 1	 11.98	 5.98	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18884	 1	 13.42	 4.68	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18885	 1	 2.66	 1.3	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18886	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18887	 1	 9.84	 3.64	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18888	 1	 22.14	 8.2	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18889	 1	 4.26	 1.93	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18890	 1	 11.63	 4.99	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18891	 1	 11.51	 4.27	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18892	 1	 8.36	 3.24	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18893	 1	 3.5	 1.7	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18894	 1	 20.17	 6.13	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18895	 1	 3.59	 1.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18896	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18897	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18898	 1	 6.66	 3.23	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18899	 1	 4.44	 1.75	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18900	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18901	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18902	 1	 7.7	 3.29	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18903	 1	 9.02	 4.07	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18904	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18905	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18906	 1	 8.51	 1.94	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18907	 1	 5.47	 1.25	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18908	 1	 27.98	 12.71	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18909	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18910	 1	 5.28	 2.3	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18911	 1	 12.8	 2.89	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18912	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18913	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18914	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18915	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18916	 1	 8.07	 3.85	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18917	 1	 12.07	 5.06	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18918	 1	 15.92	 7.38	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18919	 1	 14.39	 5.97	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18920	 1	 11.56	 5.44	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18921	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18922	 1	 1.1	 0.22	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18923	 1	 14.75	 3.31	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18924	 1	 8.61	 1.93	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18925	 1	 23.08	 8.25	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18926	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18927	 1	 6.55	 2.74	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18928	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18929	 1	 6.06	 1.76	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18930	 1	 20.84	 10.45	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18931	 1	 13.89	 7.41	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18932	 1	 7.45	 2.92	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18933	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18934	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18935	 1	 7.69	 3.17	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18936	 1	 19.35	 6.75	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18937	 1	 12.37	 5.08	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18938	 1	 9.81	 4.01	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18939	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18940	 1	 29.25	 6.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18941	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18942	 1	 10.57	 2.86	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18943	 1	 11.37	 5.04	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18944	 1	 6.19	 3.08	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18945	 1	 9.79	 3.83	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18946	 1	 3.8	 2.11	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18947	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18948	 1	 32.27	 9.57	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18949	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18950	 1	 1.66	 0.87	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18951	 1	 6.89	 2.56	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18952	 1	 7.8	 3.57	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18953	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18954	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18955	 1	 7.9	 4.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18956	 1	 6.76	 2.13	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18957	 1	 4.06	 1.93	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18958	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18959	 1	 23.8	 6.61	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18960	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18961	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18962	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18963	 1	 2.51	 1.17	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18964	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18965	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18966	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18967	 1	 5.24	 2.4	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18968	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18969	 1	 12.92	 5.58	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18970	 1	 17.19	 6.9	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18971	 1	 9.93	 4.66	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18972	 1	 8.98	 3.99	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18973	 1	 8.49	 4.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18974	 1	 5.76	 2.95	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18975	 1	 9.9	 3.96	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18976	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18977	 1	 13.71	 4.63	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18978	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18979	 1	 6.53	 2.94	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18980	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18981	 1	 11.57	 4.96	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18982	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18983	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18984	 1	 9.0	 4.68	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18985	 1	 3.88	 1.78	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18986	 1	 5.27	 2.8	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18987	 1	 10.45	 4.45	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18988	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18989	 1	 3.13	 1.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	18990	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18991	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18992	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	18993	 1	 5.95	 2.84	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18994	 1	 7.0	 3.75	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18995	 1	 16.07	 7.29	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18996	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	18997	 1	 7.74	 4.14	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18998	 1	 22.7	 11.59	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	18999	 1	 4.96	 2.35	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19000	 1	 11.98	 5.07	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19001	 1	 6.19	 3.47	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19002	 1	 4.78	 2.21	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19003	 1	 4.95	 2.88	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19004	 1	 7.98	 4.48	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19005	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19006	 1	 9.12	 4.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19007	 1	 3.1	 1.71	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19008	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19009	 1	 6.3	 3.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19010	 1	 7.49	 4.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19011	 1	 6.01	 3.34	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19012	 1	 8.15	 3.65	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19013	 1	 3.34	 1.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19014	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19015	 1	 5.18	 2.47	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19016	 1	 5.28	 2.22	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19017	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19018	 1	 5.5	 2.54	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19019	 1	 5.47	 3.18	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19020	 1	 5.81	 3.07	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19021	 1	 4.87	 2.84	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19022	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19023	 1	 4.98	 2.82	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19024	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19025	 1	 5.51	 2.08	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19026	 1	 2.77	 1.28	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19027	 1	 9.37	 4.18	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19028	 1	 2.79	 1.63	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19029	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19030	 1	 2.22	 1.14	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19031	 1	 7.0	 3.3	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19032	 1	 6.0	 2.98	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19033	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19034	 1	 13.59	 5.76	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19035	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19036	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19037	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19038	 1	 9.27	 3.98	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19039	 1	 5.23	 2.44	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19040	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19041	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19042	 1	 4.47	 2.1	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19043	 1	 5.23	 2.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19044	 1	 5.02	 2.89	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19045	 1	 10.99	 5.68	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19046	 1	 3.14	 1.66	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19047	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19048	 1	 4.77	 2.55	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19049	 1	 5.37	 2.75	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19050	 1	 8.86	 3.63	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19051	 1	 7.5	 3.51	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19052	 1	 5.52	 3.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19053	 1	 2.77	 1.17	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19054	 1	 5.77	 2.53	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19055	 1	 23.62	 10.22	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19056	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19057	 1	 5.53	 2.58	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19058	 1	 13.17	 6.42	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19059	 1	 17.58	 8.1	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19060	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19061	 1	 24.2	 6.14	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19062	 1	 13.65	 3.94	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19063	 1	 11.21	 4.26	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19064	 1	 4.86	 1.69	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19065	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19066	 1	 11.78	 3.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19067	 1	 2.44	 1.12	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19068	 1	 9.92	 4.54	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19069	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19070	 1	 9.46	 3.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19071	 1	 13.34	 4.89	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19072	 1	 12.94	 2.93	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19073	 1	 17.33	 3.89	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19074	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19075	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19076	 1	 24.6	 5.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19077	 1	 3.86	 0.88	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19078	 1	 12.06	 2.7	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19079	 1	 6.09	 1.37	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19080	 1	 8.67	 1.96	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19081	 1	 10.42	 2.35	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19082	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19083	 1	 8.34	 1.86	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19084	 1	 5.57	 2.85	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19085	 1	 11.57	 4.3	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19086	 1	 8.13	 1.84	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19087	 1	 5.4	 1.22	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19088	 1	 13.3	 3.04	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19089	 1	 25.34	 10.2	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19090	 1	 12.35	 4.82	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19091	 1	 7.64	 4.39	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19092	 1	 14.36	 3.09	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19093	 1	 6.04	 1.71	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19094	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19095	 1	 6.35	 2.95	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19096	 1	 3.27	 1.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19097	 1	 7.58	 3.18	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19098	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19099	 1	 6.08	 3.24	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19100	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19101	 1	 3.33	 1.47	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19102	 1	 5.19	 2.58	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19103	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19104	 1	 7.8	 4.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19105	 1	 18.21	 6.37	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19106	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19107	 1	 10.5	 4.34	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19108	 1	 14.53	 4.41	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19109	 1	 10.36	 5.95	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19110	 1	 9.65	 4.07	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19111	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19112	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19113	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19114	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19115	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19116	 1	 7.13	 3.57	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19117	 1	 3.13	 1.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19118	 1	 14.86	 6.96	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19119	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19120	 1	 15.86	 3.58	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19121	 1	 10.89	 3.83	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19122	 1	 9.26	 3.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19123	 1	 5.38	 3.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19124	 1	 5.87	 1.34	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19125	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19126	 1	 3.32	 1.71	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19127	 1	 7.66	 3.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19128	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19129	 1	 5.74	 2.19	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19130	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19131	 1	 18.37	 6.3	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19132	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19133	 1	 14.62	 4.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19134	 1	 19.73	 4.48	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19135	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19136	 1	 12.84	 2.91	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19137	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19138	 1	 12.86	 4.6	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19139	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19140	 1	 7.34	 2.89	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19141	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19142	 1	 6.55	 1.47	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19143	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19144	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19145	 1	 6.61	 2.81	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19146	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19147	 1	 9.46	 3.98	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19148	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19149	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19150	 1	 17.73	 7.14	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19151	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19152	 1	 10.04	 4.67	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19153	 1	 12.85	 6.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19154	 1	 3.37	 1.73	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19155	 1	 2.16	 1.13	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19156	 1	 2.52	 1.18	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19157	 1	 4.91	 2.77	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19158	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19159	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19160	 1	 21.89	 9.14	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19161	 1	 7.17	 3.32	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19162	 1	 9.49	 4.18	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19163	 1	 13.08	 5.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19164	 1	 6.78	 3.82	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19165	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19166	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19167	 1	 4.52	 2.28	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19168	 1	 3.41	 2.05	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19169	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19170	 1	 12.36	 5.85	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19171	 1	 14.51	 5.63	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19172	 1	 4.77	 2.37	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19173	 1	 7.81	 3.32	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19174	 1	 6.22	 3.18	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19175	 1	 4.12	 2.02	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19176	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19177	 1	 2.53	 1.5	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19178	 1	 7.56	 4.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19179	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19180	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19181	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19182	 1	 5.16	 2.46	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19183	 1	 4.86	 2.35	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19184	 1	 5.4	 2.56	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19185	 1	 21.67	 10.01	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19186	 1	 9.66	 4.5	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19187	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19188	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19189	 1	 8.26	 4.22	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19190	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19191	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19192	 1	 2.34	 1.15	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19193	 1	 4.53	 2.05	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19194	 1	 3.43	 2.1	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19195	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19196	 1	 15.18	 6.87	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19197	 1	 9.23	 3.84	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19198	 1	 4.58	 2.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19199	 1	 7.74	 4.21	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19200	 1	 5.5	 2.72	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19201	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19202	 1	 9.23	 4.75	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19203	 1	 3.1	 1.52	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19204	 1	 3.35	 1.87	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19205	 1	 8.85	 3.6	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19206	 1	 17.85	 5.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19207	 1	 10.52	 3.85	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19208	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19209	 1	 2.34	 1.08	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19210	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19211	 1	 10.87	 3.92	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19212	 1	 7.77	 1.75	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19213	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19214	 1	 22.23	 4.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19215	 1	 23.6	 5.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19216	 1	 7.44	 1.68	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19217	 1	 14.98	 3.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19218	 1	 11.49	 2.58	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19219	 1	 14.28	 3.21	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19220	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19221	 1	 25.4	 5.69	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19222	 1	 29.49	 6.63	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19223	 1	 8.21	 4.67	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19224	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19225	 1	 12.22	 5.33	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19226	 1	 15.86	 6.94	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19227	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19228	 1	 10.72	 3.96	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19229	 1	 4.63	 2.45	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19230	 1	 6.38	 3.06	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19231	 1	 30.54	 8.02	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19232	 1	 12.58	 5.19	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19233	 1	 12.4	 5.69	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19234	 1	 12.16	 4.88	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19235	 1	 13.41	 5.15	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19236	 1	 12.13	 5.52	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19237	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19238	 1	 17.1	 6.32	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19239	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19240	 1	 19.12	 6.02	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19241	 1	 2.84	 1.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19242	 1	 10.4	 3.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19243	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19244	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19245	 1	 13.56	 3.96	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19246	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19247	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19248	 1	 11.5	 3.98	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19249	 1	 3.87	 1.75	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19250	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19251	 1	 16.0	 5.76	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19252	 1	 12.41	 4.17	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19253	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19254	 1	 9.42	 3.82	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19255	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19256	 1	 9.45	 4.06	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19257	 1	 8.42	 3.66	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19258	 1	 7.49	 3.07	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19259	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19260	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19261	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19262	 1	 4.11	 1.88	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19263	 1	 11.38	 4.5	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19264	 1	 15.57	 3.85	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19265	 1	 8.32	 4.33	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19266	 1	 7.24	 3.53	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19267	 1	 4.2	 2.06	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19268	 1	 5.97	 3.32	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19269	 1	 9.22	 5.44	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19270	 1	 5.85	 3.07	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19271	 1	 10.39	 5.05	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19272	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19273	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19274	 1	 3.2	 1.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19275	 1	 5.89	 2.21	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19276	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19277	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19278	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19279	 1	 6.27	 2.49	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19280	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19281	 1	 5.76	 2.91	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19282	 1	 4.63	 2.27	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19283	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19284	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19285	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19286	 1	 3.94	 1.67	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19287	 1	 2.81	 1.45	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19288	 1	 5.03	 2.03	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19289	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19290	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19291	 1	 3.14	 1.75	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19292	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19293	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19294	 1	 3.58	 1.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19295	 1	 7.33	 3.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19296	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19297	 1	 10.68	 4.02	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19298	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19299	 1	 7.2	 2.63	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19300	 1	 3.59	 1.65	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19301	 1	 4.91	 2.37	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19302	 1	 14.77	 6.41	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19303	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19304	 1	 3.81	 1.49	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19305	 1	 5.01	 2.45	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19306	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19307	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19308	 1	 12.66	 5.36	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19309	 1	 8.55	 3.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19310	 1	 3.27	 1.68	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19311	 1	 11.92	 5.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19312	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19313	 1	 4.37	 1.58	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19314	 1	 9.3	 3.37	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19315	 1	 5.52	 2.06	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19316	 1	 4.64	 2.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19317	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19318	 1	 22.02	 9.25	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19319	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19320	 1	 18.86	 6.22	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19321	 1	 23.72	 7.64	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19322	 1	 30.34	 9.51	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19323	 1	 9.41	 4.57	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19324	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19325	 1	 12.04	 5.04	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19326	 1	 5.02	 2.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19327	 1	 11.54	 5.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19328	 1	 4.2	 1.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19329	 1	 7.52	 3.3	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19330	 1	 6.51	 3.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19331	 1	 9.73	 4.64	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19332	 1	 10.47	 4.67	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19333	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19334	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19335	 1	 3.69	 1.87	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19336	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19337	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19338	 1	 5.0	 2.64	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19339	 1	 6.89	 3.61	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19340	 1	 23.27	 8.16	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19341	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19342	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19343	 1	 5.49	 3.13	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19344	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19345	 1	 11.28	 5.58	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19346	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19347	 1	 9.41	 4.47	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19348	 1	 8.75	 4.09	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19349	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19350	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19351	 1	 18.77	 6.79	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19352	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19353	 1	 4.27	 2.28	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19354	 1	 16.13	 8.37	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19355	 1	 13.67	 3.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19356	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19357	 1	 10.13	 5.06	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19358	 1	 3.86	 0.88	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19359	 1	 10.72	 4.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19360	 1	 3.16	 1.61	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19361	 1	 6.54	 3.19	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19362	 1	 4.23	 1.89	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19363	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19364	 1	 18.75	 4.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19365	 1	 10.51	 2.4	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19366	 1	 9.2	 3.52	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19367	 1	 13.46	 5.11	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19368	 1	 4.92	 1.97	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19369	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19370	 1	 14.86	 5.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19371	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19372	 1	 11.25	 5.45	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19373	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19374	 1	 10.07	 4.27	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19375	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19376	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19377	 1	 7.87	 3.63	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19378	 1	 3.46	 1.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19379	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19380	 1	 6.98	 3.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19381	 1	 16.7	 4.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19382	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19383	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19384	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19385	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19386	 1	 12.6	 4.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19387	 1	 12.85	 4.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19388	 1	 6.9	 2.91	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19389	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19390	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19391	 1	 14.46	 4.35	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19392	 1	 9.54	 3.63	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19393	 1	 5.93	 2.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19394	 1	 8.62	 3.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19395	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19396	 1	 3.26	 1.35	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19397	 1	 6.51	 2.71	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19398	 1	 3.29	 0.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19399	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19400	 1	 19.01	 7.97	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19401	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19402	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19403	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19404	 1	 14.62	 5.23	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19405	 1	 7.7	 3.22	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19406	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19407	 1	 9.74	 3.48	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19408	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19409	 1	 19.76	 8.67	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19410	 1	 10.43	 4.79	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19411	 1	 4.71	 2.27	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19412	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19413	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19414	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19415	 1	 13.23	 5.64	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19416	 1	 25.88	 12.89	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19417	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19418	 1	 19.54	 4.98	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19419	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19420	 1	 7.13	 3.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19421	 1	 6.71	 2.79	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19422	 1	 13.29	 5.64	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19423	 1	 8.98	 4.03	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19424	 1	 6.2	 3.34	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19425	 1	 6.02	 3.35	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19426	 1	 3.91	 2.21	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19427	 1	 13.17	 6.57	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19428	 1	 4.04	 1.87	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19429	 1	 15.35	 6.66	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19430	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19431	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19432	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19433	 1	 9.04	 4.9	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19434	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19435	 1	 9.55	 4.13	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19436	 1	 5.26	 2.47	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19437	 1	 4.36	 1.97	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19438	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19439	 1	 11.7	 5.15	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19440	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19441	 1	 8.34	 4.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19442	 1	 4.55	 1.45	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19443	 1	 2.57	 1.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19444	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19445	 1	 4.0	 1.69	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19446	 1	 5.76	 2.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19447	 1	 7.08	 3.21	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19448	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19449	 1	 6.02	 2.58	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19450	 1	 9.1	 4.2	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19451	 1	 5.36	 3.06	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19452	 1	 18.4	 6.04	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19453	 1	 12.74	 5.11	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19454	 1	 35.97	 12.26	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19455	 1	 10.45	 3.85	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19456	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19457	 1	 8.13	 3.69	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19458	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19459	 1	 14.44	 6.37	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19460	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19461	 1	 8.66	 3.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19462	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19463	 1	 6.92	 3.1	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19464	 1	 17.03	 5.51	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19465	 1	 6.95	 3.33	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19466	 1	 5.71	 3.15	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19467	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19468	 1	 3.2	 1.7	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19469	 1	 16.8	 5.27	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19470	 1	 22.21	 8.29	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19471	 1	 8.15	 3.88	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19472	 1	 13.68	 5.44	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19473	 1	 28.12	 12.58	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19474	 1	 3.92	 1.8	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19475	 1	 14.75	 5.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19476	 1	 9.06	 3.22	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19477	 1	 6.19	 2.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19478	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19479	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19480	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19481	 1	 5.97	 2.66	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19482	 1	 23.42	 8.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19483	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19484	 1	 8.63	 3.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19485	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19486	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19487	 1	 5.39	 2.57	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19488	 1	 15.7	 5.27	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19489	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19490	 1	 16.23	 7.51	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19491	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19492	 1	 11.01	 5.43	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19493	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19494	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19495	 1	 8.66	 4.62	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19496	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19497	 1	 5.67	 2.86	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19498	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19499	 1	 26.93	 7.47	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19500	 1	 10.69	 4.31	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19501	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19502	 1	 6.13	 1.7	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19503	 1	 3.84	 1.99	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19504	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19505	 1	 7.93	 4.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19506	 1	 8.92	 4.44	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19507	 1	 3.09	 1.5	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19508	 1	 4.15	 2.29	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19509	 1	 8.44	 3.44	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19510	 1	 6.47	 2.64	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19511	 1	 12.49	 4.19	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19512	 1	 6.58	 3.24	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19513	 1	 3.91	 2.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19514	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19515	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19516	 1	 5.63	 2.97	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19517	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19518	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19519	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19520	 1	 3.59	 2.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19521	 1	 3.39	 1.74	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19522	 1	 6.61	 3.65	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19523	 1	 2.58	 1.53	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19524	 1	 6.55	 3.01	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19525	 1	 2.48	 1.2	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19526	 1	 5.76	 3.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19527	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19528	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19529	 1	 4.71	 2.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19530	 1	 5.15	 2.34	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19531	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19532	 1	 4.6	 2.33	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19533	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19534	 1	 6.89	 3.51	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19535	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19536	 1	 3.76	 2.01	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19537	 1	 5.81	 2.64	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19538	 1	 4.34	 2.68	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19539	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19540	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19541	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19542	 1	 2.85	 1.69	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19543	 1	 10.01	 5.63	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19544	 1	 7.84	 3.99	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19545	 1	 6.15	 2.96	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19546	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19547	 1	 20.55	 5.62	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19548	 1	 2.14	 0.93	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19549	 1	 3.47	 1.93	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19550	 1	 4.48	 2.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19551	 1	 3.68	 1.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19552	 1	 2.94	 1.66	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19553	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19554	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19555	 1	 6.17	 2.45	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19556	 1	 1.88	 1.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19557	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19558	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19559	 1	 2.35	 1.23	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19560	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19561	 1	 3.56	 1.62	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19562	 1	 3.14	 1.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19563	 1	 1.81	 0.97	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19564	 1	 2.86	 1.32	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19565	 1	 3.44	 1.4	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19566	 1	 1.2	 0.52	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19567	 1	 2.27	 1.18	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19568	 1	 1.73	 0.84	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19569	 1	 3.38	 1.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19570	 1	 4.15	 2.27	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19571	 1	 9.63	 4.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19572	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19573	 1	 9.5	 3.98	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19574	 1	 5.62	 3.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19575	 1	 15.78	 6.36	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19576	 1	 1.75	 0.98	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19577	 1	 6.32	 2.75	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19578	 1	 2.4	 1.21	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19579	 1	 9.5	 4.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19580	 1	 1.88	 0.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19581	 1	 4.17	 2.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19582	 1	 10.68	 4.32	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19583	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19584	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19585	 1	 2.17	 1.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19586	 1	 21.0	 7.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19587	 1	 5.19	 2.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19588	 1	 6.7	 2.43	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19589	 1	 5.08	 2.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19590	 1	 7.38	 2.19	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19591	 1	 3.56	 1.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19592	 1	 7.38	 2.91	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19593	 1	 14.0	 4.44	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19594	 1	 7.01	 3.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19595	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19596	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19597	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19598	 1	 4.6	 2.37	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19599	 1	 3.62	 1.77	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19600	 1	 8.98	 4.06	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19601	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19602	 1	 4.3	 1.98	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19603	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19604	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19605	 1	 8.59	 4.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19606	 1	 10.67	 4.2	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19607	 1	 4.52	 2.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19608	 1	 19.09	 7.52	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19609	 1	 6.28	 2.97	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19610	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19611	 1	 3.42	 1.68	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19612	 1	 4.32	 1.81	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19613	 1	 0.66	 0.36	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19614	 1	 3.19	 1.65	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19615	 1	 3.16	 1.53	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19616	 1	 2.7	 1.46	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19617	 1	 4.44	 2.04	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19618	 1	 5.75	 2.79	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19619	 1	 3.88	 2.05	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19620	 1	 2.58	 1.28	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19621	 1	 17.83	 7.08	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19622	 1	 4.23	 1.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19623	 1	 12.54	 4.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19624	 1	 4.2	 2.19	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19625	 1	 1.28	 0.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19626	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19627	 1	 6.38	 1.88	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19628	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19629	 1	 19.05	 7.35	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19630	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19631	 1	 14.12	 4.91	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19632	 1	 8.9	 3.82	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19633	 1	 4.15	 1.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19634	 1	 5.44	 2.6	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19635	 1	 8.86	 3.56	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19636	 1	 15.24	 6.7	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19637	 1	 10.45	 3.7	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19638	 1	 16.2	 5.17	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19639	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19640	 1	 3.4	 1.7	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19641	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19642	 1	 2.87	 1.63	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19643	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19644	 1	 4.82	 2.18	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19645	 1	 1.35	 0.77	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19646	 1	 10.5	 3.83	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19647	 1	 6.07	 2.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19648	 1	 10.4	 3.97	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19649	 1	 11.86	 4.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19650	 1	 4.96	 1.88	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19651	 1	 8.86	 3.91	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19652	 1	 5.72	 2.89	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19653	 1	 5.11	 2.25	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19654	 1	 6.7	 2.78	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19655	 1	 2.62	 1.1	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19656	 1	 2.87	 1.36	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19657	 1	 4.26	 1.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19658	 1	 14.75	 6.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19659	 1	 9.56	 3.76	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19660	 1	 8.59	 3.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19661	 1	 4.18	 2.22	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19662	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19663	 1	 4.32	 2.27	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19664	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19665	 1	 10.63	 4.03	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19666	 1	 6.09	 2.76	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19667	 1	 20.52	 6.22	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19668	 1	 5.75	 2.54	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19669	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19670	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19671	 1	 3.86	 2.01	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19672	 1	 5.93	 2.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19673	 1	 13.4	 3.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19674	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19675	 1	 8.42	 3.5	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19676	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19677	 1	 14.23	 5.8	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19678	 1	 4.95	 2.29	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19679	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19680	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19681	 1	 1.3	 0.68	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19682	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19683	 1	 4.38	 2.32	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19684	 1	 3.64	 1.66	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19685	 1	 8.51	 3.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19686	 1	 3.7	 1.85	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19687	 1	 26.32	 11.04	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19688	 1	 4.07	 1.82	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19689	 1	 5.89	 2.67	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19690	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19691	 1	 14.39	 5.78	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19692	 1	 12.72	 5.28	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19693	 1	 8.95	 3.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19694	 1	 2.1	 0.89	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19695	 1	 3.61	 1.85	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19696	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19697	 1	 1.42	 0.79	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19698	 1	 7.23	 2.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19699	 1	 5.32	 2.46	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19700	 1	 9.9	 4.49	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19701	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19702	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19703	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19704	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19705	 1	 5.97	 3.13	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19706	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19707	 1	 5.1	 2.1	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19708	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19709	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19710	 1	 3.52	 1.57	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19711	 1	 5.0	 2.09	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19712	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19713	 1	 2.29	 1.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19714	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19715	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19716	 1	 4.83	 2.09	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19717	 1	 8.5	 3.17	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19718	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19719	 1	 2.37	 1.21	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19720	 1	 5.22	 2.33	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19721	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19722	 1	 2.16	 1.19	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19723	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19724	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19725	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19726	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19727	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19728	 1	 34.48	 13.19	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19729	 1	 13.26	 5.11	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19730	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19731	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19732	 1	 7.75	 3.09	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19733	 1	 11.51	 5.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19734	 1	 7.09	 3.71	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19735	 1	 8.27	 3.6	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19736	 1	 9.19	 3.86	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19737	 1	 9.16	 3.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19738	 1	 8.46	 3.35	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19739	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19740	 1	 9.57	 4.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19741	 1	 7.62	 2.87	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19742	 1	 8.13	 3.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19743	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19744	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19745	 1	 13.65	 3.11	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19746	 1	 27.03	 6.16	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19747	 1	 48.98	 11.18	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19748	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19749	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19750	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19751	 1	 12.48	 2.8	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19752	 1	 16.24	 3.66	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19753	 1	 8.14	 2.96	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19754	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19755	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19756	 1	 4.29	 1.41	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19757	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19758	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19759	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19760	 1	 7.09	 1.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19761	 1	 20.99	 4.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19762	 1	 11.11	 4.2	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19763	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19764	 1	 15.71	 5.22	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19765	 1	 9.66	 2.19	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19766	 1	 32.29	 11.52	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19767	 1	 17.06	 7.33	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19768	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19769	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19770	 1	 7.61	 1.73	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19771	 1	 8.47	 3.26	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19772	 1	 5.41	 3.3	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19773	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19774	 1	 6.45	 3.31	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19775	 1	 11.36	 4.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19776	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19777	 1	 8.7	 3.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19778	 1	 3.84	 1.77	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19779	 1	 8.17	 3.52	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19780	 1	 11.05	 4.78	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19781	 1	 3.72	 1.6	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19782	 1	 11.59	 5.77	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19783	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19784	 1	 5.35	 2.93	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19785	 1	 1.14	 0.63	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19786	 1	 3.99	 1.78	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19787	 1	 5.32	 2.67	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19788	 1	 1.96	 1.15	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19789	 1	 5.25	 2.47	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19790	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19791	 1	 6.52	 2.68	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19792	 1	 8.22	 3.79	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19793	 1	 3.37	 1.2	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19794	 1	 8.97	 3.45	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19795	 1	 10.01	 4.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19796	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19797	 1	 5.12	 2.44	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19798	 1	 3.58	 1.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19799	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19800	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19801	 1	 1.41	 0.68	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19802	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19803	 1	 1.59	 0.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19804	 1	 4.5	 1.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19805	 1	 10.2	 4.05	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19806	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19807	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19808	 1	 4.94	 2.02	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19809	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19810	 1	 9.58	 4.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19811	 1	 8.56	 3.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19812	 1	 4.33	 2.37	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19813	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19814	 1	 8.3	 3.8	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19815	 1	 4.6	 2.04	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19816	 1	 7.43	 1.71	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19817	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19818	 1	 6.15	 2.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19819	 1	 7.46	 3.26	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19820	 1	 5.25	 1.21	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19821	 1	 3.18	 0.73	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19822	 1	 3.29	 0.76	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19823	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19824	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19825	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19826	 1	 9.81	 4.09	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19827	 1	 4.12	 2.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19828	 1	 3.86	 0.89	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19829	 1	 9.54	 3.69	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19830	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19831	 1	 4.81	 1.1	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19832	 1	 1.86	 0.43	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19833	 1	 1.56	 0.36	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19834	 1	 8.19	 1.86	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19835	 1	 8.48	 1.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19836	 1	 7.05	 1.6	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19837	 1	 6.84	 1.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19838	 1	 11.78	 2.68	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19839	 1	 4.49	 1.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19840	 1	 8.32	 1.91	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19841	 1	 11.82	 2.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19842	 1	 10.77	 2.45	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19843	 1	 10.86	 2.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19844	 1	 5.22	 1.21	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19845	 1	 6.73	 2.95	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19846	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19847	 1	 8.91	 2.04	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19848	 1	 5.42	 1.25	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19849	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19850	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19851	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19852	 1	 2.53	 0.57	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19853	 1	 6.56	 1.52	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19854	 1	 1.79	 0.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19855	 1	 9.29	 2.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19856	 1	 11.33	 2.57	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19857	 1	 3.31	 0.77	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19858	 1	 5.48	 1.27	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19859	 1	 14.49	 3.31	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19860	 1	 7.37	 1.69	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19861	 1	 2.7	 0.61	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19862	 1	 8.1	 1.84	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19863	 1	 6.67	 1.52	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19864	 1	 2.31	 0.53	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19865	 1	 2.53	 1.34	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19866	 1	 6.99	 3.25	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19867	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19868	 1	 6.41	 1.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19869	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19870	 1	 1.22	 0.28	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19871	 1	 6.97	 1.61	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19872	 1	 2.36	 0.54	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19873	 1	 2.11	 0.49	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19874	 1	 8.69	 2.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19875	 1	 2.86	 0.66	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19876	 1	 6.71	 3.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19877	 1	 6.99	 3.91	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19878	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19879	 1	 12.44	 4.89	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19880	 1	 3.82	 2.08	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19881	 1	 2.4	 0.99	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19882	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19883	 1	 6.02	 2.52	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19884	 1	 7.95	 3.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19885	 1	 9.19	 2.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19886	 1	 3.13	 0.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19887	 1	 6.06	 2.6	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19888	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19889	 1	 11.19	 5.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19890	 1	 3.76	 1.71	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19891	 1	 3.68	 1.87	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19892	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19893	 1	 4.72	 2.09	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19894	 1	 7.34	 3.52	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19895	 1	 3.95	 2.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19896	 1	 3.38	 1.81	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19897	 1	 10.36	 4.79	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19898	 1	 4.57	 2.21	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19899	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19900	 1	 3.46	 1.58	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19901	 1	 4.03	 2.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19902	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19903	 1	 10.2	 2.26	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19904	 1	 12.28	 4.93	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19905	 1	 9.24	 4.48	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19906	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19907	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19908	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19909	 1	 11.3	 4.43	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19910	 1	 5.49	 2.69	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19911	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19912	 1	 22.1	 9.18	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19913	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19914	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19915	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19916	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19917	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19918	 1	 8.81	 2.53	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19919	 1	 9.65	 3.38	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19920	 1	 8.34	 2.34	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19921	 1	 14.13	 4.15	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19922	 1	 15.56	 4.44	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19923	 1	 26.42	 8.59	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19924	 1	 10.04	 3.45	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19925	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19926	 1	 16.46	 5.29	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19927	 1	 10.96	 3.15	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19928	 1	 12.66	 4.07	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19929	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19930	 1	 14.52	 5.13	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19931	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19932	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19933	 1	 8.31	 2.73	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19934	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19935	 1	 8.37	 2.72	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19936	 1	 9.43	 3.26	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19937	 1	 8.27	 2.97	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19938	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19939	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	19940	 1	 3.64	 1.33	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19941	 1	 4.51	 1.55	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19942	 1	 5.65	 1.7	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19943	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19944	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19945	 1	 19.66	 5.69	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19946	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19947	 1	 8.54	 2.33	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19948	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19949	 1	 14.76	 5.23	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19950	 1	 6.91	 1.94	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19951	 1	 7.4	 2.6	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19952	 1	 53.25	 15.26	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19953	 1	 4.34	 1.24	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19954	 1	 9.77	 3.21	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19955	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19956	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19957	 1	 5.52	 1.59	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19958	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19959	 1	 14.51	 5.08	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19960	 1	 5.08	 1.43	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19961	 1	 16.64	 4.9	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19962	 1	 6.1	 1.64	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19963	 1	 6.42	 1.78	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19964	 1	 5.77	 1.69	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19965	 1	 5.85	 1.96	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19966	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19967	 1	 7.63	 2.13	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19968	 1	 4.51	 1.66	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19969	 1	 5.39	 1.75	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19970	 1	 5.71	 1.92	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19971	 1	 15.11	 4.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19972	 1	 12.14	 4.02	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19973	 1	 9.47	 3.03	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19974	 1	 15.66	 4.41	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19975	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19976	 1	 10.77	 3.05	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19977	 1	 9.81	 2.67	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19978	 1	 21.53	 7.09	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19979	 1	 16.28	 5.61	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19980	 1	 12.06	 3.96	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19981	 1	 8.8	 2.42	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19982	 1	 14.77	 4.85	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19983	 1	 6.54	 1.91	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19984	 1	 8.01	 2.43	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19985	 1	 4.08	 1.45	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19986	 1	 9.47	 3.16	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19987	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19988	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19989	 1	 8.86	 3.19	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19990	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19991	 1	 7.85	 2.22	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19992	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19993	 1	 3.96	 1.22	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19994	 1	 4.78	 1.29	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	19995	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19996	 1	 23.33	 8.32	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19997	 1	 8.97	 2.95	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	19998	 1	 5.5	 1.58	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	19999	 1	 5.73	 1.83	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20000	 1	 23.98	 9.34	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20001	 1	 8.31	 2.4	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20002	 1	 6.19	 2.25	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20003	 1	 7.48	 2.73	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20004	 1	 32.71	 9.45	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20005	 1	 19.89	 6.32	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20006	 1	 8.2	 2.84	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20007	 1	 14.3	 4.74	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20008	 1	 19.11	 6.51	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20009	 1	 6.29	 2.16	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20010	 1	 18.56	 5.59	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20011	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20012	 1	 9.11	 2.96	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20013	 1	 10.45	 3.26	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20014	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20015	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20016	 1	 9.42	 2.87	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20017	 1	 7.37	 2.1	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20018	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20019	 1	 116.45	 27.07	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20020	 1	 6.46	 2.06	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20021	 1	 10.14	 2.41	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20022	 1	 9.42	 3.15	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20023	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20024	 1	 10.52	 3.24	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20025	 1	 8.69	 2.72	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20026	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20027	 1	 18.73	 6.39	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20028	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20029	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20030	 1	 8.91	 3.11	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20031	 1	 7.77	 2.74	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20032	 1	 12.25	 4.17	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20033	 1	 5.73	 1.73	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20034	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20035	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20036	 1	 30.19	 6.68	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20037	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20038	 1	 20.38	 6.93	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20039	 1	 3.98	 1.13	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20040	 1	 5.09	 1.53	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20041	 1	 12.38	 3.9	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20042	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20043	 1	 8.5	 2.99	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20044	 1	 3.44	 1.12	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20045	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20046	 1	 4.81	 1.67	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20047	 1	 19.81	 6.05	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20048	 1	 20.71	 6.01	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20049	 1	 14.15	 4.59	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20050	 1	 17.96	 5.41	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20051	 1	 19.27	 7.11	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20052	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20053	 1	 6.75	 2.27	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20054	 1	 16.59	 5.7	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20055	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20056	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20057	 1	 4.31	 1.44	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20058	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20059	 1	 9.11	 3.22	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20060	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20061	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20062	 1	 8.42	 2.24	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20063	 1	 7.74	 2.58	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20064	 1	 5.85	 1.75	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20065	 1	 6.13	 1.74	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20066	 1	 8.25	 2.97	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20067	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20068	 1	 4.65	 1.63	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20069	 1	 6.78	 2.26	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20070	 1	 13.41	 3.42	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20071	 1	 10.48	 3.86	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20072	 1	 4.76	 1.69	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20073	 1	 6.96	 2.45	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20074	 1	 7.33	 2.56	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20075	 1	 7.62	 2.29	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20076	 1	 7.17	 2.69	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20077	 1	 7.66	 2.71	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20078	 1	 7.85	 2.43	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20079	 1	 15.31	 5.21	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20080	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20081	 1	 10.23	 3.57	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20082	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20083	 1	 6.3	 2.39	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20084	 1	 10.44	 3.46	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20085	 1	 8.52	 2.48	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20086	 1	 6.14	 1.72	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20087	 1	 8.46	 3.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20088	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20089	 1	 10.27	 3.74	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20090	 1	 8.46	 3.06	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20091	 1	 7.27	 2.39	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20092	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20093	 1	 11.98	 3.52	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20094	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20095	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20096	 1	 8.7	 2.96	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20097	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20098	 1	 6.04	 1.84	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20099	 1	 4.75	 1.65	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20100	 1	 11.43	 3.5	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20101	 1	 16.75	 5.63	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20102	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20103	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20104	 1	 17.72	 6.12	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20105	 1	 4.46	 1.3	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20106	 1	 7.63	 2.23	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20107	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20108	 1	 19.67	 5.76	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20109	 1	 8.91	 3.06	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20110	 1	 14.04	 4.92	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20111	 1	 22.97	 8.56	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20112	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20113	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20114	 1	 18.33	 6.07	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20115	 1	 8.95	 2.93	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20116	 1	 7.86	 2.51	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20117	 1	 4.22	 1.27	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20118	 1	 5.24	 1.99	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20119	 1	 5.92	 2.13	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20120	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20121	 1	 3.63	 1.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20122	 1	 10.35	 3.57	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20123	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20124	 1	 30.91	 9.58	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20125	 1	 9.69	 3.39	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20126	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20127	 1	 7.16	 2.01	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20128	 1	 8.93	 2.89	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20129	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20130	 1	 7.28	 2.09	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20131	 1	 8.46	 2.2	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20132	 1	 5.97	 1.34	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20133	 1	 8.77	 2.81	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20134	 1	 13.08	 4.19	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20135	 1	 8.95	 2.98	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20136	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20137	 1	 7.67	 2.13	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20138	 1	 3.87	 1.01	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20139	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20140	 1	 9.13	 2.36	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20141	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20142	 1	 4.96	 1.51	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20143	 1	 2.51	 0.57	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20144	 1	 10.62	 2.37	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20145	 1	 3.75	 0.85	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20146	 1	 4.13	 0.92	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20147	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20148	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20149	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20150	 1	 9.35	 2.08	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20151	 1	 3.32	 1.18	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20152	 1	 15.38	 5.92	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20153	 1	 10.85	 3.6	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20154	 1	 3.76	 1.31	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20155	 1	 12.86	 3.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20156	 1	 2.82	 0.87	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20157	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20158	 1	 6.15	 1.92	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20159	 1	 16.45	 5.12	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20160	 1	 9.09	 2.9	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20161	 1	 6.16	 1.98	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20162	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20163	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20164	 1	 4.21	 1.26	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20165	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20166	 1	 8.5	 2.66	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20167	 1	 4.42	 1.3	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20168	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20169	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20170	 1	 5.67	 2.04	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20171	 1	 5.46	 1.85	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20172	 1	 10.8	 3.02	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20173	 1	 19.91	 8.09	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20174	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20175	 1	 11.97	 3.31	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20176	 1	 10.41	 3.08	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20177	 1	 7.88	 2.38	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20178	 1	 6.42	 1.98	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20179	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20180	 1	 14.71	 4.27	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20181	 1	 15.5	 5.37	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20182	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20183	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20184	 1	 7.43	 1.99	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20185	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20186	 1	 12.37	 4.21	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20187	 1	 9.03	 2.7	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20188	 1	 19.84	 5.87	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20189	 1	 8.72	 2.53	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20190	 1	 10.3	 3.29	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20191	 1	 3.5	 1.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20192	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20193	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20194	 1	 5.37	 1.22	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20195	 1	 10.13	 3.29	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20196	 1	 6.56	 2.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20197	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20198	 1	 18.51	 4.2	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20199	 1	 18.19	 5.1	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20200	 1	 5.09	 1.58	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20201	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20202	 1	 9.41	 3.17	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20203	 1	 9.24	 2.76	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20204	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20205	 1	 10.83	 3.1	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20206	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20207	 1	 9.08	 2.98	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20208	 1	 6.84	 1.56	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20209	 1	 8.87	 1.99	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20210	 1	 11.1	 2.48	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20211	 1	 6.3	 1.97	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20212	 1	 5.8	 1.32	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20213	 1	 6.86	 2.03	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20214	 1	 3.15	 1.05	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20215	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20216	 1	 11.21	 4.21	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20217	 1	 6.45	 2.04	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20218	 1	 12.61	 4.44	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20219	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20220	 1	 8.16	 2.88	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20221	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20222	 1	 7.77	 3.01	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20223	 1	 7.68	 2.42	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20224	 1	 14.33	 4.77	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20225	 1	 68.23	 16.35	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20226	 1	 7.87	 2.32	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20227	 1	 9.66	 3.11	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20228	 1	 7.2	 2.11	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20229	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20230	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20231	 1	 6.02	 1.94	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20232	 1	 6.35	 2.25	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20233	 1	 9.15	 3.52	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20234	 1	 7.37	 2.2	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20235	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20236	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20237	 1	 15.56	 5.54	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20238	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20239	 1	 16.96	 5.8	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20240	 1	 10.66	 3.49	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20241	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20242	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20243	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20244	 1	 12.53	 3.44	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20245	 1	 6.17	 1.72	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20246	 1	 21.64	 6.02	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20247	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20248	 1	 23.48	 5.17	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20249	 1	 8.38	 1.89	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20250	 1	 19.2	 5.14	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20251	 1	 6.23	 2.13	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20252	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20253	 1	 3.68	 1.12	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20254	 1	 3.98	 1.33	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20255	 1	 2.39	 0.68	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20256	 1	 2.42	 0.76	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20257	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20258	 1	 2.37	 0.82	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20259	 1	 12.35	 4.76	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20260	 1	 9.45	 3.11	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20261	 1	 3.91	 1.08	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20262	 1	 2.7	 0.85	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20263	 1	 14.5	 4.35	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20264	 1	 4.55	 1.31	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20265	 1	 13.13	 4.5	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20266	 1	 9.36	 3.26	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20267	 1	 8.82	 2.69	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20268	 1	 15.9	 5.92	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20269	 1	 6.1	 2.13	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20270	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20271	 1	 8.96	 2.72	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20272	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20273	 1	 8.39	 2.42	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20274	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20275	 1	 3.55	 0.99	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20276	 1	 5.19	 1.43	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20277	 1	 8.65	 3.26	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20278	 1	 5.29	 1.47	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20279	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20280	 1	 7.18	 2.37	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20281	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20282	 1	 10.7	 3.63	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20283	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20284	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20285	 1	 6.0	 1.73	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20286	 1	 5.21	 1.81	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20287	 1	 16.53	 4.6	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20288	 1	 20.01	 5.17	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20289	 1	 10.5	 3.03	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20290	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20291	 1	 95.46	 34.69	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20292	 1	 12.22	 4.28	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20293	 1	 19.22	 6.16	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20294	 1	 7.73	 2.46	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20295	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20296	 1	 21.86	 8.05	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20297	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20298	 1	 10.98	 2.97	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20299	 1	 7.65	 2.46	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20300	 1	 10.41	 3.24	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20301	 1	 13.97	 5.17	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20302	 1	 7.65	 2.14	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20303	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20304	 1	 7.93	 2.07	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20305	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20306	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20307	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20308	 1	 6.74	 2.28	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20309	 1	 11.51	 2.9	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20310	 1	 8.92	 2.9	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20311	 1	 16.26	 4.78	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20312	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20313	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20314	 1	 14.72	 4.6	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20315	 1	 12.3	 4.7	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20316	 1	 10.92	 3.41	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20317	 1	 9.55	 2.65	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20318	 1	 10.34	 3.67	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20319	 1	 43.48	 15.46	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20320	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20321	 1	 12.86	 4.71	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20322	 1	 9.53	 2.7	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20323	 1	 7.34	 2.64	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20324	 1	 9.45	 2.88	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20325	 1	 8.46	 2.82	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20326	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20327	 1	 7.38	 2.1	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20328	 1	 5.08	 1.66	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20329	 1	 11.24	 3.16	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20330	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20331	 1	 7.06	 2.35	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20332	 1	 14.59	 5.12	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20333	 1	 11.49	 3.62	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20334	 1	 10.79	 3.69	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20335	 1	 3.43	 1.18	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20336	 1	 3.76	 1.36	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20337	 1	 4.15	 1.39	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20338	 1	 12.76	 3.6	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20339	 1	 9.45	 2.73	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20340	 1	 83.03	 24.01	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20341	 1	 4.73	 1.55	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20342	 1	 16.63	 4.77	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20343	 1	 9.2	 2.88	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20344	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20345	 1	 7.31	 2.46	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20346	 1	 13.14	 4.11	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20347	 1	 7.62	 2.3	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20348	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20349	 1	 11.17	 3.8	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20350	 1	 7.99	 3.12	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20351	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20352	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20353	 1	 11.29	 3.12	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20354	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20355	 1	 7.84	 2.18	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20356	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20357	 1	 5.34	 1.77	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20358	 1	 5.74	 1.89	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20359	 1	 14.51	 4.44	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20360	 1	 5.77	 1.5	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20361	 1	 4.39	 0.97	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20362	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20363	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	20364	 1	 30.52	 11.57	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20365	 1	 18.09	 5.51	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20366	 1	 2.77	 1.02	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20367	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20368	 1	 4.15	 1.49	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20369	 1	 7.61	 2.13	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20370	 1	 5.74	 1.7	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20371	 1	 4.21	 1.17	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20372	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20373	 1	 17.79	 5.64	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20374	 1	 6.42	 2.35	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20375	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20376	 1	 12.87	 4.42	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20377	 1	 5.19	 1.85	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20378	 1	 3.06	 0.92	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20379	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20380	 1	 3.47	 1.01	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20381	 1	 3.93	 1.32	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20382	 1	 15.81	 5.52	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20383	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20384	 1	 4.86	 1.3	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20385	 1	 7.74	 2.5	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20386	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20387	 1	 14.77	 5.04	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20388	 1	 7.84	 2.83	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20389	 1	 18.35	 5.42	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20390	 1	 16.64	 5.11	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20391	 1	 7.93	 2.86	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20392	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	20393	 1	 8.72	 2.65	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20394	 1	 17.82	 6.27	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20395	 1	 6.71	 1.92	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20396	 1	 8.13	 2.11	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20397	 1	 7.21	 2.3	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20398	 1	 8.31	 1.87	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20399	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20400	 1	 13.79	 4.46	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20401	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20402	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20403	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20404	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20405	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20406	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20407	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20408	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20409	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20410	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20411	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20412	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20413	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20414	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20415	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20416	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20417	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20418	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20419	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20420	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20421	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20422	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20423	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20424	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20425	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20426	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20427	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20428	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20429	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20430	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20431	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20432	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20433	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20434	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20435	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20436	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20437	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20438	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20439	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20440	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20441	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20442	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20443	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20444	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20445	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20446	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20447	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20448	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20449	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20450	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20451	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20452	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20453	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20454	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20455	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20456	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20457	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20458	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20459	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20460	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20461	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20462	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20463	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20464	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20465	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20466	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20467	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20468	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20469	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20470	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20471	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20472	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20473	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20474	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20475	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20476	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20477	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20478	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20479	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20480	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20481	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20482	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20483	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20484	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20485	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20486	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20487	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20488	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20489	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20490	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20491	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20492	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20493	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20494	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20495	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20496	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20497	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20498	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20499	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20500	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20501	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20502	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20503	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20504	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20505	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20506	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20507	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20508	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20509	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20510	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20511	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20512	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20513	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20514	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20515	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20516	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20517	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20518	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20519	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20520	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20521	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20522	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20523	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20524	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20525	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20526	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20527	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20528	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20529	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20530	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20531	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20532	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20533	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20534	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20535	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20536	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20537	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20538	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20539	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20540	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20541	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20542	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20543	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20544	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20545	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20546	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20547	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20548	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20549	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20550	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20551	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20552	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20553	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20554	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20555	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20556	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20557	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20558	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20559	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20560	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20561	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20562	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20563	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20564	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20565	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20566	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20567	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20568	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20569	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20570	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20571	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20572	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20573	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20574	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20575	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20576	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20577	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20578	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20579	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20580	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20581	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20582	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20583	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20584	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20585	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20586	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20587	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20588	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20589	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20590	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20591	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20592	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20593	 1	 17.18	 4.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20594	 1	 84.89	 19.36	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20595	 1	 19.98	 4.55	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20596	 1	 5.39	 1.23	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20597	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20598	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20599	 1	 19.49	 5.22	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20600	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20601	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20602	 1	 4.89	 1.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20603	 1	 5.09	 1.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20604	 1	 3.57	 0.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20605	 1	 7.14	 1.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20606	 1	 15.48	 3.33	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20607	 1	 19.62	 4.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20608	 1	 7.68	 1.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20609	 1	 8.59	 1.85	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20610	 1	 2.79	 0.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20611	 1	 9.27	 2.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20612	 1	 5.97	 1.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20613	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20614	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20615	 1	 6.11	 1.35	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20616	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20617	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20618	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20619	 1	 3.98	 0.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20620	 1	 4.78	 1.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20621	 1	 2.61	 0.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20622	 1	 2.99	 0.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20623	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20624	 1	 13.06	 2.85	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20625	 1	 8.16	 1.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20626	 1	 3.53	 0.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20627	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20628	 1	 5.5	 1.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20629	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20630	 1	 11.56	 2.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20631	 1	 12.48	 2.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20632	 1	 32.68	 7.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20633	 1	 6.7	 1.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20634	 1	 3.09	 0.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20635	 1	 3.93	 0.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20636	 1	 3.67	 0.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20637	 1	 6.78	 1.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20638	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20639	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20640	 1	 9.07	 1.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20641	 1	 8.81	 1.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20642	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20643	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20644	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20645	 1	 10.64	 2.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20646	 1	 6.7	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20647	 1	 8.39	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20648	 1	 5.91	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20649	 1	 3.46	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20650	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20651	 1	 19.07	 4.17	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20652	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20653	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20654	 1	 6.62	 1.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20655	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20656	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20657	 1	 10.16	 2.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20658	 1	 6.87	 1.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20659	 1	 5.83	 1.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20660	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20661	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20662	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20663	 1	 5.24	 1.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20664	 1	 11.57	 2.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20665	 1	 5.67	 1.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20666	 1	 6.77	 1.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20667	 1	 5.94	 1.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20668	 1	 6.37	 1.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20669	 1	 9.89	 2.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20670	 1	 28.34	 8.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20671	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20672	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20673	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20674	 1	 7.18	 1.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20675	 1	 3.91	 0.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20676	 1	 4.17	 0.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20677	 1	 8.23	 1.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20678	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20679	 1	 6.97	 1.57	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20680	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20681	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20682	 1	 7.83	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20683	 1	 5.99	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20684	 1	 7.21	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20685	 1	 7.77	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20686	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20687	 1	 8.5	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20688	 1	 10.41	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20689	 1	 24.73	 5.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20690	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20691	 1	 7.2	 1.63	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20692	 1	 2.87	 1.21	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20693	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20694	 1	 3.03	 0.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20695	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20696	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20697	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20698	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20699	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20700	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20701	 1	 6.63	 2.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20702	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20703	 1	 31.28	 9.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20704	 1	 11.03	 4.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20705	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20706	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20707	 1	 9.32	 3.7	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20708	 1	 13.24	 4.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20709	 1	 5.27	 2.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20710	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20711	 1	 7.78	 3.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20712	 1	 12.91	 4.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20713	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20714	 1	 23.36	 7.2	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20715	 1	 10.48	 2.83	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20716	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20717	 1	 35.21	 7.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20718	 1	 5.54	 2.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20719	 1	 12.29	 3.39	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20720	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20721	 1	 17.13	 3.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20722	 1	 24.23	 5.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20723	 1	 19.21	 6.01	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20724	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20725	 1	 6.3	 2.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20726	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20727	 1	 15.58	 4.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20728	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20729	 1	 4.54	 1.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20730	 1	 6.91	 3.18	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20731	 1	 9.62	 3.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20732	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20733	 1	 3.55	 1.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20734	 1	 5.26	 2.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20735	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20736	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20737	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20738	 1	 4.21	 1.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20739	 1	 7.24	 2.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20740	 1	 16.02	 4.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20741	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20742	 1	 15.16	 3.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20743	 1	 13.7	 2.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20744	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20745	 1	 6.53	 2.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20746	 1	 11.58	 3.85	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20747	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20748	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20749	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20750	 1	 21.73	 4.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20751	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20752	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20753	 1	 6.46	 2.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20754	 1	 3.55	 1.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20755	 1	 27.76	 7.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20756	 1	 22.79	 6.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20757	 1	 5.05	 1.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20758	 1	 6.13	 2.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20759	 1	 2.07	 0.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20760	 1	 10.44	 4.56	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20761	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20762	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20763	 1	 7.59	 3.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20764	 1	 9.94	 3.86	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20765	 1	 9.53	 2.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20766	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20767	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20768	 1	 14.82	 4.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20769	 1	 34.09	 12.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20770	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20771	 1	 5.62	 2.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20772	 1	 10.44	 3.36	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20773	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20774	 1	 7.26	 3.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20775	 1	 7.08	 3.11	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20776	 1	 27.17	 6.33	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20777	 1	 22.6	 8.16	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20778	 1	 15.92	 5.05	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20779	 1	 6.36	 3.01	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20780	 1	 10.0	 3.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20781	 1	 7.63	 2.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20782	 1	 6.91	 2.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20783	 1	 17.9	 7.22	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20784	 1	 9.16	 3.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20785	 1	 73.08	 16.49	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20786	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20787	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20788	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20789	 1	 14.84	 3.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20790	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20791	 1	 6.74	 2.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20792	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20793	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20794	 1	 3.73	 1.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20795	 1	 19.88	 7.65	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20796	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20797	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20798	 1	 7.19	 2.61	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20799	 1	 5.7	 2.84	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20800	 1	 3.69	 1.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20801	 1	 9.51	 3.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20802	 1	 5.59	 2.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20803	 1	 2.96	 1.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20804	 1	 14.16	 4.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20805	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20806	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20807	 1	 19.06	 4.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20808	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20809	 1	 8.0	 3.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20810	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20811	 1	 5.05	 2.05	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20812	 1	 79.27	 18.45	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20813	 1	 4.08	 1.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20814	 1	 18.18	 6.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20815	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20816	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20817	 1	 21.27	 4.59	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20818	 1	 77.71	 17.24	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20819	 1	 11.72	 2.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20820	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20821	 1	 8.32	 1.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20822	 1	 65.2	 13.93	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20823	 1	 12.93	 2.76	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20824	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20825	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20826	 1	 8.93	 2.38	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20827	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20828	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20829	 1	 4.77	 2.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20830	 1	 9.43	 3.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20831	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20832	 1	 8.38	 2.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20833	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20834	 1	 7.9	 2.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20835	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20836	 1	 4.38	 1.9	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20837	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20838	 1	 6.58	 1.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20839	 1	 16.81	 3.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20840	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20841	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20842	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20843	 1	 6.77	 1.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20844	 1	 11.17	 3.81	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20845	 1	 8.6	 1.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20846	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20847	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20848	 1	 13.48	 4.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20849	 1	 7.65	 2.78	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20850	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20851	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20852	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20853	 1	 10.46	 3.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20854	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20855	 1	 37.12	 7.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20856	 1	 45.1	 10.45	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20857	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20858	 1	 22.88	 6.57	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20859	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20860	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20861	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20862	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20863	 1	 19.97	 4.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20864	 1	 43.69	 9.75	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20865	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20866	 1	 13.64	 2.94	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20867	 1	 9.78	 2.12	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20868	 1	 10.31	 2.23	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20869	 1	 30.15	 6.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20870	 1	 65.4	 14.2	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20871	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20872	 1	 106.12	 22.76	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20873	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20874	 1	 48.65	 10.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20875	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20876	 1	 29.17	 6.39	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20877	 1	 38.17	 11.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20878	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20879	 1	 66.53	 15.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20880	 1	 31.08	 8.3	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20881	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20882	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20883	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20884	 1	 26.01	 7.53	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20885	 1	 50.63	 13.24	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20886	 1	 32.54	 7.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20887	 1	 86.56	 19.31	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20888	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20889	 1	 15.18	 5.4	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20890	 1	 7.27	 1.56	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20891	 1	 7.12	 3.01	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20892	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20893	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20894	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20895	 1	 6.81	 1.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20896	 1	 13.55	 2.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20897	 1	 22.8	 7.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20898	 1	 4.85	 2.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20899	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20900	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20901	 1	 5.71	 2.46	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20902	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20903	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20904	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20905	 1	 16.61	 4.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20906	 1	 4.22	 1.9	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20907	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20908	 1	 7.32	 3.02	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20909	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20910	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20911	 1	 11.19	 3.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20912	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20913	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20914	 1	 14.78	 5.2	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20915	 1	 17.25	 4.43	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20916	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20917	 1	 5.54	 2.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20918	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20919	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20920	 1	 71.15	 16.93	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20921	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20922	 1	 6.32	 2.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20923	 1	 5.86	 2.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20924	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20925	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20926	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20927	 1	 5.76	 2.76	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20928	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20929	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20930	 1	 8.06	 1.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20931	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20932	 1	 6.39	 2.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20933	 1	 14.21	 3.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20934	 1	 6.18	 2.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20935	 1	 18.82	 4.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20936	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20937	 1	 20.3	 4.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20938	 1	 8.86	 2.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20939	 1	 8.8	 2.98	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20940	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20941	 1	 8.92	 3.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20942	 1	 17.28	 7.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20943	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20944	 1	 5.99	 2.83	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20945	 1	 13.8	 4.6	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20946	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20947	 1	 15.69	 4.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20948	 1	 21.09	 4.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20949	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20950	 1	 13.04	 2.89	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20951	 1	 8.05	 1.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20952	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20953	 1	 12.55	 2.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20954	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20955	 1	 13.29	 2.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20956	 1	 32.41	 7.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20957	 1	 12.71	 2.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20958	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20959	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20960	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20961	 1	 15.6	 4.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20962	 1	 15.7	 3.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20963	 1	 16.01	 3.6	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20964	 1	 8.76	 3.16	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20965	 1	 8.61	 3.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20966	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20967	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20968	 1	 7.67	 3.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20969	 1	 5.45	 2.33	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20970	 1	 2.8	 1.33	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20971	 1	 23.05	 6.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20972	 1	 7.64	 2.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20973	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20974	 1	 14.61	 5.92	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20975	 1	 10.87	 4.57	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20976	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20977	 1	 7.39	 3.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20978	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20979	 1	 6.46	 2.49	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20980	 1	 8.7	 4.04	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20981	 1	 33.57	 11.22	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20982	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20983	 1	 26.74	 10.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20984	 1	 7.66	 3.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20985	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20986	 1	 6.38	 2.82	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20987	 1	 11.63	 4.77	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20988	 1	 37.79	 11.23	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20989	 1	 19.35	 6.92	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20990	 1	 11.76	 4.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20991	 1	 18.75	 6.69	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20992	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20993	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20994	 1	 25.81	 8.91	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20995	 1	 17.5	 7.21	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20996	 1	 7.09	 3.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20997	 1	 9.0	 3.82	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20998	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20999	 1	 7.11	 2.54	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21000	 1	 7.42	 2.89	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21001	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21002	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21003	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21004	 1	 17.85	 6.91	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21005	 1	 6.5	 3.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21006	 1	 3.7	 1.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21007	 1	 5.91	 2.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21008	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21009	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21010	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21011	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21012	 1	 7.8	 3.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21013	 1	 27.31	 8.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21014	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21015	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21016	 1	 7.61	 1.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21017	 1	 12.37	 4.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21018	 1	 19.57	 4.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21019	 1	 15.23	 6.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21020	 1	 19.0	 4.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21021	 1	 8.55	 1.89	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21022	 1	 9.12	 4.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21023	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21024	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21025	 1	 31.32	 8.24	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21026	 1	 8.53	 4.1	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21027	 1	 10.89	 4.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21028	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21029	 1	 19.11	 6.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21030	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	21031	 1	 11.3	 4.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21032	 1	 16.56	 6.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21033	 1	 27.1	 8.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21034	 1	 8.68	 3.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21035	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21036	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21037	 1	 16.84	 7.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21038	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21039	 1	 12.49	 4.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21040	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21041	 1	 86.66	 22.57	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21042	 1	 15.34	 5.26	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21043	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21044	 1	 4.09	 1.71	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21045	 1	 12.08	 4.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21046	 1	 13.97	 5.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21047	 1	 11.4	 4.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21048	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21049	 1	 7.82	 1.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21050	 1	 7.69	 1.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21051	 1	 13.58	 4.44	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21052	 1	 9.75	 3.43	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21053	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21054	 1	 8.61	 1.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21055	 1	 11.07	 2.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21056	 1	 3.21	 0.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21057	 1	 7.42	 1.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21058	 1	 11.29	 2.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21059	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21060	 1	 7.9	 1.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21061	 1	 10.58	 3.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21062	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21063	 1	 10.27	 3.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21064	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21065	 1	 6.57	 2.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21066	 1	 3.8	 1.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21067	 1	 11.45	 4.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21068	 1	 31.19	 5.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21069	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21070	 1	 3.47	 1.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21071	 1	 11.5	 4.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21072	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21073	 1	 7.28	 2.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21074	 1	 22.81	 5.02	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21075	 1	 4.78	 1.97	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21076	 1	 9.85	 4.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21077	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21078	 1	 11.12	 3.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21079	 1	 4.8	 2.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21080	 1	 6.69	 2.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21081	 1	 9.32	 3.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21082	 1	 7.75	 1.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21083	 1	 24.37	 5.38	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21084	 1	 14.49	 3.19	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21085	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21086	 1	 87.79	 19.41	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21087	 1	 16.63	 3.69	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21088	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21089	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21090	 1	 10.52	 2.35	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21091	 1	 76.11	 21.42	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21092	 1	 59.56	 14.57	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21093	 1	 5.94	 2.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21094	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21095	 1	 19.91	 5.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21096	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21097	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21098	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21099	 1	 14.78	 5.12	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21100	 1	 17.4	 5.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21101	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21102	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21103	 1	 5.72	 2.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21104	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21105	 1	 9.63	 3.64	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21106	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21107	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21108	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21109	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21110	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21111	 1	 4.16	 0.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21112	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21113	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21114	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21115	 1	 26.93	 6.67	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21116	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21117	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21118	 1	 11.41	 4.33	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21119	 1	 10.93	 4.17	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21120	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21121	 1	 26.94	 7.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21122	 1	 3.97	 1.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21123	 1	 23.84	 8.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21124	 1	 4.96	 2.21	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21125	 1	 14.86	 3.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21126	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21127	 1	 12.41	 4.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21128	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21129	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21130	 1	 15.39	 4.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21131	 1	 12.9	 5.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21132	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21133	 1	 10.33	 4.23	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21134	 1	 7.08	 2.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21135	 1	 6.02	 2.86	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21136	 1	 12.84	 5.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21137	 1	 8.35	 3.69	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21138	 1	 13.91	 5.45	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21139	 1	 12.91	 4.84	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21140	 1	 9.05	 3.55	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21141	 1	 14.99	 5.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21142	 1	 12.83	 4.61	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21143	 1	 12.39	 4.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21144	 1	 68.34	 13.06	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21145	 1	 9.85	 3.99	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21146	 1	 17.74	 6.34	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21147	 1	 8.3	 2.24	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21148	 1	 20.69	 5.92	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21149	 1	 18.3	 5.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21150	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21151	 1	 4.2	 2.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21152	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21153	 1	 12.89	 5.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21154	 1	 17.2	 4.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21155	 1	 5.25	 2.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21156	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21157	 1	 7.81	 3.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21158	 1	 8.53	 3.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21159	 1	 7.65	 2.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21160	 1	 28.36	 8.48	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21161	 1	 4.3	 0.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21162	 1	 69.13	 14.97	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21163	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21164	 1	 30.79	 -4.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21165	 1	 15.7	 -4.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21166	 1	 9.04	 1.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21167	 1	 3.25	 0.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21168	 1	 1.97	 0.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21169	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21170	 1	 105.66	 23.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21171	 1	 11.76	 2.58	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21172	 1	 0.0	 0.0	 0.0	 90.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21173	 1	 64.88	 14.19	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21174	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21175	 1	 6.79	 1.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21176	 1	 12.54	 2.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21177	 1	 21.91	 4.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21178	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21179	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21180	 1	 19.19	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21181	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21182	 1	 18.9	 3.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21183	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21184	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21185	 1	 7.29	 1.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21186	 1	 8.26	 1.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21187	 1	 4.68	 0.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21188	 1	 5.72	 2.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21189	 1	 12.67	 4.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21190	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21191	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21192	 1	 23.75	 8.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21193	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21194	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21195	 1	 1.21	 0.48	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21196	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21197	 1	 4.2	 1.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21198	 1	 2.95	 1.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21199	 1	 5.81	 2.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21200	 1	 7.19	 2.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21201	 1	 2.64	 1.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21202	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21203	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21204	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21205	 1	 2.68	 1.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21206	 1	 1.88	 0.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21207	 1	 3.44	 1.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21208	 1	 1.33	 0.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21209	 1	 1.19	 0.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21210	 1	 2.39	 0.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21211	 1	 5.75	 1.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21212	 1	 6.89	 2.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21213	 1	 7.06	 2.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21214	 1	 4.52	 1.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21215	 1	 4.44	 1.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21216	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21217	 1	 6.0	 2.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21218	 1	 67.56	 12.28	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21219	 1	 162.63	 38.97	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21220	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21221	 1	 5.04	 2.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21222	 1	 4.22	 1.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21223	 1	 10.33	 3.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21224	 1	 57.1	 14.55	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21225	 1	 79.58	 22.61	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21226	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21227	 1	 8.94	 2.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21228	 1	 4.86	 1.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21229	 1	 12.83	 5.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21230	 1	 2.89	 1.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21231	 1	 4.88	 1.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21232	 1	 6.76	 2.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21233	 1	 6.31	 2.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21234	 1	 7.1	 2.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21235	 1	 7.79	 2.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21236	 1	 1.84	 0.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21237	 1	 2.36	 0.82	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21238	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21239	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21240	 1	 20.08	 6.38	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21241	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21242	 1	 64.51	 18.33	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21243	 1	 10.32	 3.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21244	 1	 18.33	 5.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21245	 1	 2.25	 1.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21246	 1	 45.72	 7.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21247	 1	 5.55	 2.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21248	 1	 25.55	 7.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21249	 1	 22.45	 6.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21250	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21251	 1	 7.54	 2.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21252	 1	 6.22	 2.48	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21253	 1	 10.63	 4.02	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21254	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21255	 1	 6.36	 2.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21256	 1	 12.03	 4.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21257	 1	 6.31	 2.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21258	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21259	 1	 20.12	 5.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21260	 1	 5.9	 2.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21261	 1	 7.4	 2.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21262	 1	 7.78	 2.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21263	 1	 7.06	 2.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21264	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21265	 1	 2.09	 0.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21266	 1	 8.05	 3.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21267	 1	 5.85	 2.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21268	 1	 15.68	 5.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21269	 1	 12.18	 3.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21270	 1	 17.6	 6.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21271	 1	 10.29	 3.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21272	 1	 9.7	 3.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21273	 1	 44.46	 9.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21274	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21275	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21276	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21277	 1	 9.5	 3.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21278	 1	 8.05	 3.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21279	 1	 12.57	 4.41	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21280	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21281	 1	 12.5	 4.27	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21282	 1	 10.13	 3.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21283	 1	 4.24	 1.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21284	 1	 9.23	 3.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21285	 1	 6.95	 2.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21286	 1	 12.86	 5.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21287	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21288	 1	 12.2	 3.84	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21289	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21290	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21291	 1	 13.88	 4.21	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21292	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21293	 1	 22.47	 6.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21294	 1	 10.95	 4.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21295	 1	 19.68	 7.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21296	 1	 3.63	 1.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21297	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21298	 1	 4.33	 1.95	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21299	 1	 10.72	 4.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21300	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21301	 1	 20.14	 5.44	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21302	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21303	 1	 3.2	 1.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21304	 1	 19.9	 4.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21305	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21306	 1	 8.51	 2.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21307	 1	 10.43	 4.27	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21308	 1	 4.34	 1.58	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21309	 1	 21.43	 6.02	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21310	 1	 1.94	 0.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21311	 1	 3.78	 1.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21312	 1	 29.97	 7.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21313	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21314	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21315	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21316	 1	 16.18	 5.29	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21317	 1	 17.82	 5.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21318	 1	 12.44	 4.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21319	 1	 9.75	 3.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21320	 1	 17.94	 6.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21321	 1	 16.41	 5.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21322	 1	 37.3	 7.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21323	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21324	 1	 4.06	 1.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21325	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21326	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21327	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21328	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21329	 1	 56.8	 12.96	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21330	 1	 10.97	 4.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21331	 1	 10.61	 3.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21332	 1	 55.03	 11.81	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21333	 1	 5.06	 2.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21334	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21335	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21336	 1	 8.97	 3.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21337	 1	 6.68	 2.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21338	 1	 12.83	 3.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21339	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21340	 1	 9.61	 3.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21341	 1	 23.57	 7.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21342	 1	 12.22	 4.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21343	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21344	 1	 2.86	 1.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21345	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21346	 1	 3.66	 1.52	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21347	 1	 3.48	 1.37	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21348	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21349	 1	 9.83	 3.9	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21350	 1	 3.7	 1.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21351	 1	 8.16	 3.26	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21352	 1	 14.57	 4.96	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21353	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21354	 1	 3.33	 1.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21355	 1	 7.65	 2.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21356	 1	 15.96	 5.53	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21357	 1	 9.38	 4.22	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21358	 1	 14.26	 3.62	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21359	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21360	 1	 14.59	 4.79	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21361	 1	 9.25	 2.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21362	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21363	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21364	 1	 14.9	 5.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21365	 1	 4.08	 1.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21366	 1	 8.51	 2.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21367	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21368	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21369	 1	 23.61	 5.98	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21370	 1	 8.44	 3.83	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21371	 1	 3.62	 1.53	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21372	 1	 6.98	 2.7	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21373	 1	 22.98	 7.41	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21374	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21375	 1	 15.54	 5.2	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21376	 1	 5.72	 2.02	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21377	 1	 10.25	 4.44	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21378	 1	 4.44	 1.43	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21379	 1	 10.14	 2.88	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21380	 1	 11.78	 5.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21381	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	21382	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21383	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21384	 1	 4.11	 1.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21385	 1	 3.64	 1.69	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21386	 1	 6.13	 2.31	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21387	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21388	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21389	 1	 59.99	 14.24	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21390	 1	 12.94	 5.33	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21391	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21392	 1	 22.61	 6.54	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21393	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21394	 1	 5.61	 2.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21395	 1	 8.67	 3.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21396	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21397	 1	 6.29	 2.54	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21398	 1	 4.37	 1.74	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21399	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21400	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21401	 1	 6.44	 2.51	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21402	 1	 5.47	 2.41	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21403	 1	 3.8	 1.45	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21404	 1	 13.63	 5.55	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21405	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21406	 1	 4.76	 1.89	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21407	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21408	 1	 17.15	 4.86	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21409	 1	 6.24	 2.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21410	 1	 3.27	 1.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21411	 1	 4.13	 1.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21412	 1	 3.73	 1.81	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21413	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21414	 1	 5.52	 2.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21415	 1	 6.18	 2.86	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21416	 1	 6.91	 2.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21417	 1	 5.58	 2.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21418	 1	 5.13	 2.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21419	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21420	 1	 2.97	 1.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21421	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21422	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21423	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21424	 1	 5.31	 2.28	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21425	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21426	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21427	 1	 3.26	 1.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21428	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21429	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21430	 1	 4.56	 1.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21431	 1	 1.96	 0.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21432	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21433	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21434	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21435	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21436	 1	 9.53	 3.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21437	 1	 8.16	 3.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21438	 1	 6.26	 2.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21439	 1	 11.34	 3.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21440	 1	 16.46	 5.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21441	 1	 7.08	 3.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21442	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21443	 1	 6.37	 2.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21444	 1	 5.05	 2.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21445	 1	 15.25	 5.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21446	 1	 8.94	 3.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21447	 1	 9.32	 3.8	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21448	 1	 8.28	 3.36	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21449	 1	 11.66	 4.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21450	 1	 5.12	 2.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21451	 1	 4.43	 1.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21452	 1	 10.43	 4.2	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21453	 1	 5.06	 1.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21454	 1	 7.59	 2.99	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21455	 1	 6.18	 2.48	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21456	 1	 12.3	 3.9	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21457	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21458	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21459	 1	 1.74	 0.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21460	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21461	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21462	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21463	 1	 7.54	 3.16	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21464	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21465	 1	 4.55	 2.17	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21466	 1	 5.99	 2.31	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21467	 1	 4.84	 1.9	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21468	 1	 6.21	 2.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21469	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21470	 1	 10.83	 4.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21471	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21472	 1	 3.03	 1.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21473	 1	 6.4	 2.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21474	 1	 8.37	 3.81	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21475	 1	 110.0	 29.94	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21476	 1	 6.19	 2.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21477	 1	 2.72	 1.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21478	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21479	 1	 14.88	 5.55	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21480	 1	 7.31	 2.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21481	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21482	 1	 4.62	 1.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21483	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	21484	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21485	 1	 64.17	 18.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21486	 1	 20.68	 7.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21487	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	21488	 1	 11.99	 3.85	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21489	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21490	 1	 5.27	 2.04	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21491	 1	 3.84	 1.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21492	 1	 4.63	 1.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21493	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21494	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21495	 1	 1.88	 0.74	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21496	 1	 3.24	 1.11	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21497	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21498	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21499	 1	 4.55	 1.82	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21500	 1	 2.36	 1.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21501	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21502	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21503	 1	 4.87	 1.59	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21504	 1	 5.03	 1.83	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21505	 1	 16.34	 4.58	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21506	 1	 4.25	 1.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21507	 1	 5.42	 1.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21508	 1	 9.78	 2.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21509	 1	 22.27	 4.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21510	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21511	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21512	 1	 10.91	 3.01	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21513	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21514	 1	 9.58	 3.74	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21515	 1	 6.29	 2.24	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21516	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21517	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21518	 1	 2.03	 0.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21519	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21520	 1	 3.6	 1.43	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21521	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21522	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21523	 1	 3.68	 1.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21524	 1	 19.83	 4.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21525	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21526	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21527	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21528	 1	 13.15	 3.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21529	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21530	 1	 3.57	 1.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21531	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21532	 1	 9.57	 3.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21533	 1	 11.44	 3.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21534	 1	 9.77	 2.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21535	 1	 13.52	 3.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21536	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21537	 1	 8.93	 3.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21538	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21539	 1	 13.35	 4.24	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21540	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21541	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21542	 1	 17.47	 4.45	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21543	 1	 15.39	 5.06	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21544	 1	 22.21	 6.37	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21545	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21546	 1	 25.66	 7.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21547	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21548	 1	 9.52	 3.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21549	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21550	 1	 9.49	 3.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21551	 1	 7.52	 3.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21552	 1	 12.5	 4.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21553	 1	 10.79	 4.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21554	 1	 12.83	 4.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21555	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21556	 1	 3.71	 1.54	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21557	 1	 15.21	 3.17	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21558	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21559	 1	 2.65	 1.23	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21560	 1	 7.62	 2.78	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21561	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21562	 1	 23.01	 7.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21563	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21564	 1	 13.64	 4.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21565	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21566	 1	 23.31	 7.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21567	 1	 12.95	 5.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21568	 1	 10.99	 4.32	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21569	 1	 57.77	 20.41	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21570	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21571	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21572	 1	 8.01	 3.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21573	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21574	 1	 7.18	 2.96	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21575	 1	 3.18	 1.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21576	 1	 5.35	 2.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21577	 1	 13.74	 5.02	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21578	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21579	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21580	 1	 6.32	 2.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21581	 1	 13.43	 4.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21582	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21583	 1	 5.18	 1.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21584	 1	 6.74	 3.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21585	 1	 9.89	 3.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21586	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21587	 1	 5.88	 2.01	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21588	 1	 10.49	 3.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21589	 1	 9.62	 4.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21590	 1	 12.27	 4.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21591	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21592	 1	 7.73	 3.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21593	 1	 7.6	 3.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21594	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21595	 1	 12.43	 4.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21596	 1	 9.64	 3.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21597	 1	 22.01	 8.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21598	 1	 3.06	 1.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21599	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21600	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21601	 1	 55.12	 14.99	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21602	 1	 3.88	 1.6	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21603	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21604	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21605	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21606	 1	 12.16	 2.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21607	 1	 3.84	 1.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21608	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21609	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21610	 1	 5.55	 1.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21611	 1	 117.14	 25.91	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21612	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21613	 1	 6.81	 1.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21614	 1	 18.61	 -6.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21615	 1	 14.26	 3.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21616	 1	 55.91	 18.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21617	 1	 7.62	 2.79	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21618	 1	 22.15	 5.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21619	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21620	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21621	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21622	 1	 12.17	 4.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21623	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21624	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21625	 1	 10.0	 3.76	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21626	 1	 19.33	 5.45	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21627	 1	 3.82	 1.67	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21628	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21629	 1	 8.57	 3.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21630	 1	 8.75	 3.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21631	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21632	 1	 9.72	 3.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21633	 1	 9.45	 3.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21634	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21635	 1	 10.5	 3.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21636	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21637	 1	 4.0	 1.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21638	 1	 7.71	 2.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21639	 1	 5.5	 1.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21640	 1	 5.49	 1.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21641	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21642	 1	 5.91	 2.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21643	 1	 9.37	 3.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21644	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21645	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21646	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21647	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21648	 1	 6.27	 2.82	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21649	 1	 5.34	 1.83	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21650	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21651	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21652	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21653	 1	 5.26	 2.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21654	 1	 4.2	 1.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21655	 1	 6.94	 2.25	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21656	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21657	 1	 8.16	 3.49	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21658	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21659	 1	 8.92	 3.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21660	 1	 4.22	 1.93	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21661	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21662	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21663	 1	 36.87	 10.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21664	 1	 72.05	 14.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21665	 1	 8.02	 3.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21666	 1	 6.87	 3.21	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21667	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21668	 1	 18.57	 4.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21669	 1	 13.54	 5.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21670	 1	 5.66	 2.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21671	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21672	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21673	 1	 7.71	 3.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21674	 1	 6.98	 3.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21675	 1	 7.59	 2.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21676	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21677	 1	 7.68	 2.71	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21678	 1	 11.76	 4.05	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21679	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21680	 1	 6.85	 3.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21681	 1	 12.83	 5.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21682	 1	 8.92	 3.98	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21683	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21684	 1	 7.94	 2.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21685	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21686	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21687	 1	 7.88	 1.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21688	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21689	 1	 9.8	 2.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21690	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21691	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21692	 1	 9.72	 2.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21693	 1	 29.93	 6.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21694	 1	 23.44	 4.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21695	 1	 6.61	 1.42	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21696	 1	 3.81	 1.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21697	 1	 4.76	 1.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21698	 1	 16.26	 5.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21699	 1	 8.3	 3.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21700	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21701	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21702	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21703	 1	 4.91	 2.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21704	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21705	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21706	 1	 8.66	 3.25	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21707	 1	 12.5	 4.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21708	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21709	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21710	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21711	 1	 9.46	 3.91	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21712	 1	 10.06	 4.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21713	 1	 9.97	 3.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21714	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21715	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21716	 1	 18.5	 6.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21717	 1	 14.76	 2.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21718	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21719	 1	 6.24	 2.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21720	 1	 10.66	 4.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21721	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21722	 1	 16.43	 7.03	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21723	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21724	 1	 8.16	 2.98	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21725	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21726	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21727	 1	 11.9	 4.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21728	 1	 1.4	 0.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21729	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21730	 1	 9.96	 3.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21731	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21732	 1	 3.12	 1.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21733	 1	 14.52	 5.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21734	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21735	 1	 8.77	 3.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21736	 1	 10.17	 4.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21737	 1	 5.61	 2.4	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21738	 1	 5.13	 2.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21739	 1	 17.15	 6.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21740	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21741	 1	 4.31	 1.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21742	 1	 6.1	 2.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21743	 1	 21.91	 5.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21744	 1	 11.59	 3.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21745	 1	 96.06	 17.19	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21746	 1	 5.87	 1.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21747	 1	 18.99	 4.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21748	 1	 10.41	 3.79	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21749	 1	 3.34	 1.27	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21750	 1	 9.7	 4.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21751	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21752	 1	 148.69	 38.74	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21753	 1	 77.73	 11.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21754	 1	 16.91	 6.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21755	 1	 4.33	 1.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21756	 1	 3.41	 1.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21757	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21758	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21759	 1	 66.79	 22.1	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21760	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21761	 1	 4.35	 1.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21762	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21763	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21764	 1	 6.32	 2.03	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21765	 1	 13.04	 5.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21766	 1	 4.15	 1.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21767	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21768	 1	 32.41	 10.06	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21769	 1	 14.27	 5.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21770	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21771	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21772	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21773	 1	 6.76	 1.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21774	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21775	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21776	 1	 8.89	 1.98	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21777	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21778	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21779	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21780	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21781	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21782	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21783	 1	 11.34	 3.73	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21784	 1	 10.06	 3.84	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21785	 1	 7.84	 3.39	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21786	 1	 7.89	 2.83	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21787	 1	 21.37	 4.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21788	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21789	 1	 21.34	 4.97	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21790	 1	 9.45	 3.41	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21791	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21792	 1	 7.41	 1.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21793	 1	 6.64	 1.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21794	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21795	 1	 3.39	 0.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21796	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21797	 1	 3.17	 0.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21798	 1	 11.02	 2.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21799	 1	 2.12	 0.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21800	 1	 6.86	 1.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21801	 1	 4.5	 0.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21802	 1	 7.42	 1.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21803	 1	 2.76	 0.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21804	 1	 3.11	 0.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21805	 1	 4.78	 1.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21806	 1	 7.46	 1.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21807	 1	 3.76	 0.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21808	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21809	 1	 1.41	 0.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21810	 1	 4.5	 1.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21811	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21812	 1	 23.36	 6.77	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21813	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21814	 1	 6.74	 2.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21815	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21816	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21817	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21818	 1	 32.04	 8.95	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21819	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21820	 1	 2.68	 0.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21821	 1	 5.45	 1.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21822	 1	 8.15	 1.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21823	 1	 3.75	 0.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21824	 1	 60.4	 17.71	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21825	 1	 4.92	 1.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21826	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21827	 1	 19.2	 6.53	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21828	 1	 40.6	 10.67	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21829	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21830	 1	 4.79	 1.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21831	 1	 5.78	 1.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21832	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21833	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21834	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21835	 1	 79.53	 24.65	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21836	 1	 10.35	 3.22	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21837	 1	 1.84	 0.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21838	 1	 25.77	 5.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21839	 1	 12.28	 2.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21840	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21841	 1	 10.17	 2.24	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21842	 1	 3.07	 0.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21843	 1	 5.55	 1.21	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21844	 1	 6.37	 1.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21845	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21846	 1	 8.98	 3.57	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21847	 1	 5.83	 2.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21848	 1	 35.43	 9.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21849	 1	 13.12	 2.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21850	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21851	 1	 16.96	 3.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21852	 1	 13.1	 2.85	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21853	 1	 11.53	 2.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21854	 1	 10.82	 2.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21855	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21856	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21857	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21858	 1	 2.39	 1.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21859	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21860	 1	 5.49	 2.18	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21861	 1	 23.22	 6.26	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21862	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21863	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21864	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21865	 1	 11.12	 3.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21866	 1	 5.81	 2.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21867	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21868	 1	 14.29	 5.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21869	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21870	 1	 18.79	 6.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21871	 1	 59.9	 12.29	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21872	 1	 9.62	 3.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21873	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21874	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21875	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21876	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21877	 1	 9.68	 3.31	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21878	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21879	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21880	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21881	 1	 20.32	 7.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21882	 1	 13.38	 4.34	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21883	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21884	 1	 6.19	 2.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21885	 1	 5.98	 2.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21886	 1	 3.49	 1.57	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21887	 1	 9.12	 3.31	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21888	 1	 16.3	 3.61	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21889	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21890	 1	 14.36	 4.38	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21891	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21892	 1	 9.37	 3.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21893	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21894	 1	 5.83	 1.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21895	 1	 6.17	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21896	 1	 4.31	 0.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21897	 1	 6.46	 1.42	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21898	 1	 67.79	 14.77	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21899	 1	 8.99	 1.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21900	 1	 4.54	 0.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21901	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21902	 1	 19.14	 7.51	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21903	 1	 8.69	 3.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21904	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21905	 1	 3.1	 1.33	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21906	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21907	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21908	 1	 6.23	 2.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21909	 1	 6.42	 2.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21910	 1	 7.2	 2.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21911	 1	 2.43	 1.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21912	 1	 7.59	 2.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21913	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21914	 1	 24.82	 6.01	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21915	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21916	 1	 1.79	 0.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21917	 1	 3.93	 1.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21918	 1	 7.45	 2.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21919	 1	 17.35	 4.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21920	 1	 5.17	 1.93	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21921	 1	 8.57	 3.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21922	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21923	 1	 16.64	 7.25	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21924	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21925	 1	 54.92	 12.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21926	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21927	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21928	 1	 7.87	 3.41	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21929	 1	 5.71	 2.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21930	 1	 3.78	 1.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21931	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21932	 1	 5.67	 2.56	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21933	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21934	 1	 8.37	 3.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21935	 1	 11.95	 5.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21936	 1	 20.22	 8.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21937	 1	 4.53	 1.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21938	 1	 8.59	 4.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21939	 1	 2.55	 1.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21940	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21941	 1	 24.12	 6.92	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21942	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21943	 1	 11.79	 5.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21944	 1	 21.78	 6.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21945	 1	 16.31	 5.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21946	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21947	 1	 7.27	 2.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21948	 1	 4.84	 2.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21949	 1	 13.89	 3.64	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21950	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21951	 1	 21.33	 7.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21952	 1	 6.16	 2.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21953	 1	 14.03	 3.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21954	 1	 12.5	 5.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21955	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21956	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21957	 1	 2.98	 1.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21958	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21959	 1	 2.49	 1.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21960	 1	 3.87	 1.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21961	 1	 8.33	 3.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21962	 1	 9.18	 3.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21963	 1	 4.21	 1.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21964	 1	 2.39	 0.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21965	 1	 2.58	 1.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21966	 1	 5.6	 2.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21967	 1	 2.61	 1.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21968	 1	 8.45	 3.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21969	 1	 9.57	 2.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21970	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21971	 1	 11.13	 3.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21972	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21973	 1	 36.41	 9.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21974	 1	 5.79	 2.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21975	 1	 10.08	 3.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21976	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21977	 1	 36.81	 7.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21978	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21979	 1	 6.65	 3.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21980	 1	 4.65	 2.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21981	 1	 9.07	 3.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21982	 1	 11.91	 4.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21983	 1	 3.64	 1.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21984	 1	 4.17	 1.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21985	 1	 6.11	 2.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21986	 1	 6.74	 2.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21987	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21988	 1	 9.17	 3.27	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21989	 1	 8.14	 3.3	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21990	 1	 13.18	 5.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21991	 1	 7.98	 2.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21992	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21993	 1	 21.65	 8.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21994	 1	 69.71	 20.17	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21995	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21996	 1	 13.39	 6.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21997	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21998	 1	 12.37	 5.21	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21999	 1	 2.84	 1.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22000	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22001	 1	 2.47	 0.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22002	 1	 8.49	 3.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22003	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22004	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22005	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22006	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22007	 1	 10.09	 3.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22008	 1	 5.15	 2.04	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22009	 1	 2.25	 0.9	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22010	 1	 4.66	 1.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22011	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22012	 1	 13.5	 5.41	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22013	 1	 5.56	 2.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22014	 1	 4.91	 2.32	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22015	 1	 7.21	 2.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22016	 1	 70.53	 16.2	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22017	 1	 7.65	 3.27	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22018	 1	 4.4	 2.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22019	 1	 6.47	 3.36	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22020	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22021	 1	 16.39	 4.52	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22022	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22023	 1	 9.41	 3.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22024	 1	 14.58	 5.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22025	 1	 25.33	 7.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22026	 1	 17.03	 5.22	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22027	 1	 5.4	 2.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22028	 1	 3.59	 1.48	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22029	 1	 24.8	 9.49	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22030	 1	 10.89	 4.11	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22031	 1	 16.56	 7.18	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22032	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22033	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22034	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22035	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22036	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22037	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22038	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22039	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22040	 1	 14.55	 3.84	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22041	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22042	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22043	 1	 8.59	 3.55	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22044	 1	 30.98	 9.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22045	 1	 4.45	 2.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22046	 1	 5.89	 2.58	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22047	 1	 16.03	 5.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22048	 1	 5.88	 2.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22049	 1	 76.3	 23.59	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22050	 1	 16.72	 5.64	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22051	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22052	 1	 7.93	 3.55	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22053	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22054	 1	 12.09	 5.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22055	 1	 9.62	 4.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22056	 1	 8.06	 3.18	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22057	 1	 6.29	 2.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22058	 1	 13.8	 4.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22059	 1	 12.57	 4.74	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22060	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22061	 1	 10.59	 4.04	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22062	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22063	 1	 13.22	 5.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22064	 1	 13.46	 4.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22065	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22066	 1	 11.51	 4.42	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22067	 1	 9.73	 4.03	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22068	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22069	 1	 6.66	 3.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22070	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22071	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22072	 1	 4.24	 1.69	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22073	 1	 7.67	 1.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22074	 1	 10.24	 2.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22075	 1	 8.17	 2.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22076	 1	 13.15	 3.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22077	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22078	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22079	 1	 17.47	 3.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22080	 1	 21.54	 4.82	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22081	 1	 19.58	 4.74	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22082	 1	 6.8	 2.32	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22083	 1	 25.28	 6.93	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22084	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22085	 1	 9.58	 3.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22086	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22087	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22088	 1	 15.63	 4.57	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22089	 1	 11.25	 4.1	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22090	 1	 14.99	 4.69	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22091	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22092	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22093	 1	 10.56	 3.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22094	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22095	 1	 7.08	 1.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22096	 1	 12.83	 2.81	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22097	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22098	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22099	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22100	 1	 10.36	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22101	 1	 1.27	 0.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22102	 1	 2.25	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22103	 1	 2.27	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22104	 1	 3.65	 2.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22105	 1	 0.86	 0.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22106	 1	 0.0	 0.0	 0.0	 -35.22	 17	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	22107	 1	 1.99	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22108	 1	 4.61	 2.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22109	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22110	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22111	 1	 4.85	 3.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22112	 1	 5.28	 2.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22113	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22114	 1	 4.01	 2.42	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22115	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22116	 1	 1.43	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22117	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22118	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22119	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22120	 1	 2.34	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22121	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22122	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22123	 1	 9.52	 4.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22124	 1	 10.37	 6.6	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22125	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22126	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22127	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22128	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22129	 1	 4.14	 2.94	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22130	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22131	 1	 3.47	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22132	 1	 0.71	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22133	 1	 3.56	 2.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22134	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22135	 1	 8.28	 5.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22136	 1	 20.57	 9.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22137	 1	 3.84	 2.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22138	 1	 1.45	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22139	 1	 4.32	 3.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22140	 1	 2.37	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22141	 1	 4.23	 2.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22142	 1	 2.45	 0.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22143	 1	 2.61	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22144	 1	 2.0	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22145	 1	 6.87	 3.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22146	 1	 2.07	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22147	 1	 2.76	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22148	 1	 5.91	 3.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22149	 1	 1.65	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22150	 1	 2.25	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22151	 1	 2.78	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22152	 1	 2.12	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22153	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22154	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22155	 1	 7.66	 3.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22156	 1	 5.51	 3.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22157	 1	 4.1	 2.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22158	 1	 10.68	 5.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22159	 1	 4.71	 2.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22160	 1	 2.53	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22161	 1	 5.53	 3.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22162	 1	 7.21	 4.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22163	 1	 2.8	 1.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22164	 1	 1.75	 0.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22165	 1	 10.58	 6.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22166	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22167	 1	 1.52	 0.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22168	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22169	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22170	 1	 2.02	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22171	 1	 4.31	 2.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22172	 1	 2.06	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22173	 1	 5.1	 2.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22174	 1	 4.61	 2.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22175	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22176	 1	 5.73	 3.18	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22177	 1	 4.96	 3.52	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22178	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22179	 1	 6.29	 4.05	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22180	 1	 5.16	 2.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22181	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22182	 1	 16.26	 9.08	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22183	 1	 7.38	 4.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22184	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22185	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22186	 1	 1.67	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22187	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22188	 1	 3.82	 2.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22189	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22190	 1	 1.62	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22191	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22192	 1	 3.79	 2.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22193	 1	 4.69	 3.15	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22194	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22195	 1	 1.29	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22196	 1	 3.56	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22197	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22198	 1	 8.15	 2.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22199	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22200	 1	 1.36	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22201	 1	 4.74	 2.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22202	 1	 1.49	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22203	 1	 9.99	 5.47	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22204	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22205	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22206	 1	 2.37	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22207	 1	 4.82	 2.43	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22208	 1	 9.5	 5.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22209	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22210	 1	 1.58	 0.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22211	 1	 5.04	 3.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22212	 1	 3.37	 2.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22213	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22214	 1	 4.95	 3.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22215	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22216	 1	 2.03	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22217	 1	 1.55	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22218	 1	 9.16	 3.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22219	 1	 8.41	 3.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22220	 1	 5.72	 3.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22221	 1	 5.58	 3.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22222	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22223	 1	 2.43	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22224	 1	 2.14	 1.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22225	 1	 2.86	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22226	 1	 1.84	 1.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22227	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22228	 1	 2.28	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22229	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22230	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22231	 1	 1.3	 0.66	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22232	 1	 8.74	 5.42	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22233	 1	 2.74	 1.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22234	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22235	 1	 8.27	 4.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22236	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22237	 1	 7.71	 3.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22238	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22239	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22240	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22241	 1	 7.21	 4.09	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22242	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22243	 1	 0.71	 0.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22244	 1	 3.82	 2.71	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22245	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22246	 1	 5.67	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22247	 1	 8.21	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22248	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22249	 1	 5.25	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22250	 1	 4.54	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22251	 1	 1.94	 0.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22252	 1	 2.79	 0.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22253	 1	 8.75	 1.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22254	 1	 12.65	 2.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22255	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22256	 1	 2.0	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22257	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22258	 1	 3.04	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22259	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22260	 1	 2.87	 0.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22261	 1	 4.01	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22262	 1	 15.39	 3.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22263	 1	 2.5	 0.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22264	 1	 4.25	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22265	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22266	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22267	 1	 1.62	 0.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22268	 1	 9.38	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22269	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22270	 1	 7.24	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22271	 1	 3.16	 0.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22272	 1	 2.68	 0.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22273	 1	 7.19	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22274	 1	 6.09	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22275	 1	 4.06	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22276	 1	 4.11	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22277	 1	 3.3	 0.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22278	 1	 3.07	 0.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22279	 1	 2.01	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22280	 1	 2.49	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22281	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22282	 1	 3.68	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22283	 1	 7.74	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22284	 1	 7.65	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22285	 1	 1.93	 0.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22286	 1	 7.03	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22287	 1	 4.56	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22288	 1	 1.11	 0.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22289	 1	 2.6	 0.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22290	 1	 10.07	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22291	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22292	 1	 7.98	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22293	 1	 8.6	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22294	 1	 3.57	 0.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22295	 1	 34.42	 7.82	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22296	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22297	 1	 3.92	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22298	 1	 4.79	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22299	 1	 2.07	 0.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22300	 1	 3.24	 1.98	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22301	 1	 4.79	 2.41	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22302	 1	 4.96	 2.54	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22303	 1	 13.88	 5.61	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22304	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22305	 1	 7.84	 4.44	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22306	 1	 13.1	 6.08	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22307	 1	 6.95	 4.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22308	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22309	 1	 0.96	 0.67	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22310	 1	 5.89	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22311	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22312	 1	 1.2	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22313	 1	 3.01	 1.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22314	 1	 5.64	 2.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22315	 1	 2.01	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22316	 1	 7.65	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22317	 1	 4.32	 2.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22318	 1	 5.61	 2.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22319	 1	 3.42	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22320	 1	 2.52	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22321	 1	 2.82	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22322	 1	 8.89	 4.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22323	 1	 9.08	 4.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22324	 1	 2.77	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22325	 1	 3.01	 1.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22326	 1	 1.48	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22327	 1	 2.16	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22328	 1	 2.84	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22329	 1	 1.66	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22330	 1	 4.54	 2.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22331	 1	 4.1	 2.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22332	 1	 1.93	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22333	 1	 6.57	 4.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22334	 1	 4.59	 3.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22335	 1	 0.77	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22336	 1	 10.17	 5.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22337	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22338	 1	 1.81	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22339	 1	 1.12	 0.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22340	 1	 0.98	 0.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22341	 1	 0.85	 0.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22342	 1	 1.53	 0.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22343	 1	 7.97	 4.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22344	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22345	 1	 1.16	 0.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22346	 1	 6.53	 4.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22347	 1	 3.13	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22348	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22349	 1	 2.05	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22350	 1	 1.5	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22351	 1	 7.56	 3.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22352	 1	 4.07	 2.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22353	 1	 2.16	 1.7	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22354	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22355	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22356	 1	 1.92	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22357	 1	 5.6	 3.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22358	 1	 4.09	 2.65	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22359	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22360	 1	 4.47	 2.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22361	 1	 5.37	 2.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22362	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22363	 1	 1.7	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22364	 1	 2.48	 1.74	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22365	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22366	 1	 3.89	 2.36	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22367	 1	 4.61	 2.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22368	 1	 2.8	 1.71	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22369	 1	 6.85	 3.42	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22370	 1	 2.05	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22371	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22372	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22373	 1	 1.73	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22374	 1	 7.04	 4.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22375	 1	 4.72	 2.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22376	 1	 8.7	 5.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22377	 1	 1.47	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22378	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22379	 1	 0.85	 0.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22380	 1	 6.34	 3.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22381	 1	 3.2	 2.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22382	 1	 4.91	 3.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22383	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22384	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22385	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22386	 1	 11.68	 7.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22387	 1	 3.22	 2.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22388	 1	 1.85	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22389	 1	 2.91	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22390	 1	 3.58	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22391	 1	 7.48	 3.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22392	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22393	 1	 6.51	 3.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22394	 1	 11.12	 4.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22395	 1	 7.56	 3.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22396	 1	 3.32	 2.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22397	 1	 1.25	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22398	 1	 3.6	 2.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22399	 1	 2.18	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22400	 1	 3.7	 2.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22401	 1	 1.47	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22402	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22403	 1	 11.4	 6.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22404	 1	 9.05	 5.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22405	 1	 2.91	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22406	 1	 12.24	 6.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22407	 1	 1.91	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22408	 1	 4.55	 2.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22409	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22410	 1	 3.37	 2.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22411	 1	 4.66	 3.04	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22412	 1	 19.05	 7.09	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22413	 1	 3.38	 0.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22414	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22415	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22416	 1	 6.23	 3.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22417	 1	 2.65	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22418	 1	 4.64	 2.82	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22419	 1	 1.66	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22420	 1	 5.4	 3.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22421	 1	 2.51	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22422	 1	 6.81	 3.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22423	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22424	 1	 2.56	 1.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22425	 1	 1.89	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22426	 1	 5.39	 3.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22427	 1	 2.67	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22428	 1	 4.27	 2.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22429	 1	 9.13	 3.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22430	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22431	 1	 5.28	 3.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22432	 1	 11.25	 6.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22433	 1	 1.5	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22434	 1	 1.08	 0.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22435	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22436	 1	 1.08	 0.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22437	 1	 1.71	 1.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22438	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22439	 1	 2.1	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22440	 1	 0.58	 0.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22441	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22442	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22443	 1	 1.76	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22444	 1	 1.61	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22445	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22446	 1	 1.26	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22447	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22448	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22449	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22450	 1	 2.27	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22451	 1	 2.15	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22452	 1	 2.25	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22453	 1	 2.72	 1.78	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22454	 1	 5.35	 3.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22455	 1	 1.75	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22456	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22457	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22458	 1	 7.59	 4.26	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22459	 1	 1.55	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22460	 1	 4.49	 2.76	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22461	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22462	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22463	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22464	 1	 1.37	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22465	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22466	 1	 3.41	 2.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22467	 1	 3.96	 2.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22468	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22469	 1	 3.63	 2.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22470	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22471	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22472	 1	 2.29	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22473	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22474	 1	 2.19	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22475	 1	 0.69	 0.49	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22476	 1	 1.04	 0.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22477	 1	 1.12	 0.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22478	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22479	 1	 3.42	 2.11	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22480	 1	 3.88	 2.01	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22481	 1	 6.48	 4.02	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22482	 1	 1.6	 1.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22483	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22484	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22485	 1	 1.48	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22486	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22487	 1	 2.39	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22488	 1	 2.4	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22489	 1	 1.55	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22490	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22491	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22492	 1	 4.77	 2.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22493	 1	 2.15	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22494	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22495	 1	 5.58	 3.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22496	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22497	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22498	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22499	 1	 4.84	 2.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22500	 1	 6.28	 3.92	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22501	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22502	 1	 2.75	 2.24	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22503	 1	 2.64	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22504	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22505	 1	 2.78	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22506	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22507	 1	 2.07	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22508	 1	 3.8	 2.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22509	 1	 2.96	 2.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22510	 1	 5.23	 3.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22511	 1	 2.36	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22512	 1	 1.35	 0.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22513	 1	 3.49	 2.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22514	 1	 3.17	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22515	 1	 3.65	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22516	 1	 1.83	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22517	 1	 2.99	 2.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22518	 1	 1.8	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22519	 1	 1.79	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22520	 1	 4.36	 2.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22521	 1	 1.61	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22522	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22523	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22524	 1	 0.85	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22525	 1	 2.39	 1.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22526	 1	 1.15	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22527	 1	 2.49	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22528	 1	 7.17	 4.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22529	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22530	 1	 2.82	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22531	 1	 0.89	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22532	 1	 4.22	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22533	 1	 2.23	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22534	 1	 1.16	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22535	 1	 1.93	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22536	 1	 1.05	 0.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22537	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22538	 1	 1.12	 0.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22539	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22540	 1	 7.87	 4.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22541	 1	 2.28	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22542	 1	 2.27	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22543	 1	 2.37	 1.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22544	 1	 2.07	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22545	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22546	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22547	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22548	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22549	 1	 1.29	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22550	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22551	 1	 1.08	 0.74	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22552	 1	 2.16	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22553	 1	 2.23	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22554	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22555	 1	 5.32	 3.49	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22556	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22557	 1	 7.44	 3.62	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22558	 1	 3.55	 2.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22559	 1	 1.66	 1.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22560	 1	 2.93	 1.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22561	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22562	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22563	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22564	 1	 2.22	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22565	 1	 0.72	 0.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22566	 1	 1.37	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22567	 1	 1.63	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22568	 1	 4.01	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22569	 1	 1.26	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22570	 1	 4.82	 3.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22571	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22572	 1	 1.23	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22573	 1	 1.84	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22574	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22575	 1	 5.22	 2.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22576	 1	 0.59	 0.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22577	 1	 5.51	 3.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22578	 1	 3.23	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22579	 1	 2.57	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22580	 1	 3.79	 2.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22581	 1	 4.5	 2.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22582	 1	 2.96	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22583	 1	 3.96	 3.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22584	 1	 2.98	 0.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22585	 1	 4.36	 0.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22586	 1	 13.54	 7.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22587	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22588	 1	 3.27	 0.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22589	 1	 2.39	 0.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22590	 1	 2.98	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22591	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22592	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22593	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22594	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22595	 1	 2.78	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22596	 1	 2.31	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22597	 1	 14.14	 8.43	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22598	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22599	 1	 1.33	 1.09	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22600	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22601	 1	 4.87	 2.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22602	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22603	 1	 3.59	 2.66	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22604	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22605	 1	 6.15	 3.52	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22606	 1	 2.26	 1.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22607	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22608	 1	 14.48	 3.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22609	 1	 10.36	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22610	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22611	 1	 3.53	 0.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22612	 1	 11.41	 2.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22613	 1	 2.31	 0.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22614	 1	 4.92	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22615	 1	 3.61	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22616	 1	 3.12	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22617	 1	 3.17	 -4.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22618	 1	 2.07	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22619	 1	 3.55	 2.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22620	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22621	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22622	 1	 6.82	 4.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22623	 1	 5.19	 2.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22624	 1	 1.82	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22625	 1	 7.82	 4.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22626	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22627	 1	 6.48	 4.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22628	 1	 1.39	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22629	 1	 1.33	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22630	 1	 1.3	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22631	 1	 0.57	 0.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22632	 1	 1.58	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22633	 1	 6.98	 3.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22634	 1	 7.21	 3.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22635	 1	 11.53	 5.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22636	 1	 4.58	 2.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22637	 1	 7.68	 4.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22638	 1	 4.25	 2.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22639	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22640	 1	 15.42	 6.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22641	 1	 1.37	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22642	 1	 1.77	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22643	 1	 1.58	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22644	 1	 3.38	 2.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22645	 1	 2.14	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22646	 1	 1.7	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22647	 1	 2.35	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22648	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22649	 1	 1.69	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22650	 1	 0.92	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22651	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22652	 1	 4.34	 2.75	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22653	 1	 2.5	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22654	 1	 2.2	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22655	 1	 1.75	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22656	 1	 3.79	 2.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22657	 1	 7.31	 3.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22658	 1	 3.65	 2.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22659	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22660	 1	 1.07	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22661	 1	 3.26	 2.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22662	 1	 5.24	 3.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22663	 1	 2.36	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22664	 1	 1.54	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22665	 1	 4.66	 2.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22666	 1	 2.19	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22667	 1	 3.31	 2.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22668	 1	 1.26	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22669	 1	 2.59	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22670	 1	 5.01	 2.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22671	 1	 3.28	 2.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22672	 1	 2.76	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22673	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22674	 1	 1.16	 0.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22675	 1	 2.26	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22676	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22677	 1	 0.54	 0.42	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22678	 1	 1.6	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22679	 1	 0.69	 0.49	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22680	 1	 1.36	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22681	 1	 2.28	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22682	 1	 2.07	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22683	 1	 1.52	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22684	 1	 2.66	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22685	 1	 1.59	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22686	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22687	 1	 2.82	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22688	 1	 5.55	 4.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22689	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22690	 1	 3.17	 1.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22691	 1	 2.44	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22692	 1	 2.07	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22693	 1	 4.35	 2.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22694	 1	 5.04	 3.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22695	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22696	 1	 2.84	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22697	 1	 6.31	 3.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22698	 1	 2.48	 1.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22699	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22700	 1	 6.75	 3.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22701	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22702	 1	 4.97	 2.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22703	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22704	 1	 3.31	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22705	 1	 3.28	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22706	 1	 5.48	 3.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22707	 1	 4.0	 2.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22708	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22709	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22710	 1	 2.29	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22711	 1	 2.69	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22712	 1	 4.89	 2.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22713	 1	 8.59	 5.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22714	 1	 5.65	 3.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22715	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22716	 1	 7.62	 4.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22717	 1	 8.15	 5.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22718	 1	 2.09	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22719	 1	 14.35	 5.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22720	 1	 0.13	 0.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22721	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22722	 1	 8.96	 4.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22723	 1	 3.32	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22724	 1	 11.25	 5.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22725	 1	 8.67	 4.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22726	 1	 13.92	 6.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22727	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22728	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22729	 1	 2.69	 1.7	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22730	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22731	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22732	 1	 4.15	 2.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22733	 1	 1.79	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22734	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22735	 1	 5.99	 3.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22736	 1	 1.37	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22737	 1	 3.26	 1.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22738	 1	 9.0	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22739	 1	 3.62	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22740	 1	 4.51	 2.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22741	 1	 0.94	 0.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22742	 1	 1.25	 0.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22743	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22744	 1	 0.7	 0.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22745	 1	 5.64	 2.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22746	 1	 2.05	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22747	 1	 2.13	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22748	 1	 4.56	 2.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22749	 1	 3.97	 2.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22750	 1	 3.73	 1.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22751	 1	 4.76	 2.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22752	 1	 2.39	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22753	 1	 2.6	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22754	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22755	 1	 2.83	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22756	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22757	 1	 4.06	 2.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22758	 1	 3.96	 2.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22759	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22760	 1	 5.24	 3.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22761	 1	 1.3	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22762	 1	 3.07	 1.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22763	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22764	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22765	 1	 3.84	 2.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22766	 1	 2.58	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22767	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22768	 1	 2.6	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22769	 1	 1.56	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22770	 1	 1.22	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22771	 1	 1.82	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22772	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22773	 1	 2.34	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22774	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22775	 1	 3.42	 2.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22776	 1	 3.94	 3.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22777	 1	 2.83	 2.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22778	 1	 1.73	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22779	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22780	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22781	 1	 14.41	 8.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22782	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22783	 1	 3.26	 2.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22784	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22785	 1	 11.37	 7.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22786	 1	 14.24	 6.13	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22787	 1	 15.03	 8.57	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22788	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22789	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22790	 1	 2.84	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22791	 1	 2.28	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22792	 1	 6.52	 3.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22793	 1	 6.21	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22794	 1	 5.69	 3.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22795	 1	 3.56	 2.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22796	 1	 2.95	 2.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22797	 1	 2.29	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22798	 1	 1.24	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22799	 1	 3.82	 2.74	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22800	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22801	 1	 4.57	 2.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22802	 1	 9.04	 4.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22803	 1	 13.1	 5.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22804	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22805	 1	 4.41	 2.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22806	 1	 4.26	 2.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22807	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22808	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22809	 1	 6.4	 3.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22810	 1	 1.57	 0.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22811	 1	 6.96	 2.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22812	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22813	 1	 6.65	 3.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22814	 1	 3.01	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22815	 1	 6.33	 3.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22816	 1	 3.99	 2.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22817	 1	 5.15	 3.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22818	 1	 1.67	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22819	 1	 0.93	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22820	 1	 8.22	 3.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22821	 1	 2.88	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22822	 1	 4.28	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22823	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22824	 1	 16.55	 8.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22825	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22826	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22827	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22828	 1	 3.99	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22829	 1	 6.47	 3.71	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22830	 1	 2.77	 2.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22831	 1	 2.38	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22832	 1	 2.35	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22833	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22834	 1	 2.06	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22835	 1	 7.41	 3.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22836	 1	 9.78	 5.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22837	 1	 6.01	 3.78	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22838	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22839	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22840	 1	 6.98	 3.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22841	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22842	 1	 7.56	 4.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22843	 1	 7.4	 4.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22844	 1	 10.85	 6.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22845	 1	 1.25	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22846	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22847	 1	 4.32	 3.26	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22848	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22849	 1	 4.0	 2.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22850	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22851	 1	 4.73	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22852	 1	 6.6	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22853	 1	 11.38	 6.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22854	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22855	 1	 5.77	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22856	 1	 5.06	 2.49	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22857	 1	 21.62	 10.47	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22858	 1	 14.22	 7.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22859	 1	 9.59	 5.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22860	 1	 2.07	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22861	 1	 5.57	 3.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22862	 1	 2.08	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22863	 1	 2.43	 1.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22864	 1	 1.49	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22865	 1	 2.44	 1.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22866	 1	 1.71	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22867	 1	 1.85	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22868	 1	 1.95	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22869	 1	 3.62	 2.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22870	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22871	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22872	 1	 2.34	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22873	 1	 3.76	 2.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22874	 1	 1.84	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22875	 1	 3.05	 2.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22876	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22877	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22878	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22879	 1	 2.84	 2.2	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22880	 1	 2.62	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22881	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22882	 1	 4.25	 2.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22883	 1	 9.04	 4.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22884	 1	 3.72	 1.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22885	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22886	 1	 24.29	 10.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22887	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22888	 1	 3.35	 2.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22889	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22890	 1	 14.0	 7.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22891	 1	 5.91	 2.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22892	 1	 0.96	 0.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22893	 1	 0.8	 0.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22894	 1	 1.91	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22895	 1	 2.09	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22896	 1	 1.77	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22897	 1	 3.23	 2.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22898	 1	 10.41	 5.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22899	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22900	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22901	 1	 6.88	 4.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22902	 1	 7.32	 3.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22903	 1	 1.99	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22904	 1	 8.57	 4.31	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22905	 1	 5.26	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22906	 1	 2.12	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22907	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22908	 1	 6.17	 3.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22909	 1	 9.67	 4.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22910	 1	 3.88	 2.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22911	 1	 1.07	 0.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22912	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22913	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22914	 1	 3.18	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22915	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22916	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22917	 1	 7.57	 4.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22918	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22919	 1	 4.06	 3.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22920	 1	 3.56	 2.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22921	 1	 1.88	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22922	 1	 3.1	 2.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22923	 1	 3.17	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22924	 1	 1.72	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22925	 1	 3.46	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22926	 1	 5.6	 2.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22927	 1	 11.23	 4.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22928	 1	 2.51	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22929	 1	 4.22	 2.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22930	 1	 6.84	 4.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22931	 1	 4.16	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22932	 1	 2.92	 1.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22933	 1	 2.12	 1.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22934	 1	 2.88	 2.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22935	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22936	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22937	 1	 3.23	 2.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22938	 1	 4.41	 2.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22939	 1	 6.27	 4.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22940	 1	 6.28	 3.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22941	 1	 4.78	 2.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22942	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22943	 1	 4.24	 2.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22944	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22945	 1	 4.05	 2.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22946	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22947	 1	 9.99	 5.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22948	 1	 3.06	 2.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22949	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22950	 1	 1.77	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22951	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22952	 1	 2.0	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22953	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22954	 1	 2.24	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22955	 1	 6.75	 3.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22956	 1	 11.0	 5.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22957	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22958	 1	 3.82	 2.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22959	 1	 2.0	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22960	 1	 2.68	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22961	 1	 2.63	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22962	 1	 4.07	 2.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22963	 1	 2.59	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22964	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22965	 1	 4.17	 2.71	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22966	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22967	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22968	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22969	 1	 4.98	 3.27	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22970	 1	 26.45	 11.9	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22971	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22972	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22973	 1	 4.04	 3.07	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22974	 1	 4.15	 2.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22975	 1	 4.34	 3.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22976	 1	 7.09	 4.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22977	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22978	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22979	 1	 8.2	 5.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22980	 1	 12.82	 7.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22981	 1	 6.79	 4.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22982	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22983	 1	 4.13	 2.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22984	 1	 2.03	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22985	 1	 2.05	 1.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22986	 1	 1.61	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22987	 1	 10.57	 5.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22988	 1	 3.48	 2.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22989	 1	 2.63	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22990	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22991	 1	 1.6	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22992	 1	 0.13	 0.07	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22993	 1	 1.28	 0.79	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22994	 1	 2.54	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22995	 1	 3.18	 2.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22996	 1	 3.83	 2.62	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22997	 1	 2.56	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22998	 1	 1.89	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22999	 1	 1.45	 0.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23000	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23001	 1	 3.25	 2.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23002	 1	 5.68	 3.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23003	 1	 2.55	 1.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23004	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23005	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23006	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23007	 1	 3.26	 2.24	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23008	 1	 0.63	 0.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23009	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23010	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23011	 1	 3.18	 2.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23012	 1	 3.69	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23013	 1	 2.7	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23014	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23015	 1	 3.37	 2.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23016	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23017	 1	 3.99	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23018	 1	 3.8	 2.61	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23019	 1	 2.13	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23020	 1	 1.7	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23021	 1	 1.55	 0.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23022	 1	 3.08	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23023	 1	 2.01	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23024	 1	 1.77	 0.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23025	 1	 6.69	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23026	 1	 7.18	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23027	 1	 3.54	 0.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23028	 1	 4.58	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23029	 1	 3.13	 1.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23030	 1	 2.71	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23031	 1	 2.05	 0.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23032	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23033	 1	 2.77	 0.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23034	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23035	 1	 4.53	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23036	 1	 6.77	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23037	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23038	 1	 4.46	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23039	 1	 5.67	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23040	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23041	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23042	 1	 16.81	 3.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23043	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23044	 1	 6.7	 4.13	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23045	 1	 8.52	 4.23	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23046	 1	 14.12	 3.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23047	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23048	 1	 4.93	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23049	 1	 8.56	 1.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23050	 1	 1.23	 0.87	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23051	 1	 2.71	 0.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23052	 1	 1.07	 0.76	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23053	 1	 1.02	 0.67	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23054	 1	 2.88	 0.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23055	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23056	 1	 1.12	 0.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23057	 1	 2.23	 0.51	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23058	 1	 2.14	 0.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23059	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23060	 1	 2.42	 0.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23061	 1	 2.81	 0.64	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23062	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23063	 1	 2.35	 0.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23064	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23065	 1	 2.28	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23066	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23067	 1	 3.65	 1.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23068	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23069	 1	 5.13	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23070	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23071	 1	 8.31	 1.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23072	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23073	 1	 1.19	 0.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23074	 1	 2.12	 0.49	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23075	 1	 1.76	 0.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23076	 1	 2.02	 0.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23077	 1	 2.01	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23078	 1	 0.89	 0.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23079	 1	 1.43	 0.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23080	 1	 2.74	 0.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23081	 1	 2.76	 0.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23082	 1	 0.81	 0.18	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23083	 1	 2.66	 0.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23084	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23085	 1	 1.19	 0.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23086	 1	 1.57	 0.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23087	 1	 3.4	 0.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23088	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23089	 1	 6.56	 1.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23090	 1	 4.37	 0.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23091	 1	 7.44	 1.7	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23092	 1	 1.41	 0.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23093	 1	 6.92	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23094	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23095	 1	 1.74	 0.4	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23096	 1	 1.87	 0.43	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23097	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23098	 1	 1.2	 0.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23099	 1	 2.02	 0.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23100	 1	 0.83	 0.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23101	 1	 1.71	 0.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23102	 1	 6.11	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23103	 1	 1.82	 0.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23104	 1	 1.61	 0.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23105	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23106	 1	 3.91	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23107	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23108	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23109	 1	 4.26	 0.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23110	 1	 1.12	 0.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23111	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23112	 1	 1.47	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23113	 1	 1.74	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23114	 1	 6.5	 3.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23115	 1	 1.67	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23116	 1	 2.48	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23117	 1	 3.15	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23118	 1	 9.66	 4.7	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23119	 1	 4.28	 2.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23120	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23121	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23122	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23123	 1	 2.24	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23124	 1	 11.18	 6.23	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23125	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23126	 1	 3.95	 2.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23127	 1	 4.91	 2.85	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23128	 1	 3.55	 2.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23129	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23130	 1	 9.64	 5.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23131	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23132	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23133	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23134	 1	 3.01	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23135	 1	 1.87	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23136	 1	 4.06	 2.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23137	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23138	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23139	 1	 2.8	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23140	 1	 1.68	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23141	 1	 6.81	 5.07	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23142	 1	 0.82	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23143	 1	 6.64	 4.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23144	 1	 10.59	 5.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23145	 1	 9.69	 5.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23146	 1	 4.83	 3.23	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23147	 1	 5.78	 3.92	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23148	 1	 2.42	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23149	 1	 2.44	 1.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23150	 1	 2.77	 1.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23151	 1	 4.67	 2.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23152	 1	 3.11	 1.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23153	 1	 6.65	 3.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23154	 1	 3.28	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23155	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23156	 1	 3.12	 2.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23157	 1	 4.14	 2.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23158	 1	 2.8	 1.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23159	 1	 1.76	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23160	 1	 8.92	 5.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23161	 1	 4.44	 2.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23162	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23163	 1	 9.06	 4.87	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23164	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23165	 1	 3.22	 2.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23166	 1	 4.86	 3.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23167	 1	 3.52	 2.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23168	 1	 2.29	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23169	 1	 4.41	 2.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23170	 1	 2.53	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23171	 1	 3.26	 2.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23172	 1	 1.88	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23173	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23174	 1	 4.68	 2.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23175	 1	 4.51	 3.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23176	 1	 2.44	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23177	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23178	 1	 4.48	 2.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23179	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23180	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23181	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23182	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23183	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23184	 1	 2.37	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23185	 1	 3.53	 2.17	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23186	 1	 2.27	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23187	 1	 3.94	 2.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23188	 1	 1.13	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23189	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23190	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23191	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23192	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23193	 1	 2.33	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23194	 1	 2.78	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23195	 1	 17.67	 7.35	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23196	 1	 2.62	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23197	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23198	 1	 1.67	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23199	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23200	 1	 2.7	 2.03	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23201	 1	 2.73	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23202	 1	 1.99	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23203	 1	 5.26	 3.22	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23204	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23205	 1	 2.77	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23206	 1	 3.23	 2.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23207	 1	 2.76	 1.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23208	 1	 2.58	 1.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23209	 1	 2.94	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23210	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23211	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23212	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23213	 1	 3.06	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23214	 1	 4.74	 2.8	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23215	 1	 2.94	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23216	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23217	 1	 0.87	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23218	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23219	 1	 4.63	 2.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23220	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23221	 1	 8.04	 4.18	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23222	 1	 1.87	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23223	 1	 7.2	 3.62	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23224	 1	 3.98	 2.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23225	 1	 6.01	 3.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23226	 1	 1.5	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23227	 1	 2.16	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23228	 1	 1.09	 0.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23229	 1	 2.18	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23230	 1	 1.04	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23231	 1	 1.49	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23232	 1	 1.6	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23233	 1	 4.9	 2.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23234	 1	 1.14	 0.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23235	 1	 1.25	 0.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23236	 1	 1.26	 0.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23237	 1	 1.88	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23238	 1	 1.91	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23239	 1	 1.64	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23240	 1	 1.66	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23241	 1	 1.39	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23242	 1	 2.4	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23243	 1	 1.68	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23244	 1	 2.11	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23245	 1	 1.58	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23246	 1	 3.18	 2.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23247	 1	 6.48	 3.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23248	 1	 3.55	 2.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23249	 1	 2.28	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23250	 1	 1.95	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23251	 1	 1.13	 0.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23252	 1	 1.55	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23253	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23254	 1	 3.51	 2.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23255	 1	 3.69	 2.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23256	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23257	 1	 6.08	 3.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23258	 1	 3.77	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23259	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23260	 1	 4.89	 3.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23261	 1	 16.12	 8.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23262	 1	 6.54	 2.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23263	 1	 1.84	 1.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23264	 1	 2.21	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23265	 1	 4.13	 2.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23266	 1	 0.8	 0.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23267	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23268	 1	 1.18	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23269	 1	 1.31	 0.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23270	 1	 1.75	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23271	 1	 0.62	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23272	 1	 0.67	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23273	 1	 5.13	 3.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23274	 1	 1.15	 0.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23275	 1	 0.77	 0.56	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23276	 1	 1.84	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23277	 1	 5.38	 3.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23278	 1	 2.82	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23279	 1	 1.74	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23280	 1	 4.69	 2.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23281	 1	 1.38	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23282	 1	 5.1	 3.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23283	 1	 2.51	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23284	 1	 2.55	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23285	 1	 1.88	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23286	 1	 1.58	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23287	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23288	 1	 1.81	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23289	 1	 1.22	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23290	 1	 4.02	 2.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23291	 1	 2.32	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23292	 1	 2.92	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23293	 1	 3.56	 1.91	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23294	 1	 3.92	 2.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23295	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23296	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23297	 1	 1.62	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23298	 1	 1.97	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23299	 1	 1.18	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23300	 1	 1.89	 1.45	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23301	 1	 1.12	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23302	 1	 1.44	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23303	 1	 1.45	 1.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23304	 1	 2.0	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23305	 1	 2.87	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23306	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23307	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23308	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23309	 1	 9.76	 5.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23310	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23311	 1	 1.59	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23312	 1	 3.34	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23313	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23314	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23315	 1	 14.24	 4.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23316	 1	 5.15	 2.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23317	 1	 4.08	 2.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23318	 1	 4.85	 3.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23319	 1	 4.21	 2.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23320	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23321	 1	 3.02	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23322	 1	 12.18	 3.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23323	 1	 3.44	 2.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23324	 1	 4.63	 2.53	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23325	 1	 3.41	 2.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23326	 1	 7.28	 4.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23327	 1	 3.99	 2.37	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23328	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23329	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23330	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	23331	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23332	 1	 17.83	 8.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23333	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23334	 1	 4.89	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23335	 1	 2.28	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23336	 1	 1.85	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23337	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23338	 1	 3.98	 2.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23339	 1	 1.25	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23340	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23341	 1	 2.45	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23342	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23343	 1	 1.75	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23344	 1	 1.34	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23345	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23346	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23347	 1	 1.52	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23348	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23349	 1	 3.37	 2.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23350	 1	 1.47	 0.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23351	 1	 4.7	 2.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23352	 1	 5.8	 3.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23353	 1	 4.98	 2.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23354	 1	 1.53	 1.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23355	 1	 1.33	 0.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23356	 1	 3.25	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23357	 1	 2.18	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23358	 1	 5.81	 3.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23359	 1	 2.39	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23360	 1	 2.8	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23361	 1	 1.62	 1.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23362	 1	 6.37	 3.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23363	 1	 2.09	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23364	 1	 1.32	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23365	 1	 4.7	 3.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23366	 1	 9.24	 6.26	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23367	 1	 1.55	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23368	 1	 5.44	 3.35	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23369	 1	 1.78	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23370	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23371	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23372	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23373	 1	 2.12	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23374	 1	 2.44	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23375	 1	 1.49	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23376	 1	 2.67	 1.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23377	 1	 1.4	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23378	 1	 5.65	 3.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23379	 1	 11.22	 4.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23380	 1	 3.64	 2.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23381	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23382	 1	 6.01	 3.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23383	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23384	 1	 4.77	 3.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23385	 1	 2.15	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23386	 1	 2.67	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23387	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23388	 1	 1.88	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23389	 1	 1.78	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23390	 1	 9.51	 4.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23391	 1	 7.44	 3.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23392	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23393	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23394	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23395	 1	 2.14	 1.71	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23396	 1	 2.76	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23397	 1	 1.92	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23398	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	23399	 1	 2.9	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23400	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23401	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23402	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23403	 1	 2.27	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23404	 1	 12.23	 8.15	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23405	 1	 3.02	 2.17	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23406	 1	 2.53	 1.86	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23407	 1	 2.25	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23408	 1	 2.51	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23409	 1	 1.47	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23410	 1	 4.46	 3.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23411	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23412	 1	 5.38	 3.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23413	 1	 3.58	 2.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23414	 1	 5.04	 3.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23415	 1	 3.73	 2.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23416	 1	 4.37	 2.79	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23417	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23418	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23419	 1	 3.24	 1.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23420	 1	 1.89	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23421	 1	 4.47	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23422	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23423	 1	 14.85	 3.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23424	 1	 1.35	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23425	 1	 3.82	 2.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23426	 1	 3.59	 2.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23427	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23428	 1	 7.67	 4.26	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23429	 1	 8.93	 5.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23430	 1	 3.62	 2.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23431	 1	 4.85	 3.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23432	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23433	 1	 13.8	 5.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23434	 1	 1.44	 0.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23435	 1	 2.87	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23436	 1	 2.87	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23437	 1	 1.86	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23438	 1	 2.33	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23439	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23440	 1	 4.55	 2.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23441	 1	 1.62	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23442	 1	 1.19	 0.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23443	 1	 3.7	 2.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23444	 1	 3.43	 0.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23445	 1	 9.2	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23446	 1	 2.93	 2.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23447	 1	 4.4	 2.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23448	 1	 4.3	 2.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23449	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23450	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23451	 1	 1.97	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23452	 1	 6.05	 3.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23453	 1	 2.22	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23454	 1	 2.44	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23455	 1	 6.41	 3.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23456	 1	 3.66	 2.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23457	 1	 3.13	 1.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23458	 1	 8.95	 4.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23459	 1	 8.5	 4.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23460	 1	 3.58	 2.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23461	 1	 5.08	 3.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23462	 1	 2.2	 1.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23463	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23464	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23465	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23466	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23467	 1	 5.02	 3.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23468	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23469	 1	 1.71	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23470	 1	 2.12	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23471	 1	 2.09	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23472	 1	 2.71	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23473	 1	 3.92	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23474	 1	 2.9	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23475	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23476	 1	 2.75	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23477	 1	 6.76	 3.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23478	 1	 10.42	 5.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23479	 1	 2.16	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23480	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23481	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23482	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23483	 1	 2.78	 2.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23484	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23485	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23486	 1	 3.6	 2.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23487	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23488	 1	 8.44	 4.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23489	 1	 6.11	 3.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23490	 1	 3.29	 2.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23491	 1	 5.57	 3.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23492	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23493	 1	 12.15	 4.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23494	 1	 5.55	 3.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23495	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23496	 1	 6.98	 3.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23497	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23498	 1	 5.49	 4.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23499	 1	 6.69	 4.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23500	 1	 9.74	 5.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23501	 1	 6.3	 3.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23502	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23503	 1	 4.01	 2.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23504	 1	 4.72	 3.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23505	 1	 4.49	 2.53	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23506	 1	 2.15	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23507	 1	 3.95	 3.08	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23508	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23509	 1	 12.41	 6.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23510	 1	 0.85	 0.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23511	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23512	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23513	 1	 15.05	 8.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23514	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23515	 1	 2.39	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23516	 1	 2.97	 1.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23517	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23518	 1	 2.04	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23519	 1	 6.51	 3.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23520	 1	 2.3	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23521	 1	 5.18	 3.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23522	 1	 2.63	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23523	 1	 3.49	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23524	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23525	 1	 2.11	 1.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23526	 1	 2.8	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23527	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23528	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23529	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23530	 1	 3.08	 1.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23531	 1	 2.12	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23532	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23533	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23534	 1	 2.25	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23535	 1	 1.69	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23536	 1	 2.59	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23537	 1	 5.85	 2.6	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23538	 1	 3.51	 2.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23539	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23540	 1	 1.53	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23541	 1	 1.75	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23542	 1	 1.43	 0.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23543	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23544	 1	 3.01	 1.89	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23545	 1	 1.64	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23546	 1	 3.06	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23547	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23548	 1	 2.42	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23549	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23550	 1	 1.14	 0.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23551	 1	 4.06	 2.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23552	 1	 2.17	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23553	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23554	 1	 1.84	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23555	 1	 1.69	 0.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23556	 1	 1.55	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23557	 1	 2.98	 2.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23558	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23559	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23560	 1	 1.95	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23561	 1	 0.97	 0.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23562	 1	 2.22	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23563	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23564	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23565	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23566	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23567	 1	 2.32	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23568	 1	 2.14	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23569	 1	 3.62	 2.21	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23570	 1	 2.35	 1.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23571	 1	 1.64	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23572	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23573	 1	 2.81	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23574	 1	 7.49	 4.56	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23575	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23576	 1	 1.83	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23577	 1	 1.15	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23578	 1	 3.42	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23579	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23580	 1	 2.24	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23581	 1	 9.87	 2.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23582	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23583	 1	 6.08	 2.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23584	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23585	 1	 1.87	 0.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23586	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23587	 1	 2.9	 1.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23588	 1	 3.17	 1.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23589	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23590	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23591	 1	 1.8	 0.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23592	 1	 11.62	 5.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23593	 1	 5.91	 3.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23594	 1	 3.4	 2.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23595	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23596	 1	 4.31	 2.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23597	 1	 4.56	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23598	 1	 2.23	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23599	 1	 5.92	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23600	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23601	 1	 2.64	 0.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23602	 1	 8.16	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23603	 1	 2.29	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23604	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23605	 1	 4.21	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23606	 1	 2.59	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23607	 1	 8.79	 2.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23608	 1	 3.18	 0.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23609	 1	 2.38	 0.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23610	 1	 1.82	 0.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23611	 1	 3.08	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23612	 1	 2.27	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23613	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23614	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23615	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23616	 1	 6.49	 1.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23617	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23618	 1	 1.69	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23619	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23620	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23621	 1	 3.58	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23622	 1	 4.17	 2.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23623	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23624	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23625	 1	 10.14	 6.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23626	 1	 2.68	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23627	 1	 1.89	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23628	 1	 3.76	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23629	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23630	 1	 5.3	 3.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23631	 1	 3.49	 2.44	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23632	 1	 4.07	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23633	 1	 1.29	 0.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23634	 1	 0.85	 0.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23635	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23636	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23637	 1	 4.36	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23638	 1	 0.97	 0.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23639	 1	 3.01	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23640	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23641	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23642	 1	 10.73	 6.7	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23643	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23644	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23645	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23646	 1	 4.48	 2.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23647	 1	 1.85	 0.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23648	 1	 3.53	 0.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23649	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23650	 1	 5.42	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23651	 1	 1.13	 0.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23652	 1	 1.8	 0.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23653	 1	 2.88	 0.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23654	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23655	 1	 2.1	 0.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23656	 1	 2.49	 0.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23657	 1	 3.16	 0.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23658	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23659	 1	 3.47	 0.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23660	 1	 2.49	 1.89	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23661	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23662	 1	 1.19	 0.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23663	 1	 3.67	 2.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23664	 1	 1.6	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23665	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23666	 1	 1.47	 0.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23667	 1	 2.03	 0.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23668	 1	 3.66	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23669	 1	 2.71	 0.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23670	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23671	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23672	 1	 2.31	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23673	 1	 1.55	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23674	 1	 8.31	 4.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23675	 1	 1.04	 0.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23676	 1	 2.42	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23677	 1	 2.0	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23678	 1	 2.46	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23679	 1	 1.75	 0.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23680	 1	 2.3	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23681	 1	 1.96	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23682	 1	 2.48	 0.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23683	 1	 1.83	 0.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23684	 1	 1.54	 0.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23685	 1	 2.44	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23686	 1	 3.44	 2.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23687	 1	 1.87	 0.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23688	 1	 1.68	 0.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23689	 1	 2.75	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23690	 1	 2.06	 0.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23691	 1	 1.92	 0.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23692	 1	 0.95	 0.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23693	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23694	 1	 2.29	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23695	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23696	 1	 1.89	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23697	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23698	 1	 1.34	 0.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23699	 1	 6.18	 3.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23700	 1	 2.25	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23701	 1	 1.9	 0.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23702	 1	 2.18	 1.49	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23703	 1	 1.76	 1.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23704	 1	 3.71	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23705	 1	 2.06	 0.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23706	 1	 5.6	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23707	 1	 2.78	 0.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23708	 1	 3.49	 2.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23709	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23710	 1	 0.94	 0.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23711	 1	 4.84	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23712	 1	 5.36	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23713	 1	 3.44	 0.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23714	 1	 2.48	 0.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23715	 1	 3.11	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23716	 1	 2.25	 0.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23717	 1	 2.27	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23718	 1	 2.54	 0.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23719	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23720	 1	 5.53	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23721	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23722	 1	 2.27	 1.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23723	 1	 2.56	 0.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23724	 1	 2.1	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23725	 1	 5.11	 2.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23726	 1	 4.54	 2.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23727	 1	 2.36	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23728	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23729	 1	 3.46	 0.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23730	 1	 4.38	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23731	 1	 3.96	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23732	 1	 4.9	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23733	 1	 3.02	 0.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23734	 1	 1.5	 0.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23735	 1	 1.65	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23736	 1	 2.78	 0.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23737	 1	 3.55	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23738	 1	 2.23	 0.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23739	 1	 1.89	 0.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23740	 1	 2.19	 0.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23741	 1	 8.79	 2.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23742	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23743	 1	 5.69	 3.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23744	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23745	 1	 2.39	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23746	 1	 1.2	 0.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23747	 1	 1.28	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23748	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23749	 1	 1.25	 0.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23750	 1	 3.57	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23751	 1	 12.76	 7.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23752	 1	 1.71	 0.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23753	 1	 2.53	 0.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23754	 1	 1.73	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23755	 1	 1.47	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23756	 1	 2.25	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23757	 1	 2.41	 0.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23758	 1	 2.52	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23759	 1	 5.84	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23760	 1	 1.72	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23761	 1	 1.26	 0.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23762	 1	 1.76	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23763	 1	 4.37	 2.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23764	 1	 4.12	 2.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23765	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23766	 1	 0.93	 0.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23767	 1	 3.1	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23768	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23769	 1	 1.69	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23770	 1	 1.95	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23771	 1	 4.71	 2.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23772	 1	 4.58	 2.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23773	 1	 2.99	 1.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23774	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23775	 1	 2.62	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23776	 1	 5.46	 3.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23777	 1	 5.68	 2.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23778	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23779	 1	 5.31	 2.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23780	 1	 2.66	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23781	 1	 3.18	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23782	 1	 2.43	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23783	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23784	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23785	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23786	 1	 4.72	 2.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23787	 1	 2.41	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23788	 1	 7.26	 3.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23789	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23790	 1	 7.23	 4.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23791	 1	 2.35	 1.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23792	 1	 1.45	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23793	 1	 6.0	 2.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23794	 1	 2.23	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23795	 1	 8.08	 3.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23796	 1	 3.19	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23797	 1	 2.83	 2.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23798	 1	 3.23	 1.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23799	 1	 2.95	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23800	 1	 1.89	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23801	 1	 2.79	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23802	 1	 2.81	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23803	 1	 1.39	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23804	 1	 2.44	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23805	 1	 3.68	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23806	 1	 3.84	 2.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23807	 1	 0.73	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23808	 1	 1.86	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23809	 1	 2.09	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23810	 1	 1.84	 0.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23811	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23812	 1	 1.86	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23813	 1	 1.44	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23814	 1	 2.76	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23815	 1	 1.43	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23816	 1	 1.27	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23817	 1	 1.91	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23818	 1	 17.23	 6.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23819	 1	 1.93	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23820	 1	 6.68	 3.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23821	 1	 2.74	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23822	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23823	 1	 1.48	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23824	 1	 1.97	 1.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23825	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23826	 1	 1.49	 1.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23827	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23828	 1	 3.5	 1.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23829	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23830	 1	 1.75	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23831	 1	 1.82	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23832	 1	 2.84	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23833	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23834	 1	 2.38	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23835	 1	 7.23	 4.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23836	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23837	 1	 2.88	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23838	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23839	 1	 5.27	 3.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23840	 1	 2.94	 2.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23841	 1	 3.27	 2.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23842	 1	 3.05	 2.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23843	 1	 2.42	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23844	 1	 1.78	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23845	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23846	 1	 1.0	 0.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23847	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23848	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23849	 1	 3.65	 1.91	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23850	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23851	 1	 1.99	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23852	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23853	 1	 2.98	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23854	 1	 39.54	 15.98	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23855	 1	 3.04	 2.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23856	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23857	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23858	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23859	 1	 1.92	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23860	 1	 2.12	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23861	 1	 9.0	 4.06	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23862	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23863	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23864	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23865	 1	 3.63	 2.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23866	 1	 3.85	 2.34	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23867	 1	 1.5	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23868	 1	 1.42	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23869	 1	 3.21	 2.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23870	 1	 3.47	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23871	 1	 1.25	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23872	 1	 1.89	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23873	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23874	 1	 2.8	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23875	 1	 2.64	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23876	 1	 1.97	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23877	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23878	 1	 3.46	 2.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23879	 1	 3.22	 2.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23880	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23881	 1	 5.35	 3.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23882	 1	 6.29	 3.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23883	 1	 3.05	 2.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23884	 1	 12.42	 7.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23885	 1	 1.11	 0.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23886	 1	 5.87	 2.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23887	 1	 3.2	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23888	 1	 2.06	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23889	 1	 1.84	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23890	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23891	 1	 8.4	 4.25	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23892	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23893	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23894	 1	 6.78	 3.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23895	 1	 3.06	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23896	 1	 7.26	 5.03	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23897	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23898	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23899	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23900	 1	 2.64	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23901	 1	 8.52	 3.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23902	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23903	 1	 11.92	 5.15	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23904	 1	 12.08	 5.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23905	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23906	 1	 2.57	 2.05	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23907	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23908	 1	 1.7	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23909	 1	 2.63	 2.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23910	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23911	 1	 4.63	 2.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23912	 1	 4.58	 3.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23913	 1	 3.43	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23914	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23915	 1	 1.88	 1.56	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23916	 1	 3.81	 2.52	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23917	 1	 2.02	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23918	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23919	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23920	 1	 2.42	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23921	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23922	 1	 9.73	 4.64	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23923	 1	 4.54	 3.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23924	 1	 0.66	 0.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23925	 1	 2.59	 2.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23926	 1	 1.94	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23927	 1	 0.68	 0.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23928	 1	 2.78	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23929	 1	 6.41	 4.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23930	 1	 13.06	 5.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23931	 1	 0.93	 0.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23932	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23933	 1	 3.75	 2.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23934	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23935	 1	 24.17	 14.3	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23936	 1	 7.96	 5.27	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23937	 1	 1.98	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23938	 1	 1.44	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23939	 1	 1.94	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23940	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23941	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23942	 1	 2.15	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23943	 1	 12.35	 8.04	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23944	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23945	 1	 4.44	 2.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23946	 1	 1.71	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23947	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23948	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23949	 1	 1.13	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23950	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23951	 1	 1.38	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23952	 1	 6.95	 4.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23953	 1	 1.91	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23954	 1	 1.13	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23955	 1	 1.32	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23956	 1	 0.93	 0.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23957	 1	 6.37	 3.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23958	 1	 1.16	 0.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23959	 1	 0.76	 0.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23960	 1	 1.08	 0.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23961	 1	 3.03	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23962	 1	 4.39	 2.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23963	 1	 2.01	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23964	 1	 2.91	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23965	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23966	 1	 0.92	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23967	 1	 2.43	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23968	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23969	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23970	 1	 1.44	 0.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23971	 1	 7.42	 3.55	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23972	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23973	 1	 3.69	 2.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23974	 1	 2.8	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23975	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23976	 1	 1.14	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23977	 1	 1.57	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23978	 1	 2.66	 2.08	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23979	 1	 2.76	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23980	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23981	 1	 1.08	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23982	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23983	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23984	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23985	 1	 9.99	 5.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23986	 1	 4.18	 3.26	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23987	 1	 1.68	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23988	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23989	 1	 2.37	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23990	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23991	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23992	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23993	 1	 6.25	 3.64	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23994	 1	 1.23	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23995	 1	 11.39	 5.37	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23996	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23997	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23998	 1	 3.8	 2.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23999	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24000	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24001	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24002	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24003	 1	 1.79	 1.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24004	 1	 1.42	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24005	 1	 3.76	 2.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24006	 1	 1.28	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24007	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24008	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24009	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24010	 1	 3.58	 2.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24011	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24012	 1	 1.68	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24013	 1	 1.64	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24014	 1	 1.02	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24015	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24016	 1	 2.87	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24017	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24018	 1	 2.86	 1.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24019	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24020	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24021	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24022	 1	 3.12	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24023	 1	 2.97	 2.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24024	 1	 4.61	 2.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24025	 1	 6.1	 3.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24026	 1	 2.67	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24027	 1	 13.98	 4.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24028	 1	 1.49	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24029	 1	 8.24	 4.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24030	 1	 2.7	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24031	 1	 2.14	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24032	 1	 3.09	 2.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24033	 1	 1.1	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24034	 1	 4.43	 2.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24035	 1	 2.29	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24036	 1	 1.26	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24037	 1	 1.95	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24038	 1	 7.89	 4.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24039	 1	 6.0	 3.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24040	 1	 3.67	 2.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24041	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24042	 1	 3.96	 2.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24043	 1	 5.28	 3.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24044	 1	 45.16	 20.27	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24045	 1	 3.57	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24046	 1	 1.87	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24047	 1	 4.63	 2.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24048	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24049	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24050	 1	 4.55	 3.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24051	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24052	 1	 2.63	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24053	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24054	 1	 1.62	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24055	 1	 1.58	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24056	 1	 4.36	 2.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24057	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24058	 1	 0.63	 0.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24059	 1	 3.3	 1.78	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24060	 1	 1.09	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24061	 1	 6.6	 4.67	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24062	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24063	 1	 1.96	 1.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24064	 1	 3.55	 2.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24065	 1	 1.78	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24066	 1	 1.63	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24067	 1	 5.67	 3.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24068	 1	 1.17	 0.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24069	 1	 2.61	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24070	 1	 7.96	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24071	 1	 7.49	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24072	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24073	 1	 3.45	 0.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24074	 1	 2.53	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24075	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24076	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24077	 1	 2.9	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24078	 1	 3.32	 0.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24079	 1	 6.59	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24080	 1	 10.8	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24081	 1	 9.09	 2.01	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24082	 4	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24083	 1	 8.96	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24084	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24085	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24086	 1	 5.62	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24087	 1	 1.08	 0.81	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24088	 1	 6.47	 2.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24089	 1	 2.03	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24090	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24091	 1	 2.19	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24092	 1	 2.19	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24093	 1	 1.28	 0.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24094	 1	 12.38	 7.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24095	 1	 13.34	 8.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24096	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24097	 1	 5.16	 2.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24098	 1	 5.49	 2.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24099	 1	 5.38	 2.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24100	 1	 3.08	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24101	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24102	 1	 14.71	 9.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24103	 1	 1.96	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24104	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24105	 1	 4.9	 2.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24106	 1	 1.76	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24107	 1	 8.1	 3.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24108	 1	 1.4	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24109	 1	 4.72	 2.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24110	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24111	 1	 2.75	 1.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24112	 1	 3.43	 2.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24113	 1	 2.33	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24114	 1	 4.44	 3.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24115	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24116	 1	 5.72	 3.61	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24117	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24118	 1	 4.15	 2.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24119	 1	 6.14	 3.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24120	 1	 2.08	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24121	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24122	 1	 1.92	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24123	 1	 3.47	 2.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24124	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24125	 1	 10.03	 4.48	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24126	 1	 2.18	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24127	 1	 18.92	 7.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24128	 1	 5.2	 3.37	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24129	 1	 1.79	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24130	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24131	 1	 2.63	 2.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24132	 1	 6.43	 3.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24133	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24134	 1	 1.66	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24135	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24136	 1	 4.98	 2.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24137	 1	 1.8	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24138	 1	 6.45	 3.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24139	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24140	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24141	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24142	 1	 3.18	 2.13	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24143	 1	 10.51	 6.66	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24144	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24145	 1	 6.26	 3.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24146	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24147	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24148	 1	 5.22	 3.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24149	 1	 2.88	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24150	 1	 1.35	 0.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24151	 1	 3.47	 2.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24152	 1	 11.79	 2.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24153	 1	 2.6	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24154	 1	 1.37	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24155	 1	 2.38	 1.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24156	 1	 2.1	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24157	 1	 3.91	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24158	 1	 1.47	 0.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24159	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24160	 1	 3.92	 2.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24161	 1	 0.69	 0.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24162	 1	 4.14	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24163	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24164	 1	 1.62	 0.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24165	 1	 4.02	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24166	 1	 3.57	 2.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24167	 1	 1.46	 0.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24168	 1	 2.54	 0.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24169	 1	 1.67	 0.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24170	 1	 1.17	 0.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24171	 1	 1.11	 0.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24172	 1	 7.86	 1.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24173	 1	 7.64	 1.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24174	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24175	 1	 2.66	 0.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24176	 1	 4.41	 3.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24177	 1	 2.97	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24178	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24179	 1	 10.36	 2.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24180	 1	 7.16	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24181	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24182	 1	 2.68	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24183	 1	 1.32	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24184	 1	 2.11	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24185	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24186	 1	 2.98	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24187	 1	 3.28	 2.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24188	 1	 2.41	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24189	 1	 1.52	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24190	 1	 2.82	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24191	 1	 9.16	 4.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24192	 1	 0.76	 0.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24193	 1	 2.11	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24194	 1	 2.23	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24195	 1	 2.0	 1.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24196	 1	 1.01	 0.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24197	 1	 6.55	 3.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24198	 1	 8.29	 5.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24199	 1	 2.33	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24200	 1	 1.3	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24201	 1	 1.12	 0.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24202	 1	 3.19	 1.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24203	 1	 2.88	 2.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24204	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24205	 1	 1.97	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24206	 1	 2.36	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24207	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24208	 1	 1.98	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24209	 1	 2.58	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24210	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24211	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24212	 1	 3.66	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24213	 1	 2.19	 0.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24214	 1	 1.63	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24215	 1	 10.6	 2.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24216	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24217	 1	 1.57	 0.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24218	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24219	 1	 2.33	 0.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24220	 1	 2.28	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24221	 1	 2.21	 0.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24222	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24223	 1	 0.79	 0.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24224	 1	 6.57	 1.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24225	 1	 1.13	 0.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24226	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24227	 1	 3.4	 0.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24228	 1	 2.53	 0.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24229	 1	 3.7	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24230	 1	 7.2	 4.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24231	 1	 8.01	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24232	 1	 3.44	 0.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24233	 1	 2.11	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24234	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24235	 1	 4.12	 2.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24236	 1	 6.25	 3.45	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24237	 1	 6.14	 3.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24238	 1	 4.58	 1.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24239	 1	 17.95	 4.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24240	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24241	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24242	 1	 5.2	 1.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24243	 1	 6.64	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24244	 1	 11.29	 2.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24245	 1	 1.16	 0.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24246	 1	 13.94	 7.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24247	 1	 1.91	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24248	 1	 2.2	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24249	 1	 3.59	 2.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24250	 1	 0.87	 0.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24251	 1	 1.32	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24252	 1	 3.01	 2.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24253	 1	 2.72	 1.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24254	 1	 1.23	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24255	 1	 2.43	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24256	 1	 1.68	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24257	 1	 2.31	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24258	 1	 1.34	 0.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24259	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24260	 1	 2.71	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24261	 1	 2.46	 1.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24262	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24263	 1	 2.86	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24264	 1	 2.75	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24265	 1	 1.61	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24266	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24267	 1	 2.27	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24268	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24269	 1	 2.42	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24270	 1	 1.21	 0.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24271	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24272	 1	 1.12	 0.8	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24273	 1	 1.51	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24274	 1	 0.66	 0.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24275	 1	 1.68	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24276	 1	 1.59	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24277	 1	 1.71	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24278	 1	 1.4	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24279	 1	 3.49	 2.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24280	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24281	 1	 2.07	 1.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24282	 1	 3.79	 2.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24283	 1	 5.95	 2.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24284	 1	 2.0	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24285	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24286	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24287	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24288	 1	 4.72	 2.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24289	 1	 12.82	 6.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24290	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24291	 1	 1.39	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24292	 1	 3.12	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24293	 1	 4.68	 2.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24294	 1	 2.49	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24295	 1	 2.08	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24296	 1	 2.21	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24297	 1	 1.76	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24298	 1	 3.26	 2.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24299	 1	 1.63	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24300	 1	 2.43	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24301	 1	 1.75	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24302	 1	 3.94	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24303	 1	 1.75	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24304	 1	 2.28	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24305	 1	 3.09	 1.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24306	 1	 1.93	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24307	 1	 2.81	 1.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24308	 1	 3.01	 2.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24309	 1	 1.92	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24310	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24311	 1	 4.02	 2.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24312	 1	 2.05	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24313	 1	 2.7	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24314	 1	 3.3	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24315	 1	 1.69	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24316	 1	 1.1	 0.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24317	 1	 0.87	 0.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24318	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24319	 1	 2.03	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24320	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24321	 1	 1.21	 0.75	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24322	 1	 1.41	 0.95	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24323	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24324	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24325	 1	 1.38	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24326	 1	 2.32	 1.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24327	 1	 1.6	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24328	 1	 4.26	 2.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24329	 1	 0.63	 0.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24330	 1	 1.55	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24331	 1	 2.03	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24332	 1	 0.85	 0.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24333	 1	 1.0	 0.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24334	 1	 2.76	 2.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24335	 1	 2.02	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24336	 1	 2.78	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24337	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24338	 1	 0.73	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24339	 1	 2.02	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24340	 1	 5.26	 2.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24341	 1	 6.68	 3.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24342	 1	 2.03	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24343	 1	 1.97	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24344	 1	 2.42	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24345	 1	 1.14	 0.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24346	 1	 2.33	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24347	 1	 0.6	 0.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24348	 1	 10.34	 5.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24349	 1	 2.29	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24350	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24351	 1	 2.43	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24352	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24353	 1	 0.79	 0.47	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24354	 1	 0.56	 0.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24355	 1	 3.73	 2.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24356	 1	 2.44	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24357	 1	 4.77	 2.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24358	 1	 3.5	 2.2	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24359	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24360	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24361	 1	 9.8	 5.02	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24362	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24363	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24364	 1	 3.47	 1.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24365	 1	 2.53	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24366	 1	 0.93	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24367	 1	 4.95	 3.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24368	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24369	 1	 0.94	 0.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24370	 1	 0.42	 0.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24371	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24372	 1	 3.15	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24373	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24374	 1	 9.58	 5.34	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24375	 1	 2.74	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24376	 1	 1.86	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24377	 1	 1.72	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24378	 1	 2.55	 2.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24379	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24380	 1	 6.28	 3.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24381	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24382	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24383	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24384	 1	 4.95	 2.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24385	 1	 1.63	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24386	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24387	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24388	 1	 1.18	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24389	 1	 1.73	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24390	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24391	 1	 2.73	 2.17	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24392	 1	 2.09	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24393	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24394	 1	 2.49	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24395	 1	 1.66	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24396	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24397	 1	 2.27	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24398	 1	 1.83	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24399	 1	 0.92	 0.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24400	 1	 0.9	 0.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24401	 1	 5.47	 2.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24402	 1	 3.15	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24403	 1	 7.17	 3.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24404	 1	 1.4	 0.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24405	 1	 1.4	 0.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24406	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24407	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24408	 1	 1.49	 1.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24409	 1	 1.12	 0.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24410	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24411	 1	 0.86	 0.54	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24412	 1	 1.98	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24413	 1	 1.61	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24414	 1	 1.56	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24415	 1	 1.34	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24416	 1	 1.28	 0.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24417	 1	 1.4	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24418	 1	 0.56	 0.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24419	 1	 1.24	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24420	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24421	 1	 0.81	 0.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24422	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24423	 1	 1.33	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24424	 1	 1.12	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24425	 1	 0.92	 0.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24426	 1	 2.14	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24427	 1	 0.71	 0.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24428	 1	 1.34	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24429	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24430	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24431	 1	 1.31	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24432	 1	 5.81	 3.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24433	 1	 0.67	 0.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24434	 1	 1.08	 0.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24435	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24436	 1	 1.23	 0.84	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24437	 1	 1.48	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24438	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24439	 1	 1.91	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24440	 1	 6.55	 3.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24441	 1	 7.03	 4.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24442	 1	 6.86	 3.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24443	 1	 2.48	 1.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24444	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24445	 1	 1.05	 0.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24446	 1	 2.35	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24447	 1	 2.06	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24448	 1	 2.29	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24449	 1	 2.66	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24450	 1	 5.32	 2.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24451	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24452	 1	 1.04	 0.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24453	 1	 1.38	 0.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24454	 1	 2.54	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24455	 1	 2.78	 1.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24456	 1	 7.48	 3.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24457	 1	 5.95	 2.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24458	 1	 2.25	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24459	 1	 1.83	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24460	 1	 1.82	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24461	 1	 1.67	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24462	 1	 1.8	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24463	 1	 1.18	 0.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24464	 1	 1.1	 0.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24465	 1	 1.59	 0.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24466	 1	 2.26	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24467	 1	 2.96	 2.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24468	 1	 2.4	 1.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24469	 1	 2.76	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24470	 1	 1.4	 0.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24471	 1	 2.34	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24472	 1	 2.06	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24473	 1	 1.31	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24474	 1	 2.86	 2.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24475	 1	 2.15	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24476	 1	 1.93	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24477	 1	 3.78	 2.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24478	 1	 1.98	 1.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24479	 1	 1.49	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24480	 1	 1.59	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24481	 1	 2.32	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24482	 1	 2.6	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24483	 1	 2.04	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24484	 1	 2.11	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24485	 1	 2.37	 1.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24486	 1	 2.13	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24487	 1	 2.0	 1.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24488	 1	 2.39	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24489	 1	 2.13	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24490	 1	 1.74	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24491	 1	 1.98	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24492	 1	 2.5	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24493	 1	 2.33	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24494	 1	 2.06	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24495	 1	 1.98	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24496	 1	 1.49	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24497	 1	 2.31	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24498	 1	 1.93	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24499	 1	 2.8	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24500	 1	 1.55	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24501	 1	 1.1	 0.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24502	 1	 2.61	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24503	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24504	 1	 1.25	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24505	 1	 1.88	 1.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24506	 1	 2.36	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24507	 1	 1.58	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24508	 1	 2.67	 1.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24509	 1	 1.54	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24510	 1	 0.97	 0.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24511	 1	 1.0	 0.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24512	 1	 1.43	 0.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24513	 1	 0.87	 0.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24514	 1	 1.3	 0.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24515	 1	 1.22	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24516	 1	 1.19	 0.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24517	 1	 1.43	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24518	 1	 2.62	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24519	 1	 1.59	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24520	 1	 2.1	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24521	 1	 1.99	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24522	 1	 1.06	 0.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24523	 1	 2.92	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24524	 1	 2.66	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24525	 1	 1.44	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24526	 1	 2.99	 1.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24527	 1	 2.18	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24528	 1	 2.01	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24529	 1	 2.58	 1.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24530	 1	 1.4	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24531	 1	 6.75	 2.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24532	 1	 2.91	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24533	 1	 1.04	 0.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24534	 1	 1.23	 0.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24535	 1	 2.56	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24536	 1	 3.37	 1.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24537	 1	 1.9	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24538	 1	 2.4	 1.91	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24539	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24540	 1	 1.78	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24541	 1	 2.28	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24542	 1	 1.94	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24543	 1	 2.79	 1.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24544	 1	 3.58	 2.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24545	 1	 1.2	 0.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24546	 1	 1.69	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24547	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24548	 1	 2.84	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24549	 1	 2.74	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24550	 1	 3.65	 2.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24551	 1	 1.33	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24552	 1	 2.34	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24553	 1	 1.67	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24554	 1	 2.29	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24555	 1	 1.77	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24556	 1	 6.62	 3.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24557	 1	 1.97	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24558	 1	 2.21	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24559	 1	 4.3	 2.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24560	 1	 9.62	 5.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24561	 1	 3.03	 1.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24562	 1	 0.75	 0.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24563	 1	 5.34	 2.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24564	 1	 0.99	 0.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24565	 1	 1.43	 0.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24566	 1	 3.11	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24567	 1	 1.64	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24568	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24569	 1	 2.84	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24570	 1	 2.64	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24571	 1	 1.91	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24572	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24573	 1	 1.97	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24574	 1	 1.58	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24575	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24576	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24577	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24578	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24579	 1	 2.56	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24580	 1	 2.47	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24581	 1	 1.71	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24582	 1	 2.72	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24583	 1	 2.11	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24584	 1	 7.31	 4.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24585	 1	 2.57	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24586	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24587	 1	 1.78	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24588	 1	 1.3	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24589	 1	 1.18	 0.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24590	 1	 2.32	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24591	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24592	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24593	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24594	 1	 1.22	 0.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24595	 1	 1.64	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24596	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24597	 1	 2.58	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24598	 1	 1.97	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24599	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24600	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24601	 1	 1.91	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24602	 1	 3.08	 1.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24603	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	24604	 1	 3.25	 2.09	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24605	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24606	 1	 1.58	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24607	 1	 1.6	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24608	 1	 1.37	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24609	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24610	 1	 1.2	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24611	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24612	 1	 1.22	 0.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24613	 1	 4.37	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24614	 1	 4.68	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24615	 1	 2.93	 0.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24616	 1	 3.84	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24617	 1	 3.01	 2.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24618	 1	 8.86	 2.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24619	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24620	 1	 33.44	 14.53	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24621	 1	 3.53	 2.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24622	 1	 1.04	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24623	 1	 3.32	 2.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24624	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24625	 1	 3.36	 1.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24626	 1	 6.22	 4.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24627	 1	 5.38	 3.38	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24628	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24629	 1	 1.98	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24630	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24631	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24632	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24633	 1	 1.71	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24634	 1	 2.3	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24635	 1	 1.45	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24636	 1	 2.5	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24637	 1	 2.05	 1.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24638	 1	 2.44	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24639	 1	 2.86	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24640	 1	 1.82	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24641	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24642	 1	 2.2	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24643	 1	 2.22	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24644	 1	 2.29	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24645	 1	 4.24	 2.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24646	 1	 2.8	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24647	 1	 3.21	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24648	 1	 3.13	 1.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24649	 1	 4.9	 2.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24650	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24651	 1	 3.53	 2.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24652	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24653	 1	 2.9	 1.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24654	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24655	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24656	 1	 2.09	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24657	 1	 2.76	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24658	 1	 1.66	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24659	 1	 3.2	 2.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24660	 1	 2.43	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24661	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24662	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24663	 1	 8.56	 3.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24664	 1	 7.05	 3.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24665	 1	 1.98	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24666	 1	 3.24	 2.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24667	 1	 1.81	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24668	 1	 1.72	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24669	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24670	 1	 1.6	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24671	 1	 5.21	 3.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24672	 1	 2.33	 1.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24673	 1	 2.37	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24674	 1	 7.53	 4.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24675	 1	 2.3	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24676	 1	 2.88	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24677	 1	 2.92	 1.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24678	 1	 4.21	 2.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24679	 1	 2.42	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24680	 1	 2.66	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24681	 1	 1.24	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24682	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24683	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24684	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24685	 1	 1.83	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24686	 1	 1.69	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24687	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24688	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24689	 1	 1.47	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24690	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24691	 1	 5.67	 2.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24692	 1	 4.72	 2.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24693	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24694	 1	 1.41	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24695	 1	 1.47	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24696	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24697	 1	 1.51	 0.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24698	 1	 2.37	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24699	 1	 1.52	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24700	 1	 2.1	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24701	 1	 2.42	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24702	 1	 1.78	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24703	 1	 1.23	 0.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24704	 1	 3.9	 2.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24705	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24706	 1	 4.14	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24707	 1	 3.89	 2.28	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24708	 1	 4.11	 2.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24709	 1	 2.82	 1.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24710	 1	 3.41	 2.45	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24711	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24712	 1	 1.84	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24713	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24714	 1	 2.97	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24715	 1	 2.29	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24716	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24717	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24718	 1	 1.01	 0.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24719	 1	 3.44	 2.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24720	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24721	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24722	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24723	 1	 4.75	 2.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24724	 1	 6.4	 3.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24725	 1	 11.28	 7.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24726	 1	 3.6	 2.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24727	 1	 2.72	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24728	 1	 1.87	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24729	 1	 7.48	 4.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24730	 1	 2.94	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24731	 1	 2.47	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24732	 1	 2.5	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24733	 1	 2.37	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24734	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24735	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24736	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24737	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24738	 1	 9.44	 5.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24739	 1	 2.01	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24740	 1	 1.07	 0.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24741	 1	 2.54	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24742	 1	 2.37	 1.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24743	 1	 2.75	 1.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24744	 1	 2.09	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24745	 1	 3.42	 2.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24746	 1	 3.94	 2.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24747	 1	 5.39	 3.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24748	 1	 3.26	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24749	 1	 3.24	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24750	 1	 1.85	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24751	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24752	 1	 1.05	 0.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24753	 1	 3.87	 2.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24754	 1	 2.06	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24755	 1	 1.42	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24756	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24757	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24758	 1	 4.69	 2.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24759	 1	 4.93	 2.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24760	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24761	 1	 9.07	 4.76	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24762	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24763	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24764	 1	 4.11	 2.57	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24765	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24766	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24767	 1	 2.31	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24768	 1	 1.4	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24769	 1	 1.82	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24770	 1	 2.94	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24771	 1	 1.59	 1.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24772	 1	 4.68	 3.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24773	 1	 3.12	 2.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24774	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24775	 1	 3.47	 2.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24776	 1	 2.42	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24777	 1	 1.77	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24778	 1	 4.9	 2.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24779	 1	 2.76	 2.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24780	 1	 3.78	 2.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24781	 1	 3.56	 2.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24782	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24783	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24784	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24785	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24786	 1	 3.98	 2.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24787	 1	 3.09	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24788	 1	 1.23	 0.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24789	 1	 2.09	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24790	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24791	 1	 4.08	 2.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24792	 1	 2.33	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24793	 1	 3.41	 2.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24794	 1	 3.35	 1.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24795	 1	 2.28	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24796	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24797	 1	 7.7	 4.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24798	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24799	 1	 6.35	 3.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24800	 1	 1.65	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24801	 1	 3.25	 2.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24802	 1	 22.02	 11.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24803	 1	 2.09	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24804	 1	 1.26	 0.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24805	 1	 19.83	 10.41	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24806	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24807	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24808	 1	 26.43	 13.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24809	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24810	 1	 35.34	 18.71	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24811	 1	 3.48	 2.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24812	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24813	 1	 1.72	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24814	 1	 2.93	 2.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24815	 1	 10.17	 5.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24816	 1	 7.74	 4.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24817	 1	 9.59	 5.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24818	 1	 5.27	 3.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24819	 1	 8.26	 3.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24820	 1	 1.47	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24821	 1	 3.03	 1.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24822	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24823	 1	 6.3	 3.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24824	 1	 3.32	 2.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24825	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24826	 1	 2.68	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24827	 1	 2.57	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24828	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24829	 1	 2.26	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24830	 1	 2.99	 2.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24831	 1	 13.27	 5.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24832	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24833	 1	 1.89	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24834	 1	 2.36	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24835	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24836	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24837	 1	 32.86	 15.34	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24838	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24839	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24840	 1	 3.95	 2.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24841	 1	 2.21	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24842	 1	 1.28	 0.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24843	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24844	 1	 6.13	 3.78	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24845	 1	 20.67	 9.93	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24846	 1	 2.07	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24847	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24848	 1	 12.8	 3.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24849	 1	 10.96	 4.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24850	 1	 2.19	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24851	 1	 13.34	 7.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24852	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24853	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24854	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24855	 1	 5.85	 3.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24856	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24857	 1	 3.97	 2.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24858	 1	 2.88	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24859	 1	 2.42	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24860	 1	 19.24	 10.16	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24861	 1	 3.14	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24862	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24863	 1	 7.0	 4.18	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24864	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24865	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24866	 1	 7.49	 3.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24867	 1	 6.12	 2.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24868	 1	 3.34	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24869	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24870	 1	 19.16	 6.65	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24871	 1	 14.39	 4.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24872	 1	 2.36	 1.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24873	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24874	 1	 8.98	 4.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24875	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24876	 1	 9.92	 3.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24877	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24878	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24879	 1	 2.97	 1.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24880	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24881	 1	 6.12	 2.59	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24882	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	24883	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24884	 1	 2.83	 1.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24885	 1	 3.84	 1.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24886	 1	 3.93	 1.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24887	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24888	 1	 8.58	 3.03	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24889	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24890	 1	 2.33	 0.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24891	 1	 2.42	 1.09	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24892	 1	 6.93	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24893	 1	 2.25	 0.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24894	 1	 1.72	 0.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24895	 1	 1.5	 0.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24896	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24897	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24898	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24899	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24900	 1	 9.13	 3.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24901	 1	 5.7	 2.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24902	 1	 12.68	 4.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24903	 1	 12.07	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24904	 1	 7.76	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24905	 1	 10.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24906	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24907	 1	 2.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24908	 1	 6.41	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24909	 1	 7.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24910	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24911	 1	 5.49	 2.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24912	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24913	 1	 9.85	 3.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24914	 1	 17.19	 4.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24915	 1	 8.23	 3.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24916	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24917	 1	 10.14	 3.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24918	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24919	 1	 5.35	 2.41	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24920	 1	 12.53	 5.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24921	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24922	 1	 7.72	 3.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24923	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24924	 1	 55.3	 22.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24925	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24926	 1	 12.91	 4.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24927	 1	 8.55	 4.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24928	 1	 3.15	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24929	 1	 18.99	 7.03	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24930	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24931	 1	 12.67	 4.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24932	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24933	 1	 2.89	 1.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24934	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24935	 1	 9.21	 4.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24936	 1	 7.76	 1.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24937	 1	 8.59	 3.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24938	 1	 16.21	 3.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24939	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24940	 1	 5.31	 2.39	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24941	 1	 11.93	 5.19	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24942	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24943	 1	 4.24	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24944	 1	 4.64	 2.43	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24945	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24946	 1	 4.1	 2.13	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24947	 1	 6.87	 2.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24948	 1	 3.33	 1.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24949	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24950	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24951	 1	 14.84	 6.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24952	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24953	 1	 9.49	 4.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24954	 1	 5.1	 2.22	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24955	 1	 7.61	 3.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24956	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24957	 1	 6.76	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24958	 1	 8.11	 3.3	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24959	 1	 22.37	 5.13	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24960	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24961	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24962	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24963	 1	 2.32	 0.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24964	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24965	 1	 17.58	 6.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24966	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24967	 1	 3.57	 1.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24968	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24969	 1	 4.16	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24970	 1	 2.26	 1.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24971	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24972	 1	 5.11	 2.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24973	 1	 5.81	 2.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24974	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24975	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24976	 1	 3.3	 1.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24977	 1	 1.7	 0.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24978	 1	 1.37	 0.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24979	 1	 7.98	 3.61	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24980	 1	 2.56	 1.28	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24981	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24982	 1	 7.93	 3.56	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24983	 1	 5.69	 2.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24984	 1	 6.64	 2.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24985	 1	 8.2	 3.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24986	 1	 5.14	 2.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24987	 1	 18.47	 7.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24988	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24989	 1	 8.78	 3.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24990	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24991	 1	 5.97	 2.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24992	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24993	 1	 9.95	 3.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24994	 1	 5.23	 2.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24995	 1	 4.1	 1.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24996	 1	 3.98	 2.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24997	 1	 16.13	 6.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24998	 1	 4.93	 1.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24999	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25000	 1	 5.3	 2.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25001	 1	 13.47	 5.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25002	 1	 6.79	 3.25	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25003	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25004	 1	 9.79	 3.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25005	 1	 12.45	 4.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25006	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25007	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25008	 1	 4.82	 2.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25009	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25010	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25011	 1	 4.56	 2.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25012	 1	 3.93	 1.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25013	 1	 4.63	 1.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25014	 1	 7.71	 3.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25015	 1	 10.44	 4.33	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25016	 1	 7.61	 2.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25017	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25018	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25019	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25020	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25021	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25022	 1	 52.26	 19.07	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25023	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25024	 1	 4.1	 1.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25025	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25026	 1	 6.23	 2.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25027	 1	 49.23	 15.92	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25028	 1	 7.19	 2.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25029	 1	 5.1	 2.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25030	 1	 7.26	 3.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25031	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25032	 1	 8.28	 3.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25033	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25034	 1	 2.93	 1.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25035	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25036	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25037	 1	 7.05	 2.79	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25038	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25039	 1	 4.98	 2.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25040	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25041	 1	 4.47	 1.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25042	 1	 9.1	 3.79	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25043	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25044	 1	 5.75	 2.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25045	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25046	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25047	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25048	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25049	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25050	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25051	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25052	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25053	 1	 4.67	 2.28	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25054	 1	 2.64	 1.36	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25055	 1	 5.82	 2.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25056	 1	 3.05	 1.35	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25057	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25058	 1	 3.23	 1.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25059	 1	 3.78	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25060	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25061	 1	 3.71	 1.53	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25062	 1	 8.57	 4.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25063	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25064	 1	 6.8	 2.56	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25065	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25066	 1	 4.91	 2.43	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25067	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25068	 1	 8.12	 2.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25069	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25070	 1	 7.06	 3.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25071	 1	 6.26	 2.5	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25072	 1	 11.06	 5.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25073	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25074	 1	 16.32	 6.77	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25075	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25076	 1	 9.65	 4.13	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25077	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25078	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25079	 1	 8.71	 4.22	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25080	 1	 3.16	 1.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25081	 1	 1.76	 0.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25082	 1	 12.46	 2.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25083	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25084	 1	 6.88	 1.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25085	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25086	 1	 2.87	 0.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25087	 1	 9.69	 2.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25088	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25089	 1	 8.09	 1.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25090	 1	 6.5	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25091	 1	 1.86	 0.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25092	 1	 3.65	 0.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25093	 1	 2.41	 0.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25094	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25095	 1	 5.86	 1.34	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25096	 1	 6.4	 1.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25097	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25098	 1	 1.21	 0.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25099	 1	 1.46	 0.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25100	 1	 1.41	 0.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25101	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25102	 1	 10.7	 2.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25103	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25104	 1	 9.07	 2.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25105	 1	 10.08	 2.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25106	 1	 9.08	 2.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25107	 1	 8.19	 1.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25108	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25109	 1	 5.43	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25110	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25111	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25112	 1	 5.58	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25113	 1	 7.05	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25114	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25115	 1	 2.71	 0.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25116	 1	 10.87	 2.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25117	 1	 3.95	 0.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25118	 1	 9.58	 2.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25119	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25120	 1	 14.08	 3.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25121	 1	 5.88	 1.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25122	 1	 11.02	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25123	 1	 7.71	 1.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25124	 1	 10.16	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25125	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25126	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25127	 1	 4.68	 1.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25128	 1	 4.07	 0.94	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25129	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25130	 1	 15.31	 3.55	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25131	 1	 15.42	 3.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25132	 1	 8.06	 1.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25133	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25134	 1	 11.81	 2.71	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25135	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25136	 1	 2.86	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25137	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25138	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25139	 1	 9.91	 3.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25140	 1	 3.73	 1.83	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25141	 1	 4.82	 1.85	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25142	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25143	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25144	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25145	 1	 3.65	 1.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25146	 1	 2.51	 1.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25147	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25148	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25149	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25150	 1	 4.63	 1.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25151	 1	 8.89	 4.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25152	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25153	 1	 17.7	 6.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25154	 1	 8.48	 2.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25155	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25156	 1	 11.85	 5.82	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25157	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25158	 1	 4.88	 2.56	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25159	 1	 0.04	 0.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25160	 1	 6.29	 2.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25161	 1	 8.23	 3.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25162	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25163	 1	 5.43	 2.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25164	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25165	 1	 6.02	 2.97	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25166	 1	 5.69	 2.65	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25167	 1	 7.55	 3.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25168	 1	 15.73	 7.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25169	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25170	 1	 5.67	 2.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25171	 1	 3.21	 1.42	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25172	 1	 5.29	 2.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25173	 1	 13.01	 4.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25174	 1	 6.75	 2.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25175	 1	 10.99	 3.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25176	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25177	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25178	 1	 7.81	 2.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25179	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25180	 1	 5.04	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25181	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25182	 1	 5.74	 2.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25183	 1	 8.83	 3.04	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25184	 1	 7.53	 2.85	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25185	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25186	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25187	 1	 10.19	 4.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25188	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25189	 1	 7.0	 2.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25190	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25191	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25192	 1	 4.57	 1.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25193	 1	 7.29	 2.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25194	 1	 13.24	 5.6	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25195	 1	 5.01	 2.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25196	 1	 4.22	 2.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25197	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25198	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25199	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25200	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25201	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25202	 1	 5.26	 2.42	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25203	 1	 3.48	 1.57	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25204	 1	 3.37	 1.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25205	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25206	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25207	 1	 4.46	 2.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25208	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25209	 1	 6.41	 2.76	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25210	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25211	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25212	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25213	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25214	 1	 8.85	 2.48	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25215	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25216	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25217	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25218	 1	 5.73	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25219	 1	 4.71	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25220	 1	 14.53	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25221	 1	 21.14	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25222	 1	 5.69	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25223	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25224	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25225	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25226	 1	 5.41	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25227	 1	 14.85	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25228	 1	 9.58	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25229	 1	 4.7	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25230	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25231	 1	 1.73	 0.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25232	 1	 9.9	 4.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25233	 1	 10.64	 4.03	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25234	 1	 9.06	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25235	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25236	 1	 11.02	 2.82	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25237	 1	 5.81	 2.59	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25238	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25239	 1	 3.83	 1.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25240	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25241	 1	 4.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25242	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25243	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25244	 1	 2.22	 1.11	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25245	 1	 2.74	 1.2	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25246	 1	 3.15	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25247	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25248	 1	 2.96	 1.38	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25249	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25250	 1	 9.95	 3.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25251	 1	 6.71	 2.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25252	 1	 2.69	 1.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25253	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25254	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25255	 1	 3.4	 1.23	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25256	 1	 7.13	 2.94	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25257	 1	 7.87	 2.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25258	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25259	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25260	 1	 7.15	 2.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25261	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25262	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25263	 1	 3.64	 1.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25264	 1	 17.17	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25265	 1	 5.04	 1.95	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25266	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25267	 1	 2.29	 1.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25268	 1	 7.5	 2.88	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25269	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25270	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25271	 1	 4.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25272	 1	 6.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25273	 1	 4.88	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25274	 1	 1.08	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25275	 1	 3.18	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25276	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25277	 1	 7.73	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25278	 1	 5.35	 2.26	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25279	 1	 26.62	 9.78	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25280	 1	 13.56	 5.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25281	 1	 22.13	 7.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25282	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25283	 1	 59.43	 16.3	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25284	 1	 17.03	 6.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25285	 1	 10.72	 3.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25286	 1	 11.18	 4.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25287	 1	 9.62	 3.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25288	 1	 3.61	 1.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25289	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25290	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25291	 1	 4.9	 1.62	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25292	 1	 43.73	 11.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25293	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25294	 1	 1.81	 0.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25295	 1	 1.15	 0.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25296	 1	 1.1	 0.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25297	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25298	 1	 1.1	 0.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25299	 1	 0.81	 0.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25300	 1	 1.71	 0.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25301	 1	 6.18	 2.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25302	 1	 6.18	 1.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25303	 1	 1.15	 0.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25304	 1	 1.24	 0.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25305	 1	 1.02	 0.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25306	 1	 2.69	 0.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25307	 1	 20.46	 5.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25308	 1	 1.19	 0.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25309	 1	 2.88	 1.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25310	 1	 9.74	 2.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25311	 1	 5.59	 1.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25312	 1	 4.76	 1.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25313	 1	 52.2	 11.12	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25314	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25315	 1	 0.23	 0.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25316	 1	 5.61	 2.11	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25317	 1	 1.29	 0.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25318	 1	 1.41	 0.63	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25319	 1	 14.77	 5.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25320	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25321	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25322	 1	 11.71	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25323	 1	 3.56	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25324	 1	 2.59	 0.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25325	 1	 2.09	 0.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25326	 1	 4.81	 1.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25327	 1	 3.39	 1.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25328	 1	 2.76	 1.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25329	 1	 4.99	 2.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25330	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25331	 1	 3.7	 1.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25332	 1	 3.17	 1.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25333	 1	 3.32	 1.48	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25334	 1	 2.5	 1.06	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25335	 1	 9.84	 3.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25336	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25337	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25338	 1	 5.43	 1.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25339	 1	 16.53	 5.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25340	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25341	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25342	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25343	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25344	 1	 2.27	 0.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25345	 1	 3.5	 1.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25346	 1	 2.41	 1.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25347	 1	 5.62	 2.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25348	 1	 0.97	 0.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25349	 1	 1.96	 0.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25350	 1	 20.39	 7.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25351	 1	 4.7	 1.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25352	 1	 11.08	 3.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25353	 1	 20.27	 6.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25354	 1	 1.22	 0.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25355	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25356	 1	 2.8	 1.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25357	 1	 6.11	 2.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25358	 1	 6.12	 2.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25359	 1	 6.6	 2.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25360	 1	 5.08	 2.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25361	 1	 1.97	 0.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25362	 1	 2.16	 1.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25363	 1	 5.26	 2.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25364	 1	 3.18	 1.44	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25365	 1	 2.57	 1.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25366	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25367	 1	 2.31	 1.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25368	 1	 5.49	 2.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25369	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25370	 1	 3.92	 1.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25371	 1	 2.22	 1.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25372	 1	 5.06	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25373	 1	 2.22	 1.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25374	 1	 2.2	 0.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25375	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25376	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25377	 1	 5.5	 2.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25378	 1	 3.11	 1.33	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25379	 1	 6.34	 2.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25380	 1	 1.65	 0.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25381	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25382	 1	 10.18	 3.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25383	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25384	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25385	 1	 2.4	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25386	 1	 6.8	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25387	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25388	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25389	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25390	 1	 3.75	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25391	 1	 4.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25392	 1	 13.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25393	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25394	 1	 9.49	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25395	 1	 6.85	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25396	 1	 4.79	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25397	 1	 5.75	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25398	 1	 6.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25399	 1	 3.92	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25400	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25401	 1	 35.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25402	 1	 3.88	 1.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25403	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25404	 1	 4.39	 2.14	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25405	 1	 4.31	 1.79	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25406	 1	 4.14	 1.71	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25407	 1	 5.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25408	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25409	 1	 4.2	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25410	 1	 4.42	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25411	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25412	 1	 8.74	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25413	 1	 8.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25414	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25415	 1	 11.02	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25416	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25417	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25418	 1	 5.31	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25419	 1	 7.91	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25420	 1	 2.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25421	 1	 4.34	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25422	 1	 6.92	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25423	 1	 4.11	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25424	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25425	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25426	 1	 31.42	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25427	 1	 6.64	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25428	 1	 15.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25429	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25430	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25431	 1	 6.76	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25432	 1	 10.66	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25433	 1	 12.26	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25434	 1	 7.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25435	 1	 12.09	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25436	 1	 5.34	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25437	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25438	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25439	 1	 3.44	 1.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25440	 1	 2.21	 1.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25441	 1	 3.02	 1.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25442	 1	 6.59	 2.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25443	 1	 6.63	 2.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25444	 1	 3.4	 1.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25445	 1	 3.28	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25446	 1	 4.43	 1.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25447	 1	 4.42	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25448	 1	 3.08	 1.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25449	 1	 7.71	 2.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25450	 1	 6.96	 3.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25451	 1	 3.07	 1.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25452	 1	 5.02	 1.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25453	 1	 2.65	 1.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25454	 1	 2.14	 0.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25455	 1	 1.67	 0.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25456	 1	 3.72	 1.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25457	 1	 1.97	 0.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25458	 1	 6.84	 2.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25459	 1	 2.33	 0.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25460	 1	 1.59	 0.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25461	 1	 10.74	 3.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25462	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25463	 1	 2.08	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25464	 1	 4.89	 1.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25465	 1	 1.74	 0.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25466	 1	 1.36	 0.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25467	 1	 4.52	 1.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25468	 1	 4.66	 1.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25469	 1	 4.57	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25470	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25471	 1	 4.21	 1.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25472	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25473	 1	 2.64	 1.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25474	 1	 4.11	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25475	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25476	 1	 7.03	 3.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25477	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25478	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25479	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25480	 1	 4.51	 2.27	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25481	 1	 7.4	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25482	 1	 2.65	 1.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25483	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25484	 1	 7.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25485	 1	 6.18	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25486	 1	 5.68	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25487	 1	 6.52	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25488	 1	 3.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25489	 1	 4.31	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25490	 1	 7.81	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25491	 1	 1.98	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25492	 1	 6.98	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25493	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25494	 1	 6.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25495	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25496	 1	 6.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25497	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25498	 1	 20.87	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25499	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25500	 1	 5.92	 2.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25501	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25502	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25503	 1	 1.91	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25504	 1	 3.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25505	 1	 1.96	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25506	 1	 6.71	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25507	 1	 7.06	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25508	 1	 5.31	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25509	 1	 5.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25510	 1	 2.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25511	 1	 4.61	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25512	 1	 3.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25513	 1	 1.76	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25514	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25515	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25516	 1	 10.2	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25517	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25518	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25519	 1	 4.26	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25520	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25521	 1	 3.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25522	 1	 2.8	 1.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25523	 1	 12.13	 4.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25524	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25525	 1	 5.49	 2.25	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25526	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25527	 1	 5.66	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25528	 1	 10.54	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25529	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25530	 1	 9.21	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25531	 1	 5.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25532	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25533	 1	 5.91	 2.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25534	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25535	 1	 10.13	 3.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25536	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25537	 1	 11.18	 4.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25538	 1	 9.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25539	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25540	 1	 2.61	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25541	 1	 9.04	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25542	 1	 14.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25543	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25544	 1	 2.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25545	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25546	 1	 11.16	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25547	 1	 5.89	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25548	 1	 3.94	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25549	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25550	 1	 6.12	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25551	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25552	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25553	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25554	 1	 8.78	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25555	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25556	 1	 3.08	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25557	 1	 15.9	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25558	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25559	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25560	 1	 7.75	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25561	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25562	 1	 4.46	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25563	 1	 5.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25564	 1	 3.79	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25565	 1	 6.19	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25566	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25567	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25568	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25569	 1	 3.04	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25570	 1	 3.03	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25571	 1	 6.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25572	 1	 6.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25573	 1	 4.1	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25574	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25575	 1	 3.93	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25576	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25577	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25578	 1	 2.88	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25579	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25580	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25581	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25582	 1	 2.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25583	 1	 4.84	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25584	 1	 4.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25585	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25586	 1	 4.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25587	 1	 4.16	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25588	 1	 8.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25589	 1	 5.21	 1.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25590	 1	 3.03	 1.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25591	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25592	 1	 10.09	 4.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25593	 1	 6.74	 2.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25594	 1	 10.63	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25595	 1	 7.41	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25596	 1	 10.31	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25597	 1	 12.84	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25598	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25599	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25600	 1	 3.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25601	 1	 10.2	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25602	 1	 4.87	 2.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25603	 1	 2.4	 1.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25604	 1	 4.82	 1.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25605	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25606	 1	 3.39	 1.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25607	 1	 7.27	 2.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25608	 1	 4.53	 2.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25609	 1	 2.29	 0.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25610	 1	 5.34	 2.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25611	 1	 6.36	 2.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25612	 1	 1.56	 0.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25613	 1	 4.19	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25614	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25615	 1	 4.57	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25616	 1	 12.46	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25617	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25618	 1	 10.48	 2.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25619	 1	 2.62	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25620	 1	 4.69	 2.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25621	 1	 5.74	 2.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25622	 1	 2.69	 1.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25623	 1	 5.25	 2.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25624	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25625	 1	 26.25	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25626	 1	 4.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25627	 1	 3.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25628	 1	 9.45	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25629	 1	 10.79	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25630	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25631	 1	 4.74	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25632	 1	 7.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25633	 1	 9.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25634	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25635	 1	 6.17	 2.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25636	 1	 3.22	 1.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25637	 1	 6.26	 2.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25638	 1	 10.9	 4.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25639	 1	 7.07	 3.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25640	 1	 26.99	 9.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25641	 1	 5.58	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25642	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25643	 1	 11.8	 4.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25644	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25645	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25646	 1	 6.91	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25647	 1	 3.58	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25648	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25649	 1	 9.78	 4.58	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25650	 1	 4.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25651	 1	 2.54	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25652	 1	 1.71	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25653	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25654	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25655	 1	 1.39	 0.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25656	 1	 22.42	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25657	 1	 6.36	 2.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25658	 1	 1.94	 0.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25659	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25660	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25661	 1	 2.94	 1.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25662	 1	 2.81	 1.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25663	 1	 6.64	 2.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25664	 1	 4.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25665	 1	 34.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25666	 1	 3.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25667	 1	 11.02	 4.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25668	 1	 5.51	 1.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25669	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	25670	 1	 6.21	 2.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25671	 1	 5.5	 2.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25672	 1	 7.64	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25673	 1	 3.74	 1.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25674	 1	 59.34	 17.77	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25675	 1	 18.53	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25676	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25677	 1	 4.23	 1.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25678	 1	 6.64	 2.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25679	 1	 6.46	 2.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25680	 1	 9.01	 2.66	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25681	 1	 12.57	 4.42	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25682	 1	 6.1	 2.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25683	 1	 12.9	 4.38	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25684	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25685	 1	 49.64	 15.45	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25686	 1	 15.26	 5.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25687	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25688	 1	 8.19	 3.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25689	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25690	 1	 6.14	 1.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25691	 1	 8.65	 1.95	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25692	 1	 7.73	 3.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25693	 1	 16.65	 5.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25694	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25695	 1	 4.98	 2.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25696	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25697	 1	 5.45	 2.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25698	 1	 8.85	 2.03	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25699	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25700	 1	 3.33	 0.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25701	 1	 3.34	 0.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25702	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25703	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25704	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25705	 1	 3.06	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25706	 1	 5.26	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25707	 1	 4.4	 1.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25708	 1	 3.3	 0.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25709	 1	 4.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25710	 1	 6.38	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25711	 1	 7.56	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25712	 1	 6.64	 1.53	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25713	 1	 3.94	 0.92	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25714	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25715	 1	 3.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25716	 1	 5.63	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25717	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25718	 1	 8.8	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25719	 1	 7.22	 1.65	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25720	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25721	 1	 7.89	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25722	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25723	 1	 4.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25724	 1	 6.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25725	 1	 5.09	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25726	 1	 5.79	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25727	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25728	 1	 7.21	 1.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25729	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25730	 1	 9.34	 2.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25731	 1	 5.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25732	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25733	 1	 9.39	 4.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25734	 1	 4.16	 1.79	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25735	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25736	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25737	 1	 18.0	 5.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25738	 1	 6.88	 3.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25739	 1	 20.35	 7.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25740	 1	 17.47	 6.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25741	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25742	 1	 3.0	 1.43	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25743	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25744	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25745	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25746	 1	 17.08	 5.06	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25747	 1	 10.93	 5.16	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25748	 1	 36.3	 12.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25749	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25750	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25751	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25752	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25753	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25754	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25755	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25756	 1	 2.94	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25757	 1	 6.01	 2.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25758	 1	 22.25	 7.36	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25759	 1	 6.97	 2.71	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25760	 1	 13.24	 4.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25761	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25762	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25763	 1	 6.82	 3.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25764	 1	 4.85	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25765	 1	 6.43	 2.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25766	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25767	 1	 12.97	 4.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25768	 1	 3.31	 1.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25769	 1	 7.85	 3.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25770	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25771	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25772	 1	 8.21	 3.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25773	 1	 4.85	 1.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25774	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25775	 1	 5.63	 1.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25776	 1	 10.28	 4.86	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25777	 1	 6.2	 2.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25778	 1	 8.93	 4.31	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25779	 1	 18.02	 4.71	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25780	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25781	 1	 11.28	 4.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25782	 1	 5.36	 2.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25783	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25784	 1	 9.03	 3.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25785	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25786	 1	 3.49	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25787	 1	 3.07	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25788	 1	 2.85	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25789	 1	 5.57	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25790	 1	 3.06	 0.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25791	 1	 2.32	 0.53	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25792	 1	 2.25	 0.51	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25793	 1	 2.59	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25794	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25795	 1	 3.94	 0.9	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25796	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25797	 1	 3.5	 0.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25798	 1	 4.51	 1.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25799	 1	 3.0	 0.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25800	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25801	 1	 5.22	 1.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25802	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25803	 1	 2.74	 0.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25804	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25805	 1	 4.07	 0.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25806	 1	 14.89	 3.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25807	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25808	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25809	 1	 6.39	 1.48	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25810	 1	 3.76	 0.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25811	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25812	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25813	 1	 2.87	 0.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25814	 1	 4.3	 0.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25815	 1	 9.17	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25816	 1	 8.73	 2.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25817	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25818	 1	 3.4	 0.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25819	 1	 2.0	 0.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25820	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25821	 1	 6.58	 1.51	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25822	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25823	 1	 3.78	 0.87	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25824	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25825	 1	 1.8	 0.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25826	 1	 4.72	 1.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25827	 1	 2.98	 0.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25828	 1	 3.01	 0.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25829	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25830	 1	 4.37	 1.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25831	 1	 2.6	 0.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25832	 1	 3.77	 0.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25833	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25834	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25835	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25836	 1	 1.4	 0.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25837	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25838	 1	 1.84	 0.42	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25839	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25840	 1	 1.44	 0.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25841	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25842	 1	 6.95	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25843	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25844	 1	 3.07	 0.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25845	 1	 5.07	 1.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25846	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25847	 1	 2.51	 0.58	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25848	 1	 5.97	 1.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25849	 1	 7.23	 1.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25850	 1	 9.95	 2.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25851	 1	 3.44	 0.8	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25852	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25853	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25854	 1	 2.68	 0.62	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25855	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25856	 1	 1.73	 0.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25857	 1	 2.47	 0.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25858	 1	 3.77	 0.87	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25859	 1	 3.2	 0.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25860	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25861	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25862	 1	 7.15	 1.66	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25863	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25864	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25865	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25866	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25867	 1	 4.31	 1.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25868	 1	 4.21	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25869	 1	 3.22	 0.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25870	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25871	 1	 3.01	 0.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25872	 1	 4.65	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25873	 1	 4.53	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25874	 1	 7.26	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25875	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25876	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25877	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25878	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25879	 1	 6.52	 1.5	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25880	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25881	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25882	 1	 4.5	 1.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25883	 1	 5.09	 1.17	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25884	 1	 2.67	 0.62	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25885	 1	 4.3	 0.99	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25886	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25887	 1	 2.59	 0.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25888	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25889	 1	 3.54	 0.82	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25890	 1	 4.28	 0.99	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25891	 1	 4.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25892	 1	 4.75	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25893	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25894	 1	 2.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25895	 1	 5.42	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25896	 1	 1.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25897	 1	 1.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25898	 1	 6.04	 1.38	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25899	 1	 3.18	 0.73	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25900	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25901	 1	 7.04	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25902	 1	 5.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25903	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25904	 1	 1.13	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25905	 1	 4.85	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25906	 1	 3.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25907	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25908	 1	 2.67	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25909	 1	 7.9	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25910	 1	 4.91	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25911	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25912	 1	 2.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25913	 1	 4.42	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25914	 1	 5.45	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25915	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25916	 1	 10.67	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25917	 1	 5.27	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25918	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25919	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25920	 1	 5.71	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25921	 1	 7.96	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25922	 1	 8.91	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25923	 1	 8.08	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25924	 1	 6.47	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25925	 1	 2.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25926	 1	 7.07	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25927	 1	 0.59	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25928	 1	 4.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25929	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25930	 1	 3.85	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25931	 1	 4.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25932	 1	 6.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25933	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25934	 1	 9.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25935	 1	 3.21	 0.74	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25936	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25937	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25938	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25939	 1	 3.27	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25940	 1	 4.14	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25941	 1	 12.81	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25942	 1	 5.81	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25943	 1	 4.21	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25944	 1	 10.91	 2.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25945	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25946	 1	 3.47	 0.8	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25947	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25948	 1	 2.02	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25949	 1	 1.52	 0.35	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25950	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25951	 1	 3.86	 0.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25952	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25953	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25954	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25955	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25956	 1	 3.57	 0.82	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25957	 1	 1.6	 0.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25958	 1	 5.37	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25959	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25960	 1	 5.04	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25961	 1	 10.74	 2.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25962	 1	 8.47	 1.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25963	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25964	 1	 7.67	 1.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25965	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25966	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25967	 1	 8.14	 1.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25968	 1	 10.38	 2.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25969	 1	 6.38	 1.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25970	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25971	 1	 5.5	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25972	 1	 4.34	 1.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25973	 1	 5.63	 1.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25974	 1	 7.89	 1.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25975	 1	 8.33	 1.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25976	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25977	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25978	 1	 10.32	 2.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25979	 1	 3.42	 0.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25980	 1	 3.89	 0.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25981	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25982	 1	 5.64	 1.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25983	 1	 7.4	 1.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25984	 1	 6.84	 1.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25985	 1	 7.18	 1.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25986	 1	 5.15	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25987	 1	 2.23	 0.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25988	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25989	 1	 3.99	 0.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25990	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25991	 1	 7.46	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25992	 1	 7.4	 1.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25993	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25994	 1	 26.37	 6.11	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25995	 1	 3.82	 0.89	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25996	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25997	 1	 3.34	 0.78	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25998	 1	 8.96	 2.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25999	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26000	 1	 25.85	 6.01	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26001	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26002	 1	 6.36	 1.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26003	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26004	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26005	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26006	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26007	 1	 5.36	 1.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26008	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26009	 1	 17.01	 3.91	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26010	 1	 3.52	 0.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26011	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26012	 1	 1.86	 0.43	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26013	 1	 3.78	 0.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26014	 1	 2.79	 0.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26015	 1	 3.15	 0.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26016	 1	 2.1	 0.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26017	 1	 3.11	 0.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26018	 1	 3.14	 0.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26019	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26020	 1	 1.7	 0.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26021	 1	 2.0	 0.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26022	 1	 3.01	 0.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26023	 1	 2.48	 0.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26024	 1	 2.73	 0.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26025	 1	 3.13	 0.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26026	 1	 4.48	 1.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26027	 1	 3.71	 0.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26028	 1	 2.86	 0.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26029	 1	 4.87	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26030	 1	 7.47	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26031	 1	 6.83	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26032	 1	 4.18	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26033	 1	 5.6	 1.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26034	 1	 14.85	 3.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26035	 1	 7.5	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26036	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26037	 1	 3.91	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26038	 1	 3.01	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26039	 1	 4.07	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26040	 1	 2.93	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26041	 1	 5.49	 1.27	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26042	 1	 3.77	 0.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26043	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26044	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26045	 1	 5.48	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26046	 1	 9.58	 2.23	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26047	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26048	 1	 18.37	 4.27	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26049	 1	 5.99	 1.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26050	 1	 23.55	 9.02	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26051	 1	 9.55	 2.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26052	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26053	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26054	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26055	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26056	 1	 13.25	 4.78	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26057	 1	 5.94	 1.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26058	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26059	 1	 11.21	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26060	 1	 5.23	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26061	 1	 5.62	 1.29	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26062	 1	 18.87	 4.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26063	 1	 27.94	 6.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26064	 1	 7.52	 1.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26065	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26066	 1	 4.51	 1.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26067	 1	 6.3	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26068	 1	 1.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26069	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26070	 1	 4.57	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26071	 1	 6.57	 2.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26072	 1	 5.51	 2.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26073	 1	 11.27	 4.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26074	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26075	 1	 6.46	 3.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26076	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26077	 1	 8.87	 3.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26078	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26079	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26080	 1	 4.44	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26081	 1	 5.26	 2.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26082	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26083	 1	 14.94	 7.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26084	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26085	 1	 16.57	 4.51	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26086	 1	 3.63	 1.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26087	 1	 2.42	 1.12	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26088	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26089	 1	 5.94	 2.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26090	 1	 17.19	 5.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26091	 1	 12.84	 4.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26092	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26093	 1	 11.23	 3.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26094	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26095	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26096	 1	 4.67	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26097	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26098	 1	 17.33	 3.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26099	 1	 26.61	 6.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26100	 1	 6.54	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26101	 1	 4.01	 0.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26102	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26103	 1	 5.17	 2.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26104	 1	 5.5	 2.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26105	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26106	 1	 3.64	 1.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26107	 1	 5.33	 1.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26108	 1	 4.34	 1.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26109	 1	 6.42	 3.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26110	 1	 14.71	 5.2	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26111	 1	 13.28	 3.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26112	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26113	 1	 7.6	 1.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26114	 1	 4.39	 1.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26115	 1	 12.56	 5.36	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26116	 1	 18.99	 7.89	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26117	 1	 8.87	 4.11	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26118	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26119	 1	 7.86	 3.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26120	 1	 7.91	 3.39	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26121	 1	 18.04	 5.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26122	 1	 12.82	 5.88	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26123	 1	 15.07	 6.2	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26124	 1	 13.58	 4.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26125	 1	 10.15	 4.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26126	 1	 14.16	 6.05	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26127	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26128	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26129	 1	 11.33	 4.03	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26130	 1	 14.03	 5.5	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26131	 1	 17.26	 6.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26132	 1	 4.33	 1.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26133	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26134	 1	 12.12	 3.94	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26135	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26136	 1	 8.21	 1.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26137	 1	 8.48	 2.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26138	 1	 2.49	 0.97	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26139	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26140	 1	 5.67	 1.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26141	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26142	 1	 4.96	 2.38	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26143	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26144	 1	 10.69	 4.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26145	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26146	 1	 3.34	 1.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26147	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26148	 1	 5.96	 2.9	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26149	 1	 4.35	 1.9	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26150	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26151	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26152	 1	 1.28	 0.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26153	 1	 7.54	 3.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26154	 1	 1.6	 0.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26155	 1	 1.88	 0.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26156	 1	 1.1	 0.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26157	 1	 2.37	 1.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26158	 1	 2.28	 0.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26159	 1	 1.43	 0.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26160	 1	 1.4	 0.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26161	 1	 3.99	 1.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26162	 1	 2.22	 1.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26163	 1	 4.77	 2.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26164	 1	 2.36	 1.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26165	 1	 3.35	 1.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26166	 1	 1.47	 0.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26167	 1	 48.84	 16.06	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26168	 1	 11.94	 5.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26169	 1	 11.26	 4.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26170	 1	 19.62	 8.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26171	 1	 2.88	 1.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26172	 1	 1.41	 0.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26173	 1	 2.6	 1.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26174	 1	 4.36	 1.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26175	 1	 1.88	 0.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26176	 1	 2.05	 0.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26177	 1	 5.16	 1.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26178	 1	 1.77	 0.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26179	 1	 1.03	 0.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26180	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26181	 1	 2.89	 1.53	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26182	 1	 3.41	 1.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26183	 1	 2.63	 1.23	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26184	 1	 2.81	 1.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26185	 1	 13.49	 3.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26186	 1	 3.13	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26187	 1	 8.29	 3.99	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26188	 1	 8.52	 3.17	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26189	 1	 5.18	 2.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26190	 1	 5.22	 2.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26191	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26192	 1	 3.8	 1.78	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26193	 1	 34.67	 8.31	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26194	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26195	 1	 8.7	 3.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26196	 1	 5.05	 2.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26197	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26198	 1	 5.23	 2.22	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26199	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26200	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26201	 1	 29.39	 11.22	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26202	 1	 3.86	 1.89	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26203	 1	 31.22	 12.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26204	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26205	 1	 2.43	 1.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26206	 1	 3.76	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26207	 1	 3.71	 1.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26208	 1	 2.89	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26209	 1	 3.46	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26210	 1	 2.69	 1.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26211	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26212	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26213	 1	 2.52	 0.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26214	 1	 5.66	 2.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26215	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26216	 1	 1.33	 0.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26217	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26218	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26219	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26220	 1	 3.34	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26221	 1	 9.21	 4.07	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26222	 1	 1.94	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26223	 1	 3.47	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26224	 1	 1.86	 0.8	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26225	 1	 2.15	 0.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26226	 1	 3.07	 1.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26227	 1	 5.93	 2.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26228	 1	 2.77	 1.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26229	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26230	 1	 2.57	 1.27	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26231	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26232	 1	 7.49	 3.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26233	 1	 1.95	 0.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26234	 1	 4.82	 1.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26235	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26236	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26237	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26238	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26239	 1	 1.7	 0.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26240	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26241	 1	 5.62	 2.6	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26242	 1	 4.39	 2.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26243	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26244	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26245	 1	 1.41	 0.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26246	 1	 1.28	 0.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26247	 1	 3.72	 1.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26248	 1	 2.98	 1.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26249	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26250	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26251	 1	 3.35	 1.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26252	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26253	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26254	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26255	 1	 2.33	 1.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26256	 1	 6.57	 3.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26257	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26258	 1	 4.83	 2.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26259	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26260	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26261	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26262	 1	 4.57	 2.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26263	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26264	 1	 3.88	 1.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26265	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26266	 1	 8.71	 4.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26267	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26268	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26269	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26270	 1	 5.11	 2.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26271	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26272	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26273	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26274	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26275	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26276	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26277	 1	 3.53	 1.71	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26278	 1	 2.04	 1.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26279	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26280	 1	 5.67	 2.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26281	 1	 5.17	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26282	 1	 9.16	 3.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26283	 1	 7.2	 3.5	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26284	 1	 4.7	 2.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26285	 1	 2.92	 1.42	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26286	 1	 5.67	 2.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26287	 1	 25.78	 9.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26288	 1	 2.96	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26289	 1	 4.56	 1.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26290	 1	 11.57	 5.53	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26291	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26292	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26293	 1	 6.28	 2.65	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26294	 1	 3.04	 1.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26295	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26296	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26297	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26298	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26299	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26300	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26301	 1	 1.38	 0.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26302	 1	 3.98	 2.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26303	 1	 4.33	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26304	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26305	 1	 9.4	 3.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26306	 1	 52.33	 17.01	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26307	 1	 10.08	 4.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26308	 1	 2.09	 0.91	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26309	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26310	 1	 8.46	 3.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26311	 1	 6.74	 2.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26312	 1	 9.04	 4.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26313	 1	 81.02	 25.9	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26314	 1	 5.95	 2.77	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26315	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26316	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26317	 1	 10.35	 3.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26318	 1	 9.15	 2.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26319	 1	 6.64	 2.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26320	 1	 12.73	 4.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26321	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26322	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26323	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26324	 1	 4.77	 1.98	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26325	 1	 6.07	 2.81	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26326	 1	 6.22	 2.68	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26327	 1	 5.48	 2.75	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26328	 1	 9.8	 3.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26329	 1	 7.78	 3.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26330	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26331	 1	 4.27	 1.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26332	 1	 9.94	 4.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26333	 1	 2.28	 0.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26334	 1	 8.61	 4.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26335	 1	 12.87	 5.86	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26336	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26337	 1	 10.14	 4.1	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26338	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26339	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26340	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26341	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26342	 1	 11.09	 4.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26343	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26344	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26345	 1	 4.53	 2.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26346	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26347	 1	 8.71	 3.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26348	 1	 3.25	 1.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26349	 1	 9.08	 4.05	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26350	 1	 61.97	 23.82	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26351	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26352	 1	 3.9	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26353	 1	 5.1	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26354	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26355	 1	 2.59	 1.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26356	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26357	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26358	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26359	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26360	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26361	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26362	 1	 30.53	 9.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26363	 1	 3.37	 1.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26364	 1	 6.02	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26365	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26366	 1	 3.38	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26367	 1	 1.44	 0.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26368	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26369	 1	 9.83	 3.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26370	 1	 10.03	 4.01	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26371	 1	 4.47	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26372	 1	 3.52	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26373	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26374	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26375	 1	 17.18	 3.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26376	 1	 28.33	 7.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26377	 1	 9.56	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26378	 1	 12.51	 2.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26379	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26380	 1	 7.18	 1.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26381	 1	 10.35	 2.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26382	 1	 13.69	 3.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26383	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26384	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26385	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26386	 1	 12.18	 5.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26387	 1	 9.12	 2.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26388	 1	 9.63	 2.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26389	 1	 6.54	 1.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26390	 1	 10.93	 2.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26391	 1	 4.49	 1.95	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26392	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26393	 1	 24.62	 5.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26394	 1	 8.06	 3.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26395	 1	 10.24	 3.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26396	 1	 2.87	 1.28	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26397	 1	 2.57	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26398	 1	 5.62	 2.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26399	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26400	 1	 10.92	 3.75	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26401	 1	 6.28	 3.03	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26402	 1	 18.19	 4.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26403	 1	 9.54	 3.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26404	 1	 10.08	 4.03	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26405	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26406	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26407	 1	 3.87	 1.65	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26408	 1	 9.08	 4.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26409	 1	 13.3	 4.23	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26410	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26411	 1	 7.51	 2.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26412	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26413	 1	 6.6	 3.37	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26414	 1	 5.07	 2.07	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26415	 1	 4.85	 2.39	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26416	 1	 4.01	 2.03	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26417	 1	 6.36	 2.96	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26418	 1	 6.96	 2.68	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26419	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26420	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26421	 1	 4.74	 2.45	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26422	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26423	 1	 19.71	 6.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26424	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26425	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26426	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26427	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26428	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26429	 1	 5.43	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26430	 1	 6.47	 2.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26431	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26432	 1	 9.81	 3.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26433	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26434	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26435	 1	 4.55	 1.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26436	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26437	 1	 4.01	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26438	 1	 10.73	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26439	 1	 13.19	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26440	 1	 6.61	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26441	 1	 6.96	 2.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26442	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26443	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26444	 1	 6.11	 2.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26445	 1	 7.59	 2.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26446	 1	 16.31	 5.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26447	 1	 15.35	 3.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26448	 1	 16.5	 5.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26449	 1	 8.1	 3.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26450	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26451	 1	 3.27	 1.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26452	 1	 3.96	 1.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26453	 1	 3.25	 1.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26454	 1	 6.54	 2.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26455	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26456	 1	 1.46	 0.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26457	 1	 4.17	 1.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26458	 1	 1.9	 0.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26459	 1	 1.74	 0.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26460	 1	 7.39	 3.14	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26461	 1	 6.09	 2.92	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26462	 1	 3.72	 1.65	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26463	 1	 30.11	 9.17	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26464	 1	 9.79	 3.93	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26465	 1	 5.88	 3.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26466	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26467	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26468	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26469	 1	 4.75	 2.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26470	 1	 3.0	 1.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26471	 1	 2.11	 0.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26472	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26473	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26474	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26475	 1	 5.3	 2.53	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26476	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26477	 1	 4.4	 1.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26478	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26479	 1	 6.52	 3.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26480	 1	 13.43	 5.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26481	 1	 7.27	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26482	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26483	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26484	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26485	 1	 2.99	 1.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26486	 1	 4.08	 2.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26487	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26488	 1	 4.46	 2.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26489	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26490	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26491	 1	 4.6	 2.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26492	 1	 5.3	 2.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26493	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26494	 1	 13.95	 4.68	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26495	 1	 5.76	 2.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26496	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26497	 1	 9.7	 3.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26498	 1	 6.83	 2.55	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26499	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26500	 1	 3.91	 1.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26501	 1	 6.79	 3.12	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26502	 1	 3.6	 1.91	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26503	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26504	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26505	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26506	 1	 4.49	 2.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26507	 1	 5.66	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26508	 1	 4.73	 2.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26509	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26510	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26511	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26512	 1	 6.41	 2.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26513	 1	 9.68	 4.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26514	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26515	 1	 16.26	 7.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26516	 1	 5.98	 2.3	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26517	 1	 10.21	 4.39	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26518	 1	 16.18	 6.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26519	 1	 1.57	 0.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26520	 1	 12.07	 3.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26521	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26522	 1	 17.6	 6.39	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26523	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26524	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26525	 1	 8.94	 3.89	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26526	 1	 10.35	 4.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26527	 1	 5.97	 2.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26528	 1	 20.3	 7.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26529	 1	 8.61	 3.81	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26530	 1	 8.66	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26531	 1	 1.61	 0.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26532	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26533	 1	 4.28	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26534	 1	 1.26	 0.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26535	 1	 3.53	 1.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26536	 1	 5.83	 2.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26537	 1	 8.32	 2.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26538	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26539	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26540	 1	 9.27	 3.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26541	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26542	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26543	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26544	 1	 3.59	 1.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26545	 1	 6.75	 3.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26546	 1	 3.31	 1.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26547	 1	 6.52	 3.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26548	 1	 2.08	 0.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26549	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26550	 1	 4.32	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26551	 1	 3.48	 1.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26552	 1	 5.67	 2.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26553	 1	 7.35	 2.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26554	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26555	 1	 6.49	 2.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26556	 1	 5.26	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26557	 1	 5.22	 2.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26558	 1	 4.46	 2.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26559	 1	 7.11	 1.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26560	 1	 3.35	 0.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26561	 1	 3.72	 0.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26562	 1	 6.81	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26563	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26564	 1	 6.99	 2.55	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26565	 1	 5.56	 2.35	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26566	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26567	 1	 75.05	 17.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26568	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26569	 1	 1.98	 0.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26570	 1	 5.75	 1.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26571	 1	 9.64	 2.25	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26572	 1	 2.22	 0.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26573	 1	 6.99	 1.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26574	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26575	 1	 12.87	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26576	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26577	 1	 7.64	 1.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26578	 1	 8.09	 1.87	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26579	 1	 4.08	 0.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26580	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26581	 1	 6.96	 1.61	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26582	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26583	 1	 3.74	 0.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26584	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26585	 1	 9.91	 2.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26586	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26587	 1	 10.05	 4.58	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26588	 1	 15.62	 5.53	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26589	 1	 6.81	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26590	 1	 55.35	 12.93	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26591	 1	 17.63	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26592	 1	 7.81	 1.76	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26593	 1	 2.46	 0.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26594	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26595	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26596	 1	 11.6	 2.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26597	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26598	 1	 9.56	 2.13	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26599	 1	 5.42	 1.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26600	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26601	 1	 6.72	 1.5	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26602	 1	 4.14	 1.76	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26603	 1	 5.59	 2.86	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26604	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26605	 1	 58.0	 23.63	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26606	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26607	 1	 3.24	 1.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26608	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26609	 1	 2.85	 1.28	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26610	 1	 5.26	 1.93	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26611	 1	 6.8	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26612	 1	 1.56	 0.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26613	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26614	 1	 7.04	 2.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26615	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26616	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26617	 1	 5.91	 2.45	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26618	 1	 2.44	 1.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26619	 1	 3.0	 1.38	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26620	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26621	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26622	 1	 5.05	 2.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26623	 1	 9.11	 3.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26624	 1	 3.49	 1.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26625	 1	 2.2	 0.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26626	 1	 7.21	 3.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26627	 1	 5.48	 2.25	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26628	 1	 22.08	 7.25	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26629	 1	 7.57	 3.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26630	 1	 4.44	 2.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26631	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26632	 1	 9.7	 4.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26633	 1	 8.34	 3.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26634	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26635	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26636	 1	 15.48	 5.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26637	 1	 3.49	 1.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26638	 1	 6.71	 3.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26639	 1	 3.04	 1.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26640	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26641	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26642	 1	 15.79	 6.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26643	 1	 4.36	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26644	 1	 31.74	 10.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26645	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26646	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26647	 1	 5.03	 2.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26648	 1	 4.17	 1.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26649	 1	 5.04	 2.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26650	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26651	 1	 10.24	 4.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26652	 1	 4.67	 2.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26653	 1	 7.1	 3.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26654	 1	 2.73	 1.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26655	 1	 4.68	 2.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26656	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26657	 1	 9.02	 3.92	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26658	 1	 6.9	 2.92	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26659	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26660	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26661	 1	 9.78	 3.75	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26662	 1	 3.88	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26663	 1	 9.49	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26664	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26665	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26666	 1	 2.41	 1.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26667	 1	 3.88	 1.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26668	 1	 15.08	 6.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26669	 1	 11.9	 4.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26670	 1	 29.33	 10.76	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26671	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26672	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26673	 1	 5.16	 2.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26674	 1	 10.42	 4.07	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26675	 1	 6.77	 2.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26676	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26677	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26678	 1	 4.76	 2.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26679	 1	 7.19	 2.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26680	 1	 12.45	 3.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26681	 1	 32.66	 9.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26682	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26683	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26684	 1	 2.42	 1.2	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26685	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26686	 1	 5.05	 1.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26687	 1	 11.43	 4.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26688	 1	 10.38	 4.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26689	 1	 8.17	 2.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26690	 1	 6.0	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26691	 1	 3.41	 1.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26692	 1	 1.99	 0.87	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26693	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26694	 1	 1.68	 0.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26695	 1	 4.62	 1.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26696	 1	 3.31	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26697	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26698	 1	 1.46	 0.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26699	 1	 8.11	 3.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26700	 1	 3.71	 1.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26701	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26702	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26703	 1	 7.59	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26704	 1	 6.68	 2.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26705	 1	 9.32	 2.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26706	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26707	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26708	 1	 1.86	 0.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26709	 1	 1.65	 0.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26710	 1	 1.0	 0.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26711	 1	 6.56	 2.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26712	 1	 1.85	 0.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26713	 1	 5.1	 1.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26714	 1	 5.88	 2.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26715	 1	 4.07	 1.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26716	 1	 3.55	 1.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26717	 1	 5.58	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26718	 1	 2.62	 1.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26719	 1	 3.0	 1.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26720	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26721	 1	 22.03	 9.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26722	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26723	 1	 3.72	 1.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26724	 1	 5.06	 1.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26725	 1	 3.07	 1.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26726	 1	 1.82	 0.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26727	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26728	 1	 13.52	 4.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26729	 1	 5.23	 1.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26730	 1	 6.67	 2.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26731	 1	 3.9	 1.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26732	 4	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26733	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26734	 1	 65.88	 16.98	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26735	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26736	 1	 79.71	 24.51	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26737	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26738	 1	 3.85	 1.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26739	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26740	 1	 2.99	 0.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26741	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26742	 1	 2.84	 1.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26743	 1	 5.77	 2.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26744	 1	 12.04	 4.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26745	 1	 2.91	 1.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26746	 1	 7.71	 3.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26747	 1	 5.11	 1.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26748	 1	 14.68	 5.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26749	 1	 8.04	 2.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26750	 1	 26.26	 9.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26751	 1	 2.5	 1.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26752	 1	 4.01	 1.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26753	 1	 1.92	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26754	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26755	 1	 10.01	 3.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26756	 1	 3.59	 1.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26757	 1	 4.68	 1.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26758	 1	 5.77	 2.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26759	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26760	 1	 7.36	 3.2	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26761	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26762	 1	 7.43	 3.28	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26763	 1	 5.56	 2.27	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26764	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26765	 1	 4.44	 1.98	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26766	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26767	 1	 6.86	 2.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26768	 1	 2.3	 0.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26769	 1	 6.11	 1.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26770	 1	 5.61	 1.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26771	 1	 4.77	 1.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26772	 1	 5.51	 1.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26773	 1	 12.53	 2.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26774	 1	 13.14	 2.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26775	 1	 13.89	 3.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26776	 1	 1.59	 0.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26777	 1	 10.34	 2.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26778	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26779	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26780	 1	 8.14	 3.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26781	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26782	 1	 13.79	 5.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26783	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26784	 1	 35.19	 10.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26785	 1	 4.33	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26786	 1	 12.38	 4.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26787	 1	 18.47	 4.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26788	 1	 10.11	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26789	 1	 2.52	 0.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26790	 1	 11.33	 3.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26791	 1	 6.23	 2.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26792	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26793	 1	 3.01	 1.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26794	 1	 13.43	 4.94	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26795	 1	 143.37	 44.17	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26796	 1	 3.99	 1.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26797	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26798	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26799	 1	 4.06	 1.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26800	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26801	 1	 5.29	 1.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26802	 1	 2.33	 1.04	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26803	 1	 6.65	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26804	 1	 7.31	 1.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26805	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26806	 1	 9.07	 2.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26807	 1	 8.24	 1.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26808	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26809	 1	 3.58	 1.44	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26810	 1	 4.8	 1.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26811	 1	 10.46	 2.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26812	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26813	 1	 4.7	 1.65	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26814	 1	 1.23	 0.56	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26815	 1	 0.92	 0.45	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26816	 1	 4.72	 1.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26817	 1	 1.36	 0.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26818	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26819	 1	 3.42	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26820	 1	 1.57	 0.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26821	 1	 3.11	 1.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26822	 1	 3.5	 1.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26823	 1	 1.84	 0.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26824	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26825	 1	 1.71	 0.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26826	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26827	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26828	 1	 3.78	 0.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26829	 1	 1.7	 0.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26830	 1	 1.75	 0.78	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26831	 1	 14.27	 3.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26832	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26833	 1	 2.88	 0.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26834	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26835	 1	 1.91	 0.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26836	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26837	 1	 5.31	 1.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26838	 1	 3.84	 0.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26839	 1	 6.25	 1.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26840	 1	 4.42	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26841	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26842	 1	 1.7	 0.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26843	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26844	 1	 5.68	 2.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26845	 1	 4.15	 1.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26846	 1	 4.13	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26847	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26848	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26849	 1	 1.24	 0.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26850	 1	 4.61	 1.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26851	 1	 14.31	 6.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26852	 1	 4.26	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26853	 1	 7.54	 1.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26854	 1	 5.49	 2.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26855	 1	 2.53	 1.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26856	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26857	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26858	 1	 19.52	 5.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26859	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26860	 1	 4.47	 1.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26861	 1	 14.05	 6.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26862	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26863	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26864	 1	 7.26	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26865	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26866	 1	 11.9	 2.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26867	 1	 4.37	 1.83	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26868	 1	 6.59	 1.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26869	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26870	 1	 15.3	 3.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26871	 1	 4.14	 1.67	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26872	 1	 8.44	 3.2	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26873	 1	 28.36	 8.2	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26874	 1	 4.99	 2.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26875	 1	 3.75	 1.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26876	 1	 7.27	 3.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26877	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26878	 1	 24.17	 11.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26879	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26880	 1	 4.68	 2.07	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26881	 1	 4.63	 1.91	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26882	 1	 20.63	 4.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26883	 1	 15.13	 3.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26884	 1	 1.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26885	 1	 13.84	 3.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26886	 1	 3.9	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26887	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26888	 1	 13.6	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26889	 1	 3.59	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26890	 1	 6.23	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26891	 1	 2.94	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26892	 1	 4.3	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26893	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26894	 1	 6.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26895	 1	 6.65	 1.51	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26896	 1	 16.49	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26897	 1	 61.98	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26898	 1	 9.01	 2.04	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26899	 1	 10.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26900	 1	 5.78	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26901	 1	 9.57	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26902	 1	 9.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26903	 1	 24.89	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26904	 1	 4.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26905	 1	 6.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26906	 1	 6.54	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26907	 1	 7.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26908	 1	 12.84	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26909	 1	 8.27	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26910	 1	 3.89	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26911	 1	 3.21	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26912	 1	 3.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26913	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26914	 1	 68.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26915	 1	 6.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26916	 1	 11.16	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26917	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26918	 1	 2.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26919	 1	 8.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26920	 1	 11.66	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26921	 1	 8.04	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26922	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26923	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26924	 1	 14.67	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26925	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26926	 1	 6.09	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26927	 1	 6.66	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26928	 1	 4.93	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26929	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26930	 1	 19.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26931	 1	 5.7	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26932	 1	 9.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26933	 1	 2.53	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26934	 1	 3.29	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26935	 1	 23.13	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26936	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26937	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26938	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26939	 1	 4.33	 1.94	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26940	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26941	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26942	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26943	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26944	 1	 3.23	 1.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26945	 1	 5.71	 1.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26946	 1	 11.86	 2.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26947	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26948	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26949	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26950	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26951	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26952	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26953	 1	 18.14	 4.12	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26954	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26955	 1	 8.06	 1.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26956	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26957	 1	 18.2	 4.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26958	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26959	 1	 8.75	 3.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26960	 1	 13.97	 3.22	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26961	 1	 6.96	 1.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26962	 1	 5.42	 1.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26963	 1	 9.3	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26964	 1	 13.11	 2.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26965	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26966	 1	 16.58	 3.77	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26967	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26968	 1	 8.51	 1.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26969	 1	 9.83	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26970	 1	 24.91	 5.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26971	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26972	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26973	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26974	 1	 5.58	 1.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26975	 1	 19.36	 7.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26976	 1	 10.73	 4.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26977	 1	 5.0	 2.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26978	 1	 4.68	 1.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26979	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26980	 1	 2.36	 1.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26981	 1	 2.39	 1.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26982	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26983	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26984	 1	 1.79	 0.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26985	 1	 2.54	 1.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26986	 1	 4.09	 1.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26987	 1	 4.02	 1.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26988	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26989	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26990	 1	 4.12	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26991	 1	 1.53	 0.58	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26992	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26993	 1	 10.72	 3.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26994	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26995	 1	 107.33	 40.3	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26996	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26997	 1	 12.67	 4.25	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26998	 1	 5.01	 1.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26999	 1	 9.3	 2.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27000	 1	 4.69	 1.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27001	 1	 7.58	 3.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27002	 1	 7.3	 2.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27003	 1	 6.81	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27004	 1	 3.8	 1.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27005	 1	 6.64	 2.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27006	 1	 2.88	 1.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27007	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27008	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27009	 1	 6.85	 2.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27010	 1	 10.86	 3.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27011	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27012	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27013	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27014	 1	 8.22	 3.39	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27015	 1	 4.99	 2.34	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27016	 1	 4.39	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27017	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27018	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27019	 1	 2.92	 1.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27020	 1	 3.52	 1.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27021	 1	 2.55	 1.14	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27022	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27023	 1	 4.49	 1.89	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27024	 1	 10.37	 3.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27025	 1	 9.86	 3.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27026	 1	 6.62	 3.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27027	 1	 2.6	 1.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27028	 1	 8.37	 3.28	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27029	 1	 1.56	 0.61	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27030	 1	 3.29	 1.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27031	 1	 5.48	 2.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27032	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27033	 1	 3.38	 1.39	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27034	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27035	 1	 5.4	 1.43	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27036	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27037	 1	 2.44	 1.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27038	 1	 2.77	 1.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27039	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27040	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27041	 1	 2.23	 1.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27042	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27043	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27044	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27045	 1	 2.01	 0.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27046	 1	 79.79	 23.94	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27047	 1	 4.62	 2.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27048	 1	 1.82	 0.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27049	 1	 2.03	 0.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27050	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27051	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27052	 1	 8.75	 3.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27053	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27054	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27055	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27056	 1	 2.86	 1.33	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27057	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27058	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27059	 1	 22.55	 8.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27060	 1	 7.74	 3.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27061	 1	 8.16	 3.66	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27062	 1	 5.93	 2.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27063	 1	 16.35	 7.31	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27064	 1	 6.35	 2.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27065	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27066	 1	 58.85	 21.04	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27067	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27068	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27069	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27070	 1	 8.01	 3.04	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27071	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27072	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27073	 1	 21.06	 7.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27074	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27075	 1	 15.13	 5.62	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27076	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27077	 1	 7.3	 3.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27078	 1	 4.54	 2.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27079	 1	 10.05	 3.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27080	 1	 3.72	 1.59	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27081	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27082	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27083	 1	 2.71	 1.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27084	 1	 10.33	 4.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27085	 1	 1.89	 0.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27086	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27087	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27088	 1	 6.1	 2.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27089	 1	 5.78	 2.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27090	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27091	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27092	 1	 8.2	 2.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27093	 1	 74.79	 23.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27094	 1	 23.37	 7.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27095	 1	 4.07	 0.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27096	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27097	 1	 23.72	 8.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27098	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27099	 1	 1.3	 0.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27100	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27101	 1	 9.55	 4.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27102	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27103	 1	 22.66	 5.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27104	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27105	 1	 5.92	 1.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27106	 1	 2.5	 0.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27107	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27108	 1	 10.39	 4.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27109	 1	 4.12	 1.79	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27110	 1	 18.83	 7.25	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27111	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27112	 1	 6.67	 1.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27113	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27114	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27115	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27116	 1	 6.54	 1.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27117	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27118	 1	 6.06	 1.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27119	 1	 4.63	 1.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27120	 1	 6.61	 1.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27121	 1	 15.03	 3.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27122	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27123	 1	 5.15	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27124	 1	 20.53	 4.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27125	 1	 14.79	 6.77	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27126	 1	 12.0	 5.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27127	 1	 4.4	 1.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27128	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27129	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27130	 1	 4.55	 1.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27131	 1	 0.24	 0.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27132	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27133	 1	 12.94	 4.11	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27134	 1	 4.39	 1.76	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27135	 1	 3.74	 1.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27136	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27137	 1	 7.35	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27138	 1	 18.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27139	 1	 14.95	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27140	 1	 5.94	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27141	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27142	 1	 9.09	 3.33	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27143	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27144	 1	 13.58	 5.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27145	 1	 8.41	 3.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27146	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27147	 1	 8.98	 4.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27148	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27149	 1	 4.01	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27150	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27151	 1	 11.44	 3.41	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27152	 1	 3.29	 1.61	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27153	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27154	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27155	 1	 6.84	 3.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27156	 1	 12.57	 3.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27157	 1	 8.74	 4.22	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27158	 1	 9.24	 3.67	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27159	 1	 10.62	 4.14	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27160	 1	 6.94	 3.26	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27161	 1	 7.1	 3.45	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27162	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	27163	 1	 3.6	 1.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27164	 1	 2.32	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27165	 1	 1.85	 0.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27166	 1	 1.64	 0.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27167	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27168	 1	 2.48	 1.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27169	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27170	 1	 3.2	 1.54	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27171	 1	 4.08	 1.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27172	 1	 4.17	 1.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27173	 1	 22.37	 8.81	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27174	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27175	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27176	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27177	 1	 3.52	 1.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27178	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27179	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27180	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27181	 1	 6.4	 2.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27182	 1	 22.35	 8.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27183	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27184	 1	 11.27	 3.73	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27185	 1	 12.27	 5.86	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27186	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27187	 1	 10.83	 4.11	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27188	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27189	 1	 5.83	 2.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27190	 1	 5.17	 2.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27191	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27192	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27193	 1	 7.58	 3.8	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27194	 1	 18.4	 6.65	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27195	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27196	 1	 6.59	 2.85	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27197	 1	 16.14	 6.09	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27198	 1	 10.06	 3.97	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27199	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27200	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27201	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27202	 1	 21.64	 9.61	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27203	 1	 3.48	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27204	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27205	 1	 5.99	 2.74	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27206	 1	 4.33	 2.3	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27207	 1	 5.41	 1.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27208	 1	 12.83	 2.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27209	 1	 20.47	 4.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27210	 1	 11.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27211	 1	 37.02	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27212	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27213	 1	 10.65	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27214	 1	 15.19	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27215	 1	 7.95	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27216	 1	 3.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27217	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27218	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27219	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27220	 1	 3.73	 1.56	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27221	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27222	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27223	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27224	 1	 12.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27225	 1	 10.3	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27226	 1	 8.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27227	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27228	 1	 12.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27229	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27230	 1	 4.01	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27231	 1	 11.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27232	 1	 6.47	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27233	 1	 9.66	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27234	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27235	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27236	 1	 12.7	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27237	 1	 10.31	 3.85	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27238	 1	 11.19	 4.58	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27239	 1	 5.91	 2.58	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27240	 1	 9.81	 3.97	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27241	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27242	 1	 4.84	 1.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27243	 1	 2.68	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27244	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27245	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27246	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27247	 1	 8.82	 3.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27248	 1	 13.91	 4.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27249	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27250	 1	 3.33	 1.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27251	 1	 3.46	 1.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27252	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27253	 1	 4.76	 1.91	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27254	 1	 26.64	 8.51	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27255	 1	 14.9	 3.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27256	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27257	 1	 9.38	 3.61	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27258	 1	 8.22	 3.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27259	 1	 8.78	 3.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27260	 1	 7.64	 3.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27261	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27262	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27263	 1	 5.6	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27264	 1	 10.3	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27265	 1	 5.5	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27266	 1	 12.79	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27267	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27268	 1	 2.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27269	 1	 3.65	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27270	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27271	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27272	 1	 7.45	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27273	 1	 12.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27274	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27275	 1	 4.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27276	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27277	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27278	 1	 11.81	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27279	 1	 5.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27280	 1	 14.53	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27281	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27282	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27283	 1	 15.47	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27284	 1	 6.34	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27285	 1	 12.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27286	 1	 4.9	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27287	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27288	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27289	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27290	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27291	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27292	 1	 6.53	 2.32	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27293	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27294	 1	 4.32	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27295	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27296	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27297	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27298	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27299	 1	 6.93	 3.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27300	 1	 2.29	 1.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27301	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27302	 1	 4.33	 1.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27303	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27304	 1	 6.31	 2.99	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27305	 1	 7.52	 3.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27306	 1	 6.14	 2.86	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27307	 1	 4.92	 2.22	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27308	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27309	 1	 10.76	 3.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27310	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27311	 1	 7.76	 2.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27312	 1	 11.12	 2.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27313	 1	 5.27	 1.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27314	 1	 3.36	 1.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27315	 1	 9.68	 2.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27316	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27317	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27318	 1	 7.23	 2.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27319	 1	 5.35	 1.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27320	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27321	 1	 8.43	 1.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27322	 1	 12.38	 2.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27323	 1	 5.2	 2.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27324	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27325	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27326	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27327	 1	 3.08	 1.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27328	 1	 5.27	 2.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27329	 1	 4.81	 2.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27330	 1	 50.29	 10.98	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27331	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	27332	 1	 4.04	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27333	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27334	 1	 2.32	 1.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27335	 1	 2.36	 1.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27336	 1	 6.52	 3.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27337	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27338	 1	 5.55	 2.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27339	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27340	 1	 4.97	 2.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27341	 1	 3.84	 1.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27342	 1	 6.25	 2.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27343	 1	 5.76	 1.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27344	 1	 10.41	 2.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27345	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27346	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27347	 1	 9.42	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27348	 1	 17.23	 3.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27349	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27350	 1	 7.58	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27351	 1	 26.31	 5.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27352	 1	 15.13	 3.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27353	 1	 4.77	 1.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27354	 1	 4.27	 0.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27355	 1	 5.41	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27356	 1	 6.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27357	 1	 9.36	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27358	 1	 10.97	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27359	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27360	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27361	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27362	 1	 67.78	 15.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27363	 1	 5.42	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27364	 1	 7.51	 1.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27365	 1	 9.36	 2.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27366	 1	 12.47	 2.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27367	 1	 4.13	 1.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27368	 1	 12.14	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27369	 1	 2.51	 0.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27370	 1	 4.49	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27371	 1	 4.36	 1.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27372	 1	 3.68	 1.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27373	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27374	 1	 5.88	 2.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27375	 1	 6.36	 2.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27376	 1	 6.58	 2.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27377	 1	 7.57	 2.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27378	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27379	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27380	 1	 3.25	 1.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27381	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27382	 1	 23.2	 7.8	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27383	 1	 27.53	 10.14	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27384	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27385	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27386	 1	 4.72	 2.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27387	 1	 1.98	 0.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27388	 1	 15.08	 5.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27389	 1	 7.35	 3.36	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27390	 1	 3.89	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27391	 1	 28.58	 9.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27392	 1	 13.51	 4.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27393	 1	 19.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27394	 1	 5.45	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27395	 1	 4.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27396	 1	 6.34	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27397	 1	 10.25	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27398	 1	 4.94	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27399	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27400	 1	 2.54	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27401	 1	 13.87	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27402	 1	 7.07	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27403	 1	 7.24	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27404	 1	 5.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27405	 1	 7.88	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27406	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27407	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27408	 1	 5.87	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27409	 1	 3.5	 1.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27410	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27411	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27412	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27413	 1	 6.52	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27414	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27415	 1	 16.02	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27416	 1	 12.17	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27417	 1	 2.26	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27418	 1	 6.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27419	 1	 5.5	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27420	 1	 11.24	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27421	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27422	 1	 2.05	 0.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27423	 1	 17.26	 6.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27424	 1	 6.8	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27425	 1	 5.8	 2.65	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27426	 1	 5.74	 2.67	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27427	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27428	 1	 4.76	 1.84	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27429	 1	 24.08	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27430	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27431	 1	 4.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27432	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27433	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27434	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27435	 1	 5.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27436	 1	 13.66	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27437	 1	 2.67	 1.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27438	 1	 2.88	 1.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27439	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27440	 1	 4.32	 2.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27441	 1	 3.7	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27442	 1	 7.18	 2.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27443	 1	 5.06	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27444	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27445	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27446	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27447	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27448	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27449	 1	 3.83	 1.71	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27450	 1	 26.5	 10.46	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27451	 1	 25.35	 9.18	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27452	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27453	 1	 4.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27454	 1	 1.41	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27455	 1	 1.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27456	 1	 2.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27457	 1	 4.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27458	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27459	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27460	 1	 6.7	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27461	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27462	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27463	 1	 8.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27464	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27465	 1	 1.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27466	 1	 2.75	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27467	 1	 8.61	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27468	 1	 9.69	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27469	 1	 14.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27470	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27471	 1	 6.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27472	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27473	 1	 66.91	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27474	 1	 3.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27475	 1	 2.16	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27476	 1	 5.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27477	 1	 5.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27478	 1	 4.25	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27479	 1	 6.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27480	 1	 8.57	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27481	 1	 1.5	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27482	 1	 1.74	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27483	 1	 6.16	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27484	 1	 3.1	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27485	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27486	 1	 3.93	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27487	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27488	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27489	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27490	 1	 5.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27491	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27492	 1	 5.8	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27493	 1	 3.49	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27494	 1	 1.56	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27495	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27496	 1	 7.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27497	 1	 3.68	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27498	 1	 2.93	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27499	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27500	 1	 5.67	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27501	 1	 4.19	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27502	 1	 1.98	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27503	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27504	 1	 5.59	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27505	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27506	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27507	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27508	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27509	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27510	 1	 35.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27511	 1	 5.9	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27512	 1	 13.61	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27513	 1	 13.24	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27514	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27515	 1	 6.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27516	 1	 10.78	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27517	 1	 13.81	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27518	 1	 13.98	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27519	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27520	 1	 4.3	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27521	 1	 2.52	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27522	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27523	 1	 5.29	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27524	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27525	 1	 5.68	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27526	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27527	 1	 4.41	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27528	 1	 8.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27529	 1	 5.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27530	 1	 11.73	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27531	 1	 8.11	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27532	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27533	 1	 4.7	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27534	 1	 4.52	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27535	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27536	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27537	 1	 7.76	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27538	 1	 19.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27539	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27540	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27541	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27542	 1	 2.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27543	 1	 7.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27544	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27545	 1	 12.56	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27546	 1	 5.17	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27547	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27548	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27549	 1	 5.1	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27550	 1	 5.14	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27551	 1	 9.73	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27552	 1	 27.78	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27553	 1	 7.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27554	 1	 12.37	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27555	 1	 9.54	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27556	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27557	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27558	 1	 7.52	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27559	 1	 11.93	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27560	 1	 12.29	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27561	 1	 61.88	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27562	 1	 6.46	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27563	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27564	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27565	 1	 7.13	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27566	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27567	 1	 8.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27568	 1	 11.69	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27569	 1	 11.17	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27570	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27571	 1	 7.96	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27572	 1	 10.79	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27573	 1	 10.6	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27574	 1	 3.68	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27575	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27576	 1	 1.46	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27577	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27578	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27579	 1	 5.11	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27580	 1	 4.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27581	 1	 2.79	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27582	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27583	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27584	 1	 12.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27585	 1	 8.74	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27586	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27587	 1	 5.12	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27588	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27589	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27590	 1	 19.3	 4.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27591	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27592	 1	 5.52	 1.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27593	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27594	 1	 3.34	 0.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27595	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27596	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27597	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27598	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27599	 1	 3.47	 0.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27600	 1	 8.92	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27601	 1	 6.07	 2.63	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27602	 1	 4.82	 1.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27603	 1	 6.27	 1.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27604	 1	 4.86	 1.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27605	 1	 3.82	 0.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27606	 1	 9.13	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27607	 1	 6.05	 1.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27608	 1	 3.61	 0.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27609	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27610	 1	 7.04	 1.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27611	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27612	 1	 6.76	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27613	 1	 4.13	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27614	 1	 7.43	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27615	 1	 7.77	 1.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27616	 1	 7.44	 1.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27617	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27618	 1	 10.2	 2.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27619	 1	 4.37	 1.01	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27620	 1	 1.96	 0.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27621	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27622	 1	 7.23	 1.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27623	 1	 2.72	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27624	 1	 6.32	 1.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27625	 1	 6.35	 1.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27626	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27627	 1	 8.08	 1.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27628	 1	 3.98	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27629	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27630	 1	 10.11	 3.6	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27631	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27632	 1	 6.12	 1.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27633	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27634	 1	 6.24	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27635	 1	 14.09	 3.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27636	 1	 9.11	 2.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27637	 1	 27.41	 6.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27638	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27639	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27640	 1	 5.22	 1.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27641	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27642	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27643	 1	 9.87	 3.62	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27644	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27645	 1	 9.52	 3.13	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27646	 1	 10.63	 3.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27647	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27648	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27649	 1	 8.48	 3.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27650	 1	 24.47	 9.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27651	 1	 6.58	 2.75	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27652	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27653	 1	 36.19	 7.99	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27654	 1	 6.82	 2.59	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27655	 1	 19.47	 6.33	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27656	 1	 2.89	 1.38	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27657	 1	 8.61	 3.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27658	 1	 5.28	 2.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27659	 1	 22.38	 7.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27660	 1	 5.95	 2.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27661	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27662	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27663	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27664	 1	 4.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27665	 1	 5.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27666	 1	 87.39	 19.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27667	 1	 7.06	 1.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27668	 1	 2.52	 0.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27669	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27670	 1	 20.81	 4.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27671	 1	 8.62	 1.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27672	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27673	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27674	 1	 7.14	 3.29	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27675	 1	 10.58	 4.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27676	 1	 3.28	 1.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27677	 1	 13.34	 5.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27678	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27679	 1	 3.5	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27680	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27681	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27682	 1	 4.21	 1.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27683	 1	 5.35	 2.74	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27684	 1	 7.6	 3.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27685	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27686	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27687	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27688	 1	 10.85	 3.3	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27689	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27690	 1	 11.94	 5.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27691	 1	 8.2	 3.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27692	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27693	 1	 13.86	 5.99	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27694	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27695	 1	 12.57	 5.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27696	 1	 8.92	 4.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27697	 1	 5.7	 2.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27698	 1	 8.09	 3.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27699	 1	 10.91	 3.98	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27700	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27701	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27702	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27703	 1	 5.0	 2.3	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27704	 1	 28.92	 10.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27705	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27706	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27707	 1	 12.63	 4.81	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27708	 1	 8.06	 3.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27709	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27710	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27711	 1	 7.98	 3.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27712	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27713	 1	 29.57	 12.29	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27714	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27715	 1	 4.75	 2.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27716	 1	 5.77	 2.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27717	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27718	 1	 18.67	 5.61	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27719	 1	 16.14	 4.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27720	 1	 7.31	 2.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27721	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27722	 1	 67.43	 22.35	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27723	 1	 5.72	 1.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27724	 1	 7.04	 3.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27725	 1	 4.64	 2.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27726	 1	 7.5	 3.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27727	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27728	 1	 8.18	 4.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27729	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27730	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27731	 1	 6.48	 3.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27732	 1	 8.51	 3.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27733	 1	 9.48	 2.74	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27734	 1	 6.08	 2.91	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27735	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27736	 1	 3.81	 1.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27737	 1	 3.03	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27738	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27739	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27740	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27741	 1	 19.89	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27742	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27743	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27744	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27745	 1	 22.36	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27746	 1	 7.74	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27747	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27748	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27749	 1	 4.0	 1.86	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27750	 1	 6.47	 2.48	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27751	 1	 4.52	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27752	 1	 2.89	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27753	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27754	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27755	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27756	 1	 2.95	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27757	 1	 5.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27758	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27759	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27760	 1	 3.49	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27761	 1	 13.35	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27762	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27763	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27764	 1	 3.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27765	 1	 8.47	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27766	 1	 4.14	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27767	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27768	 1	 8.05	 1.82	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27769	 1	 11.71	 3.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27770	 1	 24.76	 5.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27771	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27772	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27773	 1	 14.21	 5.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27774	 1	 3.61	 1.51	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27775	 1	 5.29	 1.95	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27776	 1	 41.28	 16.23	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27777	 1	 20.91	 5.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27778	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27779	 1	 6.28	 2.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27780	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27781	 1	 5.45	 2.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27782	 1	 6.08	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27783	 1	 20.85	 8.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27784	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27785	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27786	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27787	 1	 4.81	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27788	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27789	 1	 9.01	 3.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27790	 1	 5.78	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27791	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27792	 1	 6.5	 2.99	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27793	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27794	 1	 6.34	 2.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27795	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27796	 1	 5.79	 2.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27797	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27798	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27799	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27800	 1	 19.05	 4.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27801	 1	 9.98	 2.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27802	 1	 14.94	 3.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27803	 1	 28.78	 8.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27804	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27805	 1	 17.49	 4.01	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27806	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27807	 1	 21.19	 4.77	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27808	 1	 15.05	 3.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27809	 1	 9.54	 2.14	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27810	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27811	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27812	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27813	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27814	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27815	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27816	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27817	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27818	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27819	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27820	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27821	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27822	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27823	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27824	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27825	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27826	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27827	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27828	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27829	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27830	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27831	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27832	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27833	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27834	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27835	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27836	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27837	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27838	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27839	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27840	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27841	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27842	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27843	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27844	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27845	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27846	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27847	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27848	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27849	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27850	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27851	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27852	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27853	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27854	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27855	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27856	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27857	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27858	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27859	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27860	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27861	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27862	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27863	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27864	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27865	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27866	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27867	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27868	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27869	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27870	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27871	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27872	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27873	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27874	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27875	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27876	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27877	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27878	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27879	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27880	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27881	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27882	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27883	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27884	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27885	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27886	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27887	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27888	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27889	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27890	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27891	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27892	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27893	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27894	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27895	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27896	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27897	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27898	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27899	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27900	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27901	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27902	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27903	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27904	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27905	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27906	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27907	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27908	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27909	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27910	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27911	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27912	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27913	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27914	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27915	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27916	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27917	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27918	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27919	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27920	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27921	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27922	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27923	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27924	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27925	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27926	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27927	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27928	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27929	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27930	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27931	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27932	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27933	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27934	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27935	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27936	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27937	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27938	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27939	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27940	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27941	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27942	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27943	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27944	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27945	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27946	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27947	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27948	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27949	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27950	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27951	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27952	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27953	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27954	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27955	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27956	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27957	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27958	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27959	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27960	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27961	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27962	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27963	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27964	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27965	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27966	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27967	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27968	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27969	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27970	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27971	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27972	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27973	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27974	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27975	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27976	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27977	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27978	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27979	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27980	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27981	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27982	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27983	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27984	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27985	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27986	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27987	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27988	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27989	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	27990	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27991	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27992	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27993	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27994	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27995	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27996	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27997	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27998	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	27999	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28000	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28001	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28002	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28003	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28004	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28005	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28006	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28007	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28008	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28009	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28010	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28011	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28012	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28013	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28014	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28015	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28016	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28017	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28018	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28019	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28020	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28021	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28022	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28023	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28024	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28025	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28026	 1	 10.73	 6.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28027	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28028	 1	 17.58	 9.18	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28029	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28030	 1	 13.29	 7.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28031	 1	 7.49	 3.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28032	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28033	 1	 10.99	 5.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28034	 1	 5.87	 3.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28035	 1	 12.1	 6.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28036	 1	 3.4	 2.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28037	 1	 9.32	 5.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28038	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28039	 1	 7.74	 4.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28040	 1	 4.41	 2.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28041	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28042	 1	 6.64	 3.37	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28043	 1	 6.63	 3.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28044	 1	 4.76	 2.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28045	 1	 7.73	 4.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28046	 1	 2.54	 1.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28047	 1	 6.08	 3.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28048	 1	 7.54	 4.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28049	 1	 3.18	 1.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28050	 1	 13.28	 5.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28051	 1	 2.35	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28052	 1	 13.05	 7.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28053	 1	 11.47	 6.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28054	 1	 9.74	 5.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28055	 1	 11.29	 6.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28056	 1	 10.73	 5.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28057	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28058	 1	 11.82	 5.06	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28059	 1	 18.77	 11.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28060	 1	 8.02	 4.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28061	 1	 3.15	 1.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28062	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28063	 1	 20.05	 7.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28064	 1	 5.66	 3.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28065	 1	 54.56	 31.65	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28066	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28067	 1	 2.79	 1.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28068	 1	 1.33	 0.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28069	 1	 9.9	 4.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28070	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28071	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28072	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28073	 1	 4.94	 2.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28074	 1	 3.07	 1.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28075	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28076	 1	 7.56	 3.84	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28077	 1	 8.87	 4.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28078	 1	 3.03	 1.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28079	 1	 17.65	 7.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28080	 1	 10.14	 4.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28081	 1	 2.64	 1.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28082	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28083	 1	 14.67	 6.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28084	 1	 12.82	 2.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28085	 1	 8.31	 4.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28086	 1	 10.23	 4.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28087	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28088	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28089	 1	 10.39	 6.55	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28090	 1	 14.92	 7.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28091	 1	 1.39	 0.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28092	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28093	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28094	 1	 4.73	 2.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28095	 1	 6.03	 3.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28096	 1	 4.35	 2.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28097	 1	 9.3	 5.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28098	 1	 23.61	 8.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28099	 1	 7.95	 4.27	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28100	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28101	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28102	 1	 19.63	 9.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28103	 1	 9.23	 5.59	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28104	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28105	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28106	 1	 15.86	 7.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28107	 1	 20.85	 9.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28108	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28109	 1	 8.51	 4.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28110	 1	 15.93	 8.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28111	 1	 6.5	 3.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28112	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28113	 1	 15.01	 7.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28114	 1	 6.66	 3.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28115	 1	 10.42	 5.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28116	 1	 6.17	 3.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28117	 1	 9.54	 5.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28118	 1	 9.04	 4.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28119	 1	 8.88	 4.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28120	 1	 1.4	 0.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28121	 1	 1.87	 0.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28122	 1	 4.33	 1.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28123	 1	 3.48	 1.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28124	 1	 7.11	 4.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28125	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28126	 1	 5.4	 2.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28127	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28128	 1	 6.73	 3.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28129	 1	 20.19	 11.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28130	 1	 28.77	 13.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28131	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28132	 1	 11.01	 2.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28133	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28134	 1	 11.62	 5.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28135	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28136	 1	 6.44	 3.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28137	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28138	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28139	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28140	 1	 9.97	 4.82	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28141	 1	 5.42	 3.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28142	 1	 5.76	 3.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28143	 1	 14.43	 8.91	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28144	 1	 10.85	 5.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28145	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28146	 1	 16.69	 9.13	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28147	 1	 8.25	 5.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28148	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28149	 1	 12.24	 5.79	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28150	 1	 8.07	 4.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28151	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28152	 1	 5.74	 2.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28153	 1	 5.1	 3.29	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28154	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28155	 1	 14.26	 7.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28156	 1	 8.95	 4.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28157	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28158	 1	 9.32	 4.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28159	 1	 5.15	 2.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28160	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28161	 1	 9.3	 4.69	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28162	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28163	 1	 4.81	 2.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28164	 1	 13.74	 8.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28165	 1	 6.82	 3.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28166	 1	 10.42	 5.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28167	 1	 7.65	 3.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28168	 1	 6.97	 3.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28169	 1	 6.02	 3.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28170	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28171	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28172	 1	 18.36	 9.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28173	 1	 5.61	 2.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28174	 1	 14.05	 8.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28175	 1	 9.01	 5.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28176	 1	 8.74	 5.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28177	 1	 5.12	 2.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28178	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28179	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28180	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28181	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28182	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28183	 1	 5.48	 2.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28184	 1	 3.75	 1.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28185	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28186	 1	 6.23	 3.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28187	 1	 10.74	 5.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28188	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28189	 1	 23.8	 8.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28190	 1	 3.18	 1.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28191	 1	 8.79	 5.23	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28192	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28193	 1	 8.19	 4.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28194	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28195	 1	 4.83	 2.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28196	 1	 7.14	 3.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28197	 1	 3.34	 1.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28198	 1	 5.02	 2.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28199	 1	 2.25	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28200	 1	 5.69	 3.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28201	 1	 5.51	 3.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28202	 1	 8.47	 3.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28203	 1	 5.45	 3.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28204	 1	 9.43	 4.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28205	 1	 5.38	 2.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28206	 1	 5.51	 2.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28207	 1	 8.84	 4.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28208	 1	 1.65	 0.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28209	 1	 7.43	 4.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28210	 1	 1.93	 1.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28211	 1	 2.6	 1.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28212	 1	 5.48	 3.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28213	 1	 3.83	 1.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28214	 1	 3.95	 2.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28215	 1	 5.33	 3.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28216	 1	 2.87	 1.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28217	 1	 3.43	 1.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28218	 1	 6.55	 3.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28219	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28220	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28221	 1	 3.55	 1.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28222	 1	 7.91	 3.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28223	 1	 9.81	 4.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28224	 1	 3.1	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28225	 1	 6.39	 3.66	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28226	 1	 6.62	 4.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28227	 1	 15.38	 8.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28228	 1	 6.77	 3.63	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28229	 1	 11.09	 6.15	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28230	 1	 30.22	 18.02	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28231	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28232	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28233	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28234	 1	 10.72	 5.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28235	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28236	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28237	 1	 14.13	 6.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28238	 1	 10.13	 5.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28239	 1	 7.98	 3.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28240	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28241	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28242	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28243	 1	 10.62	 5.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28244	 1	 199.6	 88.73	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28245	 1	 9.18	 2.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28246	 1	 9.61	 2.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28247	 1	 2.67	 0.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28248	 1	 9.48	 2.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28249	 1	 4.04	 0.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28250	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28251	 1	 5.22	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28252	 1	 10.66	 2.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28253	 1	 6.19	 1.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28254	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28255	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28256	 1	 9.34	 2.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28257	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28258	 1	 5.92	 1.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28259	 1	 13.72	 3.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28260	 1	 4.5	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28261	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28262	 1	 8.39	 1.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28263	 1	 9.97	 2.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28264	 1	 7.62	 1.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28265	 1	 5.17	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28266	 1	 7.69	 1.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28267	 1	 9.5	 2.27	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28268	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28269	 1	 5.88	 1.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28270	 1	 8.47	 1.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28271	 1	 5.74	 1.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28272	 1	 7.31	 1.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28273	 1	 7.04	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28274	 1	 12.67	 2.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28275	 1	 18.39	 4.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28276	 1	 2.78	 0.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28277	 1	 5.42	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28278	 1	 2.46	 0.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28279	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28280	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28281	 1	 8.04	 1.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28282	 1	 7.7	 1.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28283	 1	 11.66	 2.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28284	 1	 5.34	 1.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28285	 1	 6.67	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28286	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28287	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28288	 1	 3.1	 0.73	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28289	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28290	 1	 13.61	 3.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28291	 1	 9.07	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28292	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28293	 1	 5.72	 1.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28294	 1	 6.64	 1.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28295	 1	 7.5	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28296	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28297	 1	 7.01	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28298	 1	 7.56	 1.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28299	 1	 3.99	 0.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28300	 1	 10.45	 2.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28301	 1	 8.36	 1.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28302	 1	 9.3	 2.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28303	 1	 2.15	 0.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28304	 1	 4.97	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28305	 1	 4.68	 1.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28306	 1	 6.93	 1.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28307	 1	 4.8	 1.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28308	 1	 11.08	 2.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28309	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28310	 1	 6.1	 1.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28311	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28312	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28313	 1	 8.84	 2.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28314	 1	 8.47	 1.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28315	 1	 4.61	 1.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28316	 1	 9.0	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28317	 1	 5.31	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28318	 1	 4.97	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28319	 1	 6.49	 1.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28320	 1	 9.76	 2.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28321	 1	 7.78	 1.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28322	 1	 7.7	 1.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28323	 1	 3.56	 0.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28324	 1	 13.57	 3.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28325	 1	 5.29	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28326	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28327	 1	 4.86	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28328	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28329	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28330	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28331	 1	 5.86	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28332	 1	 6.04	 1.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28333	 1	 5.8	 1.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28334	 1	 4.09	 0.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28335	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28336	 1	 11.64	 2.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28337	 1	 11.95	 2.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28338	 1	 6.87	 1.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28339	 1	 8.73	 2.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28340	 1	 3.82	 0.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28341	 1	 10.34	 2.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28342	 1	 3.54	 0.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28343	 1	 6.01	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28344	 1	 7.25	 1.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28345	 1	 2.25	 0.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28346	 1	 3.88	 0.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28347	 1	 3.03	 0.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28348	 1	 1.53	 0.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28349	 1	 3.34	 0.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28350	 1	 6.71	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28351	 1	 3.41	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28352	 1	 6.09	 1.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28353	 1	 6.24	 1.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28354	 1	 12.58	 2.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28355	 1	 2.57	 0.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28356	 1	 13.4	 3.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28357	 1	 4.48	 1.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28358	 1	 3.61	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28359	 1	 6.99	 1.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28360	 1	 4.89	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28361	 1	 3.53	 0.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28362	 1	 3.58	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28363	 1	 5.93	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28364	 1	 6.38	 1.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28365	 1	 5.76	 1.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28366	 1	 6.56	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28367	 1	 4.14	 1.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28368	 1	 4.55	 2.57	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28369	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28370	 1	 9.86	 5.09	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28371	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28372	 1	 8.18	 1.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28373	 1	 12.46	 3.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28374	 1	 7.86	 1.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28375	 1	 12.12	 2.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28376	 1	 2.96	 0.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28377	 1	 4.66	 1.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28378	 1	 4.58	 1.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28379	 1	 4.01	 0.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28380	 1	 3.66	 0.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28381	 1	 4.04	 0.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28382	 1	 8.72	 2.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28383	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28384	 1	 1.63	 0.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28385	 1	 9.89	 2.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28386	 1	 9.02	 4.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28387	 1	 7.22	 3.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28388	 1	 14.83	 3.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28389	 1	 11.69	 2.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28390	 1	 1.66	 1.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28391	 1	 9.01	 4.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28392	 1	 6.97	 3.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28393	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28394	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28395	 1	 6.44	 1.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28396	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28397	 1	 3.01	 0.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28398	 1	 15.09	 3.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28399	 1	 10.06	 5.99	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28400	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28401	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28402	 1	 5.63	 3.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28403	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28404	 1	 4.21	 1.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28405	 1	 4.98	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28406	 1	 8.26	 1.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28407	 1	 4.26	 2.23	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28408	 1	 4.06	 1.92	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28409	 1	 4.9	 2.37	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28410	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28411	 1	 10.38	 2.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28412	 1	 5.29	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28413	 1	 6.33	 1.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28414	 1	 5.62	 1.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28415	 1	 7.02	 1.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28416	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28417	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28418	 1	 8.99	 2.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28419	 1	 4.48	 1.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28420	 1	 5.17	 1.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28421	 1	 10.1	 2.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28422	 1	 3.84	 0.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28423	 1	 3.18	 0.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28424	 1	 12.08	 2.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28425	 1	 8.57	 2.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28426	 1	 10.92	 2.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28427	 1	 13.31	 3.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28428	 1	 11.85	 2.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28429	 1	 8.1	 1.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28430	 1	 13.04	 3.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28431	 1	 5.67	 1.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28432	 1	 5.49	 1.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28433	 1	 12.43	 2.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28434	 1	 8.45	 1.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28435	 1	 5.66	 1.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28436	 1	 5.3	 1.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28437	 1	 6.56	 1.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28438	 1	 2.75	 0.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28439	 1	 9.38	 2.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28440	 1	 5.22	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28441	 1	 8.51	 2.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28442	 1	 6.71	 3.72	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28443	 1	 6.6	 1.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28444	 1	 5.12	 1.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28445	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28446	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28447	 1	 3.59	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28448	 1	 5.32	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28449	 1	 3.92	 0.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28450	 1	 5.44	 1.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28451	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28452	 1	 7.14	 4.44	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28453	 1	 3.34	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28454	 1	 2.59	 1.29	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28455	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28456	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28457	 1	 7.65	 4.8	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28458	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28459	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28460	 1	 5.59	 1.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28461	 1	 6.3	 1.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28462	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28463	 1	 5.69	 1.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28464	 1	 4.87	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28465	 1	 9.77	 2.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28466	 1	 3.26	 0.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28467	 1	 13.0	 3.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28468	 1	 4.45	 1.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28469	 1	 3.98	 0.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28470	 1	 2.94	 1.6	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28471	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28472	 1	 5.04	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28473	 1	 7.28	 1.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28474	 1	 15.0	 3.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28475	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28476	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28477	 1	 4.88	 2.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28478	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28479	 1	 6.47	 1.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28480	 1	 8.13	 1.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28481	 1	 11.43	 2.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28482	 1	 5.89	 1.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28483	 1	 6.29	 1.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28484	 1	 8.63	 2.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28485	 1	 10.33	 2.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28486	 1	 10.03	 2.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28487	 1	 10.56	 2.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28488	 1	 5.28	 1.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28489	 1	 7.86	 1.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28490	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28491	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28492	 1	 8.97	 2.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28493	 1	 6.21	 1.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28494	 1	 6.37	 1.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28495	 1	 17.94	 4.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28496	 1	 8.19	 1.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28497	 1	 5.55	 1.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28498	 1	 8.41	 1.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28499	 1	 5.01	 1.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28500	 1	 7.52	 1.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28501	 1	 8.34	 1.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28502	 1	 6.87	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28503	 1	 7.04	 1.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28504	 1	 4.67	 1.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28505	 1	 6.49	 1.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28506	 1	 7.67	 1.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28507	 1	 7.89	 1.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28508	 1	 6.14	 3.64	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28509	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28510	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28511	 1	 65.55	 30.29	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28512	 1	 1.81	 1.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28513	 1	 30.9	 14.31	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28514	 1	 6.27	 2.72	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28515	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28516	 1	 3.23	 1.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28517	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28518	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28519	 1	 8.63	 4.29	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28520	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28521	 1	 5.22	 3.26	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28522	 1	 2.83	 1.67	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28523	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28524	 1	 5.49	 3.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28525	 1	 5.33	 3.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28526	 1	 6.71	 3.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28527	 1	 9.0	 5.02	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28528	 1	 4.07	 0.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28529	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28530	 1	 3.18	 0.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28531	 1	 9.06	 2.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28532	 1	 11.85	 2.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28533	 1	 7.53	 4.55	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28534	 1	 5.41	 2.97	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28535	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28536	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28537	 1	 14.07	 8.61	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28538	 1	 7.68	 1.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28539	 1	 5.71	 1.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28540	 1	 7.51	 1.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28541	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28542	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28543	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28544	 1	 5.39	 3.12	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28545	 1	 6.58	 3.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28546	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28547	 1	 6.0	 2.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28548	 1	 4.22	 2.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28549	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28550	 1	 5.03	 2.62	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28551	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28552	 1	 5.9	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28553	 1	 3.66	 0.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28554	 1	 3.43	 0.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28555	 1	 2.9	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28556	 1	 6.62	 1.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28557	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28558	 1	 8.47	 4.58	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28559	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28560	 1	 5.71	 2.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28561	 1	 6.39	 3.62	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28562	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28563	 1	 5.79	 1.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28564	 1	 9.58	 2.31	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28565	 1	 12.94	 3.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28566	 1	 11.07	 2.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28567	 1	 10.95	 2.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28568	 1	 7.65	 1.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28569	 1	 7.21	 1.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28570	 1	 9.26	 2.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28571	 1	 8.75	 2.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28572	 1	 10.75	 2.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28573	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28574	 1	 7.22	 1.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28575	 1	 9.16	 2.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28576	 1	 12.73	 3.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28577	 1	 14.43	 3.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28578	 1	 13.42	 3.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28579	 1	 8.32	 1.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28580	 1	 20.16	 4.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28581	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28582	 1	 6.44	 3.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28583	 1	 7.7	 1.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28584	 1	 7.0	 1.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28585	 1	 4.44	 2.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28586	 1	 13.1	 3.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28587	 1	 5.3	 1.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28588	 1	 8.81	 2.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28589	 1	 3.72	 0.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28590	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28591	 1	 9.44	 2.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28592	 1	 9.3	 2.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28593	 1	 5.2	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28594	 1	 4.58	 1.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28595	 1	 13.54	 3.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28596	 1	 4.17	 0.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28597	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28598	 1	 10.98	 2.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28599	 1	 7.05	 1.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28600	 1	 5.9	 1.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28601	 1	 6.91	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28602	 1	 4.26	 1.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28603	 1	 8.67	 2.09	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28604	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28605	 1	 2.1	 0.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28606	 1	 4.21	 2.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28607	 1	 6.43	 3.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28608	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28609	 1	 6.91	 3.54	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28610	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28611	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28612	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28613	 1	 3.31	 1.95	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28614	 1	 2.52	 1.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28615	 1	 6.44	 2.87	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28616	 1	 5.47	 2.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28617	 1	 19.49	 8.22	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28618	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28619	 1	 8.06	 3.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28620	 1	 6.41	 3.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28621	 1	 3.72	 1.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28622	 1	 8.73	 5.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28623	 1	 7.83	 4.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28624	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28625	 1	 8.24	 4.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28626	 1	 7.81	 4.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28627	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28628	 1	 5.59	 1.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28629	 1	 1.75	 1.07	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28630	 1	 3.17	 1.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28631	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28632	 1	 7.51	 4.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28633	 1	 4.97	 2.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28634	 1	 7.01	 3.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28635	 1	 2.3	 1.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28636	 1	 3.39	 1.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28637	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28638	 1	 9.18	 2.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28639	 1	 8.97	 2.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28640	 1	 5.05	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28641	 1	 9.43	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28642	 1	 5.28	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28643	 1	 3.64	 0.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28644	 1	 6.81	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28645	 1	 9.46	 2.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28646	 1	 8.41	 1.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28647	 1	 13.83	 6.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28648	 1	 7.12	 3.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28649	 1	 5.52	 2.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28650	 1	 5.92	 3.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28651	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28652	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28653	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28654	 1	 8.77	 4.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28655	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28656	 1	 14.07	 6.88	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28657	 1	 9.66	 4.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28658	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28659	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28660	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28661	 1	 3.41	 1.75	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28662	 1	 5.96	 3.02	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28663	 1	 9.58	 4.67	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28664	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28665	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28666	 1	 7.9	 3.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28667	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28668	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28669	 1	 7.41	 3.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28670	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28671	 1	 6.09	 3.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28672	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28673	 1	 18.06	 8.33	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28674	 1	 15.74	 8.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28675	 1	 15.63	 7.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28676	 1	 5.86	 3.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28677	 1	 14.95	 3.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28678	 1	 17.55	 7.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28679	 1	 19.69	 4.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28680	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28681	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28682	 1	 7.82	 3.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28683	 1	 12.35	 6.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28684	 1	 3.2	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28685	 1	 17.18	 9.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28686	 1	 9.18	 4.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28687	 1	 17.3	 8.2	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28688	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28689	 1	 8.03	 4.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28690	 1	 13.28	 2.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28691	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28692	 1	 15.24	 6.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28693	 1	 11.98	 6.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28694	 1	 3.86	 2.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28695	 1	 4.47	 2.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28696	 1	 2.55	 0.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28697	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28698	 1	 12.37	 5.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28699	 1	 7.56	 4.57	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28700	 1	 20.77	 4.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28701	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28702	 1	 16.7	 8.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28703	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28704	 1	 20.08	 4.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28705	 1	 4.3	 0.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28706	 1	 6.46	 1.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28707	 1	 6.78	 1.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28708	 1	 4.67	 1.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28709	 1	 3.28	 0.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28710	 1	 1.89	 0.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28711	 1	 2.04	 0.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28712	 1	 1.55	 0.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28713	 1	 7.13	 1.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28714	 1	 10.06	 2.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28715	 1	 6.29	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28716	 1	 5.29	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28717	 1	 4.75	 1.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28718	 1	 4.63	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28719	 1	 3.21	 0.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28720	 1	 6.98	 1.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28721	 1	 8.94	 2.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28722	 1	 3.9	 0.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28723	 1	 3.5	 0.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28724	 1	 4.7	 1.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28725	 1	 2.05	 0.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28726	 1	 37.73	 8.73	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28727	 1	 5.71	 1.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28728	 1	 10.06	 2.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28729	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28730	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28731	 1	 17.74	 4.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28732	 1	 3.99	 0.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28733	 1	 14.46	 3.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28734	 1	 8.56	 1.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28735	 1	 11.12	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28736	 1	 20.21	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28737	 1	 11.44	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28738	 1	 18.33	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28739	 1	 7.44	 1.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28740	 1	 7.84	 1.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28741	 1	 6.53	 1.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28742	 1	 4.46	 1.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28743	 1	 7.1	 1.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28744	 1	 8.01	 1.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28745	 1	 37.35	 8.66	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28746	 1	 4.9	 1.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28747	 1	 5.25	 1.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28748	 1	 7.89	 1.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28749	 1	 5.18	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28750	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28751	 1	 15.26	 3.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28752	 1	 6.72	 1.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28753	 1	 6.85	 1.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28754	 1	 3.32	 0.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28755	 1	 7.0	 1.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28756	 1	 4.68	 1.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28757	 1	 5.17	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28758	 1	 12.54	 2.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28759	 1	 10.41	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28760	 1	 9.33	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28761	 1	 27.81	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28762	 1	 7.99	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28763	 1	 5.62	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28764	 1	 10.69	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28765	 1	 8.33	 1.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28766	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28767	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28768	 1	 19.34	 9.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28769	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28770	 1	 6.85	 3.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28771	 1	 25.45	 12.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28772	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28773	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28774	 1	 15.37	 8.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28775	 1	 11.84	 6.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28776	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28777	 1	 5.29	 2.66	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28778	 1	 7.49	 4.29	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28779	 1	 7.21	 3.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28780	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28781	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28782	 1	 10.47	 5.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28783	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28784	 1	 6.38	 3.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28785	 1	 6.06	 3.09	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28786	 1	 1.56	 0.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28787	 1	 15.76	 8.7	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28788	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28789	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28790	 1	 12.28	 6.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28791	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28792	 1	 57.11	 32.54	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28793	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28794	 1	 22.13	 13.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28795	 1	 8.25	 4.59	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28796	 1	 13.37	 6.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28797	 1	 17.95	 9.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28798	 1	 2.97	 1.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28799	 1	 10.62	 5.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28800	 1	 9.37	 5.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28801	 1	 21.18	 10.69	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28802	 1	 5.78	 3.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28803	 1	 6.56	 3.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28804	 1	 5.77	 2.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28805	 1	 3.08	 1.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28806	 1	 5.77	 2.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28807	 1	 2.95	 1.51	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28808	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28809	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28810	 1	 7.09	 3.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28811	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28812	 1	 40.64	 19.98	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28813	 1	 14.25	 5.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28814	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28815	 1	 8.61	 4.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28816	 1	 4.69	 2.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28817	 1	 4.36	 2.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28818	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28819	 1	 12.14	 5.98	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28820	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28821	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28822	 1	 82.35	 44.21	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28823	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28824	 1	 10.43	 5.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28825	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28826	 1	 3.95	 2.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28827	 1	 14.39	 6.74	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28828	 1	 30.38	 15.41	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28829	 1	 39.86	 22.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28830	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28831	 1	 5.93	 2.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28832	 1	 5.48	 3.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28833	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28834	 1	 7.9	 3.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28835	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28836	 1	 3.81	 1.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28837	 1	 2.96	 1.46	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28838	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28839	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28840	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28841	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28842	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28843	 1	 14.49	 7.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28844	 1	 8.96	 4.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28845	 1	 8.9	 5.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28846	 1	 77.09	 37.03	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28847	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28848	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28849	 1	 9.73	 5.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28850	 1	 11.83	 6.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28851	 1	 7.99	 3.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28852	 1	 8.61	 4.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28853	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28854	 1	 7.28	 4.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28855	 1	 7.34	 3.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28856	 1	 12.15	 5.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28857	 1	 4.28	 1.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28858	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28859	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28860	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28861	 1	 11.43	 6.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28862	 1	 7.95	 4.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28863	 1	 5.1	 2.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28864	 1	 3.96	 2.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28865	 1	 4.06	 2.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28866	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28867	 1	 10.96	 6.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28868	 1	 22.61	 11.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28869	 1	 12.93	 6.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28870	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28871	 1	 10.14	 5.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28872	 1	 10.99	 4.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28873	 1	 10.05	 5.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28874	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28875	 1	 8.86	 4.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28876	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28877	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28878	 1	 4.91	 2.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28879	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28880	 1	 8.5	 4.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28881	 1	 4.22	 2.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28882	 1	 7.09	 3.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28883	 1	 17.32	 7.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28884	 1	 9.71	 2.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28885	 1	 9.07	 2.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28886	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28887	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28888	 1	 9.32	 5.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28889	 1	 10.9	 5.26	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28890	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28891	 1	 5.33	 2.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28892	 1	 9.42	 3.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28893	 1	 13.55	 6.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28894	 1	 11.82	 5.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28895	 1	 4.57	 2.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28896	 1	 7.2	 3.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28897	 1	 9.91	 5.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28898	 1	 13.48	 6.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28899	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28900	 1	 9.02	 4.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28901	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28902	 1	 16.8	 7.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28903	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28904	 1	 5.47	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28905	 1	 15.25	 8.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28906	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28907	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28908	 1	 52.25	 28.83	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28909	 1	 24.54	 11.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28910	 1	 16.98	 7.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28911	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28912	 1	 8.5	 4.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28913	 1	 19.57	 8.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28914	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28915	 1	 3.44	 1.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28916	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28917	 1	 10.83	 6.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28918	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28919	 1	 6.49	 3.62	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28920	 1	 7.38	 3.87	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28921	 1	 8.14	 4.79	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28922	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28923	 1	 6.88	 3.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28924	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28925	 1	 11.13	 5.83	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28926	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28927	 1	 12.26	 6.45	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28928	 1	 12.93	 7.53	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28929	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28930	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28931	 1	 14.51	 5.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28932	 1	 18.28	 8.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28933	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28934	 1	 8.72	 4.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28935	 1	 8.32	 3.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28936	 1	 18.92	 8.54	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28937	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28938	 1	 15.45	 7.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28939	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28940	 1	 20.05	 10.98	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28941	 1	 8.98	 5.19	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28942	 1	 53.28	 24.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28943	 1	 6.24	 2.88	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28944	 1	 6.12	 3.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28945	 1	 12.77	 6.18	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28946	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28947	 1	 6.71	 3.91	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28948	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28949	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28950	 1	 6.9	 3.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28951	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28952	 1	 7.54	 3.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28953	 1	 5.77	 2.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28954	 1	 12.79	 5.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28955	 1	 11.16	 6.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28956	 1	 9.26	 4.31	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28957	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28958	 1	 6.42	 3.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28959	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28960	 1	 18.05	 9.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28961	 1	 18.02	 10.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28962	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28963	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	28964	 1	 14.39	 7.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28965	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28966	 1	 8.63	 4.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28967	 1	 2.8	 1.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28968	 1	 4.79	 2.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28969	 1	 13.98	 8.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28970	 1	 2.97	 1.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28971	 1	 7.12	 4.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28972	 1	 4.07	 1.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28973	 1	 11.56	 5.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28974	 1	 3.24	 1.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28975	 1	 10.91	 6.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28976	 1	 22.12	 10.73	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28977	 1	 17.03	 10.17	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28978	 1	 14.78	 8.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28979	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	28980	 1	 26.36	 13.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28981	 1	 3.52	 1.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28982	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28983	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28984	 1	 7.48	 3.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28985	 1	 6.92	 3.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28986	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28987	 1	 14.65	 7.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28988	 1	 17.42	 4.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28989	 1	 6.87	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28990	 1	 49.99	 27.72	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28991	 1	 4.26	 0.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28992	 1	 4.31	 0.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28993	 1	 1.31	 0.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28994	 1	 12.36	 2.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28995	 1	 6.77	 1.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28996	 1	 7.09	 1.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28997	 1	 10.4	 2.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28998	 1	 8.36	 1.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	28999	 1	 8.15	 1.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29000	 1	 5.11	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29001	 1	 5.8	 1.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29002	 1	 3.87	 1.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29003	 1	 5.27	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29004	 1	 5.42	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29005	 1	 9.82	 4.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29006	 1	 9.1	 4.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29007	 1	 10.92	 5.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29008	 1	 9.56	 5.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29009	 1	 3.38	 1.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29010	 1	 7.33	 3.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29011	 1	 3.92	 1.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29012	 1	 9.08	 4.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29013	 1	 2.61	 1.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29014	 1	 10.21	 5.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29015	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29016	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29017	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29018	 1	 5.09	 2.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29019	 1	 7.87	 3.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29020	 1	 12.39	 6.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29021	 1	 13.02	 5.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29022	 1	 11.27	 5.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29023	 1	 9.11	 5.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29024	 1	 9.33	 4.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29025	 1	 8.53	 4.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29026	 1	 17.41	 10.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29027	 1	 11.79	 6.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29028	 1	 8.71	 4.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29029	 1	 20.87	 12.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29030	 1	 51.1	 25.57	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29031	 1	 21.18	 8.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29032	 1	 5.89	 1.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29033	 1	 10.85	 2.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29034	 1	 9.72	 2.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29035	 1	 2.97	 0.68	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29036	 1	 4.71	 1.09	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29037	 1	 4.45	 1.03	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29038	 1	 3.75	 0.87	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29039	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29040	 1	 9.85	 2.28	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29041	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29042	 1	 21.65	 10.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29043	 1	 13.07	 2.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29044	 1	 9.79	 2.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29045	 1	 11.23	 2.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29046	 1	 7.53	 1.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29047	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29048	 1	 7.41	 1.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29049	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29050	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29051	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29052	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29053	 1	 2.5	 0.58	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29054	 1	 7.28	 1.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29055	 1	 5.78	 2.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29056	 1	 5.58	 1.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29057	 1	 4.9	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29058	 1	 4.92	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29059	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29060	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29061	 1	 8.89	 3.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29062	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29063	 1	 19.33	 9.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29064	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29065	 1	 14.6	 5.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29066	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29067	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29068	 1	 8.7	 5.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29069	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29070	 1	 4.44	 2.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29071	 1	 4.58	 2.36	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29072	 1	 11.11	 6.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29073	 1	 3.29	 1.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29074	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29075	 1	 7.7	 1.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29076	 1	 12.32	 2.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29077	 1	 15.4	 3.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29078	 1	 9.45	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29079	 1	 15.09	 7.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29080	 1	 8.03	 4.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29081	 1	 10.21	 4.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29082	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29083	 1	 11.35	 5.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29084	 1	 5.92	 3.53	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29085	 1	 1.47	 0.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29086	 1	 23.32	 11.88	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29087	 1	 37.86	 21.23	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29088	 1	 28.08	 16.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29089	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29090	 1	 44.37	 22.45	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29091	 1	 5.84	 3.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29092	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29093	 1	 15.73	 8.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29094	 1	 6.02	 3.11	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29095	 1	 8.25	 3.53	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29096	 1	 3.65	 1.79	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29097	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29098	 1	 1.99	 1.12	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29099	 1	 4.79	 2.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29100	 1	 3.85	 2.05	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29101	 1	 14.54	 7.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29102	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29103	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29104	 1	 4.25	 2.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29105	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29106	 1	 6.31	 3.64	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29107	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29108	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29109	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29110	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29111	 1	 7.66	 4.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29112	 1	 7.43	 3.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29113	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29114	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29115	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29116	 1	 6.14	 3.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29117	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29118	 1	 3.81	 2.17	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29119	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29120	 1	 3.33	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29121	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29122	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29123	 1	 2.94	 1.54	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29124	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29125	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29126	 1	 4.44	 2.7	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29127	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29128	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29129	 1	 4.51	 2.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29130	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29131	 1	 2.12	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29132	 1	 1.73	 1.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29133	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29134	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29135	 1	 5.89	 3.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29136	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29137	 1	 7.0	 3.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29138	 1	 3.4	 0.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29139	 1	 2.57	 1.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29140	 1	 7.89	 3.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29141	 1	 10.26	 5.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29142	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29143	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29144	 1	 10.27	 4.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29145	 1	 15.11	 3.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29146	 1	 4.41	 2.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29147	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29148	 1	 8.13	 4.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29149	 1	 11.57	 2.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29150	 1	 7.89	 1.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29151	 1	 10.93	 2.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29152	 1	 14.22	 3.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29153	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29154	 1	 9.11	 2.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29155	 1	 12.02	 2.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29156	 1	 10.51	 2.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29157	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29158	 1	 7.21	 3.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29159	 1	 1.22	 0.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29160	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29161	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29162	 1	 5.4	 2.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29163	 1	 7.11	 3.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29164	 1	 21.65	 7.86	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29165	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29166	 1	 3.3	 1.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29167	 1	 6.8	 3.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29168	 1	 10.86	 5.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29169	 1	 5.77	 3.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29170	 1	 5.74	 3.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29171	 1	 5.68	 3.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29172	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29173	 1	 3.78	 1.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29174	 1	 9.56	 4.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29175	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29176	 1	 4.62	 2.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29177	 1	 5.39	 3.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29178	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29179	 1	 6.11	 3.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29180	 1	 2.8	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29181	 1	 4.01	 2.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29182	 1	 10.15	 4.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29183	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29184	 1	 3.7	 1.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29185	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29186	 1	 8.99	 4.17	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29187	 1	 5.36	 2.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29188	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29189	 1	 4.44	 2.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29190	 1	 3.8	 2.34	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29191	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29192	 1	 4.95	 2.96	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29193	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29194	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29195	 1	 19.24	 8.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29196	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29197	 1	 3.78	 2.26	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29198	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29199	 1	 7.1	 3.36	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29200	 1	 3.64	 2.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29201	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29202	 1	 2.43	 1.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29203	 1	 4.53	 2.71	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29204	 1	 4.98	 2.26	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29205	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29206	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29207	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29208	 1	 4.34	 2.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29209	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29210	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29211	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29212	 1	 3.85	 2.26	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29213	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29214	 1	 5.99	 3.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29215	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29216	 1	 4.12	 2.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29217	 1	 5.44	 3.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29218	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29219	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29220	 1	 5.44	 3.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29221	 1	 4.17	 2.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29222	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29223	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	29224	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29225	 1	 3.25	 1.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29226	 1	 7.75	 3.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29227	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29228	 1	 9.48	 4.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29229	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29230	 1	 3.63	 2.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29231	 1	 6.37	 3.07	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29232	 1	 4.77	 2.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29233	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29234	 1	 5.01	 2.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29235	 1	 5.73	 2.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29236	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29237	 1	 7.76	 3.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29238	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29239	 1	 5.88	 3.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29240	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29241	 1	 6.16	 3.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29242	 1	 9.85	 5.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29243	 1	 7.27	 3.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29244	 1	 22.25	 10.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29245	 1	 5.22	 2.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29246	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29247	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29248	 1	 5.5	 3.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29249	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29250	 1	 6.56	 3.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29251	 1	 12.84	 6.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29252	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29253	 1	 2.82	 1.44	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29254	 1	 6.34	 3.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29255	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29256	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29257	 1	 4.53	 1.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29258	 1	 6.92	 3.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29259	 1	 5.94	 1.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29260	 1	 7.96	 4.55	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29261	 1	 0.8	 0.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29262	 1	 4.17	 2.15	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29263	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29264	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29265	 1	 7.42	 3.8	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29266	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29267	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29268	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29269	 1	 5.89	 3.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29270	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29271	 1	 5.05	 2.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29272	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29273	 1	 7.39	 3.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29274	 1	 4.07	 2.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29275	 1	 5.67	 2.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29276	 1	 8.1	 3.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29277	 1	 5.9	 3.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29278	 1	 8.13	 3.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29279	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29280	 1	 2.73	 1.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29281	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29282	 1	 5.21	 2.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29283	 1	 9.42	 4.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29284	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29285	 1	 7.48	 3.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29286	 1	 6.12	 1.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29287	 1	 7.63	 1.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29288	 1	 3.8	 1.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29289	 1	 7.64	 1.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29290	 1	 7.6	 4.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29291	 1	 6.43	 1.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29292	 1	 3.84	 0.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29293	 1	 1.24	 0.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29294	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29295	 1	 5.03	 2.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29296	 1	 4.2	 2.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29297	 1	 2.27	 1.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29298	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29299	 1	 3.53	 1.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29300	 1	 4.26	 2.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29301	 1	 3.55	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29302	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29303	 1	 3.92	 2.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29304	 1	 6.85	 3.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29305	 1	 6.4	 3.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29306	 1	 3.52	 2.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29307	 1	 8.21	 3.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29308	 1	 6.11	 3.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29309	 1	 4.4	 2.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29310	 1	 4.87	 2.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29311	 1	 8.29	 4.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29312	 1	 2.32	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29313	 1	 5.51	 2.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29314	 1	 6.81	 3.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29315	 1	 9.83	 5.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29316	 1	 6.89	 4.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29317	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29318	 1	 8.27	 4.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29319	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29320	 1	 3.82	 2.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29321	 1	 10.12	 5.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29322	 1	 8.76	 4.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29323	 1	 7.5	 3.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29324	 1	 3.96	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29325	 1	 4.44	 2.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29326	 1	 8.7	 5.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29327	 1	 6.08	 2.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29328	 1	 5.67	 2.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29329	 1	 13.53	 7.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29330	 1	 6.38	 3.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29331	 1	 4.47	 2.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29332	 1	 5.87	 3.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29333	 1	 5.53	 3.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29334	 1	 4.72	 2.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29335	 1	 2.16	 1.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29336	 1	 7.65	 3.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29337	 1	 5.7	 2.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29338	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	29339	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29340	 1	 9.17	 4.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29341	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29342	 1	 8.39	 4.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29343	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29344	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29345	 1	 10.96	 5.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29346	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29347	 1	 5.03	 2.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29348	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29349	 1	 5.16	 2.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29350	 1	 2.25	 1.27	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29351	 1	 8.52	 3.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29352	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29353	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29354	 1	 8.93	 5.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29355	 1	 10.45	 5.05	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29356	 1	 7.8	 4.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29357	 1	 9.26	 4.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29358	 1	 7.62	 4.14	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29359	 1	 3.15	 1.71	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29360	 1	 5.17	 2.63	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29361	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29362	 1	 13.46	 6.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29363	 1	 42.43	 17.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29364	 1	 18.01	 8.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29365	 1	 7.46	 3.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29366	 1	 9.38	 4.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29367	 1	 9.53	 4.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29368	 1	 6.99	 4.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29369	 1	 8.47	 3.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29370	 1	 7.33	 4.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29371	 1	 5.48	 3.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29372	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29373	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29374	 1	 7.76	 3.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29375	 1	 5.19	 2.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29376	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29377	 1	 6.81	 3.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29378	 1	 6.98	 4.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29379	 1	 6.13	 3.07	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29380	 1	 4.12	 2.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29381	 1	 7.11	 4.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29382	 1	 46.38	 21.55	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29383	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29384	 1	 3.57	 1.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29385	 1	 19.85	 9.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29386	 1	 12.05	 5.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29387	 1	 5.69	 2.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29388	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29389	 1	 11.68	 5.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29390	 1	 39.15	 18.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29391	 1	 11.24	 6.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29392	 1	 4.18	 2.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29393	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29394	 1	 5.38	 3.17	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29395	 1	 4.33	 2.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29396	 1	 4.58	 2.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29397	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29398	 1	 7.48	 4.15	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29399	 1	 4.65	 2.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29400	 1	 5.83	 3.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29401	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29402	 1	 6.54	 3.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29403	 1	 3.24	 2.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29404	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29405	 1	 6.25	 3.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29406	 1	 5.73	 3.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29407	 1	 3.55	 1.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29408	 1	 11.87	 5.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29409	 1	 5.63	 2.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29410	 1	 3.03	 1.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29411	 1	 3.98	 2.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29412	 1	 9.75	 5.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29413	 1	 4.72	 2.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29414	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29415	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29416	 1	 1.46	 0.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29417	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29418	 1	 5.55	 2.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29419	 1	 6.85	 3.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29420	 1	 2.23	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29421	 1	 5.56	 2.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29422	 1	 3.98	 2.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29423	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29424	 1	 4.61	 2.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29425	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29426	 1	 6.81	 3.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29427	 1	 6.48	 3.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29428	 1	 16.91	 7.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29429	 1	 45.18	 18.86	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29430	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	29431	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29432	 1	 7.71	 4.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29433	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29434	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	29435	 1	 4.14	 2.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29436	 1	 2.25	 1.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29437	 1	 10.19	 5.89	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29438	 1	 4.85	 2.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29439	 1	 8.28	 4.21	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29440	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	29441	 1	 3.26	 1.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29442	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29443	 1	 4.1	 2.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29444	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29445	 1	 5.35	 3.41	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29446	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29447	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29448	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29449	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29450	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29451	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	29452	 1	 2.26	 1.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29453	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29454	 1	 5.79	 3.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29455	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29456	 1	 1.66	 1.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29457	 1	 2.66	 1.4	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29458	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29459	 1	 4.93	 2.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29460	 1	 3.09	 1.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29461	 1	 3.89	 1.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29462	 1	 3.09	 1.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29463	 1	 1.44	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29464	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29465	 1	 1.68	 0.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29466	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29467	 1	 2.01	 0.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29468	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29469	 1	 7.86	 3.59	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29470	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29471	 1	 3.86	 2.48	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29472	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29473	 1	 4.8	 2.76	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29474	 1	 5.05	 2.67	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29475	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29476	 1	 0.01	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29477	 1	 0.13	 0.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29478	 1	 0.02	 0.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29479	 1	 38.56	 20.4	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29480	 1	 0.01	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29481	 1	 6.37	 1.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29482	 1	 10.57	 2.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29483	 1	 4.98	 1.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29484	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29485	 1	 8.71	 5.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29486	 1	 6.58	 4.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29487	 1	 8.19	 4.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29488	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	29489	 1	 3.51	 2.21	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29490	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29491	 1	 6.86	 3.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29492	 1	 5.66	 3.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29493	 1	 4.26	 2.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29494	 1	 4.26	 2.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29495	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29496	 1	 8.61	 5.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29497	 1	 7.26	 4.37	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29498	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29499	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29500	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29501	 1	 6.08	 2.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29502	 1	 11.07	 5.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29503	 1	 3.44	 2.01	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29504	 1	 6.47	 4.2	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29505	 1	 10.25	 5.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29506	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29507	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29508	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29509	 1	 5.5	 2.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29510	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29511	 1	 27.59	 13.9	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29512	 1	 11.62	 6.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29513	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29514	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	29515	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29516	 1	 14.35	 8.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29517	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29518	 1	 10.94	 2.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29519	 1	 11.59	 2.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29520	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29521	 1	 15.62	 3.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29522	 1	 12.31	 2.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29523	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29524	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29525	 1	 5.6	 1.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29526	 1	 11.13	 5.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29527	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29528	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29529	 1	 3.86	 1.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29530	 1	 10.3	 4.66	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29531	 1	 5.77	 3.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29532	 1	 2.34	 1.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29533	 1	 18.74	 9.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29534	 1	 2.29	 1.45	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29535	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29536	 1	 5.56	 3.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29537	 1	 10.76	 5.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29538	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29539	 1	 6.09	 3.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29540	 1	 6.46	 3.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29541	 1	 4.97	 2.98	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29542	 1	 10.37	 5.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29543	 1	 6.62	 3.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29544	 1	 3.02	 1.78	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29545	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29546	 1	 5.49	 2.83	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29547	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29548	 1	 6.29	 3.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29549	 1	 11.34	 4.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29550	 1	 6.98	 3.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29551	 1	 6.85	 3.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29552	 1	 7.68	 4.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29553	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29554	 1	 6.66	 3.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29555	 1	 17.04	 3.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29556	 1	 5.16	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29557	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29558	 1	 6.67	 1.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29559	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29560	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29561	 1	 15.16	 3.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29562	 1	 18.05	 4.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29563	 1	 2.69	 0.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29564	 1	 3.95	 0.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29565	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29566	 1	 10.68	 2.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29567	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29568	 1	 13.55	 6.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29569	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29570	 1	 17.36	 7.39	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29571	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29572	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29573	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29574	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29575	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29576	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29577	 1	 29.65	 16.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29578	 1	 5.56	 1.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29579	 1	 6.88	 3.38	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29580	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29581	 1	 10.58	 2.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29582	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29583	 1	 7.22	 3.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29584	 1	 14.07	 7.4	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29585	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29586	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29587	 1	 13.99	 6.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29588	 1	 10.79	 4.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29589	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	29590	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29591	 1	 17.49	 9.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29592	 1	 4.77	 2.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29593	 1	 37.54	 20.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29594	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	29595	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29596	 1	 6.2	 1.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29597	 1	 3.32	 1.96	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29598	 1	 17.24	 9.48	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29599	 1	 28.34	 12.87	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29600	 1	 32.08	 16.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29601	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	29602	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29603	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29604	 1	 24.38	 13.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29605	 1	 5.63	 2.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29606	 1	 3.3	 1.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29607	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29608	 1	 13.84	 7.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29609	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29610	 1	 14.63	 3.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29611	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29612	 1	 4.56	 1.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29613	 1	 5.87	 1.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29614	 1	 10.43	 2.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29615	 1	 6.53	 1.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29616	 1	 5.4	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29617	 1	 4.87	 1.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29618	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29619	 1	 6.64	 1.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29620	 1	 11.48	 2.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29621	 1	 4.72	 1.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29622	 1	 1.5	 0.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29623	 1	 2.94	 0.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29624	 1	 9.75	 2.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29625	 1	 7.57	 1.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29626	 1	 3.61	 0.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29627	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29628	 1	 15.29	 3.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29629	 1	 2.15	 0.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29630	 1	 7.74	 1.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29631	 1	 16.68	 3.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29632	 1	 13.2	 7.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29633	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29634	 1	 12.54	 5.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29635	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29636	 1	 17.78	 4.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29637	 1	 9.39	 2.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29638	 1	 8.15	 1.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29639	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29640	 1	 9.78	 2.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29641	 1	 10.13	 2.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29642	 1	 7.84	 1.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29643	 1	 7.94	 1.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29644	 1	 11.83	 2.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29645	 1	 15.82	 3.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29646	 1	 5.44	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29647	 1	 5.95	 1.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29648	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29649	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29650	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29651	 1	 10.47	 2.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29652	 1	 4.76	 2.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29653	 1	 5.27	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29654	 1	 2.52	 0.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29655	 1	 6.0	 1.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29656	 1	 2.55	 0.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29657	 1	 4.98	 3.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29658	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29659	 1	 11.46	 4.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29660	 1	 3.03	 1.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29661	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29662	 1	 3.52	 2.19	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29663	 1	 3.01	 1.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29664	 1	 11.9	 6.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29665	 1	 14.9	 7.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29666	 1	 5.61	 2.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29667	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29668	 1	 9.67	 5.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29669	 1	 7.13	 3.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29670	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29671	 1	 1.93	 1.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29672	 1	 1.7	 0.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29673	 1	 10.59	 5.51	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29674	 1	 5.11	 2.99	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29675	 1	 5.64	 3.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29676	 1	 2.95	 1.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29677	 1	 3.6	 1.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29678	 1	 4.22	 2.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29679	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29680	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29681	 1	 15.87	 3.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29682	 1	 9.48	 4.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29683	 1	 4.04	 2.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29684	 1	 1.3	 0.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29685	 1	 0.98	 0.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29686	 1	 1.59	 0.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29687	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29688	 1	 5.78	 2.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29689	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29690	 1	 6.46	 3.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29691	 1	 5.12	 2.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29692	 1	 3.19	 1.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29693	 1	 3.91	 1.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29694	 1	 10.67	 2.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29695	 1	 4.74	 2.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29696	 1	 1.94	 1.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29697	 1	 4.55	 1.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29698	 1	 1.56	 0.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29699	 1	 2.81	 0.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29700	 1	 2.46	 1.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29701	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29702	 1	 3.9	 2.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29703	 1	 5.36	 2.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29704	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29705	 1	 6.17	 1.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29706	 1	 4.45	 1.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29707	 1	 8.07	 1.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29708	 1	 2.94	 0.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29709	 1	 5.66	 1.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29710	 1	 1.55	 0.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29711	 1	 1.58	 0.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29712	 1	 2.26	 0.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29713	 1	 2.08	 0.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29714	 1	 3.39	 0.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29715	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29716	 1	 6.52	 1.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29717	 1	 6.49	 1.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29718	 1	 2.8	 0.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29719	 1	 16.91	 3.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29720	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29721	 1	 2.63	 0.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29722	 1	 7.06	 3.97	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29723	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29724	 1	 4.61	 1.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29725	 1	 2.97	 0.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29726	 1	 6.06	 1.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29727	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29728	 1	 5.96	 1.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29729	 1	 6.21	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29730	 1	 7.04	 1.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29731	 1	 7.72	 1.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29732	 1	 5.33	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29733	 1	 13.25	 2.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29734	 1	 14.38	 3.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29735	 1	 6.34	 1.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29736	 1	 9.65	 2.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29737	 1	 6.1	 1.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29738	 1	 3.72	 0.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29739	 1	 0.89	 0.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29740	 1	 2.66	 0.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29741	 1	 3.31	 0.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29742	 1	 1.31	 0.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29743	 1	 3.58	 0.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29744	 1	 10.46	 2.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29745	 1	 9.08	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29747	 1	 5.51	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29748	 1	 1.78	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29749	 1	 5.07	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29750	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29751	 1	 2.78	 0.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29752	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29753	 1	 1.73	 0.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29754	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29755	 1	 6.95	 3.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29756	 1	 4.59	 2.61	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29757	 1	 4.28	 2.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29758	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29759	 1	 6.04	 3.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29760	 1	 9.31	 4.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29761	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29762	 1	 5.95	 3.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29763	 1	 13.86	 7.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29764	 1	 6.23	 2.84	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29765	 1	 9.63	 5.03	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29766	 1	 6.6	 3.77	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29767	 1	 5.52	 3.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29768	 1	 2.95	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29769	 1	 3.83	 1.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29770	 1	 6.65	 3.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29771	 1	 4.19	 1.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29772	 1	 10.42	 5.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29773	 1	 4.07	 2.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29774	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29775	 1	 12.84	 6.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29776	 1	 8.94	 5.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29777	 1	 3.89	 2.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29778	 1	 9.96	 5.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29779	 1	 6.65	 3.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29780	 1	 10.66	 5.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29781	 1	 6.51	 3.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29782	 1	 22.37	 12.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29783	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29784	 1	 10.79	 5.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29785	 1	 4.42	 2.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29786	 1	 4.48	 2.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29787	 1	 5.64	 3.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29788	 1	 5.01	 2.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29789	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29790	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	29791	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29792	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29793	 1	 7.89	 3.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29794	 1	 8.56	 4.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29795	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29796	 1	 6.63	 3.18	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29797	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29798	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29799	 1	 10.98	 5.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29800	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29801	 1	 1.9	 1.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29802	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29803	 1	 7.42	 4.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29804	 1	 5.05	 3.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29805	 1	 5.11	 2.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29806	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29807	 1	 8.88	 5.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29808	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29809	 1	 3.0	 1.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29810	 1	 11.07	 5.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29811	 1	 10.41	 5.46	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29812	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29813	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29814	 1	 3.95	 2.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29815	 1	 4.25	 1.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29816	 1	 22.09	 9.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29817	 1	 7.11	 3.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29818	 1	 7.3	 4.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29819	 1	 3.82	 2.07	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29820	 1	 12.36	 7.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29821	 1	 6.28	 3.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29822	 1	 4.28	 2.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29823	 1	 12.44	 5.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29824	 1	 15.52	 8.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29825	 1	 1.78	 0.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29826	 1	 9.56	 4.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29827	 1	 10.71	 5.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29828	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29829	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29830	 1	 9.77	 5.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29831	 1	 3.17	 1.8	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29832	 1	 19.74	 11.17	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29833	 1	 8.94	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29834	 1	 7.3	 4.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29835	 1	 7.57	 3.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29836	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29837	 1	 7.29	 4.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29838	 1	 7.96	 4.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29839	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29840	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29841	 1	 9.4	 4.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29842	 1	 5.1	 2.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29843	 1	 10.86	 5.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29844	 1	 5.63	 3.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29845	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29846	 1	 6.88	 3.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29847	 1	 3.99	 2.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29848	 1	 7.33	 3.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29849	 1	 6.79	 3.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29850	 1	 6.71	 3.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29851	 1	 1.91	 0.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29852	 1	 3.11	 0.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29853	 1	 5.49	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29854	 1	 5.87	 1.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29855	 1	 6.42	 1.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29856	 1	 6.02	 1.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29857	 1	 4.38	 1.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29858	 1	 16.48	 8.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29859	 1	 3.18	 1.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29860	 1	 4.3	 2.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29861	 1	 7.71	 3.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29862	 1	 31.7	 14.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29863	 1	 6.99	 3.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29864	 1	 5.61	 2.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29865	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29866	 1	 5.05	 2.81	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29867	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	29868	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	29869	 1	 6.08	 3.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29870	 1	 7.83	 4.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29871	 1	 8.42	 4.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29872	 1	 6.4	 3.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29873	 1	 32.97	 11.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29874	 1	 8.52	 4.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29875	 1	 5.02	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29876	 1	 5.81	 2.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29877	 1	 5.64	 1.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29878	 1	 3.78	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29879	 1	 3.41	 0.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29880	 1	 7.75	 3.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29881	 1	 8.06	 1.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29882	 1	 6.85	 1.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29883	 1	 7.94	 4.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29884	 1	 2.89	 0.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29885	 1	 8.13	 3.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29886	 1	 9.43	 5.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29887	 1	 5.73	 3.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29888	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29889	 1	 11.41	 6.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29890	 1	 41.19	 22.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29891	 1	 3.18	 0.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29892	 1	 1.94	 0.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29893	 1	 0.89	 0.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29894	 1	 5.97	 1.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29895	 1	 24.74	 13.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29896	 1	 6.96	 3.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29897	 1	 7.01	 3.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29898	 1	 3.78	 1.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29899	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29900	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29901	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29902	 1	 3.36	 2.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29903	 1	 5.83	 2.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29904	 1	 5.57	 2.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29905	 1	 5.56	 3.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29906	 1	 21.89	 11.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29907	 1	 6.59	 3.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29908	 1	 8.68	 3.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29909	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29910	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	29911	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	29912	 1	 5.59	 2.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29913	 1	 7.63	 3.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29914	 1	 6.22	 3.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29915	 1	 5.87	 3.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29916	 1	 7.16	 3.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29917	 1	 15.5	 6.45	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29918	 1	 10.09	 5.85	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29919	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29920	 1	 3.02	 1.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29921	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29922	 1	 2.39	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29923	 1	 3.14	 1.69	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29924	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29925	 1	 7.09	 1.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29926	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29927	 1	 3.32	 1.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29928	 1	 7.09	 3.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29929	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29930	 1	 20.54	 9.43	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29931	 1	 16.35	 8.85	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29932	 1	 7.81	 1.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29933	 1	 14.9	 8.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29934	 1	 1.91	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29935	 1	 15.06	 3.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29936	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29937	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29938	 1	 6.42	 3.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29939	 1	 6.64	 1.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29940	 1	 3.89	 0.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29941	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29942	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29943	 1	 10.12	 4.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29944	 1	 4.06	 0.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29945	 1	 2.6	 0.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29946	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29947	 1	 4.56	 2.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29948	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29949	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29950	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29951	 1	 9.06	 4.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29952	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29953	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29954	 1	 10.05	 4.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29955	 1	 2.07	 0.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29956	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29957	 1	 10.89	 4.85	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29958	 1	 5.06	 2.87	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29959	 1	 7.68	 3.66	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29960	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29961	 1	 4.02	 1.93	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29962	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29963	 1	 10.61	 4.72	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29964	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29965	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29966	 1	 7.75	 3.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29967	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29968	 1	 14.67	 6.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29969	 1	 16.44	 6.97	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29970	 1	 8.31	 4.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29971	 1	 7.41	 3.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29972	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29973	 1	 3.46	 2.09	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29974	 1	 8.43	 1.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29975	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29976	 1	 15.38	 7.83	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29977	 1	 0.37	 0.18	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29978	 1	 5.01	 2.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29979	 1	 4.42	 2.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29980	 1	 8.65	 4.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29981	 1	 10.89	 5.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29982	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	29983	 1	 2.36	 1.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29984	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29985	 1	 6.64	 3.49	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29986	 1	 8.14	 4.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29987	 1	 3.24	 1.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29988	 1	 6.17	 3.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29989	 1	 6.89	 3.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29990	 1	 4.4	 1.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29991	 1	 13.01	 7.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29992	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29993	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29994	 1	 11.44	 5.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29995	 1	 7.73	 3.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29996	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29997	 1	 16.72	 7.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	29998	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29999	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30000	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30001	 1	 4.66	 2.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30002	 1	 3.68	 2.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30003	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30004	 1	 3.24	 1.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30005	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30006	 1	 6.08	 3.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30007	 1	 4.93	 1.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30008	 1	 1.77	 0.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30009	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30010	 1	 13.74	 7.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30011	 1	 5.23	 2.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30012	 1	 3.75	 0.9	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30013	 1	 8.48	 2.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30014	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30015	 1	 3.71	 0.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30016	 1	 1.2	 0.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30017	 1	 5.24	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30018	 1	 7.63	 1.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30019	 1	 1.83	 0.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30020	 1	 4.37	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30021	 1	 5.42	 1.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30022	 1	 5.86	 1.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30023	 1	 5.04	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30024	 1	 3.97	 0.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30025	 1	 5.01	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30026	 1	 6.44	 1.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30027	 1	 2.67	 0.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30028	 1	 3.03	 0.73	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30029	 1	 2.98	 0.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30030	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30031	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30032	 1	 7.7	 1.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30033	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30034	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30035	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30036	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30037	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30038	 1	 6.16	 1.48	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30039	 1	 5.45	 1.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30040	 1	 8.35	 1.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30041	 1	 12.38	 2.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30042	 1	 4.86	 1.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30043	 1	 5.09	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30044	 1	 7.86	 1.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30045	 1	 4.91	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30046	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30047	 1	 7.53	 1.79	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30048	 1	 10.96	 2.62	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30049	 1	 3.41	 0.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30050	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30051	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30052	 1	 6.14	 1.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30053	 1	 6.61	 1.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30054	 1	 4.65	 1.11	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30055	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30056	 1	 7.57	 1.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30057	 1	 7.16	 1.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30058	 1	 9.24	 2.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30059	 1	 6.5	 1.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30060	 1	 5.36	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30061	 1	 7.72	 1.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30062	 1	 8.9	 2.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30063	 1	 10.07	 2.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30064	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30065	 1	 16.88	 4.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30066	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30067	 1	 6.64	 1.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30068	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30069	 1	 6.88	 1.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30070	 1	 6.74	 1.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30071	 1	 6.87	 1.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30072	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30073	 1	 9.78	 2.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30074	 1	 8.25	 1.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30075	 1	 9.67	 2.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30076	 1	 7.85	 1.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30077	 1	 11.54	 2.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30078	 1	 10.4	 2.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30079	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30080	 1	 13.0	 3.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30081	 1	 9.0	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30082	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30083	 1	 8.23	 1.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30084	 1	 5.99	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30085	 1	 8.71	 2.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30086	 1	 6.86	 1.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30087	 1	 5.58	 1.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30088	 1	 5.55	 1.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30089	 1	 10.27	 2.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30090	 1	 14.09	 3.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30091	 1	 9.34	 2.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30092	 1	 13.19	 3.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30093	 1	 6.84	 1.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30094	 1	 9.65	 2.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30095	 1	 2.69	 0.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30096	 1	 5.54	 1.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30097	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30098	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30099	 1	 4.93	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30100	 1	 6.67	 1.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30101	 1	 10.34	 2.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30102	 1	 12.79	 2.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30103	 1	 5.25	 1.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30104	 1	 7.84	 1.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30105	 1	 7.44	 1.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30106	 1	 8.23	 1.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30107	 1	 6.34	 1.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30108	 1	 8.25	 1.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30109	 1	 4.11	 0.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30110	 1	 7.99	 1.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30111	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30112	 1	 6.0	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30113	 1	 5.51	 1.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30114	 1	 5.96	 1.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30115	 1	 17.99	 4.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30116	 1	 4.43	 1.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30117	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30118	 1	 5.44	 1.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30119	 1	 5.1	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30120	 1	 5.39	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30121	 1	 7.91	 1.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30122	 1	 3.57	 0.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30123	 1	 6.72	 1.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30124	 1	 6.21	 1.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30125	 1	 4.92	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30126	 1	 5.52	 1.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30127	 1	 4.36	 1.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30128	 1	 4.95	 1.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30129	 1	 6.72	 1.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30130	 1	 6.35	 1.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30131	 1	 7.33	 1.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30132	 1	 7.01	 1.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30133	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30134	 1	 6.85	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30135	 1	 5.26	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30136	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30137	 1	 8.47	 1.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30138	 1	 7.76	 1.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30139	 1	 3.85	 0.91	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30140	 1	 4.06	 0.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30141	 1	 4.15	 0.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30142	 1	 11.31	 2.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30143	 1	 8.93	 2.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30144	 1	 7.7	 1.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30145	 1	 13.86	 3.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30146	 1	 6.78	 1.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30147	 1	 3.11	 0.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30148	 1	 5.53	 1.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30149	 1	 8.3	 1.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30150	 1	 9.52	 2.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30151	 1	 1.73	 0.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30152	 1	 1.76	 0.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30153	 1	 1.99	 0.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30154	 1	 1.92	 0.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30155	 1	 1.46	 0.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30156	 1	 6.99	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30157	 1	 2.97	 0.71	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30158	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30159	 1	 3.19	 0.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30160	 1	 2.12	 0.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30161	 1	 4.85	 1.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30162	 1	 5.0	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30163	 1	 5.44	 1.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30164	 1	 5.02	 1.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30165	 1	 7.07	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30166	 1	 5.3	 1.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30167	 1	 6.27	 1.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30168	 1	 3.38	 0.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30169	 1	 3.53	 0.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30170	 1	 3.09	 0.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30171	 1	 2.4	 0.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30172	 1	 10.12	 2.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30173	 1	 3.23	 0.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30174	 1	 4.44	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30175	 1	 7.01	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30176	 1	 6.43	 1.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30177	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30178	 1	 5.66	 1.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30179	 1	 6.8	 1.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30180	 1	 2.82	 0.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30181	 1	 4.95	 1.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30182	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30183	 1	 4.09	 0.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30184	 1	 2.38	 0.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30185	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30186	 1	 4.49	 1.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30187	 1	 14.1	 3.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30188	 1	 7.34	 1.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30189	 1	 4.06	 0.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30190	 1	 5.0	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30191	 1	 1.86	 0.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30192	 1	 7.05	 1.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30193	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30194	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30195	 1	 5.96	 1.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30196	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30197	 1	 10.37	 2.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30198	 1	 7.41	 1.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30199	 1	 5.01	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30200	 1	 3.38	 0.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30201	 1	 4.99	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30202	 1	 6.57	 1.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30203	 1	 6.89	 1.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30204	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30205	 1	 5.4	 1.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30206	 1	 5.09	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30207	 1	 1.88	 0.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30208	 1	 4.72	 1.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30209	 1	 4.49	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30210	 1	 3.0	 0.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30211	 1	 5.01	 1.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30212	 1	 4.98	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30213	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30214	 1	 9.89	 2.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30215	 1	 7.26	 1.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30216	 1	 9.49	 2.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30217	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30218	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30219	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30220	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30221	 1	 6.57	 1.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30222	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30223	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30224	 1	 9.24	 2.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30225	 1	 10.02	 2.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30226	 1	 10.68	 2.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30227	 1	 7.48	 1.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30228	 1	 7.26	 1.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30229	 1	 4.58	 1.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30230	 1	 4.4	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30231	 1	 5.86	 1.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30232	 1	 7.89	 1.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30233	 1	 7.93	 1.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30234	 1	 6.71	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30235	 1	 5.58	 1.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30236	 1	 4.56	 1.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30237	 1	 4.94	 1.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30238	 1	 4.83	 1.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30239	 1	 3.53	 0.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30240	 1	 2.95	 0.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30241	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30242	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30243	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30244	 1	 4.46	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30245	 1	 2.73	 0.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30246	 1	 4.73	 1.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30247	 1	 0.48	 0.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30248	 1	 3.38	 0.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30249	 1	 2.45	 0.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30250	 1	 2.07	 0.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30251	 1	 5.18	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30252	 1	 5.32	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30253	 1	 10.48	 2.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30254	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30255	 1	 12.2	 2.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30256	 1	 3.08	 0.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30257	 1	 3.34	 0.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30258	 1	 5.89	 1.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30259	 1	 4.18	 0.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30260	 1	 5.86	 1.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30261	 1	 9.81	 2.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30262	 1	 3.11	 0.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30263	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30264	 1	 3.87	 0.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30265	 1	 9.99	 2.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30266	 1	 10.68	 2.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30267	 1	 7.15	 1.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30268	 1	 6.13	 1.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30269	 1	 12.64	 2.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30270	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30271	 1	 5.13	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30272	 1	 5.1	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30273	 1	 0.98	 0.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30274	 1	 8.0	 1.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30275	 1	 8.43	 2.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30276	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30277	 1	 5.98	 1.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30278	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30279	 1	 4.04	 0.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30280	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30281	 1	 4.42	 2.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30282	 1	 9.37	 5.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30283	 1	 5.26	 1.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30284	 1	 5.19	 2.86	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30285	 1	 5.92	 1.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30286	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30287	 1	 9.89	 2.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30288	 1	 5.59	 1.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30289	 1	 9.92	 2.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30290	 1	 6.17	 1.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30291	 1	 11.13	 2.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30292	 1	 7.9	 1.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30293	 1	 6.15	 1.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30294	 1	 10.68	 2.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30295	 1	 8.56	 2.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30296	 1	 10.45	 2.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30297	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30298	 1	 10.87	 2.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30299	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30300	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30301	 1	 6.29	 1.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30302	 1	 5.78	 1.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30303	 1	 7.47	 1.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30304	 1	 3.7	 0.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30305	 1	 5.81	 1.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30306	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30307	 1	 8.14	 1.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30308	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30309	 1	 8.24	 1.96	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30310	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30311	 1	 7.34	 1.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30312	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30313	 1	 12.05	 2.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30314	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30315	 1	 5.59	 1.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30316	 1	 10.4	 2.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30317	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30318	 1	 7.15	 1.69	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30319	 1	 7.04	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30320	 1	 6.3	 1.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30321	 1	 13.52	 3.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30322	 1	 41.58	 9.84	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30323	 1	 8.9	 2.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30324	 1	 6.59	 1.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30325	 1	 8.91	 2.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30326	 1	 6.14	 1.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30327	 1	 3.81	 0.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30328	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30329	 1	 3.48	 0.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30330	 1	 7.31	 1.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30331	 1	 5.14	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30332	 1	 3.13	 0.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30333	 1	 4.6	 1.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30334	 1	 4.64	 1.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30335	 1	 5.58	 1.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30336	 1	 6.31	 1.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30337	 1	 4.7	 1.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30338	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30339	 1	 31.64	 7.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30340	 1	 9.54	 2.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30341	 1	 9.45	 2.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30342	 1	 5.6	 1.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30343	 1	 52.07	 12.56	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30344	 1	 4.55	 1.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30345	 1	 1.44	 0.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30346	 1	 0.67	 0.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30347	 1	 3.51	 0.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30348	 1	 51.34	 12.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30349	 1	 4.76	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30350	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30351	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30352	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30353	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30354	 1	 9.54	 2.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30355	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30356	 1	 12.33	 2.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30357	 1	 7.52	 3.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30358	 1	 7.09	 1.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30359	 1	 3.62	 0.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30360	 1	 13.41	 3.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30361	 1	 8.5	 2.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30362	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30363	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30364	 1	 11.67	 2.8	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30365	 1	 4.63	 2.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30366	 1	 7.9	 1.9	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30367	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30368	 1	 4.23	 1.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30369	 1	 7.25	 1.75	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30370	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30371	 1	 3.96	 0.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30372	 1	 9.56	 2.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30373	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30374	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30375	 1	 11.56	 2.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30376	 1	 3.64	 0.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30377	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30378	 1	 10.21	 2.45	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30379	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30380	 1	 10.26	 2.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30381	 1	 9.76	 2.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30382	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30383	 1	 6.15	 1.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30384	 1	 8.9	 2.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30385	 1	 6.55	 1.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30386	 1	 6.52	 1.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30387	 1	 4.59	 1.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30388	 1	 6.78	 1.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30389	 1	 2.97	 0.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30390	 1	 4.07	 0.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30391	 1	 4.75	 2.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30392	 1	 9.26	 5.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30393	 1	 6.64	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30394	 1	 10.76	 6.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30395	 1	 7.69	 3.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30396	 1	 6.24	 3.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30397	 1	 8.77	 4.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30398	 1	 10.77	 5.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30399	 1	 6.84	 2.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30400	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30401	 1	 6.72	 3.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30402	 1	 8.62	 4.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30403	 1	 6.63	 3.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30404	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30405	 1	 5.51	 3.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30406	 1	 11.61	 7.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30407	 1	 6.6	 3.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30408	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30409	 1	 5.95	 3.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30410	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30411	 1	 11.74	 7.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30412	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30413	 1	 8.91	 4.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30414	 1	 7.28	 3.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30415	 1	 13.22	 6.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30416	 1	 5.5	 2.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30417	 1	 7.1	 3.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30418	 1	 7.01	 3.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30419	 1	 4.87	 2.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30420	 1	 6.19	 3.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30421	 1	 12.01	 7.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30422	 1	 9.31	 5.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30423	 1	 7.66	 4.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30424	 1	 9.71	 4.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30425	 1	 14.11	 6.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30426	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30427	 1	 8.08	 3.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30428	 1	 11.38	 5.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30429	 1	 9.49	 2.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30430	 1	 9.77	 2.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30431	 1	 8.96	 2.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30432	 1	 4.36	 1.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30433	 1	 7.07	 1.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30434	 1	 11.65	 7.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30435	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	30436	 1	 6.94	 4.12	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30437	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30438	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30439	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30440	 1	 7.61	 1.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30441	 1	 10.91	 2.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30442	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30443	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30444	 1	 5.72	 1.38	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30445	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30446	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30447	 1	 6.72	 1.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30448	 1	 6.47	 1.57	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30449	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30450	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30451	 1	 9.66	 2.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30452	 1	 8.0	 1.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30453	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30454	 1	 31.47	 7.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30455	 1	 10.67	 2.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30456	 1	 4.31	 1.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30457	 1	 5.4	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30458	 1	 5.77	 1.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30459	 1	 10.58	 2.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30460	 1	 12.57	 2.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30461	 1	 7.11	 1.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30462	 1	 9.57	 2.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30463	 1	 8.09	 1.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30464	 1	 7.36	 1.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30465	 1	 9.89	 2.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30466	 1	 9.12	 2.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30467	 1	 8.03	 1.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30468	 1	 3.21	 0.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30469	 1	 6.02	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30470	 1	 4.43	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30471	 1	 7.4	 1.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30472	 1	 6.35	 1.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30473	 1	 4.2	 0.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30474	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30475	 1	 7.38	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30476	 1	 9.96	 2.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30477	 1	 4.82	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30478	 1	 6.38	 1.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30479	 1	 8.56	 2.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30480	 1	 5.35	 1.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30481	 1	 6.7	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30482	 1	 8.19	 1.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30483	 1	 5.24	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30484	 1	 5.27	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30485	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30486	 1	 4.52	 1.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30487	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30488	 1	 5.81	 1.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30489	 1	 7.02	 1.69	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30490	 1	 11.58	 2.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30491	 1	 9.6	 2.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30492	 1	 6.89	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30493	 1	 3.26	 0.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30494	 1	 8.43	 2.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30495	 1	 4.22	 1.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30496	 1	 5.48	 1.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30497	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30498	 1	 5.37	 1.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30499	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30500	 1	 10.36	 2.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30501	 1	 8.41	 2.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30502	 1	 6.32	 1.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30503	 1	 7.52	 1.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30504	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	30505	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30506	 1	 9.71	 2.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30507	 1	 6.66	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30508	 1	 4.47	 1.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30509	 1	 8.95	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30510	 1	 11.13	 2.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30511	 1	 8.66	 2.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30512	 1	 6.35	 1.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30513	 1	 9.91	 4.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30514	 1	 4.45	 1.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30515	 1	 3.06	 0.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30516	 1	 0.02	 0.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30517	 1	 0.97	 0.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30518	 1	 8.54	 2.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30519	 1	 0.75	 0.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30520	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	30521	 1	 1.1	 0.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30522	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	30523	 1	 7.42	 1.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30524	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	30525	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30526	 1	 5.97	 3.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30527	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30528	 1	 8.67	 2.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30529	 1	 3.21	 0.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30530	 1	 7.13	 1.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30531	 1	 6.71	 1.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30532	 1	 7.33	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30533	 1	 4.65	 2.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30534	 1	 6.19	 1.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30535	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30536	 1	 6.24	 3.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30537	 1	 12.98	 5.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30538	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30539	 1	 3.28	 0.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30540	 1	 4.37	 2.09	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30541	 1	 5.03	 1.28	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30542	 1	 2.66	 0.69	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30543	 1	 4.64	 3.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30544	 1	 15.67	 9.53	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30545	 1	 12.05	 3.11	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30546	 1	 8.45	 2.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30547	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	30548	 1	 8.43	 2.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30549	 1	 4.56	 1.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30550	 1	 7.04	 1.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30551	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30552	 1	 2.94	 0.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30553	 1	 0.39	 0.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30555	 1	 21.58	 10.65	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30556	 1	 16.87	 7.44	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30557	 1	 2.08	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30558	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30559	 1	 5.28	 2.68	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30560	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30561	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30562	 1	 18.44	 10.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30563	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30564	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30565	 1	 15.2	 8.8	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30566	 1	 5.28	 3.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30567	 1	 16.33	 3.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30568	 1	 2.42	 1.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30569	 1	 7.29	 4.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30570	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	30571	 1	 12.67	 5.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30572	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30573	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30574	 1	 17.09	 10.1	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30575	 1	 74.26	 17.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30576	 1	 10.87	 2.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30577	 1	 6.86	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30578	 1	 6.74	 1.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30579	 1	 8.76	 2.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30580	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30581	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30582	 1	 1.76	 0.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30583	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30584	 1	 4.63	 1.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30585	 1	 2.57	 0.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30586	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30587	 1	 10.72	 2.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30588	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30589	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30590	 1	 9.27	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30591	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30592	 1	 5.89	 1.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30593	 1	 11.18	 2.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30594	 1	 7.86	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30595	 1	 14.28	 3.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30596	 1	 8.25	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30597	 1	 9.15	 2.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30598	 1	 4.0	 0.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30599	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30600	 1	 11.18	 2.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30601	 1	 3.43	 0.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30602	 1	 1.29	 0.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30603	 1	 6.04	 2.79	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30604	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30605	 1	 3.53	 0.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30606	 1	 9.58	 2.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30607	 1	 4.5	 2.31	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30608	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30609	 1	 4.92	 2.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30610	 1	 14.36	 8.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30611	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30612	 1	 6.77	 3.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30613	 1	 4.02	 2.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30614	 1	 3.06	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30615	 1	 4.04	 2.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30616	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30617	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30618	 1	 2.38	 1.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30619	 1	 6.84	 3.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30620	 1	 3.81	 2.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30621	 1	 1.49	 0.84	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30622	 1	 6.7	 3.17	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30623	 1	 5.21	 2.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30624	 1	 5.66	 3.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30625	 1	 4.08	 1.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30626	 1	 4.49	 2.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30627	 1	 10.68	 4.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30628	 1	 8.23	 4.08	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30629	 1	 11.09	 6.05	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30630	 1	 6.66	 3.48	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30631	 1	 10.26	 6.07	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30632	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30633	 1	 8.13	 4.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30634	 1	 7.19	 3.6	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30635	 1	 7.71	 4.44	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30636	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30637	 1	 12.43	 6.83	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30638	 1	 5.48	 3.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30639	 1	 9.02	 5.41	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30640	 1	 11.58	 6.74	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30641	 1	 9.11	 5.39	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30642	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30643	 1	 5.58	 2.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30644	 1	 14.85	 7.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30645	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30646	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30647	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30648	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30649	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30650	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30651	 1	 6.6	 2.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30652	 1	 5.47	 2.7	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30653	 1	 2.67	 1.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30654	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30655	 1	 4.13	 2.33	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30656	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30657	 1	 18.53	 10.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30658	 1	 4.4	 2.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30659	 1	 1.33	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30660	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30661	 1	 5.43	 2.63	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30662	 1	 6.35	 3.29	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30663	 1	 8.7	 4.82	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30664	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30665	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30666	 1	 7.9	 3.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30667	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30668	 1	 6.36	 2.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30669	 1	 10.83	 5.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30670	 1	 2.58	 1.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30671	 1	 3.39	 1.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30672	 1	 3.98	 2.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30673	 1	 9.14	 4.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30674	 1	 11.5	 6.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30675	 1	 16.11	 6.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30676	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30677	 1	 13.8	 6.83	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30678	 1	 9.43	 5.02	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30679	 1	 7.57	 3.83	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30680	 1	 6.71	 3.45	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30681	 1	 5.63	 2.65	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30682	 1	 14.74	 7.53	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30683	 1	 16.65	 8.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30684	 1	 14.45	 8.17	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30685	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30686	 1	 5.82	 2.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30687	 1	 5.37	 3.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30688	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30689	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30690	 1	 8.92	 3.98	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30691	 1	 5.48	 3.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30692	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30693	 1	 9.47	 5.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30694	 1	 8.08	 4.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30695	 1	 5.41	 2.64	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30696	 1	 10.79	 6.21	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30697	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30698	 1	 4.06	 2.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30699	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30700	 1	 8.09	 4.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30701	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30702	 1	 5.56	 3.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30703	 1	 8.01	 4.17	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30704	 1	 10.09	 4.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30705	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30706	 1	 5.27	 2.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30707	 1	 2.45	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30708	 1	 6.29	 3.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30709	 1	 8.1	 4.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30710	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30711	 1	 16.45	 7.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30712	 1	 8.85	 4.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30713	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	30714	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30715	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30716	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30717	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30718	 1	 8.44	 4.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30719	 1	 10.12	 2.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30720	 1	 3.48	 1.79	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30721	 1	 2.82	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30722	 1	 2.36	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30723	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30724	 1	 2.0	 0.93	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30725	 1	 3.01	 1.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30726	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30727	 1	 6.41	 3.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30728	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30729	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30730	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30731	 1	 8.34	 4.34	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30732	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30733	 1	 8.78	 3.53	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30734	 1	 11.19	 4.86	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30735	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30736	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30737	 1	 2.79	 1.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30738	 1	 3.93	 2.28	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30739	 1	 11.28	 2.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30740	 1	 10.9	 5.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30741	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30742	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30743	 1	 6.69	 3.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30744	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30745	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30746	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30747	 1	 9.05	 5.31	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30748	 1	 5.73	 2.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30749	 1	 7.52	 3.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30750	 1	 46.86	 28.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30751	 1	 45.86	 22.45	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30752	 1	 22.82	 10.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30753	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30754	 1	 5.69	 2.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30755	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30756	 1	 12.95	 5.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30757	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30758	 1	 8.75	 4.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30759	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30760	 1	 3.24	 1.73	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30761	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30762	 1	 7.04	 3.26	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30763	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30764	 1	 6.05	 3.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30765	 1	 19.71	 10.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30766	 1	 35.64	 21.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30767	 1	 46.34	 24.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30768	 1	 34.08	 16.1	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30769	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30770	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30771	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30772	 1	 96.83	 40.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30773	 1	 51.38	 21.38	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30774	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30775	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30776	 1	 57.52	 27.86	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30777	 1	 18.05	 8.68	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30778	 1	 5.18	 2.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30779	 1	 6.2	 3.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30780	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30781	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30782	 1	 12.59	 6.72	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30783	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30784	 1	 17.94	 10.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30785	 1	 56.47	 25.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30786	 1	 3.62	 2.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30787	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30788	 1	 15.93	 9.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30789	 1	 8.79	 4.91	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30790	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30791	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30792	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30793	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30794	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30795	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30796	 1	 8.04	 4.85	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30797	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30798	 1	 4.45	 2.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30799	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30800	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30801	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30802	 1	 11.38	 5.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30803	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	30804	 1	 12.93	 7.63	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30805	 1	 6.98	 3.83	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30806	 1	 3.44	 1.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30807	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30808	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30809	 1	 11.58	 6.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30810	 1	 4.91	 2.59	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30811	 1	 5.56	 2.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30812	 1	 7.22	 3.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30813	 1	 5.11	 2.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30814	 1	 11.69	 5.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30815	 1	 11.26	 5.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30816	 1	 7.42	 1.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30817	 1	 13.04	 5.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30818	 1	 15.93	 7.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30819	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30820	 1	 12.61	 5.65	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30821	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30822	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30823	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30824	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30825	 1	 1.13	 0.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30826	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30827	 1	 18.08	 11.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30828	 1	 9.52	 5.07	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30829	 1	 5.37	 3.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30830	 1	 9.26	 5.62	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30831	 1	 12.67	 6.85	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30832	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30833	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30834	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30835	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30836	 1	 19.55	 10.58	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30837	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30838	 1	 7.48	 3.82	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30839	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30840	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30841	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30842	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30843	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30844	 1	 8.58	 4.73	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30845	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30846	 1	 3.75	 1.9	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30847	 1	 11.88	 7.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30848	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30849	 1	 7.15	 4.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30850	 1	 15.08	 8.43	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30851	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30852	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30853	 1	 0.21	 0.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30854	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30855	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30856	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30857	 1	 2.67	 1.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30858	 1	 0.68	 0.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30859	 1	 5.03	 2.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30860	 1	 15.3	 8.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30861	 1	 6.67	 3.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30862	 1	 7.24	 3.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30863	 1	 9.41	 4.78	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30864	 1	 11.28	 5.19	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30865	 1	 14.47	 7.46	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30866	 1	 12.05	 2.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30867	 1	 9.98	 2.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30868	 1	 12.26	 2.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30869	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30870	 1	 9.14	 2.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30871	 1	 8.42	 1.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30872	 1	 5.77	 1.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30873	 1	 9.81	 2.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30874	 1	 9.16	 2.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30875	 1	 4.81	 1.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30876	 1	 7.19	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30877	 1	 7.82	 1.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30878	 1	 10.35	 2.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30879	 1	 7.29	 1.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30880	 1	 5.4	 1.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30881	 1	 10.29	 2.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30882	 1	 3.45	 0.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30883	 1	 5.11	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30884	 1	 3.38	 0.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30885	 1	 4.05	 0.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30886	 1	 4.47	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30887	 1	 7.85	 1.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30888	 1	 4.34	 1.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30889	 1	 2.19	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30890	 1	 3.64	 2.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30891	 1	 1.98	 0.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30892	 1	 3.95	 2.48	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30893	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30894	 1	 5.17	 2.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30895	 1	 4.01	 0.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30896	 1	 4.5	 1.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30897	 1	 6.08	 3.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30898	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30899	 1	 5.43	 1.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30900	 1	 5.09	 1.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30901	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30902	 1	 8.21	 4.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30903	 1	 20.85	 9.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30904	 1	 13.61	 8.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30905	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30906	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30907	 1	 15.98	 8.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30908	 1	 5.42	 2.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30909	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	30910	 1	 5.08	 2.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30911	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	30912	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30913	 1	 4.32	 2.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30914	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30915	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30916	 1	 8.17	 4.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30917	 1	 5.13	 2.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30918	 1	 3.35	 2.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30919	 1	 10.84	 6.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30920	 1	 4.33	 2.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30921	 1	 2.03	 0.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30922	 1	 1.73	 0.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30923	 1	 2.19	 1.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30924	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30925	 1	 2.69	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30926	 1	 8.13	 4.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30927	 1	 3.69	 2.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30928	 1	 9.85	 4.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30929	 1	 8.85	 5.27	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30930	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30931	 1	 5.58	 2.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30932	 1	 3.38	 2.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30933	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30934	 1	 5.36	 2.83	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30935	 1	 1.73	 1.02	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30936	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30937	 1	 7.38	 3.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30938	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30939	 1	 9.63	 5.6	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30940	 1	 12.14	 5.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30941	 1	 10.11	 5.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30942	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30943	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30944	 1	 6.8	 3.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30945	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30946	 1	 0.86	 0.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30947	 1	 2.72	 1.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30948	 1	 4.66	 2.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30949	 1	 1.86	 0.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30950	 1	 8.85	 2.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30951	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30952	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	30953	 1	 5.9	 3.17	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30954	 1	 8.6	 4.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30955	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30956	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30957	 1	 7.05	 3.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30958	 1	 8.36	 4.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30959	 1	 3.91	 2.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30960	 1	 6.81	 3.15	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30961	 1	 4.29	 2.6	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30962	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30963	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30964	 1	 4.48	 1.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30965	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30966	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30967	 1	 4.06	 0.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30968	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30969	 1	 5.96	 3.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30970	 1	 6.68	 3.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30971	 1	 18.38	 10.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30972	 1	 7.45	 4.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30973	 1	 7.37	 4.03	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30974	 1	 7.24	 1.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30975	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30976	 1	 8.21	 1.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30977	 1	 4.33	 1.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30978	 1	 2.21	 0.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30979	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30980	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30981	 1	 8.62	 2.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30982	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30983	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30984	 1	 3.8	 1.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30985	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30986	 1	 3.95	 0.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30987	 1	 6.87	 1.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30988	 1	 6.49	 3.28	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30989	 1	 5.88	 1.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30990	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30991	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30992	 1	 5.22	 2.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30993	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30994	 1	 5.75	 3.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30995	 1	 4.71	 2.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30996	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30997	 1	 5.43	 2.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30998	 1	 1.17	 0.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	30999	 1	 2.13	 1.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31000	 1	 1.24	 0.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31001	 1	 4.05	 0.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31002	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31003	 1	 11.02	 6.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31004	 1	 5.96	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31005	 1	 3.37	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31006	 1	 5.43	 1.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31007	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31008	 1	 8.65	 3.96	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31009	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31010	 1	 2.09	 0.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31011	 1	 4.04	 0.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31012	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31013	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31014	 1	 4.85	 2.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31015	 1	 5.29	 2.97	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31016	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31017	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31018	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31019	 1	 9.27	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31020	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31021	 1	 5.85	 1.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31022	 1	 3.95	 0.93	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31023	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31024	 1	 6.89	 1.61	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31025	 1	 5.97	 1.4	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31026	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31027	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31028	 1	 6.14	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31029	 1	 3.46	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31030	 1	 4.98	 1.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31031	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31032	 1	 4.96	 1.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31033	 1	 2.11	 0.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31034	 1	 4.72	 1.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31035	 1	 2.35	 0.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31036	 1	 1.93	 0.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31037	 1	 3.48	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31038	 1	 2.41	 0.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31039	 1	 2.33	 0.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31040	 1	 5.51	 1.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31041	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31042	 1	 5.33	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31043	 1	 4.92	 1.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31044	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31045	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31046	 1	 1.63	 0.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31047	 1	 5.24	 1.22	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31048	 1	 4.3	 1.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31049	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31050	 1	 1.49	 0.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31051	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31052	 1	 5.18	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31053	 1	 7.03	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31054	 1	 3.17	 0.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31055	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31056	 1	 6.84	 1.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31057	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31058	 1	 10.67	 2.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31059	 1	 7.02	 1.65	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31060	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31061	 1	 4.2	 0.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31062	 1	 3.53	 0.83	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31063	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31064	 1	 4.9	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31065	 1	 13.75	 3.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31066	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31067	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31068	 1	 4.79	 1.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31069	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31070	 1	 5.49	 1.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31071	 1	 6.9	 1.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31072	 1	 6.96	 1.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31073	 1	 11.02	 2.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31074	 1	 3.97	 0.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31075	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31076	 1	 9.53	 2.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31077	 1	 7.77	 1.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31078	 1	 6.16	 1.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31079	 1	 6.84	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31080	 1	 5.38	 1.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31081	 1	 6.58	 1.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31082	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31083	 1	 4.36	 1.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31084	 1	 5.92	 1.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31085	 1	 5.21	 1.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31086	 1	 5.28	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31087	 1	 4.14	 0.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31088	 1	 2.09	 0.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31089	 1	 3.38	 0.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31090	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31091	 1	 6.12	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31092	 1	 8.9	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31093	 1	 13.15	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31094	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31095	 1	 8.55	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31096	 1	 1.99	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31097	 1	 4.07	 0.95	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31098	 1	 1.69	 0.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31099	 1	 2.19	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31100	 1	 3.35	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31101	 1	 1.19	 0.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31102	 1	 4.16	 0.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31103	 1	 12.82	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31104	 1	 3.45	 0.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31105	 1	 16.24	 3.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31106	 1	 13.22	 3.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31107	 1	 5.31	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31108	 1	 7.71	 1.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31109	 1	 7.12	 1.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31110	 1	 10.68	 2.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31111	 1	 9.36	 2.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31112	 1	 6.03	 1.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31113	 1	 4.46	 1.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31114	 1	 5.61	 1.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31115	 1	 4.71	 1.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31116	 1	 3.98	 0.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31117	 1	 2.15	 0.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31118	 1	 6.02	 1.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31119	 1	 5.29	 2.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31120	 1	 6.85	 1.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31121	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31122	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31123	 1	 9.56	 5.41	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31124	 1	 3.15	 1.71	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31125	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31126	 1	 6.74	 3.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31127	 1	 8.4	 1.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31128	 1	 9.22	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31129	 1	 12.16	 2.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31130	 1	 3.75	 0.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31131	 1	 3.71	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31132	 1	 7.21	 1.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31133	 1	 4.33	 0.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31134	 1	 4.99	 1.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31135	 1	 3.42	 0.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31136	 1	 8.83	 2.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31137	 1	 7.66	 1.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31138	 1	 6.68	 1.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31139	 1	 6.61	 1.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31140	 1	 4.84	 1.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31141	 1	 1.24	 0.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31142	 1	 3.3	 0.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31143	 1	 5.72	 1.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31144	 1	 8.04	 1.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31145	 1	 4.97	 3.07	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31146	 1	 3.99	 2.06	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31147	 1	 9.53	 5.15	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31148	 1	 10.55	 2.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31149	 1	 6.01	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31150	 1	 5.96	 1.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31151	 1	 4.73	 1.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31152	 1	 7.2	 3.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31153	 1	 2.48	 1.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31154	 1	 3.5	 2.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31155	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31156	 1	 9.69	 5.54	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31157	 1	 4.57	 2.72	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31158	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31159	 1	 4.22	 0.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31160	 1	 3.71	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31161	 1	 7.36	 1.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31162	 1	 8.73	 4.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31163	 1	 5.05	 2.9	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31164	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31165	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31166	 1	 2.47	 0.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31167	 1	 9.27	 4.57	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31168	 1	 5.36	 1.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31169	 1	 5.57	 1.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31170	 1	 12.67	 6.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31171	 1	 10.04	 4.91	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31172	 1	 17.49	 9.65	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31173	 1	 1.78	 0.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31174	 1	 4.57	 1.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31175	 1	 11.54	 6.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31176	 1	 9.11	 5.03	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31177	 1	 7.61	 4.12	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31178	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	31179	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	31180	 1	 5.96	 3.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31181	 1	 14.49	 6.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31182	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31183	 1	 5.07	 2.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31184	 1	 4.19	 2.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31185	 1	 15.22	 7.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31186	 1	 2.28	 1.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31187	 1	 8.74	 4.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31188	 1	 1.17	 0.6	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31189	 1	 0.01	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31190	 1	 0.02	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31191	 1	 0.97	 0.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31192	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31193	 1	 4.54	 2.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31194	 1	 3.6	 2.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31195	 1	 6.88	 3.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31196	 1	 2.85	 1.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31197	 1	 5.02	 2.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31198	 1	 14.17	 7.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31199	 1	 4.31	 2.54	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31200	 1	 5.63	 2.99	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31201	 1	 4.34	 2.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31202	 1	 5.57	 2.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31203	 1	 2.44	 1.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31204	 1	 3.75	 1.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31205	 1	 3.44	 1.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31206	 1	 5.56	 2.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31207	 1	 3.14	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31208	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31209	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31210	 1	 12.36	 7.28	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31211	 1	 3.5	 1.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31212	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31213	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31214	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31215	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31216	 1	 6.43	 4.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31217	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31218	 1	 10.61	 6.02	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31219	 1	 3.31	 1.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31220	 1	 5.52	 3.04	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31221	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31222	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31223	 1	 2.32	 1.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31224	 1	 8.24	 4.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31225	 1	 3.81	 2.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31226	 1	 3.77	 2.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31227	 1	 4.79	 2.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31228	 1	 3.39	 1.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31229	 1	 5.65	 2.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31230	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31231	 1	 3.8	 2.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31232	 1	 8.53	 4.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31233	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31234	 1	 5.69	 3.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31235	 1	 3.71	 1.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31236	 1	 6.85	 3.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31237	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31238	 1	 3.09	 1.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31239	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31240	 1	 4.84	 2.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31241	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31242	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31243	 1	 5.37	 3.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31244	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31245	 1	 3.49	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31246	 1	 3.87	 1.81	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31247	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31248	 1	 6.41	 3.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31249	 1	 3.7	 2.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31250	 1	 2.34	 1.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31251	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31252	 1	 5.27	 2.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31253	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31254	 1	 5.5	 2.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31255	 1	 12.79	 5.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31256	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31257	 1	 7.74	 4.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31258	 1	 7.08	 4.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31259	 1	 6.5	 3.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31260	 1	 11.5	 6.09	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31261	 1	 5.97	 2.9	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31262	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31263	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31264	 1	 3.87	 2.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31265	 1	 4.41	 2.21	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31266	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31267	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31268	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31269	 1	 9.82	 5.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31270	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31271	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31272	 1	 6.15	 3.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31273	 1	 5.88	 3.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31274	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31275	 1	 7.16	 3.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31276	 1	 8.41	 4.19	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31277	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31278	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31279	 1	 3.22	 1.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31280	 1	 5.6	 3.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31281	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31282	 1	 3.54	 2.07	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31283	 1	 6.06	 3.26	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31284	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31285	 1	 9.37	 5.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31286	 1	 8.59	 1.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31287	 1	 6.96	 3.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31288	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31289	 1	 4.77	 2.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31290	 1	 7.88	 4.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31291	 1	 9.37	 4.48	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31292	 1	 4.76	 2.31	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31293	 1	 6.19	 1.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31294	 1	 3.36	 0.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31295	 1	 3.63	 0.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31296	 1	 4.5	 2.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31297	 1	 4.43	 1.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31298	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31299	 1	 2.73	 1.66	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31300	 1	 5.07	 2.85	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31301	 1	 5.91	 2.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31302	 1	 21.56	 10.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31303	 1	 11.19	 5.09	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31304	 1	 10.2	 5.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31305	 1	 5.01	 2.31	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31306	 1	 4.25	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31307	 1	 3.62	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31308	 1	 3.43	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31309	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31310	 1	 5.59	 2.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31311	 1	 2.23	 1.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31312	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31313	 1	 3.4	 1.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31314	 1	 5.27	 3.17	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31315	 1	 2.29	 1.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31316	 1	 2.35	 1.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31317	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31318	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31319	 1	 4.49	 2.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31320	 1	 2.5	 1.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31321	 1	 2.63	 1.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31322	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31323	 1	 5.81	 2.79	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31324	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31325	 1	 6.02	 2.91	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31326	 1	 7.55	 3.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31327	 1	 12.74	 7.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31328	 1	 4.52	 1.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31329	 1	 1.95	 1.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31330	 1	 5.69	 3.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31331	 1	 3.66	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31332	 1	 5.78	 3.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31333	 1	 3.8	 1.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31334	 1	 3.08	 1.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31335	 1	 5.57	 3.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31336	 1	 5.39	 2.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31337	 1	 4.26	 2.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31338	 1	 4.37	 2.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31339	 1	 4.39	 2.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31340	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31341	 1	 4.44	 2.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31342	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31343	 1	 4.6	 2.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31344	 1	 5.4	 3.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31345	 1	 6.65	 3.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31346	 1	 12.76	 5.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31347	 1	 12.57	 5.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31348	 1	 9.07	 5.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31349	 1	 5.91	 3.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31350	 1	 4.66	 2.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31351	 1	 3.31	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31352	 1	 6.11	 3.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31353	 1	 5.35	 2.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31354	 1	 17.37	 7.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31355	 1	 8.64	 4.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31356	 1	 7.17	 3.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31357	 1	 7.93	 4.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31358	 1	 3.84	 1.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31359	 1	 5.5	 3.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31360	 1	 5.25	 2.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31361	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31362	 1	 3.93	 2.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31363	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31364	 1	 9.23	 4.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31365	 1	 4.98	 2.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31366	 1	 3.07	 1.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31367	 1	 4.03	 2.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31368	 1	 3.02	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31369	 1	 7.27	 2.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31370	 1	 5.65	 2.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31371	 1	 5.12	 2.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31372	 1	 3.06	 1.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31373	 1	 3.36	 1.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31374	 1	 7.63	 4.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31375	 1	 4.17	 2.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31376	 1	 6.53	 3.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31377	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31378	 1	 3.66	 2.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31379	 1	 5.27	 3.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31380	 1	 6.51	 3.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31381	 1	 5.14	 2.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31382	 1	 5.57	 3.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31383	 1	 6.04	 2.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31384	 1	 6.94	 3.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31385	 1	 6.04	 3.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31386	 1	 3.84	 2.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31387	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31388	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31389	 1	 16.17	 7.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31390	 1	 5.87	 3.33	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31391	 1	 24.47	 11.44	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31392	 1	 4.51	 2.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31393	 1	 10.66	 5.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31394	 1	 26.94	 11.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31395	 1	 25.96	 12.23	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31396	 1	 9.46	 4.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31397	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31398	 1	 17.43	 7.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31399	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31400	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31401	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31402	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31403	 1	 4.86	 2.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31404	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31405	 1	 5.66	 3.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31406	 1	 3.63	 1.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31407	 1	 5.13	 3.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31408	 1	 3.29	 1.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31409	 1	 16.53	 8.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31410	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31411	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31412	 1	 7.68	 3.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31413	 1	 6.02	 3.33	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31414	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31415	 1	 6.65	 3.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31416	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31417	 1	 18.07	 8.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31418	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31419	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31420	 1	 5.94	 2.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31421	 1	 11.82	 5.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31422	 1	 3.32	 1.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31423	 1	 2.69	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31424	 1	 4.21	 1.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31425	 1	 5.51	 2.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31426	 1	 8.06	 3.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31427	 1	 11.2	 5.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31428	 1	 8.17	 4.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31429	 1	 2.88	 0.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31430	 1	 5.04	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31431	 1	 6.91	 1.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31432	 1	 5.33	 3.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31433	 1	 4.13	 0.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31434	 1	 4.38	 1.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31435	 1	 4.94	 1.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31436	 1	 3.55	 0.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31437	 1	 2.53	 0.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31438	 1	 7.39	 1.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31439	 1	 4.6	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31440	 1	 8.0	 1.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31441	 1	 5.92	 1.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31442	 1	 2.36	 0.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31443	 1	 10.1	 2.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31444	 1	 6.97	 1.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31445	 1	 9.81	 2.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31446	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31447	 1	 5.4	 1.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31448	 1	 7.61	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31449	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31450	 1	 3.84	 1.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31451	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31452	 1	 3.62	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31453	 1	 5.46	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31454	 1	 4.31	 1.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31455	 1	 4.76	 2.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31456	 1	 8.27	 4.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31457	 1	 7.19	 4.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31458	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31459	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	31460	 1	 7.1	 3.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31461	 1	 7.73	 4.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31462	 1	 14.14	 5.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31463	 1	 7.27	 3.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31464	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31465	 1	 6.35	 3.09	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31466	 1	 4.67	 1.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31467	 1	 6.14	 2.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31468	 1	 4.13	 0.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31469	 1	 9.3	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31470	 1	 5.46	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31471	 1	 3.53	 0.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31472	 1	 4.39	 1.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31473	 1	 5.16	 1.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31474	 1	 6.96	 1.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31475	 1	 18.14	 8.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31476	 1	 5.86	 1.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31477	 1	 5.97	 1.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31478	 1	 5.47	 2.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31479	 1	 1.71	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31480	 1	 11.22	 5.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31481	 1	 8.82	 4.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31482	 1	 9.61	 5.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31483	 1	 9.29	 5.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31484	 1	 6.74	 2.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31485	 1	 24.19	 13.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31486	 1	 6.43	 3.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31487	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31488	 1	 18.09	 7.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31489	 1	 11.48	 6.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31490	 1	 3.42	 1.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31491	 1	 7.68	 4.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31492	 1	 6.27	 3.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31493	 1	 5.46	 2.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31494	 1	 3.87	 2.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31495	 1	 6.23	 3.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31496	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31497	 1	 7.8	 4.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31498	 1	 5.88	 2.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31499	 1	 6.25	 2.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31500	 1	 6.0	 2.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31501	 1	 3.44	 1.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31502	 1	 7.45	 3.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31503	 1	 7.16	 3.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31504	 1	 4.95	 2.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31505	 1	 11.92	 5.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31506	 1	 10.41	 5.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31507	 1	 4.48	 2.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31508	 1	 5.58	 3.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31509	 1	 3.62	 1.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31510	 1	 6.52	 3.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31511	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31512	 1	 4.33	 2.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31513	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31514	 1	 8.06	 4.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31515	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31516	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31517	 1	 10.55	 6.26	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31518	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31519	 1	 8.7	 4.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31520	 1	 3.58	 1.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31521	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31522	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31523	 1	 2.35	 1.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31524	 1	 12.15	 6.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31525	 1	 3.72	 2.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31526	 1	 7.56	 4.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31527	 1	 5.39	 2.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31528	 1	 7.4	 3.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31529	 1	 6.63	 3.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31530	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31531	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31532	 1	 1.79	 0.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31533	 1	 7.38	 4.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31534	 1	 5.79	 3.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31535	 1	 4.43	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31536	 1	 4.15	 2.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31537	 1	 4.12	 2.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31538	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31539	 1	 12.78	 6.75	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31540	 1	 10.92	 6.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31541	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31542	 1	 12.69	 7.29	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31543	 1	 9.35	 5.33	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31544	 1	 2.94	 0.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31545	 1	 3.84	 0.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31546	 1	 1.97	 0.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31547	 1	 2.04	 0.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31548	 1	 4.71	 1.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31549	 1	 1.43	 0.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31550	 1	 2.86	 0.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31551	 1	 2.61	 0.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31552	 1	 4.28	 2.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31553	 1	 4.35	 1.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31554	 1	 1.64	 0.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31555	 1	 3.64	 1.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31556	 1	 4.78	 1.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31557	 1	 6.54	 3.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31558	 1	 2.59	 0.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31559	 1	 4.38	 2.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31560	 1	 3.51	 1.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31561	 1	 5.3	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31562	 1	 3.12	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31563	 1	 5.92	 2.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31564	 1	 1.73	 0.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31565	 1	 1.5	 0.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31566	 1	 2.45	 1.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31567	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31568	 1	 6.45	 3.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31569	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31570	 1	 2.89	 1.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31571	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31572	 1	 1.93	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31573	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31574	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31575	 1	 4.03	 2.11	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31576	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31577	 1	 6.46	 3.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31578	 1	 5.63	 2.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31579	 1	 4.65	 2.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31580	 1	 7.74	 4.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31581	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31582	 1	 11.04	 6.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31583	 1	 2.45	 1.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31584	 1	 5.63	 2.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31585	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31586	 1	 8.51	 4.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31587	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31588	 1	 9.89	 6.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31589	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31590	 1	 3.52	 1.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31591	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31592	 1	 3.12	 1.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31593	 1	 6.28	 3.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31594	 1	 60.37	 31.82	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31595	 1	 52.25	 24.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31596	 1	 60.43	 27.08	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31597	 1	 12.08	 5.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31598	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31599	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31600	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31601	 1	 12.82	 6.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31602	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31603	 1	 16.57	 8.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31604	 1	 5.91	 2.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31605	 1	 8.72	 4.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31606	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31607	 1	 52.65	 28.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31608	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31609	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31610	 1	 2.32	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31611	 1	 3.15	 1.6	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31612	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31613	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31614	 1	 20.97	 8.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31615	 1	 11.31	 5.23	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31616	 1	 16.64	 7.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31617	 1	 63.17	 30.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31618	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31619	 1	 8.04	 4.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31620	 1	 9.16	 5.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31621	 1	 3.4	 2.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31622	 1	 6.11	 3.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31623	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31624	 1	 6.02	 3.65	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31625	 1	 8.58	 4.65	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31626	 1	 4.22	 2.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31627	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31628	 1	 6.6	 3.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31629	 1	 6.38	 3.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31630	 1	 6.3	 3.19	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31631	 1	 9.35	 4.85	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31632	 1	 2.09	 1.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31633	 1	 3.23	 1.91	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31634	 1	 3.73	 1.91	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31635	 1	 1.86	 1.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31636	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31637	 1	 8.3	 5.05	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31638	 1	 5.85	 3.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31639	 1	 4.85	 2.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31640	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31641	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31642	 1	 2.11	 1.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31643	 1	 5.6	 2.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31644	 1	 7.09	 4.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31645	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31646	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31647	 1	 6.32	 3.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31648	 1	 5.9	 3.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31649	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31650	 1	 7.12	 3.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31651	 1	 10.71	 5.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31652	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31653	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31654	 1	 4.56	 2.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31655	 1	 12.74	 5.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31656	 1	 14.58	 7.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31657	 1	 3.62	 1.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31658	 1	 9.75	 4.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31659	 1	 4.96	 2.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31660	 1	 5.5	 3.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31661	 1	 12.25	 4.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31662	 1	 11.52	 5.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31663	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31664	 1	 5.75	 2.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31665	 1	 14.69	 7.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31666	 1	 10.41	 5.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31667	 1	 14.33	 7.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31668	 1	 8.15	 4.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31669	 1	 4.51	 2.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31670	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31671	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31672	 1	 7.78	 3.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31673	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31674	 1	 4.69	 2.31	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31675	 1	 14.31	 7.57	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31676	 1	 3.55	 2.15	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31677	 1	 9.85	 5.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31678	 1	 0.52	 0.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31679	 1	 9.4	 5.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31680	 1	 6.02	 2.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31681	 1	 7.45	 3.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31682	 1	 3.36	 1.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31683	 1	 12.2	 5.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31684	 1	 8.68	 4.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31685	 1	 8.17	 2.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31686	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31687	 1	 7.55	 2.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31688	 1	 18.27	 8.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31689	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31690	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31691	 1	 5.04	 2.76	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31692	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31693	 1	 7.55	 3.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31694	 1	 13.14	 7.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31695	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31696	 1	 4.04	 2.38	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31697	 1	 82.03	 43.6	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31698	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31699	 1	 27.55	 15.92	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31700	 1	 18.65	 8.33	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31701	 1	 7.21	 3.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31702	 1	 4.24	 2.09	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31703	 1	 21.76	 9.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31704	 1	 8.67	 4.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31705	 1	 4.43	 2.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31706	 1	 3.72	 2.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31707	 1	 8.65	 4.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31708	 1	 2.12	 1.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31709	 1	 15.64	 6.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31710	 1	 6.31	 3.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31711	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31712	 1	 3.44	 1.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31713	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31714	 1	 2.67	 1.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31715	 1	 4.72	 2.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31716	 1	 11.22	 5.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31717	 1	 7.94	 4.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31718	 1	 2.58	 1.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31719	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31720	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	31721	 1	 6.34	 3.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31722	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31723	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31724	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31725	 1	 10.06	 4.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31726	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31727	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31728	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31729	 1	 40.48	 16.87	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31730	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31731	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31732	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31733	 1	 7.91	 3.97	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31734	 1	 7.37	 4.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31735	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31736	 1	 7.0	 3.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31737	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31738	 1	 6.59	 3.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31739	 1	 23.86	 5.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31740	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31741	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31742	 1	 6.55	 1.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31743	 1	 8.67	 4.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31744	 1	 31.76	 13.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31745	 1	 4.57	 1.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31746	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31747	 1	 3.54	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31748	 1	 7.8	 1.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31749	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31750	 1	 3.21	 0.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31751	 1	 5.76	 1.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31752	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31753	 1	 5.31	 3.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31754	 1	 5.15	 2.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31755	 1	 4.99	 2.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31756	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31757	 1	 6.8	 3.71	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31758	 1	 2.38	 1.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31759	 1	 27.46	 12.76	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31760	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31761	 1	 8.1	 4.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31762	 1	 17.29	 7.33	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31763	 1	 6.34	 3.37	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31764	 1	 13.92	 6.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31765	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31766	 1	 6.92	 3.81	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31767	 1	 11.33	 2.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31768	 1	 1.48	 0.34	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31769	 1	 1.62	 0.38	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31770	 1	 7.24	 1.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31771	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31772	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31773	 1	 2.28	 0.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31774	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31775	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31776	 1	 6.38	 1.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31777	 1	 1.72	 0.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31778	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31779	 1	 4.62	 2.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31780	 1	 6.99	 3.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31781	 1	 11.09	 6.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31782	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31783	 1	 9.4	 5.37	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31784	 1	 10.87	 6.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31785	 1	 15.33	 8.91	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31786	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31787	 1	 11.76	 5.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31788	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31789	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31790	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31791	 1	 4.28	 2.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31792	 1	 5.33	 3.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31793	 1	 10.89	 5.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31794	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31795	 1	 15.88	 8.26	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31796	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31797	 1	 7.71	 4.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31798	 1	 4.74	 2.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31799	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31800	 1	 3.28	 2.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31801	 1	 3.26	 1.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31802	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31803	 1	 6.3	 3.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31804	 1	 7.32	 3.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31805	 1	 8.97	 4.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31806	 1	 8.81	 4.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31807	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31808	 1	 10.69	 5.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31809	 1	 10.68	 6.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31810	 1	 10.3	 5.38	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31811	 1	 6.23	 3.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31812	 1	 2.18	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31813	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31814	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31815	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31816	 1	 7.69	 4.21	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31817	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31818	 1	 8.44	 4.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31819	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31820	 1	 27.01	 15.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31821	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31822	 1	 9.49	 2.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31823	 1	 9.87	 2.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31824	 1	 11.8	 6.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31825	 1	 8.72	 4.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31826	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31827	 1	 13.76	 6.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31828	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31829	 1	 16.02	 8.67	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31830	 1	 14.48	 7.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31831	 1	 9.74	 6.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31832	 1	 36.46	 13.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31833	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31834	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31835	 1	 12.05	 6.48	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31836	 1	 6.39	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31837	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31838	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31839	 1	 18.37	 4.14	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31840	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31841	 1	 7.13	 1.6	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31842	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31843	 1	 12.51	 2.82	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31844	 1	 7.76	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31845	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31846	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31847	 1	 14.79	 3.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31848	 1	 13.43	 3.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31849	 1	 17.39	 4.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31850	 1	 13.19	 6.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31851	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31852	 1	 3.02	 0.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31853	 1	 3.75	 0.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31854	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31855	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31856	 1	 3.13	 0.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31857	 1	 5.0	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31858	 1	 4.79	 2.91	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31859	 1	 5.45	 1.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31860	 1	 5.4	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31861	 1	 12.76	 2.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31862	 1	 2.6	 0.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31863	 1	 3.67	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31864	 1	 4.35	 1.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31865	 1	 28.28	 6.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31866	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	31867	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31868	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31869	 1	 5.68	 1.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31870	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31871	 1	 6.74	 3.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31872	 1	 4.54	 2.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31873	 1	 13.07	 3.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31874	 1	 13.24	 3.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31875	 1	 2.19	 0.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31876	 1	 17.37	 4.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31877	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31878	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31879	 1	 3.75	 0.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31880	 1	 5.04	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31881	 1	 5.21	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31882	 1	 13.73	 3.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31883	 1	 8.95	 2.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31884	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31885	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31886	 1	 14.14	 3.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31887	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31888	 1	 5.23	 1.22	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31889	 1	 8.35	 1.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31890	 1	 6.69	 1.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31891	 1	 9.29	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31892	 1	 2.9	 0.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31893	 1	 2.2	 0.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31894	 1	 3.92	 0.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31895	 1	 1.6	 0.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31896	 1	 1.35	 0.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31897	 1	 1.39	 0.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31898	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31899	 1	 10.04	 2.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31900	 1	 9.88	 2.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31901	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31902	 1	 5.45	 1.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31903	 1	 8.44	 1.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31904	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31905	 1	 12.56	 2.87	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31906	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31907	 1	 6.66	 1.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31908	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31909	 1	 5.36	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31910	 1	 5.19	 1.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31911	 1	 3.16	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31912	 1	 4.36	 0.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31913	 1	 4.06	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31914	 1	 17.34	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31915	 1	 3.23	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31916	 1	 3.82	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31917	 1	 10.57	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31918	 1	 3.68	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31919	 1	 5.37	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31920	 1	 11.82	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31921	 1	 3.11	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31922	 1	 3.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31923	 1	 3.32	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31924	 1	 3.16	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31925	 1	 3.16	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31926	 1	 2.98	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31927	 1	 5.08	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31928	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31929	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	31930	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31931	 1	 5.46	 1.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31932	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31933	 1	 11.13	 2.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31934	 1	 18.29	 4.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31935	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31936	 1	 3.76	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31937	 1	 4.96	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31938	 1	 16.72	 3.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31939	 1	 2.85	 0.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31940	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31941	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31942	 1	 1.94	 1.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31943	 1	 2.75	 1.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31944	 1	 5.51	 3.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31945	 1	 2.71	 1.49	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31946	 1	 4.83	 2.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31947	 1	 4.63	 2.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31948	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31949	 1	 8.07	 4.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31950	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	31951	 1	 20.42	 11.21	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31952	 1	 7.43	 4.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31953	 1	 8.8	 5.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31954	 1	 2.74	 1.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31955	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31956	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31957	 1	 7.31	 4.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31958	 1	 9.58	 5.53	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31959	 1	 8.94	 4.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31960	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31961	 1	 6.62	 3.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31962	 1	 8.79	 5.06	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31963	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31964	 1	 4.09	 2.38	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31965	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31966	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31967	 1	 4.41	 2.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31968	 1	 26.97	 14.92	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31969	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31970	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31971	 1	 11.32	 6.23	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31972	 1	 11.06	 5.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31973	 1	 5.25	 2.91	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31974	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31975	 1	 7.27	 4.29	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31976	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31977	 1	 13.97	 6.71	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31978	 1	 4.41	 2.53	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31979	 1	 11.51	 6.18	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31980	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31981	 1	 2.4	 1.31	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31982	 1	 9.15	 5.36	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31983	 1	 3.61	 1.89	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31984	 1	 23.21	 12.99	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31985	 1	 10.16	 6.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31986	 1	 8.35	 1.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31987	 1	 14.26	 6.61	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31988	 1	 11.32	 6.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31989	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	31990	 1	 6.59	 3.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31991	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31992	 1	 4.76	 2.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31993	 1	 14.04	 7.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31994	 1	 9.59	 4.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31995	 1	 5.17	 2.69	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31996	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31997	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	31998	 1	 8.43	 3.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	31999	 1	 8.2	 4.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32000	 1	 3.04	 1.48	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32001	 1	 6.99	 3.93	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32002	 1	 8.65	 4.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32003	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32004	 1	 3.77	 2.04	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32005	 1	 9.43	 5.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32006	 1	 11.72	 5.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32007	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32008	 1	 4.55	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32009	 1	 1.87	 1.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32010	 1	 7.65	 4.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32011	 1	 6.68	 3.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32012	 1	 13.74	 7.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32013	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32014	 1	 9.22	 5.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32015	 1	 2.94	 1.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32016	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32017	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32018	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32019	 1	 4.25	 1.99	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32020	 1	 10.32	 5.72	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32021	 1	 10.12	 5.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32022	 1	 10.37	 5.2	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32023	 1	 6.77	 3.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32024	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32025	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32026	 1	 4.69	 2.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32027	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32028	 1	 9.09	 2.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32029	 1	 4.57	 2.65	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32030	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32031	 1	 16.8	 6.72	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32032	 1	 6.17	 3.04	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32033	 1	 3.51	 2.14	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32034	 1	 11.33	 5.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32035	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32036	 1	 7.92	 1.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32037	 1	 4.2	 2.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32038	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32039	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32040	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32041	 1	 10.3	 4.15	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32042	 1	 3.05	 0.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32043	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32044	 1	 5.19	 2.73	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32045	 1	 0.01	 0.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32046	 1	 12.25	 7.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32047	 1	 13.64	 6.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32048	 1	 2.49	 1.63	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32049	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32050	 1	 16.82	 8.26	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32051	 1	 17.96	 9.09	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32052	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32053	 1	 6.4	 3.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32054	 1	 14.83	 7.42	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32055	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32056	 1	 26.96	 15.32	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32057	 1	 10.13	 4.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32058	 1	 18.49	 4.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32059	 1	 15.93	 3.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32060	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32061	 1	 3.02	 0.69	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32062	 1	 3.49	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32063	 1	 4.12	 0.95	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32064	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32065	 1	 3.6	 1.72	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32066	 1	 7.82	 3.41	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32067	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32068	 1	 8.05	 4.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32069	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32070	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32071	 1	 5.4	 3.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32072	 1	 6.6	 1.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32073	 1	 16.8	 3.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32074	 1	 6.55	 3.2	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32075	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32076	 1	 3.46	 1.63	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32077	 1	 2.28	 1.36	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32078	 1	 7.08	 4.03	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32079	 1	 2.52	 1.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32080	 1	 7.66	 4.26	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32081	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32082	 1	 8.22	 4.86	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32083	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32084	 1	 3.21	 1.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32085	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32086	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32087	 1	 5.31	 2.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32088	 1	 1.88	 1.06	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32089	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32090	 1	 11.91	 5.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32091	 1	 3.53	 2.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32092	 1	 4.69	 2.33	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32093	 1	 4.7	 2.69	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32094	 1	 7.68	 1.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32095	 1	 3.87	 1.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32096	 1	 2.83	 1.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32097	 1	 3.99	 2.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32098	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32099	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32100	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32101	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32102	 1	 9.74	 4.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32103	 1	 5.98	 2.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32104	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32105	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32106	 1	 3.03	 1.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32107	 1	 3.64	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32108	 1	 4.34	 2.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32109	 1	 5.37	 2.78	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32110	 1	 2.57	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32111	 1	 2.36	 1.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32112	 1	 3.32	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32113	 1	 2.44	 1.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32114	 1	 2.98	 1.8	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32115	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32116	 1	 15.36	 8.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32117	 1	 8.87	 5.57	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32118	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32119	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32120	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	32121	 1	 8.23	 5.06	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32122	 1	 7.93	 4.14	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32123	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32124	 1	 12.17	 5.98	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32125	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32126	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32127	 1	 5.23	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32128	 1	 9.25	 2.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32129	 1	 15.12	 3.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32130	 1	 14.72	 8.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32131	 1	 10.34	 5.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32132	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32133	 1	 4.1	 2.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32134	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32135	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32136	 1	 10.37	 5.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32137	 1	 20.59	 8.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32138	 1	 12.95	 5.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32139	 1	 5.73	 2.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32140	 1	 8.5	 5.08	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32141	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32142	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32143	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32144	 1	 6.99	 4.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32145	 1	 12.1	 6.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32146	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32147	 1	 9.39	 4.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32148	 1	 9.7	 4.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32149	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32150	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32151	 1	 17.96	 8.43	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32152	 1	 5.23	 3.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32153	 1	 12.64	 5.68	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32154	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32155	 1	 2.43	 1.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32156	 1	 9.45	 4.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32157	 1	 5.04	 2.97	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32158	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32159	 1	 4.3	 2.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32160	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32161	 1	 6.79	 3.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32162	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32163	 1	 3.14	 1.55	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32164	 1	 9.15	 5.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32165	 1	 3.35	 2.11	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32166	 1	 9.8	 5.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32167	 1	 5.34	 3.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32168	 1	 8.53	 4.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32169	 1	 8.19	 3.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32170	 1	 5.88	 2.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32171	 1	 7.3	 4.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32172	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32173	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32174	 1	 11.77	 5.94	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32175	 1	 27.77	 14.39	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32176	 1	 15.72	 7.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32177	 1	 10.88	 5.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32178	 1	 3.85	 0.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32179	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32180	 1	 19.36	 8.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32181	 1	 11.44	 5.81	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32182	 1	 3.73	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32183	 1	 6.11	 1.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32184	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32185	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32186	 1	 6.43	 3.12	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32187	 1	 11.26	 5.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32188	 1	 3.05	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32189	 1	 8.46	 1.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32190	 1	 9.37	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32191	 1	 8.93	 2.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32192	 1	 2.69	 1.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32193	 1	 9.89	 2.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32194	 1	 5.89	 1.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32195	 1	 3.26	 1.43	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32196	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32197	 1	 10.86	 4.08	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32198	 1	 1.32	 0.52	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32199	 1	 3.87	 1.45	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32200	 1	 8.87	 -5.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32201	 1	 11.34	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32202	 1	 1.11	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32203	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32204	 1	 8.01	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32205	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32206	 1	 2.79	 1.02	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32207	 1	 1.12	 0.26	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32208	 1	 15.14	 6.97	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32209	 1	 8.61	 3.53	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32210	 1	 13.15	 4.63	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32211	 1	 9.4	 3.25	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32212	 1	 20.43	 6.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32213	 1	 5.63	 2.47	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32214	 1	 4.18	 1.43	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32215	 1	 16.9	 6.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32216	 1	 7.31	 3.18	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32217	 1	 6.23	 1.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32218	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32219	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32220	 1	 3.6	 1.45	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32221	 1	 4.17	 1.53	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32222	 1	 1.8	 0.71	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32223	 1	 2.23	 0.99	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32224	 1	 4.64	 1.66	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32225	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32226	 1	 3.44	 1.27	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32227	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32228	 1	 3.4	 1.17	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32229	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32230	 1	 3.88	 1.18	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32231	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32232	 1	 5.55	 2.16	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32233	 1	 3.78	 1.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32234	 1	 4.64	 1.97	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32235	 1	 7.5	 3.26	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32236	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32237	 1	 9.46	 3.62	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32238	 1	 6.24	 2.19	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32239	 1	 4.95	 1.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32240	 1	 12.92	 2.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32241	 1	 23.02	 5.22	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32242	 1	 6.75	 2.36	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32243	 1	 16.78	 6.5	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32244	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32245	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32246	 1	 59.13	 17.76	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32247	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32248	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32249	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32250	 1	 8.98	 2.65	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32251	 1	 19.31	 5.56	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32252	 1	 6.02	 2.18	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32253	 1	 9.8	 3.06	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32254	 1	 4.93	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32255	 1	 1.98	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32256	 1	 6.88	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32257	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32258	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32259	 1	 1.63	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32260	 1	 3.53	 -0.94	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32261	 1	 2.58	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32262	 1	 6.37	 -0.96	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32263	 1	 9.06	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32264	 1	 6.33	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32265	 1	 1.48	 0.64	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32266	 1	 2.35	 0.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32267	 1	 2.95	 1.05	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32268	 1	 2.53	 1.01	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32269	 1	 5.74	 2.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32270	 1	 4.89	 1.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32271	 1	 6.92	 2.79	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32272	 1	 4.48	 1.53	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32273	 1	 1.35	 0.58	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32274	 1	 2.68	 0.94	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32275	 1	 5.47	 2.27	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32276	 1	 4.89	 2.15	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32277	 1	 3.17	 1.29	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32278	 1	 5.93	 2.56	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32279	 1	 4.08	 1.8	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32280	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32281	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32282	 1	 13.06	 3.57	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32283	 1	 4.26	 1.76	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32284	 1	 6.78	 2.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32285	 1	 14.22	 5.37	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32286	 1	 1.95	 0.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32287	 1	 2.91	 1.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32288	 1	 2.74	 1.05	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32289	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32290	 1	 3.88	 1.42	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32291	 1	 11.26	 4.15	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32292	 1	 5.94	 2.23	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32293	 1	 11.91	 4.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32294	 1	 8.32	 2.95	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32295	 1	 4.77	 2.09	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32296	 1	 5.35	 1.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32297	 1	 10.76	 3.89	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32298	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32299	 1	 61.05	 17.03	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32300	 1	 3.13	 1.22	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32301	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32302	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	32303	 1	 4.29	 2.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32304	 1	 4.87	 2.15	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32305	 1	 5.47	 2.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32306	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32307	 1	 10.57	 3.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32308	 1	 78.07	 21.77	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32309	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32310	 1	 3.39	 1.21	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32311	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32312	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32313	 1	 6.8	 2.81	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32314	 1	 6.75	 1.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32315	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32316	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32317	 1	 5.28	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32318	 1	 6.49	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32319	 1	 2.33	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32320	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32321	 1	 5.68	 2.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32322	 1	 2.05	 0.8	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32323	 1	 5.71	 2.58	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32324	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32325	 1	 8.48	 2.99	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32326	 1	 0.82	 0.32	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32327	 1	 5.62	 1.99	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32328	 1	 13.86	 4.38	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32329	 1	 20.17	 4.61	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32330	 1	 8.25	 2.81	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32331	 1	 10.62	 3.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32332	 1	 8.24	 3.53	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32333	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32334	 1	 7.21	 2.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32335	 1	 8.86	 2.8	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32336	 1	 16.18	 4.66	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32337	 1	 2.27	 0.52	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32338	 1	 9.16	 3.58	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32339	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32340	 1	 2.53	 1.09	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32341	 1	 14.88	 3.34	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32342	 1	 9.5	 2.08	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32343	 1	 2.8	 1.23	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32344	 1	 1.98	 0.71	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32345	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32346	 1	 15.51	 6.17	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32347	 1	 8.11	 3.43	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32348	 1	 3.65	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32349	 1	 5.79	 1.34	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32350	 1	 2.78	 1.13	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32351	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32352	 1	 11.2	 4.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32353	 1	 11.01	 3.91	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32354	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32355	 1	 6.08	 2.68	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32356	 1	 7.13	 2.64	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32357	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32358	 1	 23.75	 8.7	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32359	 1	 1.34	 0.59	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32360	 1	 6.38	 2.52	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32361	 1	 7.23	 2.59	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32362	 1	 2.15	 0.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32363	 1	 7.42	 2.89	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32364	 1	 6.2	 2.49	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32365	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32366	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32367	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32368	 1	 4.15	 1.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32369	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32370	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32371	 1	 9.16	 3.02	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32372	 1	 16.45	 5.81	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32373	 1	 10.63	 3.91	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32374	 1	 10.21	 3.31	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32375	 1	 5.08	 2.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32376	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32377	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32378	 1	 17.8	 7.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32379	 1	 8.73	 3.14	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32380	 1	 9.75	 3.64	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32381	 1	 10.28	 4.12	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32382	 1	 6.45	 2.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32383	 1	 10.58	 3.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32384	 1	 4.19	 1.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32385	 1	 3.66	 1.28	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32386	 1	 8.44	 3.14	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32387	 1	 13.67	 2.98	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32388	 1	 5.15	 2.12	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32389	 1	 4.99	 1.79	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32390	 1	 13.91	 3.08	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32391	 1	 12.98	 4.24	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32392	 1	 5.84	 1.28	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32393	 1	 8.22	 3.1	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32394	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32395	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32396	 1	 3.83	 1.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32397	 1	 3.59	 1.19	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32398	 1	 1.99	 0.85	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32399	 1	 1.86	 0.8	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32400	 1	 1.81	 0.71	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32401	 1	 2.15	 0.93	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32402	 1	 5.01	 1.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32403	 1	 1.84	 0.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32404	 1	 2.18	 0.88	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32405	 1	 2.72	 1.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32406	 1	 3.61	 1.54	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32407	 1	 2.67	 1.09	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32408	 1	 1.7	 0.68	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32409	 1	 2.48	 1.1	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32410	 1	 1.49	 0.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32411	 1	 16.99	 6.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32412	 1	 10.29	 4.18	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32413	 1	 12.98	 4.5	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32414	 1	 4.17	 1.56	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32415	 1	 6.18	 2.31	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32416	 1	 1.26	 0.49	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32417	 1	 3.15	 1.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32418	 1	 3.16	 1.17	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32419	 1	 8.02	 2.98	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32420	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32421	 1	 1.76	 0.77	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32422	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	32423	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32424	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32425	 1	 5.15	 2.36	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32426	 1	 5.18	 1.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32427	 1	 6.78	 2.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32428	 1	 14.3	 5.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32429	 1	 2.09	 0.76	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32430	 1	 18.73	 6.63	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32431	 1	 84.09	 23.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32432	 1	 8.34	 3.26	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32433	 1	 5.49	 1.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32434	 1	 36.67	 11.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32435	 1	 4.48	 1.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32436	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32437	 1	 8.7	 3.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32438	 1	 0.6	 0.09	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32439	 1	 96.2	 36.16	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32440	 1	 2.33	 1.03	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32441	 1	 21.69	 9.49	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32442	 1	 36.27	 13.53	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32443	 1	 5.41	 2.23	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32444	 1	 4.85	 2.01	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32445	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32446	 1	 20.63	 7.31	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32447	 1	 5.8	 2.28	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32448	 1	 6.49	 2.26	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32449	 1	 9.46	 3.28	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32450	 1	 4.08	 1.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32451	 1	 5.06	 1.91	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32452	 1	 2.95	 1.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32453	 1	 6.41	 2.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32454	 1	 5.62	 2.5	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32455	 1	 7.02	 2.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32456	 1	 2.8	 1.15	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32457	 1	 6.05	 2.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32458	 1	 5.41	 1.8	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32459	 1	 4.18	 1.76	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32460	 1	 2.24	 0.9	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32461	 1	 2.44	 0.88	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32462	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32463	 1	 124.85	 43.86	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32464	 1	 3.06	 0.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32465	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32466	 1	 3.08	 0.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32467	 1	 2.61	 0.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32468	 1	 1.42	 0.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32469	 1	 2.43	 1.01	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32470	 1	 16.4	 4.71	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32471	 1	 4.37	 1.68	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32472	 1	 5.13	 2.12	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32473	 1	 10.2	 4.03	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32474	 1	 5.87	 1.74	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32475	 1	 13.6	 5.21	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32476	 1	 11.07	 2.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32477	 1	 10.32	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32478	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32479	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32480	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32481	 1	 7.74	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32482	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32483	 1	 21.55	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32484	 1	 19.47	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32485	 1	 7.17	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32486	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32487	 1	 8.08	 2.8	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32488	 1	 6.77	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32489	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32490	 1	 7.96	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32491	 1	 5.71	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32492	 1	 12.1	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32493	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32494	 1	 7.33	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32495	 1	 4.96	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32496	 1	 5.91	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32497	 1	 10.23	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32498	 1	 7.44	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32499	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32500	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32501	 1	 1.84	 0.79	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32502	 1	 1.1	 0.47	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32503	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32504	 1	 2.73	 1.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32505	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32506	 1	 3.6	 1.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32507	 1	 1.8	 0.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32508	 1	 13.76	 5.34	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32509	 1	 5.3	 1.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32510	 1	 1.52	 0.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32511	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32512	 1	 1.94	 0.85	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32513	 1	 5.09	 1.74	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32514	 1	 6.57	 2.02	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32515	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32516	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32517	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32518	 1	 11.8	 4.46	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32519	 1	 12.29	 4.26	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32520	 1	 5.38	 2.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32521	 1	 5.39	 2.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32522	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32523	 1	 5.56	 2.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32524	 1	 6.25	 2.82	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32525	 1	 16.79	 7.22	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32526	 1	 11.66	 4.22	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32527	 1	 2.9	 1.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32528	 1	 6.69	 2.91	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32529	 1	 5.64	 2.06	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32530	 1	 16.8	 5.71	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32531	 1	 4.91	 1.95	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32532	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32533	 1	 3.25	 1.33	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32534	 1	 4.17	 1.54	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32535	 1	 13.45	 3.02	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32536	 1	 28.17	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32537	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32538	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32539	 1	 52.46	 12.97	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32540	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32541	 1	 8.7	 3.07	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32542	 1	 5.52	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32543	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32544	 1	 12.11	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32545	 1	 58.02	 19.05	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32546	 1	 6.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32547	 1	 2.9	 1.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32548	 1	 10.57	 4.31	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32549	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32550	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32551	 1	 3.81	 1.48	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32552	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32553	 1	 4.54	 1.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32554	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32555	 1	 7.27	 2.81	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32556	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32557	 1	 6.25	 2.28	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32558	 1	 6.17	 2.03	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32559	 1	 4.94	 1.91	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32560	 1	 3.39	 0.76	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32561	 1	 4.38	 1.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32562	 1	 6.86	 2.13	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32563	 1	 4.15	 1.72	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32564	 1	 5.69	 2.38	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32565	 1	 2.42	 0.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32566	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32567	 1	 8.58	 1.93	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32568	 1	 11.03	 3.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32569	 1	 11.47	 3.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32570	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32571	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32572	 1	 7.66	 1.71	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32573	 1	 4.59	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32574	 1	 1.75	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32575	 1	 11.66	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32576	 1	 2.22	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32577	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32578	 1	 3.89	 0.88	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32579	 1	 8.63	 1.94	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32580	 1	 7.48	 1.68	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32581	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32582	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32583	 1	 1.8	 0.68	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32584	 1	 9.61	 3.43	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32585	 1	 14.63	 3.31	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32586	 1	 3.84	 0.87	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32587	 1	 6.93	 1.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32588	 1	 5.8	 1.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32589	 1	 7.28	 1.65	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32590	 1	 8.15	 1.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32591	 1	 8.61	 1.95	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32592	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32593	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32594	 1	 1.49	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32595	 1	 5.35	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32596	 1	 6.71	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32597	 1	 7.65	 1.72	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32598	 1	 12.61	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32599	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32600	 1	 8.05	 1.82	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32601	 1	 27.76	 6.29	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32602	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32603	 1	 8.11	 1.84	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32604	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32605	 1	 5.47	 1.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32606	 1	 5.47	 1.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32607	 1	 4.46	 1.01	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32608	 1	 4.14	 0.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32609	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32610	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32611	 1	 13.04	 2.94	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32612	 1	 6.49	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32613	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32614	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32615	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32616	 1	 9.67	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32617	 1	 4.32	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32618	 1	 6.85	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32619	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32620	 1	 3.07	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32621	 1	 4.86	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32622	 1	 4.35	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32623	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32624	 1	 6.01	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32625	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32626	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32627	 1	 4.46	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32628	 1	 5.8	 2.22	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32629	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32630	 1	 4.37	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32631	 1	 9.04	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32632	 1	 4.32	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32633	 1	 8.01	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32634	 1	 5.03	 1.86	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32635	 1	 3.93	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32636	 1	 5.86	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32637	 1	 5.05	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32638	 1	 5.69	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32639	 1	 16.09	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32640	 1	 6.5	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32641	 1	 4.52	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32642	 1	 4.01	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32643	 1	 2.96	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32644	 1	 4.6	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32645	 1	 9.74	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32646	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32647	 1	 8.01	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32648	 1	 7.01	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32649	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32650	 1	 8.58	 2.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32651	 1	 16.58	 5.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32652	 1	 16.27	 3.7	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32653	 1	 4.91	 1.6	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32654	 1	 24.11	 5.45	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32655	 1	 26.63	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32656	 1	 15.05	 4.86	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32657	 1	 27.12	 8.83	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32658	 1	 8.08	 1.82	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32659	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32660	 1	 7.1	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32661	 1	 9.91	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32662	 1	 72.86	 16.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32663	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32664	 1	 8.08	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32665	 1	 7.04	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32666	 1	 9.78	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32667	 1	 10.24	 4.11	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32668	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32669	 1	 6.27	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32670	 1	 3.42	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32671	 1	 6.72	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32672	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32673	 1	 12.08	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32674	 1	 4.1	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32675	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32676	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32677	 1	 7.04	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32678	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32679	 1	 33.09	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32680	 1	 6.2	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32681	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32682	 1	 4.21	 1.7	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32683	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32684	 1	 3.31	 1.33	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32685	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32686	 1	 6.94	 2.72	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32687	 1	 6.33	 2.22	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32688	 1	 10.62	 3.27	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32689	 1	 13.59	 4.11	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32690	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32691	 1	 9.22	 3.79	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32692	 1	 47.25	 13.22	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32693	 1	 5.79	 1.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32694	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32695	 1	 18.74	 4.27	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32696	 1	 11.62	 4.51	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32697	 1	 14.32	 4.09	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32698	 1	 7.46	 1.7	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32699	 1	 9.33	 2.97	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32700	 1	 4.71	 1.08	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32701	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32702	 1	 18.99	 4.29	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32703	 1	 9.33	 3.64	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32704	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32705	 1	 2.61	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32706	 1	 5.22	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32707	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32708	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32709	 1	 8.74	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32710	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32711	 1	 5.18	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32712	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32713	 1	 4.63	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32714	 1	 2.55	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32715	 1	 10.81	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32716	 1	 19.94	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32717	 1	 3.08	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32718	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32719	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32720	 1	 4.55	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32721	 1	 3.2	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32722	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32723	 1	 9.27	 4.1	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32724	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32725	 1	 5.6	 2.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32726	 1	 9.61	 3.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32727	 1	 9.65	 3.47	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32728	 1	 4.71	 1.7	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32729	 1	 12.58	 4.93	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32730	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32731	 1	 6.4	 2.38	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32732	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32733	 1	 10.3	 4.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32734	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32735	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32736	 1	 6.29	 2.19	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32737	 1	 10.08	 3.62	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32738	 1	 6.03	 2.79	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32739	 1	 3.11	 1.24	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32740	 1	 12.57	 3.39	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32741	 1	 10.19	 3.61	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32742	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32743	 1	 2.83	 -0.93	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32744	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32745	 1	 17.15	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32746	 1	 13.12	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32747	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32748	 1	 12.93	 4.26	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32749	 1	 4.47	 1.61	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32750	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32751	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32752	 1	 11.36	 4.59	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32753	 1	 10.81	 4.49	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32754	 1	 4.74	 1.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32755	 1	 8.11	 2.63	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32756	 1	 9.19	 3.71	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32757	 1	 4.26	 1.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32758	 1	 6.78	 2.74	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32759	 1	 5.4	 2.31	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32760	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32761	 1	 20.26	 5.45	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32762	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32763	 1	 6.09	 2.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32764	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32765	 1	 7.39	 2.51	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32766	 1	 6.24	 2.09	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32767	 1	 4.66	 1.66	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32768	 1	 6.47	 2.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32769	 1	 2.8	 1.2	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32770	 1	 6.99	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32771	 1	 7.06	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32772	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32773	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32774	 1	 7.94	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32775	 1	 3.69	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32776	 1	 14.98	 4.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32777	 1	 6.06	 2.07	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32778	 1	 3.82	 1.45	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32779	 1	 4.59	 1.65	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32780	 1	 7.86	 1.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32781	 1	 10.84	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32782	 1	 8.13	 3.21	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32783	 1	 4.25	 1.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32784	 1	 2.89	 0.94	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32785	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32786	 1	 6.32	 2.65	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32787	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32788	 1	 2.84	 0.97	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32789	 1	 15.97	 3.24	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32790	 1	 2.39	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32791	 1	 1.74	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32792	 1	 3.61	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32793	 1	 2.52	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32794	 1	 4.15	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32795	 1	 5.05	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32796	 1	 3.8	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32797	 1	 2.18	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32798	 1	 4.76	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32799	 1	 5.65	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32800	 1	 3.87	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32801	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32802	 1	 7.68	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32803	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32804	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32805	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32806	 1	 6.16	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32807	 1	 4.11	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32808	 1	 4.26	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32809	 1	 7.29	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32810	 1	 10.99	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32811	 1	 8.11	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32812	 1	 2.47	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32813	 1	 9.18	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32814	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32815	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32816	 1	 6.75	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32817	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	32818	 1	 6.5	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32819	 1	 5.33	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32820	 1	 3.78	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32821	 1	 3.89	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32822	 1	 4.5	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32823	 1	 3.57	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32824	 1	 9.29	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32825	 1	 5.83	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32826	 1	 4.07	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32827	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32828	 1	 4.17	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32829	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32830	 1	 9.24	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32831	 1	 6.75	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32832	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32833	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32834	 1	 6.25	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32835	 1	 3.62	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32836	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32837	 1	 5.82	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32838	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32839	 1	 10.07	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32840	 1	 5.5	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32841	 1	 8.72	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32842	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32843	 1	 4.18	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32844	 1	 11.63	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32845	 1	 19.39	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32846	 1	 2.94	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32847	 1	 37.71	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32848	 1	 7.61	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32849	 1	 4.45	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32850	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32851	 1	 7.55	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32852	 1	 7.25	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32853	 1	 15.31	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32854	 1	 2.77	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32855	 1	 4.73	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32856	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32857	 1	 4.51	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32858	 1	 5.66	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32859	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32860	 1	 3.38	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32861	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32862	 1	 5.41	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32863	 1	 1.92	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32864	 1	 8.71	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32865	 1	 28.05	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32866	 1	 15.58	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32867	 1	 14.13	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32868	 1	 6.27	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32869	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32870	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32871	 1	 6.92	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32872	 1	 6.85	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32873	 1	 6.42	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32874	 1	 3.96	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32875	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32876	 1	 6.26	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32877	 1	 2.14	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32878	 1	 8.54	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32879	 1	 5.31	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32880	 1	 6.45	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32881	 1	 5.44	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32882	 1	 1.52	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32883	 1	 4.39	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32884	 1	 5.74	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32885	 1	 2.17	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32886	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32887	 1	 6.31	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32888	 1	 7.68	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32889	 1	 6.52	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32890	 1	 4.85	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32891	 1	 6.68	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32892	 1	 2.67	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32893	 1	 3.18	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32894	 1	 7.69	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32895	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32896	 1	 16.33	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32897	 1	 8.52	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32898	 1	 12.29	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32899	 1	 15.71	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32900	 1	 3.63	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32901	 1	 8.25	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32902	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32903	 1	 6.39	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32904	 1	 6.72	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32905	 1	 7.88	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32906	 1	 10.37	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32907	 1	 3.21	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32908	 1	 5.85	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32909	 1	 3.9	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32910	 1	 6.29	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32911	 1	 17.6	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32912	 1	 17.71	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32913	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32914	 1	 9.12	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32915	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32916	 1	 65.67	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32917	 1	 4.55	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32918	 1	 6.55	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32919	 1	 3.96	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32920	 1	 2.54	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32921	 1	 11.84	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32922	 1	 3.17	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32923	 1	 3.53	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32924	 1	 2.47	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32925	 1	 7.03	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32926	 1	 7.4	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32927	 1	 2.65	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32928	 1	 2.07	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32929	 1	 5.59	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32930	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32931	 1	 3.32	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32932	 1	 18.29	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32933	 1	 5.88	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32934	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32935	 1	 3.6	 1.5	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32936	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32937	 1	 7.9	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32938	 1	 2.38	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32939	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32940	 1	 10.67	 3.91	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32941	 1	 4.27	 1.65	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32942	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32943	 1	 7.79	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32944	 1	 12.24	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32945	 1	 16.87	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32946	 1	 5.94	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32947	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32948	 1	 3.04	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32949	 1	 2.01	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32950	 1	 2.03	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32951	 1	 8.32	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32952	 1	 3.12	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32953	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32954	 1	 4.29	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32955	 1	 3.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32956	 1	 8.74	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32957	 1	 7.55	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32958	 1	 3.94	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32959	 1	 6.7	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32960	 1	 16.64	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32961	 1	 2.16	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32962	 1	 10.03	 3.63	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32963	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32964	 1	 16.13	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32965	 1	 12.9	 5.29	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32966	 1	 23.95	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32967	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32968	 1	 11.67	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32969	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32970	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32971	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	32972	 1	 6.72	 1.52	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32973	 1	 13.1	 3.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32974	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32975	 1	 9.28	 2.1	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32976	 1	 20.58	 6.2	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32977	 1	 7.79	 3.48	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32978	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32979	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32980	 1	 7.14	 3.01	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32981	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32982	 1	 3.23	 1.11	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32983	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32984	 1	 5.58	 2.25	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32985	 1	 6.97	 1.58	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32986	 1	 7.98	 2.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32987	 1	 4.71	 1.56	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32988	 1	 7.66	 1.72	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32989	 1	 9.21	 3.52	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32990	 1	 3.13	 0.72	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32991	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32992	 1	 3.85	 1.41	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	32993	 1	 3.97	 1.68	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32994	 1	 36.78	 8.09	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32995	 1	 1.51	 0.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32996	 1	 2.09	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32997	 1	 3.48	 1.46	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32998	 1	 6.49	 2.49	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	32999	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33000	 1	 4.34	 1.91	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33001	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33002	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33003	 1	 7.36	 3.09	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33004	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33005	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33006	 1	 4.72	 2.04	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33007	 1	 3.54	 1.5	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33008	 1	 2.58	 0.97	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33009	 1	 6.8	 2.4	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33010	 1	 9.07	 3.15	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33011	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33012	 1	 12.43	 4.57	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33013	 1	 2.38	 0.89	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33014	 1	 4.87	 1.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33015	 1	 6.83	 3.07	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33016	 1	 1.31	 0.61	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33017	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	33018	 1	 3.61	 0.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33019	 1	 11.07	 3.57	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33020	 1	 10.79	 2.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33021	 1	 3.15	 1.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33022	 1	 12.53	 4.11	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33023	 1	 2.06	 0.87	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33024	 1	 15.56	 5.57	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33025	 1	 9.69	 3.86	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33026	 1	 8.27	 3.17	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33027	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33028	 1	 11.93	 3.93	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33029	 1	 5.88	 2.29	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33030	 1	 5.64	 2.12	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33031	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33032	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33033	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33034	 1	 5.34	 1.91	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33035	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33036	 1	 26.84	 7.09	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33037	 1	 4.36	 1.77	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33038	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33039	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33040	 1	 3.9	 1.33	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33041	 1	 6.49	 1.45	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33042	 1	 9.44	 2.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33043	 1	 2.89	 1.09	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33044	 1	 6.09	 1.37	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33045	 1	 3.38	 0.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33046	 1	 19.87	 5.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33047	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33048	 1	 6.26	 2.37	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33049	 1	 9.1	 3.35	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33050	 1	 12.33	 4.42	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33051	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33052	 1	 8.58	 3.38	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33053	 1	 7.43	 2.81	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33054	 1	 8.7	 3.79	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33055	 1	 7.39	 3.21	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33056	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33057	 1	 5.0	 1.94	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33058	 1	 10.79	 4.66	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33059	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33060	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33061	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33062	 1	 6.73	 2.88	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33063	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33064	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33065	 1	 19.27	 7.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33066	 1	 10.61	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33067	 1	 2.63	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33068	 1	 3.51	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33069	 1	 3.95	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33070	 1	 2.43	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33071	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33072	 1	 4.14	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33073	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33074	 1	 4.05	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33075	 1	 2.33	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33076	 1	 4.24	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33077	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33078	 1	 3.86	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33079	 1	 3.38	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33080	 1	 4.08	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33081	 1	 4.48	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33082	 1	 4.59	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33083	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33084	 1	 3.5	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33085	 1	 4.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33086	 1	 11.06	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33087	 1	 3.64	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33088	 1	 4.99	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33089	 1	 16.15	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33090	 1	 2.11	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33091	 1	 3.21	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33092	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33093	 1	 3.24	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33094	 1	 2.12	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33095	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33096	 1	 10.74	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33097	 1	 19.5	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33098	 1	 8.84	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33099	 1	 9.48	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33100	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33101	 1	 10.2	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33102	 1	 7.52	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33103	 1	 18.04	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33104	 1	 4.94	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33105	 1	 8.94	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33106	 1	 3.88	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33107	 1	 3.78	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33108	 1	 3.16	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33109	 1	 7.08	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33110	 1	 2.84	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33111	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33112	 1	 5.08	 2.15	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33113	 1	 6.38	 2.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33114	 1	 3.31	 1.34	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33115	 1	 9.89	 4.11	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33116	 1	 4.77	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33117	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33118	 1	 2.77	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33119	 1	 7.25	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33120	 1	 11.17	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33121	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33122	 1	 3.37	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33123	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33124	 1	 3.66	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33125	 1	 3.52	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33126	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33127	 1	 7.76	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33128	 1	 2.36	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33129	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33130	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33131	 1	 12.68	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33132	 1	 6.08	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33133	 1	 14.65	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33134	 1	 5.24	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33135	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33136	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33137	 1	 3.45	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33138	 1	 1.7	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33139	 1	 5.64	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33140	 1	 4.32	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33141	 1	 5.06	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33142	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33143	 1	 4.67	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33144	 1	 9.29	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33145	 1	 2.45	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33146	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33147	 1	 1.19	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33148	 1	 1.99	 0.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33149	 1	 1.66	 0.54	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33150	 1	 3.21	 1.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33151	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33152	 1	 4.89	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33153	 1	 1.35	 0.45	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33154	 1	 2.61	 0.93	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33155	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33156	 1	 8.67	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33157	 1	 8.56	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33158	 1	 2.87	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33159	 1	 2.87	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33160	 1	 2.56	 0.86	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33161	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33162	 1	 3.44	 1.15	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33163	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33164	 1	 1.17	 0.43	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33165	 1	 6.85	 2.49	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33166	 1	 2.03	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33167	 1	 8.57	 3.05	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33168	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33169	 1	 1.01	 0.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33170	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33171	 1	 2.16	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33172	 1	 1.75	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33173	 1	 11.91	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33174	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33175	 1	 7.18	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33176	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33177	 1	 6.56	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33178	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33179	 1	 3.8	 1.38	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33180	 1	 7.4	 2.63	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33181	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33182	 1	 23.23	 9.04	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33183	 1	 2.85	 1.21	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33184	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33185	 1	 6.95	 2.84	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33186	 1	 7.88	 2.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33187	 1	 8.93	 3.15	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33188	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33189	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33190	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33191	 1	 3.3	 1.28	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33192	 1	 5.09	 1.76	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33193	 1	 5.83	 2.12	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33194	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33195	 1	 0.87	 0.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33196	 1	 8.18	 3.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33197	 1	 6.36	 2.59	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33198	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33199	 1	 3.83	 1.27	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33200	 1	 4.01	 1.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33201	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33202	 1	 3.37	 1.17	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33203	 1	 11.08	 2.98	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33204	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33205	 1	 22.95	 7.76	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33206	 1	 79.33	 29.43	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33207	 1	 79.8	 24.95	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33208	 1	 7.07	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33209	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33210	 1	 4.77	 1.85	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33211	 1	 12.85	 4.81	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33212	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33213	 1	 17.02	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33214	 1	 5.25	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33215	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33216	 1	 4.96	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33217	 1	 3.76	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33218	 1	 4.0	 1.41	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33219	 1	 7.17	 2.63	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33220	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33221	 1	 8.11	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33222	 1	 11.76	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33223	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33224	 1	 5.83	 2.08	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33225	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33226	 1	 5.29	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33227	 1	 7.31	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33228	 1	 7.49	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33229	 1	 4.05	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33230	 1	 1.64	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33231	 1	 5.9	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33232	 1	 13.23	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33233	 1	 5.69	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33234	 1	 10.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33235	 1	 13.83	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33236	 1	 5.69	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33237	 1	 4.69	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33238	 1	 9.46	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33239	 1	 1.96	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33240	 1	 3.12	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33241	 1	 6.22	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33242	 1	 8.32	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33243	 1	 4.67	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33244	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33245	 1	 6.92	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33246	 1	 5.83	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33247	 1	 7.36	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33248	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33249	 1	 5.2	 2.14	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33250	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33251	 1	 18.25	 6.57	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33252	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	33253	 1	 12.52	 4.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33254	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33255	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33256	 1	 5.42	 2.15	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33257	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	33258	 1	 7.64	 3.01	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33259	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33260	 1	 21.1	 6.46	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33261	 1	 29.77	 9.77	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33262	 1	 4.29	 1.41	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33263	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33264	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33265	 1	 13.26	 3.72	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33266	 1	 16.04	 4.56	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33267	 1	 26.88	 6.01	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33268	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33269	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33270	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33271	 1	 5.95	 2.33	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33272	 1	 4.75	 1.94	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33273	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33274	 1	 5.05	 1.63	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33275	 1	 4.79	 1.62	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33276	 1	 12.74	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33277	 1	 6.92	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33278	 1	 8.35	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33279	 1	 10.07	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33280	 1	 7.89	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33281	 1	 7.6	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33282	 1	 4.86	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33283	 1	 6.06	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33284	 1	 8.04	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33285	 1	 6.69	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33286	 1	 13.98	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33287	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33288	 1	 6.16	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33289	 1	 5.38	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33290	 1	 6.58	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33291	 1	 2.09	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33292	 1	 9.75	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33293	 1	 8.26	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33294	 1	 11.5	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33295	 1	 3.75	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33296	 1	 6.32	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33297	 1	 5.95	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33298	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33299	 1	 4.86	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33300	 1	 7.64	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33301	 1	 16.11	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33302	 1	 10.66	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33303	 1	 9.87	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33304	 1	 7.5	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33305	 1	 7.53	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33306	 1	 7.12	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33307	 1	 10.81	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33308	 1	 10.32	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33309	 1	 12.63	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33310	 1	 10.66	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33311	 1	 4.23	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33312	 1	 8.17	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33313	 1	 10.59	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33314	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33315	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33316	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33317	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33318	 1	 10.71	 2.41	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33319	 1	 4.19	 1.89	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33320	 1	 5.4	 1.96	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33321	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33322	 1	 8.03	 3.04	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33323	 1	 3.68	 1.33	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33324	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33325	 1	 1.89	 0.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33326	 1	 3.22	 1.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33327	 1	 6.2	 2.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33328	 1	 6.8	 2.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33329	 1	 10.34	 3.97	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33330	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33331	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33332	 1	 40.53	 10.22	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33333	 1	 4.88	 1.74	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33334	 1	 3.49	 1.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33335	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33336	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33337	 1	 5.15	 2.28	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33338	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33339	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33340	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33341	 1	 8.87	 3.04	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33342	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33343	 1	 6.09	 2.2	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33344	 1	 6.31	 2.54	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33345	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33346	 1	 8.75	 2.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33347	 1	 6.69	 2.71	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33348	 1	 14.0	 4.99	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33349	 1	 3.27	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33350	 1	 3.63	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33351	 1	 5.63	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33352	 1	 15.67	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33353	 1	 20.01	 7.47	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33354	 1	 2.5	 0.86	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33355	 1	 2.38	 0.86	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33356	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33357	 1	 1.69	 0.64	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33358	 1	 5.07	 1.98	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33359	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33360	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33361	 1	 1.29	 0.62	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33362	 1	 19.3	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33363	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33364	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33365	 1	 6.07	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33366	 1	 9.61	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33367	 1	 7.09	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33368	 1	 7.55	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33369	 1	 7.37	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33370	 1	 10.01	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33371	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33372	 1	 15.46	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33373	 1	 12.15	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33374	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33375	 1	 7.77	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33376	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33377	 1	 11.01	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33378	 1	 10.17	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33379	 1	 3.43	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33380	 1	 4.55	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33381	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33382	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33383	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	33384	 1	 7.38	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33385	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33386	 1	 21.68	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33387	 1	 12.77	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33388	 1	 13.17	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33389	 1	 8.56	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33390	 1	 4.33	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33391	 1	 7.11	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33392	 1	 2.4	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33393	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33394	 1	 8.68	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33395	 1	 5.1	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33396	 1	 4.1	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33397	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33398	 1	 7.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33399	 1	 3.27	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33400	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33401	 1	 6.87	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33402	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33403	 1	 12.54	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33404	 1	 6.87	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33405	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33406	 1	 11.67	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33407	 1	 4.99	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33408	 1	 5.6	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33409	 1	 5.1	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33410	 1	 10.09	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33411	 1	 6.42	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33412	 1	 6.95	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33413	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33414	 1	 5.61	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33415	 1	 2.19	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33416	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33417	 1	 7.09	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33418	 1	 9.31	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33419	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33420	 1	 11.29	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33421	 1	 7.93	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33422	 1	 6.53	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33423	 1	 11.29	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33424	 1	 4.89	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33425	 1	 21.6	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33426	 1	 5.24	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33427	 1	 6.17	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33428	 1	 5.15	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33429	 1	 10.52	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33430	 1	 11.03	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33431	 1	 7.72	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33432	 1	 6.87	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33433	 1	 8.63	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33434	 1	 6.47	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33435	 1	 7.5	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33436	 1	 20.03	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33437	 1	 9.31	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33438	 1	 6.59	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33439	 1	 5.34	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33440	 1	 7.12	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33441	 1	 4.52	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33442	 1	 16.68	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33443	 1	 8.26	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33444	 1	 11.2	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33445	 1	 17.99	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33446	 1	 14.77	 5.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33447	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33448	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33449	 1	 4.48	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33450	 1	 14.39	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33451	 1	 22.13	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33452	 1	 25.23	 9.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33453	 1	 17.91	 6.89	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33454	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33455	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33456	 1	 10.86	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33457	 1	 8.58	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33458	 1	 7.25	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33459	 1	 6.72	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33460	 1	 6.49	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33461	 1	 17.02	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33462	 1	 7.99	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33463	 1	 9.66	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33464	 1	 9.18	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33465	 1	 2.61	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33466	 1	 7.21	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33467	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33468	 1	 4.97	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33469	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33470	 1	 9.41	 3.18	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33471	 1	 13.84	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33472	 1	 3.28	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33473	 1	 5.95	 2.27	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33474	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33475	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33476	 1	 5.56	 1.26	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33477	 1	 7.07	 2.42	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33478	 1	 12.32	 4.2	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33479	 1	 6.53	 1.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33480	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33481	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33482	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33483	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33484	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33485	 1	 5.72	 1.29	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33486	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33487	 1	 3.67	 0.83	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33488	 1	 5.98	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33489	 1	 2.71	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33490	 1	 3.69	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33491	 1	 11.07	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33492	 1	 6.5	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33493	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33494	 1	 13.3	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33495	 1	 9.34	 2.1	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33496	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33497	 1	 24.35	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33498	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33499	 1	 10.72	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33500	 1	 16.16	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33501	 1	 3.82	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33502	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33503	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33504	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33505	 1	 11.21	 4.04	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33506	 1	 14.51	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33507	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33508	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33509	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33510	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33511	 1	 6.61	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33512	 1	 4.92	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33513	 1	 4.38	 1.87	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33514	 1	 5.11	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33515	 1	 10.59	 2.65	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33516	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33517	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33518	 1	 5.88	 2.43	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33519	 1	 2.38	 1.01	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33520	 1	 7.27	 3.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33521	 1	 3.14	 1.25	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33522	 1	 6.51	 2.76	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33523	 1	 3.75	 1.68	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33524	 1	 12.92	 5.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33525	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33526	 1	 5.13	 1.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33527	 1	 8.88	 2.86	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33528	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33529	 1	 16.36	 5.19	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33530	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33531	 1	 5.85	 2.43	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33532	 1	 3.71	 1.49	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33533	 1	 6.22	 1.93	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33534	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33535	 1	 11.68	 5.14	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33536	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33537	 1	 15.89	 6.88	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33538	 1	 3.39	 1.28	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33539	 1	 21.23	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33540	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33541	 1	 6.26	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33542	 1	 6.88	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33543	 1	 3.05	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33544	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33545	 1	 8.03	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33546	 1	 5.66	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33547	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33548	 1	 9.86	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33549	 1	 15.42	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33550	 1	 4.7	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33551	 1	 11.09	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33552	 1	 28.6	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33553	 1	 14.92	 3.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33554	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33555	 1	 3.9	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33556	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33557	 1	 4.33	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33558	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33559	 1	 10.24	 3.89	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33560	 1	 12.3	 2.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33561	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33562	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33563	 1	 13.61	 3.03	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33564	 1	 6.89	 2.41	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33565	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33566	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33567	 1	 10.24	 4.52	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33568	 1	 6.42	 2.64	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33569	 1	 8.59	 3.47	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33570	 1	 7.46	 2.41	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33571	 1	 153.31	 51.04	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33572	 1	 3.06	 1.43	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33573	 1	 2.2	 1.01	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33574	 1	 12.4	 5.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33575	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33576	 1	 7.95	 3.53	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33577	 1	 11.7	 4.14	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33578	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33579	 1	 7.41	 3.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33580	 1	 5.47	 2.36	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33581	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33582	 1	 7.91	 3.52	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33583	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33584	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33585	 1	 13.13	 3.81	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33586	 1	 18.37	 6.08	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33587	 1	 2.96	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33588	 1	 11.4	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33589	 1	 18.87	 5.38	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33590	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33591	 1	 7.19	 2.77	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33592	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33593	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33594	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33595	 1	 7.29	 2.99	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33596	 1	 14.55	 5.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33597	 1	 12.4	 4.11	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33598	 1	 13.9	 5.76	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33599	 1	 2.72	 1.15	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33600	 1	 2.9	 1.11	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33601	 1	 2.49	 0.97	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33602	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33603	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33604	 1	 6.28	 2.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33605	 1	 1.47	 0.54	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33606	 1	 12.2	 3.37	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33607	 1	 1.88	 0.77	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33608	 1	 11.46	 3.52	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33609	 1	 5.16	 1.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33610	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33611	 1	 3.14	 1.38	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33612	 1	 2.59	 1.19	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33613	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33614	 1	 2.8	 1.21	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33615	 1	 2.38	 1.03	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33616	 1	 1.71	 0.64	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33617	 1	 6.52	 2.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33618	 1	 2.97	 1.37	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33619	 1	 7.8	 3.15	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33620	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33621	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33622	 1	 8.96	 3.63	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33623	 1	 13.28	 4.06	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33624	 1	 1.73	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33625	 1	 8.49	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33626	 1	 3.18	 1.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33627	 1	 4.97	 1.89	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33628	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33629	 1	 4.0	 1.04	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33630	 1	 7.83	 3.17	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33631	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33632	 1	 5.0	 1.57	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33633	 1	 2.6	 1.11	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33634	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33635	 1	 6.79	 2.74	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33636	 1	 37.15	 8.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33637	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33638	 1	 2.87	 1.02	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33639	 1	 6.9	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33640	 1	 1.83	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33641	 1	 10.58	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33642	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33643	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33644	 1	 5.97	 2.5	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33645	 1	 12.78	 2.94	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33646	 1	 72.97	 28.91	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33647	 1	 3.71	 1.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33648	 1	 2.91	 0.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33649	 1	 5.64	 1.91	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33650	 1	 4.03	 0.93	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33651	 1	 5.32	 2.01	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33652	 1	 8.1	 2.5	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33653	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33654	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33655	 1	 4.91	 1.68	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33656	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33657	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33658	 1	 4.14	 1.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33659	 1	 4.23	 1.95	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33660	 1	 8.33	 3.01	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33661	 1	 5.81	 1.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33662	 1	 4.27	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33663	 1	 0.0	 0.0	 0.0	 100.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33664	 1	 3.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33665	 1	 3.86	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33666	 1	 15.32	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33667	 1	 6.02	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33668	 1	 3.11	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33669	 1	 6.74	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33670	 1	 7.15	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33671	 1	 7.47	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33672	 1	 6.43	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33673	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33674	 1	 6.74	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33675	 1	 42.94	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33676	 1	 10.57	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33677	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33678	 1	 10.61	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33679	 1	 5.4	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33680	 1	 7.06	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33681	 1	 8.99	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33682	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33683	 1	 86.87	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33684	 1	 24.07	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33685	 1	 4.31	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33686	 1	 5.02	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33687	 1	 8.58	 1.94	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33688	 1	 7.11	 1.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33689	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33690	 1	 11.55	 2.63	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33691	 1	 5.55	 2.31	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33692	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33693	 1	 4.9	 2.02	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33694	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33695	 1	 4.7	 1.77	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33696	 1	 4.79	 2.15	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33697	 1	 6.34	 2.38	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33698	 1	 4.16	 1.89	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33699	 1	 2.27	 0.96	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33700	 1	 2.03	 0.89	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33701	 1	 10.61	 3.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33702	 1	 10.99	 4.49	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33703	 1	 4.9	 2.23	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33704	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33705	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33706	 1	 8.51	 3.08	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33707	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33708	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33709	 1	 4.45	 1.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33710	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33711	 1	 12.02	 4.08	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33712	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33713	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33714	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33715	 1	 2.25	 0.52	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33716	 1	 2.54	 0.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33717	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33718	 1	 7.25	 2.9	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33719	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33720	 1	 15.42	 5.17	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33721	 1	 13.07	 5.18	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33722	 1	 18.19	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33723	 1	 6.75	 2.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33724	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	33725	 1	 16.85	 5.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33726	 1	 4.57	 2.02	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33727	 1	 7.38	 2.61	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33728	 1	 2.99	 1.08	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33729	 1	 5.99	 2.38	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33730	 1	 2.04	 0.94	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33731	 1	 3.67	 1.28	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33732	 1	 3.93	 1.36	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33733	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33734	 1	 3.51	 1.26	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33735	 1	 2.41	 0.96	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33736	 1	 4.44	 1.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33737	 1	 3.73	 1.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33738	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33739	 1	 4.68	 1.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33740	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33741	 1	 4.94	 2.1	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33742	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33743	 1	 5.39	 2.03	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33744	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33745	 1	 2.79	 1.08	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33746	 1	 19.41	 4.15	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33747	 1	 2.86	 1.09	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33748	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33749	 1	 6.32	 2.5	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33750	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33751	 1	 3.52	 0.81	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33752	 1	 1.58	 0.64	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33753	 1	 5.54	 2.1	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33754	 1	 1.65	 0.38	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33755	 1	 6.73	 1.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33756	 1	 3.78	 0.87	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33757	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33758	 1	 2.01	 0.82	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33759	 1	 2.49	 0.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33760	 1	 27.91	 8.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33761	 1	 9.5	 3.03	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33762	 1	 2.28	 0.91	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33763	 1	 6.28	 1.45	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33764	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33765	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33766	 1	 1.97	 0.45	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33767	 1	 1.18	 0.27	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33768	 1	 2.61	 0.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33769	 1	 6.77	 1.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33770	 1	 6.66	 2.89	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33771	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33772	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33773	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33774	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33775	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33776	 1	 5.49	 2.31	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33777	 1	 2.21	 0.9	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33778	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33779	 1	 5.72	 2.49	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33780	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33781	 1	 13.87	 5.37	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33782	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33783	 1	 10.11	 2.34	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33784	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33785	 1	 3.29	 1.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33786	 1	 5.59	 1.85	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33787	 1	 3.71	 0.86	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33788	 1	 6.2	 1.43	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33789	 1	 4.26	 0.98	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33790	 1	 5.77	 1.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33791	 1	 1.28	 0.29	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33792	 1	 7.46	 2.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33793	 1	 5.8	 2.42	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33794	 1	 1.74	 0.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33795	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33796	 1	 5.32	 1.23	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33797	 1	 19.59	 6.7	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33798	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33799	 1	 6.0	 2.47	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33800	 1	 67.74	 14.99	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33801	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33802	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33803	 1	 8.61	 3.21	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33804	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33805	 1	 7.36	 2.94	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33806	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33807	 1	 9.28	 3.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33808	 1	 4.89	 1.85	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33809	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33810	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33811	 1	 12.27	 4.76	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33812	 1	 4.62	 2.05	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33813	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33814	 1	 1.86	 0.86	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33815	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33816	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33817	 1	 5.95	 2.46	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33818	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33819	 1	 1.55	 0.66	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33820	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33821	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33822	 1	 8.54	 3.41	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33823	 1	 2.53	 0.86	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33824	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33825	 1	 5.12	 1.91	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33826	 1	 14.88	 6.08	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33827	 1	 4.94	 1.11	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33828	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33829	 1	 1.6	 0.7	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33830	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33831	 1	 9.07	 3.47	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33832	 1	 8.83	 2.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33833	 1	 5.15	 1.16	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33834	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33835	 1	 9.76	 2.21	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33836	 1	 8.54	 3.41	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33837	 1	 4.73	 1.07	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33838	 1	 5.87	 1.33	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33839	 1	 2.28	 1.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33840	 1	 15.89	 6.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33841	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33842	 1	 4.56	 1.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33843	 1	 2.04	 0.77	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33844	 1	 6.97	 2.58	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33845	 1	 4.07	 1.53	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33846	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33847	 1	 6.07	 2.61	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33848	 1	 3.31	 1.17	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33849	 1	 4.31	 1.66	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33850	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33851	 1	 3.83	 1.57	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33852	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33853	 1	 7.34	 1.86	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33854	 1	 0.0	 0.0	 0.0	 40.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33855	 1	 10.15	 4.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33856	 1	 4.75	 1.88	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33857	 1	 6.77	 2.33	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33858	 1	 3.56	 1.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33859	 1	 7.05	 2.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33860	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33861	 1	 27.58	 8.46	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33862	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33863	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33864	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33865	 1	 11.71	 4.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33866	 1	 5.69	 2.51	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33867	 1	 11.51	 4.65	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33868	 1	 1.44	 0.64	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33869	 1	 2.85	 1.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33870	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33871	 1	 3.76	 1.42	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33872	 1	 26.55	 9.73	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33873	 1	 7.21	 2.45	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33874	 1	 3.17	 1.25	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33875	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33876	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33877	 1	 6.06	 1.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33878	 1	 3.0	 1.09	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33879	 1	 1.78	 0.74	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33880	 1	 3.13	 1.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33881	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33882	 1	 4.18	 1.66	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33883	 1	 4.36	 1.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33884	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33885	 1	 3.76	 1.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33886	 1	 12.26	 4.97	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33887	 1	 2.23	 0.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33888	 1	 4.69	 2.01	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33889	 1	 4.86	 1.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33890	 1	 14.54	 5.25	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33891	 1	 3.79	 1.12	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33892	 1	 2.45	 0.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33893	 1	 3.24	 0.99	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33894	 1	 11.07	 4.28	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33895	 1	 4.33	 1.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33896	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33897	 1	 7.49	 2.46	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33898	 1	 9.83	 3.6	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33899	 1	 6.69	 2.65	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33900	 1	 5.27	 2.15	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33901	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33902	 1	 11.87	 4.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33903	 1	 19.9	 7.96	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33904	 1	 11.42	 3.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33905	 1	 10.9	 3.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33906	 1	 11.42	 4.28	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33907	 1	 5.03	 1.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33908	 1	 5.81	 2.54	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33909	 1	 4.73	 1.54	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33910	 1	 4.09	 1.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33911	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33912	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33913	 1	 5.14	 1.88	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33914	 1	 3.42	 1.25	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33915	 1	 146.43	 33.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33916	 1	 61.55	 15.9	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33917	 1	 2.72	 1.11	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33918	 1	 7.07	 2.5	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33919	 1	 5.51	 1.99	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33920	 1	 5.71	 2.2	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33921	 1	 3.42	 1.38	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33922	 1	 7.06	 3.01	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33923	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33924	 1	 5.01	 1.99	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33925	 1	 7.02	 2.74	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33926	 1	 5.02	 1.86	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33927	 1	 5.9	 2.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33928	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33929	 1	 3.08	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33930	 1	 5.3	 1.88	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33931	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33932	 1	 8.54	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33933	 1	 57.99	 17.29	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33934	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33935	 1	 5.97	 1.9	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33936	 1	 9.71	 3.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33937	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33938	 1	 5.33	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33939	 1	 3.18	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33940	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33941	 1	 6.21	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33942	 1	 5.17	 1.86	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33943	 1	 2.94	 1.04	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33944	 1	 5.93	 1.91	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33945	 1	 4.68	 1.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33946	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33947	 1	 10.86	 4.31	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33948	 1	 13.37	 4.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33949	 1	 5.41	 1.9	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33950	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33951	 1	 2.55	 0.99	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33952	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33953	 1	 2.33	 0.97	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33954	 1	 7.81	 2.97	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33955	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33956	 1	 3.55	 1.41	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33957	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33958	 1	 8.58	 3.24	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33959	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33960	 1	 9.04	 3.6	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33961	 1	 11.7	 3.36	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33962	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33963	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33964	 1	 8.24	 2.59	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33965	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33966	 1	 12.06	 3.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33967	 1	 8.02	 3.22	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33968	 1	 7.13	 1.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33969	 1	 15.3	 3.45	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33970	 1	 19.72	 4.45	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33971	 1	 2.18	 0.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33972	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33973	 1	 4.71	 1.19	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33974	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33975	 1	 9.52	 3.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33976	 1	 5.45	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33977	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33978	 1	 8.07	 2.7	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33979	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33980	 1	 2.85	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33981	 1	 3.3	 1.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33982	 1	 3.5	 1.62	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33983	 1	 1.59	 0.7	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33984	 1	 3.17	 1.17	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33985	 1	 3.22	 1.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33986	 1	 9.78	 4.18	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33987	 1	 6.85	 3.06	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33988	 1	 9.36	 3.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33989	 1	 9.2	 3.21	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33990	 1	 1.27	 0.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33991	 1	 2.6	 0.87	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33992	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33993	 1	 22.67	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33994	 1	 3.64	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	33995	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	33996	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33997	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33998	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	33999	 1	 3.1	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34000	 1	 4.5	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34001	 1	 5.16	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34002	 1	 2.54	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34003	 1	 2.15	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34004	 1	 11.4	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34005	 1	 9.38	 3.38	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34006	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34007	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34008	 1	 6.36	 1.86	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34009	 1	 11.11	 3.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34010	 1	 2.45	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34011	 1	 4.03	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34012	 1	 2.58	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34013	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34014	 1	 9.02	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34015	 1	 4.55	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34016	 1	 10.49	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34017	 1	 13.95	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34018	 1	 4.65	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34019	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34020	 1	 4.94	 2.07	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34021	 1	 11.3	 4.36	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34022	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34023	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34024	 1	 5.16	 1.95	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34025	 1	 3.0	 1.31	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34026	 1	 4.01	 1.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34027	 1	 2.38	 0.93	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34028	 1	 4.61	 1.86	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34029	 1	 1.17	 0.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34030	 1	 9.52	 3.26	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34031	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34032	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34033	 1	 2.39	 1.03	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34034	 1	 7.23	 2.71	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34035	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34036	 1	 8.88	 3.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34037	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34038	 1	 12.27	 4.19	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34039	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34040	 1	 22.7	 6.74	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34041	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34042	 1	 60.49	 12.96	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34043	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34044	 1	 7.86	 2.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34045	 1	 9.33	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34046	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34047	 1	 9.07	 3.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34048	 1	 5.14	 1.9	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34049	 1	 2.41	 0.8	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34050	 1	 4.55	 1.72	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34051	 1	 3.74	 1.26	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34052	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34053	 1	 2.78	 1.09	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34054	 1	 11.67	 4.72	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34055	 1	 6.29	 2.49	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34056	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34057	 1	 3.05	 1.26	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34058	 1	 4.82	 1.68	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34059	 1	 7.29	 2.64	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34060	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34061	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34062	 1	 8.37	 1.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34063	 1	 9.14	 3.21	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34064	 1	 10.08	 2.26	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34065	 1	 5.9	 1.31	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34066	 1	 2.72	 0.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34067	 1	 11.28	 2.5	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34068	 1	 6.9	 1.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34069	 1	 7.74	 3.14	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34070	 1	 4.35	 1.57	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34071	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34072	 1	 7.18	 2.23	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34073	 1	 9.4	 3.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34074	 1	 1.95	 0.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34075	 1	 7.55	 3.29	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34076	 1	 5.4	 2.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34077	 1	 18.38	 7.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34078	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34079	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34080	 1	 5.22	 2.23	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34081	 1	 4.21	 1.92	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34082	 1	 9.92	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34083	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34084	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34085	 1	 4.67	 1.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34086	 1	 5.36	 2.1	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34087	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34088	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34089	 1	 18.96	 7.12	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34090	 1	 1.43	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34091	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34092	 1	 10.27	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34093	 1	 2.57	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34094	 1	 6.28	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34095	 1	 6.29	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34096	 1	 1.54	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34097	 1	 18.59	 -5.05	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34098	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34099	 1	 15.05	 4.9	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34100	 1	 4.1	 1.59	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34101	 1	 1.64	 0.64	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34102	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34103	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34104	 1	 5.31	 2.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34105	 1	 9.43	 3.22	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34106	 1	 5.59	 2.42	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34107	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34108	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34109	 1	 13.81	 4.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34110	 1	 9.8	 3.88	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34111	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34112	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34113	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34114	 1	 2.37	 0.94	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34115	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34116	 1	 3.64	 1.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34117	 1	 11.14	 2.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34118	 1	 3.35	 0.76	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34119	 1	 11.6	 2.61	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34120	 1	 11.19	 2.55	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34121	 1	 4.05	 1.58	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34122	 1	 8.92	 2.96	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34123	 1	 3.8	 1.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34124	 1	 7.94	 3.1	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34125	 1	 9.61	 3.63	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34126	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34127	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34128	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34129	 1	 3.65	 1.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34130	 1	 4.25	 1.8	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34131	 1	 7.59	 2.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34132	 1	 4.44	 1.53	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34133	 1	 12.59	 3.86	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34134	 1	 5.03	 1.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34135	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34136	 1	 18.64	 6.58	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34137	 1	 6.89	 2.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34138	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34139	 1	 6.17	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34140	 1	 2.09	 0.92	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34141	 1	 1.33	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34142	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34143	 1	 1.89	 0.79	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34144	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34145	 1	 3.14	 1.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34146	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34147	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34148	 1	 9.5	 3.89	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34149	 1	 2.96	 1.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34150	 1	 3.31	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34151	 1	 8.14	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34152	 1	 5.75	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34153	 1	 10.29	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34154	 1	 2.28	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34155	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34156	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34157	 1	 7.72	 4.65	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34158	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34159	 1	 32.43	 13.39	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34160	 1	 8.66	 4.81	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34161	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34162	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34163	 1	 22.48	 9.96	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34164	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34165	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34166	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34167	 1	 4.64	 2.56	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34168	 1	 10.94	 6.09	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34169	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34170	 1	 11.0	 6.24	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34171	 1	 4.69	 3.02	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34172	 1	 6.88	 3.74	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34173	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34174	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34175	 1	 9.61	 5.29	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34176	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34177	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34178	 1	 5.18	 2.87	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34179	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34180	 1	 5.31	 3.57	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34181	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34182	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34183	 1	 11.19	 5.7	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34184	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34185	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34186	 1	 11.9	 6.55	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34187	 1	 6.96	 3.79	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34188	 1	 4.18	 2.01	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34189	 1	 9.58	 6.15	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34190	 1	 5.66	 3.69	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34191	 1	 10.77	 7.06	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34192	 1	 5.61	 3.07	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34193	 1	 26.07	 14.27	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34194	 1	 43.35	 18.74	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34195	 1	 2.41	 1.17	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34196	 1	 12.11	 6.63	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34197	 1	 12.86	 6.47	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34198	 1	 6.98	 3.45	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34199	 1	 4.86	 2.86	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34200	 1	 5.03	 3.13	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34201	 1	 11.09	 6.07	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34202	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34203	 1	 9.38	 5.04	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34204	 1	 10.56	 4.91	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34205	 1	 13.91	 7.49	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34206	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34207	 1	 9.03	 5.58	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34208	 1	 12.41	 7.85	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34209	 1	 7.68	 4.55	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34210	 1	 6.25	 3.54	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34211	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34212	 1	 62.65	 34.64	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34213	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34214	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34215	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34216	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34217	 1	 5.09	 2.6	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34218	 1	 6.74	 3.7	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34219	 1	 12.84	 7.38	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34220	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34221	 1	 6.26	 3.83	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34222	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34223	 1	 14.06	 6.29	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34224	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34225	 1	 14.28	 6.67	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34226	 1	 25.38	 12.71	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34227	 1	 2.55	 1.34	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34228	 1	 12.4	 7.68	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34229	 1	 14.74	 6.4	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34230	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34231	 1	 5.68	 3.3	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34232	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34233	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34234	 1	 11.28	 6.72	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34235	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34236	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34237	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34238	 1	 7.11	 3.54	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34239	 1	 2.89	 1.49	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34240	 1	 17.0	 7.01	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34241	 1	 18.73	 9.29	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34242	 1	 22.36	 9.56	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34243	 1	 6.88	 3.98	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34244	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34245	 1	 0.95	 0.49	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34246	 1	 28.03	 14.24	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34247	 1	 12.05	 5.28	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34248	 1	 9.25	 4.67	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34249	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34250	 1	 8.6	 4.49	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34251	 1	 10.78	 6.49	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34252	 1	 6.06	 3.33	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34253	 1	 4.18	 2.64	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34254	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34255	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34256	 1	 4.79	 2.78	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34257	 1	 10.15	 6.16	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34258	 1	 2.85	 1.51	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34259	 1	 41.19	 23.91	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34260	 1	 5.13	 2.58	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34261	 1	 6.11	 3.2	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34262	 1	 1.21	 0.62	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34263	 1	 3.38	 2.04	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34264	 1	 1.89	 1.18	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34265	 1	 3.7	 2.12	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34266	 1	 15.11	 8.83	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34267	 1	 3.71	 2.36	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34268	 1	 16.26	 9.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34269	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34270	 1	 6.48	 3.83	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34271	 1	 8.08	 4.25	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34272	 1	 3.69	 2.28	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34273	 1	 2.14	 1.26	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34274	 1	 4.97	 2.63	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34275	 1	 6.86	 3.33	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34276	 1	 7.17	 3.65	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34277	 1	 5.15	 2.61	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34278	 1	 6.17	 3.98	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34279	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34280	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34281	 1	 2.24	 1.42	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34282	 1	 2.21	 1.2	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34283	 1	 3.19	 1.9	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34284	 1	 1.01	 0.61	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34285	 1	 2.07	 1.01	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34286	 1	 4.27	 2.48	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34287	 1	 5.22	 3.38	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34288	 1	 36.83	 14.37	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34289	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34290	 1	 4.2	 2.62	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34291	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34292	 1	 8.54	 4.24	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34293	 1	 7.79	 4.52	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34294	 1	 14.66	 5.87	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34295	 1	 51.07	 20.81	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34296	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34297	 1	 10.67	 5.99	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34298	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34299	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34300	 1	 105.71	 49.68	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34301	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34302	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34303	 1	 3.39	 2.18	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34304	 1	 4.69	 2.61	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34305	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34306	 1	 13.97	 7.88	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34307	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34308	 1	 10.72	 6.14	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34309	 1	 6.51	 3.31	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34310	 1	 11.19	 4.4	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34311	 1	 12.65	 6.04	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34312	 1	 3.67	 2.28	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34313	 1	 4.78	 2.23	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34314	 1	 4.09	 2.33	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34315	 1	 5.5	 2.73	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34316	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34317	 1	 1.32	 0.79	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34318	 1	 6.5	 3.61	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34319	 1	 4.54	 2.21	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34320	 1	 6.82	 3.58	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34321	 1	 6.21	 2.63	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34322	 1	 4.16	 2.13	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34323	 1	 5.27	 3.17	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34324	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34325	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34326	 1	 2.21	 1.16	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34327	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34328	 1	 4.47	 2.69	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34329	 1	 29.3	 16.22	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34330	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34331	 1	 43.8	 16.58	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34332	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34333	 1	 7.73	 4.76	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34334	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34335	 1	 3.29	 1.49	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34336	 1	 4.83	 2.96	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34337	 1	 2.46	 1.36	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34338	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34339	 1	 6.28	 3.13	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34340	 1	 1.76	 0.9	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34341	 1	 7.89	 4.23	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34342	 1	 10.78	 6.11	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34343	 1	 2.98	 1.62	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34344	 1	 1.68	 0.84	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34345	 1	 7.45	 3.76	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34346	 1	 11.85	 6.76	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34347	 1	 9.05	 5.47	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34348	 1	 14.8	 3.28	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34349	 1	 2.51	 0.56	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34350	 1	 7.41	 1.65	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34351	 1	 6.37	 1.42	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34352	 1	 8.9	 1.99	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34353	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34354	 1	 8.75	 4.24	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34355	 1	 2.03	 1.2	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34356	 1	 2.17	 1.36	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34357	 1	 3.72	 1.92	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34358	 1	 2.34	 1.53	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34359	 1	 5.63	 3.37	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34360	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34361	 1	 4.9	 2.38	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34362	 1	 5.49	 2.74	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34363	 1	 3.26	 1.78	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34364	 1	 4.23	 2.2	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34365	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34366	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34367	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34368	 1	 10.2	 5.44	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34369	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34370	 1	 7.83	 4.2	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34371	 1	 9.05	 4.58	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34372	 1	 4.19	 2.25	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34373	 1	 4.16	 2.25	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34374	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34375	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34376	 1	 14.63	 6.2	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34377	 1	 18.48	 8.04	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34378	 1	 50.75	 22.89	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34379	 1	 6.14	 3.22	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34380	 1	 8.78	 5.26	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34381	 1	 48.76	 18.78	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34382	 1	 9.35	 4.09	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34383	 1	 14.94	 8.59	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34384	 1	 16.5	 7.84	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34385	 1	 71.04	 37.05	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34386	 1	 11.14	 5.54	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34387	 1	 171.18	 73.1	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34388	 1	 3.66	 1.85	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34389	 1	 4.06	 2.45	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34390	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34391	 1	 6.03	 3.73	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34392	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34393	 1	 3.44	 1.86	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34394	 1	 6.61	 2.95	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34395	 1	 42.79	 16.84	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34396	 1	 20.16	 4.57	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34397	 1	 10.98	 2.47	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34398	 1	 29.49	 14.08	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34399	 1	 7.34	 4.39	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34400	 1	 3.96	 0.89	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34401	 1	 11.48	 2.58	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34402	 1	 10.16	 6.21	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34403	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34404	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34405	 1	 9.24	 2.07	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34406	 1	 3.42	 0.76	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34407	 1	 2.23	 0.5	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34408	 1	 2.34	 0.52	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34409	 1	 3.45	 0.78	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34410	 1	 6.44	 4.01	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34411	 1	 9.73	 5.32	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34412	 1	 22.16	 10.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34413	 1	 5.46	 3.28	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34414	 1	 75.36	 36.76	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34415	 1	 39.63	 19.79	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34416	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34417	 1	 10.53	 5.56	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34418	 1	 6.56	 3.67	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34419	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34420	 1	 32.62	 11.62	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34421	 1	 22.53	 10.14	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34422	 1	 11.41	 4.69	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34423	 1	 23.45	 10.28	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34424	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34425	 1	 19.45	 9.4	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34426	 1	 2.48	 1.64	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34427	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34428	 1	 4.29	 2.35	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34429	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34430	 1	 3.08	 2.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34431	 1	 5.55	 3.15	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34432	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34433	 1	 4.08	 2.24	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34434	 1	 8.88	 4.49	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34435	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34436	 1	 4.3	 2.53	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34437	 1	 10.32	 5.04	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34438	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34439	 1	 27.53	 13.56	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34440	 1	 9.24	 4.88	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34441	 1	 6.97	 3.77	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34442	 1	 5.27	 2.42	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34443	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34444	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34445	 1	 6.85	 4.13	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34446	 1	 3.52	 1.72	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34447	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34448	 1	 3.13	 1.9	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34449	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34450	 1	 22.79	 8.44	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34451	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34452	 1	 11.11	 5.5	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34453	 1	 5.03	 1.15	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34454	 1	 4.09	 2.43	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34455	 1	 9.36	 4.43	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34456	 1	 3.44	 1.76	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34457	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34458	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34459	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34460	 1	 1.43	 0.83	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34461	 1	 5.11	 2.78	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34462	 1	 7.62	 3.47	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34463	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34464	 1	 3.59	 2.08	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34465	 1	 2.45	 1.55	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34466	 1	 9.03	 5.81	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34467	 1	 11.22	 5.06	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34468	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34469	 1	 10.42	 6.55	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34470	 1	 34.26	 19.23	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34471	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34472	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34473	 1	 8.59	 4.87	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34474	 1	 7.91	 4.08	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34475	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34476	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34477	 1	 3.75	 2.14	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34478	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34479	 1	 5.85	 3.71	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34480	 1	 9.09	 3.43	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34481	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34482	 1	 8.69	 3.7	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34483	 1	 11.11	 5.76	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34484	 1	 8.74	 5.26	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34485	 1	 14.26	 3.25	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34486	 1	 17.0	 7.6	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34487	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34488	 1	 5.7	 3.3	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34489	 1	 7.86	 1.77	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34490	 1	 8.26	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34491	 1	 28.53	 6.37	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34492	 1	 8.09	 1.78	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34493	 1	 5.77	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34494	 1	 15.47	 3.45	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34495	 1	 4.47	 2.98	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34496	 1	 14.16	 8.79	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34497	 1	 81.27	 33.05	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34498	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34499	 1	 17.47	 8.24	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34500	 1	 4.42	 0.99	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34501	 1	 14.31	 7.45	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34502	 1	 8.52	 4.58	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34503	 1	 51.19	 17.86	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34504	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34505	 1	 10.23	 5.67	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34506	 1	 2.18	 1.19	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34507	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34508	 1	 10.31	 4.44	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34509	 1	 6.2	 1.4	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34510	 1	 9.04	 5.24	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34511	 1	 4.54	 2.23	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34512	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34513	 1	 7.75	 4.51	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34514	 1	 4.24	 2.62	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34515	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34516	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34517	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34518	 1	 5.35	 3.21	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34519	 1	 14.04	 6.67	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34520	 1	 2.45	 1.35	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34521	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34522	 1	 10.41	 5.72	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34523	 1	 10.69	 4.6	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34524	 1	 18.32	 9.45	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34525	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34526	 1	 3.29	 2.04	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34527	 1	 6.12	 3.26	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34528	 1	 14.14	 6.06	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34529	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34530	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34531	 1	 11.47	 4.56	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34532	 1	 6.8	 3.92	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34533	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34534	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34535	 1	 9.03	 2.07	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34536	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34537	 1	 17.27	 9.64	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34538	 1	 13.59	 7.76	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34539	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34540	 1	 15.61	 6.61	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34541	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34542	 1	 20.36	 12.12	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34543	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34544	 1	 5.06	 2.74	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34545	 1	 6.94	 3.77	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34546	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34547	 1	 4.2	 2.34	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34548	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34549	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34550	 1	 2.46	 1.56	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34551	 1	 7.59	 1.73	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34552	 1	 11.03	 5.86	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34553	 1	 40.17	 12.8	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34554	 1	 7.27	 1.68	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34555	 1	 16.89	 3.92	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34556	 1	 5.08	 1.15	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34557	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34558	 1	 5.63	 1.28	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34559	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34560	 1	 5.27	 1.21	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34561	 1	 3.71	 0.84	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34562	 1	 12.03	 2.73	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34563	 1	 0.33	 0.1	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34564	 1	 4.48	 1.03	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34565	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34566	 1	 5.57	 3.33	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34567	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34568	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34569	 1	 3.69	 2.43	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34570	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34571	 1	 4.27	 2.15	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34572	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34573	 1	 6.85	 3.57	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34574	 1	 4.6	 2.38	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34575	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34576	 1	 52.64	 19.93	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34577	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34578	 1	 4.64	 1.05	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34579	 1	 10.41	 2.37	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34580	 1	 4.53	 1.03	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34581	 1	 3.83	 0.88	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34582	 1	 16.34	 3.72	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34583	 1	 2.32	 0.53	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34584	 1	 2.37	 0.54	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34585	 1	 6.6	 1.5	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34586	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34587	 1	 2.07	 0.47	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34588	 1	 4.43	 1.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34589	 1	 3.39	 0.77	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34590	 1	 2.92	 0.66	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34591	 1	 5.0	 1.14	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34592	 1	 7.56	 1.73	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34593	 1	 6.04	 1.39	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34594	 1	 5.38	 1.24	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34595	 1	 15.64	 3.51	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34596	 1	 22.87	 5.15	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34597	 1	 9.46	 2.12	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34598	 1	 5.16	 1.17	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34599	 1	 9.41	 2.12	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34600	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34601	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34602	 1	 3.85	 0.87	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34603	 1	 5.48	 1.24	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34604	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34605	 1	 4.32	 1.01	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34606	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34607	 1	 5.78	 1.34	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34608	 1	 25.87	 5.94	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34609	 1	 7.38	 1.68	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34610	 1	 8.56	 1.96	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34611	 1	 5.27	 1.21	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34612	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34613	 1	 8.24	 1.88	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34614	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34615	 1	 7.45	 1.7	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34616	 1	 12.83	 2.93	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34617	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34618	 1	 5.63	 1.29	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34619	 1	 25.14	 5.79	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34620	 1	 8.82	 2.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34621	 1	 5.22	 1.19	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34622	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34623	 1	 63.91	 14.56	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34624	 1	 6.56	 1.48	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34625	 1	 8.3	 1.88	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34626	 1	 7.11	 1.61	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34627	 1	 7.03	 1.59	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34628	 1	 5.59	 1.26	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34629	 1	 12.05	 2.71	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34630	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34631	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34632	 1	 8.55	 1.96	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34633	 1	 3.92	 0.89	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34634	 1	 7.54	 1.71	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34635	 1	 5.48	 1.27	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34636	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34637	 1	 10.36	 2.38	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34638	 1	 5.64	 1.29	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34639	 1	 8.32	 1.91	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34640	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34641	 1	 38.07	 17.44	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34642	 1	 10.86	 2.48	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34643	 1	 5.66	 1.31	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34644	 1	 7.06	 1.63	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34645	 1	 7.76	 1.77	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34646	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34647	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34648	 1	 32.06	 7.33	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34649	 1	 7.98	 1.84	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34650	 1	 7.42	 1.72	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34651	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34652	 1	 8.65	 2.01	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34653	 1	 7.98	 1.84	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34654	 1	 7.73	 1.8	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34655	 1	 35.56	 8.28	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34656	 1	 8.55	 4.33	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34657	 1	 10.02	 2.33	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34658	 1	 12.82	 2.98	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34659	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34660	 1	 36.76	 8.53	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34661	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34662	 1	 3.57	 1.5	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34663	 1	 9.49	 5.2	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34664	 1	 13.05	 7.42	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34665	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34666	 1	 44.19	 16.47	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34667	 1	 7.54	 4.34	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34668	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34669	 1	 5.1	 2.3	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34670	 1	 7.3	 1.68	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34671	 1	 5.92	 1.37	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34672	 1	 8.55	 1.97	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34673	 1	 4.76	 1.09	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34674	 1	 3.32	 0.76	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34675	 1	 6.86	 1.58	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34676	 1	 5.41	 1.24	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34677	 1	 9.03	 2.11	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34678	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34679	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34680	 1	 10.62	 2.41	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34681	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34682	 1	 4.02	 0.92	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34683	 1	 6.5	 3.65	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34684	 1	 10.46	 2.39	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34685	 1	 8.64	 2.84	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34686	 1	 2.94	 0.66	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34687	 1	 15.82	 3.59	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34688	 1	 16.4	 3.72	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34689	 1	 11.01	 5.7	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34690	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34691	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34692	 1	 11.01	 5.95	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34693	 1	 6.74	 1.54	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34694	 1	 15.41	 7.88	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34695	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34696	 1	 11.06	 6.08	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34697	 1	 90.83	 30.71	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34698	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34699	 1	 20.39	 10.88	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34700	 1	 21.28	 10.44	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34701	 1	 2.51	 1.3	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34702	 1	 2.54	 1.46	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34703	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34704	 1	 29.38	 11.67	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34705	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34706	 1	 48.91	 27.25	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34707	 1	 2.79	 1.54	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34708	 1	 4.43	 1.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34709	 1	 4.92	 1.1	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34710	 1	 13.57	 3.07	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34711	 1	 9.4	 2.22	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34712	 1	 0.92	 0.21	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34713	 1	 9.17	 2.11	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34714	 1	 4.42	 1.01	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34715	 1	 12.44	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34716	 1	 9.59	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34717	 1	 10.39	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34718	 1	 3.62	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34719	 1	 3.55	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34720	 1	 4.97	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34721	 1	 7.82	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34722	 1	 4.74	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34723	 1	 6.3	 1.46	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34724	 1	 5.31	 2.93	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34725	 1	 2.32	 0.54	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34726	 1	 10.41	 2.44	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34727	 1	 5.57	 1.31	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34728	 1	 2.44	 0.57	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34729	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34730	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34731	 1	 4.12	 2.04	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34732	 1	 32.64	 13.69	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34733	 1	 4.3	 2.49	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34734	 1	 1.8	 0.42	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34735	 1	 3.6	 0.84	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34736	 1	 1.49	 0.34	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34737	 1	 3.77	 0.88	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34738	 1	 6.55	 3.53	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34739	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34740	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34741	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34742	 1	 4.97	 1.16	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34743	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34744	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34745	 1	 13.36	 3.13	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34746	 1	 4.73	 1.09	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34747	 1	 9.74	 2.26	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34748	 1	 8.62	 2.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34749	 1	 3.04	 0.71	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34750	 1	 7.15	 4.1	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34751	 1	 4.33	 1.01	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34752	 1	 8.6	 4.92	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34753	 1	 9.48	 5.74	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34754	 1	 9.08	 5.62	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34755	 1	 6.48	 1.53	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34756	 1	 3.9	 0.92	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34757	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34758	 1	 4.04	 0.95	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34759	 1	 1.99	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34760	 1	 6.38	 1.5	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34761	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34762	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34763	 1	 9.97	 4.83	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34764	 1	 13.57	 5.22	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34765	 1	 7.89	 4.66	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34766	 1	 4.76	 2.11	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34767	 1	 10.23	 5.5	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34768	 1	 5.3	 3.23	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34769	 1	 8.57	 4.38	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34770	 1	 5.11	 3.17	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34771	 1	 5.16	 3.2	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34772	 1	 5.54	 2.91	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34773	 1	 11.32	 5.63	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34774	 1	 6.3	 3.6	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34775	 1	 4.32	 1.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34776	 1	 3.62	 0.84	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34777	 1	 6.0	 1.4	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34778	 1	 3.89	 1.8	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34779	 1	 8.05	 3.93	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34780	 1	 14.11	 7.23	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34781	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34782	 1	 19.98	 9.46	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34783	 1	 17.74	 9.93	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34784	 1	 3.5	 2.14	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34785	 1	 2.83	 1.81	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34786	 1	 5.71	 3.55	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34787	 1	 5.82	 3.43	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34788	 1	 34.54	 11.87	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34789	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34790	 1	 9.1	 5.14	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34791	 1	 7.4	 3.58	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34792	 1	 4.04	 2.14	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34793	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34794	 1	 12.24	 2.69	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34795	 1	 40.89	 17.43	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34796	 1	 17.53	 8.38	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34797	 1	 9.88	 3.53	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34798	 1	 4.76	 2.84	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34799	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34800	 1	 13.29	 7.71	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34801	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34802	 1	 10.44	 6.11	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34803	 1	 9.08	 5.11	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34804	 1	 6.65	 4.15	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34805	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34806	 1	 17.54	 6.85	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34807	 1	 9.31	 4.65	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34808	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34809	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34810	 1	 18.65	 9.26	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34811	 1	 17.64	 7.53	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34812	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34813	 1	 1.98	 0.45	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34814	 1	 14.18	 3.25	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34815	 1	 44.41	 10.33	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34816	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34817	 1	 4.09	 2.12	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34818	 1	 8.44	 1.95	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34819	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34820	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34821	 1	 8.77	 2.01	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34822	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34823	 1	 10.23	 2.28	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34824	 1	 21.17	 4.78	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34825	 1	 16.01	 3.6	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34826	 1	 16.93	 3.83	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34827	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34828	 1	 3.33	 1.77	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34829	 1	 1.93	 1.1	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34830	 1	 10.02	 5.45	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34831	 1	 29.11	 6.66	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34832	 1	 4.99	 3.18	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34833	 1	 1.97	 0.45	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34834	 1	 2.03	 0.47	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34835	 1	 83.02	 31.97	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34836	 1	 2.93	 1.8	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34837	 1	 3.5	 1.96	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34838	 1	 9.91	 6.13	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34839	 1	 12.25	 6.87	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34840	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34841	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34842	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34843	 1	 7.55	 3.08	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34844	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34845	 1	 8.73	 5.2	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34846	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34847	 1	 6.99	 3.37	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34848	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34849	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34850	 1	 8.58	 5.12	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34851	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34852	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34853	 1	 6.88	 3.85	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34854	 1	 3.42	 2.09	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34855	 1	 2.1	 1.2	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34856	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34857	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34858	 1	 3.57	 2.27	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34859	 1	 7.82	 4.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34860	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34861	 1	 7.19	 3.08	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34862	 1	 4.14	 2.26	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34863	 1	 5.0	 2.79	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34864	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34865	 1	 6.19	 3.36	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34866	 1	 15.26	 7.29	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34867	 1	 12.99	 7.31	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34868	 1	 10.01	 5.5	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34869	 1	 7.83	 4.66	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34870	 1	 1.71	 1.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34871	 1	 5.3	 3.19	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34872	 1	 1.83	 1.18	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34873	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34874	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34875	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34876	 1	 4.29	 2.65	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34877	 1	 5.33	 3.17	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34878	 1	 5.83	 3.55	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34879	 1	 4.95	 3.16	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34880	 1	 18.96	 7.99	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34881	 1	 73.87	 34.47	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34882	 1	 5.07	 3.03	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34883	 1	 7.24	 4.52	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34884	 1	 9.15	 4.61	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34885	 1	 5.48	 2.65	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34886	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34887	 1	 7.2	 3.12	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34888	 1	 4.52	 2.67	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34889	 1	 6.61	 3.48	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34890	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34891	 1	 4.15	 2.21	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34892	 1	 5.51	 3.55	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34893	 1	 7.31	 4.33	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34894	 1	 4.12	 2.69	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34895	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34896	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34897	 1	 3.56	 1.81	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34898	 1	 3.43	 1.84	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34899	 1	 4.4	 2.69	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34900	 1	 5.02	 2.58	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34901	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34902	 1	 5.29	 3.29	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34903	 1	 2.72	 1.63	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34904	 1	 6.67	 3.1	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34905	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34906	 1	 2.64	 1.64	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34907	 1	 8.82	 4.49	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34908	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34909	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34910	 1	 16.91	 7.2	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34911	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34912	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34913	 1	 12.73	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34914	 1	 7.72	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34915	 1	 9.96	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34916	 1	 6.42	 1.42	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34917	 1	 16.22	 3.65	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34918	 1	 2.17	 1.34	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34919	 1	 2.95	 1.72	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34920	 1	 11.86	 5.03	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34921	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34922	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34923	 1	 21.89	 9.37	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34924	 1	 6.43	 3.93	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34925	 1	 7.38	 1.68	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34926	 1	 5.4	 2.23	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34927	 1	 4.53	 2.54	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34928	 1	 8.39	 3.47	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34929	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34930	 1	 6.64	 1.51	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34931	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34932	 1	 28.27	 10.42	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34933	 1	 8.51	 3.92	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34934	 1	 10.9	 5.49	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34935	 1	 6.29	 4.03	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34936	 1	 7.19	 4.72	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34937	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34938	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34939	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34940	 1	 17.51	 8.5	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34941	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34942	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34943	 1	 5.3	 3.32	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34944	 1	 11.88	 5.87	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34945	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34946	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34947	 1	 11.72	 7.11	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34948	 1	 39.61	 13.94	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34949	 1	 4.61	 2.61	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34950	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34951	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34952	 1	 8.59	 4.58	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34953	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34954	 1	 5.81	 2.84	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34955	 1	 66.23	 29.79	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34956	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34957	 1	 11.51	 5.59	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34958	 1	 11.04	 6.79	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34959	 1	 10.48	 6.57	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34960	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34961	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34962	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34963	 1	 8.93	 5.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34964	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	34965	 1	 8.3	 5.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34966	 1	 7.75	 4.08	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34967	 1	 8.51	 4.63	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34968	 1	 6.17	 3.6	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34969	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34970	 1	 4.17	 2.25	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34971	 1	 13.13	 6.8	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34972	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34973	 1	 2.66	 1.72	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34974	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34975	 1	 5.37	 2.94	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34976	 1	 3.46	 0.81	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34977	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34978	 1	 4.42	 2.18	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34979	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34980	 1	 11.17	 4.63	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34981	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	34982	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34983	 1	 16.43	 9.12	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34984	 1	 9.31	 4.79	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34985	 1	 6.57	 3.23	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34986	 1	 8.84	 2.06	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34987	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34988	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34989	 1	 24.85	 8.45	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34990	 1	 3.08	 1.82	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34991	 1	 2.98	 1.93	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34992	 1	 14.39	 8.4	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34993	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34994	 1	 42.17	 24.34	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34995	 1	 7.63	 4.25	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34996	 1	 5.76	 3.8	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34997	 1	 10.21	 5.18	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	34998	 1	 6.26	 1.43	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	34999	 1	 8.59	 4.59	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35000	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35001	 1	 2.66	 1.41	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35002	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35003	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35004	 1	 6.62	 4.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35005	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35006	 1	 12.04	 6.99	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35007	 1	 6.31	 1.45	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35008	 1	 3.22	 0.74	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35009	 1	 12.16	 2.79	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35010	 1	 7.62	 1.75	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35011	 1	 4.3	 2.2	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35012	 1	 4.14	 0.94	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35013	 1	 3.04	 0.7	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35014	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35015	 1	 14.14	 6.76	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35016	 1	 15.88	 3.63	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35017	 1	 6.01	 1.37	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35018	 1	 3.07	 0.7	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35019	 1	 4.04	 2.4	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35020	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35021	 1	 22.06	 10.98	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35022	 1	 6.22	 1.42	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35023	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35024	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35025	 1	 23.94	 13.49	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35026	 1	 5.02	 3.08	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35027	 1	 9.66	 5.62	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35028	 1	 21.3	 12.96	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35029	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35030	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35031	 1	 10.55	 6.02	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35032	 1	 8.6	 5.19	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35033	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35034	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35035	 1	 5.34	 3.06	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35036	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35037	 1	 2.32	 1.45	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35038	 1	 8.21	 4.85	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35039	 1	 4.81	 2.67	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35040	 1	 5.21	 2.74	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35041	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35042	 1	 5.5	 2.24	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35043	 1	 0.8	 0.43	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35044	 1	 9.88	 2.27	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35045	 1	 5.58	 2.44	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35046	 1	 4.88	 1.11	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35047	 1	 7.85	 1.79	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35048	 1	 4.24	 0.97	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35049	 1	 10.9	 2.49	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35050	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35051	 1	 2.6	 0.6	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35052	 1	 3.91	 0.9	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35053	 1	 4.16	 0.95	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35054	 1	 4.39	 1.01	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35055	 1	 4.86	 1.1	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35056	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35057	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35058	 1	 15.28	 3.49	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35059	 1	 7.63	 1.74	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35060	 1	 8.72	 1.99	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35061	 1	 7.06	 1.61	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35062	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35063	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35064	 1	 8.54	 1.96	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35065	 1	 7.62	 1.73	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35066	 1	 11.38	 6.43	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35067	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35068	 1	 13.75	 8.67	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35069	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35070	 1	 10.35	 5.52	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35071	 1	 8.22	 4.14	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35072	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35073	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35074	 1	 2.66	 1.32	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35075	 1	 9.57	 5.48	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35076	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35077	 1	 5.88	 3.43	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35078	 1	 9.32	 5.04	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35079	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35080	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35081	 1	 45.45	 14.84	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35082	 1	 13.18	 6.62	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35083	 1	 11.08	 5.44	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35084	 1	 21.05	 10.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35085	 1	 45.68	 20.68	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35086	 1	 0.88	 0.39	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35087	 1	 3.51	 2.33	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35088	 1	 7.9	 4.36	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35089	 1	 5.6	 2.88	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35090	 1	 6.05	 3.36	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35091	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35092	 1	 26.73	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35093	 1	 1.94	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35094	 1	 3.57	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35095	 1	 5.99	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35096	 1	 2.69	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35097	 1	 4.67	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35098	 1	 3.83	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35099	 1	 20.27	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35100	 1	 6.43	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35101	 1	 2.9	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35102	 1	 3.26	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35103	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35104	 1	 13.02	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35105	 1	 5.21	 1.19	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35106	 1	 4.31	 0.98	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35107	 1	 7.6	 1.74	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35108	 1	 34.78	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35109	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35110	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35111	 1	 14.21	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35112	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35113	 1	 14.63	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35114	 1	 31.58	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35115	 1	 21.57	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35116	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35117	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35118	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35119	 1	 10.15	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35120	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35121	 1	 8.99	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35122	 1	 25.35	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35123	 1	 15.85	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35124	 1	 99.05	 22.5	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35125	 1	 2.6	 0.59	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35126	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35127	 1	 24.77	 10.01	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35128	 1	 9.6	 2.22	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35129	 1	 7.87	 1.82	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35130	 1	 7.76	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35131	 1	 9.4	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35132	 1	 52.9	 24.56	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35133	 1	 6.68	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35134	 1	 5.65	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35135	 1	 9.49	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35136	 1	 15.55	 3.53	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35137	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35138	 1	 8.95	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35139	 1	 42.43	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35140	 1	 16.87	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35141	 1	 43.84	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35142	 1	 18.28	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35143	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35144	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35145	 1	 47.02	 10.74	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35146	 1	 4.68	 1.06	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35147	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35148	 1	 4.81	 1.09	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35149	 1	 9.3	 2.12	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35150	 1	 24.57	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35151	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35152	 1	 40.04	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35153	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35154	 1	 7.91	 1.82	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35155	 1	 13.32	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35156	 1	 18.35	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35157	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35158	 1	 9.9	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35159	 1	 13.25	 2.99	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35160	 1	 49.39	 11.16	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35161	 1	 4.91	 3.1	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35162	 1	 6.25	 3.37	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35163	 1	 8.06	 3.99	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35164	 1	 50.04	 29.06	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35165	 1	 16.88	 3.83	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35166	 1	 2.93	 0.67	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35167	 1	 8.53	 1.93	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35168	 1	 6.71	 1.53	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35169	 1	 13.17	 3.02	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35170	 1	 17.4	 4.01	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35171	 1	 6.67	 1.54	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35172	 1	 91.39	 48.77	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35173	 1	 8.36	 1.93	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35174	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35175	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35176	 1	 8.83	 4.65	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35177	 1	 6.34	 1.46	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35178	 1	 7.97	 1.83	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35179	 1	 64.39	 33.2	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35180	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35181	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35182	 1	 7.39	 3.71	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35183	 1	 17.78	 4.09	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35184	 1	 6.97	 3.51	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35185	 1	 5.31	 2.53	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35186	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35187	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35188	 1	 3.15	 1.58	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35189	 1	 9.55	 3.86	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35190	 1	 14.3	 3.2	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35191	 1	 6.6	 1.52	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35192	 1	 3.15	 1.77	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35193	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35194	 1	 2.41	 1.17	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35195	 1	 11.9	 6.61	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35196	 1	 4.28	 2.49	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35197	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35198	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35199	 1	 11.89	 6.84	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35200	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35201	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35202	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35203	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35204	 1	 5.41	 3.2	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35205	 1	 8.97	 5.04	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35206	 1	 11.37	 5.16	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35207	 1	 3.84	 2.32	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35208	 1	 2.09	 1.18	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35209	 1	 8.84	 4.34	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35210	 1	 4.04	 2.46	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35211	 1	 7.6	 3.86	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35212	 1	 10.73	 6.78	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35213	 1	 5.78	 3.27	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35214	 1	 10.26	 5.85	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35215	 1	 5.75	 3.77	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35216	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35217	 1	 8.94	 4.91	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35218	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35219	 1	 20.1	 11.97	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35220	 1	 10.52	 5.98	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35221	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35222	 1	 9.62	 5.41	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35223	 1	 13.32	 6.97	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35224	 1	 5.62	 3.47	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35225	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35226	 1	 10.23	 4.14	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35227	 1	 5.71	 2.93	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35228	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35229	 1	 5.6	 3.16	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35230	 1	 37.28	 16.82	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35231	 1	 5.19	 3.23	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35232	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35233	 1	 20.23	 10.96	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35234	 1	 11.25	 5.11	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35235	 1	 6.02	 3.58	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35236	 1	 6.16	 3.61	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35237	 1	 4.44	 2.75	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35238	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35239	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35240	 1	 13.28	 4.48	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35241	 1	 19.14	 9.87	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35242	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35243	 1	 7.03	 4.38	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35244	 1	 6.54	 3.9	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35245	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35246	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35247	 1	 8.35	 4.19	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35248	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35249	 1	 5.92	 3.14	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35250	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35251	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35252	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35253	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35254	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35255	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35256	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35257	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35258	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35259	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35260	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35261	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35262	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35263	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35264	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35265	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35266	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35267	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35268	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35269	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35270	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35271	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35272	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35273	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35274	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35276	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35277	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35278	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35279	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35280	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35281	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35282	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35283	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35284	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35285	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35286	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35287	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35288	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35289	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35290	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35291	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35292	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35293	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35294	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35295	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35296	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35297	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35298	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35299	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35300	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35301	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35302	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35303	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35304	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35305	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35306	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35307	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35308	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35309	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35310	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35311	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35312	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35313	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35314	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35315	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35316	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35317	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35318	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35319	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35320	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35321	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35322	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35323	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35324	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35325	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35326	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35327	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35328	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35329	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35330	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35331	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35332	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35333	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35334	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35335	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35336	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35337	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35338	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35339	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35340	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35341	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35342	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35343	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35344	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35345	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35346	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35347	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35348	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35349	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35350	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35351	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35352	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35353	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35354	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35355	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35356	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35357	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35358	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35359	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35360	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35361	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35362	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35363	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35364	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35365	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35366	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35367	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35368	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35369	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35370	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35371	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35372	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35373	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35374	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35375	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35376	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35377	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35378	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35379	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35380	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35381	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35382	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35383	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35384	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35385	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35386	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35387	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35388	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35389	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35390	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35391	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35392	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35393	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35394	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35395	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35396	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35397	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35398	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35399	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35400	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35401	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35402	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35403	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35404	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35405	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35406	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35407	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35408	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35409	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35410	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35411	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35412	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35413	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35414	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35415	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35416	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35417	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35418	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35419	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35420	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35421	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35422	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35423	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35424	 1	 2.98	 1.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35425	 1	 2.64	 1.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35426	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35427	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35428	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35429	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35430	 1	 17.06	 6.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35431	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35432	 1	 14.18	 6.74	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35433	 1	 6.4	 2.73	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35434	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35435	 1	 3.75	 1.96	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35436	 1	 8.61	 3.33	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35437	 1	 5.95	 1.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35438	 1	 24.3	 8.23	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35439	 1	 9.75	 3.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35440	 1	 12.08	 5.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35441	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35442	 1	 11.28	 5.59	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35443	 1	 24.18	 9.67	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35444	 1	 6.08	 2.27	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35445	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35446	 1	 13.68	 6.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35447	 1	 9.34	 3.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35448	 1	 10.43	 4.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35449	 1	 12.47	 5.59	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35450	 1	 5.23	 1.17	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35451	 1	 7.45	 1.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35452	 1	 10.36	 4.93	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35453	 1	 6.09	 2.72	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35454	 1	 6.1	 2.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35455	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35456	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35457	 1	 22.62	 5.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35458	 1	 13.95	 3.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35459	 1	 5.67	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35460	 1	 6.9	 1.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35461	 1	 5.98	 1.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35462	 1	 0.49	 0.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35463	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35464	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35465	 1	 10.44	 2.38	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35466	 1	 6.94	 1.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35467	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35468	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35469	 1	 9.11	 2.26	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35470	 1	 4.86	 2.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35471	 1	 19.72	 5.93	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35472	 1	 4.06	 1.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35474	 1	 3.14	 1.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35475	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35477	 1	 7.81	 3.44	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35482	 1	 4.28	 0.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35483	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35484	 1	 7.77	 1.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35485	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35486	 1	 4.43	 1.66	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35487	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35488	 1	 10.23	 4.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35489	 1	 1.81	 0.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35490	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35491	 1	 2.87	 1.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35492	 1	 7.86	 3.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35493	 1	 3.66	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35494	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35495	 1	 1.66	 0.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35496	 1	 3.83	 1.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35497	 1	 7.35	 3.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35498	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35499	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35500	 1	 1.59	 0.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35501	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35502	 1	 4.28	 1.75	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35503	 1	 35.17	 9.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35504	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35505	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35506	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35507	 1	 18.98	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35508	 1	 5.31	 2.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35509	 1	 49.4	 19.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35510	 1	 45.56	 14.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35511	 1	 8.02	 3.27	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35512	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35513	 1	 4.96	 1.98	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35514	 1	 10.93	 4.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35515	 1	 22.77	 9.13	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35516	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35517	 1	 9.42	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35518	 1	 10.02	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35519	 1	 10.55	 3.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35520	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35521	 1	 3.85	 1.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35522	 1	 14.55	 5.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35523	 1	 5.53	 2.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35524	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35525	 1	 5.1	 2.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35526	 1	 16.77	 6.29	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35527	 1	 6.08	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35528	 1	 5.21	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35529	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35530	 1	 0.3	 0.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35531	 1	 4.46	 2.08	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35532	 1	 4.07	 2.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35533	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35534	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35535	 1	 24.96	 6.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35536	 1	 1.69	 0.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35537	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35538	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35539	 1	 11.81	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35540	 1	 3.95	 1.99	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35541	 1	 4.56	 2.05	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35542	 1	 13.43	 5.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35543	 1	 17.46	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35544	 1	 8.94	 3.94	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35545	 1	 6.18	 2.46	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35546	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35547	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35548	 1	 4.3	 2.15	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35549	 1	 8.52	 3.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35550	 1	 14.86	 6.67	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35551	 1	 10.66	 5.54	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35552	 1	 7.64	 2.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35553	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35554	 1	 6.81	 2.68	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35555	 1	 51.68	 18.36	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35556	 1	 8.6	 3.18	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35557	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35558	 1	 3.73	 1.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35559	 1	 17.92	 5.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35560	 1	 1.13	 0.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35561	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35562	 1	 1.5	 0.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35563	 1	 13.7	 4.81	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35564	 1	 5.27	 2.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35565	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35566	 1	 2.21	 0.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35567	 1	 1.95	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35568	 1	 14.03	 4.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35569	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35570	 1	 3.28	 1.55	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35571	 1	 3.96	 1.73	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35572	 1	 5.81	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35573	 1	 13.67	 3.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35574	 1	 18.54	 5.33	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35575	 1	 5.27	 2.03	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35576	 1	 2.89	 1.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35577	 1	 9.47	 2.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35578	 1	 6.53	 2.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35579	 1	 11.57	 5.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35580	 1	 12.32	 5.46	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35581	 1	 2.14	 0.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35582	 1	 6.31	 2.47	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35583	 1	 3.39	 1.38	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35584	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35585	 1	 5.31	 2.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35586	 1	 3.42	 1.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35587	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35588	 1	 11.14	 4.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35589	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35590	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35591	 1	 2.59	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35592	 1	 20.23	 8.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35593	 1	 3.67	 1.77	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35594	 1	 10.63	 4.06	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35595	 1	 11.56	 5.01	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35596	 1	 147.68	 68.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35597	 1	 12.95	 5.41	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35598	 1	 11.91	 4.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35599	 1	 5.25	 2.44	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35600	 1	 5.58	 2.47	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35601	 1	 10.79	 4.71	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35602	 1	 34.0	 15.97	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35603	 1	 20.28	 4.97	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35604	 1	 2.04	 0.87	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35605	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35606	 1	 12.09	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35607	 1	 7.06	 2.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35608	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35609	 1	 9.66	 4.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35610	 1	 6.43	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35611	 1	 9.56	 3.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35612	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35613	 1	 20.44	 6.96	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35614	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35615	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35616	 1	 9.95	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35617	 1	 3.22	 1.38	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35618	 1	 4.5	 2.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35619	 1	 7.15	 3.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35620	 1	 1.72	 0.82	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35621	 1	 4.35	 1.36	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35622	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35623	 1	 2.53	 1.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35624	 1	 2.08	 0.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35625	 1	 6.65	 2.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35626	 1	 4.05	 1.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35627	 1	 2.15	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35628	 1	 3.78	 1.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35629	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35630	 1	 2.11	 1.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35631	 1	 2.43	 1.06	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35632	 1	 6.4	 1.47	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35633	 1	 10.24	 3.94	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35634	 1	 10.9	 2.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35635	 1	 6.35	 2.41	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35636	 1	 4.72	 1.86	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35637	 1	 4.73	 1.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35638	 1	 20.22	 4.57	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35639	 1	 9.22	 4.37	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35640	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35641	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35642	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35643	 1	 2.61	 0.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35644	 1	 5.5	 1.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35645	 1	 5.44	 1.23	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35646	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35647	 1	 8.25	 3.67	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35648	 1	 2.55	 1.19	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35649	 1	 4.41	 2.12	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35650	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35651	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35652	 1	 2.94	 1.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35653	 1	 3.27	 1.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35654	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35655	 1	 3.83	 1.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35656	 1	 6.75	 2.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35657	 1	 3.79	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35658	 1	 5.48	 2.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35659	 1	 6.01	 2.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35660	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35661	 1	 4.18	 1.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35662	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35663	 1	 20.99	 6.74	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35664	 1	 61.09	 25.71	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35665	 1	 4.4	 1.93	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35666	 1	 3.01	 1.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35667	 1	 7.12	 3.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35668	 1	 7.54	 3.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35669	 1	 21.18	 6.21	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35670	 1	 6.39	 2.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35671	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35672	 1	 2.38	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35673	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35674	 1	 3.46	 1.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35675	 1	 2.2	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35676	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35677	 1	 2.61	 0.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35678	 1	 22.8	 7.79	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35679	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35680	 1	 4.17	 1.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35681	 1	 14.63	 3.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35682	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35683	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35684	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35685	 1	 10.35	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35686	 1	 18.67	 7.89	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35687	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35688	 1	 4.61	 1.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35689	 1	 9.83	 3.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35690	 1	 25.01	 7.77	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35691	 1	 14.9	 5.79	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35692	 1	 6.31	 2.78	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35693	 1	 11.4	 5.82	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35694	 1	 5.94	 3.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35695	 1	 2.78	 1.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35696	 1	 16.97	 7.26	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35697	 1	 12.37	 4.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35698	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35699	 1	 7.25	 2.93	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35700	 1	 7.75	 3.17	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35701	 1	 13.86	 5.91	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35702	 1	 7.6	 3.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35703	 1	 4.17	 1.68	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35704	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35706	 1	 10.24	 3.92	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35707	 1	 9.97	 4.51	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35708	 1	 8.64	 3.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35710	 1	 7.56	 3.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35711	 1	 23.93	 9.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35712	 1	 5.85	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35713	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35714	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35715	 1	 7.19	 2.57	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35716	 1	 9.51	 4.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35717	 1	 4.13	 1.79	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35718	 1	 5.25	 2.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35719	 1	 4.36	 1.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35720	 1	 2.05	 0.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35721	 1	 3.61	 1.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35722	 1	 3.79	 1.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35723	 1	 2.56	 0.92	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35724	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35725	 1	 1.83	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35726	 1	 6.09	 2.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35727	 1	 8.09	 3.08	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35728	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35729	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35730	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35731	 1	 3.46	 1.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35732	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35733	 1	 3.48	 1.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35734	 1	 8.47	 3.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35735	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35736	 1	 10.05	 4.97	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35737	 1	 7.68	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35738	 1	 7.03	 3.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35739	 1	 21.68	 10.89	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35740	 1	 4.44	 2.01	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35741	 1	 3.33	 1.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35742	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35743	 1	 5.96	 1.36	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35744	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35745	 1	 6.17	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35746	 1	 4.07	 2.05	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35747	 1	 2.08	 0.88	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35748	 1	 4.71	 1.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35749	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35750	 1	 22.19	 8.41	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35751	 1	 5.88	 2.06	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35752	 1	 14.82	 5.95	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35753	 1	 7.2	 3.74	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35754	 1	 3.06	 1.36	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35755	 1	 5.06	 2.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35756	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35757	 1	 9.45	 3.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35758	 1	 5.89	 2.48	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35759	 1	 4.98	 2.17	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35760	 1	 7.08	 3.05	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35761	 1	 6.32	 2.73	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35762	 1	 3.38	 1.29	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35763	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35764	 1	 10.04	 4.36	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35765	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35766	 1	 4.25	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35767	 1	 2.24	 0.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35768	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35769	 1	 7.23	 3.33	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35770	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35771	 1	 1.79	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35772	 1	 1.79	 0.93	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35773	 1	 2.55	 1.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35774	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35775	 1	 7.87	 3.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35776	 1	 4.27	 1.61	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35777	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35778	 1	 3.49	 1.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35779	 1	 4.19	 1.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35780	 1	 17.48	 6.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35781	 1	 2.06	 0.92	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35782	 1	 6.39	 2.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35783	 1	 17.12	 7.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35784	 1	 18.79	 6.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35785	 1	 17.16	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35786	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35787	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35788	 1	 4.28	 1.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35789	 1	 4.41	 1.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35790	 1	 3.89	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35791	 1	 14.53	 7.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35792	 1	 5.26	 2.56	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35793	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35794	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35795	 1	 4.3	 1.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35796	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35797	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35798	 1	 11.2	 4.19	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35799	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35800	 1	 3.36	 1.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35801	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35802	 1	 6.79	 2.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35803	 1	 8.8	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35804	 1	 8.67	 3.73	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35805	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35806	 1	 30.17	 12.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35807	 1	 2.39	 0.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35808	 1	 4.69	 1.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35809	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35810	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35811	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35812	 1	 13.97	 5.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35813	 1	 5.3	 2.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35814	 1	 8.95	 3.88	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35815	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35816	 1	 4.33	 1.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35817	 1	 27.15	 10.17	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35818	 1	 37.24	 14.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35819	 1	 38.06	 13.49	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35820	 1	 30.8	 8.15	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35821	 1	 12.03	 3.99	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35822	 1	 59.04	 22.38	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35823	 1	 4.55	 1.57	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35824	 1	 4.4	 1.72	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35825	 1	 4.39	 1.75	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35826	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35827	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35828	 1	 3.6	 1.71	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35829	 1	 2.97	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35830	 1	 6.31	 2.53	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35831	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35832	 1	 5.95	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35833	 1	 76.11	 27.06	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35834	 1	 27.17	 11.17	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35835	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35836	 1	 4.83	 2.23	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35837	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35838	 1	 6.0	 2.61	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35839	 1	 2.25	 0.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35840	 1	 1.83	 0.68	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35841	 1	 3.95	 1.77	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35842	 1	 13.26	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35843	 1	 5.28	 2.18	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35844	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35845	 1	 7.43	 2.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35846	 1	 5.06	 1.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35847	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35848	 1	 7.02	 3.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35849	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35850	 1	 31.7	 12.68	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35851	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35852	 1	 3.51	 1.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35853	 1	 2.1	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35854	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35855	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35856	 1	 4.31	 1.63	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35857	 1	 1.91	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35858	 1	 3.53	 1.52	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35859	 1	 9.11	 3.67	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35860	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35861	 1	 3.91	 1.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35862	 1	 63.8	 21.6	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35863	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35864	 1	 5.84	 2.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35865	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35866	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35867	 1	 8.43	 3.36	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35868	 1	 8.3	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35869	 1	 2.37	 0.89	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35870	 1	 7.28	 3.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35871	 1	 2.87	 1.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35872	 1	 5.91	 2.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35873	 1	 8.37	 4.06	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35874	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35875	 1	 6.94	 3.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35876	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35877	 1	 3.41	 1.36	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35878	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35879	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35880	 1	 2.28	 0.85	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35881	 1	 5.43	 2.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35882	 1	 21.11	 8.36	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35883	 1	 2.75	 1.26	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35884	 1	 2.69	 1.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35885	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35886	 1	 3.55	 1.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35887	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35888	 1	 4.69	 2.18	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35889	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35890	 1	 8.62	 4.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35891	 1	 6.73	 3.17	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35892	 1	 7.73	 2.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35893	 1	 3.37	 1.42	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35894	 1	 10.4	 4.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35895	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35896	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35897	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35898	 1	 10.06	 4.57	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35899	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35900	 1	 15.81	 7.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35901	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35902	 1	 6.41	 1.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35903	 1	 11.32	 2.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35904	 1	 4.44	 2.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35905	 1	 6.42	 1.45	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35906	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35907	 1	 4.49	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35908	 1	 4.01	 1.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35909	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35910	 1	 4.47	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35911	 1	 8.34	 2.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35912	 1	 10.0	 4.03	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35913	 1	 7.42	 3.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35914	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35915	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35916	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35917	 1	 8.87	 3.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35918	 1	 4.6	 1.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35919	 1	 9.8	 4.74	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35920	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35921	 1	 5.64	 2.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35922	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35923	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35924	 1	 7.06	 2.77	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35925	 1	 11.11	 4.66	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35926	 1	 7.59	 2.66	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35927	 1	 4.17	 1.76	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35928	 1	 9.39	 4.62	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35929	 1	 13.95	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35930	 1	 4.13	 1.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35931	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35932	 1	 4.79	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35933	 1	 8.66	 3.67	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35934	 1	 8.04	 2.43	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35935	 1	 5.78	 2.48	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35936	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35937	 1	 21.74	 6.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35938	 1	 7.83	 3.02	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35939	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35940	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35941	 1	 7.24	 2.81	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35942	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35943	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35944	 1	 5.64	 2.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35945	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35946	 1	 6.64	 2.55	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35947	 1	 6.5	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35948	 1	 9.21	 4.24	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35949	 1	 7.48	 3.27	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35950	 1	 2.17	 1.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35951	 1	 12.74	 5.96	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35952	 1	 2.47	 1.03	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35953	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35954	 1	 6.05	 2.68	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35955	 1	 8.91	 3.75	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35956	 1	 10.14	 4.24	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35957	 1	 5.14	 2.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35958	 1	 29.84	 10.57	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35959	 1	 46.55	 13.06	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35960	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35961	 1	 5.85	 2.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35962	 1	 10.27	 3.53	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35963	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	35964	 1	 17.79	 7.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35965	 1	 15.97	 5.52	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35966	 1	 19.38	 6.86	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35967	 1	 22.98	 8.81	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35968	 1	 11.44	 3.91	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35969	 1	 29.0	 11.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35970	 1	 7.46	 3.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35971	 1	 5.19	 2.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35972	 1	 7.26	 3.08	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35973	 1	 9.24	 4.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35974	 1	 9.23	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35975	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35976	 1	 5.08	 1.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35977	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35978	 1	 6.64	 2.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35979	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	35980	 1	 23.69	 9.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35981	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35982	 1	 3.15	 1.23	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35983	 1	 1.9	 0.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35984	 1	 3.43	 1.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35985	 1	 3.09	 1.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35986	 1	 9.78	 3.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35987	 1	 7.51	 3.57	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35988	 1	 23.62	 8.64	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35989	 1	 5.39	 2.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35990	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35991	 1	 6.64	 2.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	35992	 1	 10.45	 4.07	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35993	 1	 2.84	 1.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35994	 1	 7.6	 3.77	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35995	 1	 31.8	 11.6	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35996	 1	 6.09	 2.46	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35997	 1	 6.1	 2.74	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35998	 1	 7.52	 3.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	35999	 1	 8.6	 4.37	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36000	 1	 5.16	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36001	 1	 6.69	 3.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36002	 1	 5.6	 2.36	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36003	 1	 11.42	 5.78	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36004	 1	 34.02	 7.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36005	 1	 5.4	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36006	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36007	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36008	 1	 6.19	 2.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36009	 1	 2.4	 1.03	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36010	 1	 5.42	 2.14	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36011	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36012	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36013	 1	 3.17	 1.26	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36014	 1	 10.32	 4.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36015	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36016	 1	 5.63	 2.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36017	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36018	 1	 13.55	 5.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36019	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36020	 1	 4.72	 2.05	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36021	 1	 3.68	 1.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36022	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36023	 1	 11.24	 4.92	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36024	 1	 31.61	 10.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36025	 1	 19.82	 8.68	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36026	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36027	 1	 4.21	 2.01	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36028	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36029	 1	 44.45	 17.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36030	 1	 14.65	 6.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36031	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36032	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36033	 1	 4.11	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36034	 1	 11.46	 4.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36035	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36036	 1	 2.25	 1.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36037	 1	 8.28	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36038	 1	 8.08	 4.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36039	 1	 5.61	 2.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36040	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36041	 1	 6.66	 2.75	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36042	 1	 7.7	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36043	 1	 4.04	 1.74	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36044	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36045	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36046	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36047	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36048	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36050	 1	 10.8	 5.07	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36051	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36052	 1	 3.14	 1.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36053	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36054	 1	 22.44	 8.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36055	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36056	 1	 3.94	 1.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36057	 1	 2.71	 1.24	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36058	 1	 4.06	 1.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36059	 1	 2.38	 1.12	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36060	 1	 4.32	 2.13	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36061	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36062	 1	 2.71	 1.26	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36063	 1	 2.09	 0.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36064	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36065	 1	 1.42	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36066	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36067	 1	 2.3	 0.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36068	 1	 2.37	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36069	 1	 4.38	 1.57	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36070	 1	 2.78	 1.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36071	 1	 55.29	 14.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36072	 1	 6.86	 2.95	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36073	 1	 4.65	 2.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36074	 1	 4.31	 1.88	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36075	 1	 8.79	 1.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36076	 1	 6.4	 1.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36077	 1	 4.15	 0.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36078	 1	 2.31	 0.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36079	 1	 3.61	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36080	 1	 2.44	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36081	 1	 5.09	 2.13	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36082	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36083	 1	 15.41	 5.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36084	 1	 2.33	 1.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36085	 1	 4.22	 1.73	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36086	 1	 5.21	 1.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36087	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36088	 1	 5.2	 1.82	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36089	 1	 1.78	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36090	 1	 48.04	 13.74	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36091	 1	 8.05	 1.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36092	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36093	 1	 4.41	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36094	 1	 4.2	 1.78	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36095	 1	 2.07	 0.47	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36096	 1	 2.8	 0.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36097	 1	 8.42	 1.92	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36098	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36099	 1	 2.56	 1.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36100	 1	 6.22	 2.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36101	 1	 5.35	 1.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36102	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36104	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36105	 1	 2.86	 1.33	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36106	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36107	 1	 5.74	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36108	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36109	 1	 14.7	 5.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36110	 1	 5.69	 2.66	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36111	 1	 2.78	 1.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36113	 1	 4.95	 1.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36114	 1	 15.33	 3.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36115	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36117	 1	 12.56	 2.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36118	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36119	 1	 4.96	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36120	 1	 6.8	 3.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36121	 1	 8.36	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36122	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36123	 1	 3.3	 1.36	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36124	 1	 6.17	 2.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36125	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36127	 1	 6.6	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36129	 1	 15.23	 3.47	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36130	 1	 10.61	 4.74	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36131	 1	 18.3	 4.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36132	 1	 15.57	 3.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36133	 1	 9.95	 2.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36134	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36135	 1	 7.14	 2.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36136	 1	 6.28	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36137	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36138	 1	 12.72	 4.15	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36139	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36140	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36141	 1	 56.22	 20.39	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36142	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36143	 1	 5.61	 2.58	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36144	 1	 26.07	 11.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36145	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36146	 1	 3.94	 1.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36147	 1	 3.17	 1.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36148	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36149	 1	 35.79	 11.63	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36150	 1	 23.41	 9.94	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36151	 1	 7.45	 2.46	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36152	 1	 6.69	 2.59	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36153	 1	 8.95	 3.77	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36155	 1	 6.38	 2.24	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36157	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36158	 1	 5.41	 2.37	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36159	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36160	 1	 6.2	 2.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36161	 1	 8.31	 3.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36162	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36163	 1	 5.27	 2.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36165	 1	 9.86	 2.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36166	 1	 25.48	 5.81	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36167	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36168	 1	 18.8	 4.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36169	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36170	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36171	 1	 16.56	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36172	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36174	 1	 15.31	 4.99	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36175	 1	 10.79	 2.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36176	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36177	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36178	 1	 0.12	 0.05	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36179	 1	 2.05	 0.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36180	 1	 5.73	 2.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36181	 1	 2.63	 0.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36182	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36183	 1	 7.58	 3.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36184	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36185	 1	 2.88	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36186	 1	 2.7	 1.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36187	 1	 4.22	 1.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36188	 1	 2.65	 1.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36189	 1	 2.72	 1.08	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36190	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36191	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36192	 1	 2.64	 1.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36193	 1	 2.44	 0.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36194	 1	 1.81	 0.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36195	 1	 3.92	 1.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36196	 1	 3.87	 1.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36197	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36198	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36199	 1	 7.53	 3.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36200	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36201	 1	 3.42	 1.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36202	 1	 3.02	 1.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36203	 1	 7.09	 2.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36204	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36205	 1	 5.86	 2.67	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36206	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36207	 1	 8.55	 3.88	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36208	 1	 7.77	 3.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36209	 1	 20.02	 7.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36210	 1	 10.01	 3.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36211	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36212	 1	 3.31	 1.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36213	 1	 4.1	 1.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36214	 1	 9.66	 3.73	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36215	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36216	 1	 4.17	 1.99	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36217	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36218	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36219	 1	 3.08	 1.45	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36220	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36221	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36222	 1	 13.43	 5.94	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36223	 1	 4.89	 2.03	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36224	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36225	 1	 7.06	 3.51	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36226	 1	 1.73	 0.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36227	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36228	 1	 5.42	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36229	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36230	 1	 1.47	 0.71	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36231	 1	 6.52	 3.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36232	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36233	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36234	 1	 4.9	 2.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36235	 1	 5.62	 2.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36236	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36237	 1	 8.23	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36238	 1	 6.1	 2.95	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36239	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36240	 1	 3.78	 1.47	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36241	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36242	 1	 3.29	 1.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36243	 1	 1.03	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36244	 1	 1.77	 0.72	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36245	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36246	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36247	 1	 1.76	 0.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36248	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36249	 1	 4.35	 1.78	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36250	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36251	 1	 6.77	 2.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36252	 1	 13.86	 6.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36253	 1	 125.77	 44.27	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36254	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36255	 1	 6.07	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36256	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36257	 1	 7.49	 3.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36258	 1	 8.52	 3.68	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36259	 1	 10.63	 3.49	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36260	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36261	 1	 7.0	 3.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36262	 1	 12.36	 4.78	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36263	 1	 9.02	 3.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36265	 1	 10.88	 5.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36266	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36267	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36268	 1	 10.6	 3.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36269	 1	 7.55	 3.51	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36270	 1	 6.45	 2.51	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36272	 1	 12.17	 4.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36273	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36274	 1	 12.55	 6.18	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36275	 1	 11.87	 5.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36277	 1	 11.07	 4.41	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36278	 1	 8.65	 3.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36279	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36280	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36281	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36282	 1	 37.15	 17.4	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36283	 1	 4.4	 1.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36284	 1	 6.35	 2.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36285	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36286	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36287	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36288	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36289	 1	 2.46	 1.12	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36290	 1	 2.86	 1.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36291	 1	 10.59	 3.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36292	 1	 40.1	 7.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36293	 1	 13.71	 5.98	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36294	 1	 15.72	 7.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36295	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36296	 1	 11.63	 5.71	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36297	 1	 2.24	 1.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36298	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36299	 1	 2.19	 1.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36300	 1	 51.5	 20.97	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36301	 1	 7.8	 3.01	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36302	 1	 4.42	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36303	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36304	 1	 1.86	 0.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36305	 1	 7.21	 3.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36306	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36307	 1	 5.21	 1.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36308	 1	 3.14	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36309	 1	 3.58	 1.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36310	 1	 6.17	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36311	 1	 7.0	 2.57	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36312	 1	 7.67	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36313	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36314	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36315	 1	 3.56	 1.76	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36316	 1	 8.36	 3.99	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36317	 1	 7.65	 3.58	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36318	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36319	 1	 1.72	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36320	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36321	 1	 5.22	 2.46	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36322	 1	 12.64	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36323	 1	 7.67	 3.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36324	 1	 13.19	 4.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36325	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36326	 1	 9.46	 4.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36327	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36328	 1	 4.58	 1.98	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36329	 1	 6.65	 3.05	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36330	 1	 5.1	 2.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36331	 1	 12.88	 4.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36332	 1	 7.92	 2.79	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36333	 1	 6.68	 2.46	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36334	 1	 9.04	 3.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36335	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36336	 1	 15.29	 5.72	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36337	 1	 16.61	 7.72	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36338	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36339	 1	 6.71	 2.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36340	 1	 9.63	 3.72	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36341	 1	 3.57	 1.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36342	 1	 6.7	 2.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36343	 1	 14.82	 5.85	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36344	 1	 0.95	 0.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36345	 1	 9.85	 2.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36346	 1	 0.98	 0.23	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36347	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36348	 1	 6.26	 1.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36349	 1	 3.92	 1.79	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36350	 1	 6.09	 2.17	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36351	 1	 5.87	 2.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36352	 1	 1.07	 0.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36353	 1	 5.59	 2.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36354	 1	 1.83	 0.72	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36355	 1	 3.54	 1.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36356	 1	 1.25	 0.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36357	 1	 1.72	 0.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36358	 1	 2.66	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36359	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36360	 1	 12.26	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36361	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36362	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36364	 1	 4.09	 1.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36365	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36366	 1	 25.23	 11.77	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36367	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36368	 1	 8.36	 3.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36369	 1	 4.09	 1.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36370	 1	 11.42	 4.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36371	 1	 4.79	 2.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36372	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36373	 1	 2.32	 0.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36374	 1	 2.46	 1.08	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36375	 1	 7.26	 3.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36376	 1	 4.91	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36377	 1	 5.17	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36378	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36379	 1	 7.37	 3.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36380	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36381	 1	 5.09	 2.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36382	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36383	 1	 14.25	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36384	 1	 6.58	 2.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36385	 1	 6.89	 3.01	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36386	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36387	 1	 7.14	 2.96	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36388	 1	 3.0	 1.17	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36389	 1	 11.37	 4.18	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36390	 1	 1.76	 0.72	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36391	 1	 6.46	 2.52	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36392	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36393	 1	 9.72	 4.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36394	 1	 9.6	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36395	 1	 5.98	 2.38	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36396	 1	 8.76	 4.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36397	 1	 24.83	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36398	 1	 3.95	 1.21	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36399	 1	 7.35	 2.24	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36400	 1	 2.74	 1.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36401	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36402	 1	 43.84	 11.68	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36403	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36404	 1	 3.68	 1.55	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36405	 1	 18.08	 7.57	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36406	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36407	 1	 3.67	 1.85	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36408	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36409	 1	 5.94	 2.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36410	 1	 18.1	 6.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36411	 1	 14.71	 6.24	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36412	 1	 3.31	 1.61	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36413	 1	 4.19	 1.96	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36414	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36415	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36416	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36417	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36418	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36419	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36420	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36421	 1	 10.67	 5.18	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36422	 1	 4.96	 2.56	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36423	 1	 5.98	 2.03	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36424	 1	 53.88	 17.56	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36425	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36426	 1	 12.94	 5.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36427	 1	 10.72	 3.21	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36428	 1	 13.41	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36429	 1	 12.62	 4.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36430	 1	 12.93	 5.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36431	 1	 93.35	 41.54	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36432	 1	 6.57	 2.51	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36433	 1	 18.63	 6.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36434	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36435	 1	 17.43	 3.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36436	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36437	 1	 15.71	 3.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36438	 1	 6.62	 2.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36439	 1	 2.25	 0.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36440	 1	 3.07	 1.41	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36441	 1	 5.16	 2.21	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36442	 1	 10.69	 2.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36443	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36444	 1	 4.41	 1.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36445	 1	 8.01	 3.17	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36446	 1	 5.95	 2.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36447	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36448	 1	 7.69	 3.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36449	 1	 4.5	 1.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36450	 1	 15.27	 4.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36451	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36452	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36453	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36454	 1	 5.65	 2.54	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36455	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36456	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36457	 1	 7.56	 3.21	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36458	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36459	 1	 1.3	 0.48	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36460	 1	 5.37	 2.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36461	 1	 4.16	 2.02	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36462	 1	 12.31	 5.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36463	 1	 1.56	 0.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36464	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36465	 1	 10.58	 3.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36466	 1	 2.96	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36467	 1	 6.82	 2.72	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36468	 1	 5.76	 2.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36469	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36470	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36471	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36472	 1	 5.03	 2.36	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36474	 1	 3.72	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36475	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36476	 1	 12.83	 4.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36479	 1	 16.73	 6.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36482	 1	 4.56	 2.05	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36483	 1	 14.66	 7.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36484	 1	 3.29	 1.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36485	 1	 0.04	 0.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36486	 1	 18.38	 7.99	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36487	 1	 56.87	 26.33	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36488	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36489	 1	 4.4	 2.03	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36490	 1	 5.84	 2.43	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36491	 1	 15.39	 5.56	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36492	 1	 22.79	 8.13	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36493	 1	 16.79	 4.87	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36494	 1	 7.68	 2.73	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36495	 1	 5.21	 2.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36496	 1	 12.07	 3.63	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36497	 1	 3.69	 1.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36498	 1	 4.33	 1.75	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36499	 1	 4.65	 1.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36500	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36501	 1	 3.49	 1.76	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36502	 1	 8.2	 3.95	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36503	 1	 30.1	 10.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36504	 1	 15.61	 5.37	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36505	 1	 10.53	 3.41	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36506	 1	 23.25	 10.19	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36507	 1	 5.67	 2.93	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36508	 1	 10.0	 4.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36509	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36510	 1	 17.17	 5.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36511	 1	 3.05	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36512	 1	 2.83	 1.29	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36513	 1	 4.67	 1.87	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36514	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36515	 1	 5.58	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36516	 1	 16.67	 6.79	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36517	 1	 6.85	 3.21	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36518	 1	 5.17	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36519	 1	 3.33	 1.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36520	 1	 2.68	 1.21	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36521	 1	 15.11	 7.71	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36522	 1	 3.7	 1.72	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36523	 1	 13.13	 5.32	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36524	 1	 18.75	 5.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36525	 1	 3.89	 1.91	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36526	 1	 11.89	 5.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36527	 1	 3.09	 1.53	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36528	 1	 9.34	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36529	 1	 13.77	 5.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36530	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36531	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36532	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36533	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36534	 1	 4.22	 1.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36535	 1	 6.47	 2.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36536	 1	 4.14	 1.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36537	 1	 29.43	 10.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36538	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36539	 1	 12.9	 6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36540	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36541	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36542	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36543	 1	 5.66	 2.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36544	 1	 3.1	 1.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36545	 1	 3.0	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36546	 1	 17.6	 8.7	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36547	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36548	 1	 4.4	 2.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36549	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36550	 1	 3.05	 1.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36551	 1	 5.69	 2.74	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36552	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36553	 1	 4.9	 2.02	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36554	 1	 6.37	 2.23	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36555	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36556	 1	 6.56	 2.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36557	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36558	 1	 4.3	 1.93	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36559	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36560	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36561	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36562	 1	 11.77	 5.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36563	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36564	 1	 8.66	 4.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36565	 1	 5.83	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36566	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36567	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36568	 1	 4.22	 1.89	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36569	 1	 21.09	 7.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36570	 1	 12.03	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36571	 1	 13.85	 5.47	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36572	 1	 11.1	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36573	 1	 5.2	 2.43	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36574	 1	 4.54	 1.71	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36575	 1	 6.33	 2.88	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36576	 1	 6.29	 3.17	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36577	 1	 5.8	 2.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36578	 1	 5.84	 2.72	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36579	 1	 3.89	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36580	 1	 6.31	 2.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36581	 1	 10.67	 3.97	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36582	 1	 11.25	 3.78	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36583	 1	 1.99	 0.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36584	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36585	 1	 4.97	 2.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36586	 1	 2.81	 1.37	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36587	 1	 3.55	 1.45	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36588	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36589	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36590	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36591	 1	 2.87	 1.36	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36592	 1	 1.48	 0.68	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36593	 1	 9.79	 4.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36594	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36595	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36596	 1	 14.39	 5.29	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36597	 1	 7.04	 2.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36598	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36599	 1	 11.15	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36600	 1	 7.06	 2.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36601	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36602	 1	 3.6	 1.49	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36603	 1	 0.28	 1.69	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36604	 1	 0.45	 2.21	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36605	 1	 0.43	 2.15	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36606	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36607	 1	 1.21	 5.36	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36608	 1	 0.45	 2.25	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36609	 1	 0.25	 1.43	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36610	 1	 0.48	 3.01	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36611	 1	 0.39	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36612	 1	 2.54	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36613	 1	 1.66	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36614	 1	 0.22	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36615	 1	 0.52	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36616	 1	 4.98	 15.45	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36617	 1	 1.01	 5.97	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36618	 1	 1.56	 6.97	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36619	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36620	 1	 0.43	 2.05	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36621	 1	 1.1	 6.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36622	 1	 0.27	 1.24	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36623	 1	 5.24	 20.79	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36624	 1	 0.59	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36625	 1	 1.3	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36626	 1	 0.65	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36627	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36628	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36629	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36630	 1	 3.52	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36631	 1	 0.59	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36632	 1	 0.61	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36633	 1	 0.52	 3.01	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36634	 1	 0.29	 1.56	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36635	 1	 2.17	 11.58	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36636	 1	 0.95	 4.94	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36637	 1	 0.35	 0.08	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36638	 1	 0.97	 0.22	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36639	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36640	 1	 0.26	 0.06	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36641	 1	 1.0	 0.23	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36642	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36643	 1	 1.33	 0.31	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36644	 1	 0.51	 0.12	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36645	 1	 0.62	 0.14	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36646	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36647	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36648	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36649	 1	 0.93	 5.93	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36650	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36651	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36652	 1	 0.83	 4.37	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36653	 1	 6.35	 23.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36654	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36655	 1	 0.62	 3.77	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36656	 1	 0.82	 5.32	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36657	 1	 2.77	 13.09	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36658	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36659	 1	 1.05	 6.33	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36660	 1	 1.15	 6.1	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36661	 1	 1.1	 7.12	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36662	 1	 0.47	 2.87	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36663	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36664	 1	 1.13	 6.64	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36665	 1	 4.22	 21.14	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36666	 1	 0.63	 3.53	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36667	 1	 1.86	 9.26	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36668	 1	 4.28	 19.26	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36669	 1	 1.39	 7.85	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36670	 1	 0.63	 3.61	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36671	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36672	 1	 0.8	 3.4	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36673	 1	 0.49	 2.48	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36674	 1	 4.55	 20.48	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36675	 1	 0.63	 3.68	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36676	 1	 0.54	 2.31	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36677	 1	 0.63	 3.4	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36678	 1	 0.69	 3.45	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36679	 1	 0.55	 3.25	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36680	 1	 0.61	 3.8	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36681	 1	 1.01	 5.45	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36682	 1	 1.04	 6.09	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36683	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36684	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36685	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36686	 1	 1.01	 5.62	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36687	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36688	 1	 1.43	 7.83	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36689	 1	 1.58	 8.44	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36690	 1	 1.1	 4.97	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36691	 1	 8.27	 35.21	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36692	 1	 0.63	 4.03	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36693	 1	 0.86	 5.24	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36694	 1	 0.73	 4.34	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36695	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36696	 1	 0.86	 4.97	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36697	 1	 0.23	 0.06	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36698	 1	 0.4	 0.09	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36699	 1	 0.91	 0.21	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36700	 1	 0.17	 0.04	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36701	 1	 0.21	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36702	 1	 0.36	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36703	 1	 0.96	 0.22	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36704	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36705	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36706	 1	 0.6	 3.43	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36707	 1	 0.26	 1.66	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36708	 1	 0.45	 3.08	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36709	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36710	 1	 0.62	 3.71	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36711	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36712	 1	 0.51	 3.12	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36713	 1	 0.84	 4.62	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36714	 1	 0.59	 3.71	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36715	 1	 0.64	 4.02	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36716	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36717	 1	 0.83	 5.08	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36718	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36719	 1	 0.38	 1.94	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36720	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36721	 1	 0.93	 4.33	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36722	 1	 2.22	 9.1	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36723	 1	 0.44	 2.32	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36724	 1	 1.57	 7.16	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36725	 1	 2.18	 9.29	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36726	 1	 1.31	 6.03	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36727	 1	 0.02	 0.13	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36728	 1	 0.48	 2.58	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36729	 1	 0.21	 1.3	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36730	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36731	 1	 0.28	 1.6	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36732	 1	 0.24	 1.4	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36733	 1	 0.38	 2.33	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36734	 1	 2.87	 13.32	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36735	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36736	 1	 0.7	 3.64	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36737	 1	 1.05	 5.28	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36738	 1	 1.17	 7.59	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36739	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36740	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36741	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36742	 1	 1.03	 6.57	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36743	 1	 0.44	 2.81	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36744	 1	 0.49	 2.89	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36745	 1	 0.28	 1.43	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36746	 1	 0.5	 2.58	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36747	 1	 0.81	 4.44	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36748	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36749	 1	 0.63	 3.07	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36750	 1	 0.19	 0.95	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36751	 1	 0.61	 2.56	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36752	 1	 0.6	 3.43	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36753	 1	 0.74	 4.51	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36754	 1	 1.3	 7.96	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36755	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36756	 1	 1.4	 5.86	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36757	 1	 0.38	 2.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36758	 1	 0.69	 3.74	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36759	 1	 0.32	 2.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36760	 1	 0.93	 4.83	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36761	 1	 0.72	 4.3	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36762	 1	 0.83	 4.62	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36763	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36764	 1	 0.91	 4.5	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36765	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36766	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36767	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36768	 1	 1.11	 5.45	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36769	 1	 4.79	 19.79	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36770	 1	 0.24	 1.31	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36771	 1	 0.39	 2.37	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36772	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36773	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36774	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36775	 1	 0.58	 2.66	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36776	 1	 0.5	 3.2	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36777	 1	 0.9	 5.09	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36778	 1	 0.72	 3.77	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36779	 1	 0.38	 2.08	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36780	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36781	 1	 1.97	 9.11	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36782	 1	 0.8	 4.68	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36783	 1	 0.22	 1.3	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36784	 1	 1.4	 8.26	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36785	 1	 1.57	 8.18	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36786	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36787	 1	 0.64	 3.12	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36788	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36789	 1	 0.74	 4.21	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36790	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36791	 1	 1.39	 6.54	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36792	 1	 0.83	 4.84	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36793	 1	 0.65	 4.15	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36794	 1	 1.01	 5.75	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36795	 1	 1.34	 6.89	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36796	 1	 1.06	 5.77	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36797	 1	 0.29	 1.84	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36798	 1	 0.71	 4.19	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36799	 1	 0.38	 2.3	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36800	 1	 4.58	 16.99	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36801	 1	 1.25	 7.65	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36802	 1	 0.89	 4.98	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36803	 1	 0.72	 4.05	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36804	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36805	 1	 0.52	 2.83	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36806	 1	 0.02	 0.16	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36807	 1	 0.95	 5.93	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36808	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36809	 1	 0.63	 4.22	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36810	 1	 0.66	 3.54	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36811	 1	 7.32	 21.63	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36812	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36813	 1	 0.41	 2.2	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36814	 1	 0.56	 3.32	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36815	 1	 0.41	 2.61	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36816	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36817	 1	 0.27	 0.06	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36818	 1	 1.07	 0.25	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36819	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36820	 1	 0.48	 0.11	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36821	 1	 0.61	 0.14	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36822	 1	 0.2	 0.05	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36823	 1	 1.02	 4.4	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36824	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36825	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36826	 1	 0.5	 2.86	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36827	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36828	 1	 0.19	 1.17	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36829	 1	 0.23	 1.57	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36830	 1	 0.6	 3.21	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36831	 1	 1.05	 5.32	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36832	 1	 0.71	 4.34	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36833	 1	 6.77	 28.84	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36834	 1	 0.98	 5.66	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36835	 1	 7.42	 39.44	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36836	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36837	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36838	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36839	 1	 1.09	 5.36	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36840	 1	 1.42	 7.79	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36841	 1	 0.66	 4.23	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36842	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36843	 1	 0.46	 2.64	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36844	 1	 5.8	 25.57	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36845	 1	 2.83	 18.05	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36846	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36847	 1	 0.77	 4.01	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36848	 1	 0.47	 2.66	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36849	 1	 0.96	 5.74	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36850	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36851	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36852	 1	 0.69	 4.2	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36853	 1	 1.23	 7.8	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36854	 1	 1.65	 8.91	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36855	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36856	 1	 0.24	 1.5	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36857	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36858	 1	 0.1	 0.58	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36859	 1	 0.96	 5.52	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36860	 1	 0.34	 2.09	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36861	 1	 0.46	 2.29	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36862	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36863	 1	 1.0	 5.12	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36864	 1	 0.3	 1.71	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36865	 1	 0.92	 4.65	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36866	 1	 0.38	 1.91	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36867	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36868	 1	 0.5	 3.18	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36869	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36870	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36871	 1	 0.77	 3.76	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36872	 1	 0.53	 3.07	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36873	 1	 0.79	 3.94	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36874	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36875	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36876	 1	 5.42	 28.2	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36877	 1	 0.88	 4.41	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36878	 1	 3.81	 12.07	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36879	 1	 0.58	 3.26	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36880	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36881	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36882	 1	 0.49	 2.56	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36883	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36884	 1	 0.84	 4.07	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36885	 1	 1.15	 5.53	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36886	 1	 0.35	 2.02	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36887	 1	 0.26	 1.36	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36888	 1	 0.82	 4.4	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36889	 1	 0.66	 3.96	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36890	 1	 0.26	 1.62	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36891	 1	 1.18	 6.54	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36892	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36893	 1	 0.87	 4.84	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36894	 1	 0.84	 4.81	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36895	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36896	 1	 0.67	 4.01	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36897	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36898	 1	 0.46	 2.48	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36899	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36900	 1	 0.28	 1.5	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36901	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36902	 1	 0.68	 4.1	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36903	 1	 0.88	 5.49	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36904	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36905	 1	 0.92	 5.82	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36906	 1	 0.98	 5.61	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36907	 1	 0.49	 3.05	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36908	 1	 0.65	 3.18	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36909	 1	 0.34	 2.01	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36910	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36911	 1	 0.7	 4.23	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36912	 1	 1.51	 8.36	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36913	 1	 3.83	 19.99	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36914	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36915	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36916	 1	 1.09	 6.65	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36917	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36918	 1	 0.87	 4.97	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36919	 1	 0.61	 3.07	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36920	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36921	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36922	 1	 0.37	 2.04	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36923	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36924	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36925	 1	 0.72	 3.83	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36926	 1	 0.27	 1.37	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36927	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36928	 1	 0.07	 0.43	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36929	 1	 0.27	 1.51	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36930	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36931	 1	 0.85	 5.42	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36932	 1	 0.75	 4.28	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36933	 1	 0.26	 1.52	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36934	 1	 0.15	 0.87	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36935	 1	 0.69	 3.05	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36936	 1	 0.25	 1.55	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36937	 1	 0.76	 4.79	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36938	 1	 0.5	 2.93	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36939	 1	 0.58	 3.54	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36940	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36941	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36942	 1	 0.89	 5.22	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36943	 1	 1.22	 6.36	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36944	 1	 1.15	 6.84	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36945	 1	 0.6	 3.02	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36946	 1	 0.64	 3.54	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36947	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36948	 1	 0.94	 4.19	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36949	 1	 0.38	 2.28	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36950	 1	 0.69	 3.97	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36951	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36952	 1	 0.5	 2.63	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36953	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36954	 1	 0.73	 0.17	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36955	 1	 0.59	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36956	 1	 0.93	 0.22	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36957	 1	 0.5	 0.11	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36958	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36959	 1	 0.5	 2.71	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36960	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36961	 1	 0.96	 4.76	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36962	 1	 1.78	 9.83	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36963	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36964	 1	 0.38	 1.82	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36965	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36966	 1	 4.44	 20.62	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36967	 1	 1.5	 7.67	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36968	 1	 1.96	 9.27	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36969	 1	 1.27	 5.53	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36970	 1	 1.77	 10.83	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36971	 1	 1.37	 7.94	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36972	 1	 1.66	 8.09	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36973	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36974	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36975	 1	 1.29	 6.24	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36976	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36977	 1	 0.72	 3.81	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36978	 1	 0.86	 4.2	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36979	 1	 0.45	 2.26	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36980	 1	 1.4	 8.64	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36981	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36982	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36983	 1	 0.37	 1.83	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36984	 1	 1.32	 8.05	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36985	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36986	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36987	 1	 0.61	 3.84	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36988	 1	 0.62	 3.77	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	36989	 1	 0.32	 1.97	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	36990	 1	 2.57	 13.34	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36991	 1	 0.84	 4.49	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36992	 1	 0.41	 2.7	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	36993	 1	 0.52	 3.1	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36994	 1	 0.53	 3.32	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36995	 1	 3.82	 11.9	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36996	 1	 2.68	 13.16	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36997	 1	 0.98	 4.18	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36998	 1	 0.99	 6.31	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	36999	 1	 0.42	 2.72	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37000	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37001	 1	 1.48	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37002	 1	 0.45	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37003	 1	 0.25	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37004	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37005	 1	 0.54	 2.8	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37006	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37007	 1	 0.98	 6.09	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37008	 1	 5.73	 26.52	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37009	 1	 1.1	 5.22	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37010	 1	 0.8	 4.6	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37011	 1	 0.88	 4.73	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37012	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37013	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37014	 1	 5.45	 26.86	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37015	 1	 0.39	 2.57	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37016	 1	 0.15	 0.97	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37017	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37018	 1	 0.61	 3.92	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37019	 1	 0.55	 3.61	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37020	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37021	 1	 0.5	 2.78	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37022	 1	 0.57	 3.13	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37023	 1	 1.05	 4.98	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37024	 1	 0.63	 4.09	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37025	 1	 2.24	 12.35	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37026	 1	 0.62	 3.81	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37027	 1	 1.35	 8.21	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37028	 1	 4.03	 20.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37029	 1	 0.75	 3.55	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37030	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37031	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37032	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37033	 1	 0.9	 5.65	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37034	 1	 0.72	 4.15	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37035	 1	 2.46	 10.57	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37036	 1	 5.89	 23.9	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37037	 1	 0.56	 3.46	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37038	 1	 0.29	 0.07	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37039	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37040	 1	 0.69	 0.16	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37041	 1	 0.18	 0.04	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37042	 1	 0.34	 0.08	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37043	 1	 0.64	 0.15	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37044	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37045	 1	 0.41	 0.1	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37046	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37047	 1	 0.85	 0.2	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37048	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37049	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37050	 1	 0.47	 2.83	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37051	 1	 1.85	 7.41	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37052	 1	 0.57	 3.27	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37053	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37054	 1	 0.25	 1.55	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37055	 1	 0.43	 2.13	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37056	 1	 1.05	 5.98	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37057	 1	 4.09	 15.87	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37058	 1	 0.51	 2.76	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37059	 1	 0.61	 3.66	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37060	 1	 1.3	 6.08	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37061	 1	 0.48	 2.27	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37062	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37063	 1	 1.23	 5.36	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37064	 1	 3.7	 21.42	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37065	 1	 3.31	 15.05	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37066	 1	 0.87	 5.25	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37067	 1	 1.09	 6.19	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37068	 1	 4.72	 21.23	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37069	 1	 13.45	 76.26	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37070	 1	 0.73	 4.33	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37071	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37072	 1	 1.59	 7.36	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37073	 1	 1.56	 7.46	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37074	 1	 0.62	 3.14	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37075	 1	 0.97	 5.14	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37076	 1	 1.3	 7.84	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37077	 1	 1.18	 6.97	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37078	 1	 6.64	 27.49	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37079	 1	 1.04	 5.75	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37080	 1	 0.88	 5.51	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37081	 1	 1.0	 5.51	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37082	 1	 2.17	 12.64	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37083	 1	 0.59	 3.55	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37084	 1	 0.71	 4.51	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37085	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37086	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37087	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37088	 1	 0.9	 0.21	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37089	 1	 0.61	 3.09	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37090	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37091	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37092	 1	 1.92	 6.69	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37093	 1	 0.8	 4.23	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37094	 1	 1.8	 9.75	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37095	 1	 0.4	 2.31	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37096	 1	 0.35	 1.94	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37097	 1	 0.62	 3.81	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37098	 1	 1.29	 7.37	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37099	 1	 0.6	 3.85	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37100	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37101	 1	 1.27	 6.96	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37102	 1	 0.87	 3.93	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37103	 1	 0.5	 3.06	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37104	 1	 0.5	 2.79	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37105	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37106	 1	 0.5	 3.2	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37107	 1	 0.57	 3.24	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37108	 1	 1.7	 10.61	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37109	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37110	 1	 2.7	 9.73	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37111	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37112	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37113	 1	 1.18	 5.65	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37114	 1	 0.67	 3.95	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37115	 1	 0.75	 4.31	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37116	 1	 1.09	 6.87	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37117	 1	 0.24	 1.4	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37118	 1	 0.51	 2.78	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37119	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37120	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37121	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37122	 1	 0.9	 5.58	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37123	 1	 0.61	 3.98	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37124	 1	 4.24	 24.98	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37125	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37126	 1	 1.05	 5.84	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37127	 1	 0.67	 3.18	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37128	 1	 2.95	 16.61	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37129	 1	 2.62	 12.92	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37130	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37131	 1	 1.11	 5.03	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37132	 1	 0.47	 2.65	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37133	 1	 1.03	 5.06	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37134	 1	 2.53	 13.31	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37135	 1	 0.34	 1.84	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37136	 1	 0.32	 1.98	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37137	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37138	 1	 0.33	 1.85	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37139	 1	 3.58	 17.01	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37140	 1	 1.85	 9.81	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37141	 1	 0.72	 4.37	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37142	 1	 0.94	 4.68	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37143	 1	 0.29	 1.52	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37144	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37145	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37146	 1	 0.52	 2.52	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37147	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37148	 1	 0.32	 1.63	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37149	 1	 1.7	 9.3	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37150	 1	 0.79	 4.25	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37151	 1	 0.48	 2.95	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37152	 1	 0.51	 2.54	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37153	 1	 0.34	 2.04	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37154	 1	 1.09	 6.78	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37155	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37156	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37157	 1	 1.25	 6.56	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37158	 1	 8.15	 30.61	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37159	 1	 0.5	 2.81	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37160	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37161	 1	 0.99	 4.84	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37162	 1	 2.3	 10.54	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37163	 1	 0.63	 3.37	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37164	 1	 0.56	 3.2	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37165	 1	 0.57	 3.34	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37166	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37167	 1	 1.02	 6.28	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37168	 1	 0.69	 3.56	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37169	 1	 0.59	 3.63	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37170	 1	 0.62	 3.94	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37171	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37172	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37173	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37174	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37175	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37176	 1	 0.72	 4.54	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37177	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37178	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37179	 1	 0.44	 2.39	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37180	 1	 0.48	 2.43	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37181	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37182	 1	 0.52	 2.77	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37183	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37184	 1	 0.61	 3.25	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37185	 1	 1.2	 6.43	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37186	 1	 0.96	 6.17	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37187	 1	 0.47	 2.79	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37188	 1	 0.98	 5.67	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37189	 1	 1.0	 5.21	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37190	 1	 0.74	 4.45	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37191	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37192	 1	 0.58	 2.98	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37193	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37194	 1	 0.76	 3.93	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37195	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37196	 1	 0.83	 4.68	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37197	 1	 1.14	 5.52	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37198	 1	 0.52	 3.26	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37199	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37200	 1	 0.88	 4.63	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37201	 1	 0.62	 4.06	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37202	 1	 5.07	 27.75	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37203	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37204	 1	 0.95	 5.42	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37205	 1	 0.66	 4.05	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37206	 1	 8.71	 36.29	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37207	 1	 1.1	 6.57	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37208	 1	 0.48	 2.74	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37209	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37210	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37211	 1	 0.68	 3.66	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37212	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37213	 1	 0.86	 5.2	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37214	 1	 0.88	 5.33	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37215	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37216	 1	 1.6	 8.73	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37217	 1	 1.25	 6.86	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37218	 1	 1.03	 5.67	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37219	 1	 1.17	 7.2	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37220	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37221	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37222	 1	 0.88	 4.67	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37223	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37224	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37225	 1	 0.68	 4.09	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37226	 1	 0.59	 3.64	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37227	 1	 0.71	 4.23	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37228	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37229	 1	 0.9	 5.73	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37230	 1	 0.32	 2.02	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37231	 1	 0.78	 4.69	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37232	 1	 0.47	 2.46	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37233	 1	 1.12	 6.51	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37234	 1	 0.63	 4.07	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37235	 1	 0.66	 3.41	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37236	 1	 0.52	 3.14	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37237	 1	 0.79	 4.46	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37238	 1	 0.65	 3.56	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37239	 1	 0.55	 2.8	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37240	 1	 0.36	 1.84	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37241	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37242	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37243	 1	 0.41	 2.41	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37244	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37245	 1	 0.25	 1.47	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37246	 1	 0.42	 2.13	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37247	 1	 1.38	 7.07	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37248	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37249	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37250	 1	 1.12	 6.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37251	 1	 0.97	 5.92	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37252	 1	 0.71	 4.49	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37253	 1	 0.74	 4.36	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37254	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37255	 1	 0.78	 4.18	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37256	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37257	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37258	 1	 1.18	 7.41	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37259	 1	 1.1	 7.17	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37260	 1	 0.69	 4.07	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37261	 1	 0.45	 2.75	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37262	 1	 0.87	 4.7	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37263	 1	 0.81	 5.18	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37264	 1	 0.83	 4.61	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37265	 1	 0.47	 3.22	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37266	 1	 0.49	 3.2	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37267	 1	 0.68	 4.24	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37268	 1	 0.97	 6.17	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37269	 1	 0.56	 3.29	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37270	 1	 1.55	 8.69	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37271	 1	 0.58	 3.07	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37272	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37273	 1	 0.58	 3.26	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37274	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37275	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37276	 1	 4.43	 17.26	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37277	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37278	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37279	 1	 3.02	 13.05	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37280	 1	 0.3	 1.71	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37281	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37282	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37283	 1	 1.44	 8.71	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37284	 1	 1.61	 7.24	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37285	 1	 0.48	 2.74	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37286	 1	 1.72	 9.05	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37287	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37288	 1	 0.75	 3.75	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37289	 1	 0.72	 4.25	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37290	 1	 1.87	 8.74	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37291	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37292	 1	 0.41	 2.33	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37293	 1	 0.55	 3.35	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37294	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37295	 1	 0.58	 3.42	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37296	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37297	 1	 0.62	 2.85	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37298	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37299	 1	 0.65	 3.05	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37300	 1	 0.35	 1.95	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37301	 1	 1.55	 7.86	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37302	 1	 0.38	 2.04	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37303	 1	 0.98	 4.81	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37304	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37305	 1	 0.23	 1.46	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37306	 1	 3.66	 15.53	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37307	 1	 4.33	 16.02	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37308	 1	 1.6	 7.74	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37309	 1	 0.6	 3.27	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37310	 1	 0.6	 3.83	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37311	 1	 0.71	 3.85	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37312	 1	 0.47	 2.8	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37313	 1	 1.02	 5.05	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37314	 1	 1.37	 6.92	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37315	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37316	 1	 0.62	 3.76	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37317	 1	 1.11	 5.1	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37318	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37319	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37320	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37321	 1	 0.92	 5.33	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37322	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37323	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37324	 1	 0.47	 2.66	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37325	 1	 0.65	 3.32	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37326	 1	 3.89	 16.34	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37327	 1	 0.8	 3.78	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37328	 1	 0.59	 3.7	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37329	 1	 0.91	 4.6	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37330	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37331	 1	 0.61	 3.72	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37332	 1	 0.53	 3.09	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37333	 1	 0.83	 4.81	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37334	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37335	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37336	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37337	 1	 0.6	 3.22	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37338	 1	 0.38	 0.09	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37339	 1	 0.46	 0.1	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37340	 1	 0.84	 0.2	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37341	 1	 0.58	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37342	 1	 0.67	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37343	 1	 0.24	 0.06	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37344	 1	 0.5	 0.11	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37345	 1	 0.81	 0.19	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37346	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37347	 1	 1.13	 0.26	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37348	 1	 0.97	 0.22	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37349	 1	 0.96	 0.22	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37350	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37351	 1	 0.29	 1.63	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37352	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37353	 1	 0.34	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37354	 1	 0.87	 4.27	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37355	 1	 0.41	 0.09	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37356	 1	 1.47	 0.33	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37357	 1	 1.2	 6.13	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37358	 1	 0.67	 0.16	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37359	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37360	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37361	 1	 2.73	 0.63	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37362	 1	 0.71	 0.17	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37363	 1	 0.61	 3.57	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37364	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37365	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37366	 1	 0.35	 1.93	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37367	 1	 1.27	 6.86	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37368	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37369	 1	 0.24	 1.53	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37370	 1	 0.26	 1.6	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37371	 1	 0.45	 2.69	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37372	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37373	 1	 0.83	 0.19	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37374	 1	 0.24	 0.06	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37375	 1	 0.26	 0.06	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37376	 1	 1.1	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37377	 1	 0.45	 0.1	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37378	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37379	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37380	 1	 0.81	 0.19	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37381	 1	 0.28	 0.07	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37382	 1	 0.68	 0.16	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37383	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37384	 1	 0.2	 0.05	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37385	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37386	 1	 1.14	 6.14	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37387	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37388	 1	 0.54	 2.84	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37389	 1	 0.34	 2.08	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37390	 1	 0.37	 2.07	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37391	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37392	 1	 1.38	 4.68	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37393	 1	 0.89	 5.7	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37394	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37395	 1	 0.59	 2.65	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37396	 1	 0.59	 3.29	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37397	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37398	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37399	 1	 2.15	 10.11	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37400	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37401	 1	 4.88	 17.25	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37402	 1	 0.93	 4.59	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37403	 1	 0.7	 3.58	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37404	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37405	 1	 0.3	 1.77	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37406	 1	 0.05	 0.25	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37407	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37408	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37409	 1	 1.49	 8.51	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37410	 1	 1.25	 4.14	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37411	 1	 0.3	 2.08	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37412	 1	 2.29	 11.61	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37413	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37414	 1	 0.72	 4.45	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37415	 1	 1.25	 6.56	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37416	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37417	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37418	 1	 1.17	 5.3	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37419	 1	 1.18	 7.06	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37420	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37421	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37422	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37423	 1	 0.48	 2.87	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37424	 1	 0.41	 2.45	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37425	 1	 0.16	 0.86	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37426	 1	 1.05	 5.34	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37427	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37428	 1	 0.69	 3.6	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37429	 1	 0.7	 4.29	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37430	 1	 0.87	 4.72	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37431	 1	 0.39	 2.45	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37432	 1	 1.3	 6.74	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37433	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37434	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37435	 1	 0.51	 2.84	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37436	 1	 0.6	 3.82	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37437	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37438	 1	 1.04	 4.63	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37439	 1	 0.58	 3.59	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37440	 1	 0.68	 3.85	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37441	 1	 3.76	 11.34	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37442	 1	 4.31	 18.82	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37443	 1	 0.62	 3.86	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37444	 1	 4.7	 22.55	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37445	 1	 1.18	 7.42	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37446	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37447	 1	 0.46	 2.72	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37448	 1	 1.34	 7.77	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37449	 1	 0.95	 5.42	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37450	 1	 0.25	 1.38	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37451	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37452	 1	 0.51	 3.07	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37453	 1	 0.29	 1.4	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37454	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37455	 1	 0.4	 2.09	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37456	 1	 0.67	 3.02	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37457	 1	 0.25	 1.21	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37458	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37459	 1	 0.29	 1.51	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37460	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37461	 1	 1.61	 11.11	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37462	 1	 0.73	 4.42	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37463	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37464	 1	 1.0	 6.38	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37465	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37466	 1	 0.61	 3.1	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37467	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37468	 1	 0.21	 1.1	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37469	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37470	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37471	 1	 2.46	 11.8	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37472	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37473	 1	 0.29	 1.65	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37474	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37475	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37476	 1	 0.44	 2.54	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37477	 1	 0.81	 4.17	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37478	 1	 0.76	 4.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37479	 1	 4.87	 26.51	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37480	 1	 0.49	 3.04	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37481	 1	 0.0	 0.01	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37482	 1	 0.65	 3.82	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37483	 1	 0.66	 3.39	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37484	 1	 0.85	 5.39	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37485	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37486	 1	 0.76	 4.95	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37487	 1	 2.83	 13.39	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37488	 1	 0.77	 4.4	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37489	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37490	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37491	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37492	 1	 0.42	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37493	 1	 0.47	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37494	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37495	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37496	 1	 3.83	 17.86	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37497	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37498	 1	 0.83	 4.68	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37499	 1	 2.01	 9.04	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37500	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37501	 1	 1.14	 7.39	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37502	 1	 0.42	 2.72	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37503	 1	 0.38	 1.88	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37504	 1	 0.32	 1.67	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37505	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37506	 1	 0.38	 1.88	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37507	 1	 0.2	 1.05	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37508	 1	 2.37	 13.6	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37509	 1	 1.36	 8.03	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37510	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37511	 1	 0.79	 4.44	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37512	 1	 0.67	 4.43	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37513	 1	 0.72	 4.25	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37514	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37515	 1	 0.3	 1.56	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37516	 1	 0.61	 3.03	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37517	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37518	 1	 3.76	 14.89	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37519	 1	 4.0	 19.14	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37520	 1	 0.87	 4.35	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37521	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37522	 1	 1.34	 7.41	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37523	 1	 1.41	 5.29	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37524	 1	 1.05	 4.8	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37525	 1	 0.33	 2.15	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37526	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37527	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37528	 1	 0.59	 4.01	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37529	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37530	 1	 0.4	 2.26	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37531	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37532	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37533	 1	 0.24	 1.65	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37534	 1	 0.35	 1.86	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37535	 1	 2.77	 16.35	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37536	 1	 0.58	 3.13	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37537	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37538	 1	 1.08	 6.92	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37539	 1	 0.45	 2.61	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37540	 1	 0.62	 4.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37541	 1	 0.65	 3.84	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37542	 1	 0.94	 5.15	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37543	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37544	 1	 0.33	 1.74	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37545	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37546	 1	 0.53	 2.56	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37547	 1	 0.77	 4.57	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37548	 1	 0.48	 3.22	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37549	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37550	 1	 0.41	 2.59	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37551	 1	 0.45	 0.1	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37552	 1	 0.36	 0.08	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37553	 1	 5.11	 21.35	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37554	 1	 0.45	 2.87	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37555	 1	 1.62	 9.32	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37556	 1	 0.52	 0.12	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37557	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37558	 1	 1.43	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37559	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37560	 1	 0.43	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37561	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37562	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37563	 1	 1.25	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37564	 1	 0.84	 5.46	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37565	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37566	 1	 0.76	 0.18	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37567	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37568	 1	 0.7	 0.16	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37569	 1	 0.67	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37570	 1	 0.34	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37571	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37572	 1	 0.37	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37573	 1	 0.32	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37574	 1	 0.97	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37575	 1	 0.99	 0.24	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37576	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37577	 1	 0.67	 4.02	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37578	 1	 0.78	 4.86	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37579	 1	 0.28	 0.07	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37580	 1	 0.85	 0.2	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37581	 1	 0.59	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37582	 1	 0.55	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37583	 1	 3.14	 17.67	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37584	 1	 2.36	 11.54	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37585	 1	 1.13	 5.24	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37586	 1	 0.87	 0.19	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37587	 1	 0.81	 4.44	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37588	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37589	 1	 1.7	 7.98	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37590	 1	 1.02	 5.66	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37591	 1	 1.52	 8.09	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37592	 1	 4.85	 14.52	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37593	 1	 0.83	 4.66	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37594	 1	 1.08	 5.8	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37595	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37596	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37597	 1	 0.52	 2.76	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37598	 1	 1.29	 4.56	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37599	 1	 0.36	 1.93	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37600	 1	 0.47	 2.79	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37601	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37602	 1	 0.65	 3.72	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37603	 1	 0.43	 0.1	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37604	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37605	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37606	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37607	 1	 0.69	 3.28	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37608	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37609	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37610	 1	 0.31	 1.89	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37611	 1	 1.13	 5.07	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37612	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37613	 1	 2.74	 13.53	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37614	 1	 0.63	 3.82	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37615	 1	 0.61	 2.92	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37616	 1	 0.58	 3.3	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37617	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37618	 1	 0.48	 2.92	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37619	 1	 0.18	 1.07	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37620	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37621	 1	 1.85	 8.62	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37622	 1	 0.44	 2.11	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37623	 1	 0.52	 2.83	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37624	 1	 0.49	 2.95	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37625	 1	 0.54	 2.76	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37626	 1	 0.87	 4.52	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37627	 1	 0.54	 2.82	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37628	 1	 0.78	 4.43	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37629	 1	 1.25	 6.15	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37630	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37631	 1	 0.88	 4.37	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37632	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37633	 1	 0.52	 2.91	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37634	 1	 0.38	 2.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37635	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37636	 1	 1.38	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37637	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37638	 1	 1.41	 7.94	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37639	 1	 2.45	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37640	 1	 0.5	 2.73	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37641	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37642	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37643	 1	 1.05	 5.81	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37644	 1	 0.4	 2.4	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37645	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37646	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37647	 1	 3.54	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37648	 1	 3.97	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37649	 1	 0.44	 2.97	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37650	 1	 1.81	 10.17	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37651	 1	 1.97	 8.41	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37652	 1	 0.27	 1.42	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37653	 1	 0.4	 2.72	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37654	 1	 2.48	 12.77	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37655	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37656	 1	 0.05	 0.28	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37657	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37658	 1	 0.53	 2.83	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37659	 1	 1.43	 8.28	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37660	 1	 0.86	 5.15	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37661	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37662	 1	 0.73	 4.34	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37663	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37664	 1	 0.54	 2.71	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37665	 1	 2.34	 12.05	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37666	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37667	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37668	 1	 0.72	 4.3	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37669	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37670	 1	 1.22	 6.48	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37671	 1	 0.88	 4.67	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37672	 1	 0.97	 4.69	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37673	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37674	 1	 0.79	 4.73	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37675	 1	 1.84	 9.59	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37676	 1	 0.73	 3.85	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37677	 1	 4.91	 15.88	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37678	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37679	 1	 1.07	 4.55	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37680	 1	 6.22	 28.89	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37681	 1	 1.44	 0.35	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37682	 1	 0.37	 0.09	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37683	 1	 0.96	 5.89	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37684	 1	 1.0	 5.85	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37685	 1	 3.42	 15.77	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37686	 1	 0.86	 5.23	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37687	 1	 0.96	 5.05	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37688	 1	 0.45	 2.63	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37689	 1	 5.14	 23.03	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37690	 1	 0.33	 1.85	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37691	 1	 0.92	 3.77	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37692	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37693	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37694	 1	 0.63	 2.96	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37695	 1	 0.41	 2.14	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37696	 1	 2.77	 15.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37697	 1	 0.38	 2.06	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37698	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37699	 1	 0.87	 4.56	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37700	 1	 0.55	 0.13	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37701	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37702	 1	 1.24	 0.29	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37703	 1	 0.98	 5.02	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37704	 1	 1.19	 7.1	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37705	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37706	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37707	 1	 0.27	 1.42	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37708	 1	 0.47	 2.45	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37709	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37710	 1	 2.81	 10.86	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37711	 1	 4.8	 23.39	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37712	 1	 0.42	 2.46	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37713	 1	 0.78	 3.9	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37714	 1	 0.65	 3.19	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37715	 1	 0.57	 3.17	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37716	 1	 0.64	 2.68	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37717	 1	 0.59	 3.29	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37718	 1	 8.82	 3.85	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37719	 1	 4.15	 1.93	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37720	 1	 1.54	 0.8	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37721	 1	 5.28	 2.96	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37722	 1	 4.84	 3.15	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37723	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37724	 1	 3.04	 1.96	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37725	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37726	 1	 4.14	 2.07	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37727	 1	 13.65	 6.62	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37728	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37729	 1	 2.96	 1.52	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37730	 1	 5.02	 2.39	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37731	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37732	 1	 5.43	 2.58	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37733	 1	 3.91	 2.3	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37734	 1	 7.4	 1.61	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37735	 1	 5.91	 1.31	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37736	 1	 3.81	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37737	 1	 3.68	 2.3	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37738	 1	 2.23	 1.27	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37739	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37740	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37741	 1	 3.63	 2.22	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37742	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37743	 1	 5.53	 3.24	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37744	 1	 1.97	 1.02	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37745	 1	 3.91	 2.48	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37746	 1	 7.54	 3.4	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37747	 1	 3.24	 2.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37748	 1	 4.85	 2.74	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37749	 1	 13.14	 6.31	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37750	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37751	 1	 5.97	 3.74	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37752	 1	 2.45	 1.3	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37753	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37754	 1	 5.02	 1.8	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37755	 1	 3.57	 1.82	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37756	 1	 2.51	 1.47	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37757	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37758	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37759	 1	 4.79	 2.86	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37760	 1	 5.39	 3.1	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37761	 1	 7.88	 5.32	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37762	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37763	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37764	 1	 2.29	 1.4	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37765	 1	 5.31	 2.58	 0.0	 0.0	 19	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37766	 1	 2.53	 1.31	 0.0	 0.0	 19	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37767	 1	 6.28	 3.8	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37768	 1	 5.68	 3.05	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37769	 1	 5.03	 2.7	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37770	 1	 3.56	 2.08	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37771	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37772	 1	 7.58	 4.24	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37773	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37774	 1	 7.0	 3.14	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37775	 1	 2.68	 1.55	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37776	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37777	 1	 8.8	 4.86	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37778	 1	 10.69	 5.53	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37779	 1	 7.22	 3.64	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37780	 1	 9.33	 5.45	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37781	 1	 3.21	 1.61	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37782	 1	 6.12	 2.7	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37783	 1	 10.82	 4.84	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37784	 1	 2.46	 0.94	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37785	 1	 6.65	 3.79	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37786	 1	 9.49	 4.95	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37787	 1	 9.73	 3.72	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37788	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37789	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37790	 1	 7.19	 3.18	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37791	 1	 2.94	 1.48	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37792	 1	 40.47	 20.4	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37793	 1	 39.83	 26.58	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37794	 1	 5.94	 3.09	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37795	 1	 6.47	 3.63	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37796	 1	 4.25	 2.76	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37797	 1	 5.41	 3.34	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37798	 1	 4.87	 2.73	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37799	 1	 2.85	 1.63	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37800	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37801	 1	 4.82	 2.49	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37802	 1	 5.89	 2.85	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37803	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37804	 1	 3.57	 1.67	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37805	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37806	 1	 1.14	 0.62	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37807	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37808	 1	 4.01	 2.02	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37809	 1	 1.93	 0.89	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37810	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37811	 1	 6.07	 3.09	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37812	 1	 6.95	 3.94	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37813	 1	 4.86	 3.14	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37814	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37815	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37816	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37817	 1	 4.94	 2.29	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37818	 1	 3.62	 1.82	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37819	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37820	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37821	 1	 4.78	 2.19	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37822	 1	 6.71	 3.37	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37823	 1	 15.62	 6.82	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37824	 1	 3.34	 1.87	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37825	 1	 7.22	 3.95	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37826	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37827	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37828	 1	 2.34	 1.11	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37829	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37830	 1	 2.9	 1.75	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37831	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37832	 1	 6.91	 3.71	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37833	 1	 5.48	 3.53	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37834	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37835	 1	 6.73	 2.54	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37836	 1	 3.46	 1.61	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37837	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37838	 1	 4.38	 2.25	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37839	 1	 11.19	 7.19	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37840	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37841	 1	 3.74	 2.33	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37842	 1	 4.66	 2.83	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37843	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37844	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37845	 1	 2.49	 1.5	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37846	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37847	 1	 2.52	 1.17	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37848	 1	 4.5	 2.66	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37849	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37850	 1	 3.93	 1.87	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37851	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37852	 1	 2.33	 1.25	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37853	 1	 10.16	 5.36	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37854	 1	 7.27	 3.85	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37855	 1	 19.32	 7.21	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37856	 1	 11.19	 4.71	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37857	 1	 7.58	 3.55	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37858	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37859	 1	 8.4	 4.28	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37860	 1	 3.85	 0.87	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37861	 1	 6.14	 1.41	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37862	 1	 8.48	 1.94	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37863	 1	 28.06	 6.49	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37864	 1	 6.44	 2.98	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37865	 1	 6.65	 3.14	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37866	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37867	 1	 4.63	 1.83	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37868	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37869	 1	 2.55	 1.46	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37870	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37871	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37872	 1	 5.34	 2.59	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37873	 1	 2.71	 1.35	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37874	 1	 2.37	 1.33	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37875	 1	 2.83	 1.54	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37876	 1	 4.64	 2.72	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37877	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37878	 1	 4.88	 2.72	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37879	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37880	 1	 2.3	 1.05	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37881	 1	 9.63	 5.24	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37882	 1	 6.07	 3.51	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37883	 1	 2.99	 1.46	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37884	 1	 1.34	 0.64	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37885	 1	 3.03	 1.56	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37886	 1	 5.24	 2.49	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37887	 1	 2.05	 1.08	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37888	 1	 1.9	 0.98	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37889	 1	 2.68	 1.35	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37890	 1	 6.19	 3.1	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37891	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37892	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37893	 1	 5.18	 3.01	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37894	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37895	 1	 3.74	 1.8	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37896	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	37897	 1	 11.45	 6.17	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37898	 1	 6.96	 3.6	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37899	 1	 3.12	 1.51	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37900	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37901	 1	 2.56	 1.43	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37902	 1	 5.79	 2.51	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37903	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37904	 1	 5.01	 2.7	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37905	 1	 4.19	 2.33	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37906	 1	 6.41	 3.77	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37907	 1	 3.98	 2.07	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37908	 1	 2.24	 1.17	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37909	 1	 2.11	 1.32	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37910	 1	 2.42	 1.46	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37911	 1	 2.57	 1.32	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37912	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37913	 1	 4.32	 2.43	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37914	 1	 2.17	 1.26	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37915	 1	 3.22	 1.86	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37916	 1	 2.72	 1.63	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37917	 1	 4.46	 2.7	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37918	 1	 4.2	 2.15	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37919	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37920	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37921	 1	 1.49	 0.69	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37922	 1	 1.44	 0.74	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37923	 1	 4.56	 2.26	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37924	 1	 5.23	 2.43	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37925	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37926	 1	 2.5	 1.44	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37927	 1	 4.02	 2.64	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37928	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37929	 1	 2.13	 1.34	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37930	 1	 5.77	 1.89	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37931	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37932	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37933	 1	 1.86	 0.92	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37934	 1	 3.37	 1.81	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37935	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37936	 1	 10.86	 6.64	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37937	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37938	 1	 1.38	 0.8	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37939	 1	 5.58	 2.77	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37940	 1	 3.06	 1.68	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37941	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37942	 1	 2.91	 1.6	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37943	 1	 2.16	 1.1	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37944	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37945	 1	 5.43	 2.51	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37946	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37947	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37948	 1	 5.42	 3.03	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37949	 1	 11.53	 5.72	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37950	 1	 2.77	 1.39	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37951	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37952	 1	 3.15	 1.95	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37953	 1	 7.8	 3.91	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37954	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37955	 1	 7.37	 3.63	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37956	 1	 9.04	 4.87	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37957	 1	 1.18	 0.68	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37958	 1	 2.43	 1.49	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37959	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37960	 1	 3.27	 1.63	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37961	 1	 2.71	 1.56	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37962	 1	 4.18	 2.53	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37963	 1	 2.45	 1.27	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37964	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37965	 1	 3.41	 2.07	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37966	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37967	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37968	 1	 2.09	 1.17	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37969	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37970	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	37971	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37972	 1	 9.15	 3.74	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37973	 1	 4.5	 2.36	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37974	 1	 1.68	 0.84	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37975	 1	 3.33	 1.56	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37976	 1	 6.54	 2.82	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37977	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37978	 1	 2.42	 1.47	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37979	 1	 1.65	 0.75	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37980	 1	 5.78	 3.22	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37981	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37982	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37983	 1	 3.76	 2.16	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37984	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37985	 1	 6.02	 3.26	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37986	 1	 4.95	 2.73	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	37987	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37988	 1	 12.53	 4.72	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37989	 1	 2.86	 1.32	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37990	 1	 10.09	 5.1	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37991	 1	 7.28	 3.49	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37992	 1	 6.93	 4.23	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37993	 1	 3.88	 2.16	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37994	 1	 4.87	 2.71	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37995	 1	 5.7	 3.09	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37996	 1	 5.35	 2.67	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37997	 1	 4.31	 2.24	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37998	 1	 5.44	 3.02	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	37999	 1	 13.44	 7.95	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38000	 1	 9.37	 5.38	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38001	 1	 8.52	 4.47	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38002	 1	 4.51	 2.62	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38003	 1	 5.17	 2.92	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38004	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38005	 1	 2.9	 1.6	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38006	 1	 2.68	 1.56	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38007	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38008	 1	 2.06	 1.22	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38009	 1	 3.09	 1.49	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38010	 1	 5.4	 3.38	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38011	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38012	 1	 4.6	 3.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38013	 1	 4.58	 2.2	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38014	 1	 1.87	 1.08	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38015	 1	 6.22	 2.44	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38016	 1	 76.76	 32.81	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38017	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38018	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38019	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38020	 1	 6.99	 3.56	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38021	 1	 11.25	 6.28	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38022	 1	 8.8	 4.82	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38023	 1	 2.54	 1.39	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38024	 1	 5.72	 3.24	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38025	 1	 2.73	 1.4	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38026	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38027	 1	 27.22	 11.67	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38028	 1	 4.84	 2.86	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38029	 1	 3.54	 1.66	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38030	 1	 3.42	 1.91	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38031	 1	 4.22	 2.5	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38032	 1	 5.69	 2.45	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38033	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38034	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38035	 1	 18.17	 7.83	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38036	 1	 7.25	 3.36	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38037	 1	 7.04	 3.52	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38038	 1	 3.25	 2.05	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38039	 1	 10.59	 4.35	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38040	 1	 0.46	 0.31	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38041	 1	 9.65	 4.91	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38042	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38043	 1	 5.44	 2.36	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38044	 1	 3.55	 2.02	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38045	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38046	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38047	 1	 4.08	 1.98	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38048	 1	 17.17	 7.08	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38049	 1	 3.09	 1.46	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38050	 1	 5.24	 2.8	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38051	 1	 1.66	 0.76	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38052	 1	 6.68	 3.63	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38053	 1	 6.14	 3.27	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38054	 1	 4.83	 2.28	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38055	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38056	 1	 6.25	 3.02	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38057	 1	 12.99	 6.29	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38058	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38059	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38060	 1	 18.44	 8.88	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38061	 1	 2.37	 1.08	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38062	 1	 1.77	 0.97	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38063	 1	 4.7	 2.62	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38064	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38065	 1	 38.02	 16.54	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38066	 1	 2.67	 1.31	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38067	 1	 6.1	 3.02	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38068	 1	 3.79	 2.08	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38069	 1	 2.74	 1.31	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38070	 1	 5.06	 2.34	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38071	 1	 11.42	 4.87	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38072	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38073	 1	 4.54	 2.09	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38074	 1	 6.49	 3.06	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38075	 1	 2.23	 1.16	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38076	 1	 10.79	 5.3	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38077	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38078	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38079	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38080	 1	 13.99	 7.71	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38081	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38082	 1	 3.42	 1.54	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38083	 1	 6.22	 2.79	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38084	 1	 5.86	 2.68	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38085	 1	 3.28	 1.88	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38086	 1	 9.1	 4.01	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38087	 1	 3.06	 1.63	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38088	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38089	 1	 4.71	 1.99	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38090	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38091	 1	 4.19	 2.48	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38092	 1	 3.87	 2.27	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38093	 1	 3.47	 2.04	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38094	 1	 4.44	 2.79	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38095	 1	 6.49	 3.69	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38096	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38097	 1	 3.52	 1.88	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38098	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38099	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38100	 1	 2.57	 1.29	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38101	 1	 3.24	 1.82	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38102	 1	 8.73	 4.29	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38103	 1	 5.29	 2.88	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38104	 1	 15.04	 5.09	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38105	 1	 14.75	 7.3	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38106	 1	 3.26	 1.56	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38107	 1	 0.82	 0.38	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38108	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38109	 1	 7.68	 3.92	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38110	 1	 10.09	 5.11	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38111	 1	 6.83	 3.82	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38112	 1	 4.47	 2.39	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38113	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38114	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38115	 1	 7.64	 4.02	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38116	 1	 7.3	 1.62	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38117	 1	 6.73	 1.46	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38118	 1	 5.48	 2.29	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38119	 1	 9.83	 2.2	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38120	 1	 8.88	 1.97	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38121	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38122	 1	 2.0	 1.02	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38123	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38124	 1	 8.12	 4.82	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38125	 1	 7.35	 4.31	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38126	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38127	 1	 3.23	 1.6	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38128	 1	 3.83	 2.5	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38129	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38130	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38131	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38132	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38133	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38134	 1	 21.28	 11.87	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38135	 1	 6.55	 3.57	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38136	 1	 1.91	 0.94	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38137	 1	 4.85	 2.24	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38138	 1	 5.23	 3.08	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38139	 1	 2.01	 1.01	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38140	 1	 3.64	 2.12	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38141	 1	 5.65	 2.77	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38142	 1	 3.5	 1.71	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38143	 1	 4.84	 3.09	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38144	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38145	 1	 2.21	 1.14	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38146	 1	 5.48	 2.89	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38147	 1	 3.96	 2.16	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38148	 1	 14.38	 8.14	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38149	 1	 20.49	 10.53	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38150	 1	 7.3	 4.38	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38151	 1	 7.22	 3.73	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38152	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38153	 1	 1.65	 0.83	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38154	 1	 5.78	 3.24	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38155	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38156	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38157	 1	 3.73	 1.68	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38158	 1	 4.67	 2.24	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38159	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38160	 1	 4.03	 2.16	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38161	 1	 3.81	 0.88	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38162	 1	 8.99	 4.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38163	 1	 12.88	 5.98	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38164	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38165	 1	 3.52	 1.92	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38166	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38167	 1	 5.86	 3.39	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38168	 1	 4.74	 2.31	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38169	 1	 6.43	 3.17	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38170	 1	 6.51	 3.28	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38171	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38172	 1	 3.14	 1.56	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38173	 1	 5.41	 2.68	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38174	 1	 18.43	 7.5	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38175	 1	 3.99	 2.09	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38176	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38177	 1	 2.16	 1.11	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38178	 1	 2.43	 1.49	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38179	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38180	 1	 5.02	 2.52	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38181	 1	 2.12	 1.02	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38182	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38183	 1	 6.89	 3.15	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38184	 1	 4.77	 2.16	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38185	 1	 6.36	 3.48	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38186	 1	 3.4	 1.98	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38187	 1	 4.64	 2.19	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38188	 1	 5.21	 2.2	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38189	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38190	 1	 4.08	 2.25	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38191	 1	 5.5	 2.71	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38192	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38193	 1	 7.18	 3.6	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38194	 1	 2.77	 1.36	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38195	 1	 8.79	 4.45	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38196	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38197	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38198	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38199	 1	 4.82	 2.71	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38200	 1	 4.06	 1.92	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38201	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38202	 1	 6.34	 3.63	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38203	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38204	 1	 2.51	 1.49	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38205	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38206	 1	 9.32	 4.61	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38207	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38208	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38209	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38210	 1	 4.85	 1.1	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38211	 1	 3.11	 1.45	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38212	 1	 12.3	 2.74	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38213	 1	 6.03	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38214	 1	 8.14	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38215	 1	 10.52	 2.35	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38216	 1	 4.13	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38217	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38218	 1	 7.3	 4.35	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38219	 1	 15.77	 8.29	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38220	 1	 19.9	 13.53	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38221	 1	 6.08	 1.34	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38222	 1	 5.61	 1.25	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38223	 1	 5.09	 1.11	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38224	 1	 4.66	 1.03	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38225	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38226	 1	 10.4	 2.29	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38227	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38228	 1	 3.69	 0.81	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38229	 1	 4.26	 1.77	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38230	 1	 13.4	 6.65	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38231	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38232	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38233	 1	 3.98	 1.89	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38234	 1	 5.98	 2.97	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38235	 1	 11.73	 5.85	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38236	 1	 4.95	 2.74	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38237	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38238	 1	 5.31	 2.73	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38239	 1	 4.45	 2.45	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38240	 1	 1.68	 0.99	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38241	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38242	 1	 4.13	 2.37	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38243	 1	 4.99	 2.36	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38244	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38245	 1	 6.77	 3.53	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38246	 1	 6.56	 3.87	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38247	 1	 4.87	 2.42	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38248	 1	 3.89	 2.03	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38249	 1	 3.68	 1.85	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38250	 1	 6.81	 3.33	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38251	 1	 1.78	 0.91	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38252	 1	 3.11	 1.52	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38253	 1	 5.66	 2.55	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38254	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38255	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38256	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38257	 1	 4.08	 2.21	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38258	 1	 8.96	 4.33	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38259	 1	 1.78	 0.87	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38260	 1	 4.17	 2.32	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38261	 1	 5.25	 2.92	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38262	 1	 5.69	 2.11	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38263	 1	 10.73	 5.3	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38264	 1	 1.63	 0.69	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38265	 1	 7.18	 3.47	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38266	 1	 7.14	 3.08	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38267	 1	 7.71	 4.19	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38268	 1	 5.7	 2.47	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38269	 1	 5.4	 3.64	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38270	 1	 10.17	 2.28	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38271	 1	 3.44	 1.53	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38272	 1	 9.75	 2.21	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38273	 1	 5.82	 1.3	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38274	 1	 12.49	 2.84	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38275	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38276	 1	 8.92	 5.4	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38277	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38278	 1	 4.37	 2.51	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38279	 1	 3.43	 1.43	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38280	 1	 7.2	 3.63	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38281	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38282	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38283	 1	 3.97	 2.24	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38284	 1	 8.05	 4.16	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38285	 1	 46.92	 22.62	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38286	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38287	 1	 7.07	 3.36	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38288	 1	 5.58	 2.79	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38289	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38290	 1	 3.92	 1.95	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38291	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38292	 1	 3.82	 1.8	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38293	 1	 4.89	 2.34	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38294	 1	 3.37	 1.81	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38295	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38296	 1	 3.84	 2.09	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38297	 1	 4.37	 2.18	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38298	 1	 4.26	 2.3	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38299	 1	 2.17	 1.25	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38300	 1	 7.24	 4.53	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38301	 1	 5.08	 2.74	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38302	 1	 7.29	 3.52	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38303	 1	 7.38	 3.53	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38304	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38305	 1	 6.77	 3.58	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38306	 1	 16.3	 7.52	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38307	 1	 3.23	 1.83	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38308	 1	 11.69	 5.48	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38309	 1	 10.54	 4.78	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38310	 1	 6.02	 2.38	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38311	 1	 6.63	 4.13	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38312	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38313	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38314	 1	 7.64	 3.24	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38315	 1	 0.23	 0.13	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38316	 1	 14.46	 6.87	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38317	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38318	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38319	 1	 7.35	 2.81	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38320	 1	 13.81	 6.9	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38321	 1	 2.78	 1.35	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38322	 1	 19.24	 4.34	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38323	 1	 2.11	 0.47	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38324	 1	 9.17	 2.06	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38325	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38326	 1	 3.69	 2.15	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38327	 1	 3.66	 2.06	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38328	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38329	 1	 5.3	 3.03	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38330	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38331	 1	 2.22	 1.31	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38332	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38333	 1	 7.31	 3.71	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38334	 1	 3.61	 1.72	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38335	 1	 4.67	 2.24	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38336	 1	 21.47	 7.54	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38337	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38338	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38339	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38340	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38341	 1	 7.12	 4.85	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38342	 1	 2.75	 1.48	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38343	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38344	 1	 7.56	 4.46	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38345	 1	 2.62	 1.65	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38346	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38347	 1	 1.55	 0.79	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38348	 1	 3.13	 1.59	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38349	 1	 6.18	 3.25	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38350	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38351	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38352	 1	 1.49	 0.89	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38353	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38354	 1	 1.48	 0.91	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38355	 1	 1.05	 0.61	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38356	 1	 5.95	 3.62	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38357	 1	 14.53	 6.4	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38358	 1	 8.88	 5.02	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38359	 1	 5.93	 2.58	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38360	 1	 5.06	 2.44	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38361	 1	 3.33	 1.96	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38362	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38363	 1	 7.45	 1.62	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38364	 1	 6.23	 1.39	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38365	 1	 2.81	 1.68	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38366	 1	 2.85	 1.7	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38367	 1	 24.63	 12.97	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38368	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38369	 1	 3.39	 1.57	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38370	 1	 9.44	 5.37	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38371	 1	 3.97	 2.35	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38372	 1	 8.34	 4.15	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38373	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38374	 1	 3.75	 2.05	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38375	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38376	 1	 1.72	 0.88	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38377	 1	 9.91	 5.22	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38378	 1	 9.2	 4.77	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38379	 1	 11.67	 3.94	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38380	 1	 26.82	 9.01	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38381	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38382	 1	 7.41	 2.8	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38383	 1	 12.35	 4.67	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38384	 1	 8.59	 3.23	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38385	 1	 4.49	 1.68	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38386	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38387	 1	 11.3	 3.53	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38388	 1	 11.77	 3.21	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38389	 1	 14.59	 4.42	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38390	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38391	 1	 8.22	 2.84	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38392	 1	 11.37	 3.26	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38393	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38394	 1	 11.49	 3.92	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38395	 1	 16.05	 5.57	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38396	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38397	 1	 7.38	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38398	 1	 14.52	 -4.55	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38399	 1	 6.89	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38400	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38401	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38402	 1	 29.98	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38403	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38404	 1	 7.42	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38405	 1	 16.55	 3.82	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38406	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38407	 1	 6.06	 2.07	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38408	 1	 6.49	 2.47	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38409	 1	 10.56	 4.03	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38410	 1	 34.36	 12.53	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38411	 1	 5.98	 1.35	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38412	 1	 12.85	 2.91	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38413	 1	 10.98	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38414	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38415	 1	 23.96	 7.66	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38416	 1	 10.8	 3.38	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38417	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38418	 1	 26.29	 7.63	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38419	 1	 11.01	 3.86	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38420	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38421	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38422	 1	 6.05	 2.1	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38423	 1	 10.59	 4.01	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38424	 1	 12.71	 4.35	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38425	 1	 7.18	 2.71	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38426	 1	 10.54	 3.83	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38427	 1	 16.8	 5.07	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38428	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38429	 1	 10.28	 3.03	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38430	 1	 10.05	 3.11	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38431	 1	 3.2	 1.09	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38432	 1	 7.99	 2.53	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38433	 1	 3.37	 1.07	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38434	 1	 7.32	 2.91	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38435	 1	 13.28	 4.52	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38436	 1	 39.82	 14.52	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38437	 1	 16.22	 4.52	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38438	 1	 8.35	 3.15	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38439	 1	 7.53	 2.52	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38440	 1	 24.88	 8.7	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38441	 1	 0.05	 0.01	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38442	 1	 27.16	 7.86	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38443	 1	 30.99	 10.28	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38444	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38445	 1	 16.69	 3.76	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38446	 1	 12.87	 2.9	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38447	 1	 13.12	 2.96	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38448	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38449	 1	 8.35	 1.89	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38450	 1	 5.92	 1.33	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38451	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38452	 1	 29.51	 6.6	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38453	 1	 46.21	 8.99	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38454	 1	 20.41	 6.38	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38455	 1	 29.11	 9.51	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38456	 1	 13.71	 5.13	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38457	 1	 7.94	 1.79	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38458	 1	 24.25	 8.04	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38459	 1	 11.05	 3.9	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38460	 1	 8.62	 1.95	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38461	 1	 6.14	 2.3	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38462	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38463	 1	 3.9	 1.2	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38464	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38465	 1	 13.86	 4.85	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38466	 1	 19.07	 5.66	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38467	 1	 11.76	 3.49	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38468	 1	 5.86	 1.31	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38469	 1	 5.93	 1.65	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38470	 1	 4.69	 1.43	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38471	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38472	 1	 10.2	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38473	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38474	 1	 6.54	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38475	 1	 9.19	 3.45	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38476	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38477	 1	 7.56	 3.01	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38478	 1	 17.54	 5.2	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38479	 1	 8.94	 2.81	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38480	 1	 4.68	 1.56	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38481	 1	 4.19	 1.24	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38482	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38483	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38484	 1	 22.11	 4.73	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38485	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38486	 1	 4.07	 0.9	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38487	 1	 7.64	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38488	 1	 4.75	 1.03	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38489	 1	 6.08	 1.33	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38490	 1	 9.2	 2.12	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38491	 1	 6.12	 1.36	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38492	 1	 5.85	 1.31	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38493	 1	 4.06	 0.9	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38494	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38495	 1	 14.23	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38496	 1	 6.3	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38497	 1	 4.4	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38498	 1	 2.86	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38499	 1	 7.08	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38500	 1	 8.7	 3.27	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38501	 1	 7.09	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38502	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38503	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38504	 1	 10.34	 3.99	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38505	 1	 9.02	 2.85	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38506	 1	 20.99	 7.06	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38507	 1	 4.51	 1.44	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38508	 1	 13.18	 3.98	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38509	 1	 11.75	 3.61	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38510	 1	 14.96	 4.99	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38511	 1	 17.25	 5.18	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38512	 1	 5.0	 1.11	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38513	 1	 10.29	 2.37	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38514	 1	 10.58	 2.43	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38515	 1	 1.69	 0.38	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38516	 1	 5.18	 1.17	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38517	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38518	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38519	 1	 12.33	 2.77	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38520	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38521	 1	 15.77	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38522	 1	 6.89	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38523	 1	 7.14	 2.07	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38524	 1	 62.68	 11.34	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38525	 1	 8.26	 2.97	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38526	 1	 3.02	 0.88	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38527	 1	 12.01	 3.84	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38528	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38529	 1	 14.85	 4.86	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38530	 1	 8.07	 2.65	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38531	 1	 0.01	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38532	 1	 8.1	 2.49	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38533	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38534	 1	 3.29	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38535	 1	 16.9	 5.34	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38536	 1	 15.87	 5.38	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38537	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38538	 1	 10.09	 3.14	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38539	 1	 11.4	 3.72	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38540	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38541	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38542	 1	 27.72	 9.21	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38543	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38544	 1	 4.08	 1.49	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38545	 1	 10.25	 3.17	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38546	 1	 3.94	 1.33	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38547	 1	 4.24	 1.69	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38548	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38549	 1	 6.16	 1.36	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38550	 1	 9.71	 2.18	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38551	 1	 14.4	 5.03	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38552	 1	 12.3	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38553	 1	 9.53	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38554	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38555	 1	 12.6	 2.81	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38556	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38557	 1	 8.97	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38558	 1	 6.16	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38559	 1	 4.13	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38560	 1	 4.04	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38561	 1	 12.49	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38562	 1	 9.84	 2.76	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38563	 1	 4.81	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38564	 1	 5.65	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38565	 1	 8.74	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38566	 1	 9.04	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38567	 1	 28.65	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38568	 1	 12.71	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38569	 1	 17.2	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38570	 1	 19.6	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38571	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38572	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38573	 1	 18.37	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38574	 1	 84.35	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38575	 1	 14.38	 4.98	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38576	 1	 10.19	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38577	 1	 18.78	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38578	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38579	 1	 9.41	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38580	 1	 15.52	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38581	 1	 8.66	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38582	 1	 8.21	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38583	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38584	 1	 11.02	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38585	 1	 24.52	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38586	 1	 7.89	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38587	 1	 8.65	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38588	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38589	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38590	 1	 22.57	 7.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38591	 1	 7.23	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38592	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38593	 1	 14.26	 4.6	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38594	 1	 5.46	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38595	 1	 6.21	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38596	 1	 14.55	 5.28	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38597	 1	 4.35	 1.51	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38598	 1	 6.61	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38599	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38600	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38601	 1	 12.94	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38602	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38603	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38604	 1	 6.06	 2.11	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38605	 1	 12.29	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38606	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38607	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38608	 1	 6.3	 1.54	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38609	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38610	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38611	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38612	 1	 31.48	 9.05	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38613	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38614	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38615	 1	 16.59	 6.14	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38616	 1	 4.57	 1.44	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38617	 1	 25.91	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38618	 1	 6.81	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38619	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38620	 1	 10.46	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38621	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38622	 1	 14.39	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38623	 1	 8.99	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38624	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38625	 1	 13.46	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38626	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38627	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38628	 1	 11.85	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38629	 1	 14.08	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38630	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38631	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38632	 1	 9.27	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38633	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38634	 1	 10.09	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38635	 1	 10.81	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38636	 1	 8.35	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38637	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38638	 1	 7.04	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38639	 1	 27.73	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38640	 1	 12.88	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38641	 1	 8.83	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38642	 1	 11.01	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38643	 1	 6.01	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38644	 1	 17.98	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38645	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38646	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38647	 1	 16.42	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38648	 1	 7.4	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38649	 1	 18.41	 6.37	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38650	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38651	 1	 8.26	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38652	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38653	 1	 7.65	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38654	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38655	 1	 21.54	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38656	 1	 15.18	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38657	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38658	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38659	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38660	 1	 27.84	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38661	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38662	 1	 9.71	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38663	 1	 13.31	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38664	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38665	 1	 48.3	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38666	 1	 31.88	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38667	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38668	 1	 11.94	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38669	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38670	 1	 4.28	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38671	 1	 16.48	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38672	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38673	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38674	 1	 8.44	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38675	 1	 13.14	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38676	 1	 20.88	 7.84	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38677	 1	 14.29	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38678	 1	 7.56	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38679	 1	 23.32	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38680	 1	 2.58	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38681	 1	 34.17	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38682	 1	 8.32	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38683	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38684	 1	 13.23	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38685	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38686	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38687	 1	 6.68	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38688	 1	 7.22	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38689	 1	 5.52	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38690	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38691	 1	 4.12	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38692	 1	 7.49	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38693	 1	 18.23	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38694	 1	 11.01	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38695	 1	 8.44	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38696	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38697	 1	 14.56	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38698	 1	 6.66	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38699	 1	 9.81	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38700	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38701	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38702	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38703	 1	 5.71	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38704	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38705	 1	 14.14	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38706	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38707	 1	 8.33	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38708	 1	 8.45	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38709	 1	 17.86	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38710	 1	 9.08	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38711	 1	 9.16	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38712	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38713	 1	 6.58	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38714	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38715	 1	 8.17	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38716	 1	 8.61	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38717	 1	 15.34	 4.26	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38718	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38719	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38720	 1	 109.16	 30.48	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38721	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38722	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38723	 1	 42.58	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38724	 1	 5.02	 1.65	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38725	 1	 19.81	 6.42	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38726	 1	 5.78	 1.55	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38727	 1	 7.24	 2.31	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38728	 1	 10.28	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38729	 1	 8.13	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38730	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38731	 1	 14.53	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38732	 1	 7.58	 3.01	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38733	 1	 12.82	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38734	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38735	 1	 8.14	 1.85	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38736	 1	 31.24	 6.8	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38737	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38738	 1	 8.41	 3.14	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38739	 1	 10.81	 2.73	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38740	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38741	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38742	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38743	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38744	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38745	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38746	 1	 4.22	 1.41	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38747	 1	 20.77	 6.82	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38748	 1	 7.86	 3.01	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38749	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38750	 1	 7.63	 1.68	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38751	 1	 5.22	 1.15	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38752	 1	 6.05	 1.34	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38753	 1	 9.06	 2.05	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38754	 1	 9.36	 2.1	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38755	 1	 13.31	 3.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38756	 1	 10.17	 3.45	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38757	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38758	 1	 4.57	 1.31	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38759	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38760	 1	 5.38	 1.62	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38761	 1	 6.2	 1.38	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38762	 1	 11.5	 2.56	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38763	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38764	 1	 14.3	 4.47	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38765	 1	 16.88	 5.11	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38766	 1	 11.94	 4.65	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38767	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38768	 1	 6.76	 2.04	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38769	 1	 28.23	 7.6	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38770	 1	 23.03	 7.64	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38771	 1	 16.78	 4.36	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38772	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38773	 1	 7.27	 2.29	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38774	 1	 6.86	 2.32	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38775	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38776	 1	 6.81	 2.2	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38777	 1	 19.29	 6.4	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38778	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38779	 1	 3.29	 0.98	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38780	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38781	 1	 2.29	 0.7	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38782	 1	 23.54	 7.2	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38783	 1	 25.29	 6.6	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38784	 1	 13.14	 3.81	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38785	 1	 2.22	 0.87	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38786	 1	 8.3	 2.79	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38787	 1	 0.54	 0.19	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38788	 1	 7.11	 2.55	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38789	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38790	 1	 17.5	 6.38	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38791	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38792	 1	 28.57	 7.94	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38793	 1	 5.07	 1.93	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38794	 1	 3.23	 1.14	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38795	 1	 8.54	 2.96	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38796	 1	 7.61	 2.57	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38797	 1	 8.98	 1.94	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38798	 1	 14.1	 4.69	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38799	 1	 7.88	 2.22	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38800	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38801	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38802	 1	 19.73	 4.2	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38803	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38804	 1	 22.57	 7.87	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38805	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38806	 1	 7.83	 2.49	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38807	 1	 7.01	 2.45	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38808	 1	 7.91	 2.74	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38809	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38810	 1	 17.0	 5.88	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38811	 1	 6.44	 1.9	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38812	 1	 11.65	 3.78	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38813	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38814	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38815	 1	 6.3	 1.83	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38816	 1	 5.76	 2.13	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38817	 1	 4.33	 1.55	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38818	 1	 7.34	 2.58	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38819	 1	 11.6	 3.69	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38820	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38821	 1	 24.42	 6.6	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38822	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38823	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38824	 1	 5.34	 2.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38825	 1	 17.6	 3.9	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38826	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38827	 1	 25.91	 6.08	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38828	 1	 9.74	 2.15	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38829	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38830	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38831	 1	 12.5	 3.62	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38832	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38833	 1	 6.67	 1.98	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38834	 1	 7.92	 2.59	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38835	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38836	 1	 4.46	 1.2	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38837	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38838	 1	 6.4	 2.33	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38839	 1	 14.36	 4.58	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38840	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38841	 1	 19.0	 4.69	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38842	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38843	 1	 47.62	 13.7	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38844	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38845	 1	 14.3	 4.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38846	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38847	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38848	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38849	 1	 8.46	 3.14	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38850	 1	 11.25	 3.37	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38851	 1	 28.3	 6.92	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38852	 1	 6.09	 2.41	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38853	 1	 13.78	 4.83	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38854	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38855	 1	 24.47	 8.8	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38856	 1	 6.4	 2.19	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38857	 1	 7.11	 2.5	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38858	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38859	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38860	 1	 5.83	 2.21	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38861	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38862	 1	 5.56	 1.75	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38863	 1	 7.61	 2.67	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38864	 1	 21.94	 7.35	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38865	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38866	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38867	 1	 9.73	 3.75	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38868	 1	 21.83	 8.55	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38869	 1	 21.65	 7.98	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38870	 1	 15.53	 4.91	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38871	 1	 4.19	 1.41	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38872	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38873	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38874	 1	 6.59	 2.59	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38875	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38876	 1	 9.63	 2.62	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38877	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38878	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38879	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38880	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38881	 1	 3.21	 1.02	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38882	 1	 12.28	 3.92	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38883	 1	 13.84	 5.02	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38884	 1	 33.0	 10.22	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38885	 1	 14.85	 5.24	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38886	 1	 9.75	 3.4	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38887	 1	 44.05	 14.03	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38888	 1	 9.63	 3.66	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38889	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38890	 1	 11.02	 3.63	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38891	 1	 7.83	 2.92	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38892	 1	 9.86	 3.42	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38893	 1	 8.73	 3.14	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38894	 1	 53.68	 17.38	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38895	 1	 42.57	 11.94	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38896	 1	 18.14	 5.79	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38897	 1	 5.42	 1.69	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38898	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38899	 1	 38.49	 12.11	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38900	 1	 46.67	 12.25	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38901	 1	 7.87	 3.06	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38902	 1	 29.13	 9.05	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38903	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38904	 1	 14.0	 5.26	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38905	 1	 14.03	 5.32	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38906	 1	 5.19	 1.96	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38907	 1	 3.83	 1.25	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38908	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38909	 1	 16.2	 5.02	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38910	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38911	 1	 54.7	 15.28	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38912	 1	 12.07	 2.48	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38913	 1	 22.53	 5.72	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38914	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38915	 1	 12.39	 3.32	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38916	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38917	 1	 14.7	 4.16	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38918	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38919	 1	 18.35	 6.8	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38920	 1	 37.0	 9.9	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38921	 1	 10.92	 3.71	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38922	 1	 7.06	 2.52	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38923	 1	 8.4	 2.94	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38924	 1	 10.99	 3.57	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38925	 1	 16.57	 6.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38926	 1	 29.88	 10.03	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38927	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38928	 1	 8.23	 1.77	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38929	 1	 10.83	 3.33	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38930	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38931	 1	 7.72	 2.9	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38932	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38933	 1	 14.8	 4.93	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38934	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38935	 1	 8.88	 2.89	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38936	 1	 13.38	 4.42	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38937	 1	 97.45	 26.79	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38938	 1	 7.36	 2.29	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38939	 1	 9.38	 3.11	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38940	 1	 14.16	 3.9	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38941	 1	 5.59	 2.13	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38942	 1	 8.59	 2.61	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38943	 1	 8.92	 3.55	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38944	 1	 23.12	 5.68	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38945	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38946	 1	 13.66	 5.1	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38947	 1	 5.53	 1.86	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38948	 1	 6.68	 1.45	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38949	 1	 10.37	 3.68	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38950	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38951	 1	 23.58	 6.1	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38952	 1	 7.12	 2.31	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38953	 1	 11.08	 3.32	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38954	 1	 5.56	 1.89	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38955	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38956	 1	 26.27	 8.28	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38957	 1	 15.58	 5.96	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38958	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38959	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38960	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	38961	 1	 11.94	 3.57	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38962	 1	 10.44	 3.98	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38963	 1	 14.3	 4.49	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38964	 1	 13.21	 3.85	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38965	 1	 32.85	 11.35	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38966	 1	 5.74	 1.94	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38967	 1	 4.57	 1.7	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38968	 1	 7.36	 2.84	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38969	 1	 7.96	 2.76	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38970	 1	 5.92	 2.44	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38971	 1	 14.41	 5.06	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38972	 1	 21.85	 5.99	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38973	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38974	 1	 6.77	 2.26	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38975	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	38976	 1	 3.94	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38977	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38978	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38979	 1	 13.51	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38980	 1	 14.34	 4.94	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38981	 1	 10.63	 2.98	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38982	 1	 30.75	 9.05	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38983	 1	 7.6	 2.43	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38984	 1	 11.26	 3.47	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38985	 1	 18.88	 5.97	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38986	 1	 20.58	 7.13	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38987	 1	 12.76	 4.09	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38988	 1	 15.58	 3.35	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38989	 1	 1.83	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38990	 1	 8.1	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38991	 1	 7.54	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38992	 1	 17.22	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38993	 1	 16.89	 -4.48	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38994	 1	 20.69	 4.61	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38995	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38996	 1	 3.93	 1.21	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38997	 1	 22.54	 5.32	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	38998	 1	 6.64	 1.81	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38999	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39000	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39001	 1	 14.02	 3.97	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39002	 1	 5.43	 1.84	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39003	 1	 4.17	 1.32	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39004	 1	 13.41	 3.99	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39005	 1	 6.6	 2.03	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39006	 1	 12.8	 2.83	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39007	 1	 18.03	 6.48	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39008	 1	 16.95	 4.71	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39009	 1	 13.49	 4.8	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39010	 1	 11.46	 4.04	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39011	 1	 32.03	 7.98	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39012	 1	 14.52	 4.76	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39013	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39014	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39015	 1	 12.07	 3.78	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39016	 1	 4.88	 1.4	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39017	 1	 9.9	 3.48	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39018	 1	 25.95	 8.84	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39019	 1	 18.42	 6.12	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39020	 1	 61.47	 20.96	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39021	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39022	 1	 8.04	 2.64	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39023	 1	 16.55	 6.18	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39024	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39025	 1	 14.08	 4.66	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39026	 1	 8.19	 2.17	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39027	 1	 19.38	 5.89	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39028	 1	 9.97	 3.05	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39029	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39030	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39031	 1	 13.76	 5.19	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39032	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39033	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39034	 1	 5.19	 1.78	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39035	 1	 8.52	 3.15	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39036	 1	 14.99	 5.51	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39037	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39038	 1	 4.42	 1.58	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39039	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39040	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39041	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39042	 1	 11.87	 4.03	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39043	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39044	 1	 9.61	 3.43	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39045	 1	 10.43	 3.39	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39046	 1	 10.98	 3.6	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39047	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39048	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39049	 1	 19.03	 4.57	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39050	 1	 7.23	 2.58	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39051	 1	 111.36	 33.81	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39052	 1	 7.43	 2.12	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39053	 1	 14.8	 3.81	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39054	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39055	 1	 7.29	 2.13	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39056	 1	 8.03	 2.8	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39057	 1	 7.51	 2.82	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39058	 1	 8.33	 2.86	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39059	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39060	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39061	 1	 6.01	 1.9	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39062	 1	 5.53	 2.13	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39063	 1	 3.97	 1.27	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39064	 1	 3.83	 1.35	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39065	 1	 10.45	 3.73	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39066	 1	 14.65	 4.76	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39067	 1	 19.16	 5.5	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39068	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39069	 1	 11.54	 3.5	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39070	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39071	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39072	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39073	 1	 9.21	 3.39	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39074	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39075	 1	 7.03	 2.37	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39076	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39077	 1	 6.72	 2.38	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39078	 1	 3.01	 1.17	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39079	 1	 5.88	 2.34	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39080	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39081	 1	 5.62	 1.72	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39082	 1	 15.81	 5.07	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39083	 1	 7.74	 2.92	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39084	 1	 40.1	 13.44	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39085	 1	 9.73	 3.62	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39086	 1	 11.78	 4.16	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39087	 1	 10.07	 2.22	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39088	 1	 15.01	 3.32	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39089	 1	 7.84	 2.66	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39090	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39091	 1	 12.9	 4.55	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39092	 1	 14.31	 4.66	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39093	 1	 6.41	 2.08	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39094	 1	 5.03	 1.63	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39095	 1	 9.33	 2.06	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39096	 1	 8.3	 1.84	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39097	 1	 5.11	 1.51	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39098	 1	 6.96	 2.31	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39099	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39100	 1	 23.26	 6.98	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39101	 1	 24.74	 6.95	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39102	 1	 9.7	 3.05	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39103	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39104	 1	 10.9	 3.92	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39105	 1	 8.73	 3.06	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39106	 1	 12.61	 5.11	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39107	 1	 4.22	 1.36	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39108	 1	 8.8	 2.94	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39109	 1	 8.3	 3.15	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39110	 1	 6.17	 1.93	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39111	 1	 5.75	 2.1	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39112	 1	 8.1	 2.95	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39113	 1	 48.84	 14.06	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39114	 1	 15.01	 5.84	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39115	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39116	 1	 4.59	 1.77	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39117	 1	 8.12	 1.84	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39118	 1	 4.44	 1.59	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39119	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39120	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39121	 1	 7.21	 2.42	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39122	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39123	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39124	 1	 7.63	 2.29	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39125	 1	 11.52	 3.01	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39126	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39127	 1	 3.61	 1.17	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39128	 1	 10.8	 2.39	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39129	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39130	 1	 3.13	 0.72	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39131	 1	 4.23	 0.96	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39132	 1	 7.18	 2.13	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39133	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39134	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39135	 1	 9.5	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39136	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39137	 1	 7.27	 1.66	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39138	 1	 6.0	 2.13	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39139	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39140	 1	 62.04	 17.32	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39141	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39142	 1	 8.77	 2.75	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39143	 1	 11.69	 3.61	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39144	 1	 15.63	 3.9	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39145	 1	 16.82	 5.99	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39146	 1	 4.25	 1.33	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39147	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39148	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39149	 1	 28.82	 9.49	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39150	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39151	 1	 33.27	 10.96	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39152	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39153	 1	 11.52	 3.76	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39154	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39155	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39156	 1	 52.43	 11.87	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39157	 1	 12.03	 3.98	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39158	 1	 45.1	 11.13	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39159	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39160	 1	 3.96	 1.39	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39161	 1	 6.71	 2.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39162	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39163	 1	 40.99	 11.01	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39164	 1	 6.81	 2.57	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39165	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39166	 1	 10.35	 3.08	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39167	 1	 10.8	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39168	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39169	 1	 27.07	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39170	 1	 12.56	 2.83	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39171	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39172	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39173	 1	 14.85	 3.36	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39174	 1	 11.38	 2.56	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39175	 1	 4.06	 0.93	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39176	 1	 16.76	 4.55	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39177	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39178	 1	 13.21	 4.84	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39179	 1	 5.28	 1.96	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39180	 1	 11.42	 3.31	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39181	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39182	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39183	 1	 44.95	 12.32	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39184	 1	 8.6	 1.91	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39185	 1	 11.66	 3.98	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39186	 1	 4.37	 1.35	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39187	 1	 12.63	 4.3	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39188	 1	 8.65	 2.58	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39189	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39190	 1	 19.44	 6.4	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39191	 1	 4.15	 0.94	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39192	 1	 10.11	 3.59	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39193	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39194	 1	 14.21	 3.17	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39195	 1	 5.83	 1.28	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39196	 1	 7.64	 2.76	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39197	 1	 9.98	 4.02	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39198	 1	 12.19	 3.69	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39199	 1	 8.88	 3.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39200	 1	 42.75	 14.4	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39201	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39202	 1	 7.13	 2.66	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39203	 1	 14.36	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39204	 1	 16.3	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39205	 1	 67.61	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39206	 1	 14.24	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39207	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39208	 1	 8.36	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39209	 1	 8.47	 2.67	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39210	 1	 23.56	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39211	 1	 21.5	 7.25	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39212	 1	 11.62	 3.75	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39213	 1	 6.99	 1.61	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39214	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39215	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39216	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39217	 1	 15.37	 4.21	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39218	 1	 17.18	 4.86	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39219	 1	 19.34	 6.35	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39220	 1	 24.27	 8.5	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39221	 1	 29.12	 6.48	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39222	 1	 46.79	 14.32	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39223	 1	 15.08	 3.9	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39224	 1	 9.55	 3.29	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39225	 1	 12.18	 4.16	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39226	 1	 7.11	 2.48	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39227	 1	 23.91	 8.02	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39228	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39229	 1	 59.5	 18.31	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39230	 1	 35.81	 9.94	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39231	 1	 22.52	 7.31	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39232	 1	 16.71	 5.79	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39233	 1	 30.52	 10.75	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39234	 1	 7.07	 2.29	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39235	 1	 9.51	 3.59	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39236	 1	 22.05	 6.59	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39237	 1	 3.54	 1.38	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39238	 1	 14.16	 4.46	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39239	 1	 6.44	 2.17	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39240	 1	 11.62	 4.19	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39241	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39242	 1	 4.83	 1.78	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39243	 1	 3.02	 1.15	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39244	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39245	 1	 6.38	 2.45	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39246	 1	 9.86	 3.52	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39247	 1	 7.09	 2.47	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39248	 1	 5.51	 1.81	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39249	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39250	 1	 5.67	 1.82	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39251	 1	 4.44	 1.45	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39252	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39253	 1	 23.24	 8.65	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39254	 1	 12.67	 5.01	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39255	 1	 5.66	 1.88	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39256	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39257	 1	 4.16	 1.36	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39258	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39259	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39260	 1	 19.63	 5.88	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39261	 1	 14.57	 5.44	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39262	 1	 21.38	 6.87	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39263	 1	 15.81	 5.82	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39264	 1	 12.82	 4.34	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39265	 1	 4.58	 1.77	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39266	 1	 19.2	 6.64	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39267	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39268	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39269	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39270	 1	 8.78	 3.02	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39271	 1	 10.44	 4.15	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39272	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39273	 1	 15.08	 4.37	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39274	 1	 1.24	 0.49	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39275	 1	 6.92	 2.32	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39276	 1	 27.18	 6.3	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39277	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39278	 1	 8.59	 3.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39279	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39280	 1	 14.59	 4.41	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39281	 1	 16.33	 6.34	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39282	 1	 11.35	 4.47	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39283	 1	 4.75	 1.67	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39284	 1	 19.21	 7.28	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39285	 1	 7.25	 2.43	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39286	 1	 23.13	 7.99	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39287	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39288	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39289	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39290	 1	 7.43	 2.56	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39291	 1	 30.46	 8.49	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39292	 1	 5.21	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39293	 1	 3.63	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39294	 1	 15.29	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39295	 1	 19.8	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39296	 1	 3.76	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39297	 1	 13.24	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39298	 1	 5.2	 -7.04	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39299	 1	 20.44	 5.99	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39300	 1	 11.77	 2.66	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39301	 1	 14.15	 4.47	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39302	 1	 2.78	 1.04	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39303	 1	 4.54	 1.68	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39304	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39305	 1	 10.49	 2.58	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39306	 1	 15.4	 5.29	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39307	 1	 34.03	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39308	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39309	 1	 5.56	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39310	 1	 13.95	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39311	 1	 9.72	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39312	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39313	 1	 12.16	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39314	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39315	 1	 31.87	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39316	 1	 35.41	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39317	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39318	 1	 7.11	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39319	 1	 21.01	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39320	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39321	 1	 4.9	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39322	 1	 15.78	 5.44	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39323	 1	 16.13	 5.21	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39324	 1	 29.84	 10.48	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39325	 1	 11.66	 3.95	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39326	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39327	 1	 7.27	 2.5	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39328	 1	 5.8	 2.3	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39329	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39330	 1	 20.06	 6.36	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39331	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39332	 1	 13.4	 4.29	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39333	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39334	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39335	 1	 14.93	 5.49	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39336	 1	 13.19	 4.14	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39337	 1	 12.55	 4.33	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39338	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39339	 1	 18.69	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39340	 1	 23.11	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39341	 1	 13.43	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39342	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39343	 1	 5.02	 1.47	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39344	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39345	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39346	 1	 16.98	 5.79	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39347	 1	 15.46	 4.35	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39348	 1	 10.93	 3.71	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39349	 1	 6.63	 1.51	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39350	 1	 22.33	 5.12	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39351	 1	 11.89	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39352	 1	 19.08	 7.17	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39353	 1	 5.86	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39354	 1	 6.6	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39355	 1	 15.03	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39356	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39357	 1	 15.44	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39358	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39359	 1	 24.09	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39360	 1	 3.67	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39361	 1	 6.93	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39362	 1	 4.39	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39363	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39364	 1	 7.23	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39365	 1	 12.2	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39366	 1	 18.17	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39367	 1	 14.99	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39368	 1	 29.89	 -7.26	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39369	 1	 8.64	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39370	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39371	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39372	 1	 16.86	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39373	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39374	 1	 8.92	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39375	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39376	 1	 8.87	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39377	 1	 6.84	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39378	 1	 19.2	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39379	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39380	 1	 18.23	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39381	 1	 10.97	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39382	 1	 15.83	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39383	 1	 26.52	 -4.51	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39384	 1	 14.54	 -4.46	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39385	 1	 10.13	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39386	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39387	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39388	 1	 9.76	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39389	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39390	 1	 10.14	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39391	 1	 27.61	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39392	 1	 19.32	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39393	 1	 5.34	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39394	 1	 26.58	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39395	 1	 26.36	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39396	 1	 73.56	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39397	 1	 10.54	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39398	 1	 9.19	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39399	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39400	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39401	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39402	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39403	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39404	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39405	 1	 6.21	 2.1	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39406	 1	 4.99	 1.66	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39407	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39408	 1	 4.04	 1.2	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39409	 1	 7.02	 2.15	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39410	 1	 11.29	 3.31	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39411	 1	 14.76	 5.22	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39412	 1	 15.31	 4.63	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39413	 1	 18.47	 6.02	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39414	 1	 14.86	 5.18	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39415	 1	 12.92	 4.13	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39416	 1	 13.85	 4.05	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39417	 1	 12.18	 3.49	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39418	 1	 16.27	 3.58	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39419	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39420	 1	 15.69	 4.44	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39421	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39422	 1	 6.12	 2.2	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39423	 1	 10.42	 3.31	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39424	 1	 21.7	 7.15	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39425	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39426	 1	 5.89	 2.29	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39427	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39428	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39429	 1	 9.76	 2.67	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39430	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39431	 1	 5.55	 1.5	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39432	 1	 8.64	 1.98	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39433	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39434	 1	 14.74	 3.3	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39435	 1	 6.7	 1.88	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39436	 1	 7.78	 1.74	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39437	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39438	 1	 9.11	 2.04	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39439	 1	 19.44	 4.09	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39440	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39441	 1	 7.8	 2.83	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39442	 1	 8.23	 2.34	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39443	 1	 3.49	 1.2	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39444	 1	 4.2	 1.16	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39445	 1	 5.77	 1.83	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39446	 1	 7.1	 2.27	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39447	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39448	 1	 4.77	 1.73	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39449	 1	 7.1	 2.07	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39450	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39451	 1	 14.42	 5.26	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39452	 1	 15.02	 5.16	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39453	 1	 14.78	 4.94	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39454	 1	 14.48	 4.7	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39455	 1	 5.44	 1.53	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39456	 1	 8.34	 2.68	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39457	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39458	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39459	 1	 10.48	 3.6	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39460	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39461	 1	 10.03	 3.04	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39462	 1	 24.47	 5.88	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39463	 1	 9.4	 2.47	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39464	 1	 1.72	 0.62	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39465	 1	 7.59	 1.86	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39466	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39467	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39468	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39469	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39470	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39471	 1	 2.47	 0.79	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39472	 1	 5.04	 1.53	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39473	 1	 4.02	 1.22	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39474	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39475	 1	 4.82	 1.48	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39476	 1	 4.44	 1.61	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39477	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39478	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39479	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39480	 1	 6.52	 2.19	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39481	 1	 8.8	 3.23	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39482	 1	 10.18	 3.52	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39483	 1	 5.12	 1.8	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39484	 1	 4.83	 1.43	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39485	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39486	 1	 10.7	 3.71	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39487	 1	 2.85	 0.9	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39488	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39489	 1	 12.58	 4.6	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39490	 1	 4.86	 1.52	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39491	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39492	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39493	 1	 11.06	 2.97	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39494	 1	 10.8	 3.82	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39495	 1	 9.77	 3.12	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39496	 1	 19.01	 6.32	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39497	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39498	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39499	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39500	 1	 10.93	 2.42	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39501	 1	 5.68	 1.26	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39502	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39503	 1	 11.8	 3.85	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39504	 1	 6.81	 2.54	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39505	 1	 15.25	 5.64	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39506	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39507	 1	 6.29	 1.82	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39508	 1	 8.77	 2.38	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39509	 1	 29.33	 6.49	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39510	 1	 11.73	 2.58	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39511	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39512	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39513	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39514	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39515	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39516	 1	 2.66	 0.6	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39517	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39518	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39519	 1	 8.27	 2.61	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39520	 1	 8.54	 3.19	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39521	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39522	 1	 9.48	 2.79	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39523	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39524	 1	 9.7	 3.06	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39525	 1	 11.07	 3.36	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39526	 1	 22.06	 6.66	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39527	 1	 105.05	 22.46	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39528	 1	 4.16	 1.41	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39529	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39530	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39531	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39532	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39533	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39534	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39535	 1	 8.95	 1.95	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39536	 1	 6.08	 1.31	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39537	 1	 13.97	 3.09	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39538	 1	 203.92	 44.88	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39539	 1	 6.37	 1.41	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39540	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39541	 1	 3.07	 0.65	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39542	 1	 3.83	 0.85	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39543	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39544	 1	 6.65	 1.46	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39545	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39546	 1	 8.84	 1.97	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39547	 1	 11.63	 2.58	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39548	 1	 14.5	 3.22	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39549	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39550	 1	 13.8	 3.04	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39551	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39552	 1	 23.25	 5.18	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39553	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39554	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39555	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39556	 1	 5.77	 1.28	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39557	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39558	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39559	 1	 15.82	 3.47	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39560	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39561	 1	 12.13	 2.69	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39562	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39563	 1	 5.18	 1.14	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39564	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39565	 1	 19.63	 4.41	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39566	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39567	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39568	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39569	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39570	 1	 11.17	 4.02	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39571	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39572	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39573	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39574	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39575	 1	 11.84	 2.64	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39576	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39577	 1	 11.83	 4.14	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39578	 1	 7.33	 2.53	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39579	 1	 12.46	 3.96	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39580	 1	 9.6	 2.88	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39581	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39582	 1	 9.2	 2.06	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39583	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39584	 1	 9.68	 2.95	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39585	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39586	 1	 6.19	 1.38	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39587	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39588	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39589	 1	 4.5	 1.44	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39590	 1	 19.09	 6.12	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39591	 1	 7.39	 2.07	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39592	 1	 7.72	 2.23	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39593	 1	 6.68	 2.13	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39594	 1	 12.28	 4.47	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39595	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39596	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39597	 1	 12.48	 3.64	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39598	 1	 17.26	 5.45	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39599	 1	 5.2	 1.75	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39600	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39601	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39602	 1	 16.1	 4.63	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39603	 1	 29.18	 9.98	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39604	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39605	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39606	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39607	 1	 8.28	 2.5	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39608	 1	 8.36	 3.05	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39609	 1	 16.48	 5.25	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39610	 1	 10.49	 2.9	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39611	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39612	 1	 7.34	 2.65	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39613	 1	 8.39	 2.67	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39614	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39615	 1	 11.56	 3.32	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39616	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39617	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39618	 1	 12.17	 3.93	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39619	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39620	 1	 10.38	 3.57	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39621	 1	 8.32	 2.73	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39622	 1	 13.25	 5.04	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39623	 1	 8.39	 3.13	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39624	 1	 5.98	 2.23	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39625	 1	 9.06	 2.58	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39626	 1	 13.46	 4.49	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39627	 1	 19.44	 6.81	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39628	 1	 8.51	 2.99	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39629	 1	 7.46	 2.82	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39630	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39631	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39632	 1	 11.16	 4.17	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39633	 1	 11.02	 3.97	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39634	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39635	 1	 9.2	 3.6	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39636	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39637	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39638	 1	 10.02	 3.56	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39639	 1	 7.56	 2.28	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39640	 1	 9.07	 2.85	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39641	 1	 11.72	 4.61	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39642	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39643	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39644	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39645	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39646	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39647	 1	 26.49	 7.63	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39648	 1	 6.35	 2.13	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39649	 1	 11.43	 4.43	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39650	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39651	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39652	 1	 3.84	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39653	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39654	 1	 12.03	 4.69	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39655	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39656	 1	 8.8	 3.16	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39657	 1	 0.24	 0.04	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39658	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	39659	 1	 5.43	 1.99	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39660	 1	 10.94	 3.39	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39661	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39662	 1	 17.16	 5.09	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39663	 1	 14.6	 5.49	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39664	 1	 15.87	 5.21	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39665	 1	 8.48	 2.94	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39666	 1	 13.32	 3.86	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39667	 1	 14.4	 4.95	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39668	 1	 8.74	 2.7	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39669	 1	 15.09	 4.91	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39670	 1	 11.17	 2.92	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39671	 1	 6.5	 2.19	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39672	 1	 6.11	 1.87	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39673	 1	 12.21	 3.49	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39674	 1	 6.98	 2.11	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39675	 1	 6.65	 1.44	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39676	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39677	 1	 9.63	 2.08	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39678	 1	 18.68	 4.04	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39679	 1	 10.34	 2.2	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39680	 1	 20.16	 4.38	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39681	 1	 14.24	 3.08	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39682	 1	 32.24	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39683	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39684	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39685	 1	 23.7	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39686	 1	 7.33	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39687	 1	 24.31	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39688	 1	 5.54	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39689	 1	 10.81	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39690	 1	 9.47	 3.2	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39691	 1	 10.04	 3.57	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39692	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39693	 1	 10.28	 2.21	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39694	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39695	 1	 20.19	 6.42	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39696	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39697	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39698	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39699	 1	 4.88	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39700	 1	 12.39	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39701	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39702	 1	 2.33	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39703	 1	 3.08	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39704	 1	 4.4	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39705	 1	 5.56	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39706	 1	 48.52	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39707	 1	 3.19	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39708	 1	 3.5	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39709	 1	 4.73	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39710	 1	 6.1	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39711	 1	 7.32	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39712	 1	 16.48	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39713	 1	 8.38	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39714	 1	 8.12	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39715	 1	 5.79	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39716	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39717	 1	 6.37	 2.34	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39718	 1	 23.65	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39719	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39720	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39721	 1	 65.85	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39722	 1	 7.36	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39723	 1	 16.03	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39724	 1	 15.75	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39725	 1	 17.36	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39726	 1	 6.68	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39727	 1	 3.26	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39728	 1	 9.96	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39729	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39730	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39731	 1	 10.44	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39732	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39733	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39734	 1	 8.67	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39735	 1	 12.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39736	 1	 14.17	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39737	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39738	 1	 20.98	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39739	 1	 9.18	 1.96	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39740	 1	 4.34	 1.35	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39741	 1	 17.37	 3.91	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39742	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39743	 1	 12.57	 3.82	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39744	 1	 5.71	 1.77	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39745	 1	 11.85	 4.27	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39746	 1	 19.95	 4.62	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39747	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39748	 1	 30.09	 6.98	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39749	 1	 9.16	 2.56	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39750	 1	 16.18	 5.22	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39751	 1	 5.92	 1.32	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39752	 1	 22.16	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39753	 1	 8.99	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39754	 1	 9.33	 2.01	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39755	 1	 26.84	 5.7	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39756	 1	 11.0	 2.44	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39757	 1	 18.11	 3.83	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39758	 1	 22.38	 5.06	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39759	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39760	 1	 20.3	 4.81	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39761	 1	 4.79	 1.07	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39762	 1	 5.32	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39763	 1	 8.21	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39764	 1	 10.6	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39765	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39766	 1	 4.52	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39767	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39768	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39769	 1	 14.91	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39770	 1	 11.55	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39771	 1	 32.9	 9.09	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39772	 1	 3.25	 1.07	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39773	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39774	 1	 22.12	 6.65	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39775	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39776	 1	 12.83	 2.86	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39777	 1	 25.89	 7.58	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39778	 1	 4.85	 1.64	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39779	 1	 17.57	 5.2	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39780	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39781	 1	 15.86	 3.55	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39782	 1	 10.33	 2.3	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39783	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39784	 1	 35.85	 11.04	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39785	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39786	 1	 20.45	 6.3	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39787	 1	 16.39	 4.74	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39788	 1	 8.46	 2.41	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39789	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39790	 1	 13.35	 4.72	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39791	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39792	 1	 12.2	 2.72	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39793	 1	 17.46	 3.85	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39794	 1	 11.52	 3.64	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39795	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39796	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39797	 1	 22.06	 7.06	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39798	 1	 9.75	 3.28	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39799	 1	 13.15	 5.2	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39800	 1	 2.12	 0.77	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39801	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39802	 1	 3.34	 1.03	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39803	 1	 17.35	 6.39	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39804	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39805	 1	 7.25	 2.26	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39806	 1	 6.3	 2.2	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39807	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39808	 1	 11.93	 4.39	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39809	 1	 9.65	 3.06	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39810	 1	 3.2	 1.11	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39811	 1	 8.06	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39812	 1	 12.89	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39813	 1	 10.68	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39814	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39815	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39816	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39817	 1	 13.96	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39818	 1	 7.14	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39819	 1	 8.4	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39820	 1	 12.24	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39821	 1	 8.7	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39822	 1	 6.55	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39823	 1	 5.15	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39824	 1	 6.32	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39825	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39826	 1	 5.45	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39827	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39828	 1	 4.78	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39829	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39830	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39831	 1	 3.54	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39832	 1	 11.66	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39833	 1	 4.47	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39834	 1	 10.33	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39835	 1	 14.96	 5.24	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39836	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39837	 1	 7.59	 2.79	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39838	 1	 17.63	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39839	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39840	 1	 7.68	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39841	 1	 10.22	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39842	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39843	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39844	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39845	 1	 13.6	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39846	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39847	 1	 16.64	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39848	 1	 8.18	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39849	 1	 12.53	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39850	 1	 11.52	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39851	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39852	 1	 17.11	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39853	 1	 41.3	 14.82	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39854	 1	 15.07	 5.97	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39855	 1	 14.56	 5.48	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39856	 1	 13.23	 4.13	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39857	 1	 10.64	 3.37	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39858	 1	 12.06	 3.89	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39859	 1	 10.03	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39860	 1	 13.28	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39861	 1	 12.31	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39862	 1	 29.26	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39863	 1	 9.73	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39864	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39865	 1	 19.76	 6.61	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39866	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39867	 1	 32.16	 8.44	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39868	 1	 14.85	 4.4	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39869	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39870	 1	 27.81	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39871	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39872	 1	 24.14	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39873	 1	 12.69	 -4.56	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39874	 1	 14.92	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39875	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39876	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39877	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39878	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39879	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39880	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39881	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39882	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39883	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39884	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39885	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39886	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39887	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39888	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39889	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39890	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39891	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39892	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39893	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39894	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39895	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39896	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39897	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39898	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39899	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39900	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39901	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39902	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39903	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39904	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39905	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39906	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39907	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39908	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39909	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39910	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39911	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39912	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39913	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39914	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39915	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39916	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39917	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39918	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39919	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39920	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39921	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39922	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39923	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39924	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39925	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39926	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39927	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39928	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39929	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39930	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39931	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39932	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39933	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39934	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39935	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39936	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39937	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39938	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39939	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39940	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39941	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39942	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39943	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39944	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39945	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39946	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39947	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39948	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39949	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39950	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39951	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	39952	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39953	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39954	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39955	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39956	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39957	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39958	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39959	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39960	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39961	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39962	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39963	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39964	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39965	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39966	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39967	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39968	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39969	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39970	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39971	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39972	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39973	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39974	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39975	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39976	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39977	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39978	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39979	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39980	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39981	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39982	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39983	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39984	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39985	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39986	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39987	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39988	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39989	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39990	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39991	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39992	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	39993	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39994	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39995	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39996	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	39997	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39998	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39999	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40000	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40001	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40002	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40003	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40004	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40005	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40006	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40007	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40008	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40009	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40010	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40011	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40012	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	40013	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40014	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40015	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40016	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40017	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40018	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40019	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40020	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40021	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40022	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	40023	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40024	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40025	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	40026	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40027	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40028	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	40029	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40030	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40031	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40032	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40033	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40034	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40035	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40036	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40037	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40038	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40039	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40040	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40041	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40042	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40043	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40044	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40045	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40046	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	40047	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40048	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40049	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40050	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40051	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40052	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40053	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40054	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40055	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40056	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40057	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40058	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	40059	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40060	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40061	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40062	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40063	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40064	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	40065	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40066	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40067	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40068	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40069	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40070	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40071	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40072	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40073	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40074	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40075	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40076	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40077	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40078	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40079	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40080	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40081	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40082	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40083	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40084	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40085	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40086	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40087	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40088	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40089	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40090	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40091	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40092	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40093	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40094	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40095	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40096	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40097	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40098	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40099	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40100	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40101	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40102	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40103	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40104	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40105	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40106	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40107	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40108	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40109	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40110	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40111	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40112	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40113	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40114	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40115	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40116	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40117	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40118	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	40119	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40120	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40121	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40122	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40123	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40124	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40125	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40126	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40127	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40128	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40129	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40130	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40131	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40132	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40133	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40134	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40135	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40136	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40137	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40138	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40139	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40140	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40141	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40142	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40143	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40144	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40145	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40146	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40147	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	40148	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40149	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40150	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40151	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40152	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40153	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40154	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40155	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40156	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40157	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40158	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40159	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40160	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40161	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40162	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40163	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40164	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40165	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40166	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40167	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40168	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40169	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40170	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40171	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40172	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	40173	 1	 1.4	 2.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40174	 1	 0.9	 1.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40175	 1	 3.75	 6.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40176	 1	 0.98	 1.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40177	 1	 1.6	 3.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40178	 1	 1.13	 1.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40179	 1	 3.5	 6.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40180	 1	 0.44	 0.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40181	 1	 0.58	 1.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40182	 1	 0.55	 1.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40183	 1	 2.13	 4.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40184	 1	 3.99	 6.58	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40185	 1	 2.86	 4.93	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40186	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40187	 1	 3.18	 6.3	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40188	 1	 0.91	 1.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40189	 1	 6.95	 8.85	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40190	 1	 1.31	 2.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40191	 1	 0.4	 0.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40192	 1	 2.81	 4.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40193	 1	 0.98	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40194	 1	 1.53	 3.15	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40195	 1	 6.22	 10.31	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40196	 1	 2.0	 3.87	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40197	 1	 4.4	 7.98	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40198	 1	 5.58	 7.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40199	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40200	 1	 3.04	 5.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40201	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40202	 1	 2.7	 6.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40203	 1	 2.29	 3.22	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40204	 1	 3.65	 7.86	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40205	 1	 1.64	 2.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40206	 1	 3.06	 6.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40207	 1	 6.1	 10.71	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40208	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40209	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40210	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40211	 1	 1.89	 2.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40212	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40213	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40214	 1	 1.96	 4.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40215	 1	 1.28	 2.23	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40216	 1	 8.24	 15.97	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40217	 1	 0.91	 1.83	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40218	 1	 1.25	 2.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40219	 1	 5.91	 9.01	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40220	 1	 2.71	 4.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40221	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40222	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40223	 1	 2.9	 5.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40224	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	40225	 1	 2.29	 4.56	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40226	 1	 3.95	 7.39	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40227	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40228	 1	 0.99	 1.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40229	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40230	 1	 1.18	 1.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40231	 1	 1.55	 3.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40232	 1	 0.96	 1.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40233	 1	 1.62	 3.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40234	 1	 0.67	 1.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40235	 1	 1.02	 2.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40236	 1	 1.22	 2.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40237	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40238	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40239	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40240	 1	 1.94	 3.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40241	 1	 0.62	 1.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40242	 1	 2.1	 4.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40243	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40244	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40245	 1	 3.42	 6.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40246	 1	 0.31	 0.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40247	 1	 1.33	 2.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40248	 1	 1.11	 2.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40249	 1	 2.56	 4.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40250	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40251	 1	 2.44	 4.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40252	 1	 2.04	 2.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40253	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40254	 1	 1.37	 3.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40255	 1	 0.96	 2.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40256	 1	 2.21	 3.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40257	 1	 0.72	 1.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40258	 1	 2.43	 5.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40259	 1	 0.95	 1.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40260	 1	 1.14	 2.57	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40261	 1	 2.65	 5.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40262	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40263	 1	 10.09	 13.66	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40264	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40265	 1	 2.78	 5.07	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40266	 1	 2.41	 3.73	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40267	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40268	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40269	 1	 5.74	 9.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40270	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40271	 1	 1.79	 2.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40272	 1	 1.19	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40273	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40274	 1	 3.37	 6.69	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40275	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40276	 1	 1.57	 2.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40277	 1	 1.2	 2.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40278	 1	 3.08	 4.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40279	 1	 5.37	 10.76	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40280	 1	 1.23	 2.35	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40281	 1	 2.31	 4.36	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40282	 1	 2.88	 5.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40283	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40284	 1	 3.52	 6.12	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40285	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40286	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40287	 1	 0.91	 1.64	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	40288	 1	 3.44	 6.81	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	40289	 1	 7.52	 14.2	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40290	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40291	 1	 3.59	 5.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40292	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40293	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40294	 1	 2.06	 3.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40295	 1	 4.24	 6.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40296	 1	 6.83	 10.89	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40297	 1	 0.82	 1.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40298	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40299	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40300	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40301	 1	 2.23	 3.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40302	 1	 6.04	 7.53	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40303	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40304	 1	 3.23	 5.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40305	 1	 1.69	 3.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40306	 1	 2.1	 3.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40307	 1	 1.35	 2.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40308	 1	 0.93	 1.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40309	 1	 2.69	 4.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40310	 1	 2.09	 4.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40311	 1	 2.21	 0.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40312	 1	 1.2	 0.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40313	 1	 0.75	 0.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40314	 1	 1.56	 0.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40315	 1	 1.44	 0.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40316	 1	 0.7	 0.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40317	 1	 1.01	 0.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40318	 1	 0.58	 0.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40319	 1	 1.04	 0.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40320	 1	 1.05	 0.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40321	 1	 1.22	 0.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40322	 1	 1.0	 0.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40323	 1	 1.21	 0.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40324	 1	 1.79	 0.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40325	 1	 1.64	 0.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40326	 1	 0.97	 0.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40327	 1	 1.91	 0.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40328	 1	 1.18	 0.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40329	 1	 0.9	 0.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40330	 1	 0.39	 0.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40331	 1	 1.71	 0.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40332	 1	 1.13	 0.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40333	 1	 1.5	 0.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40334	 1	 1.18	 0.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40335	 1	 1.22	 0.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40336	 1	 0.72	 0.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40337	 1	 0.74	 0.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40338	 1	 1.23	 0.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40339	 1	 0.63	 0.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40340	 1	 1.27	 0.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40341	 1	 0.65	 0.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40342	 1	 0.87	 0.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40343	 1	 1.51	 0.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40344	 1	 1.01	 0.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40345	 1	 0.62	 0.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40346	 1	 0.71	 0.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40347	 1	 0.27	 0.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40348	 1	 0.28	 0.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40349	 1	 0.93	 0.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40350	 1	 0.74	 0.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40351	 1	 1.07	 0.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40352	 1	 0.87	 0.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40353	 1	 2.0	 0.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40354	 1	 0.75	 0.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40355	 1	 1.84	 0.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40356	 1	 1.21	 0.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40357	 1	 1.43	 0.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40358	 1	 0.7	 0.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40359	 1	 0.87	 0.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40360	 1	 1.13	 0.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40361	 1	 0.36	 0.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40362	 1	 0.45	 0.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40363	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40364	 1	 1.33	 0.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40365	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40366	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40367	 1	 0.53	 0.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40368	 1	 0.53	 0.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40369	 1	 1.45	 0.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40370	 1	 0.45	 0.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40371	 1	 0.63	 0.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40372	 1	 0.39	 0.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40373	 1	 0.33	 0.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40374	 1	 0.45	 0.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40375	 1	 1.15	 0.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40376	 1	 0.7	 0.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40377	 1	 1.21	 0.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40378	 1	 1.58	 0.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40379	 1	 0.24	 0.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40380	 1	 0.41	 0.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40381	 1	 0.24	 0.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40382	 1	 0.7	 1.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40383	 1	 0.27	 0.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40384	 1	 0.32	 0.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40385	 1	 0.59	 0.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40386	 1	 1.66	 2.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40387	 1	 0.44	 0.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40388	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40389	 1	 0.55	 0.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40390	 1	 1.19	 0.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40391	 1	 0.48	 0.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40392	 1	 0.86	 0.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40393	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40394	 1	 0.28	 0.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40395	 1	 0.24	 0.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40396	 1	 0.64	 0.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40397	 1	 0.39	 0.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40398	 1	 0.32	 0.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40399	 1	 1.2	 1.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40400	 1	 0.77	 1.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40401	 1	 1.05	 1.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40402	 1	 0.68	 0.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40403	 1	 0.53	 0.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40404	 1	 0.8	 0.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40405	 1	 0.24	 0.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40406	 1	 0.3	 0.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40407	 1	 0.99	 1.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40408	 1	 0.92	 0.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40409	 1	 0.7	 1.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40410	 1	 0.85	 1.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40411	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40412	 1	 1.53	 2.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40413	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40414	 1	 1.51	 2.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40415	 1	 0.78	 1.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40416	 1	 0.69	 1.31	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40417	 1	 0.57	 1.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40418	 1	 0.95	 2.12	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40419	 1	 0.54	 0.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40420	 1	 0.29	 0.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40421	 1	 1.08	 1.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40422	 1	 0.9	 1.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40423	 1	 0.51	 0.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40424	 1	 1.19	 2.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40425	 1	 0.68	 1.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40426	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40427	 1	 0.89	 1.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40428	 1	 0.5	 1.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40429	 1	 1.1	 1.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40430	 1	 1.21	 1.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40431	 1	 1.04	 1.99	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40432	 1	 1.08	 1.97	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40433	 1	 0.4	 0.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40434	 1	 0.28	 0.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40435	 1	 0.48	 0.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40436	 1	 1.17	 2.52	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40437	 1	 0.6	 1.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40438	 1	 0.92	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40439	 1	 0.82	 1.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40440	 1	 1.45	 2.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40441	 1	 2.15	 4.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40442	 1	 0.69	 1.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40443	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40444	 1	 0.71	 1.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40445	 1	 2.52	 3.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40446	 1	 4.18	 6.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40447	 1	 3.16	 4.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40448	 1	 2.77	 4.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40449	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40450	 1	 1.24	 2.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40451	 1	 0.77	 1.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40452	 1	 4.18	 7.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40453	 1	 0.64	 1.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40454	 1	 0.73	 1.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40455	 1	 2.79	 5.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40456	 1	 0.45	 0.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40457	 1	 1.3	 2.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40458	 1	 2.09	 3.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40459	 1	 1.31	 2.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40460	 1	 1.42	 2.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40461	 1	 1.09	 2.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40462	 1	 1.08	 1.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40463	 1	 1.28	 2.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40464	 1	 2.67	 4.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40465	 1	 1.65	 2.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40466	 1	 1.24	 2.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40467	 1	 1.58	 2.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40468	 1	 0.92	 1.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40469	 1	 1.42	 2.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40470	 1	 0.96	 1.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40471	 1	 1.56	 0.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40472	 1	 2.39	 0.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40473	 1	 0.92	 0.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40474	 1	 1.64	 0.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40475	 1	 2.9	 0.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40476	 1	 1.35	 0.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40477	 1	 0.84	 0.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40478	 1	 1.09	 2.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40479	 1	 0.5	 1.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40480	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40481	 1	 2.01	 0.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40482	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40483	 1	 0.7	 1.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40484	 1	 1.13	 2.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40485	 1	 0.89	 1.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40486	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40487	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40488	 1	 2.32	 4.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40489	 1	 1.55	 2.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40490	 1	 1.14	 2.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40491	 1	 0.67	 1.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40492	 1	 0.63	 1.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40493	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40494	 1	 1.1	 2.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40495	 1	 1.17	 1.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40496	 1	 1.1	 2.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40497	 1	 0.61	 1.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40498	 1	 1.19	 2.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40499	 1	 1.0	 2.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40500	 1	 0.79	 1.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40501	 1	 0.56	 1.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40502	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40503	 1	 0.71	 1.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40504	 1	 0.88	 1.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40505	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40506	 1	 0.61	 1.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40507	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40508	 1	 0.65	 0.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40509	 1	 1.38	 2.87	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40510	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40511	 1	 0.54	 1.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40512	 1	 0.36	 0.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40513	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40514	 1	 0.86	 1.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40515	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40516	 1	 0.85	 1.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40517	 1	 0.67	 1.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40518	 1	 1.29	 2.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40519	 1	 1.11	 1.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40520	 1	 0.85	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40521	 1	 0.43	 0.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40522	 1	 0.51	 1.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40523	 1	 1.56	 2.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40524	 1	 0.29	 0.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40525	 1	 2.71	 5.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40526	 1	 0.7	 1.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40527	 1	 1.28	 2.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40528	 1	 0.61	 1.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40529	 1	 1.16	 2.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40530	 1	 1.12	 2.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40531	 1	 1.06	 2.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40532	 1	 1.0	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40533	 1	 0.78	 1.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40534	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40535	 1	 0.73	 1.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40536	 1	 0.96	 1.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40537	 1	 1.49	 2.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40538	 1	 0.95	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40539	 1	 1.94	 3.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40540	 1	 1.91	 3.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40541	 1	 1.15	 2.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40542	 1	 1.93	 3.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40543	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40544	 1	 1.24	 2.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40545	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	40546	 1	 0.46	 0.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40547	 1	 0.96	 1.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40548	 1	 1.08	 1.99	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40549	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40550	 1	 1.42	 2.09	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40551	 1	 0.83	 1.49	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40552	 1	 0.77	 1.7	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40553	 1	 1.01	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40554	 1	 0.8	 1.5	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40555	 1	 1.46	 2.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40556	 1	 0.46	 0.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40557	 1	 2.54	 4.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40558	 1	 0.36	 0.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40559	 1	 0.56	 1.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40560	 1	 0.74	 1.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40561	 1	 0.4	 0.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40562	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40563	 1	 0.74	 1.47	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40564	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40565	 1	 1.01	 2.14	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40566	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40567	 1	 0.54	 1.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40568	 1	 0.83	 1.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40569	 1	 0.72	 1.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40570	 1	 0.79	 1.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40571	 1	 0.78	 1.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40572	 1	 0.74	 1.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40573	 1	 0.88	 1.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40574	 1	 0.83	 1.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40575	 1	 0.33	 0.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40576	 1	 0.27	 0.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40577	 1	 0.41	 0.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40578	 1	 0.51	 0.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40579	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40580	 1	 0.28	 0.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40581	 1	 0.53	 0.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40582	 1	 0.24	 0.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40583	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40584	 1	 0.94	 1.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40585	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40586	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40587	 1	 0.23	 0.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40588	 1	 1.02	 2.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40589	 1	 0.31	 0.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40590	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40591	 1	 1.17	 2.21	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40592	 1	 0.48	 0.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40593	 1	 0.51	 0.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40594	 1	 0.88	 1.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40595	 1	 0.42	 0.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40596	 1	 0.43	 0.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40597	 1	 0.28	 0.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40598	 1	 0.78	 1.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40599	 1	 0.35	 0.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40600	 1	 0.63	 1.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40601	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40602	 1	 0.32	 0.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40603	 1	 1.46	 2.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40604	 1	 0.77	 1.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40605	 1	 0.72	 1.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40606	 1	 1.01	 1.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40607	 1	 0.73	 1.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40608	 1	 0.62	 1.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40609	 1	 0.82	 1.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40610	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40611	 1	 1.13	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40612	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40613	 1	 0.44	 0.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40614	 1	 0.46	 0.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40615	 1	 1.9	 2.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40616	 1	 0.89	 1.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40617	 1	 1.42	 2.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40618	 1	 0.77	 1.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40619	 1	 1.63	 2.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40620	 1	 0.76	 1.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40621	 1	 1.38	 2.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40622	 1	 1.47	 2.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40623	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40624	 1	 2.37	 4.38	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40625	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40626	 1	 1.21	 2.3	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40627	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40628	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40629	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40630	 1	 0.74	 1.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40631	 1	 0.81	 1.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40632	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40633	 1	 0.72	 1.48	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40634	 1	 0.95	 1.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40635	 1	 0.63	 1.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40636	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40637	 1	 1.93	 3.5	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40638	 1	 1.11	 2.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40639	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40640	 1	 0.23	 0.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40641	 1	 1.1	 2.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40642	 1	 0.51	 1.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40643	 1	 1.48	 2.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40644	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40645	 1	 1.31	 1.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40646	 1	 0.46	 0.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40647	 1	 1.2	 1.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40648	 1	 0.66	 0.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40649	 1	 0.55	 1.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40650	 1	 0.35	 0.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40651	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40652	 1	 0.39	 0.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40653	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40654	 1	 0.43	 0.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40655	 1	 0.3	 0.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40656	 1	 1.36	 1.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40657	 1	 1.16	 2.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40658	 1	 0.69	 1.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40659	 1	 0.33	 0.54	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40660	 1	 1.97	 3.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40661	 1	 2.52	 3.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40662	 1	 0.44	 0.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40663	 1	 0.16	 0.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40664	 1	 2.95	 5.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40665	 1	 1.31	 1.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40666	 1	 0.37	 0.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40667	 1	 0.46	 1.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40668	 1	 0.41	 0.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40669	 1	 1.18	 2.26	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40670	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40671	 1	 0.38	 0.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40672	 1	 0.21	 0.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40673	 1	 0.51	 1.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40674	 1	 0.48	 0.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40675	 1	 4.86	 7.41	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40676	 1	 1.27	 2.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40677	 1	 0.55	 1.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40678	 1	 0.89	 2.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40679	 1	 1.08	 1.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40680	 1	 0.93	 1.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40681	 1	 0.73	 1.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40682	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40683	 1	 0.86	 2.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40684	 1	 0.81	 1.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40685	 1	 0.69	 1.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40686	 1	 1.08	 2.15	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40687	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40688	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40689	 1	 0.29	 0.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40690	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40691	 1	 0.45	 0.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40692	 1	 0.36	 0.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40693	 1	 2.02	 3.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40694	 1	 0.85	 1.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40695	 1	 0.9	 1.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40696	 1	 0.96	 2.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40697	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40698	 1	 4.27	 7.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40699	 1	 2.08	 3.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40700	 1	 8.03	 14.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40701	 1	 0.78	 1.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40702	 1	 0.43	 0.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40703	 1	 0.55	 0.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40704	 1	 0.68	 1.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40705	 1	 0.21	 0.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40706	 1	 1.42	 2.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40707	 1	 0.53	 0.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40708	 1	 1.26	 2.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40709	 1	 0.46	 0.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40710	 1	 0.27	 0.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40711	 1	 0.11	 0.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40712	 1	 0.25	 0.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40713	 1	 0.71	 1.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40714	 1	 0.35	 0.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40715	 1	 0.23	 0.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40716	 1	 0.35	 0.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40717	 1	 0.37	 0.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40718	 1	 0.37	 0.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40719	 1	 1.26	 2.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40720	 1	 0.21	 0.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40721	 1	 0.3	 0.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40722	 1	 0.7	 1.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40723	 1	 0.22	 0.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40724	 1	 0.31	 0.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40725	 1	 0.47	 1.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40726	 1	 0.69	 1.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40727	 1	 0.4	 0.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40728	 1	 0.38	 0.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40729	 1	 1.34	 2.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40730	 1	 0.48	 0.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40731	 1	 0.56	 1.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40732	 1	 0.55	 1.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40733	 1	 0.78	 1.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40734	 1	 0.37	 0.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40735	 1	 0.25	 0.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40736	 1	 0.92	 1.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40737	 1	 0.46	 0.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40738	 1	 0.66	 1.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40739	 1	 0.68	 1.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40740	 1	 0.97	 2.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40741	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40742	 1	 0.46	 0.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40743	 1	 0.63	 1.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40744	 1	 1.05	 2.04	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40745	 1	 0.62	 1.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40746	 1	 0.43	 0.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40747	 1	 0.45	 0.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40748	 1	 0.64	 1.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40749	 1	 0.38	 0.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40750	 1	 1.07	 1.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40751	 1	 0.51	 0.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40752	 1	 0.24	 0.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40753	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40754	 1	 0.51	 1.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40755	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40756	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40757	 1	 0.53	 1.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40758	 1	 1.58	 3.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40759	 1	 0.29	 0.65	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40760	 1	 0.38	 0.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40761	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40762	 1	 0.47	 0.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40763	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40764	 1	 0.77	 1.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40765	 1	 0.84	 1.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40766	 1	 1.23	 2.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40767	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40768	 1	 1.25	 2.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40769	 1	 1.25	 2.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40770	 1	 0.77	 1.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40771	 1	 1.3	 2.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40772	 1	 0.65	 1.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40773	 1	 0.26	 0.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40774	 1	 0.31	 0.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40775	 1	 0.58	 1.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40776	 1	 0.74	 1.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40777	 1	 0.85	 1.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40778	 1	 0.44	 0.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40779	 1	 1.26	 2.13	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40780	 1	 0.72	 1.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40781	 1	 0.86	 1.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40782	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40783	 1	 0.36	 0.73	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40784	 1	 0.6	 1.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40785	 1	 1.01	 1.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40786	 1	 2.18	 3.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40787	 1	 0.6	 1.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40788	 1	 0.53	 0.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40789	 1	 0.28	 0.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40790	 1	 2.03	 4.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40791	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40792	 1	 0.35	 0.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40793	 1	 0.18	 0.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40794	 1	 1.51	 2.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40795	 1	 0.27	 0.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40796	 1	 0.53	 1.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40797	 1	 1.42	 2.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40798	 1	 0.87	 1.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40799	 1	 1.46	 2.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40800	 1	 1.14	 2.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40801	 1	 0.87	 1.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40802	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40803	 1	 0.62	 1.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40804	 1	 0.9	 1.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40805	 1	 2.74	 4.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40806	 1	 3.22	 4.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40807	 1	 0.89	 1.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40808	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40809	 1	 1.27	 2.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40810	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40811	 1	 2.01	 3.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40812	 1	 1.44	 3.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40813	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40814	 1	 1.15	 2.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40815	 1	 0.96	 2.05	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40816	 1	 1.42	 2.53	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40817	 1	 1.0	 1.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40818	 1	 0.98	 2.19	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40819	 1	 1.51	 3.08	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40820	 1	 1.55	 2.77	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40821	 1	 0.99	 2.41	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40822	 1	 1.33	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40823	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40824	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40825	 1	 2.56	 4.7	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40826	 1	 6.21	 10.06	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40827	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40828	 1	 2.61	 3.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40829	 1	 1.42	 2.58	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40830	 1	 0.72	 1.41	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40831	 1	 0.93	 1.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40832	 1	 0.7	 1.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40833	 1	 1.09	 2.09	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40834	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40835	 1	 0.9	 1.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40836	 1	 1.1	 2.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40837	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40838	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40839	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40840	 1	 2.54	 4.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40841	 1	 0.74	 1.35	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40842	 1	 0.62	 1.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40843	 1	 1.84	 3.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40844	 1	 1.48	 2.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40845	 1	 1.0	 1.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40846	 1	 1.72	 3.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40847	 1	 0.87	 2.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40848	 1	 1.11	 2.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40849	 1	 1.01	 2.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40850	 1	 1.09	 2.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40851	 1	 0.49	 0.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40852	 1	 0.88	 1.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40853	 1	 0.8	 1.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40854	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40855	 1	 1.43	 2.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40856	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40857	 1	 1.06	 1.5	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40858	 1	 0.63	 1.36	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40859	 1	 6.79	 9.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40860	 1	 0.44	 1.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40861	 1	 0.24	 0.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40862	 1	 0.9	 0.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40863	 1	 0.5	 0.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40864	 1	 0.68	 1.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40865	 1	 0.67	 1.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40866	 1	 0.9	 1.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40867	 1	 1.36	 2.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40868	 1	 0.39	 0.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40869	 1	 0.47	 0.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40870	 1	 0.39	 0.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40871	 1	 0.6	 1.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40872	 1	 0.26	 0.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40873	 1	 0.25	 0.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40874	 1	 0.84	 1.48	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40875	 1	 0.86	 1.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40876	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40877	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40878	 1	 1.06	 1.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40879	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40880	 1	 1.33	 2.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40881	 1	 1.21	 2.68	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40882	 1	 1.46	 3.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40883	 1	 1.28	 3.14	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40884	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40885	 1	 0.49	 0.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40886	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40887	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	40888	 1	 0.8	 1.49	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	40889	 1	 0.74	 1.41	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40890	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40891	 1	 0.29	 0.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40892	 1	 0.95	 1.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40893	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40894	 1	 1.0	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40895	 1	 1.0	 1.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40896	 1	 1.44	 3.25	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40897	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40898	 1	 0.85	 1.51	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40899	 1	 0.95	 2.31	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40900	 1	 1.02	 2.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40901	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40902	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40903	 1	 0.53	 1.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40904	 1	 1.2	 2.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40905	 1	 1.88	 3.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40906	 1	 1.89	 3.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40907	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40908	 1	 0.34	 0.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40909	 1	 0.3	 0.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40910	 1	 0.24	 0.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40911	 1	 0.33	 0.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40912	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40913	 1	 0.28	 0.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40914	 1	 0.35	 0.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40915	 1	 0.28	 0.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40916	 1	 0.41	 0.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40917	 1	 0.34	 0.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40918	 1	 0.21	 0.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40919	 1	 0.46	 0.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40920	 1	 0.35	 0.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40921	 1	 0.62	 1.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40922	 1	 0.49	 1.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40923	 1	 0.27	 0.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40924	 1	 0.3	 0.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40925	 1	 1.62	 2.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40926	 1	 0.25	 0.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40927	 1	 0.73	 1.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40928	 1	 1.43	 2.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40929	 1	 0.79	 1.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40930	 1	 1.35	 2.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40931	 1	 0.47	 1.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40932	 1	 0.57	 1.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40933	 1	 0.72	 1.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40934	 1	 0.38	 0.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40935	 1	 0.85	 1.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40936	 1	 0.34	 0.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40937	 1	 0.77	 1.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40938	 1	 0.43	 0.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40939	 1	 0.56	 1.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40940	 1	 2.16	 3.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40941	 1	 0.87	 1.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40942	 1	 0.94	 1.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40943	 1	 0.85	 1.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40944	 1	 1.68	 2.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40945	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40946	 1	 0.98	 2.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40947	 1	 1.58	 2.71	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40948	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40949	 1	 0.67	 1.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40950	 1	 1.3	 2.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40951	 1	 0.96	 1.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40952	 1	 0.44	 0.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40953	 1	 0.87	 1.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40954	 1	 1.16	 1.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40955	 1	 1.16	 2.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40956	 1	 1.34	 2.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40957	 1	 0.51	 1.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40958	 1	 0.61	 1.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40959	 1	 1.31	 2.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40960	 1	 2.21	 3.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40961	 1	 1.04	 1.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40962	 1	 0.74	 1.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40963	 1	 1.07	 2.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40964	 1	 1.05	 1.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40965	 1	 0.79	 1.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40966	 1	 0.57	 1.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40967	 1	 0.85	 1.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40968	 1	 1.43	 2.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40969	 1	 0.77	 1.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40970	 1	 0.39	 0.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40971	 1	 0.37	 0.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40972	 1	 0.71	 1.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40973	 1	 1.08	 2.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40974	 1	 0.42	 0.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40975	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40976	 1	 1.72	 2.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40977	 1	 0.37	 0.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40978	 1	 1.15	 2.21	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40979	 1	 1.01	 2.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40980	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40981	 1	 0.67	 1.15	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40982	 1	 0.91	 1.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40983	 1	 2.44	 4.73	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40984	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40985	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40986	 1	 0.71	 1.46	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40987	 1	 0.68	 1.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40988	 1	 1.26	 2.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40989	 1	 0.75	 1.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40990	 1	 1.8	 2.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40991	 1	 0.76	 1.71	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40992	 1	 1.29	 2.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40993	 1	 1.0	 1.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40994	 1	 1.07	 2.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40995	 1	 1.64	 3.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	40996	 1	 2.69	 4.65	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40997	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40998	 1	 15.45	 25.47	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	40999	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41000	 1	 4.6	 8.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41001	 1	 12.39	 17.06	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41002	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41003	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41004	 1	 1.65	 3.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41005	 1	 1.22	 2.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41006	 1	 0.41	 0.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41007	 1	 2.94	 0.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41008	 1	 0.63	 1.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41009	 1	 1.24	 2.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41010	 1	 1.42	 2.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41011	 1	 1.05	 0.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41012	 1	 1.42	 0.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41013	 1	 1.31	 2.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41014	 1	 1.59	 0.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41015	 1	 1.1	 0.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41016	 1	 1.55	 0.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41017	 1	 1.74	 0.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41018	 1	 1.76	 0.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41019	 1	 1.01	 0.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41020	 1	 3.03	 0.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41021	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41022	 1	 5.83	 10.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41023	 1	 1.8	 0.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41024	 1	 2.3	 0.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41025	 1	 2.93	 4.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41026	 1	 6.11	 1.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41027	 1	 0.77	 0.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41028	 1	 2.73	 0.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41029	 1	 2.21	 0.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41030	 1	 2.9	 0.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41031	 1	 1.87	 0.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41032	 1	 1.41	 0.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41033	 1	 1.08	 1.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41034	 1	 2.4	 4.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41035	 1	 1.9	 0.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41036	 1	 2.49	 0.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41037	 1	 3.02	 0.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41038	 1	 4.29	 1.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41039	 1	 0.43	 0.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41040	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41041	 1	 1.16	 2.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41042	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41043	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41044	 1	 0.73	 1.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41045	 1	 3.72	 5.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41046	 1	 0.44	 0.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41047	 1	 2.03	 4.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41048	 1	 1.67	 3.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41049	 1	 0.4	 0.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41050	 1	 3.06	 5.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41051	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41052	 1	 0.96	 2.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41053	 1	 3.63	 6.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41054	 1	 1.99	 3.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41055	 1	 3.85	 5.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41056	 1	 0.9	 1.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41057	 1	 1.9	 3.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41058	 1	 0.99	 0.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41059	 1	 1.84	 3.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41060	 1	 1.45	 0.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41061	 1	 0.59	 1.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41062	 1	 0.76	 1.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41063	 1	 0.66	 1.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41064	 1	 1.87	 3.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41065	 1	 0.72	 1.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41066	 1	 1.06	 2.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41067	 1	 1.89	 3.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41068	 1	 3.25	 6.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41069	 1	 2.34	 3.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41070	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41071	 1	 1.06	 2.19	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41072	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41073	 1	 2.51	 4.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41074	 1	 0.88	 2.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41075	 1	 3.43	 6.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41076	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41077	 1	 1.05	 2.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41078	 1	 0.61	 1.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41079	 1	 1.74	 3.01	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41080	 1	 2.35	 3.63	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41081	 1	 5.14	 7.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41082	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41083	 1	 0.7	 1.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41084	 1	 1.23	 2.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41085	 1	 2.08	 3.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41086	 1	 1.12	 2.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41087	 1	 1.93	 3.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41088	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41089	 1	 1.33	 2.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41090	 1	 0.57	 1.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41091	 1	 2.99	 6.09	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41092	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41093	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41094	 1	 1.21	 2.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41095	 1	 2.25	 4.4	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41096	 1	 2.79	 5.08	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41097	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41098	 1	 1.48	 3.37	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41099	 1	 1.38	 3.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41100	 1	 1.28	 2.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41101	 1	 1.61	 2.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41102	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41103	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41104	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41105	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41106	 1	 0.57	 1.13	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41107	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41108	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41109	 1	 0.41	 0.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41110	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41111	 1	 2.56	 4.56	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41112	 1	 1.66	 2.8	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41113	 1	 1.16	 2.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41114	 1	 1.56	 2.79	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41115	 1	 0.5	 1.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41116	 1	 0.8	 1.59	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41117	 1	 2.07	 3.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41118	 1	 0.78	 1.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41119	 1	 0.46	 0.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41120	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41121	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41122	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41123	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41124	 1	 0.87	 1.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41125	 1	 0.69	 1.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41126	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41127	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41128	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41129	 1	 1.74	 3.32	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41130	 1	 1.79	 3.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41131	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41132	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41133	 1	 0.43	 1.03	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41134	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41135	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41136	 1	 2.36	 4.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41137	 1	 1.52	 2.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41138	 1	 0.96	 2.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41139	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41140	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41141	 1	 2.09	 3.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41142	 1	 4.21	 7.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41143	 1	 1.32	 2.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41144	 1	 1.62	 2.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41145	 1	 1.2	 2.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41146	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41147	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41148	 1	 1.07	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41149	 1	 1.17	 0.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41150	 1	 0.98	 1.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41151	 1	 0.85	 1.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41152	 1	 0.85	 1.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41153	 1	 1.1	 2.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41154	 1	 0.9	 1.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41155	 1	 0.73	 1.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41156	 1	 1.47	 2.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41157	 1	 1.0	 2.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41158	 1	 0.49	 1.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41159	 1	 0.45	 0.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41160	 1	 1.23	 2.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41161	 1	 1.95	 2.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41162	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41163	 1	 1.25	 2.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41164	 1	 1.79	 3.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41165	 1	 1.71	 3.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41166	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41167	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41168	 1	 1.25	 2.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41169	 1	 2.06	 3.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41170	 1	 1.75	 2.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41171	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41172	 1	 1.52	 2.61	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41173	 1	 0.56	 1.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41174	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41175	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41176	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41177	 1	 1.24	 0.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41178	 1	 2.4	 0.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41179	 1	 0.69	 0.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41180	 1	 1.16	 0.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41181	 1	 1.44	 0.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41182	 1	 1.33	 0.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41183	 1	 1.27	 0.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41184	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41185	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41186	 1	 1.09	 1.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41187	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41188	 1	 2.29	 0.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41189	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41190	 1	 1.83	 0.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41191	 1	 1.24	 0.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41192	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41193	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41194	 1	 2.97	 0.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41195	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41196	 1	 0.82	 0.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41197	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41198	 1	 1.37	 0.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41199	 1	 1.43	 0.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41200	 1	 2.69	 0.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41201	 1	 2.06	 0.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41202	 1	 1.0	 0.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41203	 1	 1.71	 0.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41204	 1	 1.06	 0.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41205	 1	 1.75	 0.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41206	 1	 1.95	 0.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41207	 1	 1.8	 0.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41208	 1	 2.05	 0.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41209	 1	 1.14	 0.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41210	 1	 2.38	 0.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41211	 1	 0.47	 0.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41212	 1	 0.75	 0.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41213	 1	 2.0	 0.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41214	 1	 0.81	 0.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41215	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41216	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41217	 1	 0.56	 0.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41218	 1	 1.05	 2.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41219	 1	 1.42	 2.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41220	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41221	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41222	 1	 0.84	 1.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41223	 1	 0.97	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41224	 1	 0.95	 1.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41225	 1	 1.88	 3.13	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41226	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41227	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41228	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41229	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41230	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	41231	 1	 1.76	 3.45	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41232	 1	 1.78	 3.45	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41233	 1	 9.19	 12.71	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41234	 1	 8.86	 15.1	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41235	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41236	 1	 3.16	 5.28	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41237	 1	 5.32	 7.67	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41238	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41239	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41240	 1	 1.01	 1.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41241	 1	 1.62	 3.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41242	 1	 1.36	 2.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41243	 1	 1.39	 2.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41244	 1	 1.11	 2.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41245	 1	 2.76	 4.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41246	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41247	 1	 1.27	 2.03	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41248	 1	 0.66	 1.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41249	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41250	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41251	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41252	 1	 1.04	 2.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41253	 1	 1.05	 2.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41254	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41255	 1	 1.97	 2.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41256	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41257	 1	 1.61	 3.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41258	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41259	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41260	 1	 0.9	 1.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41261	 1	 1.83	 2.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41262	 1	 1.34	 2.37	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41263	 1	 1.4	 2.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41264	 1	 1.36	 2.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41265	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41266	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41267	 1	 1.65	 2.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41268	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41269	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41270	 1	 1.18	 2.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41271	 1	 1.46	 2.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41272	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41273	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41274	 1	 1.19	 2.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41275	 1	 0.82	 1.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41276	 1	 1.48	 2.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41277	 1	 1.48	 2.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41278	 1	 2.31	 4.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41279	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41280	 1	 1.33	 2.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41281	 1	 0.71	 1.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41282	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41283	 1	 0.27	 0.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41284	 1	 1.75	 3.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41285	 1	 1.27	 2.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41286	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41287	 1	 1.46	 2.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41288	 1	 3.68	 6.65	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41289	 1	 1.14	 2.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41290	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41291	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41292	 1	 1.31	 2.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41293	 1	 1.0	 1.93	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41294	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41295	 1	 1.93	 3.9	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41296	 1	 4.67	 6.38	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41297	 1	 0.87	 1.88	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41298	 1	 4.27	 5.73	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41299	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41300	 1	 1.0	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41301	 1	 1.11	 1.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41302	 1	 1.25	 2.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41303	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41304	 1	 1.03	 1.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41305	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41306	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41307	 1	 0.4	 0.88	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41308	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41309	 1	 6.18	 9.49	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41310	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41311	 1	 0.97	 1.84	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41312	 1	 1.77	 3.39	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41313	 1	 3.62	 5.8	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41314	 1	 0.69	 1.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41315	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41316	 1	 1.11	 2.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41317	 1	 0.88	 1.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41318	 1	 1.21	 2.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41319	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41320	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41321	 1	 1.08	 2.42	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41322	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41323	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41324	 1	 1.14	 2.6	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41325	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41326	 1	 0.52	 1.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41327	 1	 0.58	 1.19	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41328	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41329	 1	 4.02	 6.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41330	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41331	 1	 1.58	 2.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41332	 1	 2.86	 5.75	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41333	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41334	 1	 1.88	 2.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41335	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	41336	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41337	 1	 5.25	 8.36	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	41338	 1	 0.93	 1.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41339	 1	 1.49	 3.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41340	 1	 2.17	 3.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41341	 1	 1.02	 1.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41342	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41343	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41344	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41345	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41346	 1	 0.96	 2.24	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	41347	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	41348	 1	 0.82	 1.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41349	 1	 1.35	 2.43	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41350	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41351	 1	 1.04	 2.23	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41352	 1	 0.89	 1.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41353	 1	 0.82	 1.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41354	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41355	 1	 2.0	 3.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41356	 1	 1.77	 3.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41357	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41358	 1	 1.1	 2.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41359	 1	 0.91	 1.96	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41360	 1	 1.06	 2.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41361	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41362	 1	 0.67	 1.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41363	 1	 0.72	 1.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41364	 1	 1.14	 2.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41365	 1	 1.23	 2.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41366	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41367	 1	 0.77	 1.71	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41368	 1	 2.05	 3.6	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41369	 1	 0.72	 1.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41370	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41371	 1	 0.77	 1.7	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41372	 1	 0.62	 1.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41373	 1	 0.51	 0.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41374	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41375	 1	 1.93	 3.39	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41376	 1	 0.76	 1.6	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41377	 1	 1.34	 2.27	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41378	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41379	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41380	 1	 1.11	 2.4	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41381	 1	 2.16	 4.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41382	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41383	 1	 0.95	 1.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41384	 1	 1.65	 2.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41385	 1	 2.01	 3.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41386	 1	 0.68	 1.53	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41387	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41388	 1	 1.24	 2.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41389	 1	 6.78	 9.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41390	 1	 0.69	 1.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41391	 1	 2.14	 4.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41392	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	41393	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41394	 1	 0.57	 1.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41395	 1	 1.44	 2.57	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41396	 1	 0.86	 1.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41397	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41398	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41399	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41400	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41401	 1	 5.57	 9.42	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41402	 1	 1.05	 2.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41403	 1	 1.38	 2.78	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41404	 1	 2.77	 5.16	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41405	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41406	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41407	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	41408	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41409	 1	 1.02	 1.79	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41410	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41411	 1	 2.1	 4.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41412	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41413	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41414	 1	 0.67	 1.25	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41415	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41416	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41417	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41418	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41419	 1	 1.28	 2.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41420	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41421	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41422	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41423	 1	 1.65	 3.2	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41424	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41425	 1	 1.6	 2.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41426	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41427	 1	 2.07	 3.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41428	 1	 0.68	 1.53	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41429	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41430	 1	 1.47	 2.84	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41431	 1	 1.77	 3.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41432	 1	 0.89	 1.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41433	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41434	 1	 2.66	 4.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41435	 1	 1.05	 2.1	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41436	 1	 1.68	 2.84	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41437	 1	 1.46	 2.48	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41438	 1	 0.95	 2.29	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41439	 1	 3.62	 6.51	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41440	 1	 3.11	 4.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41441	 1	 7.28	 9.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41442	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41443	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41444	 1	 1.38	 2.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41445	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41446	 1	 1.42	 3.02	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41447	 1	 1.05	 1.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41448	 1	 1.13	 2.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41449	 1	 1.13	 2.25	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41450	 1	 0.91	 1.64	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41451	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41452	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41453	 1	 2.3	 4.81	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41454	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41455	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41456	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41457	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41458	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41459	 1	 0.28	 0.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41460	 1	 0.85	 1.98	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41461	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41462	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41463	 1	 2.64	 3.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41464	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41465	 1	 16.03	 18.29	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41466	 1	 2.66	 5.14	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41467	 1	 0.59	 1.31	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41468	 1	 1.95	 4.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41469	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41470	 1	 0.65	 1.18	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41471	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41472	 1	 1.82	 3.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41473	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41474	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41475	 1	 1.13	 2.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41476	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41477	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41478	 1	 4.98	 7.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41479	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41480	 1	 2.37	 4.03	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41481	 1	 1.52	 3.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41482	 1	 1.28	 2.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41483	 1	 1.34	 3.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41484	 1	 1.64	 3.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41485	 1	 0.72	 1.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41486	 1	 0.97	 2.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41487	 1	 3.23	 5.72	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41488	 1	 7.64	 12.71	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41489	 1	 0.85	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41490	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41491	 1	 2.48	 4.53	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41492	 1	 5.58	 8.53	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41493	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41494	 1	 1.53	 3.37	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41495	 1	 0.68	 1.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41496	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41497	 1	 0.24	 0.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41498	 1	 0.85	 1.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41499	 1	 3.66	 6.05	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41500	 1	 1.21	 1.94	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41501	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41502	 1	 2.02	 4.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41503	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41504	 1	 1.21	 2.82	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41505	 1	 0.43	 0.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41506	 1	 1.56	 3.53	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41507	 1	 2.1	 4.82	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41508	 1	 1.96	 3.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41509	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41510	 1	 1.08	 2.62	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41511	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41512	 1	 0.57	 1.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41513	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41514	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41515	 1	 1.55	 3.36	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41516	 1	 0.76	 1.63	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41517	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41518	 1	 2.48	 0.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41519	 1	 1.59	 0.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41520	 1	 1.17	 0.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41521	 1	 2.72	 4.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41522	 1	 0.78	 1.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41523	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41524	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41525	 1	 1.32	 2.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41526	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41527	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41528	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41529	 1	 1.26	 2.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41530	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41531	 1	 1.05	 0.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41532	 1	 0.31	 0.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41533	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41534	 1	 0.54	 1.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41535	 1	 3.68	 3.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41536	 1	 1.24	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41537	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41538	 1	 3.89	 6.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41539	 1	 0.38	 0.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41540	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41541	 1	 2.98	 5.34	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41542	 1	 2.1	 3.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41543	 1	 0.98	 1.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41544	 1	 0.72	 1.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41545	 1	 1.48	 2.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41546	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41547	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41548	 1	 0.48	 0.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41549	 1	 0.91	 1.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41550	 1	 0.57	 1.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41551	 1	 0.53	 1.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41552	 1	 0.52	 1.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41553	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41554	 1	 1.59	 2.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41555	 1	 1.92	 3.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41556	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41557	 1	 0.6	 1.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41558	 1	 0.53	 0.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41559	 1	 0.27	 0.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41560	 1	 1.1	 1.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41561	 1	 0.37	 0.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41562	 1	 0.46	 0.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41563	 1	 1.38	 2.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41564	 1	 0.22	 0.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41565	 1	 1.28	 2.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41566	 1	 0.26	 0.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41567	 1	 1.84	 2.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41568	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41569	 1	 0.75	 1.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41570	 1	 0.66	 1.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41571	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41572	 1	 3.44	 5.58	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41573	 1	 0.71	 1.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41574	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41575	 1	 2.83	 5.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41576	 1	 0.77	 1.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41577	 1	 1.75	 2.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41578	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41579	 1	 0.7	 1.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41580	 1	 0.4	 0.83	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41581	 1	 0.83	 1.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41582	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	41583	 1	 2.36	 4.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41584	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41585	 1	 0.86	 1.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41586	 1	 0.84	 1.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41587	 1	 0.33	 0.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41588	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41589	 1	 0.47	 1.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41590	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41591	 1	 0.68	 1.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41592	 1	 0.76	 1.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41593	 1	 1.98	 2.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41594	 1	 1.16	 1.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41595	 1	 2.78	 3.7	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41596	 1	 1.83	 3.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41597	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41598	 1	 2.66	 3.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41599	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41600	 1	 0.94	 1.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41601	 1	 3.13	 5.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41602	 1	 0.31	 0.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41603	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41604	 1	 0.2	 0.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41605	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41606	 1	 0.61	 1.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41607	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41608	 1	 1.39	 2.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41609	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41610	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41611	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41612	 1	 1.9	 3.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41613	 1	 1.52	 2.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41614	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41615	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41616	 1	 4.15	 6.02	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41617	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41618	 1	 0.45	 0.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41619	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41620	 1	 1.88	 3.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41621	 1	 0.9	 1.44	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41622	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41623	 1	 0.64	 1.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41624	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41625	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41626	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41627	 1	 11.11	 18.65	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41628	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41629	 1	 1.65	 0.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41630	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41631	 1	 1.44	 0.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41632	 1	 3.2	 0.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41633	 1	 12.43	 16.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41634	 1	 1.52	 0.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41635	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41636	 1	 3.06	 5.2	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41637	 1	 2.74	 4.68	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41638	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41639	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41640	 1	 3.25	 5.78	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41641	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41642	 1	 2.53	 4.63	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41643	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41644	 1	 2.58	 3.23	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41645	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41646	 1	 1.61	 3.56	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41647	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41648	 1	 1.54	 2.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41649	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41650	 1	 3.76	 6.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41651	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41652	 1	 3.37	 5.05	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	41653	 1	 2.85	 4.38	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41654	 1	 4.63	 7.56	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41655	 1	 0.84	 1.41	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41656	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41657	 1	 1.82	 3.64	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41658	 1	 1.32	 2.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41659	 1	 3.44	 7.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41660	 1	 6.25	 12.46	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41661	 1	 3.19	 5.09	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41662	 1	 1.85	 2.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41663	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41664	 1	 2.97	 4.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41665	 1	 3.75	 6.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41666	 1	 2.59	 4.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41667	 1	 5.33	 7.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41668	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41669	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	41670	 1	 13.12	 21.41	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41671	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41672	 1	 1.33	 2.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41673	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41674	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41675	 1	 1.06	 2.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41676	 1	 0.99	 1.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41677	 1	 1.35	 2.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41678	 1	 1.36	 2.48	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41679	 1	 0.86	 1.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41680	 1	 1.14	 1.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41681	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41682	 1	 2.26	 3.39	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41683	 1	 2.81	 4.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41684	 1	 2.19	 4.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41685	 1	 7.66	 10.12	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41686	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41687	 1	 0.89	 1.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41688	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41689	 1	 2.36	 3.81	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41690	 1	 1.45	 2.97	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41691	 1	 0.93	 1.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41692	 1	 0.89	 1.93	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41693	 1	 0.76	 1.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41694	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41695	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41696	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41697	 1	 3.33	 6.06	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41698	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41699	 1	 0.68	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41700	 1	 1.18	 2.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41701	 1	 0.74	 1.59	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41702	 1	 0.66	 1.51	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41703	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41704	 1	 4.83	 7.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41705	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41706	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41707	 1	 1.43	 2.57	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41708	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41709	 1	 8.8	 10.57	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41710	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41711	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41712	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41713	 1	 2.33	 4.1	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41714	 1	 0.92	 1.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41715	 1	 11.95	 19.79	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41716	 1	 1.11	 2.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41717	 1	 1.25	 2.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41718	 1	 0.75	 1.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41719	 1	 1.11	 2.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41720	 1	 0.53	 1.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41721	 1	 0.46	 1.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41722	 1	 0.43	 0.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41723	 1	 0.8	 1.79	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41724	 1	 0.52	 1.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41725	 1	 0.49	 0.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41726	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41727	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41728	 1	 1.15	 2.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41729	 1	 1.35	 2.92	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41730	 1	 1.64	 3.18	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41731	 1	 0.61	 1.21	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41732	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41733	 1	 0.83	 1.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41734	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41735	 1	 0.78	 1.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41736	 1	 0.98	 1.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41737	 1	 1.75	 3.13	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41738	 1	 0.35	 0.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41739	 1	 0.91	 2.09	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41740	 1	 2.16	 4.55	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41741	 1	 6.16	 7.92	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41742	 1	 1.57	 2.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41743	 1	 0.81	 1.71	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41744	 1	 1.06	 2.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41745	 1	 0.87	 1.73	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41746	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41747	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41748	 1	 1.32	 2.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41749	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41750	 1	 1.07	 2.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41751	 1	 1.14	 2.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41752	 1	 1.35	 2.33	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41753	 1	 1.4	 2.5	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41754	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41755	 1	 0.74	 1.73	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41756	 1	 2.82	 4.2	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41757	 1	 0.99	 1.72	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41758	 1	 0.97	 1.73	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41759	 1	 0.95	 1.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41760	 1	 0.69	 1.31	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41761	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41762	 1	 1.62	 2.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41763	 1	 0.54	 1.13	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41764	 1	 0.63	 1.37	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41765	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41766	 1	 0.5	 1.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41767	 1	 1.55	 2.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41768	 1	 2.74	 5.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41769	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41770	 1	 1.13	 2.33	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41771	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41772	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41773	 1	 0.52	 1.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41774	 1	 0.6	 1.46	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41775	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41776	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41777	 1	 0.58	 1.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41778	 1	 0.76	 1.8	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41779	 1	 0.76	 1.51	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41780	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41781	 1	 1.72	 2.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41782	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41783	 1	 0.81	 1.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41784	 1	 2.06	 3.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41785	 1	 0.52	 1.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41786	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41787	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41788	 1	 1.16	 2.27	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41789	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41790	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41791	 1	 1.43	 2.22	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41792	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41793	 1	 3.59	 5.17	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41794	 1	 0.68	 1.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41795	 1	 1.88	 2.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41796	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41797	 1	 1.08	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41798	 1	 3.6	 5.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41799	 1	 2.37	 3.68	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41800	 1	 2.08	 3.85	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41801	 1	 1.32	 2.39	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41802	 1	 1.03	 1.83	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41803	 1	 1.67	 3.28	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41804	 1	 1.09	 2.71	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41805	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41806	 1	 2.07	 4.14	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41807	 1	 0.67	 1.53	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41808	 1	 0.7	 1.45	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41809	 1	 1.04	 2.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41810	 1	 0.77	 1.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41811	 1	 0.72	 1.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41812	 1	 0.83	 1.83	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41813	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41814	 1	 0.69	 1.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41815	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41816	 1	 1.3	 2.88	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41817	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41818	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	41819	 1	 1.78	 3.73	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41820	 1	 1.27	 2.22	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41821	 1	 1.15	 2.29	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41822	 1	 1.23	 2.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41823	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41824	 1	 0.76	 1.56	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41825	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41826	 1	 1.18	 2.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41827	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41828	 1	 1.0	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41829	 1	 0.85	 1.75	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41830	 1	 0.67	 1.52	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41831	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41832	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41833	 1	 2.67	 5.02	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41834	 1	 1.74	 3.51	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41835	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41836	 1	 1.01	 2.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41837	 1	 1.74	 3.6	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41838	 1	 1.7	 3.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41839	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41840	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41841	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41842	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41843	 1	 0.63	 1.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41844	 1	 1.08	 2.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41845	 1	 1.42	 3.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41846	 1	 1.33	 2.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41847	 1	 0.94	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41848	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41849	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41850	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41851	 1	 0.84	 1.64	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41852	 1	 0.87	 1.79	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	41853	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41854	 1	 0.87	 1.63	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41855	 1	 0.96	 2.22	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41856	 1	 0.87	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41857	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41858	 1	 1.54	 3.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41859	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41860	 1	 1.31	 2.84	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41861	 1	 3.48	 4.26	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41862	 1	 1.46	 2.7	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41863	 1	 3.08	 4.48	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41864	 1	 2.4	 4.3	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41865	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41866	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41867	 1	 3.49	 5.19	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41868	 1	 4.96	 8.15	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41869	 1	 1.52	 2.91	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41870	 1	 1.18	 2.53	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41871	 1	 0.87	 1.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41872	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41873	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41874	 1	 2.99	 6.1	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41875	 1	 0.67	 1.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41876	 1	 3.89	 6.81	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41877	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41878	 1	 0.7	 1.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41879	 1	 0.58	 1.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41880	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41881	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41882	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41883	 1	 0.94	 1.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41884	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41885	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41886	 1	 3.45	 6.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41887	 1	 4.3	 7.57	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41888	 1	 8.74	 11.32	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41889	 1	 2.58	 4.24	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41890	 1	 1.3	 2.39	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41891	 1	 5.63	 9.67	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41892	 1	 2.31	 3.72	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41893	 1	 3.32	 5.94	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41894	 1	 2.07	 3.68	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41895	 1	 2.25	 3.99	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41896	 1	 1.95	 3.88	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41897	 1	 2.25	 4.71	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41898	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41899	 1	 2.89	 5.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41900	 1	 9.19	 17.42	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41901	 1	 6.01	 10.34	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41902	 1	 0.63	 1.39	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41903	 1	 2.63	 5.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41904	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41905	 1	 2.51	 4.29	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41906	 1	 2.35	 4.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41907	 1	 3.88	 6.84	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41908	 1	 4.6	 6.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41909	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41910	 1	 3.1	 6.24	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41911	 1	 4.79	 7.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41912	 1	 5.28	 8.92	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41913	 1	 1.01	 2.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41914	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41915	 1	 0.96	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41916	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	41917	 1	 2.41	 4.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41918	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41919	 1	 0.96	 1.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41920	 1	 0.76	 1.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41921	 1	 1.74	 2.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41922	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41923	 1	 1.39	 2.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41924	 1	 2.3	 4.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41925	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41926	 1	 2.81	 4.61	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41927	 1	 1.63	 2.64	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41928	 1	 1.05	 2.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41929	 1	 1.22	 2.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41930	 1	 2.23	 3.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41931	 1	 1.16	 1.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41932	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41933	 1	 1.23	 2.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41934	 1	 2.7	 4.01	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41935	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41936	 1	 1.77	 2.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41937	 1	 2.09	 3.72	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41938	 1	 3.26	 6.43	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41939	 1	 3.43	 6.84	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41940	 1	 0.49	 0.88	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41941	 1	 0.57	 1.04	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41942	 1	 1.78	 2.65	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41943	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	41944	 1	 5.51	 9.2	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41945	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	41946	 1	 3.04	 6.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41947	 1	 12.23	 19.03	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	41948	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41949	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41950	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41951	 1	 5.97	 10.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41952	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41953	 1	 0.95	 2.25	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41954	 1	 2.78	 4.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41955	 1	 1.1	 2.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41956	 1	 2.51	 4.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41957	 1	 1.97	 3.56	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41958	 1	 1.53	 3.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41959	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41960	 1	 3.01	 5.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41961	 1	 1.18	 2.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41962	 1	 1.17	 2.19	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41963	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41964	 1	 1.72	 3.41	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41965	 1	 1.86	 3.56	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41966	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41967	 1	 4.0	 6.72	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41968	 1	 3.27	 6.7	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41969	 1	 2.03	 4.29	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41970	 1	 3.61	 7.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41971	 1	 3.97	 7.59	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41972	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41973	 1	 5.73	 10.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41974	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41975	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41976	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41977	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41978	 1	 2.16	 3.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41979	 1	 1.87	 3.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41980	 1	 5.72	 8.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41981	 1	 4.87	 9.67	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41982	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41983	 1	 2.77	 5.38	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41984	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41985	 1	 4.76	 8.82	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41986	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41987	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41988	 1	 3.58	 6.97	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41989	 1	 4.33	 7.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41990	 1	 2.92	 4.95	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41991	 1	 1.75	 3.3	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41992	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41993	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41994	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41995	 1	 2.35	 5.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	41996	 1	 1.88	 3.74	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41997	 1	 3.35	 5.61	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41998	 1	 2.54	 4.45	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41999	 1	 2.11	 4.88	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42000	 1	 1.99	 3.39	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42001	 1	 1.54	 2.93	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42002	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42003	 1	 0.78	 1.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42004	 1	 1.72	 3.89	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42005	 1	 2.15	 4.25	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42006	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42007	 1	 6.53	 12.85	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42008	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42009	 1	 0.53	 1.08	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42010	 1	 2.69	 4.48	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42011	 1	 2.14	 4.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42012	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42013	 1	 2.06	 4.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42014	 1	 1.12	 2.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42015	 1	 0.76	 1.73	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42016	 1	 0.65	 1.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42017	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42018	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42019	 1	 3.62	 6.32	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42020	 1	 0.66	 1.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42021	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42022	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42023	 1	 1.07	 1.89	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42024	 1	 0.43	 0.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42025	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42026	 1	 6.25	 10.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42027	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42028	 1	 1.04	 2.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42029	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42030	 1	 3.45	 6.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42031	 1	 0.99	 1.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42032	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42033	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42034	 1	 1.1	 2.17	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42035	 1	 1.67	 3.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42036	 1	 1.53	 2.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42037	 1	 1.76	 3.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42038	 1	 1.82	 3.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42039	 1	 0.7	 1.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42040	 1	 1.2	 2.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42041	 1	 5.19	 5.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42042	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42043	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42044	 1	 2.3	 3.9	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42045	 1	 10.37	 13.3	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42046	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42047	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42048	 1	 0.39	 0.79	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42049	 1	 2.41	 4.5	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42050	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42051	 1	 1.23	 2.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42052	 1	 0.65	 1.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42053	 1	 0.77	 1.7	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42054	 1	 0.85	 1.91	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42055	 1	 1.29	 2.43	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42056	 1	 1.37	 2.01	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42057	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42058	 1	 6.29	 8.74	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42059	 1	 2.42	 4.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42060	 1	 2.8	 5.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42061	 1	 2.19	 3.66	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42062	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42063	 1	 0.94	 1.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42064	 1	 3.3	 4.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42065	 1	 2.31	 3.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42066	 1	 12.79	 17.87	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42067	 1	 2.57	 4.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42068	 1	 1.4	 3.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42069	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42070	 1	 1.39	 3.09	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42071	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42072	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42073	 1	 1.89	 4.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42074	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42075	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42076	 1	 11.14	 15.63	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42077	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42078	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42079	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42080	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42081	 1	 2.64	 5.04	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42082	 1	 2.03	 3.92	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42083	 1	 0.52	 1.19	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42084	 1	 1.96	 3.61	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42085	 1	 3.52	 4.8	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42086	 1	 2.55	 3.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42087	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42088	 1	 6.02	 6.48	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42089	 1	 1.64	 3.57	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42090	 1	 2.84	 4.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42091	 1	 1.61	 2.29	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42092	 1	 1.64	 3.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42093	 1	 0.81	 1.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42094	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42095	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42096	 1	 0.67	 1.17	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42097	 1	 1.79	 3.04	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42098	 1	 2.13	 3.44	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42099	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42100	 1	 2.01	 3.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42101	 1	 1.58	 3.79	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42102	 1	 1.11	 2.15	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42103	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42104	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42105	 1	 1.3	 2.45	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42106	 1	 1.04	 2.32	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42107	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42108	 1	 1.27	 2.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42109	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42110	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42111	 1	 3.27	 6.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42112	 1	 1.9	 4.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42113	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42114	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42115	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42116	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42117	 1	 1.96	 3.57	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42118	 1	 1.49	 3.01	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42119	 1	 5.29	 9.04	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42120	 1	 2.56	 5.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42121	 1	 3.3	 5.68	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42122	 1	 1.29	 2.58	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42123	 1	 0.93	 2.4	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42124	 1	 3.92	 5.71	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42125	 1	 0.94	 2.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42126	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42127	 1	 2.29	 4.59	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42128	 1	 3.88	 6.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42129	 1	 0.77	 1.5	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42130	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42131	 1	 0.33	 0.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42132	 1	 0.44	 1.02	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42133	 1	 0.69	 1.36	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42134	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42135	 1	 2.11	 3.7	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42136	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42137	 1	 0.62	 1.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42138	 1	 0.84	 1.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42139	 1	 1.75	 3.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42140	 1	 1.88	 3.61	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42141	 1	 1.36	 2.7	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42142	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42143	 1	 0.85	 2.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42144	 1	 13.01	 16.04	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42145	 1	 7.96	 14.53	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42146	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42147	 1	 3.75	 6.58	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42148	 1	 0.75	 1.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42149	 1	 0.5	 1.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42150	 1	 2.41	 4.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42151	 1	 1.04	 2.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42152	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42153	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42154	 1	 5.24	 8.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42155	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42156	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42157	 1	 3.03	 5.21	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42158	 1	 1.88	 3.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42159	 1	 2.03	 4.37	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42160	 1	 1.75	 3.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42161	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42162	 1	 0.37	 0.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42163	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42164	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42165	 1	 0.97	 2.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42166	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42167	 1	 1.04	 1.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42168	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42169	 1	 2.36	 4.49	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42170	 1	 2.01	 3.98	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42171	 1	 2.27	 3.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42172	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42173	 1	 0.6	 0.17	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42174	 1	 0.87	 0.24	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42175	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42176	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42177	 1	 0.56	 0.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42178	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42179	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42180	 1	 1.39	 0.37	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42181	 1	 0.4	 0.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42182	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42183	 1	 0.97	 0.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42184	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42185	 1	 0.52	 0.14	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42186	 1	 3.04	 0.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42187	 1	 2.34	 0.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42188	 1	 4.09	 1.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42189	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42190	 1	 1.12	 0.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42191	 1	 2.43	 0.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42192	 1	 0.75	 0.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42193	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42194	 1	 1.01	 0.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42195	 1	 1.46	 0.39	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42196	 1	 2.8	 0.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42197	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42198	 1	 0.63	 0.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42199	 1	 0.64	 0.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42200	 1	 2.04	 0.54	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42201	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42202	 1	 0.73	 0.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42203	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42204	 1	 1.92	 0.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42205	 1	 1.15	 0.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42206	 1	 0.89	 0.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42207	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42208	 1	 0.63	 0.16	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42209	 1	 2.91	 0.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42210	 1	 1.08	 0.29	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42211	 1	 1.23	 0.33	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42212	 1	 5.34	 1.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42213	 1	 0.65	 0.18	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42214	 1	 1.16	 0.31	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42215	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42216	 1	 2.82	 0.75	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42217	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42218	 1	 1.26	 0.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42219	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42220	 1	 1.24	 0.33	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42221	 1	 0.86	 0.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42222	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42223	 1	 1.28	 0.34	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42224	 1	 0.6	 0.17	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42225	 1	 0.84	 0.22	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42226	 1	 0.92	 0.25	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42227	 1	 1.47	 0.39	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42228	 1	 2.57	 0.7	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42229	 1	 0.83	 0.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42230	 1	 0.81	 0.22	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42231	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42232	 1	 1.29	 0.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42233	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42234	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42235	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42236	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42237	 1	 0.86	 0.23	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42238	 1	 1.57	 0.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42239	 1	 1.7	 0.46	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42240	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42241	 1	 2.12	 0.57	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42242	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42243	 1	 0.93	 0.25	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42244	 1	 1.51	 0.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42245	 1	 6.29	 1.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42246	 1	 0.79	 0.21	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42247	 1	 7.28	 1.94	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42248	 1	 2.92	 0.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42249	 1	 0.76	 0.2	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42250	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42251	 1	 2.66	 0.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42252	 1	 4.32	 1.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42253	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42254	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42255	 1	 3.35	 0.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42256	 1	 1.87	 0.49	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42257	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42258	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42259	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42260	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42261	 1	 2.13	 0.57	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42262	 1	 1.5	 0.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42263	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42264	 1	 1.29	 0.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42265	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42266	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42267	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42268	 1	 1.25	 0.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42269	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42270	 1	 1.22	 0.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42271	 1	 0.98	 0.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42272	 1	 1.13	 1.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42273	 1	 1.14	 2.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42274	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42275	 1	 2.62	 4.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42276	 1	 0.9	 2.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42277	 1	 0.66	 1.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42278	 1	 1.19	 1.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42279	 1	 1.4	 2.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42280	 1	 3.73	 6.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42281	 1	 1.31	 0.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42282	 1	 2.39	 4.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42283	 1	 1.59	 3.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42284	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42285	 1	 3.32	 5.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42286	 1	 1.02	 2.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42287	 1	 1.0	 2.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42288	 1	 0.79	 1.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42289	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42290	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42291	 1	 1.12	 0.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42292	 1	 1.33	 0.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42293	 1	 3.06	 0.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42294	 1	 0.8	 0.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42295	 1	 0.6	 0.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42296	 1	 0.94	 0.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42297	 1	 0.57	 0.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42298	 1	 1.33	 0.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42299	 1	 1.35	 0.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42300	 1	 2.56	 0.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42301	 1	 4.69	 1.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42302	 1	 1.03	 0.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42303	 1	 1.34	 0.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42304	 1	 0.77	 0.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42305	 1	 0.92	 0.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42306	 1	 1.01	 0.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42307	 1	 1.8	 0.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42308	 1	 2.12	 0.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42309	 1	 0.88	 0.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42310	 1	 2.0	 0.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42311	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42312	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42313	 1	 0.69	 0.18	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42314	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42315	 1	 0.88	 0.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42316	 1	 0.41	 0.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42317	 1	 1.32	 0.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42318	 1	 1.66	 0.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42319	 1	 1.79	 0.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42320	 1	 0.77	 0.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42321	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42322	 1	 1.03	 0.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42323	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42324	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42325	 1	 2.01	 3.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42326	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42327	 1	 4.26	 8.2	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42328	 1	 4.53	 8.79	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42329	 1	 10.93	 18.55	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42330	 1	 13.17	 19.92	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42331	 1	 11.6	 19.45	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42332	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42333	 1	 1.91	 3.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42334	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42335	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42336	 1	 1.38	 2.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42337	 1	 0.62	 1.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42338	 1	 2.37	 4.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42339	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42340	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42341	 1	 0.93	 1.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42342	 1	 2.45	 4.93	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42343	 1	 2.02	 3.29	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42344	 1	 1.61	 3.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42345	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42346	 1	 3.05	 5.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42347	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42348	 1	 3.25	 6.57	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42349	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42350	 1	 1.3	 2.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42351	 1	 1.76	 3.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42352	 1	 2.66	 0.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42353	 1	 2.43	 0.58	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42354	 1	 2.4	 0.57	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42355	 1	 0.83	 0.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42356	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42357	 1	 3.19	 6.59	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42358	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42359	 1	 4.31	 7.12	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42360	 1	 2.39	 4.82	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42361	 1	 2.88	 5.88	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42362	 1	 3.13	 4.77	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42363	 1	 4.4	 5.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42364	 1	 6.01	 11.81	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42365	 1	 4.4	 8.95	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42366	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42367	 1	 8.88	 16.68	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42368	 1	 6.46	 12.61	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42369	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42370	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42371	 1	 2.98	 5.55	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42372	 1	 2.58	 4.76	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42373	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42374	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42375	 1	 4.51	 7.17	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42376	 1	 6.19	 9.82	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42377	 1	 3.28	 6.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42378	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42379	 1	 4.71	 8.82	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42380	 1	 2.79	 4.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42381	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42382	 1	 5.41	 9.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42383	 1	 4.0	 7.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42384	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42385	 1	 3.13	 5.84	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42386	 1	 0.82	 1.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42387	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42388	 1	 2.12	 3.23	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42389	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42390	 1	 2.42	 4.43	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42391	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42392	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42393	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42394	 1	 5.29	 8.59	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42395	 1	 4.94	 1.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42396	 1	 4.63	 8.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42397	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42398	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42399	 1	 2.27	 3.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42400	 1	 1.77	 3.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42401	 1	 2.54	 4.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42402	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42403	 1	 3.64	 7.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42404	 1	 1.61	 3.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42405	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42406	 1	 1.62	 3.29	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42407	 1	 1.99	 0.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42408	 1	 0.66	 0.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42409	 1	 5.88	 11.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42410	 1	 3.44	 5.09	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42411	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42412	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42413	 1	 1.65	 3.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42414	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42415	 1	 0.83	 1.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42416	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42417	 1	 3.43	 6.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42418	 1	 1.62	 2.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42419	 1	 2.27	 4.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42420	 1	 5.7	 8.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42421	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42422	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42423	 1	 0.95	 1.99	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42424	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42425	 1	 0.9	 2.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42426	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42427	 1	 0.88	 2.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42428	 1	 1.35	 3.21	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42429	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42430	 1	 1.01	 2.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42431	 1	 3.29	 6.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42432	 1	 1.3	 2.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42433	 1	 0.87	 1.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42434	 1	 1.01	 2.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42435	 1	 2.86	 4.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42436	 1	 1.42	 2.26	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42437	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42438	 1	 5.38	 6.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42439	 1	 1.59	 2.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42440	 1	 1.04	 1.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42441	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42442	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42443	 1	 1.76	 2.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42444	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42445	 1	 2.95	 3.55	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42446	 1	 2.1	 4.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42447	 1	 2.64	 5.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42448	 1	 2.64	 4.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42449	 1	 1.94	 3.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42450	 1	 0.91	 1.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42451	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42452	 1	 1.2	 2.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42453	 1	 0.46	 0.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42454	 1	 0.5	 1.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42455	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42456	 1	 0.98	 2.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42457	 1	 2.82	 4.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42458	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42459	 1	 0.97	 2.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42460	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42461	 1	 1.57	 2.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42462	 1	 0.4	 0.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42463	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42464	 1	 0.45	 0.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42465	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42466	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42467	 1	 1.41	 2.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42468	 1	 0.51	 1.12	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42469	 1	 1.76	 3.43	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42470	 1	 1.43	 2.64	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42471	 1	 2.07	 3.62	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42472	 1	 1.63	 2.82	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42473	 1	 0.83	 1.63	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42474	 1	 1.74	 3.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42475	 1	 6.14	 11.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42476	 1	 2.11	 3.3	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42477	 1	 2.41	 5.07	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42478	 1	 5.97	 11.06	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42479	 1	 2.73	 4.59	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42480	 1	 3.12	 6.07	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42481	 1	 2.0	 3.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42482	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42483	 1	 5.61	 9.13	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42484	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42485	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42486	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42487	 1	 0.89	 2.09	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42488	 1	 2.24	 4.43	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42489	 1	 0.32	 0.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42490	 1	 1.05	 2.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42491	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42492	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42493	 1	 2.14	 3.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42494	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42495	 1	 1.79	 3.01	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42496	 1	 0.39	 0.85	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42497	 1	 0.73	 1.63	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42498	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42499	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42500	 1	 1.67	 3.03	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42501	 1	 0.48	 1.13	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42502	 1	 1.6	 2.52	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42503	 1	 0.55	 1.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42504	 1	 3.89	 7.85	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42505	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42506	 1	 3.32	 5.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42507	 1	 1.74	 2.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42508	 1	 0.65	 1.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42509	 1	 1.45	 2.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42510	 1	 3.5	 5.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42511	 1	 1.12	 2.61	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42512	 1	 2.04	 3.36	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42513	 1	 1.3	 2.68	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42514	 1	 6.86	 11.09	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42515	 1	 3.19	 5.76	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42516	 1	 0.98	 2.5	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42517	 1	 3.46	 6.75	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42518	 1	 1.96	 4.45	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42519	 1	 3.01	 5.16	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42520	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42521	 1	 2.25	 3.68	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42522	 1	 2.32	 4.12	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42523	 1	 2.22	 3.82	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42524	 1	 2.48	 4.99	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42525	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42526	 1	 1.51	 3.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42527	 1	 4.67	 9.15	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42528	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42529	 1	 0.61	 1.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42530	 1	 1.51	 3.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42531	 1	 0.78	 1.81	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42532	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42533	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42534	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42535	 1	 1.45	 3.21	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42536	 1	 12.3	 23.1	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42537	 1	 3.68	 7.29	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42538	 1	 3.56	 6.93	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42539	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42540	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42541	 1	 7.53	 13.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42542	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42543	 1	 1.46	 3.09	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42544	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42545	 1	 11.76	 20.03	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42546	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42547	 1	 9.18	 16.14	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42548	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42549	 1	 1.13	 2.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42550	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42551	 1	 1.77	 2.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42552	 1	 1.29	 2.88	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42553	 1	 0.52	 1.3	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42554	 1	 1.63	 3.64	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42555	 1	 2.75	 5.26	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42556	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42557	 1	 0.25	 0.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42558	 1	 1.63	 3.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42559	 1	 2.54	 4.49	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42560	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42561	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42562	 1	 1.76	 3.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42563	 1	 0.64	 1.38	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42564	 1	 1.24	 2.24	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42565	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42566	 1	 1.9	 4.1	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42567	 1	 0.88	 1.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42568	 1	 0.92	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42569	 1	 1.56	 3.09	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42570	 1	 0.99	 2.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42571	 1	 1.1	 1.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42572	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42573	 1	 1.67	 3.6	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42574	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42575	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42576	 1	 1.28	 2.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42577	 1	 1.61	 3.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42578	 1	 1.7	 3.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42579	 1	 0.87	 1.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42580	 1	 1.61	 2.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42581	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42582	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42583	 1	 1.58	 2.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42584	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42585	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42586	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42587	 1	 0.32	 0.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42588	 1	 2.94	 5.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42589	 1	 2.32	 3.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42590	 1	 4.27	 7.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42591	 1	 2.14	 4.46	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42592	 1	 2.19	 3.89	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42593	 1	 12.22	 16.84	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42594	 1	 13.66	 22.6	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42595	 1	 1.75	 3.89	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42596	 1	 10.33	 20.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42597	 1	 3.49	 5.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42598	 1	 2.46	 3.82	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42599	 1	 1.33	 2.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42600	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42601	 1	 2.4	 4.98	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42602	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42603	 1	 0.94	 2.04	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42604	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42605	 1	 1.47	 2.47	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42606	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42607	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42608	 1	 7.03	 11.39	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42609	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42610	 1	 2.04	 3.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42611	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42612	 1	 2.34	 4.39	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42613	 1	 1.66	 2.66	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42614	 1	 6.45	 12.1	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42615	 1	 1.56	 2.98	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42616	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42617	 1	 2.43	 4.18	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42618	 1	 8.05	 13.84	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42619	 1	 1.62	 3.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42620	 1	 0.96	 1.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42621	 1	 2.13	 3.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42622	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42623	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42624	 1	 1.7	 3.34	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42625	 1	 0.85	 1.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42626	 1	 2.7	 5.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42627	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42628	 1	 4.38	 8.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42629	 1	 2.84	 4.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42630	 1	 3.58	 6.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42631	 1	 2.7	 5.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42632	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42633	 1	 1.71	 3.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42634	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42635	 1	 2.93	 4.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42636	 1	 2.16	 3.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42637	 1	 4.25	 6.94	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42638	 1	 3.89	 6.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42639	 1	 3.03	 5.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42640	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42641	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42642	 1	 2.53	 4.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42643	 1	 8.09	 14.38	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42644	 1	 2.39	 0.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42645	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42646	 1	 2.75	 0.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42647	 1	 1.17	 0.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42648	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42649	 1	 6.19	 10.8	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42650	 1	 1.62	 3.29	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42651	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42652	 1	 4.54	 7.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42653	 1	 4.48	 8.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42654	 1	 3.87	 7.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42655	 1	 2.2	 3.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42656	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42657	 1	 1.68	 3.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42658	 1	 2.8	 4.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42659	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42660	 1	 9.71	 18.52	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42661	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42662	 1	 1.77	 3.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42663	 1	 2.13	 4.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42664	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42665	 1	 3.75	 7.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42666	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42667	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42668	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42669	 1	 0.35	 0.74	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42670	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42671	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42672	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42673	 1	 5.55	 7.94	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42674	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42675	 1	 1.3	 2.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42676	 1	 3.55	 6.46	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42677	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42678	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42679	 1	 0.46	 0.97	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42680	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42681	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42682	 1	 0.95	 1.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42683	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42684	 1	 1.22	 2.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42685	 1	 0.7	 1.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42686	 1	 1.26	 1.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42687	 1	 0.82	 2.07	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42688	 1	 0.76	 1.93	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42689	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42690	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42691	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42692	 1	 1.11	 2.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42693	 1	 1.62	 3.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42694	 1	 1.9	 3.84	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42695	 1	 1.25	 2.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42696	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42697	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42698	 1	 1.36	 2.44	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42699	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42700	 1	 3.07	 6.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42701	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42702	 1	 4.48	 7.16	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42703	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42704	 1	 2.38	 5.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42705	 1	 3.89	 6.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42706	 1	 1.01	 2.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42707	 1	 0.45	 0.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42708	 1	 1.04	 1.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42709	 1	 2.12	 3.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42710	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42711	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42712	 1	 0.82	 1.99	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42713	 1	 14.11	 22.05	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42714	 1	 1.16	 2.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42715	 1	 0.88	 1.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42716	 1	 0.61	 1.28	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42717	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42718	 1	 3.32	 6.39	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42719	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42720	 1	 1.92	 3.79	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42721	 1	 0.95	 2.13	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42722	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42723	 1	 5.29	 9.76	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42724	 1	 3.96	 6.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42725	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42726	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42727	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42728	 1	 2.75	 4.92	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42729	 1	 4.66	 7.41	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42730	 1	 1.98	 3.86	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42731	 1	 0.42	 0.93	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42732	 1	 0.48	 0.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42733	 1	 2.5	 5.04	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42734	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42735	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42736	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42737	 1	 1.89	 3.63	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42738	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42739	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42740	 1	 5.43	 9.17	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42741	 1	 2.27	 4.31	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42742	 1	 0.73	 1.68	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42743	 1	 2.91	 4.54	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42744	 1	 2.58	 4.51	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42745	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42746	 1	 1.29	 2.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42747	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42748	 1	 1.38	 2.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42749	 1	 1.13	 1.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42750	 1	 2.04	 3.56	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42751	 1	 14.19	 21.79	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42752	 1	 3.12	 5.07	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42753	 1	 5.14	 10.59	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42754	 1	 7.98	 15.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42755	 1	 4.17	 7.62	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42756	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42757	 1	 1.11	 2.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42758	 1	 1.21	 2.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42759	 1	 1.48	 2.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42760	 1	 1.44	 2.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42761	 1	 1.82	 3.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42762	 1	 1.1	 2.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42763	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42764	 1	 1.25	 2.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42765	 1	 0.59	 1.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42766	 1	 1.29	 2.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42767	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42768	 1	 1.66	 2.46	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42769	 1	 0.82	 1.58	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42770	 1	 0.65	 1.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42771	 1	 1.06	 2.49	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42772	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42773	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42774	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42775	 1	 0.91	 1.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42776	 1	 1.28	 2.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42777	 1	 0.49	 1.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42778	 1	 2.73	 5.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42779	 1	 1.1	 2.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42780	 1	 0.54	 0.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42781	 1	 2.72	 5.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42782	 1	 3.02	 5.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42783	 1	 0.9	 2.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42784	 1	 3.42	 6.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42785	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42786	 1	 3.48	 6.2	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42787	 1	 3.9	 6.99	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42788	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42789	 1	 1.21	 1.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42790	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42791	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42792	 1	 0.46	 1.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42793	 1	 1.98	 3.53	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42794	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42795	 1	 2.16	 3.78	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42796	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42797	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42798	 1	 0.31	 0.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42799	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42800	 1	 2.62	 4.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42801	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42802	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42803	 1	 0.45	 1.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42804	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42805	 1	 3.7	 6.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42806	 1	 1.55	 2.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42807	 1	 6.19	 8.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42808	 1	 0.4	 0.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42809	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42810	 1	 0.56	 1.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42811	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42812	 1	 2.5	 4.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42813	 1	 1.14	 2.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42814	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42815	 1	 0.31	 0.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42816	 1	 1.18	 2.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42817	 1	 0.78	 1.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42818	 1	 6.39	 12.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42819	 1	 2.83	 5.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42820	 1	 3.1	 5.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42821	 1	 0.79	 1.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42822	 1	 1.7	 3.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42823	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42824	 1	 1.71	 3.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42825	 1	 1.61	 3.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42826	 1	 0.97	 2.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42827	 1	 1.43	 2.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42828	 1	 1.38	 2.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42829	 1	 2.35	 4.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42830	 1	 0.9	 2.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42831	 1	 0.65	 1.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42832	 1	 1.19	 2.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42833	 1	 1.36	 2.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42834	 1	 1.7	 3.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42835	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42836	 1	 1.32	 2.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42837	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42838	 1	 1.1	 2.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42839	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42840	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42841	 1	 7.39	 12.92	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42842	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42843	 1	 4.63	 8.37	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42844	 1	 0.87	 1.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42845	 1	 1.28	 2.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42846	 1	 0.71	 1.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42847	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42848	 1	 0.88	 1.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42849	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42850	 1	 4.29	 7.31	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42851	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42852	 1	 1.03	 2.25	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42853	 1	 1.26	 2.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42854	 1	 1.21	 2.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42855	 1	 1.08	 2.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42856	 1	 2.01	 2.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42857	 1	 2.04	 3.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42858	 1	 0.45	 1.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42859	 1	 2.24	 4.56	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42860	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42861	 1	 0.74	 1.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42862	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42863	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42864	 1	 0.8	 1.94	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42865	 1	 2.15	 3.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42866	 1	 1.17	 2.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42867	 1	 0.56	 1.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42868	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42869	 1	 1.1	 1.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42870	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42871	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42872	 1	 0.36	 0.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42873	 1	 0.23	 0.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42874	 1	 0.86	 1.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42875	 1	 0.82	 1.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42876	 1	 0.6	 1.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42877	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42878	 1	 1.16	 1.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42879	 1	 0.64	 1.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42880	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42881	 1	 0.38	 0.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42882	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42883	 1	 0.72	 1.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42884	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42885	 1	 1.6	 3.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42886	 1	 0.71	 1.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42887	 1	 1.27	 2.28	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42888	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42889	 1	 1.66	 3.62	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42890	 1	 0.51	 1.19	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42891	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42892	 1	 0.68	 1.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42893	 1	 1.09	 2.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42894	 1	 1.79	 3.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42895	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42896	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42897	 1	 0.83	 1.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42898	 1	 1.51	 3.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42899	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42900	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42901	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42902	 1	 6.35	 9.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42903	 1	 1.43	 2.97	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42904	 1	 1.21	 2.83	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42905	 1	 3.44	 5.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42906	 1	 0.96	 1.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42907	 1	 3.16	 5.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42908	 1	 1.74	 3.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42909	 1	 2.65	 5.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42910	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42911	 1	 1.17	 2.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42912	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42913	 1	 2.51	 4.98	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42914	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42915	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42916	 1	 2.35	 4.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42917	 1	 1.89	 3.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42918	 1	 2.45	 4.51	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42919	 1	 2.16	 4.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42920	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42921	 1	 2.01	 3.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42922	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42923	 1	 4.1	 6.17	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42924	 1	 4.07	 7.82	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42925	 1	 5.33	 8.76	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42926	 1	 2.29	 3.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42927	 1	 2.01	 3.64	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42928	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42929	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42930	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42931	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42932	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42933	 1	 3.83	 6.5	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42934	 1	 1.07	 2.43	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42935	 1	 1.02	 2.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42936	 1	 2.23	 4.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42937	 1	 3.24	 4.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42938	 1	 2.5	 3.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42939	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42940	 1	 1.05	 2.14	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42941	 1	 2.14	 4.48	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42942	 1	 2.67	 5.03	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42943	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42944	 1	 1.41	 2.64	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42945	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42946	 1	 2.29	 4.38	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42947	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42948	 1	 1.69	 3.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42949	 1	 2.26	 4.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42950	 1	 1.1	 2.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42951	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42952	 1	 0.8	 1.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42953	 1	 0.92	 2.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42954	 1	 3.4	 4.94	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42955	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42956	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	42957	 1	 0.87	 1.77	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42958	 1	 1.69	 4.03	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42959	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42960	 1	 7.07	 11.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42961	 1	 7.88	 13.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42962	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	42963	 1	 3.2	 4.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42964	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42965	 1	 0.81	 1.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42966	 1	 2.21	 3.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42967	 1	 1.9	 3.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42968	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42969	 1	 1.34	 2.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42970	 1	 2.32	 3.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42971	 1	 0.71	 1.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42972	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42973	 1	 1.13	 2.55	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42974	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42975	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42976	 1	 0.86	 1.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42977	 1	 9.03	 11.97	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42978	 1	 2.49	 3.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42979	 1	 1.3	 2.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42980	 1	 0.68	 1.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42981	 1	 0.78	 1.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42982	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42983	 1	 1.22	 2.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42984	 1	 1.66	 3.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42985	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42986	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42987	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42988	 1	 1.09	 1.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42989	 1	 4.97	 8.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	42990	 1	 1.49	 3.41	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42991	 1	 5.93	 10.41	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42992	 1	 1.27	 2.63	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42993	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42994	 1	 6.95	 9.79	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42995	 1	 3.4	 6.5	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42996	 1	 1.41	 2.43	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42997	 1	 10.18	 14.5	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42998	 1	 1.8	 3.4	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42999	 1	 1.13	 0.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43000	 1	 0.86	 0.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43001	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43002	 1	 1.72	 3.5	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43003	 1	 3.81	 5.52	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43004	 1	 4.32	 6.3	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43005	 1	 3.2	 4.96	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43006	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43007	 1	 3.72	 7.43	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43008	 1	 3.51	 6.98	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43009	 1	 2.78	 5.14	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43010	 1	 3.96	 5.74	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43011	 1	 2.3	 3.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43012	 1	 3.34	 6.44	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43013	 1	 1.54	 2.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43014	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43015	 1	 3.1	 5.14	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43016	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43017	 1	 1.26	 2.51	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43018	 1	 3.16	 4.95	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43019	 1	 2.73	 3.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43020	 1	 4.04	 6.64	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43021	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43022	 1	 3.44	 7.11	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	43023	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43024	 1	 1.42	 2.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43025	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43026	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43027	 1	 1.81	 2.52	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43028	 1	 5.56	 10.09	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43029	 1	 3.13	 5.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43030	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43031	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43032	 1	 0.81	 1.72	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43033	 1	 0.74	 1.72	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43034	 1	 1.62	 3.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43035	 1	 2.35	 4.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43036	 1	 2.25	 3.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43037	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43038	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43039	 1	 1.58	 3.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43040	 1	 0.77	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43041	 1	 1.09	 2.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43042	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43043	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43044	 1	 0.49	 1.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43045	 1	 0.85	 1.84	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43046	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43047	 1	 0.61	 1.28	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43048	 1	 0.53	 1.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43049	 1	 0.68	 1.4	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43050	 1	 1.0	 2.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43051	 1	 0.74	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43052	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43053	 1	 5.25	 8.66	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43054	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43055	 1	 1.16	 2.16	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43056	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43057	 1	 1.4	 2.81	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43058	 1	 0.92	 2.12	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43059	 1	 0.96	 2.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43060	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43061	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43062	 1	 1.92	 4.57	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43063	 1	 1.04	 2.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43064	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43065	 1	 3.15	 5.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43066	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43067	 1	 3.92	 7.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43068	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43069	 1	 0.87	 2.15	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43070	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43071	 1	 2.1	 3.81	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43072	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43073	 1	 0.91	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43074	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43075	 1	 0.53	 1.2	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43076	 1	 0.61	 1.16	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43077	 1	 1.37	 3.25	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43078	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43079	 1	 1.78	 3.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43080	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	43081	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43082	 1	 0.75	 1.5	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43083	 1	 1.39	 3.3	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43084	 1	 1.72	 4.18	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43085	 1	 1.67	 3.22	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43086	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43087	 1	 0.74	 1.6	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43088	 1	 1.61	 2.61	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43089	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43090	 1	 0.59	 1.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43091	 1	 0.62	 1.32	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43092	 1	 1.57	 3.34	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43093	 1	 0.9	 2.18	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43094	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43095	 1	 0.45	 0.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43096	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43097	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43098	 1	 0.64	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43099	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43100	 1	 0.74	 1.3	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43101	 1	 1.05	 2.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43102	 1	 1.88	 3.75	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43103	 1	 2.13	 4.19	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43104	 1	 0.78	 1.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43105	 1	 0.93	 2.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43106	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43107	 1	 2.39	 3.61	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43108	 1	 1.11	 2.15	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43109	 1	 1.06	 1.83	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43110	 1	 1.3	 2.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43111	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43112	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43113	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43114	 1	 1.11	 2.34	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43115	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43116	 1	 0.37	 0.79	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43117	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43118	 1	 0.67	 1.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43119	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43120	 1	 1.02	 2.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43121	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43122	 1	 1.99	 4.01	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43123	 1	 0.59	 1.41	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43124	 1	 4.28	 7.1	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	43125	 1	 1.85	 2.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43126	 1	 1.01	 1.78	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43127	 1	 0.73	 1.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43128	 1	 0.53	 1.14	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	43129	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43130	 1	 0.92	 1.7	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43131	 1	 0.65	 1.41	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43132	 1	 1.28	 2.51	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43133	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43134	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43135	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43136	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43137	 1	 0.82	 2.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43138	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43139	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43140	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43141	 1	 12.76	 18.26	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43142	 1	 0.95	 2.1	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43143	 1	 1.63	 3.9	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43144	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43145	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43146	 1	 0.81	 1.87	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43147	 1	 1.34	 2.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43148	 1	 1.68	 2.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43149	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43150	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43151	 1	 3.13	 6.02	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43152	 1	 1.79	 2.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43153	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43154	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43155	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43156	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43157	 1	 2.96	 6.26	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43158	 1	 2.08	 4.51	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43159	 1	 1.36	 2.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43160	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43161	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43162	 1	 1.07	 2.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43163	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43164	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43165	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43166	 1	 0.92	 2.06	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43167	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43168	 1	 11.7	 19.52	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43169	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43170	 1	 0.53	 1.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43171	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43172	 1	 1.0	 1.64	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43173	 1	 0.44	 1.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43174	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43175	 1	 0.58	 1.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43176	 1	 0.33	 0.79	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43177	 1	 2.71	 4.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43178	 1	 0.75	 1.89	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43179	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43180	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43181	 1	 1.13	 2.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43182	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43183	 1	 0.78	 1.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43184	 1	 1.03	 1.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43185	 1	 0.28	 0.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43186	 1	 2.04	 3.5	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43187	 1	 5.91	 8.22	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43188	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43189	 1	 1.76	 2.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43190	 1	 1.81	 3.64	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43191	 1	 1.1	 2.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43192	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43193	 1	 0.7	 1.38	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43194	 1	 1.35	 2.54	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43195	 1	 1.82	 3.91	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43196	 1	 1.08	 2.38	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43197	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	43198	 1	 2.73	 4.94	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43199	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43200	 1	 3.47	 6.09	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43201	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43202	 1	 1.46	 2.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43203	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43204	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43205	 1	 6.83	 12.67	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43206	 1	 1.19	 2.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43207	 1	 0.73	 1.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43208	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43209	 1	 1.21	 2.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43210	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43211	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43212	 1	 0.62	 1.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43213	 1	 0.66	 1.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43214	 1	 0.93	 1.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43215	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43216	 1	 1.16	 2.44	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43217	 1	 1.56	 3.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43218	 1	 0.91	 1.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43219	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43220	 1	 1.79	 2.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43221	 1	 0.56	 1.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43222	 1	 1.34	 2.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43223	 1	 2.06	 3.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43224	 1	 1.55	 2.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43225	 1	 1.53	 3.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43226	 1	 0.85	 1.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43227	 1	 1.27	 2.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43228	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43229	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43230	 1	 0.89	 1.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43231	 1	 1.34	 2.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43232	 1	 0.95	 2.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43233	 1	 1.77	 3.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43234	 1	 1.12	 2.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43235	 1	 0.63	 1.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43236	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43237	 1	 1.04	 2.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43238	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43239	 1	 9.07	 13.39	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43240	 1	 4.21	 5.88	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43241	 1	 0.88	 1.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43242	 1	 0.85	 1.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43243	 1	 0.62	 1.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43244	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43245	 1	 1.97	 3.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43246	 1	 0.61	 1.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43247	 1	 2.97	 3.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43248	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43249	 1	 0.46	 0.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43250	 1	 2.85	 5.64	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43251	 1	 0.72	 1.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43252	 1	 1.94	 3.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43253	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43254	 1	 0.99	 1.72	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43255	 1	 3.16	 5.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43256	 1	 0.95	 1.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43257	 1	 0.53	 1.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43258	 1	 0.97	 2.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43259	 1	 0.62	 1.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43260	 1	 4.92	 7.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43261	 1	 2.58	 4.16	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43262	 1	 1.3	 1.93	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43263	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43264	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43265	 1	 0.44	 1.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43266	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43267	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43268	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43269	 1	 1.2	 2.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43270	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43271	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43272	 1	 1.8	 3.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43273	 1	 1.06	 1.9	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43274	 1	 1.24	 2.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43275	 1	 2.19	 3.59	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43276	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43277	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43278	 1	 0.79	 1.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43279	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43280	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43281	 1	 8.94	 12.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43282	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43283	 1	 1.41	 2.42	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43284	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	43285	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	43286	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43287	 1	 1.85	 3.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43288	 1	 1.82	 3.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43289	 1	 3.21	 5.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43290	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43291	 1	 2.92	 5.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43292	 1	 1.31	 2.91	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43293	 1	 0.43	 1.05	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43294	 1	 2.79	 4.93	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43295	 1	 0.42	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43296	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43297	 1	 0.8	 1.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43298	 1	 1.33	 2.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43299	 1	 3.71	 5.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43300	 1	 0.41	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43301	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43302	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43303	 1	 0.35	 0.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43304	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43305	 1	 2.95	 3.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43306	 1	 0.39	 1.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43307	 1	 0.75	 1.77	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43308	 1	 1.9	 2.6	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43309	 1	 0.36	 0.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43310	 1	 0.62	 1.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43311	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43312	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43313	 1	 0.61	 1.14	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43314	 1	 1.44	 3.21	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43315	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43316	 1	 1.2	 1.53	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43317	 1	 1.9	 3.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43318	 1	 0.75	 1.91	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43319	 1	 0.57	 1.38	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43320	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43321	 1	 0.94	 1.04	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43322	 1	 0.54	 1.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43323	 1	 4.51	 6.54	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43324	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43325	 1	 0.61	 1.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43326	 1	 0.43	 0.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43327	 1	 0.55	 1.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43328	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43329	 1	 0.68	 1.42	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43330	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43331	 1	 0.65	 1.69	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43332	 1	 0.99	 1.99	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43333	 1	 3.21	 4.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43334	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43335	 1	 0.92	 1.4	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43336	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43337	 1	 0.23	 0.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43338	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43339	 1	 0.98	 2.04	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43340	 1	 2.03	 2.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43341	 1	 0.99	 1.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43342	 1	 0.79	 1.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43343	 1	 0.42	 0.97	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43344	 1	 0.85	 2.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43345	 1	 1.53	 3.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43346	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43347	 1	 2.73	 5.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43348	 1	 3.26	 4.09	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43349	 1	 5.27	 5.33	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43350	 1	 0.65	 1.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43351	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43352	 1	 1.25	 2.44	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43353	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43354	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43355	 1	 1.64	 3.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43356	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43357	 1	 2.59	 5.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43358	 1	 0.42	 0.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43359	 1	 2.69	 4.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43360	 1	 1.04	 1.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43361	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43362	 1	 1.13	 1.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43363	 1	 2.23	 3.18	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43364	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43365	 1	 0.68	 1.22	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43366	 1	 0.9	 1.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43367	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43368	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43369	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43370	 1	 0.7	 1.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43371	 1	 5.16	 5.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43372	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43373	 1	 1.56	 2.39	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43374	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43375	 1	 1.96	 3.52	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43376	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43377	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43378	 1	 1.1	 1.75	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43379	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43380	 1	 0.96	 1.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43381	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43382	 1	 4.5	 5.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43383	 1	 0.66	 1.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43384	 1	 2.5	 3.82	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43385	 1	 1.53	 2.46	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43386	 1	 5.82	 6.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43387	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43388	 1	 1.2	 2.87	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43389	 1	 1.7	 2.6	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43390	 1	 2.48	 3.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43391	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43392	 1	 1.5	 1.6	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43393	 1	 1.29	 2.87	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43394	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43395	 1	 0.74	 1.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43396	 1	 1.91	 2.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43397	 1	 0.91	 2.02	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43398	 1	 0.86	 1.79	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43399	 1	 0.99	 1.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43400	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43401	 1	 5.27	 4.9	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43402	 1	 1.36	 2.01	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43403	 1	 0.97	 2.04	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43404	 1	 2.74	 3.13	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43405	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43406	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43407	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43408	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43409	 1	 3.91	 6.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43410	 1	 5.7	 5.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43411	 1	 0.86	 1.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43412	 1	 2.82	 4.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43413	 1	 1.02	 1.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43414	 1	 0.44	 0.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43415	 1	 1.02	 2.56	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43416	 1	 1.42	 2.1	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43417	 1	 0.75	 1.49	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43418	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43419	 1	 1.32	 2.74	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43420	 1	 4.5	 4.17	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43421	 1	 2.42	 3.69	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43422	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43423	 1	 1.75	 2.32	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43424	 1	 5.58	 3.91	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43425	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43426	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43427	 1	 0.86	 1.33	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43428	 1	 0.89	 1.6	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43429	 1	 0.67	 1.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43430	 1	 1.59	 3.36	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43431	 1	 3.72	 4.65	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43432	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43433	 1	 2.05	 3.1	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43434	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43435	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43436	 1	 1.06	 1.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43437	 1	 0.35	 0.74	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43438	 1	 1.18	 2.29	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43439	 1	 0.75	 1.92	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43440	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43441	 1	 0.83	 1.92	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43442	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43443	 1	 0.95	 1.99	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43444	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43445	 1	 0.7	 1.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43446	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43447	 1	 8.35	 10.95	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43448	 1	 1.0	 1.95	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43449	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43450	 1	 1.04	 2.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43451	 1	 0.34	 0.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43452	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43453	 1	 4.27	 2.99	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43454	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43455	 1	 0.49	 1.01	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43456	 1	 1.17	 2.5	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43457	 1	 1.63	 2.31	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43458	 1	 0.96	 2.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43459	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43460	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43461	 1	 1.99	 2.19	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43462	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43463	 1	 0.9	 2.17	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43464	 1	 0.89	 1.96	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43465	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43466	 1	 1.52	 3.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43467	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43468	 1	 0.59	 1.36	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43469	 1	 1.0	 2.08	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43470	 1	 1.22	 2.31	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43471	 1	 1.06	 0.27	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43472	 1	 4.31	 1.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43473	 1	 0.47	 0.96	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43474	 1	 1.09	 1.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43475	 1	 0.72	 1.31	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43476	 1	 2.22	 2.46	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43477	 1	 1.17	 2.2	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43478	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43479	 1	 3.66	 5.27	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43480	 1	 7.6	 6.7	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43481	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43482	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43483	 1	 0.78	 1.94	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43484	 1	 0.64	 1.54	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43485	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43486	 1	 4.02	 6.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43487	 1	 0.52	 1.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43488	 1	 1.31	 2.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43489	 1	 8.84	 7.52	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43490	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43491	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43492	 1	 5.28	 6.48	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43493	 1	 2.18	 2.98	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43494	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43495	 1	 1.17	 1.86	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43496	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43497	 1	 0.32	 0.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43498	 1	 0.7	 1.51	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43499	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43500	 1	 0.56	 1.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43501	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43502	 1	 0.9	 2.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43503	 1	 1.49	 2.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43504	 1	 1.66	 3.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43505	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43506	 1	 0.55	 1.36	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43507	 1	 1.21	 2.78	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43508	 1	 0.76	 1.58	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43509	 1	 0.98	 1.71	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43510	 1	 4.6	 3.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43511	 1	 0.91	 1.77	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43512	 1	 0.42	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43513	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43514	 1	 2.57	 3.67	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43515	 1	 2.19	 4.85	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43516	 1	 3.55	 5.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43517	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43518	 1	 1.42	 2.53	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43519	 1	 1.51	 0.37	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43520	 1	 5.7	 1.36	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43521	 1	 0.93	 1.82	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43522	 1	 3.84	 3.18	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43523	 1	 1.28	 1.62	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43524	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43525	 1	 1.85	 2.58	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43526	 1	 2.32	 2.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43527	 1	 2.79	 3.69	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43528	 1	 0.98	 1.59	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43529	 1	 1.22	 1.92	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43530	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43531	 1	 1.61	 2.51	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43532	 1	 0.98	 1.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43533	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43534	 1	 1.15	 1.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43535	 1	 1.19	 2.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43536	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43537	 1	 16.45	 13.83	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43538	 1	 2.32	 3.45	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43539	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43540	 1	 1.69	 3.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43541	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43542	 1	 0.61	 1.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43543	 1	 2.04	 2.22	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43544	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43545	 1	 2.13	 2.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43546	 1	 1.14	 2.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43547	 1	 1.74	 1.71	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43548	 1	 2.15	 2.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43549	 1	 0.64	 1.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43550	 1	 1.19	 2.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43551	 1	 3.29	 3.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43552	 1	 1.25	 2.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43553	 1	 4.31	 4.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43554	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43555	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43556	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43557	 1	 3.26	 4.6	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43558	 1	 2.72	 4.58	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43559	 1	 0.82	 1.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43560	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43561	 1	 3.28	 5.2	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43562	 1	 2.87	 4.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43563	 1	 4.6	 6.27	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43564	 1	 3.38	 3.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43565	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43566	 1	 4.46	 5.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43567	 1	 2.22	 3.36	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43568	 1	 2.76	 3.96	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43569	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43570	 1	 0.95	 1.79	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43571	 1	 1.25	 2.33	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43572	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43573	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43574	 1	 1.04	 1.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43575	 1	 1.5	 2.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43576	 1	 0.62	 1.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43577	 1	 4.95	 6.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43578	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43579	 1	 0.86	 1.53	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43580	 1	 6.74	 7.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43581	 1	 0.85	 1.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43582	 1	 2.85	 3.18	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43583	 1	 1.24	 2.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43584	 1	 1.47	 2.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43585	 1	 0.7	 1.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43586	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43587	 1	 8.06	 9.26	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43588	 1	 3.87	 3.71	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43589	 1	 4.13	 4.15	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43590	 1	 6.6	 1.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43591	 1	 2.13	 3.18	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43592	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43593	 1	 2.13	 3.4	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43594	 1	 0.47	 0.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43595	 1	 0.98	 1.85	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43596	 1	 1.29	 2.52	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43597	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43598	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43599	 1	 4.87	 4.91	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43600	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43601	 1	 1.14	 2.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43602	 1	 3.7	 4.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43603	 1	 1.21	 2.69	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43604	 1	 2.45	 3.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43605	 1	 0.5	 1.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43606	 1	 1.71	 2.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43607	 1	 2.05	 3.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43608	 1	 1.19	 2.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43609	 1	 0.65	 0.16	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43610	 1	 1.94	 0.49	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43611	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43612	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43613	 1	 1.25	 2.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43614	 1	 2.13	 3.57	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43615	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43616	 1	 1.05	 2.38	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43617	 1	 2.41	 5.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43618	 1	 1.24	 2.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43619	 1	 0.6	 1.49	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43620	 1	 0.89	 2.13	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43621	 1	 0.32	 0.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43622	 1	 0.46	 1.01	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43623	 1	 0.81	 1.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43624	 1	 0.39	 0.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43625	 1	 1.2	 3.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43626	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43627	 1	 0.87	 2.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43628	 1	 0.94	 1.97	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43629	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43630	 1	 1.06	 2.13	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43631	 1	 1.52	 3.22	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43632	 1	 0.88	 2.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43633	 1	 2.68	 5.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43634	 1	 2.58	 4.51	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43635	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43636	 1	 1.91	 4.27	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43637	 1	 0.88	 0.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43638	 1	 5.0	 1.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43639	 1	 1.75	 0.43	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43640	 1	 0.64	 1.54	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43641	 1	 5.59	 1.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43642	 1	 2.17	 0.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43643	 1	 0.97	 0.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43644	 1	 1.03	 0.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43645	 1	 1.2	 0.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43646	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43647	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43648	 1	 0.7	 1.22	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43649	 1	 1.15	 1.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43650	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43651	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43652	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43653	 1	 19.31	 12.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43654	 1	 2.74	 3.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43655	 1	 0.93	 1.88	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43656	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43657	 1	 1.45	 2.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43658	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43659	 1	 12.53	 11.88	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43660	 1	 0.44	 0.95	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43661	 1	 0.38	 0.76	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43662	 1	 0.95	 2.1	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43663	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43664	 1	 1.22	 2.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43665	 1	 1.16	 2.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43666	 1	 1.17	 2.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43667	 1	 2.25	 4.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43668	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43669	 1	 1.81	 4.23	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43670	 1	 0.95	 2.42	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43671	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43672	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43673	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43674	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43675	 1	 1.09	 2.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43676	 1	 1.39	 3.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43677	 1	 0.9	 2.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43678	 1	 0.53	 1.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43679	 1	 2.01	 3.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43680	 1	 0.65	 1.41	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43681	 1	 0.57	 1.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43682	 1	 3.61	 2.76	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43683	 1	 5.8	 5.95	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43684	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43685	 1	 1.06	 1.75	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43686	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43687	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43688	 1	 0.65	 1.46	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43689	 1	 6.9	 5.61	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43690	 1	 2.11	 3.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43691	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43692	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43693	 1	 2.09	 3.1	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43694	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43695	 1	 7.23	 8.22	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43696	 1	 0.68	 1.7	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43697	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43698	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43699	 1	 33.15	 23.62	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43700	 1	 0.64	 1.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43701	 1	 1.38	 3.14	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43702	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43703	 1	 0.9	 1.62	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43704	 1	 0.68	 1.49	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43705	 1	 1.29	 2.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43706	 1	 2.75	 5.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43707	 1	 2.35	 3.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43708	 1	 0.73	 1.61	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43709	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43710	 1	 1.95	 2.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43711	 1	 0.55	 1.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43712	 1	 0.39	 0.8	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43713	 1	 0.8	 1.92	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43714	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43715	 1	 2.04	 2.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43716	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43717	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43718	 1	 1.92	 3.31	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43719	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43720	 1	 1.15	 2.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43721	 1	 1.47	 0.37	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43722	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43723	 1	 1.23	 0.31	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43724	 1	 0.67	 0.17	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43725	 1	 6.46	 1.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43726	 1	 0.62	 0.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43727	 1	 0.97	 0.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43728	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43729	 1	 5.94	 7.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43730	 1	 3.19	 3.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43731	 1	 1.74	 0.42	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43732	 1	 5.23	 1.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43733	 1	 0.66	 0.16	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43734	 1	 0.57	 0.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43735	 1	 1.26	 0.31	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43736	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43737	 1	 0.85	 1.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43738	 1	 1.1	 2.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43739	 1	 0.93	 2.32	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43740	 1	 6.1	 5.84	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43741	 1	 1.37	 2.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43742	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43743	 1	 1.73	 3.96	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43744	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43745	 1	 3.76	 4.05	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43746	 1	 1.79	 3.23	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43747	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43748	 1	 1.97	 2.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43749	 1	 0.53	 1.27	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43750	 1	 1.61	 3.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43751	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43752	 1	 5.66	 5.91	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43753	 1	 3.68	 4.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43754	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43755	 1	 1.19	 2.23	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43756	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43757	 1	 0.44	 0.91	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	43758	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	43759	 1	 1.89	 2.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43760	 1	 0.39	 1.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43761	 1	 5.75	 5.93	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43762	 1	 0.56	 1.41	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43763	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43764	 1	 0.97	 1.57	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43765	 1	 6.42	 7.3	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43766	 1	 9.35	 8.63	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43767	 1	 3.75	 4.36	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43768	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43769	 1	 0.75	 1.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43770	 1	 0.92	 1.92	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43771	 1	 4.59	 6.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43772	 1	 3.83	 3.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43773	 1	 1.18	 1.76	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43774	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	43775	 1	 5.18	 5.91	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43776	 1	 1.96	 2.95	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43777	 1	 5.07	 6.05	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43778	 1	 0.89	 1.75	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43779	 1	 1.56	 2.41	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43780	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43781	 1	 1.14	 1.74	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43782	 1	 2.19	 3.45	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43783	 1	 1.14	 1.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43784	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43785	 1	 1.48	 2.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43786	 1	 0.52	 1.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43787	 1	 5.94	 5.86	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43788	 1	 1.14	 1.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43789	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43790	 1	 0.5	 1.13	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43791	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43792	 1	 5.47	 6.55	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43793	 1	 1.45	 2.13	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43794	 1	 1.11	 2.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43795	 1	 0.63	 1.51	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43796	 1	 4.39	 4.27	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43797	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43798	 1	 3.1	 3.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43799	 1	 1.09	 1.91	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43800	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43801	 1	 0.63	 1.39	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43802	 1	 0.5	 0.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43803	 1	 0.78	 1.71	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43804	 1	 0.83	 1.75	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43805	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43806	 1	 1.17	 2.36	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43807	 1	 1.95	 3.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43808	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43809	 1	 1.16	 2.21	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43810	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43811	 1	 0.88	 1.76	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43812	 1	 0.52	 1.18	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43813	 1	 2.2	 4.02	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43814	 1	 2.7	 3.58	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43815	 1	 0.8	 1.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43816	 1	 0.53	 1.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43817	 1	 0.75	 1.47	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43818	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43819	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43820	 1	 0.81	 1.52	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43821	 1	 1.86	 2.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43822	 1	 0.53	 1.32	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43823	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43824	 1	 0.69	 1.79	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43825	 1	 3.02	 3.96	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43826	 1	 0.42	 0.97	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43827	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43828	 1	 0.77	 1.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43829	 1	 1.06	 2.47	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43830	 1	 0.84	 1.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43831	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43832	 1	 0.3	 0.62	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43833	 1	 1.34	 3.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43834	 1	 0.59	 1.36	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	43835	 1	 0.9	 1.88	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	43836	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43837	 1	 3.44	 4.89	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43838	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43839	 1	 0.92	 1.6	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43840	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43841	 1	 0.79	 1.99	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43842	 1	 0.78	 1.91	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43843	 1	 0.67	 1.65	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43844	 1	 2.21	 4.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43845	 1	 1.38	 2.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43846	 1	 1.59	 2.96	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43847	 1	 1.02	 2.37	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43848	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43849	 1	 4.42	 5.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43850	 1	 1.23	 2.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43851	 1	 11.76	 17.1	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43852	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43853	 1	 14.34	 16.02	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43854	 1	 2.43	 4.16	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43855	 1	 3.15	 5.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43856	 1	 3.83	 8.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43857	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43858	 1	 1.59	 2.45	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43859	 1	 0.68	 1.69	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43860	 1	 1.03	 1.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43861	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43862	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43863	 1	 0.74	 1.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43864	 1	 1.72	 3.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43865	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43866	 1	 0.87	 1.81	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43867	 1	 1.34	 2.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43868	 1	 1.5	 3.1	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43869	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43870	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43871	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43872	 1	 3.05	 3.65	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43873	 1	 0.94	 2.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43874	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43875	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43876	 1	 1.89	 3.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43877	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43878	 1	 2.23	 4.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43879	 1	 0.76	 1.76	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43880	 1	 0.59	 1.4	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43881	 1	 1.07	 2.18	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43882	 1	 1.36	 3.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43883	 1	 6.13	 5.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43884	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43885	 1	 0.71	 1.62	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43886	 1	 0.75	 1.58	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43887	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43888	 1	 1.37	 2.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43889	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43890	 1	 2.61	 4.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43891	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43892	 1	 7.9	 12.31	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43893	 1	 3.28	 5.91	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43894	 1	 1.55	 3.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43895	 1	 1.09	 2.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43896	 1	 1.58	 3.58	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43897	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43898	 1	 2.18	 3.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43899	 1	 0.63	 1.59	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43900	 1	 0.6	 1.4	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43901	 1	 1.0	 2.18	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43902	 1	 0.54	 1.13	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43903	 1	 1.25	 2.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43904	 1	 2.21	 3.83	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43905	 1	 1.21	 2.51	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43906	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43907	 1	 0.67	 1.43	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43908	 1	 0.85	 1.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43909	 1	 0.66	 1.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43910	 1	 1.14	 1.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43911	 1	 0.6	 1.4	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43912	 1	 0.49	 1.22	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43913	 1	 0.98	 1.62	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43914	 1	 0.74	 1.58	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43915	 1	 1.81	 2.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43916	 1	 1.23	 2.16	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43917	 1	 0.49	 1.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43918	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	43919	 1	 0.85	 2.11	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43920	 1	 0.57	 1.16	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43921	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43922	 1	 0.71	 1.39	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43923	 1	 0.68	 1.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43924	 1	 0.46	 0.94	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43925	 1	 0.78	 1.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43926	 1	 0.57	 1.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43927	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43928	 1	 3.32	 0.82	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43929	 1	 1.45	 2.31	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43930	 1	 1.14	 2.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43931	 1	 4.44	 5.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43932	 1	 5.88	 1.46	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43933	 1	 0.51	 1.22	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43934	 1	 1.12	 2.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43935	 1	 1.22	 2.38	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43936	 1	 2.08	 2.64	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43937	 1	 0.89	 1.51	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43938	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43939	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	43940	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	43941	 1	 6.43	 6.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43942	 1	 5.45	 5.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43943	 1	 0.75	 1.65	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43944	 1	 2.42	 4.23	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43945	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43946	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43947	 1	 0.53	 1.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43948	 1	 0.63	 1.42	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43949	 1	 3.42	 2.75	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43950	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43951	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43952	 1	 0.51	 0.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43953	 1	 0.7	 1.69	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43954	 1	 0.41	 1.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43955	 1	 0.36	 0.75	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43956	 1	 0.82	 1.67	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43957	 1	 0.5	 1.22	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43958	 1	 1.03	 2.36	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43959	 1	 0.79	 1.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43960	 1	 0.63	 1.46	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43961	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43962	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43963	 1	 0.51	 0.96	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43964	 1	 5.86	 5.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43965	 1	 2.2	 2.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43966	 1	 0.6	 1.28	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43967	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43968	 1	 0.69	 1.43	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43969	 1	 0.5	 1.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43970	 1	 0.62	 1.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43971	 1	 4.91	 4.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43972	 1	 1.61	 3.27	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43973	 1	 0.71	 1.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43974	 1	 1.35	 2.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43975	 1	 0.87	 2.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43976	 1	 0.28	 0.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43977	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43978	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43979	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43980	 1	 0.67	 1.67	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43981	 1	 0.46	 1.04	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43982	 1	 18.11	 19.54	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43983	 1	 0.92	 1.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43984	 1	 0.83	 1.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43985	 1	 0.67	 1.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43986	 1	 0.83	 1.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43987	 1	 1.03	 2.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43988	 1	 2.71	 2.89	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43989	 1	 1.6	 2.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43990	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43991	 1	 4.6	 4.32	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43992	 1	 6.48	 6.69	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43993	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43994	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43995	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43996	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	43997	 1	 15.35	 21.18	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	43998	 1	 0.56	 1.45	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	43999	 1	 0.55	 1.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44000	 1	 0.39	 1.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44001	 1	 0.47	 1.02	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44002	 1	 0.73	 1.76	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44003	 1	 0.48	 1.23	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44004	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44005	 1	 2.78	 3.17	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44006	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44007	 1	 0.99	 2.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44008	 1	 0.06	 0.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44009	 1	 1.51	 3.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44010	 1	 2.88	 4.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44011	 1	 1.87	 3.16	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44012	 1	 1.27	 2.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44013	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44014	 1	 1.19	 1.89	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44015	 1	 0.49	 0.99	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44016	 1	 4.87	 6.6	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44017	 1	 1.06	 2.01	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44018	 1	 0.72	 1.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44019	 1	 0.84	 1.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44020	 1	 0.91	 2.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44021	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44022	 1	 0.56	 1.46	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44023	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44024	 1	 0.64	 1.48	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44025	 1	 0.36	 0.81	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44026	 1	 0.84	 1.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44027	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44028	 1	 4.01	 4.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44029	 1	 0.97	 1.81	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44030	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44031	 1	 0.78	 0.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44032	 1	 3.65	 0.92	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44033	 1	 0.54	 0.13	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44034	 1	 2.42	 0.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44035	 1	 1.1	 0.27	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44036	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44037	 1	 1.11	 0.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44038	 1	 1.37	 0.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44039	 1	 0.58	 0.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44040	 1	 0.56	 0.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44041	 1	 2.94	 0.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44042	 1	 0.62	 0.15	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44043	 1	 0.42	 0.74	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44044	 1	 1.44	 2.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44045	 1	 0.89	 2.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44046	 1	 1.63	 3.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44047	 1	 0.39	 0.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44048	 1	 0.64	 1.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44049	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44050	 1	 0.52	 1.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44051	 1	 0.71	 1.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44052	 1	 1.17	 1.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44053	 1	 1.25	 2.62	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44054	 1	 1.44	 3.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44055	 1	 3.18	 0.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44056	 1	 2.62	 0.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44057	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44058	 1	 1.05	 1.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44059	 1	 1.37	 2.65	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44060	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44061	 1	 1.52	 3.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44062	 1	 1.4	 0.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44063	 1	 2.89	 4.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44064	 1	 2.41	 3.02	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44065	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44066	 1	 0.39	 0.89	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44067	 1	 7.78	 5.37	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44068	 1	 1.87	 2.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44069	 1	 1.27	 1.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44070	 1	 3.07	 3.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44071	 1	 11.67	 12.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44072	 1	 7.73	 5.21	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44073	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44074	 1	 0.73	 1.57	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44075	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44076	 1	 1.03	 2.14	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44077	 1	 5.8	 4.43	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44078	 1	 0.94	 1.97	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44079	 1	 3.9	 4.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44080	 1	 3.08	 0.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44081	 1	 1.66	 0.39	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44082	 1	 1.47	 2.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44083	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44084	 1	 1.36	 2.6	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44085	 1	 0.97	 2.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44086	 1	 0.71	 1.49	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44087	 1	 0.52	 1.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44088	 1	 0.47	 1.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44089	 1	 0.49	 1.17	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44090	 1	 0.8	 1.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44091	 1	 0.4	 0.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44092	 1	 0.66	 1.58	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44093	 1	 0.7	 1.47	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44094	 1	 0.54	 1.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44095	 1	 0.32	 0.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44096	 1	 1.84	 2.18	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44097	 1	 1.62	 1.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44098	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44099	 1	 0.68	 1.52	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44100	 1	 0.87	 2.1	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44101	 1	 0.7	 1.37	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44102	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44103	 1	 1.37	 3.22	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44104	 1	 1.32	 2.78	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44105	 1	 2.55	 3.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44106	 1	 16.49	 14.99	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44107	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44108	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44109	 1	 4.02	 3.55	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44110	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44111	 1	 3.38	 3.36	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44112	 1	 3.7	 2.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44113	 1	 3.47	 4.26	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44114	 1	 0.38	 0.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44115	 1	 4.52	 5.58	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44116	 1	 1.07	 1.71	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44117	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44118	 1	 2.07	 0.5	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44119	 1	 1.1	 1.56	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44120	 1	 0.62	 0.99	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44121	 1	 0.71	 1.26	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44122	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44123	 1	 2.07	 3.55	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44124	 1	 1.36	 2.49	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44125	 1	 2.14	 3.44	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44126	 1	 0.78	 1.26	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44127	 1	 0.58	 0.91	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44128	 1	 1.34	 2.17	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44129	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44130	 1	 2.02	 2.93	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44131	 1	 3.16	 4.66	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44132	 1	 2.04	 2.62	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44133	 1	 1.37	 1.95	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44134	 1	 0.56	 1.14	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44135	 1	 0.53	 1.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44136	 1	 0.72	 1.18	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44137	 1	 1.4	 2.56	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44138	 1	 1.14	 1.98	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44139	 1	 1.1	 1.76	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44140	 1	 0.56	 1.02	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44141	 1	 0.48	 0.97	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44142	 1	 1.4	 2.13	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44143	 1	 0.58	 0.93	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44144	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44145	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44146	 1	 2.48	 3.23	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44147	 1	 1.24	 2.02	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44148	 1	 0.78	 1.57	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44149	 1	 1.14	 0.26	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44150	 1	 0.71	 1.19	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44151	 1	 2.1	 3.22	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44152	 1	 0.7	 1.38	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44153	 1	 1.63	 2.79	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44154	 1	 4.45	 4.59	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44155	 1	 0.87	 1.7	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44156	 1	 1.97	 3.32	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44157	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44158	 1	 2.63	 3.41	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44159	 1	 0.67	 0.97	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44160	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44161	 1	 0.38	 0.6	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44162	 1	 1.4	 2.29	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44163	 1	 1.25	 2.27	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44164	 1	 2.4	 3.79	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44165	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44166	 1	 0.88	 1.64	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44167	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44168	 1	 0.8	 1.34	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44169	 1	 1.06	 2.08	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44170	 1	 1.49	 1.7	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44171	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44172	 1	 0.87	 1.39	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44173	 1	 0.82	 1.33	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44174	 1	 1.79	 3.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44175	 1	 1.35	 2.14	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44176	 1	 0.7	 1.29	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44177	 1	 0.63	 1.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44178	 1	 2.16	 3.5	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44179	 1	 0.79	 1.29	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44180	 1	 1.33	 2.22	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44181	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44182	 1	 3.5	 4.27	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44183	 1	 0.81	 1.52	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44184	 1	 0.82	 0.19	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44185	 1	 1.12	 1.7	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44186	 1	 2.3	 3.33	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44187	 1	 0.82	 1.35	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44188	 1	 1.14	 2.15	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44189	 1	 2.16	 3.26	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44190	 1	 1.45	 2.39	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44191	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44192	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44193	 1	 4.37	 5.35	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44194	 1	 2.34	 3.72	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44195	 1	 2.06	 3.18	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44196	 1	 1.09	 2.13	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44197	 1	 12.53	 11.37	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44198	 1	 1.09	 1.8	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44199	 1	 1.2	 1.99	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44200	 1	 0.77	 1.22	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44201	 1	 3.0	 3.77	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44202	 1	 1.05	 1.7	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44203	 1	 0.59	 0.96	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44204	 1	 1.5	 1.94	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44205	 1	 0.95	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44206	 1	 0.47	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44207	 1	 1.44	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44208	 1	 1.48	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44209	 1	 4.1	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44210	 1	 1.18	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44211	 1	 0.65	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44212	 1	 1.05	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44213	 1	 0.8	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44214	 1	 0.88	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44215	 1	 3.52	 4.59	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44216	 1	 2.92	 0.71	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44217	 1	 1.45	 0.35	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44218	 1	 0.96	 0.23	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44219	 1	 0.95	 0.23	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44220	 1	 2.08	 0.51	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44221	 1	 2.25	 0.55	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44222	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44223	 1	 1.04	 0.25	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44224	 1	 0.33	 0.08	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44225	 1	 1.6	 3.11	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44226	 1	 1.27	 1.78	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44227	 1	 2.02	 2.24	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44228	 1	 1.81	 2.78	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44229	 1	 1.49	 1.68	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44230	 1	 4.29	 6.49	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44231	 1	 2.89	 4.18	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44232	 1	 3.39	 5.63	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44233	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44234	 1	 1.27	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44235	 1	 0.9	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44236	 1	 1.51	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44237	 1	 2.26	 3.44	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44238	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	44239	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	44240	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44241	 1	 2.84	 4.5	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44242	 1	 0.96	 1.7	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44243	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44244	 1	 3.2	 3.96	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44245	 1	 7.23	 9.57	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44246	 1	 2.25	 4.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44247	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44248	 1	 1.1	 2.41	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44249	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44250	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44251	 1	 1.94	 3.26	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44252	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44253	 1	 2.3	 3.56	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44254	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44255	 1	 2.33	 3.78	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44256	 1	 0.83	 1.75	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44257	 1	 5.8	 7.47	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44258	 1	 2.89	 4.88	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44259	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44260	 1	 1.15	 2.3	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44261	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44262	 1	 2.01	 3.58	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44263	 1	 1.31	 2.18	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44264	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44265	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44266	 1	 1.29	 2.34	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44267	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44268	 1	 2.12	 3.9	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44269	 1	 1.13	 2.11	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44270	 1	 2.7	 4.62	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44271	 1	 4.14	 4.68	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44272	 1	 1.25	 1.83	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44273	 1	 1.17	 2.38	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44274	 1	 0.43	 0.77	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44275	 1	 0.53	 0.87	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44276	 1	 0.51	 0.99	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44277	 1	 1.77	 2.77	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44278	 1	 0.49	 1.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44279	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44280	 1	 0.46	 0.93	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44281	 1	 2.75	 4.89	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44282	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44283	 1	 4.77	 6.67	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44284	 1	 2.32	 3.82	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44285	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44286	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44287	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44288	 1	 1.32	 1.74	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44289	 1	 0.84	 1.43	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44290	 1	 0.73	 1.35	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44291	 1	 0.67	 1.11	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44292	 1	 1.2	 1.77	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44293	 1	 1.08	 1.88	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44294	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44295	 1	 0.84	 0.2	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44296	 1	 1.39	 0.34	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44297	 1	 3.44	 0.83	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44298	 1	 2.08	 0.5	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44299	 1	 0.96	 1.4	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44300	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44301	 1	 0.92	 1.71	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44302	 1	 3.96	 5.49	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44303	 1	 2.86	 3.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44304	 1	 1.71	 2.7	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44305	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44306	 1	 1.53	 2.62	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44307	 1	 1.6	 2.6	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44308	 1	 2.72	 4.49	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44309	 1	 1.05	 1.9	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44310	 1	 1.35	 2.19	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44311	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44312	 1	 1.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44313	 1	 2.83	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44314	 1	 1.95	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44315	 1	 1.13	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44316	 1	 2.27	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44317	 1	 2.2	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44318	 1	 1.49	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44319	 1	 2.39	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44320	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44321	 1	 0.73	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44322	 1	 2.22	 -4.51	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44323	 1	 2.07	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44324	 1	 1.34	 0.33	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44325	 1	 0.84	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44326	 1	 1.78	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44327	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44328	 1	 0.98	 1.6	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44329	 1	 1.17	 1.95	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44330	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44331	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44332	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44333	 1	 0.82	 1.46	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44334	 1	 0.69	 1.19	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44335	 1	 1.79	 3.05	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44336	 1	 1.12	 1.77	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44337	 1	 0.89	 1.48	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44338	 1	 2.04	 0.49	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44339	 1	 2.86	 0.69	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44340	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44341	 1	 2.26	 0.56	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44342	 1	 4.64	 1.13	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44343	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44344	 1	 1.95	 0.48	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44345	 1	 2.12	 0.52	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44346	 1	 1.62	 0.4	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44347	 1	 0.6	 0.14	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44348	 1	 1.08	 1.89	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44349	 1	 0.73	 1.21	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44350	 1	 0.64	 1.24	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44351	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44352	 1	 2.15	 3.43	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44353	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44354	 1	 0.56	 0.88	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44355	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44356	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44357	 1	 0.61	 1.09	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44358	 1	 0.44	 0.95	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44359	 1	 2.3	 3.95	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44360	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	44361	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44362	 1	 1.92	 3.17	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44363	 1	 1.71	 3.28	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44364	 1	 0.72	 1.15	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44365	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44366	 1	 2.78	 4.48	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44367	 1	 1.55	 2.55	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44368	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44369	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44370	 1	 0.55	 0.98	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44371	 1	 1.41	 2.53	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44372	 1	 5.29	 6.7	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44373	 1	 2.88	 4.69	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44374	 1	 0.67	 1.06	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44375	 1	 0.85	 1.4	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44376	 1	 1.17	 1.73	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44377	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44378	 1	 0.87	 1.2	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44379	 1	 6.63	 10.39	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44380	 1	 2.45	 4.01	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44381	 1	 2.34	 3.8	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44382	 1	 1.87	 3.3	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44383	 1	 1.31	 2.54	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44384	 1	 1.15	 2.24	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44385	 1	 0.74	 1.39	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44386	 1	 1.08	 1.98	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44387	 1	 0.93	 1.74	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44388	 1	 0.99	 1.63	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44389	 1	 1.9	 3.59	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44390	 1	 1.03	 1.95	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44391	 1	 0.57	 1.05	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44392	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44393	 1	 1.26	 2.39	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44394	 1	 0.64	 1.09	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44395	 1	 0.24	 0.45	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44396	 1	 0.49	 0.77	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44397	 1	 2.96	 4.36	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44398	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44399	 1	 0.66	 1.22	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44400	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44401	 1	 0.33	 0.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44402	 1	 0.65	 1.42	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44403	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44404	 1	 0.94	 1.9	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44405	 1	 2.12	 3.55	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44406	 1	 1.2	 1.96	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44407	 1	 0.96	 1.52	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44408	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44409	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44410	 1	 1.39	 2.31	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44411	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44412	 1	 1.34	 2.67	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44413	 1	 1.11	 2.08	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44414	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44415	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44416	 1	 0.49	 0.71	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44417	 1	 1.79	 2.75	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44418	 1	 1.06	 1.97	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44419	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44420	 1	 1.48	 2.74	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44421	 1	 2.25	 3.78	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44422	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44423	 1	 1.99	 2.73	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44424	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44425	 1	 1.52	 2.68	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44426	 1	 0.56	 1.06	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44427	 1	 1.21	 2.49	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44428	 1	 2.15	 3.25	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44429	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44430	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44431	 1	 0.39	 0.81	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44432	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44433	 1	 0.7	 1.29	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44434	 1	 1.05	 2.2	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44435	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44436	 1	 1.51	 1.99	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44437	 1	 0.72	 1.33	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44438	 1	 1.18	 2.07	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44439	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44440	 1	 1.12	 2.04	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44441	 1	 1.63	 2.58	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44442	 1	 1.16	 1.71	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44443	 1	 3.19	 3.46	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44444	 1	 1.01	 2.17	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44445	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44446	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44447	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44448	 1	 2.31	 4.11	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44449	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44450	 1	 0.98	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44451	 1	 1.88	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44452	 1	 2.53	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44453	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44454	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44455	 1	 1.23	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44456	 1	 0.87	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44457	 1	 0.93	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44458	 1	 1.02	 1.89	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44459	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44460	 1	 1.46	 2.35	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44461	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44462	 1	 2.06	 3.3	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44463	 1	 3.21	 4.46	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44464	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	44465	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44466	 1	 3.17	 5.23	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44467	 1	 0.95	 1.4	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44468	 1	 1.22	 2.2	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44469	 1	 1.22	 1.74	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44470	 1	 0.94	 1.79	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44471	 1	 1.99	 2.89	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44472	 1	 1.71	 3.12	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44473	 1	 0.64	 1.31	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44474	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44475	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44476	 1	 5.42	 8.08	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44477	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44478	 1	 0.75	 1.31	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44479	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44480	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44481	 1	 1.13	 1.97	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44482	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44483	 1	 1.65	 3.05	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44484	 1	 0.98	 1.55	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44485	 1	 1.9	 2.66	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44486	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44487	 1	 1.95	 2.54	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44488	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	44489	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44490	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44491	 1	 1.97	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44492	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44493	 1	 1.23	 1.8	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44494	 1	 0.7	 1.3	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44495	 1	 3.41	 4.26	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44496	 1	 0.63	 1.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44497	 1	 0.7	 1.28	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44498	 1	 1.38	 1.78	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44499	 1	 0.6	 1.03	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44500	 1	 1.09	 1.52	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44501	 1	 0.5	 0.91	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44502	 1	 0.34	 0.6	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44503	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44504	 1	 2.31	 3.79	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44505	 1	 1.48	 2.16	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44506	 1	 1.0	 1.62	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44507	 1	 1.04	 1.84	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44508	 1	 1.91	 2.61	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44509	 1	 1.27	 1.72	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44510	 1	 0.79	 1.33	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44511	 1	 2.15	 3.37	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44512	 1	 0.52	 0.9	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44513	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44514	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44515	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44516	 1	 0.97	 1.9	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44517	 1	 0.49	 1.03	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44518	 1	 0.59	 1.07	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44519	 1	 0.96	 1.84	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44520	 1	 0.74	 1.25	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44521	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44522	 1	 0.95	 1.69	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44523	 1	 0.77	 1.26	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44524	 1	 1.13	 2.31	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44525	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44526	 1	 1.59	 2.85	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44527	 1	 0.46	 0.99	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44528	 1	 0.66	 1.29	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44529	 1	 1.22	 2.02	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44530	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44531	 1	 0.83	 1.46	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44532	 1	 1.21	 1.86	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44533	 1	 0.77	 1.37	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44534	 1	 0.8	 1.49	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44535	 1	 2.83	 3.51	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44536	 1	 0.84	 1.3	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44537	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44538	 1	 1.64	 2.68	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44539	 1	 0.84	 1.31	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44540	 1	 1.72	 2.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44541	 1	 0.51	 0.83	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44542	 1	 1.84	 2.81	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44543	 1	 1.68	 3.01	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44544	 1	 0.64	 1.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44545	 1	 0.38	 0.74	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44546	 1	 0.87	 1.63	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44547	 1	 1.68	 2.7	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44548	 1	 1.37	 2.46	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44549	 1	 0.97	 1.44	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44550	 1	 4.93	 6.23	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44551	 1	 5.51	 6.75	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44552	 1	 2.19	 3.53	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44553	 1	 3.13	 4.07	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44554	 1	 2.93	 3.53	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44555	 1	 6.49	 8.94	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44556	 1	 0.98	 1.86	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44557	 1	 1.26	 1.73	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44558	 1	 3.68	 4.76	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44559	 1	 2.36	 2.93	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44560	 1	 1.05	 1.39	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44561	 1	 0.51	 0.84	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44562	 1	 0.94	 1.73	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44563	 1	 0.5	 0.83	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44564	 1	 1.14	 2.01	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44565	 1	 0.87	 1.32	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44566	 1	 1.83	 2.28	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44567	 1	 0.34	 0.57	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44568	 1	 1.84	 2.81	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44569	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44570	 1	 0.29	 0.51	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44571	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44572	 1	 0.41	 0.81	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44573	 1	 2.16	 3.07	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44574	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44575	 1	 4.94	 5.41	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44576	 1	 0.63	 1.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44577	 1	 1.29	 2.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44578	 1	 1.24	 2.17	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44579	 1	 1.32	 2.18	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44580	 1	 1.53	 2.39	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44581	 1	 0.48	 0.89	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44582	 1	 0.87	 1.64	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44583	 1	 0.86	 1.21	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44584	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44585	 1	 2.12	 2.83	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44586	 1	 2.02	 3.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44587	 1	 5.12	 7.24	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44588	 1	 0.54	 0.82	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44589	 1	 1.43	 2.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44590	 1	 0.67	 1.31	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44591	 1	 0.92	 1.86	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44592	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44593	 1	 0.53	 0.91	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44594	 1	 1.43	 2.44	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44595	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44596	 1	 0.48	 0.99	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44597	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44598	 1	 0.55	 0.78	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44599	 1	 0.73	 1.36	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44600	 1	 0.42	 0.8	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44601	 1	 4.69	 6.01	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44602	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44603	 1	 1.01	 1.93	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44604	 1	 0.73	 1.38	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44605	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44606	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44607	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44608	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44609	 1	 1.82	 3.16	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44610	 1	 1.9	 2.46	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44611	 1	 1.65	 2.79	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44612	 1	 3.82	 6.2	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44613	 1	 0.89	 1.72	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44614	 1	 0.4	 0.76	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44615	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44616	 1	 0.45	 0.79	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44617	 1	 2.35	 3.88	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44618	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44619	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44620	 1	 1.98	 2.66	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44621	 1	 1.44	 2.11	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44622	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44623	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44624	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44625	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44626	 1	 2.52	 4.4	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44627	 1	 2.08	 4.09	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44628	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44629	 1	 4.32	 6.85	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44630	 1	 1.99	 3.29	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44631	 1	 1.23	 1.89	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44632	 1	 1.18	 2.6	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44633	 1	 0.8	 1.25	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44634	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44635	 1	 5.48	 6.9	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44636	 1	 1.04	 1.53	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44637	 1	 1.48	 1.85	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44638	 1	 0.95	 1.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44639	 1	 0.73	 1.33	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44640	 1	 0.65	 1.16	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44641	 1	 1.56	 2.48	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44642	 1	 1.97	 2.59	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44643	 1	 1.59	 2.07	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44644	 1	 1.87	 2.74	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44645	 1	 1.73	 2.43	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44646	 1	 2.18	 3.67	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44647	 1	 0.71	 1.16	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44648	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44649	 1	 4.25	 6.75	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44650	 1	 1.09	 1.98	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44651	 1	 1.48	 1.96	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44652	 1	 0.65	 1.18	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44653	 1	 1.92	 3.21	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44654	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44655	 1	 0.96	 1.35	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44656	 1	 0.97	 1.92	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44657	 1	 0.69	 1.33	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44658	 1	 1.0	 1.76	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44659	 1	 2.15	 2.7	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44660	 1	 2.27	 3.66	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44661	 1	 1.19	 2.13	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44662	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44663	 1	 0.61	 1.01	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44664	 1	 3.05	 4.87	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44665	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44666	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44667	 1	 1.31	 1.77	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44668	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44669	 1	 1.12	 1.67	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44670	 1	 2.14	 3.54	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44671	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44672	 1	 1.34	 2.34	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44673	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44674	 1	 1.79	 2.57	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44675	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44676	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44677	 1	 7.15	 10.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44678	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44679	 1	 1.01	 1.73	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44680	 1	 2.87	 4.63	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44681	 1	 1.16	 1.85	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44682	 1	 1.15	 1.96	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44683	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44684	 1	 1.63	 2.92	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44685	 1	 0.91	 1.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44686	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44687	 1	 1.41	 2.71	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44688	 1	 1.56	 2.93	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44689	 1	 1.2	 2.43	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44690	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44691	 1	 1.59	 2.14	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44692	 1	 2.23	 3.42	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44693	 1	 3.2	 5.12	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44694	 1	 3.86	 5.79	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44695	 1	 1.48	 2.49	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44696	 1	 2.73	 4.39	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44697	 1	 1.49	 2.34	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44698	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44699	 1	 2.59	 3.29	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44700	 1	 1.18	 1.74	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44701	 1	 1.52	 2.12	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44702	 1	 1.16	 1.99	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44703	 1	 0.78	 1.38	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44704	 1	 0.91	 1.45	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44705	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44706	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44707	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44708	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44709	 1	 4.84	 6.94	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44710	 1	 0.73	 1.15	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44711	 1	 0.65	 1.37	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44712	 1	 1.74	 2.77	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44713	 1	 0.96	 1.5	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44714	 1	 0.42	 0.71	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44715	 1	 2.57	 3.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44716	 1	 2.05	 2.86	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44717	 1	 0.5	 0.89	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44718	 1	 0.62	 0.99	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44719	 1	 0.81	 1.39	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44720	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44721	 1	 2.86	 2.75	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44722	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44723	 1	 0.76	 1.35	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44724	 1	 0.39	 0.57	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44725	 1	 1.87	 2.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44726	 1	 0.49	 0.9	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44727	 1	 2.02	 2.86	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44728	 1	 2.43	 2.95	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44729	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44730	 1	 0.85	 1.22	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44731	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44732	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44733	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44734	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44735	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44736	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44737	 1	 0.99	 1.72	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44738	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44739	 1	 2.52	 4.31	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44740	 1	 1.38	 2.53	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44741	 1	 0.67	 1.21	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44742	 1	 0.6	 1.18	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44743	 1	 1.2	 2.03	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44744	 1	 1.54	 2.38	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44745	 1	 0.37	 0.6	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44746	 1	 0.94	 1.5	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44747	 1	 1.01	 1.52	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44748	 1	 1.69	 2.72	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44749	 1	 1.3	 2.01	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44750	 1	 0.88	 1.59	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44751	 1	 1.32	 2.12	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44752	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44753	 1	 0.85	 1.57	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44754	 1	 0.7	 1.24	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44755	 1	 0.67	 1.18	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44756	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44757	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44758	 1	 0.63	 0.97	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44759	 1	 0.34	 0.68	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44760	 1	 1.06	 1.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44761	 1	 1.11	 2.03	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44762	 1	 1.08	 2.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44763	 1	 0.37	 0.65	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44764	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44765	 1	 0.74	 1.23	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44766	 1	 0.88	 1.55	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44767	 1	 0.27	 0.6	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44768	 1	 0.53	 0.93	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44769	 1	 1.27	 1.77	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44770	 1	 1.33	 2.2	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44771	 1	 2.04	 3.39	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44772	 1	 0.94	 1.54	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44773	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44774	 1	 0.71	 1.24	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44775	 1	 0.73	 1.16	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44776	 1	 1.05	 2.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44777	 1	 0.92	 1.53	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44778	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44779	 1	 0.49	 0.94	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44780	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44781	 1	 1.63	 2.02	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44782	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44783	 1	 4.48	 5.13	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44784	 1	 0.61	 1.07	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44785	 1	 2.33	 4.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44786	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44787	 1	 4.35	 5.34	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44788	 1	 7.61	 10.07	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44789	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44790	 1	 7.77	 10.67	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44791	 1	 1.92	 3.5	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44792	 1	 0.69	 1.39	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44793	 1	 1.2	 2.07	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44794	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44795	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44796	 1	 3.2	 0.78	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44797	 1	 0.52	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44798	 1	 0.55	 0.84	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44799	 1	 0.82	 1.35	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44800	 1	 3.26	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44801	 1	 2.09	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44802	 1	 0.58	 1.02	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44803	 1	 1.72	 2.48	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44804	 1	 1.34	 2.12	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44805	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44806	 1	 3.2	 4.92	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44807	 1	 1.08	 1.69	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44808	 1	 1.31	 2.29	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44809	 1	 2.8	 3.3	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44810	 1	 1.03	 1.52	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44811	 1	 1.3	 2.11	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44812	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44813	 1	 1.1	 1.95	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44814	 1	 1.16	 2.22	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44815	 1	 0.76	 1.55	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44816	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44817	 1	 0.65	 1.14	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44818	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44819	 1	 4.32	 7.52	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44820	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44821	 1	 0.84	 1.33	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44822	 1	 1.31	 2.24	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44823	 1	 0.86	 1.44	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44824	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44825	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44826	 1	 0.9	 1.55	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44827	 1	 1.02	 1.85	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44828	 1	 3.39	 5.19	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44829	 1	 1.93	 2.63	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44830	 1	 1.49	 0.35	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44831	 1	 0.63	 0.15	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44832	 1	 0.71	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44833	 1	 1.95	 0.47	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44834	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44835	 1	 2.33	 0.56	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44836	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44837	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44838	 1	 1.57	 0.37	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44839	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44840	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44841	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44842	 1	 0.95	 -4.66	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44843	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44844	 1	 1.19	 1.95	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44845	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44846	 1	 1.54	 2.24	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44847	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44848	 1	 1.75	 0.43	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44849	 1	 0.76	 1.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44850	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44851	 1	 1.5	 3.04	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44852	 1	 1.03	 1.82	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44853	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44854	 1	 0.72	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44855	 1	 2.78	 4.7	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44856	 1	 5.65	 5.85	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44857	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44858	 1	 1.54	 2.8	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44859	 1	 3.46	 4.03	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44860	 1	 1.84	 2.99	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44861	 1	 1.3	 2.47	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44862	 1	 1.7	 2.75	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44863	 1	 2.52	 3.24	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44864	 1	 2.43	 3.25	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44865	 1	 2.03	 3.28	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44866	 1	 2.61	 4.66	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44867	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44868	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44869	 1	 1.38	 2.51	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44870	 1	 3.71	 6.08	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44871	 1	 1.69	 2.73	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44872	 1	 10.36	 14.03	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44873	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44874	 1	 1.47	 2.79	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44875	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44876	 1	 3.64	 6.32	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44877	 1	 1.26	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44878	 1	 0.46	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44879	 1	 1.3	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44880	 1	 1.28	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44881	 1	 1.62	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44882	 1	 2.12	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44883	 1	 1.84	 2.73	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44884	 1	 1.83	 3.33	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44885	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44886	 1	 0.96	 1.13	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44887	 1	 2.57	 4.04	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44888	 1	 7.9	 11.4	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44889	 1	 1.67	 3.03	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44890	 1	 2.25	 0.53	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44891	 1	 3.62	 0.86	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44892	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44893	 1	 1.52	 0.36	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44894	 1	 1.64	 2.33	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44895	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44896	 1	 2.79	 4.37	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44897	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44898	 1	 2.45	 3.86	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44899	 1	 1.83	 2.52	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44900	 1	 1.41	 2.06	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44901	 1	 1.05	 1.85	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44902	 1	 1.02	 0.24	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44903	 1	 2.21	 0.53	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44904	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44905	 1	 0.64	 1.21	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44906	 1	 1.87	 2.59	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44907	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44908	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44909	 1	 1.41	 2.64	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44910	 1	 2.18	 2.72	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44911	 1	 0.98	 1.72	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44912	 1	 1.07	 2.36	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44913	 1	 3.47	 4.81	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44914	 1	 0.6	 1.15	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44915	 1	 0.77	 1.72	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44916	 1	 1.0	 2.18	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44917	 1	 1.54	 2.37	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44918	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44919	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44920	 1	 1.56	 2.84	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44921	 1	 0.64	 1.22	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44922	 1	 1.13	 2.14	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44923	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44924	 1	 1.41	 1.98	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44925	 1	 2.86	 4.2	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44926	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44927	 1	 3.18	 4.49	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44928	 1	 4.08	 7.14	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44929	 1	 1.66	 2.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44930	 1	 1.8	 2.54	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44931	 1	 3.71	 5.71	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44932	 1	 1.1	 2.01	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44933	 1	 1.4	 2.17	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44934	 1	 3.43	 5.49	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44935	 1	 2.57	 4.57	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44936	 1	 1.21	 2.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44937	 1	 1.13	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44938	 1	 1.29	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44939	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44940	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44941	 1	 1.39	 2.7	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44942	 1	 4.84	 6.9	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44943	 1	 0.95	 1.82	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44944	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44945	 1	 3.06	 3.87	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44946	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44947	 1	 0.98	 1.7	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44948	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44949	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44950	 1	 1.73	 2.8	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44951	 1	 1.03	 1.99	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44952	 1	 1.72	 3.08	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44953	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44954	 1	 1.9	 3.15	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44955	 1	 0.83	 1.51	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44956	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44957	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	44958	 1	 0.73	 1.28	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44959	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44960	 1	 0.61	 1.13	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44961	 1	 1.4	 2.63	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44962	 1	 0.62	 1.33	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44963	 1	 3.17	 4.45	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44964	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44965	 1	 1.03	 1.88	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44966	 1	 1.57	 2.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44967	 1	 2.51	 3.78	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44968	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	44969	 1	 2.82	 5.26	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44970	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44971	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44972	 1	 2.4	 4.38	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44973	 1	 0.94	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44974	 1	 0.44	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44975	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44976	 1	 0.42	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44977	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	44978	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44979	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44980	 1	 0.55	 1.2	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44981	 1	 6.97	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44982	 1	 3.12	 4.15	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44983	 1	 0.9	 2.01	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44984	 1	 0.6	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44985	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44986	 1	 0.53	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44987	 1	 1.08	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44988	 1	 0.7	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44989	 1	 1.22	 2.13	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44990	 1	 0.53	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44991	 1	 1.2	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44992	 1	 1.24	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44993	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	44994	 1	 1.32	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44995	 1	 0.53	 1.06	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44996	 1	 0.73	 1.29	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44997	 1	 0.85	 1.53	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	44998	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	44999	 1	 2.11	 3.11	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45000	 1	 1.41	 2.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45001	 1	 3.31	 5.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45002	 1	 0.58	 0.99	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45003	 1	 0.82	 1.3	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45004	 1	 1.98	 3.1	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45005	 1	 1.0	 1.74	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45006	 1	 2.13	 3.13	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45007	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45008	 1	 1.71	 3.12	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45009	 1	 2.69	 3.27	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45010	 1	 0.56	 0.94	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45011	 1	 1.17	 0.27	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45012	 1	 3.47	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45013	 1	 1.95	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45014	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45015	 1	 1.16	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45016	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45017	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45018	 1	 1.74	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45019	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45020	 1	 0.7	 1.24	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45021	 1	 1.64	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45022	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	45023	 1	 1.16	 2.15	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45024	 1	 2.34	 3.35	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45025	 1	 1.06	 2.08	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45026	 1	 1.52	 2.85	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45027	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45028	 1	 1.1	 2.01	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45029	 1	 1.0	 1.78	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45030	 1	 1.0	 1.89	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45031	 1	 1.27	 1.84	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45032	 1	 1.07	 1.63	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45033	 1	 1.42	 2.31	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45034	 1	 0.77	 1.49	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45035	 1	 1.75	 2.54	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45036	 1	 1.14	 2.15	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45037	 1	 0.75	 1.12	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45038	 1	 2.65	 4.2	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45039	 1	 1.72	 2.93	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45040	 1	 1.57	 2.37	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45041	 1	 2.06	 2.95	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45042	 1	 2.7	 3.97	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45043	 1	 1.49	 2.27	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45044	 1	 1.08	 2.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45045	 1	 1.27	 2.09	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45046	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45047	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45048	 1	 1.82	 2.82	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45049	 1	 0.84	 1.23	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45050	 1	 1.16	 1.81	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45051	 1	 1.94	 2.07	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45052	 1	 1.23	 1.87	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45053	 1	 1.54	 2.44	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45054	 1	 1.32	 2.11	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45055	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45056	 1	 2.57	 3.25	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45057	 1	 5.3	 7.01	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45058	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45059	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45060	 1	 1.25	 2.02	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45061	 1	 0.4	 0.69	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45062	 1	 0.58	 0.78	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45063	 1	 0.28	 0.54	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45064	 1	 0.27	 0.51	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45065	 1	 0.88	 1.35	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45066	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45067	 1	 3.49	 4.53	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45068	 1	 0.69	 1.23	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45069	 1	 0.87	 1.7	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45070	 1	 0.79	 1.3	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45071	 1	 0.81	 1.3	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45072	 1	 1.55	 2.31	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45073	 1	 0.91	 1.73	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45074	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45075	 1	 0.72	 1.08	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45076	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45077	 1	 0.99	 1.54	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45078	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45079	 1	 0.68	 1.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45080	 1	 0.49	 0.87	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45081	 1	 0.59	 1.21	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45082	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45083	 1	 1.19	 2.03	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45084	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45085	 1	 1.66	 2.94	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45086	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45087	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45088	 1	 0.95	 1.97	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45089	 1	 3.38	 5.42	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45090	 1	 0.72	 1.08	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45091	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45092	 1	 0.88	 1.32	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45093	 1	 3.84	 5.62	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45094	 1	 1.39	 2.17	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45095	 1	 0.61	 1.02	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45096	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45097	 1	 1.43	 2.7	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45098	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45099	 1	 1.86	 3.04	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45100	 1	 2.91	 3.8	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45101	 1	 1.17	 2.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45102	 1	 0.4	 0.79	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45103	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45104	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45105	 1	 2.44	 3.14	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45106	 1	 1.0	 1.86	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45107	 1	 5.8	 6.14	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45108	 1	 2.07	 3.41	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45109	 1	 1.93	 2.81	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45110	 1	 1.75	 3.01	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45111	 1	 7.12	 8.17	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45112	 1	 1.5	 2.92	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45113	 1	 3.14	 5.01	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45114	 1	 1.01	 1.59	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45115	 1	 0.79	 1.38	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45116	 1	 1.58	 2.78	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45117	 1	 4.56	 6.8	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45118	 1	 0.84	 1.23	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45119	 1	 5.0	 6.51	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45120	 1	 2.56	 2.31	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45121	 1	 2.0	 2.54	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45122	 1	 1.0	 1.61	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45123	 1	 0.55	 1.12	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45124	 1	 2.4	 3.74	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45125	 1	 1.15	 1.85	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45126	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	45127	 1	 0.81	 1.5	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45128	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45129	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45130	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	45131	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45132	 1	 1.84	 2.94	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45133	 1	 1.03	 1.76	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45134	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45135	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45136	 1	 1.17	 1.68	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45137	 1	 2.87	 4.8	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45138	 1	 0.94	 1.79	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45139	 1	 0.47	 0.92	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45140	 1	 0.91	 1.15	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45141	 1	 5.61	 8.51	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45142	 1	 1.16	 2.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45143	 1	 0.99	 1.26	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45144	 1	 1.31	 2.33	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45145	 1	 2.82	 3.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45146	 1	 1.65	 2.66	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45147	 1	 5.11	 7.73	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45148	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45149	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45150	 1	 0.84	 1.66	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45151	 1	 1.41	 2.28	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45152	 1	 1.06	 1.91	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45153	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45154	 1	 2.56	 3.57	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45155	 1	 3.76	 5.4	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45156	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45157	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45158	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45159	 1	 0.56	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45160	 1	 0.9	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45161	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45162	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45163	 1	 1.01	 1.48	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45164	 1	 2.38	 3.55	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45165	 1	 1.98	 3.4	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45166	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45167	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45168	 1	 1.43	 2.3	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45169	 1	 0.66	 0.16	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45170	 1	 3.97	 4.35	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45171	 1	 3.0	 4.4	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45172	 1	 1.46	 2.16	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45173	 1	 3.06	 5.42	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45174	 1	 1.75	 3.17	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45175	 1	 1.43	 2.18	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45176	 1	 2.99	 3.9	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45177	 1	 2.39	 4.13	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45178	 1	 0.6	 1.18	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45179	 1	 0.74	 1.31	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45180	 1	 2.02	 3.41	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45181	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45182	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45183	 1	 2.14	 3.82	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45184	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45185	 1	 2.79	 4.52	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45186	 1	 0.92	 1.49	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45187	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45188	 1	 1.95	 3.54	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45189	 1	 2.36	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45190	 1	 0.94	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45191	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45192	 1	 1.08	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45193	 1	 1.43	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45194	 1	 0.97	 2.09	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45195	 1	 1.25	 2.52	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45196	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45197	 1	 1.96	 3.55	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45198	 1	 0.58	 1.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45199	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45200	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45201	 1	 0.67	 1.2	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45202	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45203	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45204	 1	 0.6	 1.11	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45205	 1	 0.61	 0.91	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45206	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45207	 1	 1.16	 1.89	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45208	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45209	 1	 0.54	 1.07	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45210	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45211	 1	 0.99	 1.46	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45212	 1	 0.68	 0.99	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45213	 1	 0.86	 1.68	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45214	 1	 0.18	 0.31	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45215	 1	 0.54	 0.92	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45216	 1	 0.31	 0.63	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45217	 1	 0.29	 0.62	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45218	 1	 1.17	 2.21	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45219	 1	 0.88	 1.3	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45220	 1	 1.38	 1.41	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45221	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45222	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45223	 1	 1.4	 1.95	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45224	 1	 0.93	 1.63	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45225	 1	 3.91	 7.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45226	 1	 1.56	 2.81	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45227	 1	 1.26	 2.04	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45228	 1	 1.4	 3.02	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45229	 1	 2.5	 4.59	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45230	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45231	 1	 0.7	 1.12	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45232	 1	 1.19	 1.87	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45233	 1	 3.89	 5.01	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45234	 1	 1.33	 2.4	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45235	 1	 1.1	 1.79	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45236	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45237	 1	 0.92	 1.8	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45238	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45239	 1	 0.93	 1.36	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45240	 1	 2.91	 5.12	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45241	 1	 2.05	 3.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45242	 1	 2.49	 4.38	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45243	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45244	 1	 2.12	 3.87	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45245	 1	 1.43	 2.25	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45246	 1	 1.27	 2.21	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45247	 1	 0.99	 1.45	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45248	 1	 0.73	 1.3	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45249	 1	 2.34	 2.9	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45250	 1	 0.57	 1.07	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45251	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45252	 1	 0.95	 1.8	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45253	 1	 2.43	 3.62	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45254	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45255	 1	 1.24	 1.82	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45256	 1	 2.36	 4.03	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45257	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45258	 1	 1.17	 2.48	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45259	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45260	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45261	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45262	 1	 1.13	 2.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45263	 1	 1.49	 3.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45264	 1	 1.01	 1.91	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45265	 1	 1.69	 3.32	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45266	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45267	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45268	 1	 1.78	 2.81	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45269	 1	 3.34	 5.02	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45270	 1	 0.84	 1.53	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45271	 1	 3.08	 4.34	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45272	 1	 5.14	 7.62	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45273	 1	 1.82	 2.76	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45274	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45275	 1	 1.01	 1.99	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45276	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45277	 1	 1.63	 2.93	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45278	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45279	 1	 3.46	 4.28	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45280	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45281	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45282	 1	 3.21	 4.66	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45283	 1	 1.85	 3.27	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45284	 1	 2.53	 4.52	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45285	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45286	 1	 1.7	 3.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45287	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45288	 1	 7.69	 12.05	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45289	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45290	 1	 1.65	 2.71	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45291	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45292	 1	 1.3	 1.95	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45293	 1	 4.84	 6.57	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45294	 1	 1.86	 2.77	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45295	 1	 1.69	 2.18	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45296	 1	 0.91	 1.73	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45297	 1	 1.96	 3.71	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45298	 1	 1.72	 2.62	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45299	 1	 2.36	 3.85	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45300	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45301	 1	 2.38	 3.23	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45302	 1	 1.9	 2.71	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45303	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45304	 1	 1.11	 1.66	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45305	 1	 2.46	 4.05	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45306	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45307	 1	 1.6	 3.12	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45308	 1	 3.74	 5.68	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45309	 1	 2.66	 3.73	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45310	 1	 2.26	 3.28	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45311	 1	 2.38	 3.69	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45312	 1	 0.9	 1.39	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45313	 1	 1.32	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45314	 1	 5.78	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45315	 1	 2.91	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45316	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45317	 1	 2.43	 0.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45318	 1	 2.55	 3.5	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45319	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45320	 1	 3.77	 5.39	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45321	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	45322	 1	 3.19	 5.17	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45323	 1	 5.34	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45324	 1	 1.71	 2.75	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45325	 1	 5.0	 6.52	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45326	 1	 1.3	 2.62	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45327	 1	 1.31	 2.83	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45328	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45329	 1	 1.84	 2.9	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45330	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45331	 1	 0.95	 1.69	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45332	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45333	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45334	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45335	 1	 3.8	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45336	 1	 1.33	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45337	 1	 2.12	 2.72	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45338	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45339	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45340	 1	 2.32	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45341	 1	 0.54	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45342	 1	 1.39	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45343	 1	 2.07	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45344	 1	 0.67	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45345	 1	 4.86	 -7.43	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45346	 1	 0.99	 -7.59	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45347	 1	 0.51	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45348	 1	 1.5	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45349	 1	 0.53	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45350	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45351	 1	 1.43	 2.11	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45352	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45353	 1	 1.23	 2.41	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45354	 1	 1.48	 1.98	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45355	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45356	 1	 2.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45357	 1	 2.91	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45358	 1	 3.69	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45359	 1	 2.79	 4.37	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45360	 1	 1.38	 2.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45361	 1	 1.03	 1.83	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45362	 1	 1.95	 3.12	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45363	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45364	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45365	 1	 1.22	 2.22	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45366	 1	 0.73	 1.23	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45367	 1	 1.98	 3.62	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45368	 1	 3.33	 5.92	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45369	 1	 2.38	 2.94	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45370	 1	 1.7	 2.8	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45371	 1	 1.15	 1.71	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45372	 1	 0.36	 0.57	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45373	 1	 1.12	 1.96	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45374	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45375	 1	 0.98	 1.81	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45376	 1	 0.6	 1.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45377	 1	 0.92	 1.74	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45378	 1	 2.98	 4.74	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45379	 1	 1.23	 1.87	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45380	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45381	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45382	 1	 1.56	 2.93	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45383	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45384	 1	 1.84	 3.47	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45385	 1	 1.78	 2.28	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45386	 1	 0.55	 0.94	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45387	 1	 0.13	 0.22	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45388	 1	 2.34	 3.16	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45389	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45390	 1	 1.35	 2.78	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45391	 1	 2.96	 5.18	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45392	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45393	 1	 1.02	 1.56	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45394	 1	 2.04	 2.98	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45395	 1	 5.2	 8.07	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45396	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45397	 1	 2.1	 3.72	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45398	 1	 0.58	 1.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45399	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45400	 1	 1.64	 2.81	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45401	 1	 0.78	 1.6	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45402	 1	 1.35	 2.81	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45403	 1	 0.83	 1.67	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45404	 1	 1.37	 2.56	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45405	 1	 2.63	 5.4	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45406	 1	 1.32	 1.98	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45407	 1	 1.82	 3.43	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45408	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45409	 1	 1.54	 3.29	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45410	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45411	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45412	 1	 4.58	 7.61	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	45413	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45414	 1	 4.23	 6.54	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45415	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45416	 1	 1.73	 3.16	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45417	 1	 1.9	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45418	 1	 2.52	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45419	 1	 1.83	 3.13	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45420	 1	 5.1	 6.35	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45421	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45422	 1	 3.76	 4.54	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45423	 1	 4.2	 6.33	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45424	 1	 3.07	 4.98	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45425	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45426	 1	 2.05	 3.74	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45427	 1	 1.75	 3.18	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45428	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45429	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45430	 1	 1.29	 2.31	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45431	 1	 2.48	 3.28	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45432	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45433	 1	 1.52	 2.7	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45434	 1	 2.36	 4.27	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45435	 1	 1.51	 2.84	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45436	 1	 2.52	 4.74	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45437	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	45438	 1	 3.0	 4.84	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45439	 1	 2.41	 4.31	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45440	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45441	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45442	 1	 5.1	 6.28	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45443	 1	 2.66	 4.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45444	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45445	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45446	 1	 1.98	 0.47	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45447	 1	 2.38	 3.74	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45448	 1	 2.91	 0.7	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45449	 1	 0.96	 1.53	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45450	 1	 0.53	 1.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45451	 1	 0.15	 0.43	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45452	 1	 0.6	 1.65	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45453	 1	 1.68	 3.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45454	 1	 0.16	 0.45	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45455	 1	 1.42	 2.68	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45456	 1	 0.53	 1.49	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45457	 1	 0.3	 0.84	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45458	 1	 1.16	 2.66	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45459	 1	 0.62	 1.72	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45460	 1	 0.29	 0.92	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45461	 1	 0.84	 1.17	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45462	 1	 0.5	 1.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45463	 1	 2.82	 6.01	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45464	 1	 0.83	 1.54	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45465	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45466	 1	 1.04	 1.9	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45467	 1	 3.41	 6.76	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45468	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45469	 1	 3.23	 6.56	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45470	 1	 1.29	 2.51	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45471	 1	 1.58	 3.48	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45472	 1	 0.25	 0.68	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45473	 1	 1.6	 3.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45474	 1	 0.7	 1.7	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45475	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45476	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45477	 1	 2.02	 4.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45478	 1	 0.32	 0.87	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45479	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45480	 1	 1.32	 2.87	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45481	 1	 0.95	 2.43	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45482	 1	 1.23	 2.72	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45483	 1	 0.71	 2.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45484	 1	 0.82	 2.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45485	 1	 0.6	 1.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45486	 1	 0.55	 1.62	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45487	 1	 1.03	 2.49	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45488	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45489	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45490	 1	 0.83	 1.71	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45491	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45492	 1	 0.41	 1.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45493	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45494	 1	 0.51	 1.34	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45495	 1	 3.14	 6.47	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45496	 1	 0.97	 1.74	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45497	 1	 1.67	 3.46	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45498	 1	 0.9	 2.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45499	 1	 4.21	 8.97	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45500	 1	 1.27	 2.95	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45501	 1	 1.38	 3.67	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45502	 1	 2.95	 4.56	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45503	 1	 0.78	 2.5	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45504	 1	 2.37	 4.52	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45505	 1	 3.42	 5.43	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45506	 1	 4.83	 9.45	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45507	 1	 0.66	 2.1	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45508	 1	 0.84	 2.29	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45509	 1	 0.54	 1.49	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45510	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45511	 1	 1.24	 3.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45512	 1	 0.47	 1.48	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45513	 1	 2.19	 3.74	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45514	 1	 1.6	 3.85	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45515	 1	 2.6	 5.43	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45516	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45517	 1	 1.27	 3.31	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45518	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45519	 1	 0.4	 1.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45520	 1	 0.12	 0.41	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45521	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45522	 1	 0.56	 1.56	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45523	 1	 1.23	 3.55	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45524	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45525	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45526	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45527	 1	 0.53	 1.2	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45528	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45529	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45530	 1	 0.72	 1.99	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45531	 1	 1.94	 3.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45532	 1	 3.38	 6.91	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45533	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	45534	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	45535	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45536	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45537	 1	 2.31	 3.79	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45538	 1	 1.04	 2.6	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45539	 1	 0.21	 0.69	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45540	 1	 0.37	 1.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45541	 1	 0.97	 1.75	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45542	 1	 1.67	 2.82	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45543	 1	 2.3	 3.82	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45544	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45545	 1	 0.87	 2.49	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45546	 1	 0.42	 1.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45547	 1	 0.52	 1.35	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45548	 1	 0.85	 2.31	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45549	 1	 0.32	 1.07	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45550	 1	 0.37	 1.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45551	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45552	 1	 2.8	 6.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45553	 1	 0.45	 1.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45554	 1	 0.81	 2.31	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45555	 1	 3.16	 5.75	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45556	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45557	 1	 3.1	 5.23	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45558	 1	 0.63	 1.82	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45559	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45560	 1	 0.99	 2.57	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45561	 1	 1.31	 3.52	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45562	 1	 2.54	 4.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45563	 1	 3.42	 7.25	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45564	 1	 0.58	 1.75	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45565	 1	 2.98	 5.85	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45566	 1	 1.38	 2.3	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45567	 1	 1.54	 2.74	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45568	 1	 1.17	 2.86	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45569	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45570	 1	 1.27	 3.35	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45571	 1	 0.95	 2.56	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45572	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45573	 1	 0.34	 0.99	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45574	 1	 3.61	 4.46	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45575	 1	 2.13	 3.86	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45576	 1	 1.66	 3.23	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45577	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45578	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45579	 1	 0.72	 1.54	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45580	 1	 0.83	 2.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45581	 1	 0.66	 1.69	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45582	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45583	 1	 0.64	 1.86	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45584	 1	 1.35	 2.53	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45585	 1	 3.75	 6.36	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45586	 1	 0.35	 0.96	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45587	 1	 0.35	 1.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45588	 1	 0.27	 0.87	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45589	 1	 2.38	 4.17	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45590	 1	 2.54	 5.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45591	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45592	 1	 0.28	 0.79	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45593	 1	 0.34	 0.93	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45594	 1	 0.63	 1.42	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45595	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45596	 1	 0.66	 1.8	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45597	 1	 0.94	 2.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45598	 1	 0.34	 1.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45599	 1	 1.61	 2.99	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45600	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45601	 1	 0.51	 1.5	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45602	 1	 0.72	 2.19	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45603	 1	 3.52	 6.56	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45604	 1	 1.4	 2.81	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45605	 1	 0.86	 2.91	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45606	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45607	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45608	 1	 0.35	 0.95	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45609	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45610	 1	 0.33	 0.84	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45611	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45612	 1	 0.66	 1.41	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45613	 1	 2.1	 4.67	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45614	 1	 0.34	 0.96	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45615	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45616	 1	 0.6	 1.25	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45617	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45618	 1	 2.5	 5.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45619	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45620	 1	 0.22	 0.69	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45621	 1	 1.03	 2.46	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45622	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45623	 1	 0.65	 1.95	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45624	 1	 0.52	 1.43	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45625	 1	 0.59	 2.03	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45626	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45627	 1	 0.65	 1.83	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45628	 1	 0.56	 1.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45629	 1	 0.67	 1.65	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45630	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45631	 1	 1.34	 3.01	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45632	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45633	 1	 0.67	 2.02	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45634	 1	 0.48	 1.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45635	 1	 0.86	 1.76	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45636	 1	 0.37	 1.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45637	 1	 0.37	 1.03	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45638	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45639	 1	 2.42	 5.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45640	 1	 1.17	 3.24	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45641	 1	 3.0	 5.75	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45642	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45643	 1	 0.34	 0.95	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45644	 1	 0.96	 2.24	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45645	 1	 1.02	 2.74	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45646	 1	 0.4	 1.42	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45647	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45648	 1	 3.59	 8.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45649	 1	 0.68	 1.57	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45650	 1	 0.19	 0.57	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45651	 1	 0.42	 1.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45652	 1	 0.46	 1.48	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45653	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45654	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45655	 1	 1.07	 2.76	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45656	 1	 0.75	 2.39	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45657	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45658	 1	 1.56	 4.86	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45659	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45660	 1	 0.28	 0.86	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45661	 1	 6.54	 11.44	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45662	 1	 0.86	 2.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45663	 1	 0.79	 2.36	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45664	 1	 1.7	 3.61	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45665	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45666	 1	 2.23	 4.93	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45667	 1	 2.24	 4.63	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45668	 1	 2.48	 5.59	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45669	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45670	 1	 1.39	 3.9	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45671	 1	 0.91	 1.89	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45672	 1	 0.77	 2.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45673	 1	 1.37	 2.77	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45674	 1	 2.49	 5.37	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45675	 1	 0.49	 1.37	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45676	 1	 1.82	 3.42	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45677	 1	 1.6	 3.26	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45678	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	45679	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45680	 1	 0.7	 1.72	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45681	 1	 1.61	 2.97	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45682	 1	 1.3	 2.85	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45683	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45684	 1	 0.83	 2.31	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45685	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45686	 1	 1.35	 3.17	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45687	 1	 1.03	 2.71	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45688	 1	 0.52	 1.53	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45689	 1	 1.29	 3.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45690	 1	 0.63	 1.64	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45691	 1	 0.8	 1.99	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45692	 1	 0.7	 1.91	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45693	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45694	 1	 3.34	 4.85	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45695	 1	 1.43	 2.91	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45696	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45697	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45698	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45699	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45700	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45701	 1	 1.71	 3.15	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45702	 1	 1.6	 3.46	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45703	 1	 1.77	 2.73	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45704	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45705	 1	 0.79	 1.75	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45706	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45707	 1	 1.31	 2.17	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45708	 1	 2.52	 4.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45709	 1	 2.01	 3.57	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45710	 1	 3.13	 5.42	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45711	 1	 4.0	 7.3	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45712	 1	 2.41	 5.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45713	 1	 0.86	 2.23	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45714	 1	 1.81	 2.57	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45715	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45716	 1	 1.71	 2.93	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45717	 1	 0.26	 0.85	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45718	 1	 0.55	 1.37	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45719	 1	 0.31	 0.82	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45720	 1	 0.43	 1.35	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45721	 1	 0.36	 1.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45722	 1	 0.43	 1.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45723	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45724	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45725	 1	 0.41	 0.95	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45726	 1	 0.29	 0.96	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45727	 1	 2.99	 5.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45728	 1	 1.06	 2.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45729	 1	 0.75	 1.61	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45730	 1	 0.94	 2.22	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45731	 1	 0.48	 1.66	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45732	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45733	 1	 0.98	 2.32	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45734	 1	 1.96	 4.81	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45735	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45736	 1	 0.98	 2.84	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45737	 1	 1.7	 3.81	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45738	 1	 1.01	 2.42	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45739	 1	 0.68	 1.53	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45740	 1	 3.43	 4.5	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45741	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45742	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45743	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45744	 1	 0.5	 1.43	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45745	 1	 3.01	 6.23	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45746	 1	 2.78	 5.9	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45747	 1	 0.98	 2.43	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45748	 1	 0.57	 1.73	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45749	 1	 3.39	 7.13	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45750	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45751	 1	 1.51	 3.81	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45752	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45753	 1	 0.61	 1.7	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45754	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45755	 1	 1.21	 2.87	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45756	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45757	 1	 0.41	 1.32	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45758	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45759	 1	 1.79	 3.88	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45760	 1	 0.62	 1.62	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45761	 1	 2.97	 7.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45762	 1	 0.76	 2.24	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45763	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45764	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45765	 1	 0.98	 2.94	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	45766	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45767	 1	 0.35	 1.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45768	 1	 0.25	 0.71	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45769	 1	 0.87	 2.45	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45770	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45771	 1	 1.38	 3.95	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45772	 1	 0.31	 0.91	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45773	 1	 1.62	 2.91	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45774	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45775	 1	 0.6	 1.74	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45776	 1	 0.46	 1.51	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45777	 1	 0.36	 1.09	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45778	 1	 1.47	 4.03	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45779	 1	 1.93	 5.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45780	 1	 2.27	 5.17	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45781	 1	 2.02	 3.49	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45782	 1	 1.73	 3.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45783	 1	 2.91	 4.42	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45784	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45785	 1	 1.86	 4.99	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45786	 1	 1.63	 4.03	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45787	 1	 0.64	 2.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45788	 1	 0.66	 2.37	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45789	 1	 0.22	 0.51	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45790	 1	 0.42	 1.03	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45791	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45792	 1	 0.54	 1.46	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45793	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45794	 1	 2.14	 3.6	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45795	 1	 1.3	 2.51	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45796	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45797	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45798	 1	 1.46	 2.75	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45799	 1	 2.84	 5.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45800	 1	 0.59	 1.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45801	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45802	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45803	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45804	 1	 0.88	 2.07	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45805	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45806	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45807	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45808	 1	 1.76	 4.31	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45809	 1	 5.22	 8.02	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45810	 1	 0.39	 1.2	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45811	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45812	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45813	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45814	 1	 0.58	 1.2	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45815	 1	 0.45	 1.03	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45816	 1	 0.55	 1.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45817	 1	 0.33	 1.01	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45818	 1	 1.61	 2.82	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45819	 1	 0.54	 1.3	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45820	 1	 0.39	 1.3	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45821	 1	 0.71	 1.84	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45822	 1	 1.51	 3.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45823	 1	 0.62	 1.63	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45824	 1	 1.29	 2.72	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45825	 1	 0.67	 1.46	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45826	 1	 0.26	 0.72	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45827	 1	 0.65	 1.53	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45828	 1	 1.33	 2.41	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45829	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45830	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45831	 1	 0.67	 1.86	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45832	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45833	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45834	 1	 0.91	 2.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45835	 1	 2.94	 5.35	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45836	 1	 2.58	 5.59	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45837	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45838	 1	 0.42	 1.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45839	 1	 0.37	 1.12	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45840	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45841	 1	 0.54	 1.73	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45842	 1	 0.73	 2.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45843	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45844	 1	 2.5	 5.7	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45845	 1	 0.29	 0.81	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45846	 1	 0.31	 0.84	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45847	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45848	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45849	 1	 1.94	 4.85	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45850	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45851	 1	 1.74	 4.13	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45852	 1	 0.8	 2.03	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45853	 1	 1.4	 1.93	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45854	 1	 2.3	 5.34	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45855	 1	 2.52	 3.19	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45856	 1	 1.97	 3.66	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45857	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45858	 1	 1.45	 2.59	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45859	 1	 0.49	 1.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45860	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45861	 1	 1.15	 0.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45862	 1	 0.89	 0.24	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45863	 1	 0.78	 0.21	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45864	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45865	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45866	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45867	 1	 0.29	 0.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45868	 1	 0.62	 0.17	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45869	 1	 0.73	 0.2	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45870	 1	 0.57	 0.16	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45871	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45872	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45873	 1	 0.88	 0.25	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45874	 1	 1.42	 0.39	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45875	 1	 0.37	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45876	 1	 0.6	 0.16	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45877	 1	 2.2	 0.6	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45878	 1	 0.25	 0.07	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45879	 1	 0.64	 0.17	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45880	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45881	 1	 0.59	 0.16	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45882	 1	 1.21	 0.33	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45883	 1	 0.87	 0.24	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45884	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45885	 1	 1.95	 0.54	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45886	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	45887	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45888	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45889	 1	 0.5	 0.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45890	 1	 1.46	 0.39	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45891	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45892	 1	 0.53	 0.15	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45893	 1	 0.52	 0.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45894	 1	 2.13	 0.57	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45895	 1	 2.0	 2.79	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45896	 1	 0.7	 1.74	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45897	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45898	 1	 1.82	 4.11	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45899	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45900	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45901	 1	 3.24	 4.43	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45902	 1	 1.31	 2.96	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45903	 1	 0.52	 1.62	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45904	 1	 0.23	 0.79	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45905	 1	 0.58	 1.67	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45906	 1	 0.33	 1.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45907	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45908	 1	 1.56	 2.69	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45909	 1	 1.19	 2.45	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45910	 1	 2.84	 6.56	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45911	 1	 0.61	 1.67	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45912	 1	 1.43	 3.48	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45913	 1	 1.63	 2.78	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45914	 1	 1.48	 3.29	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45915	 1	 0.86	 2.42	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45916	 1	 1.48	 2.65	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45917	 1	 2.27	 5.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45918	 1	 3.18	 4.99	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45919	 1	 24.17	 37.17	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45920	 1	 2.1	 4.49	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45921	 1	 0.35	 1.03	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45922	 1	 0.7	 2.25	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45923	 1	 0.41	 1.15	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45924	 1	 0.33	 1.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45925	 1	 0.7	 1.97	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45926	 1	 0.56	 1.35	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45927	 1	 0.5	 1.31	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45928	 1	 1.84	 3.89	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45929	 1	 0.29	 0.79	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45930	 1	 0.33	 0.99	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45931	 1	 0.82	 2.02	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45932	 1	 0.65	 1.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45933	 1	 2.49	 4.2	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45934	 1	 2.4	 5.17	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45935	 1	 0.3	 0.79	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45936	 1	 2.47	 3.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45937	 1	 2.04	 3.03	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45938	 1	 0.21	 0.65	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45939	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45940	 1	 0.64	 1.71	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45941	 1	 1.89	 3.71	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45942	 1	 2.11	 3.64	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45943	 1	 0.37	 1.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45944	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45945	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45946	 1	 1.05	 1.73	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45947	 1	 0.71	 2.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45948	 1	 1.48	 3.44	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45949	 1	 5.54	 11.07	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45950	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45951	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45952	 1	 1.75	 4.1	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45953	 1	 0.47	 1.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45954	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45955	 1	 1.53	 2.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45956	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45957	 1	 1.02	 2.3	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45958	 1	 2.03	 3.85	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45959	 1	 2.13	 4.32	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45960	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45961	 1	 1.46	 3.03	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45962	 1	 1.28	 3.28	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	45963	 1	 2.59	 3.35	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45964	 1	 2.16	 3.87	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45965	 1	 0.42	 1.27	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45966	 1	 0.77	 2.25	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45967	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45968	 1	 0.42	 1.32	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45969	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45970	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45971	 1	 2.1	 4.72	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45972	 1	 0.68	 2.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45973	 1	 2.2	 3.76	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45974	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	45975	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45976	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45977	 1	 2.08	 4.95	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45978	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45979	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45980	 1	 1.66	 4.28	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45981	 1	 12.74	 18.58	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45982	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45983	 1	 1.87	 4.74	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45984	 1	 0.45	 1.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45985	 1	 1.8	 3.86	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45986	 1	 1.64	 4.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45987	 1	 0.95	 1.99	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45988	 1	 3.1	 6.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45989	 1	 1.31	 2.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45990	 1	 2.17	 4.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45991	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45992	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45993	 1	 0.9	 2.3	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45994	 1	 0.43	 1.21	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45995	 1	 0.56	 1.39	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45996	 1	 0.42	 1.29	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45997	 1	 0.81	 2.22	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	45998	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	45999	 1	 1.23	 2.93	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46000	 1	 2.02	 3.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46001	 1	 6.85	 9.78	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46002	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46003	 1	 0.36	 0.86	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46004	 1	 0.37	 0.83	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46005	 1	 1.26	 2.68	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46006	 1	 0.28	 0.87	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46007	 1	 2.81	 4.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46008	 1	 0.25	 0.6	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46009	 1	 0.31	 0.87	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46010	 1	 1.09	 0.31	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46011	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46012	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46013	 1	 0.97	 0.28	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46014	 1	 0.16	 0.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46015	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46016	 1	 0.2	 0.06	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46017	 1	 0.42	 0.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46018	 1	 1.19	 0.34	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46019	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46020	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46021	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46022	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46023	 1	 0.81	 0.22	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46024	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46025	 1	 3.04	 0.86	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46026	 1	 1.52	 0.43	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46027	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46028	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46029	 1	 0.44	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46030	 1	 0.76	 0.21	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46031	 1	 0.43	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46032	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46033	 1	 0.34	 0.09	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46034	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46035	 1	 2.03	 0.57	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46036	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46037	 1	 1.22	 0.35	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46038	 1	 0.58	 0.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46039	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46040	 1	 1.39	 0.39	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46041	 1	 0.31	 0.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46042	 1	 0.22	 0.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46043	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46044	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46045	 1	 0.56	 0.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46046	 1	 0.39	 0.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46047	 1	 0.46	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46048	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46049	 1	 0.86	 0.24	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46050	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46051	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46052	 1	 0.25	 0.07	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46053	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46054	 1	 0.28	 0.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46055	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46056	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46057	 1	 1.0	 0.29	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46058	 1	 2.93	 0.83	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46059	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46060	 1	 0.47	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46061	 1	 0.32	 0.09	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46062	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46063	 1	 0.43	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46064	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46065	 1	 0.56	 0.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46066	 1	 0.37	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46067	 1	 0.18	 0.05	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46068	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46069	 1	 0.4	 0.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46070	 1	 0.46	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46071	 1	 0.7	 0.19	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46072	 1	 0.31	 0.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46073	 1	 0.37	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46074	 1	 0.6	 0.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46075	 1	 0.29	 0.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46076	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46077	 1	 0.32	 0.09	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46078	 1	 1.04	 0.3	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46079	 1	 0.27	 0.07	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46080	 1	 0.28	 0.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46081	 1	 0.33	 0.09	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46082	 1	 0.16	 0.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46083	 1	 0.3	 0.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46084	 1	 0.52	 0.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46085	 1	 0.43	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46086	 1	 0.31	 0.09	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46087	 1	 0.4	 0.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46088	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46089	 1	 1.16	 0.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46090	 1	 0.29	 0.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46091	 1	 0.77	 0.21	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46092	 1	 1.7	 0.48	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46093	 1	 0.48	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46094	 1	 0.76	 0.21	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46095	 1	 0.21	 0.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46096	 1	 0.14	 0.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46097	 1	 0.24	 0.07	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46098	 1	 0.14	 0.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46099	 1	 0.16	 0.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46100	 1	 0.15	 0.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46101	 1	 0.23	 0.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46102	 1	 1.02	 0.29	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46103	 1	 0.67	 0.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46104	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46105	 1	 0.21	 0.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46106	 1	 0.38	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46107	 1	 0.88	 0.24	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46108	 1	 0.23	 0.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46109	 1	 0.25	 0.07	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46110	 1	 0.96	 0.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46111	 1	 0.17	 0.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46112	 1	 0.67	 0.19	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46113	 1	 0.18	 0.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46114	 1	 0.24	 0.07	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46115	 1	 1.37	 0.39	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46116	 1	 0.37	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46117	 1	 0.16	 0.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46118	 1	 0.65	 0.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46119	 1	 0.66	 0.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46120	 1	 0.19	 0.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46121	 1	 0.35	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46122	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46123	 1	 0.49	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46124	 1	 0.24	 0.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46125	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46126	 1	 0.16	 0.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46127	 1	 0.97	 0.27	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46128	 1	 0.42	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46129	 1	 0.19	 0.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46130	 1	 0.22	 0.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46131	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46132	 1	 0.21	 0.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46133	 1	 0.37	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46134	 1	 0.48	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46135	 1	 1.94	 0.54	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46136	 1	 0.35	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46137	 1	 1.51	 0.43	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46138	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46139	 1	 0.46	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46140	 1	 0.26	 0.07	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46141	 1	 0.16	 0.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46142	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46143	 1	 0.43	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46144	 1	 0.67	 0.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46145	 1	 0.36	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46146	 1	 0.96	 0.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46147	 1	 0.47	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46148	 1	 0.59	 0.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46149	 1	 0.79	 0.22	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46150	 1	 2.98	 0.84	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46151	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46152	 1	 0.47	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46153	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46154	 1	 0.45	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46155	 1	 0.76	 0.21	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46156	 1	 1.35	 0.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46157	 1	 0.27	 0.07	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46158	 1	 0.42	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46159	 1	 0.52	 0.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46160	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46161	 1	 0.45	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46162	 1	 0.77	 0.21	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46163	 1	 4.92	 1.38	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46164	 1	 0.18	 0.05	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46165	 1	 0.17	 0.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46166	 1	 0.51	 0.14	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46167	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46168	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46169	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46170	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46171	 1	 0.22	 0.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46172	 1	 1.12	 0.31	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46173	 1	 1.01	 0.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46174	 1	 0.7	 0.19	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46175	 1	 0.55	 0.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46176	 1	 0.28	 0.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46177	 1	 0.51	 0.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46178	 1	 0.47	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46179	 1	 0.6	 0.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46180	 1	 0.68	 0.19	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46181	 1	 0.63	 0.17	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46182	 1	 0.48	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46183	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46184	 1	 2.53	 0.71	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46185	 1	 0.84	 0.23	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46186	 1	 0.51	 0.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46187	 1	 0.5	 0.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46188	 1	 0.42	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46189	 1	 0.59	 0.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46190	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46191	 1	 0.43	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46192	 1	 0.38	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46193	 1	 0.34	 0.09	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46194	 1	 0.15	 0.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46195	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46196	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46197	 1	 0.37	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46198	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46199	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46200	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46201	 1	 0.65	 0.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46202	 1	 0.57	 0.17	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46203	 1	 0.24	 0.07	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46204	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46205	 1	 0.17	 0.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46206	 1	 2.04	 0.57	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46207	 1	 1.54	 0.43	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46208	 1	 0.59	 0.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46209	 1	 0.79	 0.22	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46210	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46211	 1	 0.52	 0.14	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46212	 1	 0.56	 0.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46213	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46214	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46215	 1	 0.98	 0.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46216	 1	 0.42	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46217	 1	 0.4	 0.11	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46218	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46219	 1	 3.65	 1.02	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46220	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46221	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46222	 1	 0.44	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46223	 1	 0.46	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46224	 1	 0.77	 0.21	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46225	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46226	 1	 0.46	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46227	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46228	 1	 0.51	 0.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46229	 1	 0.24	 0.07	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46230	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46231	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46232	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46233	 1	 0.72	 0.2	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46234	 1	 0.94	 0.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46235	 1	 0.23	 0.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46236	 1	 0.72	 0.2	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46237	 1	 2.68	 0.75	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46238	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46239	 1	 2.04	 0.57	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46240	 1	 1.27	 0.36	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46241	 1	 0.45	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46242	 1	 1.21	 0.34	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46243	 1	 0.71	 0.19	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46244	 1	 0.98	 0.27	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46245	 1	 0.74	 0.2	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46246	 1	 0.36	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46247	 1	 0.44	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46248	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46249	 1	 0.89	 0.24	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46250	 1	 1.38	 0.39	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46251	 1	 0.49	 0.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46252	 1	 0.96	 0.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46253	 1	 0.69	 0.19	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46254	 1	 0.22	 0.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46255	 1	 1.3	 0.37	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46256	 1	 0.43	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46257	 1	 1.29	 0.36	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46258	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46259	 1	 0.51	 0.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46260	 1	 0.67	 0.18	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46261	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46262	 1	 0.63	 0.17	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46263	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46264	 1	 1.15	 0.32	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46265	 1	 0.88	 0.24	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46266	 1	 0.75	 0.2	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46267	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46268	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46269	 1	 3.28	 0.92	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46270	 1	 1.1	 0.31	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46271	 1	 6.19	 1.74	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46272	 1	 0.67	 0.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46273	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46274	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46275	 1	 0.42	 0.11	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46276	 1	 0.99	 0.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46277	 1	 1.45	 0.41	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46278	 1	 1.8	 0.5	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46279	 1	 0.53	 0.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46280	 1	 0.59	 0.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46281	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46282	 1	 1.48	 0.42	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46283	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46284	 1	 0.85	 0.23	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46285	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46286	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46287	 1	 0.49	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46288	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46289	 1	 0.19	 0.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46290	 1	 0.33	 0.09	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46291	 1	 0.17	 0.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46292	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46293	 1	 0.69	 0.19	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46294	 1	 0.25	 0.07	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46295	 1	 0.15	 0.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46296	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46297	 1	 5.91	 1.66	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46298	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46299	 1	 0.34	 0.09	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46300	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46301	 1	 0.24	 0.07	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46302	 1	 0.66	 0.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46303	 1	 10.66	 2.96	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46304	 1	 0.78	 0.22	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46305	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46306	 1	 0.72	 2.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46307	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46308	 1	 2.88	 4.99	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46309	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46310	 1	 2.98	 6.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46311	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46312	 1	 0.74	 2.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46313	 1	 0.53	 1.29	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46314	 1	 1.19	 3.05	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46315	 1	 0.38	 1.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46316	 1	 1.73	 3.99	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46317	 1	 1.18	 2.01	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46318	 1	 1.75	 2.48	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46319	 1	 1.37	 2.77	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46320	 1	 0.92	 2.32	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46321	 1	 2.55	 4.7	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46322	 1	 0.65	 1.97	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46323	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46324	 1	 1.23	 3.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46325	 1	 0.22	 0.55	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46326	 1	 1.25	 2.55	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46327	 1	 0.43	 1.21	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46328	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46329	 1	 0.26	 0.76	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46330	 1	 0.45	 1.34	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46331	 1	 0.87	 1.83	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46332	 1	 0.57	 1.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46333	 1	 0.28	 0.69	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46334	 1	 0.41	 0.91	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46335	 1	 0.27	 0.86	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46336	 1	 0.77	 1.76	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46337	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46338	 1	 1.15	 3.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46339	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46340	 1	 0.64	 1.75	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46341	 1	 0.52	 1.51	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46342	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46343	 1	 0.84	 2.18	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46344	 1	 1.1	 2.69	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46345	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46346	 1	 0.37	 0.81	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46347	 1	 0.39	 1.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46348	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46349	 1	 0.79	 2.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46350	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46351	 1	 0.88	 2.27	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46352	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46353	 1	 0.78	 2.44	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46354	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46355	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46356	 1	 3.88	 9.13	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46357	 1	 1.52	 2.21	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46358	 1	 0.82	 1.8	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46359	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46360	 1	 3.41	 7.58	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46361	 1	 1.19	 3.77	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46362	 1	 0.37	 0.9	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46363	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46364	 1	 6.13	 10.64	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46365	 1	 0.4	 1.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46366	 1	 1.34	 3.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46367	 1	 1.51	 2.66	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46368	 1	 3.21	 6.07	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46369	 1	 3.24	 6.83	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46370	 1	 0.56	 1.63	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46371	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46372	 1	 1.28	 3.31	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46373	 1	 0.72	 2.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46374	 1	 0.63	 1.49	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46375	 1	 1.04	 3.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46376	 1	 0.53	 1.42	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46377	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46378	 1	 1.53	 3.29	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46379	 1	 1.09	 2.46	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46380	 1	 0.81	 1.97	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46381	 1	 4.67	 8.15	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46382	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46383	 1	 0.58	 2.04	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46384	 1	 4.35	 7.39	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46385	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46386	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46387	 1	 1.01	 0.29	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46388	 1	 0.54	 0.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46389	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46390	 1	 1.4	 0.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46391	 1	 0.76	 0.22	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46392	 1	 0.46	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46393	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46394	 1	 0.77	 0.22	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46395	 1	 0.68	 0.19	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46396	 1	 0.34	 0.09	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46397	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46398	 1	 0.88	 2.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46399	 1	 0.46	 1.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46400	 1	 0.82	 2.62	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46401	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46402	 1	 1.02	 2.66	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46403	 1	 1.68	 3.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46404	 1	 1.06	 2.69	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46405	 1	 2.05	 4.31	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46406	 1	 0.66	 1.89	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46407	 1	 0.81	 1.8	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46408	 1	 0.62	 1.61	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46409	 1	 0.57	 1.73	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46410	 1	 0.44	 1.25	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46411	 1	 0.77	 1.61	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46412	 1	 1.74	 3.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46413	 1	 4.2	 8.92	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46414	 1	 0.72	 2.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46415	 1	 1.89	 3.39	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46416	 1	 2.04	 3.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46417	 1	 0.52	 1.73	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46418	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46419	 1	 0.68	 1.54	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46420	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46421	 1	 1.32	 2.95	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46422	 1	 0.81	 2.21	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46423	 1	 3.19	 5.54	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46424	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46425	 1	 2.43	 4.91	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46426	 1	 0.58	 1.34	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46427	 1	 0.61	 1.69	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46428	 1	 11.77	 23.08	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46429	 1	 1.51	 3.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46430	 1	 0.6	 1.51	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46431	 1	 1.27	 2.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46432	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46433	 1	 0.42	 1.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46434	 1	 2.5	 3.45	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46435	 1	 0.4	 0.92	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46436	 1	 2.44	 3.41	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46437	 1	 0.36	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46438	 1	 1.06	 0.29	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46439	 1	 19.46	 5.44	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46440	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46441	 1	 1.41	 0.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46442	 1	 0.6	 0.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46443	 1	 3.18	 0.89	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46444	 1	 4.38	 1.22	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46445	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46446	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46447	 1	 0.69	 0.19	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46448	 1	 1.36	 0.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46449	 1	 0.7	 0.19	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46450	 1	 0.51	 0.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46451	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46452	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46453	 1	 1.0	 0.28	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46454	 1	 0.7	 0.19	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46455	 1	 0.54	 0.15	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46456	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46457	 1	 0.69	 0.2	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46458	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46459	 1	 0.35	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46460	 1	 0.82	 0.24	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46461	 1	 1.81	 0.51	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46462	 1	 0.32	 0.09	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46463	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46464	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46465	 1	 2.77	 0.77	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46466	 1	 0.58	 0.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46467	 1	 0.6	 0.17	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46468	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46469	 1	 1.66	 0.46	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46470	 1	 2.26	 0.62	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46471	 1	 0.32	 0.09	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46472	 1	 0.95	 0.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46473	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46474	 1	 1.2	 0.32	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46475	 1	 1.67	 0.45	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46476	 1	 2.6	 0.7	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46477	 1	 0.54	 0.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46478	 1	 1.2	 0.32	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46479	 1	 0.69	 0.19	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46480	 1	 2.23	 0.6	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46481	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46482	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46483	 1	 0.74	 1.63	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46484	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46485	 1	 0.72	 2.15	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46486	 1	 0.15	 0.36	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46487	 1	 0.31	 1.01	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46488	 1	 0.6	 1.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46489	 1	 3.2	 6.31	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46490	 1	 1.29	 2.56	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46491	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46492	 1	 1.46	 3.08	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46493	 1	 0.42	 1.43	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46494	 1	 0.4	 1.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46495	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46496	 1	 0.75	 2.19	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46497	 1	 1.24	 3.29	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46498	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46499	 1	 2.13	 4.83	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46500	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46501	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46502	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46503	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46504	 1	 0.55	 1.81	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46505	 1	 1.71	 4.22	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46506	 1	 0.79	 2.24	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46507	 1	 0.3	 0.94	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46508	 1	 0.52	 1.67	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46509	 1	 0.62	 1.75	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46510	 1	 0.3	 0.81	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46511	 1	 0.51	 1.21	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46512	 1	 0.64	 1.7	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46513	 1	 0.38	 1.04	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46514	 1	 2.68	 5.4	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46515	 1	 6.45	 10.19	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46516	 1	 0.43	 1.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46517	 1	 0.72	 2.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46518	 1	 3.53	 6.85	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46519	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46520	 1	 1.93	 4.82	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46521	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46522	 1	 0.8	 2.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46523	 1	 1.97	 3.74	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46524	 1	 0.79	 2.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46525	 1	 0.22	 0.58	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46526	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46527	 1	 0.68	 1.61	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46528	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46529	 1	 0.43	 1.22	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46530	 1	 1.51	 4.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46531	 1	 1.59	 3.34	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46532	 1	 0.73	 2.46	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46533	 1	 1.98	 5.21	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46534	 1	 2.91	 5.71	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46535	 1	 1.16	 2.43	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46536	 1	 1.45	 3.32	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46537	 1	 1.17	 2.25	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46538	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46539	 1	 2.23	 4.44	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46540	 1	 3.73	 8.93	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46541	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46542	 1	 1.63	 4.27	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46543	 1	 1.56	 4.02	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46544	 1	 0.79	 2.23	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46545	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46546	 1	 0.76	 2.19	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46547	 1	 0.99	 2.03	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46548	 1	 1.27	 2.73	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46549	 1	 1.87	 3.86	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46550	 1	 2.17	 3.19	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46551	 1	 1.33	 2.53	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46552	 1	 0.67	 1.66	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46553	 1	 1.33	 3.52	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46554	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46555	 1	 0.82	 2.07	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46556	 1	 2.97	 4.89	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46557	 1	 0.29	 0.74	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46558	 1	 0.69	 1.65	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46559	 1	 0.59	 1.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46560	 1	 0.18	 0.55	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46561	 1	 0.43	 1.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46562	 1	 0.41	 1.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46563	 1	 0.25	 0.6	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46564	 1	 1.48	 2.79	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46565	 1	 1.63	 3.89	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46566	 1	 2.73	 4.62	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46567	 1	 1.07	 2.65	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46568	 1	 1.01	 1.99	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46569	 1	 1.02	 2.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46570	 1	 0.46	 1.46	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46571	 1	 0.72	 1.88	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46572	 1	 0.43	 1.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46573	 1	 1.44	 3.28	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46574	 1	 0.32	 1.11	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46575	 1	 0.55	 1.83	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46576	 1	 3.56	 6.91	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46577	 1	 4.42	 8.14	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46578	 1	 0.97	 2.45	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46579	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46580	 1	 7.79	 14.84	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46581	 1	 1.21	 3.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46582	 1	 0.51	 1.47	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46583	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46584	 1	 0.93	 2.48	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46585	 1	 0.59	 1.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46586	 1	 0.89	 2.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46587	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46588	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46589	 1	 2.19	 4.2	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46590	 1	 3.03	 5.73	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46591	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46592	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46593	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46594	 1	 0.69	 1.76	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46595	 1	 1.48	 3.7	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46596	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46597	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46598	 1	 1.03	 2.65	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46599	 1	 0.84	 1.96	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46600	 1	 0.35	 0.89	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46601	 1	 0.44	 1.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46602	 1	 1.71	 3.58	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46603	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46604	 1	 0.59	 1.54	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46605	 1	 1.81	 3.98	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46606	 1	 0.46	 1.46	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46607	 1	 0.51	 1.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46608	 1	 1.75	 3.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46609	 1	 1.21	 2.02	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46610	 1	 3.52	 6.81	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46611	 1	 0.97	 2.45	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46612	 1	 1.29	 2.42	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46613	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46614	 1	 0.56	 1.42	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46615	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46616	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46617	 1	 0.38	 1.36	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46618	 1	 0.5	 1.74	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46619	 1	 0.43	 1.24	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46620	 1	 0.62	 1.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46621	 1	 0.71	 1.6	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46622	 1	 2.27	 4.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46623	 1	 0.97	 2.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46624	 1	 0.86	 1.87	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46625	 1	 7.32	 13.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46626	 1	 1.01	 0.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46627	 1	 1.24	 2.94	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46628	 1	 0.44	 1.31	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46629	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46630	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46631	 1	 0.6	 1.42	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46632	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46633	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46634	 1	 0.62	 1.67	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46635	 1	 1.55	 2.73	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46636	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46637	 1	 2.14	 5.25	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46638	 1	 2.57	 4.68	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46639	 1	 2.24	 0.59	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46640	 1	 0.33	 0.95	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46641	 1	 3.42	 6.62	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46642	 1	 1.81	 3.98	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46643	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46644	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46645	 1	 0.68	 0.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46646	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46647	 1	 0.32	 0.89	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46648	 1	 0.64	 1.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46649	 1	 0.72	 1.89	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46650	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46651	 1	 0.83	 1.94	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46652	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46653	 1	 0.43	 1.31	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46654	 1	 2.08	 3.56	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46655	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46656	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46657	 1	 0.55	 1.99	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46658	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46659	 1	 0.39	 1.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46660	 1	 1.61	 4.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46661	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46662	 1	 1.17	 2.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46663	 1	 0.38	 0.93	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46664	 1	 1.03	 3.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46665	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46666	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46667	 1	 0.36	 1.2	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46668	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46669	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46670	 1	 1.33	 2.67	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46671	 1	 1.71	 4.35	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46672	 1	 0.28	 0.88	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46673	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46674	 1	 0.78	 2.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46675	 1	 0.58	 1.76	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46676	 1	 5.44	 9.43	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46677	 1	 0.68	 0.2	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46678	 1	 1.98	 3.31	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46679	 1	 3.45	 7.46	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46680	 1	 1.82	 3.67	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46681	 1	 2.52	 4.25	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46682	 1	 8.54	 2.42	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46683	 1	 0.47	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46684	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46685	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46686	 1	 9.31	 2.63	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46687	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46688	 1	 2.46	 0.69	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46689	 1	 1.92	 0.54	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46690	 1	 1.62	 0.46	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46691	 1	 1.41	 0.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46692	 1	 0.49	 0.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46693	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46694	 1	 0.54	 0.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46695	 1	 1.46	 0.41	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46696	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46697	 1	 0.31	 0.09	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46698	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46699	 1	 2.54	 0.71	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46700	 1	 1.17	 0.32	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46701	 1	 1.21	 0.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46702	 1	 0.61	 0.17	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46703	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46704	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46705	 1	 0.72	 0.2	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46706	 1	 0.67	 0.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46707	 1	 1.12	 0.31	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46708	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46709	 1	 1.02	 0.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46710	 1	 0.5	 0.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46711	 1	 1.02	 0.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46712	 1	 1.35	 0.37	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46713	 1	 0.83	 0.23	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46714	 1	 1.79	 0.49	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46715	 1	 0.54	 0.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46716	 1	 0.64	 0.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46717	 1	 0.44	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46718	 1	 0.5	 0.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46719	 1	 0.57	 0.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46720	 1	 1.4	 0.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46721	 1	 2.6	 0.72	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46722	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46723	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46724	 1	 0.95	 0.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46725	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46726	 1	 0.64	 0.17	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46727	 1	 0.63	 0.17	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46728	 1	 3.62	 6.7	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46729	 1	 2.3	 0.64	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46730	 1	 0.83	 0.23	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46731	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46732	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46733	 1	 1.03	 3.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46734	 1	 0.59	 0.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46735	 1	 0.44	 1.62	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46736	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46737	 1	 1.28	 3.24	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46738	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46739	 1	 4.22	 8.91	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46740	 1	 0.66	 0.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46741	 1	 0.6	 1.91	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46742	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46743	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46744	 1	 0.89	 2.88	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46745	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46746	 1	 1.53	 2.96	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46747	 1	 0.71	 1.99	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46748	 1	 1.5	 3.34	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46749	 1	 0.9	 2.26	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46750	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46751	 1	 0.67	 2.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46752	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46753	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46754	 1	 0.75	 0.21	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46755	 1	 1.86	 0.51	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46756	 1	 1.58	 3.46	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46757	 1	 0.47	 1.27	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46758	 1	 0.61	 1.84	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46759	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46760	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46761	 1	 0.89	 2.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46762	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46763	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46764	 1	 0.42	 1.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46765	 1	 0.96	 2.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46766	 1	 1.93	 3.57	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46767	 1	 0.3	 0.91	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46768	 1	 0.64	 1.84	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46769	 1	 1.7	 2.83	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46770	 1	 0.43	 1.38	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46771	 1	 1.76	 2.86	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46772	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46773	 1	 0.84	 2.23	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46774	 1	 1.38	 3.42	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46775	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46776	 1	 3.42	 6.44	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46777	 1	 0.75	 1.93	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46778	 1	 0.37	 1.02	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46779	 1	 0.47	 1.21	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46780	 1	 1.14	 2.37	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46781	 1	 0.53	 1.49	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46782	 1	 0.22	 0.6	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46783	 1	 2.48	 4.78	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46784	 1	 1.55	 2.92	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46785	 1	 0.32	 0.92	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46786	 1	 0.33	 0.88	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46787	 1	 0.45	 1.25	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46788	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46789	 1	 1.92	 3.89	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46790	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46791	 1	 0.34	 1.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46792	 1	 2.2	 4.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46793	 1	 0.45	 1.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46794	 1	 1.02	 2.69	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46795	 1	 1.04	 1.9	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46796	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46797	 1	 0.79	 1.77	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46798	 1	 12.59	 24.02	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46799	 1	 6.15	 9.56	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46800	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46801	 1	 5.13	 8.44	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46802	 1	 1.96	 5.03	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46803	 1	 0.59	 1.75	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46804	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46805	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46806	 1	 0.59	 1.51	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46807	 1	 1.59	 3.81	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46808	 1	 0.37	 1.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46809	 1	 2.2	 5.02	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46810	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46811	 1	 0.96	 2.2	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46812	 1	 1.01	 2.02	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46813	 1	 1.02	 2.22	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46814	 1	 0.39	 1.02	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46815	 1	 1.27	 3.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46816	 1	 3.56	 5.24	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46817	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46818	 1	 1.6	 3.65	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46819	 1	 0.25	 0.75	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46820	 1	 5.25	 10.43	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46821	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46822	 1	 3.57	 4.42	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46823	 1	 0.55	 1.5	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46824	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46825	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46826	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46827	 1	 1.31	 2.7	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46828	 1	 1.04	 2.35	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46829	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46830	 1	 0.92	 2.41	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46831	 1	 2.62	 5.17	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46832	 1	 2.65	 5.8	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46833	 1	 0.52	 1.52	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46834	 1	 1.78	 3.69	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46835	 1	 5.95	 7.94	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46836	 1	 19.58	 26.8	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46837	 1	 0.85	 2.29	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46838	 1	 1.87	 4.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46839	 1	 1.7	 3.68	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46840	 1	 0.64	 2.31	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46841	 1	 0.68	 1.79	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46842	 1	 7.02	 12.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46843	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	46844	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	46845	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	46846	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	46847	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46848	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	46849	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46850	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46851	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46852	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46853	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	46854	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46855	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46856	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46857	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46858	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46859	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46860	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46861	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46862	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46863	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46864	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46865	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46866	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46867	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46868	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46869	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46870	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46871	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46872	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46873	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46874	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46875	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46876	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46877	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46878	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46879	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46880	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46881	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46882	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46883	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46884	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	46885	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46886	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46887	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46888	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46889	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46890	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46891	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	46892	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46893	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46894	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46895	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46896	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46897	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46898	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46899	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46900	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	46901	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46902	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46903	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	46904	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46905	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46906	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46907	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46908	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46909	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46910	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46911	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46912	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46913	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46914	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46915	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46916	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46917	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46918	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46919	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46920	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46921	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46922	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46923	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46924	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46925	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46926	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46927	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46928	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46929	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46930	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46931	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46932	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46933	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46934	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46935	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46936	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46937	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46938	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46939	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46940	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46941	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46942	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46943	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46944	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46945	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46946	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	46947	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	46948	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	46949	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46950	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	46951	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46952	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46953	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46954	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	46955	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46956	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46957	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46958	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46959	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46960	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46961	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46962	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46963	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46964	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46965	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46966	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46967	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46968	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	46969	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46970	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46971	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46972	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46973	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46974	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46975	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46976	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46977	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46978	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46979	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46980	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46981	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46982	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46983	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46984	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46985	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	46986	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46987	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46988	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46989	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46990	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46991	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46992	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46993	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46994	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46995	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	46996	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46997	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46998	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	46999	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47000	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47001	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47002	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47003	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47004	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47005	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47006	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47007	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47008	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47009	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47010	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47011	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47012	 1	 2.61	 1.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47013	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47014	 1	 3.76	 1.82	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47015	 1	 7.37	 3.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47016	 1	 3.32	 1.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47017	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47018	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47019	 1	 4.63	 2.54	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47020	 1	 3.04	 1.52	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47021	 1	 5.5	 3.04	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47022	 1	 1.58	 0.92	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47023	 1	 2.37	 1.57	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47024	 1	 44.52	 14.94	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47025	 1	 2.02	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47026	 1	 10.0	 4.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47027	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47028	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47029	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47030	 1	 3.45	 2.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47031	 1	 2.92	 1.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47032	 1	 2.96	 1.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47033	 1	 5.15	 3.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47034	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47035	 1	 3.96	 2.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47036	 1	 3.6	 0.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47037	 1	 14.32	 3.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47038	 1	 7.35	 3.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47039	 1	 3.96	 2.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47040	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47041	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47042	 1	 2.45	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47043	 1	 8.37	 1.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47044	 1	 6.55	 3.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47045	 1	 5.58	 2.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47046	 1	 3.21	 1.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47047	 1	 3.98	 2.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47048	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47049	 1	 8.17	 4.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47050	 1	 5.48	 2.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47051	 1	 8.05	 1.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47052	 1	 4.01	 2.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47053	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47054	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47055	 1	 3.24	 1.58	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47056	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47057	 1	 2.89	 1.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47058	 1	 2.74	 1.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47059	 1	 2.52	 1.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47060	 1	 2.62	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47061	 1	 3.27	 1.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47062	 1	 3.28	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47063	 1	 4.38	 2.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47064	 1	 4.8	 2.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47065	 1	 4.15	 2.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47066	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47067	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47068	 1	 6.19	 3.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47069	 1	 3.38	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47070	 1	 2.84	 1.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47071	 1	 8.13	 3.99	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47072	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47073	 1	 6.19	 3.47	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47074	 1	 2.35	 1.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47075	 1	 2.01	 1.12	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47076	 1	 7.88	 4.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47077	 1	 3.53	 2.01	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47078	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47079	 1	 1.35	 0.77	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47080	 1	 12.86	 7.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47081	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47082	 1	 3.7	 2.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47083	 1	 1.69	 0.96	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47084	 1	 6.25	 3.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47085	 1	 7.78	 3.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47086	 1	 5.21	 2.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47087	 1	 4.43	 3.02	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47088	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47089	 1	 8.92	 4.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47090	 1	 9.29	 5.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47091	 1	 3.1	 1.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47092	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47093	 1	 5.23	 2.05	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47094	 1	 1.81	 0.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47095	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47096	 1	 6.28	 2.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47097	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47098	 1	 3.2	 1.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47099	 1	 4.31	 2.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47100	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47101	 1	 2.95	 1.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47102	 1	 13.93	 5.74	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47103	 1	 3.16	 0.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47104	 1	 2.02	 1.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47105	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47106	 1	 2.32	 0.54	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47107	 1	 3.0	 1.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47108	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47109	 1	 5.39	 2.88	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47110	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47111	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47112	 1	 1.4	 0.82	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47113	 1	 2.35	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47114	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47115	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47116	 1	 1.68	 1.21	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47117	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47118	 1	 4.5	 2.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47119	 1	 1.07	 0.57	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47120	 1	 5.58	 3.12	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47121	 1	 8.58	 4.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47122	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47123	 1	 4.04	 2.24	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47124	 1	 5.93	 2.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47125	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47126	 1	 2.78	 1.94	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47127	 1	 10.86	 4.91	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47128	 1	 7.46	 3.26	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47129	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47130	 1	 13.05	 4.96	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47131	 1	 9.46	 5.19	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47132	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47133	 1	 4.4	 2.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47134	 1	 10.09	 4.34	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47135	 1	 1.54	 0.79	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47136	 1	 10.52	 5.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47137	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47138	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47139	 1	 3.47	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47140	 1	 3.52	 2.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47141	 1	 4.24	 2.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47142	 1	 7.88	 4.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47143	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47144	 1	 5.46	 3.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47145	 1	 41.44	 20.49	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47146	 1	 4.14	 2.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47147	 1	 4.75	 2.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47148	 1	 11.73	 6.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47149	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47150	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47151	 1	 4.25	 2.85	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47152	 1	 6.75	 4.15	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47153	 1	 5.57	 3.78	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47154	 1	 6.59	 3.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47155	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47156	 1	 3.93	 2.39	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47157	 1	 6.09	 3.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47158	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47159	 1	 2.76	 1.82	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47160	 1	 6.36	 1.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47161	 1	 4.1	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47162	 1	 3.6	 2.04	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47163	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47164	 1	 8.41	 4.47	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47165	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47166	 1	 3.28	 1.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47167	 1	 5.34	 2.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47168	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47169	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47170	 1	 2.46	 1.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47171	 1	 4.92	 2.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47172	 1	 0.64	 0.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47173	 1	 1.07	 0.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47174	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47175	 1	 2.22	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47176	 1	 2.09	 1.25	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47177	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47178	 1	 5.95	 3.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47179	 1	 1.86	 1.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47180	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47181	 1	 3.41	 2.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47182	 1	 2.04	 1.12	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47183	 1	 2.23	 1.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47184	 1	 2.14	 1.13	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47185	 1	 5.7	 2.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47186	 1	 2.4	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47187	 1	 3.53	 1.8	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47188	 1	 3.04	 2.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47189	 1	 2.09	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47190	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47191	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47192	 1	 3.41	 1.86	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47193	 1	 3.43	 1.93	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47194	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47195	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47196	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47197	 1	 2.52	 1.08	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47198	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47199	 1	 2.32	 1.43	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47200	 1	 3.97	 2.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47201	 1	 6.83	 3.59	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47202	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47203	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47204	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47205	 1	 4.21	 2.2	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47206	 1	 4.24	 2.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47207	 1	 3.1	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47208	 1	 4.67	 2.96	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47209	 1	 7.86	 4.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47210	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47211	 1	 4.64	 2.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47212	 1	 2.97	 1.58	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47213	 1	 1.68	 0.93	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47214	 1	 2.57	 1.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47215	 1	 3.61	 1.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47216	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47217	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47218	 1	 3.11	 1.53	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47219	 1	 5.56	 2.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47220	 1	 2.63	 1.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47221	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47222	 1	 4.81	 2.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47223	 1	 19.33	 9.21	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47224	 1	 3.23	 1.95	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47225	 1	 2.35	 1.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47226	 1	 4.38	 2.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47227	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47228	 1	 3.23	 1.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47229	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47230	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47231	 1	 22.41	 13.15	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47232	 1	 11.19	 5.84	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47233	 1	 6.14	 3.93	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47234	 1	 5.3	 2.72	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47235	 1	 6.38	 3.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47236	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47237	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47238	 1	 4.01	 2.16	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47239	 1	 2.28	 1.31	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47240	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47241	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47242	 1	 10.45	 4.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47243	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47244	 1	 5.14	 2.83	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47245	 1	 5.61	 3.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47246	 1	 2.33	 1.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47247	 1	 3.51	 1.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47248	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47249	 1	 4.64	 2.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47250	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47251	 1	 4.67	 3.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47252	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47253	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47254	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47255	 1	 3.23	 2.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47256	 1	 3.13	 1.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47257	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47258	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47259	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47260	 1	 3.09	 2.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47261	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47262	 1	 5.56	 3.64	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47263	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47264	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47265	 1	 10.69	 4.56	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47266	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47267	 1	 3.28	 1.79	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47268	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47269	 1	 3.11	 1.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47270	 1	 9.49	 5.3	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47271	 1	 5.04	 2.75	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47272	 1	 9.28	 4.61	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47273	 1	 24.08	 8.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47274	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47275	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47276	 1	 7.61	 4.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47277	 1	 6.91	 4.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47278	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47279	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47280	 1	 10.53	 5.35	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47281	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47282	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47283	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47284	 1	 4.67	 2.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47285	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47286	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47287	 1	 3.61	 2.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47288	 1	 11.25	 5.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47289	 1	 9.1	 4.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47290	 1	 5.05	 2.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47291	 1	 2.14	 1.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47292	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47293	 1	 3.15	 1.97	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47294	 1	 2.47	 1.31	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47295	 1	 4.36	 2.44	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47296	 1	 3.99	 2.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47297	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47298	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47299	 1	 1.79	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47300	 1	 1.0	 0.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47301	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47302	 1	 4.44	 2.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47303	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47304	 1	 14.08	 4.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47305	 1	 2.51	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47306	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47307	 1	 1.89	 1.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47308	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47309	 1	 3.56	 1.48	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47310	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47311	 1	 2.82	 1.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47312	 1	 4.46	 2.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47313	 1	 2.35	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47314	 1	 2.09	 1.41	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47315	 1	 2.21	 1.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47316	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47317	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47318	 1	 4.31	 2.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47319	 1	 3.61	 2.1	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47320	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47321	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47322	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47323	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47324	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47325	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47326	 1	 2.6	 1.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47327	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47328	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47329	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47330	 1	 4.75	 2.69	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47331	 1	 6.31	 4.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47332	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47333	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47334	 1	 1.77	 0.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47335	 1	 1.71	 1.1	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47336	 1	 2.06	 1.14	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47337	 1	 5.2	 3.17	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47338	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47339	 1	 1.34	 0.76	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47340	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47341	 1	 1.56	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47342	 1	 2.3	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47343	 1	 3.09	 1.62	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47344	 1	 2.72	 1.46	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47345	 1	 4.5	 2.47	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47346	 1	 13.88	 7.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47347	 1	 5.38	 3.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47348	 1	 16.44	 4.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47349	 1	 2.37	 0.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47350	 1	 6.7	 3.96	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47351	 1	 4.63	 2.52	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47352	 1	 4.22	 2.44	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47353	 1	 5.1	 2.82	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47354	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47355	 1	 2.17	 1.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47356	 1	 4.71	 2.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47357	 1	 3.62	 1.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47358	 1	 3.41	 2.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47359	 1	 4.59	 2.37	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47360	 1	 2.36	 1.39	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47361	 1	 3.78	 1.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47362	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47363	 1	 3.28	 2.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47364	 1	 2.98	 1.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47365	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47366	 1	 4.08	 2.6	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47367	 1	 4.87	 2.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47368	 1	 6.51	 3.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47369	 1	 1.53	 0.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47370	 1	 4.59	 2.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47371	 1	 1.09	 0.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47372	 1	 3.06	 1.79	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47373	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47374	 1	 3.77	 2.24	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47375	 1	 4.63	 2.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47376	 1	 3.38	 2.32	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47377	 1	 2.6	 1.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47378	 1	 6.83	 3.76	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47379	 1	 3.66	 2.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47380	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47381	 1	 2.14	 0.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47382	 1	 3.01	 0.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47383	 1	 6.16	 1.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47384	 1	 3.29	 0.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47385	 1	 3.55	 0.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47386	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47387	 1	 5.95	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47388	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47389	 1	 11.87	 6.09	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47390	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47391	 1	 4.65	 1.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47392	 1	 3.09	 1.53	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47393	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47394	 1	 3.56	 2.14	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47395	 1	 5.11	 2.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47396	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47397	 1	 6.7	 4.31	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47398	 1	 3.14	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47399	 1	 14.09	 7.53	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47400	 1	 14.17	 4.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47401	 1	 8.52	 2.99	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47402	 1	 2.59	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47403	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47404	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47405	 1	 2.63	 1.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47406	 1	 2.31	 1.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47407	 1	 3.82	 2.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47408	 1	 1.48	 0.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47409	 1	 3.81	 2.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47410	 1	 2.22	 1.17	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47411	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47412	 1	 2.44	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47413	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47414	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47415	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47416	 1	 1.76	 1.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47417	 1	 9.23	 4.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47418	 1	 3.21	 1.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47419	 1	 5.17	 2.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47420	 1	 6.11	 3.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47421	 1	 4.04	 2.08	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47422	 1	 4.02	 2.58	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47423	 1	 1.46	 0.86	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47424	 1	 2.52	 1.44	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47425	 1	 5.04	 3.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47426	 1	 12.38	 6.49	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47427	 1	 9.87	 6.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47428	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47429	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47430	 1	 6.51	 3.98	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47431	 1	 2.41	 1.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47432	 1	 4.92	 3.24	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47433	 1	 3.4	 2.26	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47434	 1	 1.55	 0.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47435	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47436	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47437	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47438	 1	 2.5	 1.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47439	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47440	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47441	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47442	 1	 3.79	 2.15	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47443	 1	 3.96	 1.93	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47444	 1	 4.58	 2.68	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47445	 1	 3.75	 1.66	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47446	 1	 2.89	 1.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47447	 1	 5.39	 2.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47448	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47449	 1	 6.07	 3.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47450	 1	 3.71	 1.92	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47451	 1	 14.56	 8.42	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47452	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47453	 1	 5.09	 3.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47454	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47455	 1	 4.94	 3.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47456	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47457	 1	 4.08	 2.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47458	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47459	 1	 2.01	 1.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47460	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47461	 1	 2.14	 1.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47462	 1	 1.88	 1.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47463	 1	 2.64	 1.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47464	 1	 2.56	 1.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47465	 1	 2.56	 1.4	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47466	 1	 4.24	 2.11	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47467	 1	 3.5	 2.18	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47468	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47469	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47470	 1	 5.6	 3.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47471	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47472	 1	 4.64	 2.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47473	 1	 4.23	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47474	 1	 3.38	 1.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47475	 1	 4.0	 2.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47476	 1	 5.7	 3.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47477	 1	 2.28	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47478	 1	 2.8	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47479	 1	 4.18	 2.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47480	 1	 2.68	 1.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47481	 1	 5.28	 2.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47482	 1	 5.16	 2.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47483	 1	 2.17	 1.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47484	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47485	 1	 5.15	 2.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47486	 1	 8.08	 4.68	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47487	 1	 20.79	 11.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47488	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47489	 1	 1.53	 0.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47490	 1	 3.57	 2.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47491	 1	 2.18	 1.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47492	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47493	 1	 5.0	 2.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47494	 1	 0.38	 0.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47495	 1	 1.63	 0.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47496	 1	 3.76	 2.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47497	 1	 3.22	 1.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47498	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47499	 1	 3.35	 1.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47500	 1	 2.27	 1.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47501	 1	 5.47	 2.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47502	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47503	 1	 4.27	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47504	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47505	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47506	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47507	 1	 2.09	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47508	 1	 3.48	 1.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47509	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47510	 1	 2.57	 1.32	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47511	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47512	 1	 2.62	 1.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47513	 1	 0.72	 0.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47514	 1	 2.95	 1.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47515	 1	 2.32	 1.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47516	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47517	 1	 2.7	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47518	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47519	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47520	 1	 35.46	 20.15	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47521	 1	 20.59	 8.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47522	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47523	 1	 2.91	 1.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47524	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47525	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47526	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47527	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47528	 1	 5.05	 3.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47529	 1	 4.09	 2.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47530	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47531	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47532	 1	 1.68	 1.13	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47533	 1	 3.81	 2.5	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47534	 1	 2.49	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47535	 1	 6.33	 4.06	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47536	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47537	 1	 2.65	 1.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47538	 1	 1.83	 0.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47539	 1	 4.04	 2.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47540	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47541	 1	 3.43	 1.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47542	 1	 3.42	 1.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47543	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47544	 1	 3.13	 1.87	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47545	 1	 8.02	 4.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47546	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47547	 1	 4.84	 3.08	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47548	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47549	 1	 3.52	 2.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47550	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47551	 1	 4.13	 2.44	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47552	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47553	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47554	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47555	 1	 9.35	 6.55	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47556	 1	 4.92	 3.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47557	 1	 4.61	 2.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47558	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47559	 1	 2.87	 1.53	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47560	 1	 6.05	 3.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47561	 1	 3.05	 2.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47562	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47563	 1	 3.24	 1.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47564	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47565	 1	 4.39	 2.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47566	 1	 7.98	 4.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47567	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47568	 1	 2.26	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47569	 1	 2.89	 1.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47570	 1	 2.33	 1.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47571	 1	 5.74	 3.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47572	 1	 3.13	 1.89	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	47573	 1	 3.89	 2.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47574	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47575	 1	 3.77	 2.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47576	 1	 1.81	 1.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47577	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47578	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47579	 1	 2.25	 1.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47580	 1	 3.15	 1.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47581	 1	 2.23	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47582	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47583	 1	 9.63	 4.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47584	 1	 1.83	 1.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47585	 1	 9.9	 5.31	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47586	 1	 5.45	 2.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47587	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47588	 1	 1.31	 0.79	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47589	 1	 3.44	 1.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47590	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47591	 1	 1.88	 0.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47592	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47593	 1	 24.48	 5.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47594	 1	 21.29	 5.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47595	 1	 2.84	 1.59	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47596	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47597	 1	 2.7	 1.76	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47598	 1	 5.11	 3.01	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47599	 1	 4.01	 0.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47600	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47601	 1	 3.46	 0.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47602	 1	 3.53	 0.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47603	 1	 3.69	 0.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47604	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47605	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47606	 1	 17.61	 7.4	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47607	 1	 3.25	 0.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47608	 1	 37.18	 8.88	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47609	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47610	 1	 5.19	 2.6	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47611	 1	 3.17	 1.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47612	 1	 5.26	 3.11	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47613	 1	 4.96	 1.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47614	 1	 6.3	 1.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47615	 1	 4.19	 0.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47616	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47617	 1	 5.31	 2.58	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47618	 1	 3.29	 2.08	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47619	 1	 6.64	 2.93	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47620	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47621	 1	 1.81	 1.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47622	 1	 3.46	 2.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47623	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47624	 1	 2.79	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47625	 1	 3.79	 2.24	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47626	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47627	 1	 1.39	 0.83	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47628	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47629	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47630	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47631	 1	 12.28	 4.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47632	 1	 42.12	 18.83	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47633	 1	 35.67	 17.47	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47634	 1	 6.11	 3.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47635	 1	 4.46	 2.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47636	 1	 4.16	 0.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47637	 1	 19.13	 8.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47638	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47639	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47640	 1	 8.81	 5.46	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47641	 1	 2.17	 1.31	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47642	 1	 4.9	 2.46	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47643	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47644	 1	 6.79	 2.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47645	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47646	 1	 3.67	 2.24	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47647	 1	 5.32	 3.11	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47648	 1	 4.46	 2.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47649	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47650	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47651	 1	 19.7	 9.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47652	 1	 19.16	 8.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47653	 1	 5.53	 3.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47654	 1	 3.73	 2.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47655	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47656	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47657	 1	 10.87	 5.73	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47658	 1	 7.36	 3.96	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47659	 1	 9.41	 5.29	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47660	 1	 5.34	 2.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47661	 1	 4.66	 2.73	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47662	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47663	 1	 4.12	 2.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47664	 1	 6.09	 3.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47665	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47666	 1	 4.93	 2.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47667	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47668	 1	 3.6	 1.76	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47669	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47670	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47671	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47672	 1	 21.66	 7.41	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47673	 1	 2.67	 1.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47674	 1	 2.84	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47675	 1	 7.63	 4.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47676	 1	 4.16	 2.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47677	 1	 7.15	 4.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47678	 1	 6.39	 3.5	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47679	 1	 4.42	 2.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47680	 1	 3.2	 1.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47681	 1	 9.0	 4.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47682	 1	 7.85	 4.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47683	 1	 4.56	 2.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47684	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47685	 1	 11.95	 6.88	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47686	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47687	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47688	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47689	 1	 6.9	 4.07	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47690	 1	 3.69	 1.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47691	 1	 5.93	 3.45	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47692	 1	 2.05	 1.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47693	 1	 2.81	 1.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47694	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47695	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47696	 1	 2.29	 1.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47697	 1	 19.06	 4.48	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47698	 1	 15.07	 9.46	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47699	 1	 26.33	 17.42	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47700	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47701	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47702	 1	 18.39	 4.25	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47703	 1	 21.22	 4.98	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47704	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47705	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47706	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47707	 1	 8.46	 4.54	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47708	 1	 6.74	 3.06	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47709	 1	 9.21	 2.06	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47710	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47711	 1	 9.22	 4.57	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47712	 1	 16.96	 3.84	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47713	 1	 25.44	 5.75	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47714	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47715	 1	 9.2	 5.1	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47716	 1	 10.45	 5.03	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47717	 1	 34.31	 18.28	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47718	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47719	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47720	 1	 19.73	 9.71	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47721	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47722	 1	 14.06	 6.11	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47723	 1	 15.55	 7.39	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47724	 1	 29.43	 13.48	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47725	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47726	 1	 15.75	 8.03	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47727	 1	 81.35	 36.24	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47728	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47729	 1	 10.54	 5.31	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47730	 1	 4.3	 2.26	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47731	 1	 9.72	 5.54	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47732	 1	 10.12	 2.37	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47733	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47734	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47735	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47736	 1	 14.12	 3.29	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47737	 1	 4.94	 1.13	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47738	 1	 6.26	 1.42	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47739	 1	 13.27	 6.42	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47740	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47741	 1	 20.36	 11.7	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47742	 1	 39.52	 16.54	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47743	 1	 12.16	 7.47	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47744	 1	 8.61	 5.28	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47745	 1	 29.43	 14.89	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47746	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47747	 1	 11.99	 2.81	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47748	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47749	 1	 10.55	 5.78	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47750	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47751	 1	 23.71	 5.62	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47752	 1	 10.84	 2.57	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47753	 1	 48.12	 11.49	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47754	 1	 8.62	 2.04	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47755	 1	 9.72	 2.3	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47756	 1	 7.11	 1.68	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47757	 1	 7.08	 1.67	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47758	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47759	 1	 7.87	 1.84	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47760	 1	 7.03	 1.64	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47761	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47762	 1	 25.83	 6.16	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47763	 1	 12.77	 6.87	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47764	 1	 12.22	 2.79	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47765	 1	 14.45	 3.41	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47766	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47767	 1	 11.21	 2.59	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47768	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47769	 1	 32.8	 7.81	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47770	 1	 15.1	 3.55	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47771	 1	 12.66	 2.84	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47772	 1	 14.06	 3.34	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47773	 1	 41.46	 21.13	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47774	 1	 1.63	 0.81	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47775	 1	 2.08	 1.08	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47776	 1	 6.33	 3.97	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47777	 1	 6.12	 1.45	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47778	 1	 8.2	 4.4	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47779	 1	 6.63	 1.57	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47780	 1	 3.66	 0.86	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47781	 1	 5.56	 3.15	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47782	 1	 9.13	 4.88	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47783	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47784	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47785	 1	 3.47	 1.89	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47786	 1	 3.12	 1.5	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47787	 1	 10.54	 5.55	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47788	 1	 18.03	 9.54	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47789	 1	 7.0	 3.82	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47790	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47791	 1	 10.91	 6.16	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47792	 1	 5.7	 2.88	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47793	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47794	 1	 7.79	 1.85	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47795	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47796	 1	 8.83	 2.11	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47797	 1	 2.97	 0.71	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47798	 1	 3.47	 1.62	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47799	 1	 18.49	 10.79	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47800	 1	 14.45	 7.01	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47801	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47802	 1	 11.82	 2.79	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47803	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47804	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47805	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47806	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47807	 1	 9.84	 2.34	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47808	 1	 9.21	 4.92	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47809	 1	 40.99	 17.97	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47810	 1	 8.49	 4.77	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47811	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47812	 1	 14.04	 3.28	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47813	 1	 11.83	 2.81	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47814	 1	 14.24	 3.35	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47815	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47816	 1	 10.12	 2.38	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47817	 1	 18.89	 9.78	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47818	 1	 11.9	 4.87	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47819	 1	 16.13	 3.71	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47820	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47821	 1	 29.1	 6.67	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47822	 1	 9.78	 5.3	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47823	 1	 9.42	 2.15	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47824	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47825	 1	 9.77	 2.29	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47826	 1	 15.67	 3.71	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47827	 1	 3.68	 0.86	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47828	 1	 7.74	 -4.63	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47829	 1	 12.48	 2.94	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47830	 1	 12.08	 2.84	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47831	 1	 4.3	 1.01	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47832	 1	 3.25	 1.63	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47833	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47834	 1	 16.9	 3.87	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47835	 1	 8.57	 1.95	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47836	 1	 3.34	 0.79	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47837	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47838	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47839	 1	 5.83	 2.78	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47840	 1	 3.21	 1.47	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47841	 1	 8.69	 5.13	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47842	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47843	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47844	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47845	 1	 13.87	 7.15	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47846	 1	 9.57	 4.97	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47847	 1	 10.82	 5.64	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47848	 1	 9.71	 5.61	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47849	 1	 6.3	 2.92	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47850	 1	 13.14	 6.59	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47851	 1	 48.52	 24.91	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47852	 1	 7.54	 4.8	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47853	 1	 52.49	 28.14	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47854	 1	 24.61	 13.67	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47855	 1	 75.58	 33.37	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47856	 1	 7.24	 4.04	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47857	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47858	 1	 13.71	 7.76	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47859	 1	 27.33	 14.51	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47860	 1	 7.39	 3.72	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47861	 1	 15.54	 7.26	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47862	 1	 13.36	 7.01	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47863	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47864	 1	 13.5	 7.63	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47865	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47866	 1	 6.98	 4.01	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47867	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47868	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47869	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47870	 1	 5.06	 2.6	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47871	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47872	 1	 20.18	 11.7	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47873	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47874	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47875	 1	 111.36	 42.42	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47876	 1	 11.79	 6.03	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47877	 1	 7.86	 4.2	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47878	 1	 15.17	 8.24	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47879	 1	 1.66	 0.79	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47880	 1	 1.17	 0.66	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47881	 1	 8.8	 5.37	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47882	 1	 6.49	 1.52	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47883	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47884	 1	 29.94	 19.66	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47885	 1	 92.66	 46.98	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47886	 1	 8.56	 2.01	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47887	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47888	 1	 6.6	 3.8	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47889	 1	 16.51	 9.34	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47890	 1	 11.61	 2.75	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47891	 1	 9.71	 2.31	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47892	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47893	 1	 5.32	 1.26	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47894	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47895	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47896	 1	 9.09	 2.08	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47897	 1	 14.14	 3.24	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47898	 1	 6.94	 3.87	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47899	 1	 16.29	 7.44	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47900	 1	 26.28	 10.18	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47901	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47902	 1	 7.61	 3.36	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47903	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47904	 1	 5.09	 2.53	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47905	 1	 4.8	 2.5	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47906	 1	 3.13	 1.69	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47907	 1	 24.39	 12.41	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47908	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47909	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47910	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47911	 1	 8.25	 4.5	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47912	 1	 12.78	 6.83	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47913	 1	 11.37	 6.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47914	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47915	 1	 9.59	 5.07	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47916	 1	 7.74	 4.51	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47917	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47918	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47919	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47920	 1	 9.39	 5.09	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47921	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47922	 1	 8.18	 4.02	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47923	 1	 5.68	 2.83	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47924	 1	 16.24	 8.14	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47925	 1	 2.62	 1.09	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47926	 1	 5.94	 2.71	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47927	 1	 11.51	 7.02	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47928	 1	 7.03	 3.24	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47929	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47930	 1	 9.38	 5.34	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47931	 1	 3.46	 1.69	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47932	 1	 6.81	 3.73	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47933	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47934	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47935	 1	 7.74	 4.06	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47936	 1	 21.02	 12.14	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47937	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47938	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47939	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47940	 1	 12.41	 6.84	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47941	 1	 6.57	 2.94	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47942	 1	 10.69	 4.67	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47943	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47944	 1	 35.66	 21.02	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47945	 1	 10.92	 4.94	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47946	 1	 21.61	 9.76	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47947	 1	 19.29	 9.22	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47948	 1	 17.01	 9.02	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47949	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47950	 1	 7.21	 4.19	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47951	 1	 12.96	 6.85	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47952	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47953	 1	 16.78	 7.41	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47954	 1	 12.92	 7.34	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47955	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47956	 1	 13.52	 7.05	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47957	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47958	 1	 13.76	 7.27	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47959	 1	 8.85	 3.76	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47960	 1	 11.45	 5.39	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47961	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47962	 1	 15.01	 8.67	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47963	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47964	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47965	 1	 9.05	 4.16	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47966	 1	 13.73	 5.73	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47967	 1	 6.49	 3.44	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47968	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47969	 1	 15.38	 8.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47970	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47971	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47972	 1	 72.69	 32.68	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47973	 1	 11.5	 6.99	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47974	 1	 11.36	 6.25	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47975	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47976	 1	 12.54	 5.79	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47977	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47978	 1	 12.77	 6.65	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47979	 1	 9.44	 4.25	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47980	 1	 16.95	 8.65	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47981	 1	 13.22	 6.58	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47982	 1	 17.1	 8.35	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47983	 1	 11.18	 5.65	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47984	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47985	 1	 24.0	 11.91	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47986	 1	 12.47	 5.78	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47987	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47988	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	47989	 1	 21.53	 10.91	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47990	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	47991	 1	 7.56	 3.84	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47992	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47993	 1	 5.68	 2.8	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47994	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47995	 1	 5.76	 2.57	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47996	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47997	 1	 2.44	 1.22	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	47998	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47999	 1	 18.2	 4.2	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48000	 1	 4.8	 1.11	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48001	 1	 7.22	 4.07	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48002	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48003	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48004	 1	 15.18	 8.16	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48005	 1	 9.79	 5.53	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48006	 1	 11.99	 6.35	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48007	 1	 9.58	 5.16	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48008	 1	 10.72	 6.2	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48009	 1	 13.27	 5.66	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48010	 1	 7.73	 4.36	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48011	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48012	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48013	 1	 12.55	 6.29	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48014	 1	 10.13	 2.3	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48015	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48016	 1	 14.14	 3.23	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48017	 1	 5.13	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48018	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48019	 1	 5.89	 1.34	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48020	 1	 14.69	 6.62	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48021	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48022	 1	 5.42	 3.31	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48023	 1	 13.8	 7.85	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48024	 1	 14.78	 7.85	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48025	 1	 27.02	 12.58	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48026	 1	 22.3	 5.13	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48027	 1	 37.38	 8.61	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48028	 1	 32.37	 7.41	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48029	 1	 53.21	 24.24	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48030	 1	 15.1	 3.46	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48031	 1	 11.85	 2.72	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48032	 1	 7.33	 1.68	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48033	 1	 5.07	 1.16	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48034	 1	 6.35	 1.46	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48035	 1	 7.5	 1.73	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48036	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48037	 1	 12.9	 2.96	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48038	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48039	 1	 27.13	 12.51	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48040	 1	 6.34	 1.44	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48041	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	48042	 1	 14.14	 8.16	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48043	 1	 12.84	 6.85	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48044	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48045	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	48046	 1	 5.43	 1.27	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48047	 1	 33.19	 11.07	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48048	 1	 9.88	 4.87	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48049	 1	 7.68	 4.24	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48050	 1	 4.73	 2.37	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48051	 1	 5.06	 2.57	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48052	 1	 5.86	 2.8	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48053	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48054	 1	 7.63	 4.37	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48055	 1	 13.64	 6.9	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48056	 1	 5.55	 2.49	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48057	 1	 10.72	 5.71	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48058	 1	 7.43	 3.59	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48059	 1	 5.38	 2.39	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48060	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48061	 1	 4.07	 2.1	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48062	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48063	 1	 7.63	 3.26	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48064	 1	 14.31	 6.42	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48065	 1	 7.05	 3.53	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48066	 1	 8.2	 3.71	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48067	 1	 10.68	 5.03	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48068	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48069	 1	 5.39	 2.25	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48070	 1	 8.27	 3.98	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48071	 1	 6.98	 3.13	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48072	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48073	 1	 17.7	 10.73	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48074	 1	 5.84	 2.57	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48075	 1	 6.64	 3.12	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48076	 1	 9.13	 4.95	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48077	 1	 7.83	 4.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48078	 1	 3.64	 1.65	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48079	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48080	 1	 12.41	 6.41	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48081	 1	 12.77	 6.39	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48082	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48083	 1	 9.53	 4.84	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48084	 1	 9.06	 4.45	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48085	 1	 3.55	 1.7	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48086	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48087	 1	 4.46	 2.03	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48088	 1	 2.74	 1.48	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48089	 1	 5.25	 2.79	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48090	 1	 7.18	 4.09	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48091	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48092	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48093	 1	 5.23	 2.74	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48094	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48095	 1	 5.72	 3.1	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48096	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48097	 1	 5.7	 3.05	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48098	 1	 6.6	 3.24	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48099	 1	 5.1	 2.65	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48100	 1	 3.16	 1.57	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48101	 1	 7.92	 4.27	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48102	 1	 4.92	 2.54	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48103	 1	 4.77	 2.15	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48104	 1	 7.73	 3.72	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48105	 1	 2.85	 1.41	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48106	 1	 5.41	 2.73	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48107	 1	 7.64	 3.43	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48108	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48109	 1	 7.37	 4.06	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48110	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48111	 1	 4.43	 2.04	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48112	 1	 4.16	 2.3	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48113	 1	 4.07	 2.23	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48114	 1	 6.09	 3.19	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48115	 1	 4.91	 2.42	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48116	 1	 6.89	 3.77	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48117	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48118	 1	 13.09	 8.06	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48119	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48120	 1	 12.71	 6.31	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48121	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48122	 1	 5.22	 3.27	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48123	 1	 12.83	 5.22	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48124	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48125	 1	 13.59	 6.34	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48126	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48127	 1	 6.24	 2.76	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48128	 1	 7.87	 3.75	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48129	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48130	 1	 5.36	 2.94	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48131	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48132	 1	 5.23	 2.4	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48133	 1	 5.23	 3.34	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48134	 1	 5.95	 3.67	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48135	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48136	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48137	 1	 39.4	 22.27	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48138	 1	 15.08	 8.74	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48139	 1	 48.57	 20.97	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48140	 1	 60.13	 29.76	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48141	 1	 3.32	 1.64	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48142	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48143	 1	 8.05	 3.37	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48144	 1	 6.07	 3.76	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48145	 1	 4.78	 2.13	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48146	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48147	 1	 11.6	 6.42	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48148	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48149	 1	 12.63	 5.69	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48150	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48151	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48152	 1	 14.11	 3.15	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48153	 1	 7.27	 3.49	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48154	 1	 10.9	 6.23	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48155	 1	 13.47	 6.57	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48156	 1	 31.1	 15.67	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48157	 1	 17.52	 8.69	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48158	 1	 13.97	 7.11	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48159	 1	 9.59	 4.24	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48160	 1	 13.86	 4.87	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48161	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48162	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48163	 1	 9.75	 5.08	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48164	 1	 18.19	 9.06	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48165	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48166	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48167	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48168	 1	 7.1	 3.3	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48169	 1	 12.43	 7.46	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48170	 1	 10.42	 2.45	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48171	 1	 5.91	 1.39	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48172	 1	 8.26	 1.94	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48173	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48174	 1	 11.19	 2.62	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48175	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48176	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48177	 1	 11.22	 2.65	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48178	 1	 3.29	 0.77	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48179	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48180	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48181	 1	 7.95	 3.91	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48182	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48183	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48184	 1	 10.8	 2.52	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48185	 1	 21.41	 4.88	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48186	 1	 13.21	 3.03	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48187	 1	 10.44	 2.4	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48188	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48189	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48190	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48191	 1	 11.93	 2.78	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48192	 1	 49.35	 11.57	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48193	 1	 27.97	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48194	 1	 64.11	 15.12	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48195	 1	 16.05	 3.74	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48196	 1	 5.12	 1.2	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48197	 1	 13.68	 3.17	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48198	 1	 8.88	 2.07	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48199	 1	 9.3	 2.18	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48200	 1	 11.08	 2.53	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48201	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48202	 1	 12.02	 2.76	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48203	 1	 9.29	 2.16	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48204	 1	 15.35	 3.51	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48205	 1	 12.02	 2.82	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48206	 1	 20.57	 4.82	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48207	 1	 11.81	 2.77	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48208	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48209	 1	 9.82	 2.29	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48210	 1	 21.64	 5.07	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48211	 1	 19.09	 4.48	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48212	 1	 11.71	 2.75	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48213	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48214	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48215	 1	 35.84	 15.69	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48216	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48217	 1	 15.24	 3.43	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48218	 1	 20.84	 4.87	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48219	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48220	 1	 14.34	 7.27	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48221	 1	 8.59	 4.2	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48222	 1	 29.21	 6.91	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48223	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48224	 1	 12.85	 7.43	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48225	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48226	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48227	 1	 14.2	 5.54	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48228	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48229	 1	 6.45	 2.99	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48230	 1	 11.86	 2.79	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48231	 1	 30.69	 15.69	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48232	 1	 12.22	 6.29	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48233	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48234	 1	 16.34	 8.27	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48235	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48236	 1	 9.25	 4.04	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48237	 1	 16.35	 9.4	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48238	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48239	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48240	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48241	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48242	 1	 11.31	 6.13	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48243	 1	 25.15	 10.77	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48244	 1	 9.91	 4.77	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48245	 1	 12.85	 6.34	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48246	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48247	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48248	 1	 14.02	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48249	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48250	 1	 5.23	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48251	 1	 3.1	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48252	 1	 4.12	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48253	 1	 3.53	 1.62	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48254	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48255	 1	 5.44	 2.77	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48256	 1	 17.25	 7.48	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48257	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48258	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48259	 1	 6.86	 3.21	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48260	 1	 10.68	 5.01	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48261	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48262	 1	 38.73	 12.28	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48263	 1	 10.89	 5.31	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48264	 1	 18.14	 6.57	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48265	 1	 9.5	 5.08	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48266	 1	 32.7	 13.06	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48267	 1	 8.63	 4.1	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48268	 1	 8.33	 3.76	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48269	 1	 14.5	 7.74	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48270	 1	 8.51	 3.92	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48271	 1	 4.05	 1.88	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48272	 1	 2.45	 1.19	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48273	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48274	 1	 1.46	 0.76	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48275	 1	 4.69	 2.58	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48276	 1	 3.09	 1.52	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48277	 1	 7.25	 3.37	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48278	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48279	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48280	 1	 7.6	 4.24	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48281	 1	 1.92	 1.08	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48282	 1	 3.24	 1.56	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48283	 1	 2.43	 1.37	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48284	 1	 1.23	 0.69	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48285	 1	 0.55	 0.26	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48286	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48287	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48288	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48289	 1	 4.29	 2.13	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48290	 1	 3.85	 2.03	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48291	 1	 2.08	 1.16	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48292	 1	 2.24	 1.27	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48293	 1	 3.27	 1.57	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48294	 1	 4.32	 2.23	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48295	 1	 0.01	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48296	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48297	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48298	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48299	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48300	 1	 7.25	 3.43	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48301	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48302	 1	 10.15	 5.06	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48303	 1	 2.43	 1.43	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48304	 1	 11.93	 2.72	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48305	 1	 4.06	 2.05	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48306	 1	 6.53	 3.89	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48307	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48308	 1	 2.98	 1.78	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48309	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	48310	 1	 2.53	 1.33	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48311	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48312	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48313	 1	 6.64	 3.8	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48314	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48315	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	48316	 1	 6.66	 3.14	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48317	 1	 5.66	 3.1	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48318	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	48319	 1	 3.7	 1.85	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48320	 1	 3.4	 1.61	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48321	 1	 3.1	 1.66	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48322	 1	 1.47	 0.74	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48323	 1	 1.99	 1.14	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48324	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48325	 1	 2.94	 1.45	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48326	 1	 4.9	 2.5	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48327	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48328	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48329	 1	 3.23	 1.76	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48330	 1	 3.89	 1.8	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48331	 1	 3.41	 1.53	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48332	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48333	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48334	 1	 2.32	 1.07	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48335	 1	 1.89	 1.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48336	 1	 2.03	 1.06	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48337	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48338	 1	 4.89	 2.59	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48339	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48340	 1	 3.67	 1.99	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48341	 1	 2.04	 0.93	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48342	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48343	 1	 2.44	 1.43	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48344	 1	 2.12	 0.96	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48345	 1	 2.57	 1.26	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48346	 1	 5.8	 3.69	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48347	 1	 7.14	 3.32	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48348	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48349	 1	 2.39	 1.28	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48350	 1	 3.53	 1.78	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48351	 1	 2.79	 1.4	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48352	 1	 2.23	 1.1	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48353	 1	 0.17	 0.11	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48354	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48355	 1	 5.49	 2.65	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48356	 1	 2.13	 0.98	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48357	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48358	 1	 4.43	 2.73	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48359	 1	 5.56	 3.3	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48360	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48361	 1	 3.3	 1.72	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48362	 1	 4.23	 2.33	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48363	 1	 2.16	 1.18	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48364	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48365	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48366	 1	 3.83	 2.12	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48367	 1	 5.14	 2.84	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48368	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48369	 1	 4.56	 2.76	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48370	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48371	 1	 8.15	 4.33	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48372	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48373	 1	 3.57	 1.78	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48374	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48375	 1	 3.83	 1.93	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48376	 1	 3.69	 1.81	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48377	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48378	 1	 7.75	 4.33	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48379	 1	 2.54	 1.1	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48380	 1	 3.33	 1.92	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48381	 1	 2.11	 1.02	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48382	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48383	 1	 1.9	 0.86	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48384	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48385	 1	 2.91	 1.43	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48386	 1	 3.78	 2.02	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48387	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48388	 1	 1.91	 0.91	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48389	 1	 3.43	 1.99	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48390	 1	 3.59	 1.9	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48391	 1	 2.39	 1.08	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48392	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48393	 1	 2.97	 1.69	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48394	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48395	 1	 3.71	 1.76	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48396	 1	 4.28	 2.13	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48397	 1	 2.41	 1.26	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48398	 1	 4.04	 2.31	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48399	 1	 2.43	 1.06	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48400	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48401	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48402	 1	 2.54	 1.3	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48403	 1	 4.23	 2.07	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48404	 1	 2.6	 1.16	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48405	 1	 2.49	 1.11	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48406	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48407	 1	 2.99	 1.46	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48408	 1	 4.41	 2.16	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48409	 1	 5.08	 2.69	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48410	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48411	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48412	 1	 3.4	 1.71	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48413	 1	 3.12	 1.67	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48414	 1	 3.99	 2.2	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48415	 1	 4.01	 2.18	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48416	 1	 3.97	 1.8	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48417	 1	 3.72	 1.83	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48418	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48419	 1	 2.73	 1.27	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48420	 1	 2.45	 1.16	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48421	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48422	 1	 5.94	 3.16	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48423	 1	 9.92	 5.18	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48424	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48425	 1	 8.64	 5.47	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48426	 1	 1.61	 0.8	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48427	 1	 12.45	 5.9	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48428	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48429	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48430	 1	 3.39	 1.94	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48431	 1	 6.71	 3.81	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48432	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48433	 1	 1.96	 1.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48434	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48435	 1	 5.43	 2.66	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48436	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48437	 1	 4.16	 2.96	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48438	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48439	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48440	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48441	 1	 6.0	 3.33	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48442	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48443	 1	 16.16	 8.53	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48444	 1	 8.66	 3.22	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48445	 1	 2.62	 1.15	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48446	 1	 5.51	 2.52	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48447	 1	 9.08	 4.46	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48448	 1	 3.83	 1.62	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48449	 1	 12.1	 7.46	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48450	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48451	 1	 6.37	 3.16	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48452	 1	 6.54	 3.77	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48453	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48454	 1	 12.33	 7.5	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48455	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48456	 1	 4.0	 1.87	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48457	 1	 11.67	 5.93	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48458	 1	 19.05	 8.33	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48459	 1	 5.64	 3.34	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48460	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48461	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48462	 1	 10.9	 5.12	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48463	 1	 21.83	 10.93	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48464	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48465	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	48466	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48467	 1	 10.77	 5.44	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48468	 1	 3.12	 1.68	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48469	 1	 16.63	 6.93	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48470	 1	 35.76	 16.41	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48471	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48472	 1	 6.05	 3.08	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48473	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48474	 1	 9.63	 4.23	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48475	 1	 9.16	 4.87	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48476	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48477	 1	 1.68	 1.09	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48478	 1	 40.94	 18.9	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48479	 1	 36.19	 13.55	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48480	 1	 11.11	 6.51	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48481	 1	 9.07	 4.23	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48482	 1	 19.4	 7.74	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48483	 1	 6.16	 2.83	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48484	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48485	 1	 20.45	 4.73	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48486	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48487	 1	 10.15	 5.79	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48488	 1	 7.01	 3.52	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48489	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48490	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48491	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48492	 1	 6.35	 3.65	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48493	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48494	 1	 18.24	 7.98	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48495	 1	 6.73	 4.15	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48496	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48497	 1	 10.43	 4.21	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48498	 1	 6.46	 3.44	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48499	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48500	 1	 10.6	 5.74	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48501	 1	 10.42	 5.76	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48502	 1	 12.22	 7.42	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48503	 1	 23.1	 5.35	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48504	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48505	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48506	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48507	 1	 5.34	 2.81	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48508	 1	 6.44	 2.97	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48509	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48510	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48511	 1	 22.94	 12.94	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48512	 1	 7.05	 3.7	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48513	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48514	 1	 6.88	 1.58	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48515	 1	 14.31	 7.63	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48516	 1	 11.89	 6.85	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48517	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48518	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48519	 1	 20.22	 10.48	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48520	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48521	 1	 60.36	 14.05	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48522	 1	 22.87	 5.22	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48523	 1	 5.26	 1.15	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48524	 1	 6.23	 3.43	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48525	 1	 12.36	 2.72	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48526	 1	 7.81	 1.81	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48527	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48528	 1	 6.59	 2.9	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48529	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48530	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48531	 1	 10.33	 5.22	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48532	 1	 13.2	 6.61	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48533	 1	 5.58	 2.37	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48534	 1	 12.57	 6.74	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48535	 1	 1.18	 0.45	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48536	 1	 7.21	 4.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48537	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48538	 1	 2.94	 1.6	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48539	 1	 4.77	 2.56	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48540	 1	 4.84	 2.05	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48541	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48542	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48543	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48544	 1	 2.64	 1.19	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48545	 1	 1.89	 0.93	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48546	 1	 9.5	 4.41	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48547	 1	 3.04	 1.69	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48548	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48549	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48550	 1	 3.47	 1.69	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48551	 1	 28.69	 17.22	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48552	 1	 127.99	 48.16	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	48553	 1	 2.76	 1.22	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48554	 1	 15.14	 7.66	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48555	 1	 10.83	 5.55	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48556	 1	 26.62	 13.03	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48557	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48558	 1	 58.32	 28.95	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48559	 1	 6.53	 3.24	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48560	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48561	 1	 6.83	 3.09	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48562	 1	 17.63	 9.2	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48563	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48564	 1	 20.95	 9.89	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48565	 1	 20.66	 10.23	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48566	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48567	 1	 12.22	 5.17	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48568	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48569	 1	 9.74	 5.01	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48570	 1	 6.3	 3.54	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48571	 1	 6.56	 3.42	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48572	 1	 11.9	 2.75	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48573	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48574	 1	 13.9	 3.22	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48575	 1	 9.92	 2.29	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48576	 1	 10.91	 2.53	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48577	 1	 15.66	 3.62	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48578	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48579	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48580	 1	 9.3	 5.15	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48581	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48582	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48583	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48584	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48585	 1	 25.39	 5.9	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48586	 1	 7.73	 4.15	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48587	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48588	 1	 7.54	 1.74	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48589	 1	 3.31	 0.76	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48590	 1	 5.18	 2.18	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48591	 1	 28.46	 14.43	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48592	 1	 20.77	 9.22	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48593	 1	 7.21	 3.72	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48594	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48595	 1	 26.66	 14.35	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48596	 1	 14.58	 7.52	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48597	 1	 9.91	 4.66	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48598	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48599	 1	 4.28	 2.29	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48600	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48601	 1	 4.34	 2.3	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48602	 1	 3.69	 2.05	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48603	 1	 17.98	 9.12	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48604	 1	 10.33	 5.57	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48605	 1	 16.31	 8.81	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48606	 1	 19.11	 7.96	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48607	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48608	 1	 21.13	 11.73	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48609	 1	 15.34	 8.22	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48610	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48611	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48612	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48613	 1	 7.43	 3.47	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48614	 1	 14.63	 5.9	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48615	 1	 5.53	 3.28	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48616	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48617	 1	 21.44	 13.12	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48618	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48619	 1	 25.21	 13.07	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48620	 1	 11.63	 5.53	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48621	 1	 12.28	 5.43	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48622	 1	 11.0	 2.52	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48623	 1	 13.03	 6.92	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48624	 1	 15.06	 7.59	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48625	 1	 11.13	 5.35	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48626	 1	 11.94	 5.04	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48627	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48628	 1	 12.97	 6.2	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48629	 1	 8.56	 4.22	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48630	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48631	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48632	 1	 6.58	 3.51	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48633	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48634	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48635	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	48636	 1	 6.8	 3.84	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48637	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48638	 1	 9.53	 4.86	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48639	 1	 8.94	 4.3	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48640	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48641	 1	 4.89	 2.16	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48642	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48643	 1	 7.18	 4.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48644	 1	 16.13	 8.03	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48645	 1	 0.17	 0.11	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	48646	 1	 5.19	 2.64	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48647	 1	 11.86	 4.86	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48648	 1	 25.85	 13.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48649	 1	 13.23	 5.94	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48650	 1	 24.68	 13.1	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48651	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48652	 1	 24.77	 9.58	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48653	 1	 19.83	 10.77	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48654	 1	 10.04	 4.53	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48655	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48656	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48657	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48658	 1	 9.3	 4.73	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48659	 1	 10.21	 4.82	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48660	 1	 8.84	 4.45	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48661	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48662	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48663	 1	 19.84	 10.19	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48664	 1	 8.78	 4.47	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48665	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48666	 1	 3.87	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48667	 1	 2.62	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48668	 1	 3.72	 0.84	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48669	 1	 22.3	 5.02	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48670	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48671	 1	 18.55	 4.15	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48672	 1	 13.55	 3.02	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48673	 1	 104.56	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48674	 1	 9.85	 2.19	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48675	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48676	 1	 11.03	 4.5	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48677	 1	 5.08	 2.58	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48678	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48679	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48680	 1	 6.0	 3.32	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48681	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48682	 1	 11.91	 2.69	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48683	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48684	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48685	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48686	 1	 13.91	 3.2	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48687	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48688	 1	 23.74	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48689	 1	 23.06	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48690	 1	 7.62	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48691	 1	 34.83	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48692	 1	 20.61	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48693	 1	 11.37	 5.77	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48694	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48695	 1	 8.8	 4.36	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48696	 1	 10.54	 5.97	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48697	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48698	 1	 10.48	 5.17	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48699	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48700	 1	 6.07	 2.75	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48701	 1	 4.93	 2.1	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48702	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48703	 1	 13.26	 5.82	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48704	 1	 14.75	 7.67	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48705	 1	 16.68	 6.59	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48706	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	48707	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	48708	 1	 8.02	 4.26	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48709	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	48710	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48711	 1	 10.25	 4.3	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48712	 1	 11.25	 6.13	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48713	 1	 7.8	 3.97	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48714	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	48715	 1	 9.78	 4.96	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48716	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48717	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48718	 1	 9.76	 2.32	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48719	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48720	 1	 23.94	 5.6	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48721	 1	 6.39	 1.5	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48722	 1	 20.7	 4.84	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48723	 1	 5.01	 1.16	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48724	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48725	 1	 7.97	 1.86	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48726	 1	 17.05	 4.01	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48727	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48728	 1	 138.75	 68.9	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48729	 1	 19.4	 9.69	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48730	 1	 64.59	 36.74	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48731	 1	 63.63	 25.26	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48732	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48733	 1	 8.25	 1.92	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48734	 1	 6.6	 1.56	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48735	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48736	 1	 4.5	 2.82	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48737	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48738	 1	 47.69	 11.03	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48739	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48740	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48741	 1	 6.27	 3.52	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48742	 1	 2.97	 0.72	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48743	 1	 2.88	 0.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48744	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48745	 1	 3.24	 0.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48746	 1	 10.82	 2.66	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48747	 1	 6.1	 1.49	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48748	 1	 5.62	 1.37	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48749	 1	 4.47	 4.17	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48750	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48751	 1	 1.74	 1.3	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48752	 1	 3.48	 2.92	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48753	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48754	 1	 4.2	 3.98	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48755	 1	 10.17	 8.4	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48756	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48757	 1	 4.48	 3.32	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48758	 1	 13.31	 10.59	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48759	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48760	 1	 5.32	 4.26	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48761	 1	 6.42	 4.91	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48762	 1	 5.48	 4.43	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48763	 1	 6.11	 4.62	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48764	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48765	 1	 3.1	 2.88	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48766	 1	 4.68	 2.82	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48767	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48768	 1	 2.33	 1.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48769	 1	 3.75	 2.44	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48770	 1	 8.39	 7.85	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48771	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48772	 1	 6.73	 6.48	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48773	 1	 3.46	 3.23	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48774	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48775	 1	 2.91	 2.45	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48776	 1	 4.86	 1.16	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48777	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48778	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48779	 1	 1.68	 0.4	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48780	 1	 3.09	 2.55	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48781	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48782	 1	 4.83	 4.36	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48783	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48784	 1	 2.34	 2.18	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48785	 1	 1.71	 1.34	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48786	 1	 4.93	 4.35	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48787	 1	 5.8	 4.14	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48788	 1	 5.06	 3.86	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48789	 1	 3.62	 2.97	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48790	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48791	 1	 5.1	 4.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48792	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48793	 1	 6.89	 6.81	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48794	 1	 6.77	 6.51	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48795	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48796	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48797	 1	 6.0	 4.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48798	 1	 4.39	 4.04	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48799	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48800	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48801	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48802	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48803	 1	 10.09	 9.72	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48804	 1	 5.1	 4.41	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48805	 1	 7.36	 6.86	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48806	 1	 4.62	 3.76	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48807	 1	 3.67	 2.67	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48808	 1	 7.25	 6.81	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48809	 1	 3.19	 2.54	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48810	 1	 12.03	 8.81	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48811	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48812	 1	 6.16	 5.85	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48813	 1	 8.99	 7.39	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48814	 1	 4.62	 3.28	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48815	 1	 3.6	 2.6	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48816	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48817	 1	 1.57	 1.41	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48818	 1	 2.25	 1.6	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48819	 1	 9.58	 6.24	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48820	 1	 14.74	 10.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48821	 1	 10.76	 9.63	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48822	 1	 6.45	 4.77	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48823	 1	 4.91	 4.17	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48824	 1	 2.33	 1.92	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48825	 1	 9.53	 8.12	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48826	 1	 4.26	 3.65	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48827	 1	 4.02	 3.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48828	 1	 9.12	 5.86	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48829	 1	 3.71	 3.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48830	 1	 3.65	 2.69	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48831	 1	 5.18	 3.51	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48832	 1	 2.38	 1.93	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48833	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48834	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48835	 1	 6.64	 1.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48836	 1	 13.25	 9.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48837	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48838	 1	 49.35	 36.96	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48839	 1	 7.85	 5.5	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48840	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	48841	 1	 3.89	 3.2	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48842	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48843	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48844	 1	 6.15	 5.02	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48845	 1	 4.56	 3.85	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48846	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48847	 1	 7.45	 5.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48848	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48849	 1	 4.24	 3.76	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48850	 1	 8.53	 2.06	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48851	 1	 8.02	 6.69	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48852	 1	 3.11	 2.97	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48853	 1	 14.04	 11.19	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48854	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48855	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48856	 1	 6.2	 5.11	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48857	 1	 5.98	 4.32	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48858	 1	 6.68	 4.73	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48859	 1	 5.03	 1.25	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48860	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48861	 1	 3.15	 0.78	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48862	 1	 4.34	 1.06	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48863	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48864	 1	 4.21	 1.03	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48865	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48866	 1	 7.35	 1.82	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48867	 1	 3.76	 0.91	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48868	 1	 2.4	 0.59	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48869	 1	 3.06	 0.75	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48870	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48871	 1	 3.15	 3.1	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48872	 1	 3.78	 3.02	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48873	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48874	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48875	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48876	 1	 3.23	 3.07	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48877	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48878	 1	 2.25	 2.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48879	 1	 3.77	 2.94	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48880	 1	 8.6	 7.13	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48881	 1	 6.41	 4.84	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48882	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48883	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48884	 1	 12.24	 8.5	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48885	 1	 3.59	 3.24	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48886	 1	 5.06	 1.22	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48887	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48888	 1	 27.37	 22.13	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48889	 1	 4.36	 3.88	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48890	 1	 3.22	 2.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48891	 1	 4.52	 3.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48892	 1	 2.91	 2.11	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48893	 1	 7.77	 5.88	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48894	 1	 1.7	 1.23	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48895	 1	 3.56	 3.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48896	 1	 7.76	 6.7	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48897	 1	 6.73	 5.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48898	 1	 3.37	 2.85	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48899	 1	 3.5	 3.2	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48900	 1	 2.64	 2.6	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48901	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48902	 1	 3.15	 2.98	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48903	 1	 9.76	 8.73	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48904	 1	 10.34	 8.47	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48905	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48906	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48907	 1	 8.83	 7.98	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48908	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48909	 1	 6.49	 5.22	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48910	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48911	 1	 4.48	 3.43	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48912	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48913	 1	 4.61	 3.95	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48914	 1	 3.56	 2.73	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48915	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48916	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48917	 1	 4.23	 3.4	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48918	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48919	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48920	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48921	 1	 5.07	 5.05	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48922	 1	 3.35	 3.21	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48923	 1	 5.37	 4.99	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48924	 1	 4.63	 4.32	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48925	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48926	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48927	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48928	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48929	 1	 6.22	 5.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48930	 1	 5.49	 4.81	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	48931	 1	 4.0	 2.91	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48932	 1	 5.73	 1.42	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48933	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48934	 1	 6.33	 3.96	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48935	 1	 3.94	 3.59	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48936	 1	 7.45	 5.77	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48937	 1	 3.49	 2.7	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48938	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48939	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48940	 1	 3.15	 2.65	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48941	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48942	 1	 9.91	 7.72	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48943	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48944	 1	 2.18	 1.9	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48945	 1	 4.27	 3.62	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48946	 1	 4.13	 3.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48947	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48948	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48949	 1	 5.24	 4.32	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48950	 1	 3.41	 2.45	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48951	 1	 4.84	 4.23	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48952	 1	 5.21	 4.44	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48953	 1	 6.27	 4.68	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48954	 1	 4.57	 3.15	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48955	 1	 5.82	 4.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48956	 1	 2.42	 2.1	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48957	 1	 5.73	 4.31	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48958	 1	 5.17	 4.58	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48959	 1	 5.36	 4.3	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48960	 1	 3.6	 3.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48961	 1	 4.89	 4.4	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48962	 1	 11.03	 7.64	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48963	 1	 7.91	 6.86	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48964	 1	 3.73	 3.07	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48965	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48966	 1	 7.39	 5.11	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48967	 1	 7.5	 5.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48968	 1	 5.78	 5.39	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48969	 1	 7.1	 6.14	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48970	 1	 6.98	 5.07	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48971	 1	 4.05	 3.4	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48972	 1	 4.72	 3.43	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48973	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48974	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	48975	 1	 26.47	 17.92	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48976	 1	 2.3	 1.85	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48977	 1	 9.78	 6.22	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48978	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48979	 1	 5.96	 4.42	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48980	 1	 8.92	 6.03	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48981	 1	 3.69	 0.86	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48982	 1	 6.49	 5.5	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48983	 1	 6.03	 5.49	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48984	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48985	 1	 9.81	 2.43	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48986	 1	 12.12	 2.99	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48987	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48988	 1	 13.44	 3.33	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48989	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48990	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	48991	 1	 3.43	 0.84	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48992	 1	 2.69	 0.65	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48993	 1	 5.36	 1.31	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48994	 1	 2.92	 0.7	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	48995	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48996	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48997	 1	 4.87	 1.19	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48998	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48999	 1	 17.21	 4.11	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49000	 1	 4.48	 1.08	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49001	 1	 9.03	 2.11	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49002	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49003	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49004	 1	 3.38	 3.13	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49005	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49006	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49007	 1	 6.27	 1.51	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49008	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49009	 1	 3.87	 3.65	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49010	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49011	 1	 5.42	 3.84	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49012	 1	 5.14	 4.53	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49013	 1	 7.56	 1.85	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49014	 1	 7.04	 1.69	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49015	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49016	 1	 9.11	 7.19	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49017	 1	 3.98	 0.96	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49018	 1	 6.4	 1.52	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49019	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49020	 1	 5.02	 1.21	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49021	 1	 2.75	 2.36	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49022	 1	 4.2	 0.99	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49023	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49024	 1	 3.38	 3.26	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49025	 1	 4.39	 3.35	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49026	 1	 4.75	 4.34	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49027	 1	 4.82	 4.83	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49028	 1	 2.44	 2.5	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49029	 1	 12.22	 9.96	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49030	 1	 8.24	 6.84	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49031	 1	 1.87	 1.53	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49032	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49033	 1	 1.64	 1.69	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49034	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49035	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49036	 1	 10.08	 7.43	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49037	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49038	 1	 14.59	 3.51	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49039	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49040	 1	 8.33	 1.99	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49041	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49042	 1	 9.78	 6.79	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49043	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49044	 1	 2.49	 2.38	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49045	 1	 5.87	 5.07	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49046	 1	 4.13	 3.67	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49047	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49048	 1	 3.16	 2.76	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49049	 1	 10.52	 2.49	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49050	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49051	 1	 5.7	 1.39	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49052	 1	 2.75	 0.67	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49053	 1	 3.36	 0.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49054	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49055	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49056	 1	 5.91	 4.67	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49057	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49058	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49059	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49060	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49061	 1	 4.86	 4.58	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49062	 1	 1.94	 1.52	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49063	 1	 3.98	 2.86	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49064	 1	 14.04	 9.03	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49065	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49066	 1	 10.34	 7.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49067	 1	 6.15	 4.56	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49068	 1	 7.38	 4.99	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49069	 1	 5.8	 5.11	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49070	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49071	 1	 2.24	 1.93	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49072	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49073	 1	 6.01	 5.39	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49074	 1	 4.81	 4.01	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49075	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49076	 1	 8.21	 4.27	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49077	 1	 3.62	 2.95	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49078	 1	 31.91	 21.92	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49079	 1	 13.37	 11.52	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49080	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49081	 1	 4.7	 3.9	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49082	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49083	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49084	 1	 2.68	 2.14	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49085	 1	 6.01	 4.73	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49086	 1	 16.62	 14.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49087	 1	 2.65	 2.38	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49088	 1	 9.62	 6.39	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49089	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49090	 1	 5.41	 4.11	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49091	 1	 19.31	 16.66	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49092	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49093	 1	 3.7	 2.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49094	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49095	 1	 2.65	 2.11	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49096	 1	 3.56	 3.23	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49097	 1	 6.24	 5.08	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49098	 1	 5.46	 4.75	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49099	 1	 5.02	 3.93	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49100	 1	 3.51	 3.56	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49101	 1	 4.56	 4.46	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49102	 1	 6.23	 4.85	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49103	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49104	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49105	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49106	 1	 6.82	 5.18	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49107	 1	 3.89	 3.45	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49108	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49109	 1	 5.7	 4.88	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49110	 1	 5.78	 5.32	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49111	 1	 4.85	 4.34	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49112	 1	 4.94	 4.48	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49113	 1	 5.22	 4.39	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49114	 1	 5.8	 3.79	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49115	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49116	 1	 5.37	 4.76	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49117	 1	 6.67	 6.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49118	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49119	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49120	 1	 4.27	 1.05	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49121	 1	 1.54	 0.38	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49122	 1	 3.95	 0.97	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49123	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49124	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49125	 1	 2.26	 2.01	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49126	 1	 4.13	 2.84	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49127	 1	 5.03	 3.36	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49128	 1	 3.29	 2.47	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49129	 1	 4.59	 3.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49130	 1	 2.73	 2.25	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49131	 1	 7.24	 5.96	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49132	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49133	 1	 2.29	 1.92	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49134	 1	 2.05	 1.91	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49135	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49136	 1	 4.25	 2.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49137	 1	 3.54	 2.5	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49138	 1	 4.88	 2.64	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49139	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49140	 1	 5.15	 4.38	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49141	 1	 5.18	 4.7	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49142	 1	 6.83	 5.38	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49143	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49144	 1	 4.5	 4.01	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49145	 1	 3.69	 3.63	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49146	 1	 5.46	 3.75	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49147	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49148	 1	 10.44	 8.16	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49149	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49150	 1	 5.65	 3.55	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49151	 1	 2.47	 2.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49152	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49153	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49154	 1	 3.09	 2.37	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49155	 1	 3.67	 2.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49156	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49157	 1	 3.76	 3.48	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49158	 1	 2.62	 2.01	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49159	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49160	 1	 1.48	 1.21	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49161	 1	 3.28	 2.69	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49162	 1	 5.78	 3.54	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49163	 1	 5.12	 4.17	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49164	 1	 12.81	 7.43	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49165	 1	 3.7	 2.63	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49166	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49167	 1	 3.22	 2.26	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49168	 1	 0.95	 0.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49169	 1	 1.39	 1.25	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49170	 1	 8.01	 5.78	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49171	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49172	 1	 6.79	 4.66	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49173	 1	 3.36	 3.02	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49174	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49175	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49176	 1	 1.09	 0.86	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49177	 1	 0.8	 0.76	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49178	 1	 1.51	 1.29	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49179	 1	 2.35	 2.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49180	 1	 3.97	 2.99	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49181	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49182	 1	 1.21	 1.14	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49183	 1	 2.02	 1.91	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49184	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49185	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49186	 1	 4.49	 3.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49187	 1	 4.25	 3.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49188	 1	 3.39	 2.58	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49189	 1	 3.96	 2.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49190	 1	 2.68	 2.45	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49191	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49192	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49193	 1	 2.16	 1.79	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49194	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49195	 1	 1.7	 1.19	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49196	 1	 4.34	 3.4	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49197	 1	 4.04	 3.26	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49198	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49199	 1	 2.05	 1.63	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49200	 1	 2.9	 2.6	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49201	 1	 2.97	 2.41	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49202	 1	 2.21	 2.04	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49203	 1	 2.93	 2.19	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49204	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49205	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49206	 1	 2.81	 2.49	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49207	 1	 1.62	 1.17	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49208	 1	 4.54	 3.39	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49209	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49210	 1	 4.92	 3.7	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49211	 1	 6.2	 5.09	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49212	 1	 6.84	 4.73	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49213	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49214	 1	 34.07	 19.84	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49215	 1	 3.24	 2.48	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49216	 1	 4.59	 3.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49217	 1	 2.97	 2.2	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49218	 1	 6.31	 4.14	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49219	 1	 6.02	 4.1	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49220	 1	 2.25	 1.6	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49221	 1	 5.64	 4.53	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49222	 1	 1.35	 1.23	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49223	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49224	 1	 5.48	 4.51	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49225	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49226	 1	 3.26	 2.48	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49227	 1	 4.89	 4.29	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49228	 1	 6.32	 4.31	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49229	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49230	 1	 3.4	 2.55	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49231	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49232	 1	 24.65	 18.95	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49233	 1	 2.91	 2.51	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49234	 1	 5.51	 4.59	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49235	 1	 7.45	 6.63	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49236	 1	 6.4	 5.81	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49237	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49238	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49239	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49240	 1	 2.5	 2.26	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49241	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49242	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49243	 1	 2.86	 2.64	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49244	 1	 4.18	 3.88	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49245	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49246	 1	 3.08	 2.81	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49247	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49248	 1	 8.73	 7.61	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49249	 1	 5.01	 4.03	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49250	 1	 1.69	 1.48	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49251	 1	 4.73	 3.5	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49252	 1	 5.04	 4.03	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49253	 1	 1.99	 1.81	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49254	 1	 4.01	 3.18	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49255	 1	 8.79	 6.9	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49256	 1	 9.43	 7.67	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49257	 1	 5.8	 4.86	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49258	 1	 2.58	 2.12	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49259	 1	 2.34	 1.78	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49260	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49261	 1	 2.22	 1.68	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49262	 1	 6.24	 5.27	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49263	 1	 4.0	 3.01	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49264	 1	 9.42	 7.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49265	 1	 10.57	 7.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49266	 1	 4.68	 3.77	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49267	 1	 4.85	 4.39	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49268	 1	 2.92	 2.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49269	 1	 1.56	 1.4	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49270	 1	 5.29	 4.38	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49271	 1	 2.51	 1.9	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49272	 1	 2.58	 1.6	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49273	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49274	 1	 5.09	 3.62	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49275	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49276	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49277	 1	 7.38	 5.21	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49278	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49279	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49280	 1	 1.02	 0.91	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49281	 1	 6.2	 5.44	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49282	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49283	 1	 1.67	 1.56	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49284	 1	 2.77	 2.38	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49285	 1	 4.81	 3.9	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49286	 1	 4.58	 3.7	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49287	 1	 6.54	 5.03	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49288	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49289	 1	 6.45	 5.66	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49290	 1	 6.58	 5.94	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49291	 1	 2.77	 2.4	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49292	 1	 0.66	 0.63	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49293	 1	 5.63	 4.75	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49294	 1	 2.05	 1.54	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49295	 1	 3.45	 3.14	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49296	 1	 8.1	 6.06	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49297	 1	 10.24	 9.06	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49298	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49299	 1	 3.35	 2.96	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49300	 1	 6.07	 4.51	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49301	 1	 6.65	 4.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49302	 1	 2.71	 2.05	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49303	 1	 4.82	 4.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49304	 1	 4.7	 3.4	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49305	 1	 5.87	 4.63	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49306	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49307	 1	 3.51	 3.22	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49308	 1	 1.79	 1.57	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49309	 1	 5.66	 4.27	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49310	 1	 4.95	 3.66	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49311	 1	 3.59	 3.14	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49312	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49313	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49314	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49315	 1	 8.17	 5.5	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49316	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49317	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49318	 1	 3.21	 2.41	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49319	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49320	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49321	 1	 4.15	 3.3	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49322	 1	 4.15	 3.26	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49323	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49324	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49325	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49326	 1	 3.95	 3.57	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49327	 1	 1.86	 1.69	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49328	 1	 1.6	 1.37	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49329	 1	 5.3	 4.27	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49330	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49331	 1	 2.04	 1.64	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49332	 1	 3.38	 2.74	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49333	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49334	 1	 6.96	 5.38	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49335	 1	 4.99	 3.99	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49336	 1	 7.02	 5.65	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49337	 1	 3.97	 3.07	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49338	 1	 4.5	 3.23	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49339	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49340	 1	 7.22	 5.81	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49341	 1	 9.32	 7.63	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49342	 1	 4.3	 3.6	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49343	 1	 4.92	 4.64	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49344	 1	 2.53	 2.05	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49345	 1	 2.48	 2.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49346	 1	 2.4	 1.94	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49347	 1	 5.73	 4.51	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49348	 1	 2.45	 1.57	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49349	 1	 0.21	 0.19	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49350	 1	 0.08	 0.06	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49351	 1	 0.22	 0.17	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49352	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49353	 1	 6.45	 4.93	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49354	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49355	 1	 15.65	 11.84	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49356	 1	 5.58	 4.92	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49357	 1	 7.34	 6.26	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49358	 1	 8.5	 6.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49359	 1	 7.23	 5.57	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49360	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49361	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49362	 1	 1.87	 1.42	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49363	 1	 10.21	 6.88	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49364	 1	 7.34	 6.51	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49365	 1	 5.17	 3.89	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49366	 1	 12.42	 7.72	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49367	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49368	 1	 7.21	 6.88	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49369	 1	 7.17	 5.24	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49370	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49371	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49372	 1	 3.33	 2.87	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49373	 1	 14.69	 9.33	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49374	 1	 3.38	 2.11	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49375	 1	 11.15	 9.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49376	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49377	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49378	 1	 2.99	 2.68	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49379	 1	 7.19	 6.47	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49380	 1	 4.11	 3.46	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49381	 1	 2.6	 1.97	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49382	 1	 9.8	 6.75	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49383	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49384	 1	 2.02	 1.7	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49385	 1	 5.03	 4.15	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49386	 1	 4.58	 4.08	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49387	 1	 3.72	 3.43	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49388	 1	 4.45	 3.74	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49389	 1	 4.21	 3.73	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49390	 1	 8.18	 1.94	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49391	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49392	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49393	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49394	 1	 7.85	 6.43	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49395	 1	 4.03	 3.38	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49396	 1	 4.45	 3.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49397	 1	 6.77	 6.39	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49398	 1	 3.09	 2.31	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49399	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49400	 1	 14.27	 11.95	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49401	 1	 5.2	 4.4	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49402	 1	 4.92	 4.77	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49403	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49404	 1	 11.2	 9.06	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49405	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49406	 1	 7.58	 5.67	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49407	 1	 6.66	 5.19	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49408	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49409	 1	 3.56	 3.17	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49410	 1	 4.74	 3.77	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49411	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49412	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49413	 1	 3.04	 2.73	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49414	 1	 2.97	 2.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49415	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49416	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49417	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49418	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49419	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49420	 1	 10.67	 7.06	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49421	 1	 5.72	 4.2	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49422	 1	 8.26	 1.96	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49423	 1	 8.12	 7.52	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49424	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49425	 1	 2.42	 0.59	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49426	 1	 3.21	 0.78	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49427	 1	 7.57	 1.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49428	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49429	 1	 10.09	 8.42	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49430	 1	 4.72	 3.86	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49431	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49432	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49433	 1	 8.43	 5.53	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49434	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49435	 1	 9.56	 6.43	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49436	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49437	 1	 7.4	 1.76	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49438	 1	 9.7	 8.34	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49439	 1	 3.01	 2.85	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49440	 1	 14.7	 10.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49441	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49442	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49443	 1	 6.28	 5.78	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49444	 1	 6.4	 4.89	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49445	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49446	 1	 5.06	 3.78	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49447	 1	 6.34	 1.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49448	 1	 4.14	 1.02	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49449	 1	 2.82	 0.69	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49450	 1	 4.22	 1.02	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49451	 1	 8.54	 6.35	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49452	 1	 8.6	 2.05	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49453	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49454	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49455	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49456	 1	 8.01	 1.93	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49457	 1	 9.1	 2.18	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49458	 1	 1.43	 0.35	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49459	 1	 5.4	 1.3	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49460	 1	 4.94	 1.21	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49461	 1	 10.92	 2.68	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49462	 1	 7.96	 1.95	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49463	 1	 8.85	 2.15	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49464	 1	 3.29	 0.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49465	 1	 4.16	 1.05	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49466	 1	 8.35	 2.11	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49467	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49468	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49469	 1	 3.59	 2.57	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49470	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49471	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49472	 1	 3.97	 3.67	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49473	 1	 2.59	 2.41	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49474	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49475	 1	 8.41	 6.98	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49476	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49477	 1	 4.42	 4.43	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49478	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49479	 1	 3.15	 2.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49480	 1	 6.18	 1.47	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49481	 1	 3.44	 0.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49482	 1	 3.1	 0.74	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49483	 1	 20.38	 4.93	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49484	 1	 3.3	 3.01	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49485	 1	 7.14	 1.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49486	 1	 5.33	 1.28	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49487	 1	 3.24	 0.79	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49488	 1	 3.83	 0.93	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49489	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49490	 1	 7.5	 1.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49491	 1	 1.99	 0.48	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49492	 1	 2.1	 0.5	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49493	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49494	 1	 2.92	 0.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49495	 1	 3.3	 0.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49496	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49497	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49498	 1	 5.69	 4.17	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49499	 1	 7.66	 5.56	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49500	 1	 3.96	 2.89	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49501	 1	 4.61	 3.4	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49502	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49503	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49504	 1	 2.81	 0.69	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49505	 1	 9.65	 2.24	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49506	 1	 7.22	 5.78	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49507	 1	 5.48	 3.97	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49508	 1	 2.25	 2.14	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49509	 1	 4.33	 2.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49510	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49511	 1	 5.1	 4.5	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49512	 1	 6.87	 1.66	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49513	 1	 5.45	 1.28	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49514	 1	 3.56	 0.84	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49515	 1	 7.28	 1.7	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49516	 1	 2.85	 0.7	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49517	 1	 5.99	 1.41	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49518	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49519	 1	 4.9	 3.88	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49520	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49521	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	49522	 1	 2.91	 2.82	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49523	 1	 5.19	 3.27	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	49524	 1	 8.81	 7.31	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49525	 1	 3.85	 3.3	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49526	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49527	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49528	 1	 9.75	 2.26	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49529	 1	 9.94	 9.09	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49530	 1	 4.24	 3.58	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49531	 1	 4.46	 3.9	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49532	 1	 5.0	 3.35	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49533	 1	 20.04	 11.07	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49534	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49535	 1	 3.04	 2.6	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49536	 1	 3.94	 2.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49537	 1	 5.91	 5.41	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49538	 1	 10.87	 9.08	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49539	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49540	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49541	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49542	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49543	 1	 1.96	 1.79	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49544	 1	 4.23	 3.54	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49545	 1	 5.41	 1.32	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49546	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49547	 1	 3.32	 0.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49548	 1	 4.86	 3.24	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49549	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49550	 1	 2.91	 2.58	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	49551	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	49552	 1	 4.04	 3.44	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49553	 1	 4.82	 4.53	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49554	 1	 10.2	 7.73	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	49555	 1	 2.58	 2.43	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	49556	 1	 4.52	 3.53	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49557	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49558	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49559	 1	 4.44	 3.2	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49560	 1	 5.25	 4.61	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49561	 1	 14.42	 3.39	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49562	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49563	 1	 3.84	 0.92	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49564	 1	 4.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49565	 1	 8.17	 1.9	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49566	 1	 3.86	 0.9	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49567	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49568	 1	 6.5	 1.51	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49569	 1	 3.56	 0.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49570	 1	 7.35	 1.72	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49571	 1	 4.85	 1.15	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49572	 1	 7.7	 1.82	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49573	 1	 6.84	 1.62	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49574	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49575	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49576	 1	 2.94	 0.69	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49577	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49578	 1	 4.18	 1.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49579	 1	 9.44	 2.24	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49580	 1	 3.4	 0.81	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49581	 1	 4.57	 1.09	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49582	 1	 7.82	 6.41	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49583	 1	 11.89	 6.92	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49584	 1	 10.47	 8.56	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49585	 1	 6.26	 5.06	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49586	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49587	 1	 7.86	 5.46	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49588	 1	 8.47	 6.48	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49589	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49590	 1	 4.04	 3.6	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49591	 1	 7.44	 5.26	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49592	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49593	 1	 4.97	 3.61	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49594	 1	 4.2	 3.86	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49595	 1	 1.97	 1.63	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49596	 1	 7.23	 5.87	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49597	 1	 1.63	 1.17	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49598	 1	 8.55	 5.91	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49599	 1	 9.36	 7.09	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49600	 1	 2.59	 2.42	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49601	 1	 10.16	 6.46	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49602	 1	 6.97	 5.61	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49603	 1	 4.51	 3.3	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49604	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49605	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49606	 1	 4.23	 3.79	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49607	 1	 6.42	 4.33	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49608	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49609	 1	 9.35	 6.42	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49610	 1	 10.77	 8.22	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49611	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49612	 1	 3.44	 0.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49613	 1	 3.39	 0.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49614	 1	 8.02	 1.94	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49615	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49616	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49617	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49618	 1	 5.42	 1.29	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49619	 1	 5.26	 1.25	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49620	 1	 4.47	 1.1	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49621	 1	 4.49	 3.53	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49622	 1	 12.78	 7.56	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49623	 1	 12.12	 7.24	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49624	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49625	 1	 6.1	 4.29	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49626	 1	 3.84	 3.37	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49627	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49628	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49629	 1	 11.57	 9.25	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49630	 1	 5.41	 4.33	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49631	 1	 6.15	 5.15	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49632	 1	 11.06	 7.18	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49633	 1	 9.05	 6.08	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49634	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49635	 1	 4.82	 3.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49636	 1	 3.78	 3.32	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49637	 1	 3.93	 3.38	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	49638	 1	 2.19	 1.76	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49639	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	49640	 1	 1.87	 1.78	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49641	 1	 7.85	 5.39	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49642	 1	 2.59	 0.62	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49643	 1	 4.07	 0.98	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49644	 1	 3.49	 0.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49645	 1	 5.1	 1.23	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49646	 1	 6.82	 1.64	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49647	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49648	 1	 8.43	 2.02	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49649	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49650	 1	 5.28	 1.26	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49651	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49652	 1	 6.57	 1.57	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49653	 1	 7.15	 1.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49654	 1	 5.09	 1.22	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49655	 1	 8.18	 1.94	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49656	 1	 3.8	 0.91	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49657	 1	 12.35	 2.95	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49658	 1	 3.01	 0.72	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49659	 1	 4.45	 1.06	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49660	 1	 6.63	 1.6	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49661	 1	 5.43	 1.31	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49662	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49663	 1	 7.13	 1.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49664	 1	 2.55	 0.61	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49665	 1	 4.93	 1.17	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49666	 1	 3.63	 0.87	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49667	 1	 4.7	 1.12	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49668	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49669	 1	 4.66	 1.12	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49670	 1	 3.52	 0.84	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49671	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49672	 1	 3.73	 0.89	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49673	 1	 5.12	 1.23	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49674	 1	 3.68	 0.88	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49675	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49676	 1	 4.17	 0.99	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49677	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49678	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49679	 1	 5.08	 1.21	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49680	 1	 3.78	 0.9	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49681	 1	 5.31	 1.27	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49682	 1	 6.23	 1.49	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49683	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49684	 1	 3.78	 0.91	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49685	 1	 3.69	 0.88	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49686	 1	 4.57	 1.09	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49687	 1	 21.73	 17.16	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49688	 1	 4.39	 1.06	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49689	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49690	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49691	 1	 3.47	 0.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49692	 1	 6.22	 1.5	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49693	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49694	 1	 2.9	 0.7	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49695	 1	 3.51	 0.84	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49696	 1	 4.77	 1.14	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49697	 1	 4.94	 1.18	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49698	 1	 3.71	 0.9	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49699	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49700	 1	 8.87	 2.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49701	 1	 4.81	 1.15	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49702	 1	 5.07	 1.22	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49703	 1	 2.45	 0.58	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49704	 1	 4.15	 0.99	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49705	 1	 1.85	 0.44	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49706	 1	 3.59	 0.87	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49707	 1	 12.54	 3.02	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49708	 1	 5.05	 1.21	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49709	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49710	 1	 4.42	 1.06	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49711	 1	 4.6	 1.1	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49712	 1	 3.82	 0.91	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49713	 1	 5.11	 1.23	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49714	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49715	 1	 4.76	 1.14	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49716	 1	 4.62	 1.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49717	 1	 2.14	 0.52	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49718	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49719	 1	 5.66	 4.93	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49720	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49721	 1	 2.4	 2.11	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49722	 1	 2.44	 1.88	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49723	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49724	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49725	 1	 7.56	 6.73	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49726	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49727	 1	 4.3	 3.73	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49728	 1	 5.67	 4.09	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49729	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49730	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49731	 1	 3.18	 3.07	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49732	 1	 6.07	 6.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49733	 1	 8.93	 7.77	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49734	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49735	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49736	 1	 6.99	 4.9	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49737	 1	 11.86	 10.33	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49738	 1	 6.55	 1.59	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49739	 1	 6.76	 6.23	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49740	 1	 3.4	 0.82	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49741	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49742	 1	 3.67	 0.89	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49743	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49744	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49745	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49746	 1	 4.89	 1.18	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49747	 1	 4.7	 1.14	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49748	 1	 4.25	 3.75	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49749	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49750	 1	 8.34	 2.02	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49751	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49752	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49753	 1	 3.14	 2.59	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49754	 1	 4.07	 3.35	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49755	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49756	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49757	 1	 1.99	 1.76	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49758	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49759	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49760	 1	 7.84	 5.59	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49761	 1	 6.71	 6.31	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49762	 1	 9.86	 2.37	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49763	 1	 8.3	 6.12	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49764	 1	 6.55	 5.15	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49765	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49766	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49767	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49768	 1	 4.31	 3.47	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49769	 1	 3.47	 3.02	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49770	 1	 7.84	 1.9	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49771	 1	 15.47	 3.73	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49772	 1	 29.84	 19.23	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49773	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49774	 1	 4.45	 1.07	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49775	 1	 4.07	 0.98	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49776	 1	 8.33	 2.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49777	 1	 7.03	 1.69	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49778	 1	 10.29	 2.46	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49779	 1	 5.14	 1.23	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49780	 1	 6.88	 1.65	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49781	 1	 2.72	 0.65	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49782	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49783	 1	 6.36	 1.53	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49784	 1	 3.49	 0.84	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49785	 1	 10.33	 2.48	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49786	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49787	 1	 8.98	 2.16	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49788	 1	 13.38	 10.93	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49789	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49790	 1	 14.84	 3.54	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49791	 1	 4.88	 4.4	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49792	 1	 3.5	 2.69	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49793	 1	 9.9	 2.37	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49794	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49795	 1	 4.65	 3.99	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49796	 1	 6.85	 1.65	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49797	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49798	 1	 8.17	 1.95	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49799	 1	 9.15	 2.21	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49800	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49801	 1	 6.53	 1.57	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49802	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49803	 1	 10.2	 8.36	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49804	 1	 12.22	 8.81	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49805	 1	 3.86	 0.92	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49806	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49807	 1	 6.45	 1.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49808	 1	 9.68	 2.32	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49809	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49810	 1	 37.51	 9.03	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49811	 1	 10.36	 2.48	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49812	 1	 6.01	 1.44	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49813	 1	 5.13	 1.23	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49814	 1	 4.79	 1.15	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49815	 1	 5.09	 1.21	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49816	 1	 2.65	 0.64	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49817	 1	 3.1	 0.75	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49818	 1	 9.2	 2.2	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49819	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49820	 1	 5.85	 1.4	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49821	 1	 14.61	 3.48	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49822	 1	 14.72	 3.5	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49823	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49824	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49825	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49826	 1	 5.02	 1.2	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49827	 1	 9.38	 6.59	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49828	 1	 10.82	 9.11	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49829	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	49830	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49831	 1	 11.15	 8.77	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49832	 1	 8.1	 1.94	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49833	 1	 2.33	 0.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49834	 1	 6.25	 1.49	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49835	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49836	 1	 8.12	 1.94	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49837	 1	 6.41	 4.99	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49838	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49839	 1	 2.54	 0.6	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49840	 1	 5.09	 1.21	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49841	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49842	 1	 2.89	 0.69	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49843	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49844	 1	 3.72	 2.87	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49845	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49846	 1	 5.56	 1.32	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49847	 1	 10.95	 8.53	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49848	 1	 11.59	 2.75	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49849	 1	 12.75	 3.05	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49850	 1	 14.62	 3.51	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49851	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49852	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49853	 1	 5.04	 1.2	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49854	 1	 4.2	 1.01	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49855	 1	 7.65	 1.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49856	 1	 3.46	 0.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49857	 1	 7.15	 1.72	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49858	 1	 5.59	 1.34	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49859	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49860	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49861	 1	 7.61	 5.85	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49862	 1	 8.19	 1.95	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49863	 1	 4.55	 3.97	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49864	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49865	 1	 4.42	 4.02	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49866	 1	 7.23	 1.73	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49867	 1	 10.14	 2.41	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49868	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49869	 1	 2.72	 2.21	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49870	 1	 24.76	 17.99	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49871	 1	 4.7	 1.12	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49872	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49873	 1	 6.49	 1.54	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49874	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49875	 1	 7.78	 1.85	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49876	 1	 10.37	 2.47	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49877	 1	 5.67	 1.35	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49878	 1	 27.59	 23.67	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49879	 1	 6.32	 4.93	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49880	 1	 5.38	 1.29	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49881	 1	 3.57	 0.85	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49882	 1	 6.19	 1.47	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49883	 1	 7.07	 1.69	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49884	 1	 8.4	 6.52	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49885	 1	 10.22	 2.44	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49886	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49887	 1	 7.75	 6.08	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49888	 1	 3.69	 0.88	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49889	 1	 2.83	 0.68	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49890	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49891	 1	 8.69	 5.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49892	 1	 7.31	 6.28	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49893	 1	 9.44	 6.52	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49894	 1	 7.23	 6.69	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49895	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49896	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49897	 1	 3.51	 2.96	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49898	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49899	 1	 4.02	 3.66	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49900	 1	 3.68	 2.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49901	 1	 4.81	 3.63	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49902	 1	 7.37	 5.19	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49903	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49904	 1	 10.31	 8.09	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49905	 1	 3.33	 0.79	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49906	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49907	 1	 5.58	 5.03	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49908	 1	 9.73	 2.32	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49909	 1	 6.37	 4.13	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49910	 1	 6.66	 4.96	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49911	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49912	 1	 1.86	 0.44	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49913	 1	 7.19	 1.72	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49914	 1	 17.4	 4.15	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49915	 1	 9.28	 7.36	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49916	 1	 7.31	 6.06	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49917	 1	 4.48	 4.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49918	 1	 5.06	 4.04	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49919	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49920	 1	 13.72	 3.28	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49921	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49922	 1	 6.9	 5.54	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49923	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49924	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49925	 1	 4.56	 4.11	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49926	 1	 3.52	 2.7	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49927	 1	 3.44	 2.75	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49928	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49929	 1	 5.14	 3.98	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49930	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49931	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49932	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49933	 1	 24.89	 18.16	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49934	 1	 10.0	 2.38	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49935	 1	 3.06	 2.31	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49936	 1	 4.33	 3.5	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49937	 1	 5.41	 4.25	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49938	 1	 8.08	 1.93	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49939	 1	 13.79	 3.33	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49940	 1	 5.36	 1.3	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49941	 1	 4.93	 1.19	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49942	 1	 3.4	 0.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49943	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49944	 1	 2.26	 0.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49945	 1	 3.72	 -5.07	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49946	 1	 2.81	 0.7	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49947	 1	 3.0	 -5.08	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49948	 1	 6.3	 -5.08	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49949	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49950	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49951	 1	 6.69	 5.23	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49952	 1	 6.78	 6.21	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49953	 1	 6.71	 5.11	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49954	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49955	 1	 4.86	 4.61	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49956	 1	 2.66	 1.99	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49957	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49958	 1	 5.92	 4.34	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49959	 1	 2.8	 2.49	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49960	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49961	 1	 1.62	 1.32	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49962	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49963	 1	 3.37	 2.4	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49964	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49965	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49966	 1	 3.73	 3.41	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49967	 1	 11.43	 9.31	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49968	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49969	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49970	 1	 4.58	 3.55	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49971	 1	 2.25	 2.23	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49972	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49973	 1	 3.74	 3.17	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49974	 1	 4.14	 3.07	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49975	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49976	 1	 3.21	 2.78	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49977	 1	 4.53	 4.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49978	 1	 1.79	 0.45	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49979	 1	 2.59	 0.64	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49980	 1	 12.06	 3.03	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49981	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49982	 1	 2.01	 1.82	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49983	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49984	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	49985	 1	 4.34	 3.85	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49986	 1	 3.32	 2.76	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49987	 1	 5.2	 4.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49988	 1	 1.92	 1.63	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49989	 1	 3.84	 3.44	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49990	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49991	 1	 8.19	 5.9	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49992	 1	 5.23	 1.26	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49993	 1	 7.08	 5.93	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49994	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	49995	 1	 7.63	 6.18	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	49996	 1	 4.5	 3.68	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49997	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49998	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49999	 1	 6.25	 4.92	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50000	 1	 4.07	 3.76	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50001	 1	 8.37	 2.01	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50002	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50003	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50004	 1	 2.35	 0.57	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50005	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50006	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50007	 1	 3.77	 2.84	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50008	 1	 6.88	 5.25	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50009	 1	 5.17	 4.29	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50010	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50011	 1	 2.67	 2.52	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50012	 1	 4.2	 3.88	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50013	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50014	 1	 2.04	 2.04	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50015	 1	 3.49	 2.58	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50016	 1	 5.55	 4.43	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50017	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50018	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50019	 1	 5.06	 3.53	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50020	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50021	 1	 3.93	 3.38	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50022	 1	 2.71	 2.07	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50023	 1	 5.25	 3.74	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50024	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50025	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50026	 1	 8.12	 6.79	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50027	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50028	 1	 2.62	 1.68	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50029	 1	 2.44	 2.03	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50030	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50031	 1	 2.86	 2.1	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50032	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50033	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50034	 1	 2.34	 2.15	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50035	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50036	 1	 1.58	 1.46	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50037	 1	 2.26	 1.99	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50038	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50039	 1	 2.73	 0.65	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50040	 1	 2.55	 1.67	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50041	 1	 11.23	 8.46	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50042	 1	 3.87	 2.66	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50043	 1	 3.43	 2.59	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50044	 1	 2.59	 0.62	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50045	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50046	 1	 10.46	 2.51	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50047	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50048	 1	 2.27	 0.55	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50049	 1	 2.14	 0.52	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50050	 1	 3.37	 0.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50051	 1	 4.22	 1.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50052	 1	 2.51	 0.6	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50053	 1	 3.39	 0.81	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50054	 1	 2.63	 0.63	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50055	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50056	 1	 3.35	 0.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50057	 1	 2.95	 0.71	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50058	 1	 1.37	 0.32	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50059	 1	 6.41	 1.53	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50060	 1	 2.14	 0.51	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50061	 1	 2.51	 0.6	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50062	 1	 4.26	 1.01	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50063	 1	 4.9	 1.18	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50064	 1	 2.28	 0.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50065	 1	 2.53	 0.6	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50066	 1	 8.32	 1.99	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50067	 1	 27.15	 6.51	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50068	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50069	 1	 2.75	 0.66	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50070	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50071	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50072	 1	 2.86	 0.69	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50073	 1	 2.47	 0.59	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50074	 1	 2.95	 0.71	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50075	 1	 2.95	 0.71	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50076	 1	 3.62	 0.87	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50077	 1	 1.46	 0.34	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50078	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50079	 1	 5.48	 1.31	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50080	 1	 2.43	 0.59	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50081	 1	 7.96	 1.91	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50082	 1	 15.96	 11.75	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50083	 1	 4.98	 3.76	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50084	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50085	 1	 5.18	 4.45	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50086	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50087	 1	 8.37	 5.65	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50088	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50089	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50090	 1	 3.14	 2.87	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50091	 1	 5.48	 4.48	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50092	 1	 7.12	 6.41	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50093	 1	 8.11	 5.57	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50094	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50095	 1	 6.12	 4.99	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50096	 1	 3.57	 0.85	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50097	 1	 3.79	 2.7	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50098	 1	 5.95	 4.46	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50099	 1	 5.69	 1.36	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50100	 1	 4.37	 1.05	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50101	 1	 5.99	 1.44	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50102	 1	 9.04	 2.16	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50103	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50104	 1	 10.5	 2.52	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50105	 1	 26.43	 6.34	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50106	 1	 3.99	 0.96	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50107	 1	 2.86	 0.68	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50108	 1	 1.86	 0.45	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50109	 1	 10.83	 2.58	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50110	 1	 2.05	 0.49	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50111	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50112	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50113	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50114	 1	 3.03	 0.73	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50115	 1	 5.3	 1.27	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50116	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50117	 1	 4.04	 2.92	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50118	 1	 4.67	 3.42	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50119	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50120	 1	 11.81	 2.83	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50121	 1	 25.24	 6.05	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50122	 1	 4.56	 1.09	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50123	 1	 21.22	 5.09	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50124	 1	 22.82	 5.47	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50125	 1	 9.33	 6.97	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50126	 1	 26.77	 6.41	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50127	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50128	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50129	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50130	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50131	 1	 37.25	 8.94	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50132	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50133	 1	 22.98	 13.6	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50134	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50135	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50136	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50137	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50138	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50139	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50140	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50141	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50142	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50143	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50144	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50145	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50146	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50147	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50148	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50149	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50150	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50151	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50152	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50153	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50154	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50155	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50156	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50157	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50158	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50159	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50160	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50161	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50162	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50163	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50164	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50165	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50166	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50167	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50168	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50169	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50170	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50171	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50172	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50173	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50174	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50175	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50176	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50177	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50178	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50179	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50180	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50181	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50182	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50183	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50184	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50185	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50186	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50187	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50188	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50189	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50190	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50191	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50192	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50193	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50194	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50195	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50196	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50197	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50198	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50199	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50200	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50201	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50202	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50203	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50204	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50205	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50206	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50207	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50208	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50209	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50210	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50211	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50212	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50213	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50214	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50215	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50216	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50217	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50218	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50219	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50220	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50221	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50222	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50223	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50224	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50225	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50226	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50227	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50228	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50229	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50230	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50231	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50232	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50233	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50234	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50235	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50236	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50237	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50238	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50239	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50240	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50241	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50242	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50243	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50244	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50245	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50246	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50247	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50248	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50249	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50250	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50251	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50252	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50253	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50254	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50255	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50256	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50257	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50258	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50259	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50260	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50261	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50262	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50263	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50264	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50265	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50266	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50267	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50268	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50269	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50270	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50271	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50272	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50273	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50274	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50275	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50276	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50277	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50278	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50279	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50280	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50281	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50282	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50283	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50284	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50285	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50286	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50287	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50288	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50289	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50290	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50291	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50292	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50293	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50294	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50295	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50296	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50297	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50298	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50299	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50300	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50301	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50302	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50303	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50304	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50305	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50306	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50307	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50308	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50309	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50310	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50311	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50312	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50313	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50314	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50315	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50316	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50317	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50318	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50319	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50320	 3	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50321	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50322	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50323	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50324	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50325	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50326	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50327	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50328	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50329	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50330	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50331	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50332	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50333	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50334	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50335	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50336	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50337	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50338	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50339	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50340	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50341	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50342	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50343	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50344	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50345	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50346	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50347	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50348	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50349	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50350	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50351	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50352	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50353	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50354	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50355	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50356	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50357	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50358	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50359	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50360	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50361	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50362	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50363	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50364	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50365	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50366	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50367	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50368	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50369	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50370	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50371	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50372	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50373	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50374	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50375	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50376	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50377	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50378	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50379	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50380	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50381	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50382	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50383	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50384	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50385	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50386	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50387	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50388	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50389	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50390	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50391	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50392	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50393	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50394	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50395	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50396	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50397	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50398	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50399	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50400	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50401	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50402	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50403	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50404	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50405	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50406	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50407	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50408	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50409	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50410	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50411	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50412	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50413	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50414	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50415	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50416	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50417	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50418	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50419	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50420	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50421	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50422	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50423	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50424	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50425	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50426	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50427	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50428	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50429	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50430	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50431	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50432	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50433	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50434	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50435	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50436	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50437	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50438	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50439	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50440	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50441	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50442	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50443	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50444	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50445	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50446	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50447	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50448	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50449	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50450	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50451	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50452	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50453	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50454	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50455	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50456	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50457	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50458	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50459	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50460	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50461	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50462	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50463	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50464	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50465	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50466	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50467	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50468	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50469	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50470	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50471	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50472	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50473	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50474	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50475	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50476	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50477	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50478	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50479	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50480	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50481	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50482	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50483	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50484	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50485	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50486	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50487	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50488	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50489	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50490	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50491	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50492	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50493	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50494	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50495	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50496	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50497	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50498	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50499	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50500	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50501	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50502	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50503	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50504	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50505	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50506	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50507	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50508	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50509	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50510	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50511	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50512	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50513	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50514	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50515	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50516	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50517	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50518	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50519	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50520	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50521	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50522	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50523	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50524	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50525	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50526	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50527	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50528	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50529	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50530	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50531	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50532	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50533	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50534	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50535	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50536	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50537	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50538	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50539	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50540	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50541	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50542	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50543	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50544	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50545	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50546	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50547	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50548	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50549	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50550	 1	 2.95	 1.96	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50551	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50552	 1	 6.43	 1.54	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50553	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50554	 1	 7.62	 5.61	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50555	 1	 6.99	 1.7	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50556	 1	 12.51	 2.96	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50557	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50558	 1	 6.33	 5.81	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50559	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50560	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50561	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50562	 1	 6.68	 2.92	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50563	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50564	 1	 11.24	 2.78	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50565	 1	 3.33	 2.55	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50566	 1	 2.85	 0.71	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50567	 1	 4.7	 4.57	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50568	 1	 3.54	 0.9	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50569	 1	 7.3	 1.84	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50570	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50571	 1	 3.11	 2.17	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50572	 1	 1.64	 1.59	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50573	 1	 5.17	 4.78	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50574	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50575	 1	 2.46	 2.85	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50576	 1	 12.17	 7.29	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50577	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50578	 1	 5.7	 3.24	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50579	 1	 7.81	 5.02	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50580	 1	 26.01	 24.12	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50581	 1	 6.23	 6.71	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50582	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50583	 1	 2.81	 2.67	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50584	 1	 4.0	 2.39	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50585	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50586	 1	 10.78	 5.38	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50587	 1	 3.26	 2.5	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50588	 1	 5.52	 4.16	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50589	 1	 3.02	 2.36	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50590	 1	 2.09	 0.48	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50591	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50592	 1	 3.97	 2.77	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50593	 1	 3.94	 0.92	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50594	 1	 5.54	 3.66	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50595	 1	 1.95	 2.38	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50596	 1	 5.91	 4.32	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50597	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50598	 1	 2.41	 3.35	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50599	 1	 5.49	 4.04	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50600	 1	 15.78	 6.42	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50601	 1	 13.59	 6.93	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50602	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50603	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50604	 1	 13.89	 6.15	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50605	 1	 2.24	 3.44	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50606	 1	 6.85	 4.25	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50607	 1	 5.77	 2.91	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50608	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50609	 1	 5.21	 3.37	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50610	 1	 4.12	 2.62	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50611	 1	 8.78	 4.26	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50612	 1	 5.41	 3.29	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50613	 1	 9.76	 5.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50614	 1	 5.65	 6.11	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50615	 1	 3.87	 2.84	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50616	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50617	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50618	 1	 2.21	 1.71	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50619	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50620	 1	 1.73	 1.91	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50621	 1	 1.66	 2.49	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50622	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50623	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50624	 1	 8.16	 4.07	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50625	 1	 6.87	 4.47	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50626	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50627	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50628	 1	 2.22	 2.39	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50629	 1	 2.6	 1.92	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50630	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50631	 1	 1.25	 1.7	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50632	 1	 2.44	 1.58	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50633	 1	 7.64	 6.31	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50634	 1	 6.29	 3.07	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50635	 1	 4.66	 2.76	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50636	 1	 6.08	 5.32	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50637	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50638	 1	 2.59	 4.27	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50639	 1	 9.18	 6.03	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50640	 1	 12.1	 5.78	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50641	 1	 4.78	 2.99	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50642	 1	 6.36	 3.35	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50643	 1	 3.82	 2.29	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50644	 1	 8.4	 12.11	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50645	 1	 3.76	 5.44	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50646	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50647	 1	 4.03	 3.33	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50648	 1	 3.89	 2.88	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50649	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50650	 1	 4.88	 3.5	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50651	 1	 3.31	 2.56	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50652	 1	 2.87	 2.46	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50653	 1	 4.32	 4.52	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50654	 1	 3.27	 2.69	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50655	 1	 2.93	 2.3	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50656	 1	 5.71	 4.08	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50657	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50658	 1	 2.0	 1.62	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50659	 1	 5.44	 4.18	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50660	 1	 4.06	 3.16	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50661	 1	 0.88	 0.9	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50662	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50663	 1	 5.99	 4.57	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50664	 1	 3.1	 2.34	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50665	 1	 2.54	 3.08	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50666	 1	 5.24	 4.48	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50667	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50668	 1	 3.48	 2.86	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50669	 1	 1.84	 0.45	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50670	 1	 5.74	 3.24	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50671	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50672	 1	 7.64	 5.38	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50673	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50674	 1	 14.41	 8.21	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50675	 1	 6.3	 3.96	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50676	 1	 11.44	 5.81	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50677	 1	 6.48	 5.33	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50678	 1	 24.32	 14.46	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50679	 1	 7.04	 4.63	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50680	 1	 3.76	 2.77	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50681	 1	 2.21	 1.33	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50682	 1	 1.63	 1.3	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50683	 1	 2.29	 2.13	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50684	 1	 6.27	 6.71	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50685	 1	 0.83	 0.93	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50686	 1	 3.34	 2.39	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50687	 1	 2.35	 1.36	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50688	 1	 2.72	 1.91	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50689	 1	 13.56	 9.29	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50690	 1	 13.43	 7.49	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50691	 1	 11.29	 6.23	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50692	 1	 10.98	 12.87	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50693	 1	 6.93	 4.95	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50694	 1	 6.84	 4.49	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50695	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50696	 1	 4.29	 7.26	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50697	 1	 5.15	 1.22	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50698	 1	 5.54	 1.32	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50699	 1	 3.38	 0.8	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50700	 1	 5.45	 1.28	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50701	 1	 11.72	 2.79	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50702	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50703	 1	 2.06	 0.48	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50704	 1	 4.51	 1.06	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50705	 1	 3.96	 0.93	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50706	 1	 2.82	 0.66	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50707	 1	 3.8	 0.9	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50708	 1	 1.56	 2.19	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50709	 1	 3.98	 0.93	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50710	 1	 6.82	 3.09	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50711	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50712	 1	 8.25	 1.97	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50713	 1	 3.67	 0.87	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50714	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50715	 1	 9.01	 5.48	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50716	 1	 7.96	 5.32	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50717	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50718	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50719	 1	 3.49	 2.16	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50720	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50721	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50722	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50723	 1	 10.3	 2.45	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50724	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50725	 1	 5.32	 1.24	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50726	 1	 6.51	 4.05	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50727	 1	 2.87	 3.27	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50728	 1	 5.44	 7.14	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50729	 1	 8.12	 5.46	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50730	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50731	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50732	 1	 25.54	 12.35	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50733	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50734	 1	 6.83	 4.2	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50735	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50736	 1	 4.22	 3.29	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50737	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50738	 1	 3.58	 2.37	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50739	 1	 5.21	 3.66	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50740	 1	 8.13	 4.69	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50741	 1	 6.13	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50742	 1	 9.37	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50743	 1	 4.38	 3.32	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50744	 1	 3.85	 2.3	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50745	 1	 2.79	 1.96	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50746	 1	 4.06	 2.35	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50747	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50748	 1	 4.31	 2.59	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50749	 1	 2.55	 1.94	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50750	 1	 2.26	 2.04	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50751	 1	 2.3	 2.1	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50752	 1	 1.3	 1.01	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50753	 1	 2.43	 2.04	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50754	 1	 2.11	 1.51	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50755	 1	 2.09	 1.96	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50756	 1	 3.05	 2.02	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50757	 1	 3.87	 2.34	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50758	 1	 1.88	 1.75	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50759	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50760	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50761	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50762	 1	 2.28	 1.93	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50763	 1	 5.02	 3.7	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50764	 1	 2.99	 2.34	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50765	 1	 4.32	 3.43	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50766	 1	 4.27	 2.8	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50767	 1	 3.15	 2.52	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50768	 1	 2.84	 2.06	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50769	 1	 2.74	 2.11	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50770	 1	 4.07	 2.64	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50771	 1	 6.36	 4.74	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50772	 1	 3.73	 2.15	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50773	 1	 0.87	 0.67	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50774	 1	 2.83	 2.48	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50775	 1	 8.67	 4.68	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50776	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50777	 1	 1.22	 1.44	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50778	 1	 4.59	 3.27	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50779	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50780	 1	 3.1	 2.58	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50781	 1	 1.97	 1.56	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50782	 1	 5.26	 3.5	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50783	 1	 5.3	 4.55	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50784	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50785	 1	 1.75	 1.46	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50786	 1	 7.4	 4.58	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50787	 1	 2.87	 2.42	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50788	 1	 1.6	 1.43	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50789	 1	 2.43	 2.04	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50790	 1	 1.6	 1.52	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50791	 1	 3.34	 2.75	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50792	 1	 5.76	 5.29	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50793	 1	 4.82	 3.01	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50794	 1	 3.67	 2.8	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50795	 1	 2.62	 2.03	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50796	 1	 15.78	 8.49	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50797	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50798	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50799	 1	 9.32	 10.5	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50800	 1	 3.4	 3.1	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50801	 1	 1.12	 0.9	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50802	 1	 1.0	 0.91	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50803	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50804	 1	 6.99	 6.31	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50805	 1	 4.43	 3.49	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50806	 1	 2.4	 2.26	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50807	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50808	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50809	 1	 2.86	 2.53	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50810	 1	 3.82	 3.06	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50811	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50812	 1	 5.83	 4.42	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50813	 1	 2.92	 2.69	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50814	 1	 3.31	 2.34	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50815	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50816	 1	 2.01	 1.85	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50817	 1	 2.43	 2.24	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50818	 1	 2.39	 2.26	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50819	 1	 2.29	 2.12	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50820	 1	 4.14	 2.58	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50821	 1	 3.49	 1.77	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50822	 1	 2.07	 2.07	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50823	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50824	 1	 2.29	 1.6	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50825	 1	 2.13	 1.99	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50826	 1	 2.3	 1.49	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50827	 1	 2.55	 2.12	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50828	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50829	 1	 3.5	 2.04	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50830	 1	 6.72	 4.57	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50831	 1	 3.46	 2.57	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50832	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50833	 1	 7.73	 3.57	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50834	 1	 8.53	 5.85	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50835	 1	 3.7	 2.56	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50836	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50837	 1	 4.8	 3.2	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50838	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50839	 1	 1.66	 1.49	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50840	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50841	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50842	 1	 3.66	 2.68	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50843	 1	 0.84	 0.81	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50844	 1	 1.92	 1.78	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50845	 1	 1.36	 1.07	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50846	 1	 2.9	 2.57	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50847	 1	 1.96	 1.91	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50848	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50849	 1	 4.48	 4.1	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50850	 1	 2.79	 1.97	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50851	 1	 2.83	 2.62	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50852	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50853	 1	 5.97	 4.87	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50854	 1	 2.83	 2.19	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50855	 1	 2.67	 1.74	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50856	 1	 2.11	 1.54	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50857	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50858	 1	 1.63	 2.72	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50859	 1	 14.2	 13.84	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50860	 1	 3.59	 2.19	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50861	 1	 1.46	 1.29	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50862	 1	 2.28	 1.67	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50863	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50864	 1	 3.75	 4.4	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50865	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50866	 1	 1.98	 1.86	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50867	 1	 3.46	 6.21	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50868	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50869	 1	 1.4	 1.04	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50870	 1	 22.78	 19.36	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50871	 1	 2.26	 1.63	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50872	 1	 0.47	 0.18	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50873	 1	 15.02	 8.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50874	 1	 8.86	 5.49	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50875	 1	 4.78	 3.61	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50876	 1	 13.87	 6.93	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50877	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50878	 1	 3.03	 4.81	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50879	 1	 3.38	 0.82	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50880	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50881	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50882	 1	 6.31	 1.53	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50883	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50884	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50885	 1	 2.16	 2.12	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50886	 1	 13.59	 5.71	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50887	 1	 3.83	 2.61	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50888	 1	 2.19	 1.96	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50889	 1	 3.57	 2.49	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50890	 1	 1.85	 1.71	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50891	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50892	 1	 2.52	 2.6	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50893	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50894	 1	 2.38	 1.8	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50895	 1	 5.38	 4.37	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50896	 1	 16.52	 11.19	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50897	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50898	 1	 3.65	 3.38	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50899	 1	 4.42	 2.53	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50900	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50901	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50902	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50903	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50904	 1	 4.72	 3.99	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50905	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50906	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50907	 1	 9.49	 5.02	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50908	 1	 4.54	 4.73	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50909	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50910	 1	 2.06	 1.83	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50911	 1	 2.65	 7.86	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50912	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50913	 1	 4.78	 2.68	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50914	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50915	 1	 6.3	 3.81	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50916	 1	 3.09	 2.7	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50917	 1	 15.62	 6.74	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50918	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50919	 1	 6.1	 6.53	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50920	 1	 10.55	 13.83	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50921	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50922	 1	 4.71	 2.72	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50923	 1	 7.46	 4.79	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50924	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50925	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50926	 1	 7.58	 3.96	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50927	 1	 4.67	 4.85	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50928	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50929	 1	 10.1	 5.01	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50930	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50931	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50932	 1	 3.59	 2.72	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50933	 1	 4.94	 3.69	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50934	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50935	 1	 7.97	 4.2	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50936	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50937	 1	 8.58	 6.64	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50938	 1	 1.87	 1.49	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50939	 1	 5.06	 3.96	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50940	 1	 10.17	 6.99	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50941	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50942	 1	 5.49	 1.3	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50943	 1	 3.08	 0.73	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50944	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50945	 1	 2.31	 0.55	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50946	 1	 4.93	 1.16	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50947	 1	 3.09	 0.73	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50948	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50949	 1	 4.4	 1.06	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50950	 1	 2.81	 0.68	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50951	 1	 3.37	 0.81	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50952	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50953	 1	 2.35	 0.56	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50954	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50955	 1	 9.39	 4.77	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50956	 1	 2.51	 2.02	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50957	 1	 33.93	 17.08	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50958	 1	 3.92	 2.75	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50959	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50960	 1	 7.8	 4.61	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50961	 1	 6.01	 6.7	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50962	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50963	 1	 3.25	 3.05	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50964	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50965	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50966	 1	 13.7	 5.47	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50967	 1	 13.12	 6.41	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50968	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50969	 1	 3.46	 2.19	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50970	 1	 4.25	 2.42	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50971	 1	 2.29	 1.43	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50972	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50973	 1	 3.58	 2.63	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50974	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50975	 1	 7.21	 1.69	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50976	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50977	 1	 10.68	 6.62	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50978	 1	 13.29	 6.86	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50979	 1	 4.66	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50980	 1	 10.47	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50981	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50982	 1	 9.84	 8.47	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50983	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50984	 1	 8.85	 6.35	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50985	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50986	 1	 21.62	 5.14	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50987	 1	 4.58	 3.26	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50988	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50989	 1	 15.29	 7.19	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50990	 1	 3.72	 2.34	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50991	 1	 4.57	 3.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50992	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50993	 1	 1.93	 1.51	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50994	 1	 4.35	 3.4	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50995	 1	 7.54	 5.38	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50996	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50997	 1	 8.2	 6.72	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	50998	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	50999	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51000	 1	 9.86	 4.69	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51001	 1	 17.32	 10.7	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51002	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51003	 1	 3.13	 3.39	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51004	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51005	 1	 8.01	 3.59	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51006	 1	 2.91	 1.85	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51007	 1	 5.68	 2.52	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51008	 1	 7.12	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51009	 1	 5.51	 2.99	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51010	 1	 18.92	 10.27	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51011	 1	 9.18	 5.78	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51012	 1	 11.69	 10.21	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51013	 1	 4.55	 4.45	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51014	 1	 2.5	 1.93	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51015	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51016	 1	 4.37	 2.96	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51017	 1	 5.4	 4.55	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51018	 1	 3.82	 2.73	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51019	 1	 4.47	 2.96	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51020	 1	 3.19	 2.12	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51021	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51022	 1	 5.04	 1.19	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51023	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51024	 1	 1.51	 1.36	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51025	 1	 5.4	 3.92	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51026	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51027	 1	 7.15	 4.05	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51028	 1	 10.02	 6.17	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51029	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51030	 1	 7.17	 1.74	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51031	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51032	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51033	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51034	 1	 9.39	 6.65	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51035	 1	 4.68	 3.83	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51036	 1	 2.65	 0.63	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51037	 1	 5.37	 3.82	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51038	 1	 6.02	 5.98	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51039	 1	 4.15	 3.55	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51040	 1	 3.43	 2.13	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51041	 1	 5.29	 3.76	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51042	 1	 3.01	 2.46	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51043	 1	 14.89	 8.92	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51044	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51045	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51046	 1	 2.25	 2.32	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51047	 1	 1.62	 1.6	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51048	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51049	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51050	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51051	 1	 1.69	 1.84	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51052	 1	 1.16	 1.03	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51053	 1	 3.08	 1.95	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51054	 1	 2.13	 1.84	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51055	 1	 5.48	 2.34	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51056	 1	 2.12	 1.86	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51057	 1	 1.74	 1.78	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51058	 1	 2.6	 2.47	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51059	 1	 1.44	 1.08	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51060	 1	 1.44	 1.13	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51061	 1	 5.91	 2.79	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51062	 1	 1.03	 0.97	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51063	 1	 1.89	 1.41	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51064	 1	 3.32	 2.77	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51065	 1	 1.86	 1.85	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51066	 1	 2.4	 1.73	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51067	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51068	 1	 1.74	 1.29	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51069	 1	 1.38	 1.51	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51070	 1	 2.4	 2.88	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51071	 1	 3.13	 2.33	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51072	 1	 2.45	 3.22	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51073	 1	 1.02	 0.97	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51074	 1	 4.27	 2.48	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51075	 1	 0.94	 0.82	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51076	 1	 1.56	 1.6	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51077	 1	 4.38	 3.69	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51078	 1	 3.38	 2.67	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51079	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51080	 1	 9.17	 5.75	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51081	 1	 2.61	 2.4	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51082	 1	 6.32	 4.15	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51083	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51084	 1	 3.06	 2.9	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51085	 1	 2.89	 2.59	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51086	 1	 3.23	 2.33	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51087	 1	 6.78	 4.5	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51088	 1	 3.15	 2.32	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51089	 1	 5.27	 4.58	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51090	 1	 2.76	 2.39	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51091	 1	 2.87	 2.17	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51092	 1	 1.83	 1.31	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51093	 1	 6.19	 3.09	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51094	 1	 1.03	 0.77	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51095	 1	 2.37	 1.82	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51096	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51097	 1	 1.42	 1.21	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51098	 1	 2.77	 2.2	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51099	 1	 2.01	 1.54	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51100	 1	 2.8	 2.19	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51101	 1	 2.44	 1.47	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51102	 1	 3.31	 2.56	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51103	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51104	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51105	 1	 7.47	 5.27	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51106	 1	 2.13	 1.73	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51107	 1	 4.2	 2.37	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51108	 1	 0.39	 0.37	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51109	 1	 1.77	 1.53	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51110	 1	 4.38	 2.64	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51111	 1	 6.79	 5.01	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51112	 1	 1.69	 1.6	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51113	 1	 5.08	 4.71	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51114	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51115	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51116	 1	 4.21	 2.44	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51117	 1	 3.19	 2.09	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51118	 1	 2.77	 1.61	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51119	 1	 2.26	 1.61	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51120	 1	 2.17	 1.63	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51121	 1	 2.84	 2.68	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51122	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51123	 1	 9.45	 8.14	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51124	 1	 19.85	 23.38	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51125	 1	 18.95	 13.75	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51126	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51127	 1	 4.98	 3.88	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51128	 1	 6.53	 3.44	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51129	 1	 1.27	 1.13	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51130	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51131	 1	 3.84	 3.15	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51132	 1	 1.73	 1.59	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51133	 1	 2.88	 2.34	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51134	 1	 3.82	 3.37	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51135	 1	 2.17	 2.93	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51136	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51137	 1	 2.6	 2.02	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51138	 1	 5.1	 5.34	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51139	 1	 2.33	 2.18	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51140	 1	 2.89	 2.8	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51141	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51142	 1	 3.3	 2.06	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51143	 1	 8.26	 14.94	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51144	 1	 4.93	 4.09	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51145	 1	 4.98	 3.8	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51146	 1	 4.96	 3.75	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51147	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51148	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51149	 1	 1.77	 1.72	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51150	 1	 3.06	 1.75	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51151	 1	 5.58	 3.65	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51152	 1	 2.65	 2.07	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51153	 1	 3.12	 3.37	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51154	 1	 1.79	 1.69	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51155	 1	 1.5	 1.14	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51156	 1	 1.58	 0.99	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51157	 1	 0.97	 0.76	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51158	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51159	 1	 38.66	 21.46	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51160	 1	 5.24	 3.32	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51161	 1	 4.36	 2.55	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51162	 1	 13.08	 8.59	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51163	 1	 16.81	 10.49	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51164	 1	 4.15	 2.58	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51165	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51166	 1	 6.96	 4.48	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51167	 1	 4.43	 2.27	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51168	 1	 4.32	 2.38	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51169	 1	 2.74	 3.36	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51170	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51171	 1	 8.5	 6.95	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51172	 1	 4.39	 3.5	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51173	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51174	 1	 7.76	 4.97	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51175	 1	 3.01	 2.09	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51176	 1	 1.93	 1.29	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51177	 1	 4.08	 2.32	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51178	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51179	 1	 5.26	 3.71	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51180	 1	 6.29	 3.68	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51181	 1	 1.94	 2.32	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51182	 1	 1.87	 1.67	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51183	 1	 1.15	 1.2	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51184	 1	 2.17	 2.13	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51185	 1	 6.11	 3.78	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51186	 1	 3.78	 2.54	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51187	 1	 2.02	 1.64	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51188	 1	 2.56	 1.9	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51189	 1	 5.66	 3.97	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51190	 1	 1.52	 1.21	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51191	 1	 4.4	 2.39	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51192	 1	 1.29	 1.08	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51193	 1	 6.88	 4.88	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51194	 1	 2.76	 2.04	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51195	 1	 4.38	 2.54	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51196	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51197	 1	 6.0	 3.58	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51198	 1	 2.22	 2.19	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51199	 1	 4.8	 3.11	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51200	 1	 3.8	 3.03	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51201	 1	 1.93	 1.81	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51202	 1	 2.82	 3.19	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51203	 1	 7.26	 5.26	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51204	 1	 2.94	 2.39	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51205	 1	 2.1	 1.71	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51206	 1	 10.31	 6.06	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51207	 1	 14.74	 11.37	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51208	 1	 2.44	 2.39	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51209	 1	 2.06	 1.59	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51210	 1	 2.25	 1.74	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51211	 1	 2.53	 2.51	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51212	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51213	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51214	 1	 3.5	 5.05	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51215	 1	 5.3	 3.27	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51216	 1	 17.81	 11.93	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51217	 1	 4.79	 3.71	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51218	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51219	 1	 2.92	 1.64	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51220	 1	 5.91	 4.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51221	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51222	 1	 6.18	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51223	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51224	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51225	 1	 7.73	 1.89	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51226	 1	 8.41	 4.12	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51227	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51228	 1	 16.25	 7.94	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51229	 1	 9.01	 6.18	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51230	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51231	 1	 11.06	 5.86	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51232	 1	 6.05	 7.36	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51233	 1	 7.09	 5.1	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51234	 1	 4.81	 3.67	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51235	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51236	 1	 14.63	 3.32	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51237	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51238	 1	 6.46	 4.27	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51239	 1	 2.6	 1.64	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51240	 1	 11.59	 5.22	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51241	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51242	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51243	 1	 13.13	 7.68	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51244	 1	 2.14	 1.8	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51245	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51246	 1	 7.44	 1.77	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51247	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51248	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51249	 1	 1.96	 1.15	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51250	 1	 52.9	 52.34	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51251	 1	 1.78	 2.13	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51252	 1	 0.68	 0.6	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51253	 1	 1.3	 0.84	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51254	 1	 0.95	 0.85	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51255	 1	 1.5	 1.23	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51256	 1	 1.36	 1.24	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51257	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51258	 1	 0.27	 0.33	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51259	 1	 0.65	 0.57	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51260	 1	 0.91	 0.9	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51261	 1	 0.92	 1.25	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51262	 1	 0.85	 0.96	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51263	 1	 2.69	 2.4	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51264	 1	 1.86	 1.35	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51265	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51266	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51267	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51268	 1	 1.24	 1.15	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51269	 1	 1.01	 0.93	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51270	 1	 1.29	 0.96	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51271	 1	 3.12	 2.16	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51272	 1	 2.29	 1.3	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51273	 1	 2.14	 1.64	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51274	 1	 1.51	 1.35	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51275	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51276	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51277	 1	 4.08	 3.48	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51278	 1	 2.11	 1.79	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51279	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51280	 1	 3.84	 3.46	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51281	 1	 2.89	 2.24	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51282	 1	 2.24	 1.61	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51283	 1	 0.88	 0.85	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51284	 1	 4.1	 3.77	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51285	 1	 1.6	 1.17	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51286	 1	 5.88	 3.27	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51287	 1	 2.14	 1.53	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51288	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51289	 1	 1.77	 1.44	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51290	 1	 2.2	 1.59	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51291	 1	 9.08	 5.31	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51292	 1	 2.55	 1.94	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51293	 1	 3.75	 2.24	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51294	 1	 16.26	 11.5	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51295	 1	 0.97	 0.69	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51296	 1	 6.28	 2.95	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51297	 1	 4.3	 2.84	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51298	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51299	 1	 3.35	 2.56	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51300	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51301	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51302	 1	 1.02	 0.81	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51303	 1	 1.55	 1.3	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51304	 1	 2.66	 1.93	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51305	 1	 1.16	 1.16	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51306	 1	 1.77	 1.35	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51307	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51308	 1	 2.25	 1.56	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51309	 1	 1.19	 0.95	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51310	 1	 3.59	 3.12	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51311	 1	 3.64	 2.98	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51312	 1	 2.39	 1.89	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51313	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51314	 1	 4.06	 2.94	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51315	 1	 3.2	 3.43	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51316	 1	 3.1	 2.01	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51317	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51318	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51319	 1	 10.97	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51320	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51321	 1	 4.34	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51322	 1	 13.8	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51323	 1	 3.83	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51324	 1	 28.37	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51325	 1	 13.52	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51326	 1	 24.73	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51327	 1	 7.97	 1.96	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51328	 1	 3.3	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51329	 1	 11.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51330	 1	 0.89	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51331	 1	 2.83	 -0.92	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51332	 1	 0.58	 -5.34	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51333	 1	 13.7	 -4.91	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51334	 1	 13.86	 -4.9	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51335	 1	 4.21	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51336	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51337	 1	 7.64	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51338	 1	 4.19	 2.64	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51339	 1	 6.32	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51340	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51341	 1	 13.52	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51342	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51343	 1	 2.59	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51344	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51345	 1	 4.05	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51346	 1	 10.77	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51347	 1	 3.91	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51348	 1	 4.67	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51349	 1	 8.01	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51350	 1	 9.88	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51351	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51352	 1	 8.29	 6.53	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51353	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51354	 1	 9.06	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51355	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51356	 1	 5.87	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51357	 1	 5.82	 4.82	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51358	 1	 11.89	 8.57	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51359	 1	 11.56	 7.32	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51360	 1	 12.94	 10.06	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51361	 1	 8.38	 6.57	 0.0	 0.0	 21	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51362	 1	 7.31	 5.46	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51363	 1	 15.84	 3.79	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51364	 1	 13.87	 9.19	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51365	 1	 17.95	 11.37	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51366	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51367	 1	 1.25	 -5.11	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51368	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51369	 1	 2.85	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51370	 1	 12.68	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51371	 1	 15.62	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51372	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51373	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51374	 1	 4.48	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51375	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51376	 1	 6.84	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51377	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51378	 1	 7.32	 1.73	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51379	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51380	 1	 12.45	 -5.18	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51381	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51382	 1	 3.49	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51383	 1	 7.51	 6.94	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51384	 1	 10.8	 6.28	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51385	 1	 28.08	 13.56	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51386	 1	 13.71	 7.52	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51387	 1	 5.26	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51388	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51389	 1	 11.96	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51390	 1	 5.49	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51391	 1	 15.81	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51392	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51393	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51394	 1	 5.96	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51395	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51396	 1	 8.83	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51397	 1	 4.07	 3.74	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51398	 1	 14.4	 8.63	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51399	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51400	 1	 7.14	 1.68	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51401	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51402	 1	 5.37	 4.5	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51403	 1	 2.83	 2.95	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51404	 1	 3.4	 2.96	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51405	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51406	 1	 9.24	 6.26	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51407	 1	 32.82	 14.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51408	 1	 2.91	 2.65	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51409	 1	 1.49	 1.36	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51410	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51411	 1	 31.81	 19.24	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51412	 1	 1.45	 1.2	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51413	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51414	 1	 3.18	 2.57	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51415	 1	 1.94	 1.9	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51416	 1	 7.48	 4.6	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51417	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51418	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51419	 1	 1.9	 1.43	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51420	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51421	 1	 1.71	 1.67	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51422	 1	 2.03	 1.55	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51423	 1	 3.28	 3.11	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51424	 1	 2.64	 2.57	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51425	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51426	 1	 2.4	 2.26	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51427	 1	 3.56	 3.04	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51428	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51429	 1	 8.09	 6.81	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51430	 1	 4.66	 5.17	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51431	 1	 30.41	 19.12	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51432	 1	 10.15	 5.64	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51433	 1	 5.07	 2.57	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51434	 1	 2.47	 2.35	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51435	 1	 2.16	 1.81	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51436	 1	 4.71	 4.11	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51437	 1	 3.46	 2.74	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51438	 1	 1.53	 1.52	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51439	 1	 6.24	 4.59	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51440	 1	 3.64	 2.93	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51441	 1	 4.65	 4.13	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51442	 1	 1.32	 1.34	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51443	 1	 3.11	 2.61	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51444	 1	 6.37	 3.48	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51445	 1	 2.82	 2.5	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51446	 1	 1.93	 1.94	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51447	 1	 3.09	 3.11	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51448	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51449	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51450	 1	 4.73	 4.62	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51451	 1	 2.79	 2.32	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51452	 1	 1.01	 1.06	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51453	 1	 2.07	 1.96	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51454	 1	 2.03	 1.92	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51455	 1	 3.35	 3.17	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51456	 1	 3.37	 3.25	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51457	 1	 2.88	 3.01	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51458	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51459	 1	 1.44	 1.42	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51460	 1	 3.66	 2.71	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51461	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51462	 1	 1.53	 1.49	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51463	 1	 2.84	 3.13	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51464	 1	 3.52	 3.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51465	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51466	 1	 2.69	 2.78	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51467	 1	 1.81	 1.72	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51468	 1	 3.43	 3.19	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51469	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51470	 1	 4.46	 2.91	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51471	 1	 2.72	 2.09	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51472	 1	 2.43	 2.63	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51473	 1	 4.84	 3.84	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51474	 1	 4.8	 3.65	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51475	 1	 3.64	 3.5	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51476	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51477	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51478	 1	 1.55	 1.4	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51479	 1	 1.3	 1.07	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51480	 1	 0.96	 0.82	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51481	 1	 2.7	 2.25	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51482	 1	 3.18	 2.7	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51483	 1	 1.61	 1.37	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51484	 1	 4.85	 3.81	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51485	 1	 1.12	 1.2	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51486	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51487	 1	 6.11	 4.08	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51488	 1	 2.13	 2.08	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51489	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51490	 1	 2.84	 2.91	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51491	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51492	 1	 2.31	 1.88	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51493	 1	 4.7	 2.62	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51494	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51495	 1	 1.76	 1.52	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51496	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51497	 1	 1.84	 1.71	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51498	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51499	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51500	 1	 2.56	 2.64	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51501	 1	 1.75	 1.75	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51502	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51503	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51504	 1	 1.65	 1.61	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51505	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51506	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51507	 1	 2.86	 2.7	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51508	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51509	 1	 2.2	 2.3	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51510	 1	 2.31	 1.87	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51511	 1	 3.21	 3.15	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51512	 1	 2.35	 2.21	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51513	 1	 3.22	 3.22	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51514	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51515	 1	 2.47	 2.21	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51516	 1	 2.97	 2.61	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51517	 1	 1.26	 1.38	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51518	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51519	 1	 1.12	 0.99	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51520	 1	 1.71	 1.77	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51521	 1	 3.33	 2.88	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51522	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51523	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51524	 1	 3.56	 2.9	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51525	 1	 2.5	 2.27	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51526	 1	 1.78	 1.75	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51527	 1	 2.48	 2.15	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51528	 1	 2.59	 1.98	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51529	 1	 2.19	 2.35	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51530	 1	 3.58	 3.61	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51531	 1	 3.34	 2.87	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51532	 1	 2.16	 2.2	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51533	 1	 2.85	 2.56	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51534	 1	 3.55	 2.78	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51535	 1	 1.97	 1.64	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51536	 1	 2.71	 2.24	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51537	 1	 2.23	 1.82	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51538	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51539	 1	 2.47	 2.35	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51540	 1	 4.12	 4.18	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51541	 1	 2.98	 2.58	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51542	 1	 3.63	 3.59	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51543	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51544	 1	 3.14	 2.69	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51545	 1	 4.26	 3.99	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51546	 1	 4.43	 3.61	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51547	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51548	 1	 2.27	 2.33	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51549	 1	 3.77	 4.05	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51550	 1	 2.73	 2.53	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51551	 1	 3.13	 3.08	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51552	 1	 15.04	 6.38	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51553	 1	 6.67	 4.84	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51554	 1	 2.23	 1.93	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51555	 1	 5.02	 3.44	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51556	 1	 9.51	 6.08	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51557	 1	 3.35	 3.4	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51558	 1	 8.77	 7.11	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51559	 1	 3.1	 3.03	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51560	 1	 2.32	 2.42	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51561	 1	 2.55	 2.05	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51562	 1	 1.91	 1.6	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51563	 1	 2.72	 2.7	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51564	 1	 5.62	 4.18	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51565	 1	 9.42	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51566	 1	 16.94	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51567	 1	 4.64	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51568	 1	 6.64	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51569	 1	 11.54	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51570	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51571	 1	 8.12	 6.31	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51572	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51573	 1	 20.23	 10.33	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51574	 1	 6.45	 5.29	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51575	 1	 6.9	 5.47	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51576	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51577	 1	 10.75	 7.62	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51578	 1	 3.19	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51579	 1	 4.15	 -5.17	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51580	 1	 3.36	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51581	 1	 0.7	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51582	 1	 7.15	 -12.14	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51583	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51584	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51585	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51586	 1	 4.58	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51587	 1	 4.12	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51588	 1	 20.6	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51589	 1	 7.14	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51590	 1	 15.79	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51591	 1	 15.83	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51592	 1	 22.57	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51593	 1	 4.19	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51594	 1	 4.93	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51595	 1	 19.38	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51596	 1	 8.52	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51597	 1	 5.43	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51598	 1	 13.39	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51599	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51600	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51601	 1	 2.05	 1.73	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51602	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51603	 1	 5.89	 4.5	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51604	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51605	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51606	 1	 11.41	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51607	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51608	 1	 2.83	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51609	 1	 8.07	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51610	 1	 12.96	 3.18	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51611	 1	 12.03	 2.95	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51612	 1	 4.91	 1.21	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51613	 1	 8.47	 7.42	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51614	 1	 11.19	 9.45	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51615	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51616	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51617	 1	 6.67	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51618	 1	 11.39	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51619	 1	 7.72	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51620	 1	 0.8	 0.76	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51621	 1	 12.94	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51622	 1	 6.16	 5.19	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51623	 1	 8.16	 6.27	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51624	 1	 4.41	 4.14	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51625	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51626	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51627	 1	 3.81	 3.39	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51628	 1	 9.38	 5.91	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51629	 1	 9.01	 6.2	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51630	 1	 5.6	 3.03	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51631	 1	 4.74	 5.07	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51632	 1	 3.64	 2.48	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51633	 1	 2.66	 2.55	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51634	 1	 3.6	 2.94	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51635	 1	 1.88	 1.8	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51636	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51637	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51638	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51639	 1	 2.2	 2.34	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51640	 1	 4.17	 4.27	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51641	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51642	 1	 1.82	 1.71	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51643	 1	 4.78	 3.85	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51644	 1	 5.44	 4.41	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51645	 1	 3.8	 3.9	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51646	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51647	 1	 3.1	 2.11	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51648	 1	 3.27	 2.93	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51649	 1	 1.94	 1.86	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51650	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51651	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51652	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51653	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51654	 1	 2.02	 1.83	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51655	 1	 3.65	 3.58	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51656	 1	 2.98	 2.4	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51657	 1	 4.71	 4.69	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51658	 1	 3.89	 4.05	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51659	 1	 42.06	 17.54	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51660	 1	 4.83	 4.42	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51661	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51662	 1	 6.8	 4.99	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51663	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51664	 1	 1.53	 1.3	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51665	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51666	 1	 2.02	 0.49	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51667	 1	 3.74	 3.7	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51668	 1	 2.92	 0.71	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51669	 1	 3.64	 4.02	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51670	 1	 13.8	 8.42	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51671	 1	 0.29	 0.28	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51672	 1	 1.43	 1.19	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51673	 1	 5.39	 3.86	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51674	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51675	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51676	 1	 0.74	 0.77	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51677	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51678	 1	 3.7	 3.15	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51679	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51680	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51681	 1	 2.7	 2.85	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51682	 1	 3.74	 3.34	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51683	 1	 1.5	 1.37	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51684	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51685	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51686	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51687	 1	 3.54	 2.44	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51688	 1	 1.41	 1.19	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51689	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51690	 1	 0.86	 0.98	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51691	 1	 2.93	 2.71	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51692	 1	 2.47	 2.34	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51693	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51694	 1	 2.1	 2.01	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51695	 1	 5.79	 1.4	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51696	 1	 8.18	 6.16	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51697	 1	 7.82	 8.1	 0.0	 0.0	 21	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51698	 1	 15.38	 3.74	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51699	 1	 4.59	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51700	 1	 15.92	 8.96	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51701	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51702	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51703	 1	 3.67	 3.41	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51704	 1	 3.5	 3.94	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51705	 1	 9.47	 6.91	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51706	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51707	 1	 1.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51708	 1	 0.64	 -5.3	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51709	 1	 0.38	 0.39	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51710	 1	 18.37	 4.48	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51711	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51712	 1	 3.56	 0.87	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51713	 1	 4.15	 1.01	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51714	 1	 4.05	 0.98	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51715	 1	 6.83	 1.67	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51716	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51717	 1	 7.06	 1.72	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51718	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51719	 1	 11.17	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51720	 1	 10.58	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51721	 1	 10.56	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51722	 1	 17.16	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51723	 1	 9.55	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51724	 1	 10.95	 8.51	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51725	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51726	 1	 8.09	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51727	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51728	 1	 5.1	 4.07	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51729	 1	 9.71	 6.75	 0.0	 0.0	 21	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51730	 1	 10.62	 9.54	 0.0	 0.0	 21	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51731	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51732	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51733	 1	 10.07	 7.66	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51734	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51735	 1	 11.11	 -5.38	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51736	 1	 12.21	 -5.39	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51737	 1	 10.5	 -5.4	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51738	 1	 7.5	 1.78	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51739	 1	 11.78	 7.35	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51740	 1	 15.27	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51741	 1	 8.94	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51742	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51743	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51744	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51745	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51746	 1	 6.38	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51747	 1	 5.88	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51748	 1	 9.52	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51749	 1	 8.1	 5.03	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51750	 1	 8.17	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51751	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51752	 1	 5.88	 5.13	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51753	 1	 4.27	 3.05	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51754	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51755	 1	 3.06	 2.79	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51756	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51757	 1	 4.81	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51758	 1	 5.5	 3.91	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51759	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51760	 1	 3.53	 3.1	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51761	 1	 1.85	 1.53	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51762	 1	 2.24	 2.31	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51763	 1	 3.53	 3.72	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51764	 1	 3.31	 3.35	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51765	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51766	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51767	 1	 4.43	 3.09	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51768	 1	 3.4	 3.1	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51769	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51770	 1	 2.12	 2.23	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51771	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51772	 1	 4.99	 4.09	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51773	 1	 1.11	 1.14	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51774	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51775	 1	 2.81	 2.53	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51776	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51777	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51778	 1	 2.92	 3.1	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51779	 1	 2.13	 1.92	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51780	 1	 3.74	 3.36	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51781	 1	 1.3	 1.26	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51782	 1	 6.55	 4.51	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51783	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51784	 1	 4.18	 3.63	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51785	 1	 4.56	 3.89	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51786	 1	 3.16	 3.24	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51787	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51788	 1	 2.96	 2.46	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51789	 1	 3.5	 3.17	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51790	 1	 4.05	 4.3	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51791	 1	 5.78	 5.15	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51792	 1	 3.19	 3.28	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51793	 1	 2.8	 2.28	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51794	 1	 5.31	 3.89	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51795	 1	 13.63	 9.65	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51796	 1	 1.54	 1.39	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51797	 1	 6.38	 5.71	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51798	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51799	 1	 7.01	 4.97	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51800	 1	 1.97	 2.09	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51801	 1	 5.92	 5.17	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51802	 1	 4.62	 3.83	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51803	 1	 7.05	 5.4	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51804	 1	 11.16	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51805	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51806	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51807	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51808	 1	 3.17	 -0.94	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51809	 1	 6.72	 -0.94	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51810	 1	 12.66	 -0.93	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51811	 1	 2.45	 -0.94	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51812	 1	 8.35	 -0.94	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51813	 1	 3.0	 -0.95	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51814	 1	 2.5	 -0.95	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51815	 1	 4.18	 -0.95	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51816	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51817	 1	 15.91	 -0.95	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51818	 1	 4.84	 -0.95	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51819	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51820	 1	 12.12	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51821	 1	 4.99	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51822	 1	 10.03	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51823	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51824	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51825	 1	 6.5	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51826	 1	 1.14	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51827	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51828	 1	 13.88	 3.35	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51829	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51830	 1	 9.36	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51831	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51832	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51833	 1	 5.37	 4.19	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51834	 1	 15.21	 -12.34	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51835	 1	 7.09	 -12.33	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51836	 1	 2.95	 2.47	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51837	 1	 31.72	 16.64	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51838	 1	 3.68	 3.04	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51839	 1	 5.8	 4.14	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51840	 1	 9.56	 6.73	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51841	 1	 7.67	 1.86	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51842	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51843	 1	 6.8	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51844	 1	 6.78	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51845	 1	 2.75	 -7.94	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51846	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51847	 1	 15.75	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51848	 1	 8.74	 -4.83	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51849	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51850	 1	 4.01	 2.37	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51851	 1	 3.18	 1.65	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51852	 1	 10.8	 7.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51853	 1	 17.88	 9.46	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51854	 1	 8.09	 4.59	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51855	 1	 10.23	 4.54	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51856	 1	 4.74	 2.3	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51857	 1	 2.0	 1.03	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51858	 1	 3.36	 1.69	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51859	 1	 4.77	 1.14	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51860	 1	 6.99	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51861	 1	 4.38	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51862	 1	 7.89	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51863	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51864	 1	 2.14	 1.04	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51865	 1	 8.92	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51866	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51867	 1	 9.78	 5.68	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51868	 1	 6.87	 3.65	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51869	 1	 5.84	 2.66	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51870	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51871	 1	 9.82	 4.97	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51872	 1	 7.22	 3.88	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51873	 1	 17.88	 7.37	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51874	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51875	 1	 21.95	 13.82	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51876	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51877	 1	 7.86	 4.28	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51878	 1	 4.19	 2.2	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51879	 1	 4.36	 2.39	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51880	 1	 5.23	 2.8	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51881	 1	 8.32	 4.14	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51882	 1	 22.38	 9.36	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51883	 1	 3.53	 1.66	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51884	 1	 3.66	 2.22	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51885	 1	 8.89	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51886	 1	 4.77	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51887	 1	 3.51	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51888	 1	 35.92	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51889	 1	 4.47	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51890	 1	 9.61	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51891	 1	 6.59	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51892	 1	 64.14	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51893	 1	 13.91	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51894	 1	 4.57	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51895	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51896	 1	 7.9	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51897	 1	 4.43	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51898	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51899	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51900	 1	 3.61	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51901	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51902	 1	 64.97	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51903	 1	 7.9	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51904	 1	 5.98	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51905	 1	 22.06	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51906	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51907	 1	 6.68	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51908	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51909	 1	 6.66	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51910	 1	 5.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51911	 1	 3.05	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51912	 1	 3.65	 1.77	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51913	 1	 4.39	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51914	 1	 34.47	 12.17	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51915	 1	 29.8	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51916	 1	 34.9	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51917	 1	 7.12	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51918	 1	 5.58	 2.76	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51919	 1	 7.13	 3.42	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51920	 1	 8.01	 3.58	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51921	 1	 2.81	 1.57	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51922	 1	 2.57	 1.46	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51923	 1	 4.17	 -4.98	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51924	 1	 19.29	 9.03	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51925	 1	 5.41	 3.11	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51926	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51927	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51928	 1	 3.04	 -4.85	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51929	 1	 16.75	 10.18	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51930	 1	 6.31	 3.19	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51931	 1	 8.27	 4.04	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51932	 1	 19.11	 7.83	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51933	 1	 3.03	 1.73	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51934	 1	 2.89	 1.43	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51935	 1	 43.36	 21.13	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51936	 1	 10.51	 5.71	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51937	 1	 7.09	 3.31	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51938	 1	 1.78	 0.84	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51939	 1	 4.06	 2.34	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51940	 1	 5.78	 2.66	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51941	 1	 11.41	 5.2	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51942	 1	 3.87	 1.8	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51943	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51944	 1	 3.57	 2.02	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51945	 1	 7.99	 3.99	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51946	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51947	 1	 4.12	 2.03	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51948	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51949	 1	 2.09	 1.11	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51950	 1	 2.43	 0.57	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51951	 1	 4.17	 2.26	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51952	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51953	 1	 7.43	 4.82	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51954	 1	 4.0	 2.39	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51955	 1	 6.71	 3.24	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51956	 1	 35.24	 16.81	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51957	 1	 10.25	 6.29	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51958	 1	 2.49	 0.62	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51959	 1	 8.23	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51960	 1	 5.32	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51961	 1	 3.21	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51962	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	51963	 1	 17.76	 10.73	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51964	 1	 4.33	 2.49	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51965	 1	 5.37	 2.9	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51966	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51967	 1	 12.19	 5.76	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51968	 1	 63.36	 23.19	 0.0	 0.0	 26	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51969	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	51970	 1	 6.47	 3.46	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51971	 1	 17.81	 7.55	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51972	 1	 3.89	 2.19	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51973	 1	 7.17	 1.81	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51974	 1	 0.0	 0.0	 0.0	 24.74	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51975	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51976	 1	 2.8	 1.48	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51977	 1	 16.36	 3.79	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51978	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51979	 1	 2.58	 1.23	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51980	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51981	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51982	 1	 8.31	 3.77	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51983	 1	 5.97	 2.94	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51984	 1	 18.05	 7.29	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51985	 1	 7.14	 4.05	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51986	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51987	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51988	 1	 3.17	 1.75	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51989	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51990	 1	 8.91	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51991	 1	 3.94	 1.87	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51992	 1	 35.14	 13.41	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51993	 1	 41.07	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51994	 1	 19.45	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51995	 1	 3.74	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51996	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	51997	 1	 12.82	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51998	 1	 7.23	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	51999	 1	 8.6	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52000	 1	 3.14	 1.65	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52001	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52002	 1	 4.54	 2.64	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52003	 1	 2.78	 1.73	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52004	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52005	 1	 5.25	 2.74	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52006	 1	 1.28	 0.73	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52007	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52008	 1	 10.98	 6.39	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52009	 1	 7.53	 4.09	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52010	 1	 7.39	 4.27	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52011	 1	 6.18	 3.45	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52012	 1	 9.69	 4.39	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52013	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52014	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52015	 1	 4.85	 2.56	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52016	 1	 17.81	 8.16	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52017	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52018	 1	 26.3	 9.58	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52019	 1	 7.28	 3.82	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52020	 1	 7.98	 4.34	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52021	 1	 16.57	 6.5	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52022	 1	 5.4	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52023	 1	 4.02	 1.87	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52024	 1	 4.89	 2.75	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52025	 1	 33.94	 9.81	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52026	 1	 2.67	 1.53	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52027	 1	 5.74	 2.63	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52028	 1	 1.89	 0.43	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52029	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52030	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52031	 1	 2.2	 1.24	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52032	 1	 2.88	 1.46	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52033	 1	 8.09	 1.94	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52034	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52035	 1	 5.02	 1.18	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52036	 1	 5.83	 1.37	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52037	 1	 9.65	 2.27	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52038	 1	 10.33	 2.43	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52039	 1	 14.06	 3.33	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52040	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52041	 1	 5.92	 1.4	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52042	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52043	 1	 9.2	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52044	 1	 15.46	 6.56	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52045	 1	 13.57	 3.24	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52046	 1	 3.22	 1.62	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52047	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52048	 1	 4.06	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52049	 1	 4.12	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52050	 1	 5.95	 1.55	 0.0	 17.87	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52051	 1	 24.99	 6.28	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52052	 1	 4.87	 1.22	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52053	 1	 6.11	 3.75	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52054	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52055	 1	 3.34	 3.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52056	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52057	 1	 6.09	 4.63	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52058	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52059	 1	 6.8	 6.21	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52060	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52061	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52062	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52063	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52064	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52065	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52066	 1	 5.73	 4.63	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52067	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52068	 1	 18.25	 4.33	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52069	 1	 3.88	 2.89	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52070	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52071	 1	 10.18	 7.88	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52072	 1	 3.26	 2.33	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52073	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52074	 1	 12.52	 2.98	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52075	 1	 2.84	 2.41	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52076	 1	 9.07	 2.14	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52077	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52078	 1	 6.65	 4.75	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52079	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52080	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52081	 1	 2.01	 1.75	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52082	 1	 22.44	 14.49	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52083	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52084	 1	 15.49	 11.39	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52085	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52086	 1	 3.6	 3.04	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52087	 1	 3.33	 2.94	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52088	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52089	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52090	 1	 18.98	 13.58	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52091	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52092	 1	 8.69	 6.84	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52093	 1	 2.0	 1.87	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52094	 1	 9.1	 8.02	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52095	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52096	 1	 3.78	 2.93	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52097	 1	 11.56	 2.71	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52098	 1	 9.66	 7.13	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52099	 1	 6.8	 5.23	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52100	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52101	 1	 7.15	 6.12	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52102	 1	 6.09	 4.37	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52103	 1	 6.43	 4.34	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52104	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52105	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52106	 1	 15.21	 3.53	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52107	 1	 2.95	 0.69	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52108	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52109	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52110	 1	 4.28	 0.99	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52111	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52112	 1	 54.7	 31.65	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52113	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52114	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52115	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52116	 1	 6.99	 6.25	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52117	 1	 3.26	 2.79	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52118	 1	 6.99	 1.62	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52119	 1	 7.14	 5.74	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52120	 1	 3.76	 0.87	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52121	 1	 7.08	 5.96	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52122	 1	 8.14	 6.86	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52123	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52124	 1	 3.45	 2.73	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52125	 1	 3.31	 2.53	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52126	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52127	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52128	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52129	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52130	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52131	 1	 31.37	 7.45	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52132	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52133	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52134	 1	 13.8	 3.27	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52135	 1	 10.95	 2.59	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52136	 1	 21.08	 4.97	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52137	 1	 5.85	 1.38	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52138	 1	 6.84	 4.93	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52139	 1	 9.55	 8.41	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52140	 1	 9.66	 8.69	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52141	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52142	 1	 7.45	 6.34	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52143	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52144	 1	 3.41	 2.8	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52145	 1	 4.62	 3.61	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52146	 1	 12.95	 8.12	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52147	 1	 3.17	 2.73	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52148	 1	 3.7	 3.07	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52149	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52150	 1	 14.79	 10.24	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52151	 1	 3.87	 3.19	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52152	 1	 23.43	 19.75	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52153	 1	 3.93	 3.49	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52154	 1	 4.28	 2.98	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52155	 1	 3.69	 3.28	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52156	 1	 5.44	 4.23	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52157	 1	 5.84	 4.68	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52158	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52159	 1	 7.29	 6.27	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52160	 1	 5.64	 4.25	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52161	 1	 0.32	 0.27	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52162	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52163	 1	 7.46	 4.95	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52164	 1	 6.79	 6.14	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52165	 1	 6.82	 5.34	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52166	 1	 5.66	 4.85	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52167	 1	 2.49	 2.1	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52168	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52169	 1	 10.59	 7.61	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52170	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52171	 1	 6.7	 5.8	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52172	 1	 5.29	 3.46	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52173	 1	 6.72	 5.14	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52174	 1	 8.88	 6.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52175	 1	 8.22	 6.25	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52176	 1	 4.35	 3.49	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52177	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52178	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52179	 1	 3.19	 2.67	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52180	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52181	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52182	 1	 6.09	 4.5	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52183	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52184	 1	 4.36	 3.8	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52185	 1	 2.6	 2.03	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52186	 1	 5.97	 4.52	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52187	 1	 11.07	 7.04	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52188	 1	 4.87	 4.07	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52189	 1	 6.42	 5.82	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52190	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52191	 1	 3.44	 2.8	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52192	 1	 6.6	 4.52	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52193	 1	 4.99	 4.4	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52194	 1	 4.22	 3.71	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52195	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52196	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52197	 1	 5.04	 4.4	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52198	 1	 4.89	 3.47	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52199	 1	 6.89	 5.98	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52200	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52201	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52202	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52203	 1	 2.66	 2.29	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52204	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52205	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52206	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52207	 1	 7.29	 6.49	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52208	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52209	 1	 7.04	 5.96	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52210	 1	 9.29	 7.1	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52211	 1	 6.18	 4.7	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52212	 1	 5.57	 3.92	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52213	 1	 9.03	 6.54	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52214	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52215	 1	 3.14	 2.35	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52216	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52217	 1	 14.16	 3.29	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52218	 1	 8.73	 7.6	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52219	 1	 3.92	 3.04	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52220	 1	 7.25	 5.58	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52221	 1	 10.36	 8.52	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52222	 1	 5.12	 4.65	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52223	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52224	 1	 9.27	 6.87	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52225	 1	 9.37	 7.72	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52226	 1	 4.14	 3.19	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52227	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52228	 1	 2.86	 2.42	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52229	 1	 2.38	 1.95	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52230	 1	 4.03	 3.52	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52231	 1	 2.24	 1.87	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52232	 1	 2.2	 1.76	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52233	 1	 4.61	 3.69	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52234	 1	 2.41	 1.68	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52235	 1	 3.39	 2.48	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52236	 1	 2.07	 1.68	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52237	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52238	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52239	 1	 3.65	 3.29	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52240	 1	 5.6	 4.1	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52241	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52242	 1	 17.26	 4.01	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52243	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52244	 1	 10.39	 8.26	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52245	 1	 5.77	 4.61	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52246	 1	 0.16	 0.15	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52247	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52248	 1	 32.33	 29.44	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52249	 1	 5.74	 5.18	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52250	 1	 6.84	 6.34	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52251	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52252	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52253	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52254	 1	 10.75	 8.19	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52255	 1	 4.97	 3.98	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52256	 1	 3.16	 2.41	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52257	 1	 40.91	 24.75	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52258	 1	 6.43	 4.11	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52259	 1	 12.25	 7.86	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52260	 1	 7.86	 6.67	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52261	 1	 5.0	 4.41	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52262	 1	 4.4	 3.87	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52263	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52264	 1	 3.44	 3.14	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52265	 1	 7.79	 6.52	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52266	 1	 2.45	 1.97	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52267	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52268	 1	 4.53	 3.7	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52269	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52270	 1	 10.74	 9.18	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52271	 1	 4.7	 3.48	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52272	 1	 2.26	 1.69	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52273	 1	 25.68	 13.15	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52274	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52275	 1	 13.24	 9.28	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52276	 1	 6.94	 5.37	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52277	 1	 3.02	 2.61	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52278	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52279	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52280	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52281	 1	 31.22	 19.1	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52282	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52283	 1	 4.28	 2.95	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52284	 1	 3.69	 2.99	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52285	 1	 33.68	 23.43	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52286	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52287	 1	 4.8	 3.96	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52288	 1	 6.86	 5.98	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52289	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52290	 1	 6.69	 6.06	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52291	 1	 6.8	 5.26	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52292	 1	 19.0	 12.98	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52293	 1	 6.89	 5.44	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52294	 1	 7.89	 7.26	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52295	 1	 9.92	 8.03	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52296	 1	 2.98	 0.71	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52297	 1	 24.72	 5.93	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52298	 1	 28.06	 6.76	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52299	 1	 7.62	 1.83	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52300	 1	 9.31	 2.25	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52301	 1	 18.99	 13.01	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52302	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52303	 1	 9.61	 2.26	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52304	 1	 3.93	 0.95	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52305	 1	 6.05	 1.42	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52306	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52307	 1	 9.79	 2.28	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52308	 1	 38.4	 9.18	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52309	 1	 4.19	 3.85	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52310	 1	 4.27	 3.36	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52311	 1	 5.99	 4.92	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52312	 1	 8.8	 6.25	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52313	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52314	 1	 10.2	 2.41	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52315	 1	 3.38	 0.77	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52316	 1	 7.82	 1.81	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52317	 1	 9.6	 2.23	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52318	 1	 18.06	 12.05	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52319	 1	 3.85	 3.33	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52320	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52321	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52322	 1	 19.72	 4.56	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52323	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52324	 1	 5.36	 4.93	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52325	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52326	 1	 10.97	 9.49	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52327	 1	 13.45	 10.32	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52328	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52329	 1	 30.42	 7.22	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52330	 1	 3.48	 2.79	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52331	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52332	 1	 4.63	 3.17	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52333	 1	 4.8	 4.39	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52334	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52335	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52336	 1	 6.24	 5.27	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52337	 1	 6.63	 4.92	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52338	 1	 3.6	 2.79	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52339	 1	 6.46	 5.62	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52340	 1	 4.93	 4.03	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52341	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52342	 1	 4.26	 3.1	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52343	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52344	 1	 3.27	 2.68	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52345	 1	 3.61	 2.82	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52346	 1	 13.28	 7.14	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52347	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52348	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52349	 1	 7.48	 5.31	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52350	 1	 2.61	 1.98	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52351	 1	 5.19	 4.22	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52352	 1	 2.69	 0.62	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52353	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52354	 1	 9.65	 2.25	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52355	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52356	 1	 8.07	 1.92	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52357	 1	 3.57	 0.84	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52358	 1	 47.42	 28.02	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52359	 1	 3.73	 3.12	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52360	 1	 12.43	 8.64	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52361	 1	 5.85	 5.63	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52362	 1	 4.34	 3.68	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52363	 1	 5.06	 4.33	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52364	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52365	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52366	 1	 8.91	 7.66	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52367	 1	 22.27	 4.72	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52368	 1	 23.18	 16.56	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52369	 1	 8.67	 6.7	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52370	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52371	 1	 10.61	 8.65	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52372	 1	 16.88	 13.21	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52373	 1	 8.25	 7.42	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52374	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52375	 1	 8.64	 5.36	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52376	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52377	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52378	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52379	 1	 5.57	 3.93	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52380	 1	 2.45	 2.05	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52381	 1	 5.25	 4.02	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52382	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52383	 1	 4.87	 1.16	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52384	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52385	 1	 9.33	 2.23	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52386	 1	 10.19	 7.96	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52387	 1	 8.04	 6.28	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52388	 1	 14.45	 8.44	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52389	 1	 7.92	 5.75	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52390	 1	 3.74	 3.22	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52391	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52392	 1	 6.85	 5.96	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52393	 1	 7.06	 5.79	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52394	 1	 9.55	 7.72	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52395	 1	 10.32	 7.87	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52396	 1	 4.34	 3.2	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52397	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52398	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52399	 1	 5.55	 3.61	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52400	 1	 6.27	 5.47	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52401	 1	 10.65	 9.98	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52402	 1	 17.3	 13.23	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52403	 1	 5.89	 5.03	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52404	 1	 20.98	 18.96	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52405	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52406	 1	 6.0	 1.4	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52407	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52408	 1	 2.65	 0.62	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52409	 1	 21.35	 16.22	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52410	 1	 12.55	 2.88	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52411	 1	 5.51	 1.3	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52412	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52413	 1	 9.28	 7.94	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52414	 1	 1.58	 1.4	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52415	 1	 3.17	 2.83	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52416	 1	 9.88	 5.03	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52417	 1	 42.03	 27.31	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52418	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52419	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52420	 1	 17.8	 10.84	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52421	 1	 9.46	 7.63	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52422	 1	 3.2	 2.88	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52423	 1	 5.52	 4.07	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52424	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52425	 1	 6.63	 5.75	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52426	 1	 3.21	 2.88	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52427	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52428	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52429	 1	 15.23	 3.64	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52430	 1	 33.25	 22.67	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52431	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52432	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52433	 1	 37.65	 27.03	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52434	 1	 4.13	 3.85	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52435	 1	 5.78	 4.27	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52436	 1	 6.45	 5.65	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52437	 1	 5.96	 5.24	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52438	 1	 32.07	 20.73	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52439	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52440	 1	 4.52	 3.69	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52441	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52442	 1	 5.38	 4.32	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52443	 1	 5.01	 4.88	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52444	 1	 9.55	 7.18	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52445	 1	 2.39	 0.57	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52446	 1	 9.28	 6.48	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52447	 1	 12.67	 3.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52448	 1	 8.75	 6.2	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52449	 1	 2.59	 2.38	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52450	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52451	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52452	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52453	 1	 8.41	 6.31	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52454	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52455	 1	 13.8	 10.7	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52456	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52457	 1	 2.25	 1.69	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52458	 1	 10.09	 8.98	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52459	 1	 7.0	 5.13	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52460	 1	 39.44	 29.31	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52461	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52462	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52463	 1	 7.0	 6.39	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52464	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52465	 1	 11.78	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52466	 1	 8.91	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52467	 1	 10.19	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52468	 1	 6.5	 1.55	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52469	 1	 2.77	 0.67	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52470	 1	 2.49	 0.6	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52471	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52472	 1	 4.87	 4.21	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52473	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52474	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52475	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52476	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52477	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52478	 1	 3.11	 2.34	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52479	 1	 8.37	 1.92	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52480	 1	 5.38	 1.24	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52481	 1	 0.86	 0.62	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52482	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52483	 1	 3.62	 0.84	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52484	 1	 3.37	 0.78	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52485	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52486	 1	 1.38	 1.07	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52487	 1	 1.8	 1.53	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52488	 1	 4.2	 0.97	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52489	 1	 1.25	 0.29	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52490	 1	 12.28	 2.83	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52491	 1	 5.26	 2.44	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52492	 1	 1.41	 0.97	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52493	 1	 1.66	 1.16	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52494	 1	 3.68	 2.97	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52495	 1	 4.35	 1.01	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52496	 1	 4.51	 1.04	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52497	 1	 4.07	 0.94	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52498	 1	 5.12	 1.19	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52499	 1	 3.98	 3.33	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52500	 1	 8.19	 5.42	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52501	 1	 2.32	 1.81	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52502	 1	 3.73	 3.18	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52503	 1	 8.7	 2.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52504	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52505	 1	 6.38	 5.3	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52506	 1	 5.52	 4.48	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52507	 1	 4.16	 2.19	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52508	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52509	 1	 3.3	 1.93	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52510	 1	 8.25	 5.42	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52511	 1	 3.71	 2.91	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52512	 1	 3.2	 2.74	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52513	 1	 7.55	 5.13	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52514	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52515	 1	 4.59	 2.77	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52516	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52517	 1	 4.6	 3.63	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52518	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52519	 1	 6.37	 5.51	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52520	 1	 5.87	 5.01	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52521	 1	 2.28	 1.84	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52522	 1	 7.09	 2.92	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52523	 1	 5.45	 4.26	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52524	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52525	 1	 4.51	 3.6	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52526	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52527	 1	 5.74	 1.32	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52528	 1	 1.36	 0.31	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52529	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52530	 1	 3.84	 2.78	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52531	 1	 4.01	 3.22	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52532	 1	 6.09	 4.6	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52533	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52534	 1	 4.46	 2.62	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52535	 1	 9.77	 5.72	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52536	 1	 9.3	 6.19	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52537	 1	 4.11	 3.31	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52538	 1	 4.1	 3.01	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52539	 1	 6.14	 1.42	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52540	 1	 4.74	 3.14	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52541	 1	 7.71	 6.58	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52542	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52543	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52544	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52545	 1	 4.08	 3.46	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52546	 1	 3.35	 2.03	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52547	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52548	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52549	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52550	 1	 5.86	 3.96	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52551	 1	 3.26	 2.39	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52552	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52553	 1	 4.59	 3.66	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52554	 1	 4.31	 3.15	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52555	 1	 5.96	 4.22	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52556	 1	 3.93	 2.8	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52557	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52558	 1	 3.04	 2.48	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52559	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52560	 1	 5.24	 3.75	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52561	 1	 3.43	 0.79	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52562	 1	 4.85	 4.08	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52563	 1	 4.57	 3.62	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52564	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52565	 1	 16.88	 3.89	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52566	 1	 2.28	 1.84	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52567	 1	 2.22	 1.65	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52568	 1	 4.39	 2.85	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52569	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52570	 1	 6.35	 4.98	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52571	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52572	 1	 3.22	 2.36	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52573	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52574	 1	 2.18	 1.97	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52575	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52576	 1	 3.65	 2.93	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52577	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52578	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52579	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52580	 1	 12.4	 9.37	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52581	 1	 18.8	 12.39	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52582	 1	 13.98	 9.33	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52583	 1	 43.84	 30.81	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52584	 1	 2.25	 2.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52585	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52586	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52587	 1	 4.3	 3.8	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52588	 1	 7.69	 5.5	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52589	 1	 1.25	 1.01	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52590	 1	 2.49	 2.2	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52591	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52592	 1	 7.29	 6.56	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52593	 1	 3.27	 2.8	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52594	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52595	 1	 5.79	 4.54	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52596	 1	 2.25	 2.04	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52597	 1	 5.5	 4.88	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52598	 1	 6.37	 5.29	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52599	 1	 4.57	 3.64	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52600	 1	 5.19	 3.46	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52601	 1	 3.31	 2.9	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52602	 1	 3.18	 2.81	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52603	 1	 4.94	 4.38	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52604	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52605	 1	 12.87	 8.36	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52606	 1	 17.55	 12.49	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52607	 1	 24.05	 14.72	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52608	 1	 27.45	 14.21	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52609	 1	 7.44	 5.87	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52610	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52611	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52612	 1	 3.89	 2.78	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52613	 1	 3.32	 2.91	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52614	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52615	 1	 1.11	 0.68	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52616	 1	 3.95	 3.4	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52617	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52618	 1	 3.49	 2.41	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52619	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52620	 1	 3.71	 3.27	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52621	 1	 3.49	 2.91	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52622	 1	 5.76	 4.61	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52623	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52624	 1	 5.82	 4.76	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52625	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52626	 1	 3.68	 3.24	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52627	 1	 2.55	 2.07	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52628	 1	 6.23	 3.14	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52629	 1	 6.42	 4.68	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52630	 1	 14.02	 9.99	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52631	 1	 9.79	 7.01	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52632	 1	 13.13	 10.08	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52633	 1	 6.33	 4.48	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52634	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52635	 1	 5.19	 4.32	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52636	 1	 3.51	 3.16	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52637	 1	 4.39	 3.98	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52638	 1	 5.31	 4.9	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52639	 1	 7.7	 5.85	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52640	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52641	 1	 3.28	 2.9	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52642	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52643	 1	 5.87	 4.94	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52644	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52645	 1	 5.35	 4.11	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52646	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52647	 1	 4.65	 2.99	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52648	 1	 3.62	 2.9	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52649	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52650	 1	 4.63	 3.61	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52651	 1	 5.05	 3.92	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52652	 1	 11.16	 9.47	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52653	 1	 5.57	 4.35	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52654	 1	 3.8	 2.98	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52655	 1	 5.05	 3.95	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52656	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52657	 1	 5.15	 4.34	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52658	 1	 6.07	 4.92	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52659	 1	 11.32	 8.93	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52660	 1	 5.01	 3.85	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52661	 1	 10.67	 8.33	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52662	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52663	 1	 6.14	 5.56	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52664	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52665	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52666	 1	 3.03	 2.55	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52667	 1	 7.91	 6.83	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52668	 1	 4.64	 3.25	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52669	 1	 8.66	 6.78	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52670	 1	 7.05	 6.29	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52671	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52672	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52673	 1	 3.14	 2.79	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52674	 1	 2.35	 1.68	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52675	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52676	 1	 7.88	 5.99	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52677	 1	 3.79	 3.41	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52678	 1	 1.35	 1.08	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52679	 1	 2.35	 1.81	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52680	 1	 13.36	 11.97	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52681	 1	 8.67	 7.01	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52682	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52683	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52684	 1	 7.72	 6.17	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52685	 1	 4.3	 3.92	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52686	 1	 4.59	 3.8	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52687	 1	 3.66	 3.05	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52688	 1	 6.32	 4.98	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52689	 1	 3.81	 2.9	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52690	 1	 2.48	 2.22	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52691	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52692	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52693	 1	 2.53	 1.81	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52694	 1	 3.29	 2.7	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52695	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52696	 1	 96.92	 73.5	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52697	 1	 21.97	 13.69	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52698	 1	 57.47	 40.52	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52699	 1	 2.97	 2.62	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52700	 1	 6.28	 5.44	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52701	 1	 7.36	 5.45	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52702	 1	 3.22	 2.64	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52703	 1	 7.45	 5.32	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52704	 1	 4.27	 3.47	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52705	 1	 4.79	 4.27	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52706	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52707	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52708	 1	 1.28	 0.98	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52709	 1	 3.1	 2.32	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52710	 1	 4.3	 3.98	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52711	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52712	 1	 6.75	 5.63	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52713	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52714	 1	 4.09	 2.96	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52715	 1	 19.96	 17.95	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52716	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52717	 1	 4.15	 3.79	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52718	 1	 4.47	 3.21	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52719	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52720	 1	 9.26	 2.14	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52721	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52722	 1	 23.22	 17.83	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52723	 1	 4.56	 3.88	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52724	 1	 5.35	 1.22	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52725	 1	 21.14	 13.42	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52726	 1	 9.39	 7.05	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52727	 1	 13.06	 9.58	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52728	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52729	 1	 8.66	 8.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52730	 1	 34.05	 8.07	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52731	 1	 4.61	 3.48	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52732	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52733	 1	 31.72	 7.44	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52734	 1	 27.0	 13.41	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52735	 1	 4.18	 3.36	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52736	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52737	 1	 5.65	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52738	 1	 26.26	 10.58	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52739	 1	 12.97	 8.66	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52740	 1	 7.33	 5.38	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52741	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52742	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52743	 1	 8.26	 5.16	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52744	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52745	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52746	 1	 3.83	 2.65	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52747	 1	 6.62	 5.08	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52748	 1	 5.31	 4.03	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52749	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52750	 1	 7.18	 5.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52751	 1	 4.49	 3.96	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52752	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52753	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52754	 1	 6.87	 5.03	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52755	 1	 4.0	 3.51	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52756	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52757	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52758	 1	 6.45	 5.05	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52759	 1	 3.77	 2.81	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52760	 1	 8.16	 7.46	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52761	 1	 12.1	 11.5	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52762	 1	 7.54	 6.37	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52763	 1	 9.48	 7.11	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52764	 1	 11.77	 8.89	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52765	 1	 2.88	 2.18	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52766	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52767	 1	 25.29	 20.98	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52768	 1	 13.14	 10.39	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52769	 1	 3.26	 2.75	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52770	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52771	 1	 6.35	 4.46	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52772	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52773	 1	 9.69	 7.15	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52774	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52775	 1	 4.37	 3.71	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52776	 1	 3.7	 2.44	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52777	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52778	 1	 7.11	 5.14	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52779	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52780	 1	 8.76	 7.52	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52781	 1	 4.88	 4.53	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52782	 1	 33.85	 29.19	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52783	 1	 3.24	 0.74	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52784	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52785	 1	 10.54	 9.18	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52786	 1	 6.4	 1.48	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52787	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52788	 1	 2.34	 1.79	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52789	 1	 6.97	 1.61	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52790	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52791	 1	 3.35	 0.76	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52792	 1	 9.22	 6.89	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52793	 1	 5.37	 4.88	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52794	 1	 3.33	 2.81	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52795	 1	 5.22	 4.42	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52796	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52797	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52798	 1	 6.15	 5.08	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52799	 1	 5.36	 4.65	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52800	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52801	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52802	 1	 5.84	 4.27	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52803	 1	 12.26	 6.64	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52804	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52805	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52806	 1	 2.73	 2.59	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52807	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52808	 1	 3.57	 2.65	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52809	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52810	 1	 9.59	 7.18	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52811	 1	 26.93	 6.43	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52812	 1	 12.54	 11.6	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52813	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52814	 1	 2.51	 1.97	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52815	 1	 5.51	 4.9	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52816	 1	 26.21	 18.87	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52817	 1	 3.44	 3.02	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52818	 1	 1.92	 1.57	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52819	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52820	 1	 3.2	 2.88	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52821	 1	 9.01	 6.23	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52822	 1	 4.2	 3.28	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52823	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52824	 1	 7.69	 5.71	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52825	 1	 4.32	 3.49	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52826	 1	 6.51	 4.79	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52827	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52828	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52829	 1	 10.92	 7.71	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52830	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52831	 1	 4.37	 3.16	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52832	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52833	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52834	 1	 3.48	 2.81	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52835	 1	 5.27	 3.84	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52836	 1	 2.55	 2.24	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52837	 1	 8.18	 6.42	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52838	 1	 6.75	 6.32	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52839	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52840	 1	 14.09	 11.29	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52841	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52842	 1	 6.08	 1.41	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52843	 1	 6.86	 4.61	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52844	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52845	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52846	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52847	 1	 3.35	 2.56	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52848	 1	 10.6	 7.43	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52849	 1	 6.11	 5.19	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52850	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52851	 1	 10.71	 9.27	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52852	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52853	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52854	 1	 5.47	 3.73	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52855	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52856	 1	 4.71	 4.39	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52857	 1	 16.73	 14.35	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52858	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52859	 1	 7.22	 1.71	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52860	 1	 5.32	 1.25	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52861	 1	 5.27	 1.25	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52862	 1	 7.1	 1.67	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52863	 1	 33.27	 8.02	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52864	 1	 16.17	 3.94	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52865	 1	 9.03	 2.14	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52866	 1	 21.65	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52867	 1	 8.42	 2.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52868	 1	 7.71	 1.8	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52869	 1	 38.23	 32.18	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52870	 1	 16.9	 12.38	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52871	 1	 14.87	 10.38	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52872	 1	 24.87	 13.73	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52873	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52874	 1	 5.01	 3.78	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52875	 1	 3.72	 3.48	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52876	 1	 2.81	 2.16	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52877	 1	 18.51	 13.37	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52878	 1	 7.31	 5.99	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52879	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52880	 1	 9.95	 5.96	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52881	 1	 6.27	 5.04	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52882	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52883	 1	 2.74	 2.07	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52884	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52885	 1	 2.39	 2.08	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52886	 1	 1.64	 1.48	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52887	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52888	 1	 1.67	 1.29	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52889	 1	 31.29	 14.13	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52890	 1	 7.22	 4.21	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52891	 1	 30.06	 19.36	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52892	 1	 8.5	 6.33	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52893	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52894	 1	 9.02	 6.7	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52895	 1	 2.23	 1.69	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52896	 1	 2.47	 1.82	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52897	 1	 2.15	 1.72	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52898	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52899	 1	 19.32	 8.62	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52900	 1	 37.85	 20.95	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52901	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52902	 1	 3.85	 3.06	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52903	 1	 9.41	 6.22	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52904	 1	 4.52	 3.57	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52905	 1	 8.13	 5.73	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52906	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52907	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52908	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52909	 1	 2.64	 2.29	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52910	 1	 5.13	 4.17	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52911	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52912	 1	 8.75	 6.51	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52913	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52914	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52915	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52916	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52917	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52918	 1	 9.15	 6.8	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52919	 1	 2.88	 2.62	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52920	 1	 14.36	 7.76	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52921	 1	 18.77	 13.26	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52922	 1	 7.56	 6.88	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52923	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52924	 1	 4.8	 3.59	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52925	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52926	 1	 3.72	 2.81	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52927	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52928	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52929	 1	 3.14	 2.73	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52930	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52931	 1	 6.26	 4.35	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52932	 1	 2.94	 2.45	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52933	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52934	 1	 7.09	 5.65	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52935	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52936	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52937	 1	 16.81	 12.37	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52938	 1	 28.89	 13.06	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52939	 1	 91.99	 66.44	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52940	 1	 9.86	 7.41	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52941	 1	 5.0	 3.75	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52942	 1	 2.68	 2.19	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52943	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52944	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52945	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52946	 1	 15.05	 9.07	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52947	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52948	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52949	 1	 10.87	 6.91	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52950	 1	 3.44	 2.6	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52951	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52952	 1	 4.08	 3.37	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52953	 1	 6.44	 5.68	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52954	 1	 5.84	 4.78	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52955	 1	 4.26	 3.94	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52956	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52957	 1	 13.29	 10.25	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52958	 1	 5.07	 3.54	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52959	 1	 4.29	 3.96	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52960	 1	 18.09	 9.97	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52961	 1	 3.21	 2.63	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52962	 1	 4.99	 4.46	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52963	 1	 4.88	 3.84	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52964	 1	 7.45	 5.49	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52965	 1	 9.48	 7.07	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52966	 1	 7.39	 5.28	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52967	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52968	 1	 4.32	 3.63	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52969	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52970	 1	 5.63	 4.23	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52971	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	52972	 1	 6.49	 5.32	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52973	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52974	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52975	 1	 3.42	 2.47	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52976	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52977	 1	 4.65	 3.93	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52978	 1	 5.08	 4.81	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52979	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	52980	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52981	 1	 7.41	 4.86	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52982	 1	 9.46	 8.01	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52983	 1	 4.03	 3.77	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52984	 1	 10.31	 7.89	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52985	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52986	 1	 3.28	 3.09	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52987	 1	 5.12	 3.9	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52988	 1	 5.5	 5.19	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52989	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52990	 1	 5.08	 4.57	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52991	 1	 4.1	 3.32	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52992	 1	 3.45	 2.72	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52993	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52994	 1	 2.95	 2.35	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52995	 1	 4.55	 3.34	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52996	 1	 7.19	 6.64	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52997	 1	 3.03	 2.65	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	52998	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52999	 1	 3.99	 3.07	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53000	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53001	 1	 3.94	 3.14	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53002	 1	 2.86	 2.05	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53003	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53004	 1	 9.13	 7.92	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53005	 1	 5.91	 4.94	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53006	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53007	 1	 8.1	 6.09	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53008	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53009	 1	 5.1	 4.57	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53010	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53011	 1	 9.26	 8.41	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53012	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53013	 1	 3.78	 2.79	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53014	 1	 3.72	 2.82	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53015	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53016	 1	 4.34	 4.04	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53017	 1	 6.93	 5.46	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53018	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53019	 1	 6.05	 5.77	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53020	 1	 4.62	 4.36	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53021	 1	 9.24	 7.85	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53022	 1	 5.3	 3.74	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53023	 1	 2.02	 1.69	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53024	 1	 24.63	 21.15	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53025	 1	 13.09	 11.34	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53026	 1	 3.57	 3.22	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53027	 1	 15.87	 13.11	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53028	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53029	 1	 2.66	 1.86	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53030	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53031	 1	 5.13	 3.3	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53032	 1	 2.12	 1.77	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53033	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53034	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53035	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53036	 1	 5.86	 4.94	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53037	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53038	 1	 6.15	 4.87	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53039	 1	 4.13	 3.48	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53040	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53041	 1	 7.12	 6.68	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53042	 1	 9.17	 8.09	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53043	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53044	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53045	 1	 7.56	 5.4	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53046	 1	 3.15	 2.46	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53047	 1	 2.76	 2.31	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53048	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53049	 1	 12.25	 9.75	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53050	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53051	 1	 6.97	 5.54	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53052	 1	 7.03	 4.74	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53053	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53054	 1	 11.08	 7.24	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53055	 1	 21.03	 13.78	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53056	 1	 3.72	 3.57	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53057	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53058	 1	 2.11	 2.04	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53059	 1	 5.02	 4.37	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53060	 1	 2.66	 2.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53061	 1	 6.28	 5.33	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53062	 1	 5.86	 5.17	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53063	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53064	 1	 2.01	 1.53	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53065	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53066	 1	 7.52	 6.5	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53067	 1	 2.38	 1.84	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53068	 1	 4.28	 4.06	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53069	 1	 2.02	 1.78	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53070	 1	 3.81	 2.77	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53071	 1	 6.45	 4.65	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53072	 1	 6.6	 5.83	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53073	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53074	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53075	 1	 6.42	 5.11	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53076	 1	 2.22	 0.53	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53077	 1	 28.0	 6.72	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53078	 1	 9.26	 2.22	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53079	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53080	 1	 7.68	 1.83	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53081	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53082	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53083	 1	 4.07	 0.98	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53084	 1	 2.91	 0.7	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53085	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53086	 1	 11.15	 2.66	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53087	 1	 5.24	 1.25	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53088	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53089	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53090	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53091	 1	 12.06	 2.88	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53092	 1	 7.66	 1.81	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53093	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53094	 1	 11.11	 2.67	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53095	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53096	 1	 13.02	 9.81	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53097	 1	 39.24	 17.41	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53098	 1	 27.75	 20.61	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53099	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53100	 1	 7.17	 5.83	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53101	 1	 2.44	 1.37	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53102	 1	 3.13	 1.83	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53103	 1	 5.13	 2.53	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53104	 1	 17.8	 8.22	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53105	 1	 3.89	 1.87	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53106	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53107	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53108	 1	 1.58	 -5.14	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53109	 1	 7.68	 -5.15	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53110	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53111	 1	 5.75	 3.12	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53112	 1	 20.96	 11.52	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53113	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53114	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53115	 1	 3.43	 2.17	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53116	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53117	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53118	 1	 20.39	 11.94	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53119	 1	 9.09	 3.88	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53120	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53121	 1	 4.24	 2.67	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53122	 1	 11.89	 5.49	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53123	 1	 8.59	 5.17	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53124	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53125	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53126	 1	 2.71	 1.8	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53127	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53128	 1	 2.75	 1.56	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53129	 1	 4.84	 3.1	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53130	 1	 6.16	 -1.5	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53131	 1	 4.42	 2.39	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53132	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53133	 1	 2.92	 1.45	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53134	 1	 4.61	 2.66	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53135	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53136	 1	 6.7	 4.32	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53137	 1	 4.32	 2.36	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53138	 1	 12.0	 6.39	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53139	 1	 3.86	 1.87	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53140	 1	 5.82	 3.42	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53141	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53142	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53143	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53144	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53145	 1	 4.41	 2.51	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53146	 1	 4.79	 2.4	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53147	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53148	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53149	 1	 5.55	 2.72	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53150	 1	 10.24	 3.76	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53151	 1	 7.74	 4.5	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53152	 1	 9.6	 4.68	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53153	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53154	 1	 4.14	 2.11	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53155	 1	 5.43	 2.72	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53156	 1	 2.44	 1.35	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53157	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53158	 1	 2.07	 1.24	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53159	 1	 1.95	 1.13	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53160	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53161	 1	 3.46	 1.82	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53162	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53163	 1	 2.72	 1.61	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53164	 1	 4.06	 -0.96	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53165	 1	 6.82	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53166	 1	 6.55	 4.01	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53167	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53168	 1	 3.93	 2.27	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53169	 1	 3.82	 2.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53170	 1	 3.28	 2.03	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53171	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53172	 1	 4.35	 2.5	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53173	 1	 9.36	 4.85	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53174	 1	 1.22	 0.8	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53175	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53176	 1	 10.49	 2.49	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53177	 1	 2.86	 1.81	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53178	 1	 6.78	 3.8	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53179	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53180	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53181	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53182	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53183	 1	 2.66	 1.54	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53184	 1	 1.83	 0.81	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53185	 1	 1.43	 0.75	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53186	 1	 6.43	 4.0	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53187	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53188	 1	 4.24	 2.04	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53189	 1	 2.98	 1.59	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53190	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53191	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53192	 1	 3.71	 2.02	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53193	 1	 19.41	 9.6	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53194	 1	 8.48	 4.01	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53195	 1	 0.0	 0.0	 0.0	 34.49	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53196	 1	 4.44	 2.5	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53197	 1	 7.48	 1.88	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53198	 1	 4.4	 1.1	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53199	 1	 6.92	 4.66	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53200	 1	 7.86	 1.88	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53201	 1	 5.6	 1.35	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53202	 1	 4.6	 1.1	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53203	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53204	 1	 0.53	 0.12	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53205	 1	 0.86	 0.21	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53206	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53207	 1	 1.8	 0.44	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53208	 1	 7.1	 1.73	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53209	 1	 8.47	 2.06	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53210	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53211	 1	 1.47	 0.88	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53212	 1	 2.72	 1.67	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53213	 1	 3.9	 1.83	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53214	 1	 2.83	 1.65	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53215	 1	 2.56	 1.56	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53216	 1	 7.88	 4.24	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53217	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53218	 1	 9.0	 5.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53219	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53220	 1	 6.2	 3.38	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53221	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53222	 1	 2.55	 1.54	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53223	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53224	 1	 34.12	 15.4	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53225	 1	 7.5	 4.26	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53226	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53227	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53228	 1	 2.62	 0.65	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53229	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53230	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53231	 1	 2.68	 0.66	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53232	 1	 11.96	 4.88	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53233	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53234	 1	 4.94	 1.22	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53235	 1	 8.91	 2.19	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53236	 1	 3.72	 2.11	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53237	 1	 13.67	 3.3	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53238	 1	 4.89	 1.18	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53239	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53240	 1	 5.4	 1.3	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53241	 1	 8.26	 1.99	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53242	 1	 2.76	 0.67	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53243	 1	 3.83	 0.93	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53244	 1	 9.19	 2.25	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53245	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53246	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53247	 1	 2.02	 0.49	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53248	 1	 6.35	 1.55	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53249	 1	 5.17	 1.26	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53250	 1	 3.7	 0.9	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53251	 1	 2.36	 0.58	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53252	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53253	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53254	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53255	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53256	 1	 12.83	 3.07	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53257	 1	 1.32	 0.32	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53258	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53259	 1	 1.23	 0.75	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53260	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53261	 1	 5.54	 1.35	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53262	 1	 1.33	 0.32	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53263	 1	 6.49	 1.59	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53264	 1	 3.54	 0.87	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53265	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53266	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53267	 1	 5.47	 3.42	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53268	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53269	 1	 2.66	 1.46	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53270	 1	 5.51	 3.49	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53271	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53272	 1	 3.98	 2.3	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53273	 1	 3.3	 1.86	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53274	 1	 4.66	 2.31	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53275	 1	 6.12	 3.76	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53276	 1	 4.24	 2.82	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53277	 1	 6.67	 3.45	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53278	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53279	 1	 8.11	 3.4	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53280	 1	 3.28	 2.21	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53281	 1	 5.3	 2.62	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53282	 1	 5.5	 2.79	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53283	 1	 4.05	 2.0	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53284	 1	 2.26	 1.3	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53285	 1	 3.81	 2.28	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53286	 1	 11.13	 6.06	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53287	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53288	 1	 0.58	 0.36	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53289	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53290	 1	 4.37	 2.37	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53291	 1	 4.22	 2.49	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53292	 1	 3.51	 1.7	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53293	 1	 6.52	 3.54	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53294	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53295	 1	 3.81	 2.32	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53296	 1	 2.38	 1.48	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53297	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53298	 1	 4.41	 -4.99	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53299	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53300	 1	 16.92	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53301	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53302	 1	 4.32	 2.82	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53303	 1	 2.34	 1.18	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53304	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53305	 1	 4.06	 2.25	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53306	 1	 5.06	 3.15	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53307	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53308	 1	 2.4	 1.24	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53309	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53310	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53311	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53312	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53313	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53314	 1	 8.94	 5.28	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53315	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53316	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53317	 1	 5.79	 1.39	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53318	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53319	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53320	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53321	 1	 3.61	 0.87	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53322	 1	 2.82	 1.92	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53323	 1	 8.98	 4.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53324	 1	 6.02	 3.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53325	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53326	 1	 9.32	 4.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53327	 1	 14.74	 5.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53328	 1	 3.28	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53329	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53330	 1	 15.17	 7.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53331	 1	 8.65	 3.7	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53332	 1	 17.59	 4.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53333	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53334	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53335	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53336	 1	 6.71	 3.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53337	 1	 4.49	 2.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53338	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53339	 1	 5.37	 1.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53340	 1	 26.58	 6.09	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53341	 1	 5.75	 1.33	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53342	 1	 10.92	 2.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53343	 1	 49.57	 11.43	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53344	 1	 33.94	 7.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53345	 1	 53.05	 12.15	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53346	 1	 18.22	 4.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53347	 1	 13.72	 3.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53348	 1	 7.27	 1.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53349	 1	 6.53	 1.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53350	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53351	 1	 27.08	 6.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53352	 1	 10.72	 2.48	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53353	 1	 4.52	 1.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53354	 1	 6.61	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53355	 1	 7.77	 4.58	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53356	 1	 2.48	 1.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53357	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53358	 1	 3.87	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53359	 1	 12.21	 5.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53360	 1	 5.64	 1.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53361	 1	 7.77	 3.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53362	 1	 9.6	 4.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53363	 1	 3.55	 1.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53364	 1	 11.86	 6.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53365	 1	 7.16	 3.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53366	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53367	 1	 4.87	 2.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53368	 1	 2.27	 1.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53369	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53370	 1	 4.32	 2.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53371	 1	 9.6	 4.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53372	 1	 4.05	 2.1	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53373	 1	 20.12	 8.6	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53374	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53375	 1	 4.75	 2.92	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53376	 1	 6.3	 3.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53377	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53378	 1	 20.54	 10.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53379	 1	 6.62	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53380	 1	 8.51	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53381	 1	 5.51	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53382	 1	 6.96	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53383	 1	 2.45	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53384	 1	 20.02	 7.94	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53385	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53386	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53387	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53388	 1	 15.33	 8.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53389	 1	 7.67	 4.05	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53390	 1	 6.46	 3.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53391	 1	 6.1	 2.96	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53392	 1	 7.11	 4.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53393	 1	 7.31	 4.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53394	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53395	 1	 4.48	 1.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53396	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53397	 1	 14.17	 6.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53398	 1	 7.53	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53399	 1	 1.98	 0.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53400	 1	 9.24	 2.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53401	 1	 2.73	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53402	 1	 14.48	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53403	 1	 6.28	 1.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53404	 1	 8.48	 1.96	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53405	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53406	 1	 87.29	 19.95	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53407	 1	 5.01	 1.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53408	 1	 4.92	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53409	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53410	 1	 3.67	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53411	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53412	 1	 10.34	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53413	 1	 5.05	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53414	 1	 11.25	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53415	 1	 8.35	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53416	 1	 4.99	 1.14	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53417	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53418	 1	 12.95	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53419	 1	 5.07	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53420	 1	 2.83	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53421	 1	 9.76	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53422	 1	 4.61	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53423	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53424	 1	 8.52	 1.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53425	 1	 2.47	 0.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53426	 1	 11.81	 2.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53427	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53428	 1	 6.43	 1.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53429	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53430	 1	 8.71	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53431	 1	 8.86	 2.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53432	 1	 5.54	 1.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53433	 1	 5.45	 1.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53434	 1	 4.34	 1.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53435	 1	 3.96	 0.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53436	 1	 9.63	 2.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53437	 1	 6.12	 1.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53438	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53439	 1	 4.34	 1.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53440	 1	 5.8	 3.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53441	 1	 7.98	 3.77	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53442	 1	 2.73	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53443	 1	 3.72	 1.98	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53444	 1	 14.11	 6.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53445	 1	 4.24	 0.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53446	 1	 3.51	 0.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53447	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53448	 1	 10.62	 6.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53449	 1	 6.08	 3.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53450	 1	 3.86	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53451	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53452	 1	 10.6	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53453	 1	 8.02	 3.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53454	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53455	 1	 2.65	 1.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53456	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53457	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53458	 1	 4.76	 1.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53459	 1	 7.86	 4.26	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53460	 1	 6.77	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53461	 1	 7.34	 3.51	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53462	 1	 3.66	 1.74	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53463	 1	 8.15	 1.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53464	 1	 0.31	 0.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53465	 1	 0.49	 0.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53466	 1	 0.67	 0.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53467	 1	 14.36	 3.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53468	 1	 3.83	 1.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53469	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53470	 1	 12.81	 2.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53471	 1	 5.97	 2.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53472	 1	 3.6	 1.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53473	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53474	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53475	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53476	 1	 12.63	 7.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53477	 1	 5.82	 3.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53478	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53479	 1	 6.58	 3.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53480	 1	 9.89	 4.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53481	 1	 11.78	 2.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53482	 1	 8.08	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53483	 1	 8.26	 4.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53484	 1	 3.05	 0.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53485	 1	 7.05	 3.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53486	 1	 20.72	 4.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53487	 1	 11.04	 2.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53488	 1	 6.17	 1.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53489	 1	 10.86	 2.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53490	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53491	 1	 6.08	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53492	 1	 10.14	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53493	 1	 5.06	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53494	 1	 6.89	 1.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53495	 1	 6.3	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53496	 1	 10.27	 2.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53497	 1	 3.96	 0.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53498	 1	 6.33	 1.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53499	 1	 17.37	 4.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53500	 1	 12.75	 6.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53501	 1	 6.8	 1.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53502	 1	 10.19	 4.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53503	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53504	 1	 5.51	 3.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53505	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53506	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53507	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53508	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53509	 1	 5.16	 2.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53510	 1	 5.67	 2.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53511	 1	 5.46	 2.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53512	 1	 5.67	 3.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53513	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53514	 1	 7.65	 4.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53515	 1	 3.24	 1.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53516	 1	 5.47	 3.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53517	 1	 6.07	 3.19	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53518	 1	 10.89	 5.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53519	 1	 24.11	 10.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53520	 1	 5.97	 3.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53521	 1	 8.28	 4.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53522	 1	 4.06	 0.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53523	 1	 7.26	 1.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53524	 1	 4.66	 1.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53525	 1	 6.1	 1.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53526	 1	 6.62	 3.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53527	 1	 2.89	 1.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53528	 1	 5.71	 1.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53529	 1	 8.88	 2.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53530	 1	 8.38	 1.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53531	 1	 8.17	 1.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53532	 1	 12.56	 2.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53533	 1	 3.11	 0.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53534	 1	 4.77	 2.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53535	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53536	 1	 1.73	 0.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53537	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53538	 1	 4.21	 2.17	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53539	 1	 3.92	 2.1	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53540	 1	 5.35	 2.41	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53541	 1	 5.88	 3.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53542	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53543	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53544	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53545	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53546	 1	 3.08	 1.63	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53547	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53548	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53549	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53550	 1	 4.24	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53551	 1	 3.78	 2.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53552	 1	 22.31	 11.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53553	 1	 3.86	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53554	 1	 22.72	 9.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53555	 1	 6.73	 3.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53556	 1	 3.14	 1.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53557	 1	 5.5	 3.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53558	 1	 6.68	 2.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53559	 1	 10.02	 5.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53560	 1	 5.7	 2.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53561	 1	 1.18	 0.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53562	 1	 1.83	 0.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53563	 1	 5.2	 3.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53564	 1	 4.33	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53565	 1	 16.32	 8.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53566	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53567	 1	 3.89	 2.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53568	 1	 28.22	 14.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53569	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53570	 1	 7.13	 2.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53571	 1	 3.65	 2.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53572	 1	 3.78	 2.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53573	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53574	 1	 2.93	 1.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53575	 1	 6.02	 2.95	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53576	 1	 5.79	 3.49	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53577	 1	 2.26	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53578	 1	 4.51	 2.62	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53579	 1	 7.06	 3.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53580	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53581	 1	 7.13	 3.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53582	 1	 11.88	 6.51	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53583	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53584	 1	 3.67	 2.19	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53585	 1	 6.36	 2.98	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53586	 1	 4.35	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53587	 1	 16.18	 8.52	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53588	 1	 32.5	 17.36	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53589	 1	 11.11	 5.27	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53590	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53591	 1	 4.98	 2.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53592	 1	 3.92	 2.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53593	 1	 5.99	 3.04	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53594	 1	 3.89	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53595	 1	 38.98	 19.58	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53596	 1	 6.08	 2.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53597	 1	 17.4	 8.45	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53598	 1	 8.52	 3.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53599	 1	 3.32	 1.92	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53600	 1	 7.52	 4.43	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53601	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53602	 1	 7.45	 3.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53603	 1	 3.11	 1.82	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53604	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53605	 1	 3.37	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53606	 1	 7.49	 3.78	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53607	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53608	 1	 18.93	 9.26	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53609	 1	 26.36	 9.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53610	 1	 11.53	 5.51	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53611	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53612	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53613	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53614	 1	 3.43	 1.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53615	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53616	 1	 17.21	 7.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53617	 1	 4.07	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53618	 1	 4.05	 1.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53619	 1	 4.83	 2.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53620	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53621	 1	 5.58	 2.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53622	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53623	 1	 7.46	 3.72	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53624	 1	 9.24	 3.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53625	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53626	 1	 13.04	 7.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53627	 1	 5.81	 3.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53628	 1	 4.78	 2.66	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53629	 1	 4.39	 2.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53630	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53631	 1	 7.89	 4.18	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53632	 1	 3.85	 1.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53633	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53634	 1	 6.23	 3.36	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53635	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53636	 1	 49.07	 24.43	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53637	 1	 1.32	 0.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53638	 1	 14.06	 6.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53639	 1	 2.89	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53640	 1	 6.75	 3.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53641	 1	 5.81	 2.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53642	 1	 4.13	 0.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53643	 1	 4.24	 2.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53644	 1	 5.47	 2.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53645	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53646	 1	 6.25	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53647	 1	 5.13	 1.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53648	 1	 5.19	 1.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53649	 1	 5.24	 1.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53650	 1	 4.81	 1.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53651	 1	 1.89	 0.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53652	 1	 4.6	 2.51	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53653	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53654	 1	 3.67	 2.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53655	 1	 4.66	 2.17	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53656	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53657	 1	 5.29	 2.89	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53658	 1	 5.19	 2.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53659	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53660	 1	 4.3	 2.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53661	 1	 5.11	 2.77	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53662	 1	 5.41	 2.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53663	 1	 7.56	 1.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53664	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53665	 1	 6.38	 3.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53666	 1	 6.92	 3.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53667	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53668	 1	 8.04	 4.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53669	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53670	 1	 5.26	 1.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53671	 1	 5.63	 1.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53672	 1	 2.25	 0.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53673	 1	 6.97	 1.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53674	 1	 8.33	 1.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53675	 1	 12.44	 2.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53676	 1	 5.6	 2.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53677	 1	 9.7	 2.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53678	 1	 5.94	 2.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53679	 1	 3.6	 0.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53680	 1	 11.03	 2.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53681	 1	 4.58	 1.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53682	 1	 12.81	 2.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53683	 1	 14.33	 6.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53684	 1	 6.43	 1.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53685	 1	 2.8	 0.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53686	 1	 3.48	 0.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53687	 1	 7.28	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53688	 1	 9.42	 2.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53689	 1	 5.63	 1.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53690	 1	 2.18	 0.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53691	 1	 7.97	 1.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53692	 1	 5.94	 1.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53693	 1	 5.9	 2.97	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53694	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53695	 1	 5.13	 1.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53696	 1	 4.36	 2.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53697	 1	 4.44	 2.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53698	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53699	 1	 1.92	 0.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53700	 1	 7.16	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53701	 1	 4.6	 1.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53702	 1	 10.85	 2.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53703	 1	 5.16	 2.9	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53704	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53705	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53706	 1	 10.6	 2.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53707	 1	 14.88	 3.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53708	 1	 6.59	 1.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53709	 1	 5.09	 1.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53710	 1	 13.63	 3.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53711	 1	 5.41	 1.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53712	 1	 4.47	 1.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53713	 1	 11.13	 2.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53714	 1	 12.22	 2.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53715	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53716	 1	 5.9	 1.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53717	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53718	 1	 7.8	 1.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53719	 1	 6.73	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53720	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53721	 1	 5.76	 1.33	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53722	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53723	 1	 16.99	 3.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53724	 1	 8.03	 1.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53725	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53726	 1	 8.17	 1.89	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53727	 1	 7.98	 1.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53728	 1	 4.11	 0.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53729	 1	 7.88	 1.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53730	 1	 6.63	 1.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53731	 1	 9.59	 2.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53732	 1	 5.14	 1.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53733	 1	 5.37	 1.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53734	 1	 3.96	 0.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53735	 1	 5.15	 1.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53736	 1	 4.87	 1.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53737	 1	 13.05	 2.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53738	 1	 8.02	 1.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53739	 1	 10.65	 2.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53740	 1	 4.47	 1.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53741	 1	 10.37	 2.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53742	 1	 5.07	 1.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53743	 1	 4.27	 0.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53744	 1	 7.11	 1.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53745	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53746	 1	 6.95	 1.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53747	 1	 4.32	 0.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53748	 1	 11.63	 2.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53749	 1	 8.72	 1.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53750	 1	 9.01	 2.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53751	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53752	 1	 2.99	 0.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53753	 1	 5.98	 1.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53754	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53755	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53756	 1	 3.48	 0.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53757	 1	 6.19	 1.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53758	 1	 4.14	 0.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53759	 1	 6.33	 1.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53760	 1	 3.34	 0.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53761	 1	 6.3	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53762	 1	 10.93	 2.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53763	 1	 8.94	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53764	 1	 8.63	 1.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53765	 1	 11.57	 2.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53766	 1	 5.56	 1.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53767	 1	 7.19	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53768	 1	 7.9	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53769	 1	 2.55	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53770	 1	 2.49	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53771	 1	 7.23	 1.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53772	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53773	 1	 10.24	 4.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53774	 1	 7.32	 3.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53775	 1	 4.73	 1.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53776	 1	 3.41	 1.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53777	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53778	 1	 3.72	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53779	 1	 3.07	 1.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53780	 1	 5.72	 2.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53781	 1	 5.66	 2.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53782	 1	 3.21	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53783	 1	 10.59	 2.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53784	 1	 6.75	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53785	 1	 7.66	 1.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53786	 1	 5.02	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53787	 1	 2.56	 1.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53788	 1	 7.59	 3.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53789	 1	 4.29	 0.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53790	 1	 3.46	 0.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53791	 1	 4.11	 0.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53792	 1	 6.77	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53793	 1	 4.67	 1.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53794	 1	 10.64	 2.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53795	 1	 10.54	 2.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53796	 1	 8.73	 1.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53797	 1	 5.29	 1.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53798	 1	 10.52	 2.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53799	 1	 10.11	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53800	 1	 4.71	 1.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53801	 1	 3.96	 0.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53802	 1	 9.3	 2.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53803	 1	 14.52	 3.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53804	 1	 2.38	 0.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53805	 1	 2.72	 0.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53806	 1	 5.11	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53807	 1	 8.24	 1.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53808	 1	 13.0	 2.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53809	 1	 6.87	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53810	 1	 11.07	 2.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53811	 1	 7.01	 1.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53812	 1	 5.24	 1.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53813	 1	 5.4	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53814	 1	 5.99	 1.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53815	 1	 5.63	 1.29	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53816	 1	 4.01	 0.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53817	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53818	 1	 6.49	 1.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53819	 1	 6.9	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53820	 1	 6.08	 1.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53821	 1	 25.01	 5.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53822	 1	 10.61	 5.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53823	 1	 11.45	 5.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53824	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53825	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53826	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53827	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53828	 1	 1.34	 0.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53829	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53830	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53831	 1	 0.02	 0.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53832	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53833	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53834	 1	 7.63	 3.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53835	 1	 0.63	 0.41	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53836	 1	 7.32	 4.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53837	 1	 2.52	 1.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53838	 1	 2.23	 1.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53839	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53840	 1	 4.96	 2.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53841	 1	 2.22	 1.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53842	 1	 2.9	 1.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53843	 1	 8.43	 1.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53844	 1	 27.05	 6.5	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53845	 1	 6.81	 1.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53846	 1	 3.25	 0.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53847	 1	 10.85	 2.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53848	 1	 12.3	 2.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53849	 1	 12.04	 2.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53850	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53851	 1	 11.61	 2.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53852	 1	 24.65	 5.92	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53853	 1	 7.8	 1.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53854	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53855	 1	 9.18	 2.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53856	 1	 2.41	 0.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53857	 1	 10.98	 6.2	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53858	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53859	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53860	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53861	 1	 4.46	 1.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53862	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53863	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53864	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53865	 1	 44.7	 20.92	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53866	 1	 16.23	 8.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53867	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53868	 1	 20.61	 9.49	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53869	 1	 14.02	 7.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53870	 1	 9.32	 4.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53871	 1	 8.49	 1.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53872	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53873	 1	 11.51	 6.17	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53874	 1	 9.18	 4.66	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53875	 1	 10.13	 5.45	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53876	 1	 8.49	 4.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53877	 1	 41.21	 12.45	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53878	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53879	 1	 5.39	 2.6	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53880	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53881	 1	 12.14	 4.57	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53882	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53883	 1	 6.48	 3.2	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53884	 1	 33.04	 18.36	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53885	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53886	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53887	 1	 12.85	 7.3	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53888	 1	 5.45	 2.81	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53889	 1	 9.32	 4.9	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53890	 1	 4.13	 2.55	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53891	 1	 3.62	 2.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53892	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53893	 1	 28.98	 13.42	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53894	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53895	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53896	 1	 22.78	 11.15	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53897	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53898	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53899	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53900	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53901	 1	 5.02	 2.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53902	 1	 4.93	 2.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53903	 1	 7.59	 4.16	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53904	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53905	 1	 19.34	 9.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53906	 1	 41.36	 15.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53907	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53908	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53909	 1	 87.19	 38.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53910	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53911	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53912	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53913	 1	 2.15	 1.41	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53914	 1	 9.56	 4.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53915	 1	 41.92	 16.45	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53916	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53917	 1	 7.52	 4.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53918	 1	 6.81	 4.13	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53919	 1	 6.85	 3.55	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53920	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53921	 1	 4.69	 2.68	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53922	 1	 10.37	 6.49	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53923	 1	 19.96	 8.55	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53924	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53925	 1	 8.5	 5.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53926	 1	 4.86	 2.87	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53927	 1	 3.97	 2.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53928	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53929	 1	 4.08	 2.54	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53930	 1	 5.52	 2.9	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53931	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53932	 1	 3.66	 2.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53933	 1	 3.39	 1.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53934	 1	 6.85	 3.98	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53935	 1	 3.25	 1.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53936	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53937	 1	 6.53	 3.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53938	 1	 2.34	 1.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53939	 1	 9.66	 5.03	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53940	 1	 5.14	 2.83	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53941	 1	 10.63	 6.42	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53942	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53943	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53944	 1	 5.81	 3.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53945	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53946	 1	 5.18	 2.95	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53947	 1	 3.79	 2.26	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53948	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53949	 1	 5.15	 2.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53950	 1	 2.08	 1.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53951	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53952	 1	 0.67	 0.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53953	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53954	 1	 2.52	 0.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53955	 1	 11.83	 2.74	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53956	 1	 2.93	 1.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53957	 1	 9.05	 5.13	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53958	 1	 7.91	 4.18	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53959	 1	 1.99	 1.03	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53960	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53961	 1	 3.44	 1.83	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53962	 1	 2.88	 1.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53963	 1	 4.96	 2.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53964	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53965	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53966	 1	 4.75	 2.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53967	 1	 5.97	 3.12	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53968	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53969	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53970	 1	 6.87	 3.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53971	 1	 3.07	 1.52	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53972	 1	 7.95	 4.45	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53973	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53974	 1	 7.23	 3.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53975	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53976	 1	 8.16	 4.25	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53977	 1	 4.18	 1.89	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53978	 1	 21.4	 7.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53979	 1	 5.91	 3.05	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53980	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53981	 1	 5.89	 3.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53982	 1	 22.55	 11.71	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53983	 1	 10.52	 5.72	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53984	 1	 7.9	 1.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53985	 1	 4.13	 0.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53986	 1	 9.66	 2.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53987	 1	 4.8	 1.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53988	 1	 4.9	 1.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53989	 1	 11.29	 2.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53990	 1	 4.83	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53991	 1	 17.54	 4.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	53992	 1	 6.84	 4.26	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53993	 1	 4.99	 2.64	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53994	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53995	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53996	 1	 121.95	 29.37	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53997	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	53998	 1	 6.32	 3.71	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53999	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54000	 1	 12.29	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54001	 1	 2.12	 1.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54002	 1	 14.63	 7.18	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54003	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54004	 1	 10.59	 4.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54005	 1	 5.71	 3.43	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54006	 1	 6.6	 3.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54007	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54008	 1	 11.85	 5.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54009	 1	 2.95	 1.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54010	 1	 4.57	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54011	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54012	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54013	 1	 4.6	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54014	 1	 2.88	 1.48	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54015	 1	 1.97	 1.12	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54016	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54017	 1	 7.29	 4.25	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54018	 1	 7.6	 4.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54019	 1	 8.0	 3.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54020	 1	 7.57	 3.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54021	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54022	 1	 8.55	 4.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54023	 1	 4.54	 2.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54024	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54025	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54026	 1	 2.67	 1.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54027	 1	 9.76	 5.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54028	 1	 6.0	 3.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54029	 1	 7.62	 3.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54030	 1	 5.75	 3.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54031	 1	 14.71	 6.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54032	 1	 4.95	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54033	 1	 9.58	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54034	 1	 9.37	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54035	 1	 7.91	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54036	 1	 5.16	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54037	 1	 19.78	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54038	 1	 9.34	 5.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54039	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54040	 1	 6.64	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54041	 1	 2.72	 1.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54042	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54043	 1	 5.96	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54044	 1	 9.83	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54045	 1	 10.42	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54046	 1	 5.46	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54047	 1	 40.54	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54048	 1	 6.47	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54049	 1	 6.58	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54050	 1	 10.49	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54051	 1	 4.56	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54052	 1	 3.62	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54053	 1	 6.32	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54054	 1	 6.26	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54055	 1	 9.01	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54056	 1	 2.88	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54057	 1	 2.52	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54058	 1	 3.62	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54059	 1	 3.55	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54060	 1	 4.33	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54061	 1	 4.6	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54062	 1	 5.2	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54063	 1	 2.88	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54064	 1	 2.19	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54065	 1	 3.48	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54066	 1	 3.31	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54067	 1	 12.22	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54068	 1	 10.95	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54069	 1	 4.05	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54070	 1	 3.27	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54071	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54072	 1	 4.58	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54073	 1	 4.56	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54074	 1	 4.09	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54075	 1	 4.42	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54076	 1	 4.61	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54077	 1	 4.16	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54078	 1	 2.94	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54079	 1	 12.11	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54080	 1	 16.53	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54081	 1	 20.04	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54082	 1	 15.02	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54083	 1	 11.29	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54084	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54085	 1	 4.47	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54086	 1	 5.75	 3.08	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54087	 1	 5.69	 3.65	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54088	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54089	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54090	 1	 32.82	 10.45	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54091	 1	 47.82	 19.14	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54092	 1	 3.4	 1.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54093	 1	 2.33	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54094	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54095	 1	 8.48	 3.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54096	 1	 9.9	 5.18	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54097	 1	 10.95	 5.44	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54098	 1	 1.25	 0.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54099	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54100	 1	 7.88	 3.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54101	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	54102	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54103	 1	 10.55	 5.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54104	 1	 9.21	 5.83	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54105	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	54106	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	54107	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54108	 1	 8.52	 4.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54109	 1	 12.94	 6.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54110	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54111	 1	 7.74	 4.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54112	 1	 9.02	 4.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54113	 1	 4.69	 2.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54114	 1	 4.33	 1.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54115	 1	 4.95	 2.48	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54116	 1	 11.03	 4.44	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54117	 1	 1.71	 0.85	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54118	 1	 4.42	 2.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54119	 1	 8.38	 4.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54120	 1	 6.71	 3.19	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54121	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54122	 1	 11.98	 6.72	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54123	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54124	 1	 2.32	 1.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54125	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54126	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54127	 1	 2.72	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54128	 1	 4.09	 2.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54129	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54130	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54131	 1	 2.22	 0.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54132	 1	 16.41	 3.95	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54133	 1	 4.51	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54134	 1	 2.67	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54135	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54136	 1	 5.76	 1.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54137	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54138	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54139	 1	 12.27	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54140	 1	 6.5	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54141	 1	 4.52	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54142	 1	 3.65	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54143	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54144	 1	 5.69	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54145	 1	 5.8	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54146	 1	 3.33	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54147	 1	 1.78	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54148	 1	 6.05	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54149	 1	 2.37	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54150	 1	 3.12	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54151	 1	 4.83	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54152	 1	 9.33	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54153	 1	 7.98	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54154	 1	 8.58	 1.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54155	 1	 6.26	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54156	 1	 5.11	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54157	 1	 5.81	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54158	 1	 1.67	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54159	 1	 2.12	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54160	 1	 4.4	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54161	 1	 3.15	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54162	 1	 4.46	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54163	 1	 8.74	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54164	 1	 4.57	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54165	 1	 6.45	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54166	 1	 9.83	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54167	 1	 3.7	 0.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54168	 1	 7.31	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54169	 1	 3.2	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54170	 1	 5.95	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54171	 1	 5.59	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54172	 1	 10.68	 2.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54173	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54174	 1	 2.97	 0.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54175	 1	 7.55	 1.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54176	 1	 14.31	 3.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54177	 1	 9.49	 2.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54178	 1	 4.55	 1.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54179	 1	 6.57	 1.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54180	 1	 77.6	 18.46	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54181	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54182	 1	 5.57	 1.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54183	 1	 6.1	 1.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54184	 1	 15.3	 3.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54185	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54186	 1	 7.95	 1.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54187	 1	 9.58	 2.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54188	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54189	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54190	 1	 14.22	 3.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54191	 1	 7.16	 1.72	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54192	 1	 13.04	 3.14	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54193	 1	 2.89	 0.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54194	 1	 17.18	 4.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54195	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	54196	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	54197	 1	 18.28	 4.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54198	 1	 17.26	 4.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54199	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54200	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54201	 1	 9.45	 2.27	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54202	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54203	 1	 5.16	 1.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54204	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54205	 1	 11.68	 2.78	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54206	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54207	 1	 5.34	 1.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54208	 1	 9.91	 2.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54209	 1	 8.28	 1.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54210	 1	 7.7	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54211	 1	 7.07	 1.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54212	 1	 14.19	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54213	 1	 12.37	 2.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54214	 1	 4.76	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54215	 1	 7.3	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54216	 1	 4.84	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54217	 1	 2.35	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54218	 1	 6.04	 1.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54219	 1	 4.26	 1.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54220	 1	 3.8	 0.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54221	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54222	 1	 5.05	 1.19	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54223	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54224	 1	 3.66	 0.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54225	 1	 3.27	 0.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54226	 1	 5.75	 1.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54227	 1	 8.53	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54228	 1	 8.2	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54229	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54230	 1	 5.98	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54231	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54232	 1	 6.56	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54233	 1	 4.58	 1.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54234	 1	 6.16	 1.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54235	 1	 3.81	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54236	 1	 6.2	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54237	 1	 3.67	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54238	 1	 9.29	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54239	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54240	 1	 8.52	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54241	 1	 10.79	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54242	 1	 4.05	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54243	 1	 6.96	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54244	 1	 7.24	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54245	 1	 1.74	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54246	 1	 10.32	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54247	 1	 1.83	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54248	 1	 4.21	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54249	 1	 7.78	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54250	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54251	 1	 3.62	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54252	 1	 3.93	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54253	 1	 7.46	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54254	 1	 2.93	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54255	 1	 7.12	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54256	 1	 8.46	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54257	 1	 4.37	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54258	 1	 5.24	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54259	 1	 6.6	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54260	 1	 4.97	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54261	 1	 2.51	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54262	 1	 2.36	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54263	 1	 3.38	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54264	 1	 4.45	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54265	 1	 2.04	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54266	 1	 4.35	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54267	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54268	 1	 8.42	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54269	 1	 15.32	 3.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54270	 1	 2.28	 0.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54271	 1	 12.99	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54272	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54273	 1	 8.34	 1.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54274	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54275	 1	 4.5	 1.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54276	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54277	 1	 8.15	 1.96	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54278	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	54279	 1	 4.11	 0.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54280	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54281	 1	 6.7	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54282	 1	 11.56	 5.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54283	 1	 5.15	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54284	 1	 11.08	 5.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54285	 1	 8.84	 4.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54286	 1	 9.45	 2.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54287	 1	 9.45	 4.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54288	 1	 3.46	 1.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54289	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	54290	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	54291	 1	 9.48	 4.13	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54292	 1	 8.23	 4.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54293	 1	 10.25	 3.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54294	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54295	 1	 5.85	 3.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54296	 1	 6.03	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54297	 1	 2.96	 0.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54298	 1	 7.14	 1.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54299	 1	 4.41	 0.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54300	 1	 5.96	 1.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54301	 1	 4.72	 1.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54302	 1	 7.26	 1.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54303	 1	 6.39	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54304	 1	 7.03	 1.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54305	 1	 11.31	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54306	 1	 17.36	 9.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54307	 1	 53.91	 25.68	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	54308	 1	 7.34	 3.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54309	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54310	 1	 18.73	 7.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54311	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54312	 1	 6.25	 3.02	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54313	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54314	 1	 2.66	 1.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54315	 1	 6.54	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54316	 1	 7.83	 1.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54317	 1	 8.93	 2.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54318	 1	 44.11	 10.09	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54319	 1	 16.28	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54320	 1	 7.78	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54321	 1	 7.79	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54322	 1	 10.84	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54323	 1	 7.57	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54324	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54325	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54326	 1	 8.71	 2.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54327	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54328	 1	 9.22	 3.66	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54329	 1	 5.04	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54330	 1	 5.18	 1.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54331	 1	 4.24	 0.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54332	 1	 2.92	 1.76	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54333	 1	 2.97	 0.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54334	 1	 4.63	 1.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54335	 1	 5.25	 1.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54336	 1	 4.79	 1.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54337	 1	 4.09	 0.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54338	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54339	 1	 5.97	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54340	 1	 2.62	 0.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54341	 1	 8.53	 1.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54342	 1	 0.7	 0.36	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54343	 1	 1.82	 1.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54344	 1	 12.59	 6.42	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54345	 1	 12.2	 5.76	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54346	 1	 4.21	 2.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54347	 1	 4.15	 2.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54348	 1	 1.46	 0.77	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54349	 1	 14.22	 -6.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54350	 1	 14.27	 8.2	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54351	 1	 9.2	 4.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54352	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54353	 1	 4.51	 1.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54354	 1	 4.71	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54355	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54356	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54357	 1	 5.75	 1.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54358	 1	 3.01	 0.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54359	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54360	 1	 5.8	 1.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54361	 1	 9.93	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54362	 1	 5.76	 1.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54363	 1	 3.79	 0.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54364	 1	 3.0	 0.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54365	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54366	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54367	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54368	 1	 5.02	 1.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54369	 1	 2.25	 0.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54370	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54371	 1	 3.65	 0.86	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54372	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54373	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54374	 1	 1.46	 0.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54375	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54376	 1	 2.57	 0.61	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54377	 1	 2.79	 0.66	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54378	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54379	 1	 9.31	 2.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54380	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54381	 1	 4.11	 0.98	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54382	 1	 7.15	 1.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54383	 1	 1.41	 0.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54384	 1	 6.81	 1.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54385	 1	 2.05	 0.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54386	 1	 4.02	 0.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54387	 1	 4.89	 1.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54388	 1	 17.89	 4.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54389	 1	 4.84	 1.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54390	 1	 10.72	 2.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54391	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54392	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54393	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54394	 1	 1.54	 0.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54395	 1	 6.8	 1.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54396	 1	 25.09	 5.92	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54397	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54398	 1	 2.26	 0.54	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54399	 1	 1.7	 0.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54400	 1	 1.84	 0.44	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54401	 1	 10.06	 2.38	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54402	 1	 12.15	 2.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54403	 1	 6.6	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54404	 1	 5.22	 1.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54405	 1	 21.1	 4.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54406	 1	 3.07	 0.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54407	 1	 9.28	 2.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54408	 1	 2.02	 0.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54409	 1	 6.16	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54410	 1	 6.17	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54411	 1	 4.29	 0.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54412	 1	 4.26	 0.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54413	 1	 2.84	 0.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54414	 1	 4.65	 1.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54415	 1	 7.49	 1.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54416	 1	 5.9	 1.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54417	 1	 4.45	 1.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54418	 1	 7.56	 1.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54419	 1	 5.01	 1.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54420	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54421	 1	 4.05	 0.95	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54422	 1	 4.01	 0.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54423	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54424	 1	 5.21	 1.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54425	 1	 6.2	 1.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54426	 1	 5.81	 1.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54427	 1	 9.43	 2.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54428	 1	 2.54	 0.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54429	 1	 5.6	 1.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54430	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54431	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54432	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54433	 1	 6.92	 1.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54434	 1	 3.74	 0.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54435	 1	 2.83	 0.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54436	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54437	 1	 21.91	 5.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54438	 1	 9.65	 2.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54439	 1	 6.45	 1.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54440	 1	 4.76	 1.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54441	 1	 3.22	 0.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54442	 1	 3.55	 0.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54443	 1	 5.83	 1.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54444	 1	 5.07	 1.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54445	 1	 3.74	 0.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54446	 1	 10.98	 2.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54447	 1	 8.42	 1.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54448	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54449	 1	 9.08	 2.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54450	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54451	 1	 3.19	 0.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54452	 1	 5.22	 1.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54453	 1	 7.28	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54454	 1	 3.0	 0.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54455	 1	 6.67	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54456	 1	 4.72	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54457	 1	 5.43	 1.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54458	 1	 1.4	 0.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54459	 1	 2.65	 0.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54460	 1	 6.03	 1.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54461	 1	 0.66	 0.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54462	 1	 2.33	 0.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54463	 1	 5.69	 1.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54464	 1	 3.77	 0.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54465	 1	 2.77	 0.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54466	 1	 5.37	 1.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54467	 1	 3.16	 0.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54468	 1	 3.09	 0.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54469	 1	 6.15	 1.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54470	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54471	 1	 4.34	 1.02	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54472	 1	 7.45	 1.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54473	 1	 7.35	 1.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54474	 1	 5.22	 1.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54475	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54476	 1	 6.88	 1.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54477	 1	 48.32	 11.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54478	 1	 3.71	 0.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54479	 1	 12.13	 2.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54480	 1	 3.22	 0.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54481	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54482	 1	 1.36	 0.32	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54483	 1	 2.73	 0.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54484	 1	 5.14	 1.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54485	 1	 10.55	 2.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54486	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54487	 1	 7.96	 1.91	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54488	 1	 3.83	 0.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54489	 1	 3.38	 0.81	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54490	 1	 4.46	 1.08	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54491	 1	 8.37	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54492	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54493	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54494	 1	 4.66	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54495	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54496	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54497	 1	 2.69	 0.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54498	 1	 2.22	 0.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54499	 1	 4.9	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54500	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54501	 1	 3.33	 0.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54502	 1	 3.41	 0.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54503	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54504	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54505	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54506	 1	 4.78	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54507	 1	 13.77	 3.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54508	 1	 4.02	 0.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54509	 1	 6.74	 1.59	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54510	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54511	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54512	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54513	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54514	 1	 4.83	 1.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54515	 1	 4.48	 1.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54516	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	54517	 1	 31.65	 7.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54518	 1	 20.55	 4.9	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54519	 1	 12.53	 2.98	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54520	 1	 3.01	 0.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54521	 1	 5.62	 1.36	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54522	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54523	 1	 6.86	 1.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54524	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54525	 1	 13.76	 3.29	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54526	 1	 8.81	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54527	 1	 42.05	 9.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54528	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54529	 1	 6.74	 1.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54530	 1	 3.51	 0.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54531	 1	 5.62	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54532	 1	 3.87	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54533	 1	 3.92	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54534	 1	 4.09	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54535	 1	 6.54	 1.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54536	 1	 6.03	 1.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54537	 1	 5.79	 1.37	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54538	 1	 5.94	 1.42	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54539	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54540	 1	 9.29	 2.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54541	 1	 6.9	 1.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54542	 1	 10.25	 2.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54543	 1	 10.24	 2.48	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54544	 1	 15.34	 3.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54545	 1	 7.09	 1.72	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54546	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54547	 1	 6.38	 1.52	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54548	 1	 5.21	 1.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54549	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	54550	 1	 3.4	 0.81	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54551	 1	 4.62	 1.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54552	 1	 5.68	 1.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54553	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54554	 1	 5.66	 1.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54555	 1	 8.2	 1.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54556	 1	 8.5	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54557	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54558	 1	 9.52	 2.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54559	 1	 1.92	 0.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54560	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54561	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54562	 1	 3.27	 0.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54563	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54564	 1	 4.94	 1.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54565	 1	 8.34	 1.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54566	 1	 5.64	 1.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54567	 1	 3.7	 0.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54568	 1	 3.92	 0.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54569	 1	 5.77	 1.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54570	 1	 8.69	 2.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54571	 1	 5.72	 1.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54572	 1	 3.79	 0.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54573	 1	 1.64	 0.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54574	 1	 1.88	 0.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54575	 1	 7.33	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54576	 1	 18.12	 4.27	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54577	 1	 1.96	 0.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54578	 1	 5.26	 1.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54579	 1	 2.43	 0.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54580	 1	 6.9	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54581	 1	 8.07	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54582	 1	 4.0	 0.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54583	 1	 3.51	 0.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54584	 1	 5.27	 1.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54585	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54586	 1	 2.9	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54587	 1	 8.0	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54588	 1	 16.57	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54589	 1	 6.38	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54590	 1	 3.24	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54591	 1	 5.97	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54592	 1	 5.29	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54593	 1	 4.09	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54594	 1	 4.08	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54595	 1	 6.19	 1.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54596	 1	 3.52	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54597	 1	 2.92	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54598	 1	 5.93	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54599	 1	 2.83	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54600	 1	 2.28	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54601	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54602	 1	 15.52	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54603	 1	 2.68	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54604	 1	 6.68	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54605	 1	 2.72	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54606	 1	 4.93	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54607	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54608	 1	 8.71	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54609	 1	 7.98	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54610	 1	 13.43	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54611	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54612	 1	 3.31	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54613	 1	 18.33	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54614	 1	 12.22	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54615	 1	 3.8	 0.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54616	 1	 3.33	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54617	 1	 45.06	 10.56	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54618	 1	 21.13	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54619	 1	 7.81	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54620	 1	 11.69	 2.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54621	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54622	 1	 52.68	 12.22	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54623	 1	 5.28	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54624	 1	 3.07	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54625	 1	 7.83	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54626	 1	 4.97	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54627	 1	 4.09	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54628	 1	 5.64	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54629	 1	 9.41	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54630	 1	 9.83	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54631	 1	 20.29	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54632	 1	 23.65	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54633	 1	 10.22	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54634	 1	 4.81	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54635	 1	 8.86	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54636	 1	 5.37	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54637	 1	 5.1	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54638	 1	 2.14	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54639	 1	 4.53	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54640	 1	 4.35	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54641	 1	 6.07	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54642	 1	 6.67	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54643	 1	 3.93	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54644	 1	 3.53	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54645	 1	 4.22	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54646	 1	 43.52	 10.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54647	 1	 2.09	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54648	 1	 4.83	 1.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54649	 1	 8.6	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54650	 1	 8.41	 1.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54651	 1	 5.2	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54652	 1	 10.11	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54653	 1	 6.67	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54654	 1	 5.09	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54655	 1	 6.45	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54656	 1	 11.52	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54657	 1	 6.95	 1.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54658	 1	 4.14	 0.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54659	 1	 8.83	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54660	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54661	 1	 5.23	 1.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54662	 1	 5.14	 1.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54663	 1	 5.2	 1.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54664	 1	 2.9	 0.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54665	 1	 17.36	 4.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54666	 1	 6.88	 1.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54667	 1	 9.63	 2.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54668	 1	 4.18	 0.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54669	 1	 2.22	 0.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54670	 1	 1.71	 0.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54671	 1	 5.91	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54672	 1	 12.4	 2.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54673	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54674	 1	 8.08	 1.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54675	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54676	 1	 4.03	 0.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54677	 1	 4.89	 1.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54678	 1	 7.52	 1.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54679	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54680	 1	 5.25	 1.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54681	 1	 6.29	 1.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54682	 1	 6.2	 1.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54683	 1	 2.97	 0.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54684	 1	 6.53	 1.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54685	 1	 9.14	 2.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54686	 1	 7.74	 1.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54687	 1	 10.34	 2.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54688	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	54689	 1	 32.13	 7.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54690	 1	 4.74	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54691	 1	 3.47	 0.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54692	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	54693	 1	 4.34	 1.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54694	 1	 8.22	 1.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54695	 1	 7.2	 1.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54696	 1	 2.0	 0.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54697	 1	 12.88	 3.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54698	 1	 5.13	 1.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54699	 1	 6.62	 1.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54700	 1	 12.05	 2.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54701	 1	 3.67	 0.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54702	 1	 6.39	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54703	 1	 8.82	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54704	 1	 6.65	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54705	 1	 7.73	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54706	 1	 13.16	 3.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54707	 1	 5.49	 1.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54708	 1	 12.23	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54709	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54710	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54711	 1	 7.33	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54712	 1	 6.77	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54713	 1	 13.14	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54714	 1	 5.52	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54715	 1	 3.58	 0.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54716	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54717	 1	 6.75	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54718	 1	 4.7	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54719	 1	 17.69	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54720	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54721	 1	 10.04	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54722	 1	 5.6	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54723	 1	 6.39	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54724	 1	 9.56	 2.22	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54725	 1	 18.1	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54726	 1	 3.67	 0.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54727	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54728	 1	 4.69	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54729	 1	 5.8	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54730	 1	 4.39	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54731	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54732	 1	 6.01	 1.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54733	 1	 3.83	 0.89	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54734	 1	 6.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54735	 1	 4.1	 0.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54736	 1	 11.41	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54737	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54738	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54739	 1	 27.16	 6.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54740	 1	 4.08	 0.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54741	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54742	 1	 7.38	 1.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54743	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54744	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54745	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54746	 1	 64.12	 15.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54747	 1	 20.28	 4.98	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54748	 1	 11.12	 2.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54749	 1	 8.59	 2.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54750	 1	 6.42	 1.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54751	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54752	 1	 10.5	 2.55	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54753	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54754	 1	 6.41	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54755	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54756	 1	 9.87	 2.44	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54757	 1	 9.8	 2.42	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54758	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54759	 1	 8.26	 2.03	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54760	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54761	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54762	 1	 3.29	 0.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54763	 1	 3.5	 0.86	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54764	 1	 5.17	 1.26	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54765	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54766	 1	 4.93	 1.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54767	 1	 11.6	 2.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54768	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54769	 1	 17.47	 4.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54770	 1	 7.99	 1.94	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54771	 1	 6.99	 1.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54772	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54773	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54774	 1	 4.72	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54775	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54776	 1	 8.58	 2.1	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54777	 1	 8.15	 1.98	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54778	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54779	 1	 4.56	 1.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54780	 1	 24.76	 6.12	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54781	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54782	 1	 5.76	 1.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54783	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54784	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54785	 1	 12.31	 2.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54786	 1	 5.56	 1.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54787	 1	 19.89	 4.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54788	 1	 11.4	 2.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54789	 1	 18.61	 4.55	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54790	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54791	 1	 3.81	 0.93	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54792	 1	 5.51	 1.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54793	 1	 5.82	 1.42	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54794	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54795	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54796	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54797	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54798	 1	 3.41	 0.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54799	 1	 8.0	 1.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54800	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54801	 1	 4.69	 1.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54802	 1	 10.02	 2.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54803	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54804	 1	 6.46	 1.6	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54805	 1	 3.25	 0.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54806	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54807	 1	 7.94	 1.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54808	 1	 4.5	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54809	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54810	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54811	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54812	 1	 4.28	 1.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54813	 1	 4.26	 1.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54814	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54815	 1	 5.78	 1.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54816	 1	 4.82	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54817	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54818	 1	 17.16	 4.14	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54819	 1	 8.09	 1.95	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54820	 1	 54.14	 13.1	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54821	 1	 5.15	 1.25	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54822	 1	 19.18	 4.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54823	 1	 6.53	 1.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54824	 1	 18.42	 4.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54825	 1	 9.73	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54826	 1	 4.36	 1.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54827	 1	 5.62	 1.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54828	 1	 8.51	 2.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54829	 1	 5.32	 1.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54830	 1	 8.63	 2.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54831	 1	 7.42	 1.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54832	 1	 5.41	 1.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54833	 1	 4.91	 1.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54834	 1	 9.02	 2.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54835	 1	 9.45	 2.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54836	 1	 4.98	 1.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54837	 1	 5.98	 1.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54838	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54839	 1	 4.13	 0.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54840	 1	 5.17	 1.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54841	 1	 5.26	 1.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54842	 1	 4.52	 1.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54843	 1	 5.77	 1.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54844	 1	 7.8	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54845	 1	 23.58	 5.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54846	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54847	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54848	 1	 2.87	 0.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54849	 1	 5.81	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54850	 1	 10.5	 2.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54851	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54852	 1	 6.76	 1.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54853	 1	 4.91	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54854	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54855	 1	 8.06	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54856	 1	 5.71	 1.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54857	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54858	 1	 5.57	 1.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54859	 1	 14.28	 3.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54860	 1	 3.65	 0.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54861	 1	 4.88	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54862	 1	 2.9	 0.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54863	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54864	 1	 5.93	 1.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54865	 1	 8.16	 1.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54866	 1	 7.64	 1.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54867	 1	 2.23	 0.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54868	 1	 2.02	 0.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54869	 1	 6.54	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54870	 1	 5.51	 1.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54871	 1	 10.17	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54872	 1	 59.42	 13.93	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54873	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54874	 1	 9.87	 2.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54875	 1	 43.61	 10.27	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54876	 1	 29.77	 6.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54877	 1	 2.43	 0.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54878	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54879	 1	 12.11	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54880	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	54881	 1	 8.14	 3.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54882	 1	 4.45	 2.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54883	 1	 4.8	 2.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54884	 1	 6.17	 3.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54885	 1	 7.79	 4.04	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54886	 1	 5.96	 3.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54887	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54888	 1	 39.38	 16.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54889	 1	 3.59	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54890	 1	 2.57	 1.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54891	 1	 12.72	 2.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54892	 1	 4.32	 1.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54893	 1	 6.35	 1.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54894	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54895	 1	 5.23	 1.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54896	 1	 9.17	 2.14	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54897	 1	 2.49	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54898	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54899	 1	 4.29	 1.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54900	 1	 3.85	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54901	 1	 9.49	 2.21	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54902	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54903	 1	 5.78	 1.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54904	 1	 13.8	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54905	 1	 7.76	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54906	 1	 8.31	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54907	 1	 3.45	 0.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54908	 1	 12.33	 2.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54909	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54910	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54911	 1	 13.77	 3.23	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54912	 1	 47.28	 11.25	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54913	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54914	 1	 3.71	 0.87	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54915	 1	 15.67	 3.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54916	 1	 9.66	 2.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54917	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54918	 1	 5.99	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54919	 1	 2.77	 0.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54920	 1	 7.4	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54921	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	54922	 1	 7.19	 1.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54923	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54924	 1	 5.9	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54925	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54926	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54927	 1	 10.49	 2.45	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54928	 1	 5.57	 1.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54929	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54930	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54931	 1	 4.33	 1.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54932	 1	 9.04	 2.12	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54933	 1	 16.54	 3.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54934	 1	 4.6	 2.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54935	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54936	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54937	 1	 15.61	 3.65	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54938	 1	 7.56	 1.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54939	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54940	 1	 7.39	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54941	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54942	 1	 18.57	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54943	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54944	 1	 4.56	 1.07	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54945	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54946	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54947	 1	 7.88	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54948	 1	 7.19	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54949	 1	 3.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54950	 1	 7.4	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54951	 1	 13.03	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54952	 1	 3.77	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54953	 1	 4.52	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54954	 1	 1.05	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54955	 1	 4.89	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54956	 1	 1.75	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54957	 1	 8.59	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54958	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54959	 1	 6.65	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54960	 1	 4.29	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54961	 1	 4.01	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54962	 1	 5.29	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54963	 1	 6.8	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54964	 1	 5.66	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54965	 1	 5.72	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54966	 1	 12.24	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54967	 1	 21.43	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54968	 1	 1.97	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54969	 1	 8.28	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54970	 1	 6.16	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54971	 1	 6.09	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54972	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54973	 1	 7.43	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54974	 1	 3.4	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54975	 1	 6.27	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54976	 1	 7.03	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54977	 1	 7.02	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54978	 1	 4.77	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54979	 1	 5.52	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54980	 1	 5.23	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54981	 1	 4.95	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54982	 1	 4.74	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54983	 1	 4.79	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54984	 1	 6.43	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54985	 1	 5.76	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54986	 1	 5.94	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54987	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54988	 1	 10.09	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54989	 1	 6.25	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54990	 1	 7.8	 1.82	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54991	 1	 8.08	 1.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54992	 1	 4.22	 0.98	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54993	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	54994	 1	 4.33	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54995	 1	 1.32	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54996	 1	 4.33	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54997	 1	 4.27	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54998	 1	 6.74	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	54999	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55000	 1	 3.13	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55001	 1	 3.53	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55002	 1	 3.92	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55003	 1	 3.72	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55004	 1	 2.44	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55005	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55006	 1	 2.74	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55007	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55008	 1	 2.33	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55009	 1	 4.23	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55010	 1	 5.33	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55011	 1	 6.37	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55012	 1	 5.04	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55013	 1	 1.86	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55014	 1	 7.15	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55015	 1	 5.2	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55016	 1	 3.31	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55017	 1	 5.5	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55018	 1	 4.55	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55019	 1	 8.76	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55020	 1	 4.35	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55021	 1	 3.26	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55022	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55023	 1	 4.83	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55024	 1	 4.74	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55025	 1	 5.36	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55026	 1	 4.69	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55027	 1	 4.89	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55028	 1	 6.85	 3.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55029	 1	 8.9	 4.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55030	 1	 9.83	 5.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55031	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55032	 1	 4.42	 1.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55033	 1	 4.42	 2.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55034	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55035	 1	 5.27	 2.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55036	 1	 3.03	 0.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55037	 1	 2.94	 0.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55038	 1	 5.58	 1.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55039	 1	 18.99	 4.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55040	 1	 15.19	 8.26	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55041	 1	 7.69	 4.22	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55042	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55043	 1	 15.04	 8.87	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55044	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55045	 1	 4.86	 2.54	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55046	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55047	 1	 12.02	 6.37	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55048	 1	 4.04	 2.62	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55049	 1	 5.4	 3.02	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55050	 1	 5.67	 3.7	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55051	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55052	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55053	 1	 6.28	 3.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55054	 1	 9.29	 5.56	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55055	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55056	 1	 7.89	 4.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55057	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55058	 1	 12.45	 6.76	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55059	 1	 8.62	 4.98	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55060	 1	 7.29	 3.86	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55061	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55062	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55063	 1	 20.32	 8.44	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55064	 1	 8.14	 4.26	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55065	 1	 3.73	 2.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55066	 1	 5.91	 3.23	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55067	 1	 9.69	 5.11	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55068	 1	 21.11	 10.29	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55069	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55070	 1	 14.67	 6.89	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55071	 1	 4.0	 2.45	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55072	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55073	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55074	 1	 6.48	 1.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55075	 1	 12.7	 3.07	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55076	 1	 10.49	 2.55	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55077	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55078	 1	 9.39	 2.2	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55079	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55080	 1	 4.13	 0.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55081	 1	 5.82	 1.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55082	 1	 1.48	 0.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55083	 1	 4.74	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55084	 1	 60.06	 14.12	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55085	 1	 44.1	 10.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55086	 1	 7.95	 1.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55087	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55088	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55089	 1	 8.23	 1.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55090	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55091	 1	 3.81	 0.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55092	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55093	 1	 18.06	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55094	 1	 6.88	 1.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55095	 1	 81.45	 19.22	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55096	 1	 5.97	 1.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55097	 1	 12.67	 2.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55098	 1	 8.25	 4.62	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55099	 1	 11.21	 2.69	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55100	 1	 27.49	 15.78	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55101	 1	 2.93	 1.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55102	 1	 11.93	 5.98	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55103	 1	 31.11	 7.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55104	 1	 67.62	 18.48	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55105	 1	 24.34	 9.61	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55106	 1	 10.38	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55107	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55108	 1	 5.73	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55109	 1	 3.81	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55110	 1	 3.82	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55111	 1	 8.21	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55112	 1	 3.56	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55113	 1	 4.54	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55114	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55115	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55116	 1	 6.4	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55117	 1	 4.7	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55118	 1	 6.79	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55119	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55120	 1	 7.72	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55121	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55122	 1	 4.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55123	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55124	 1	 6.5	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55125	 1	 8.52	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55126	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55127	 1	 3.52	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55128	 1	 3.8	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55129	 1	 12.51	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55130	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55131	 1	 4.99	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55132	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55133	 1	 5.42	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55134	 1	 4.78	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55135	 1	 10.63	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55136	 1	 6.27	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55137	 1	 5.23	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55138	 1	 7.26	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55139	 1	 5.12	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55140	 1	 9.12	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55141	 1	 4.21	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55142	 1	 10.26	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55143	 1	 20.32	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55144	 1	 6.81	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55145	 1	 13.79	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55146	 1	 5.8	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55147	 1	 4.53	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55148	 1	 1.69	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55149	 1	 6.44	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55150	 1	 5.65	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55151	 1	 12.03	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55152	 1	 7.01	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55153	 1	 6.82	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55154	 1	 5.14	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55155	 1	 7.25	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55156	 1	 8.35	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55157	 1	 11.16	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55158	 1	 11.51	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55159	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55160	 1	 5.14	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55161	 1	 5.92	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55162	 1	 10.52	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55163	 1	 7.85	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55164	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55165	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55166	 1	 17.93	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55167	 1	 0.0	 0.0	 0.0	 300.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55168	 1	 6.2	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55169	 1	 6.34	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55170	 1	 3.67	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55171	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55172	 1	 5.48	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55173	 1	 7.56	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55174	 1	 4.88	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55175	 1	 4.55	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55176	 1	 8.92	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55177	 1	 3.16	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55178	 1	 9.51	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55179	 1	 49.72	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55180	 1	 10.74	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55181	 1	 12.11	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55182	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55183	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55184	 1	 4.42	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55185	 1	 7.88	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55186	 1	 1.44	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55187	 1	 6.31	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55188	 1	 7.56	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55189	 1	 7.22	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55190	 1	 8.49	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55191	 1	 25.47	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55192	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55193	 1	 5.06	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55194	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55195	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55196	 1	 9.41	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55197	 1	 10.56	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55198	 1	 7.56	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55199	 1	 10.27	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55200	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55201	 1	 5.06	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55202	 1	 60.03	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55203	 1	 5.07	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55204	 1	 2.52	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55205	 1	 18.78	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55206	 1	 29.41	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55207	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55208	 1	 3.23	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55209	 1	 6.21	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55210	 1	 5.67	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55211	 1	 7.7	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55212	 1	 24.9	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55213	 1	 9.43	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55214	 1	 6.63	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55215	 1	 2.74	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55216	 1	 16.06	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55217	 1	 5.41	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55218	 1	 38.93	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55219	 1	 3.15	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55220	 1	 3.44	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55221	 1	 6.62	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55222	 1	 6.91	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55223	 1	 5.15	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55224	 1	 5.03	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55225	 1	 5.36	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55226	 1	 2.64	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55227	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55228	 1	 4.86	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55229	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55230	 1	 8.61	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55231	 1	 5.95	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55232	 1	 3.85	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55233	 1	 4.45	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55234	 1	 5.63	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55235	 1	 12.78	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55236	 1	 12.32	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55237	 1	 27.15	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55238	 1	 4.71	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55239	 1	 10.77	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55240	 1	 3.94	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55241	 1	 6.89	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55242	 1	 6.99	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55243	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55244	 1	 58.32	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55245	 1	 2.57	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55246	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55247	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55248	 1	 7.42	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55249	 1	 3.72	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55250	 1	 8.21	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55251	 1	 7.4	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55252	 1	 7.31	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55253	 1	 7.24	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55254	 1	 9.55	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55255	 1	 7.86	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55256	 1	 5.01	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55257	 1	 6.26	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55258	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55259	 1	 7.97	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55260	 1	 6.38	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55261	 1	 3.26	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55262	 1	 2.14	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55263	 1	 6.03	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55264	 1	 4.27	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55265	 1	 6.74	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55266	 1	 35.39	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55267	 1	 4.36	 2.6	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55268	 1	 9.53	 4.32	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55269	 1	 8.56	 4.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55270	 1	 8.12	 4.79	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55271	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55272	 1	 11.57	 6.73	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55273	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55274	 1	 3.13	 1.51	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55275	 1	 2.9	 0.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55276	 1	 4.67	 1.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55277	 1	 5.38	 1.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55278	 1	 4.9	 1.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55279	 1	 4.07	 0.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55280	 1	 5.28	 1.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55281	 1	 3.15	 1.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55282	 1	 3.39	 1.73	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55283	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55284	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55285	 1	 2.78	 1.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55286	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55287	 1	 7.08	 3.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55288	 1	 5.48	 2.65	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55289	 1	 4.7	 2.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55290	 1	 3.28	 1.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55291	 1	 7.46	 3.75	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55292	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55293	 1	 4.96	 2.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55294	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55295	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55296	 1	 2.3	 1.32	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55297	 1	 1.92	 1.14	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55298	 1	 5.84	 2.47	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55299	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55300	 1	 13.13	 7.8	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55301	 1	 2.66	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55302	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55303	 1	 3.34	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55304	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55305	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55306	 1	 5.66	 2.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55307	 1	 7.73	 3.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55308	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55309	 1	 2.38	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55310	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55311	 1	 16.79	 9.31	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55312	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55313	 1	 4.96	 2.59	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55314	 1	 5.68	 2.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55315	 1	 7.72	 3.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55316	 1	 15.16	 8.72	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55317	 1	 7.08	 3.62	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55318	 1	 4.75	 2.26	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55319	 1	 12.7	 7.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55320	 1	 9.85	 5.11	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55321	 1	 3.33	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55322	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55323	 1	 4.89	 2.44	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55324	 1	 11.87	 5.38	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55325	 1	 57.54	 21.45	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55326	 1	 11.46	 2.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55327	 1	 39.59	 14.33	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55328	 1	 10.47	 2.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55329	 1	 8.01	 4.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55330	 1	 33.37	 12.44	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55331	 1	 8.19	 1.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55332	 1	 10.45	 5.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55333	 1	 8.97	 2.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55334	 1	 7.36	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55335	 1	 10.13	 2.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55336	 1	 6.59	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55337	 1	 19.06	 9.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55338	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55339	 1	 9.64	 5.62	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55340	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55341	 1	 11.37	 2.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55342	 1	 10.2	 2.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55343	 1	 13.09	 3.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55344	 1	 39.47	 21.62	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55345	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55346	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55347	 1	 4.64	 1.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55348	 1	 18.09	 9.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55349	 1	 10.34	 5.92	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55350	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55351	 1	 2.18	 1.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55352	 1	 9.22	 5.22	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55353	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55354	 1	 8.96	 5.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55355	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55356	 1	 7.84	 4.23	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55357	 1	 5.87	 2.99	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55358	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55359	 1	 13.45	 7.63	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55360	 1	 8.19	 4.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55361	 1	 19.96	 9.29	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55362	 1	 6.39	 3.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55363	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55364	 1	 7.26	 3.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55365	 1	 9.24	 4.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55366	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55367	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55368	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55369	 1	 4.86	 2.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55370	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55371	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55372	 1	 9.05	 5.66	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55373	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55374	 1	 14.97	 8.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55375	 1	 20.13	 12.93	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55376	 1	 10.74	 5.38	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55377	 1	 18.99	 9.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55378	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55379	 1	 3.39	 2.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55380	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55381	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55382	 1	 1.55	 0.97	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55383	 1	 4.88	 2.9	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55384	 1	 9.18	 5.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55385	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55386	 1	 4.1	 1.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55387	 1	 3.74	 2.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55388	 1	 10.41	 5.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55389	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55390	 1	 8.97	 4.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55391	 1	 8.09	 4.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55392	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55393	 1	 9.1	 4.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55394	 1	 6.8	 3.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55395	 1	 5.74	 3.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55396	 1	 2.57	 1.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55397	 1	 8.59	 3.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55398	 1	 7.19	 3.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55399	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55400	 1	 11.43	 5.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55401	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55402	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55403	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55404	 1	 5.95	 3.08	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55405	 1	 8.42	 4.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55406	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55407	 1	 11.31	 5.26	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55408	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55409	 1	 4.09	 2.15	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55410	 1	 6.81	 2.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55411	 1	 11.68	 6.37	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55412	 1	 9.02	 4.63	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55413	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55414	 1	 13.86	 6.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55415	 1	 36.82	 15.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55416	 1	 63.74	 21.99	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55417	 1	 7.09	 4.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55418	 1	 4.67	 2.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55419	 1	 9.89	 5.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55420	 1	 6.43	 3.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55421	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55422	 1	 32.32	 16.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55423	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55424	 1	 4.52	 2.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55425	 1	 2.91	 1.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55426	 1	 5.95	 2.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55427	 1	 3.84	 1.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55428	 1	 6.33	 3.73	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55429	 1	 10.41	 5.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55430	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55431	 1	 1.0	 0.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55432	 1	 18.83	 8.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55433	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55434	 1	 2.14	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55435	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55436	 1	 7.35	 4.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55437	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55438	 1	 2.9	 1.79	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55439	 1	 4.93	 2.78	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55440	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55441	 1	 5.28	 3.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55442	 1	 1.51	 0.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55443	 1	 3.78	 1.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55444	 1	 1.89	 1.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55445	 1	 1.6	 1.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55446	 1	 2.22	 1.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55447	 1	 2.57	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55448	 1	 2.36	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55449	 1	 3.8	 1.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55450	 1	 2.54	 1.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55451	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55452	 1	 3.12	 1.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55453	 1	 4.4	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55454	 1	 2.19	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55455	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55456	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55457	 1	 1.55	 0.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55458	 1	 3.57	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55459	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55460	 1	 11.03	 5.49	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55461	 1	 6.13	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55462	 1	 7.27	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55463	 1	 9.36	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55464	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55465	 1	 5.63	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55466	 1	 6.9	 3.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55467	 1	 4.0	 2.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55468	 1	 5.13	 2.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55469	 1	 4.56	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55470	 1	 7.39	 1.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55471	 1	 9.95	 2.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55472	 1	 4.43	 1.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55473	 1	 5.27	 2.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55474	 1	 4.31	 2.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55475	 1	 91.89	 40.41	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55476	 1	 4.27	 2.21	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55477	 1	 7.49	 3.97	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55478	 1	 2.74	 1.47	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55479	 1	 4.17	 2.17	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55480	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55481	 1	 2.31	 1.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55482	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55483	 1	 8.62	 3.29	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55484	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55485	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55486	 1	 5.09	 2.73	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55487	 1	 6.91	 1.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55488	 1	 12.13	 4.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55489	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55490	 1	 1.62	 0.9	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55491	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55492	 1	 6.81	 3.08	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55493	 1	 7.2	 3.63	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55494	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55495	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55496	 1	 17.09	 7.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55497	 1	 18.22	 4.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55498	 1	 6.15	 3.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55499	 1	 6.36	 3.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55500	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55501	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55502	 1	 4.91	 2.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55503	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55504	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55505	 1	 5.85	 3.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55506	 1	 14.52	 3.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55507	 1	 17.67	 8.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55508	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55509	 1	 8.56	 5.02	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55510	 1	 3.37	 1.74	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55511	 1	 6.13	 3.15	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55512	 1	 5.37	 2.82	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55513	 1	 7.75	 3.79	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55514	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55515	 1	 7.03	 3.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55516	 1	 7.6	 4.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55517	 1	 81.26	 39.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55518	 1	 3.98	 1.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55519	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55520	 1	 3.99	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55521	 1	 8.94	 5.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55522	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55523	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55524	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55525	 1	 35.46	 14.76	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55526	 1	 5.79	 2.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55527	 1	 39.47	 18.97	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55528	 1	 37.46	 21.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55529	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55530	 1	 14.99	 7.94	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55531	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55532	 1	 7.9	 3.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55533	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55534	 1	 4.45	 2.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55535	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55536	 1	 9.85	 5.61	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55537	 1	 3.63	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55538	 1	 2.89	 1.47	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55539	 1	 11.7	 6.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55540	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55541	 1	 8.49	 4.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55542	 1	 7.42	 4.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55543	 1	 42.55	 14.46	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55544	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55545	 1	 3.04	 1.83	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55546	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55547	 1	 3.63	 1.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55548	 1	 1.96	 1.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55549	 1	 8.47	 5.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55550	 1	 4.55	 2.21	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55551	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55552	 1	 4.09	 2.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55553	 1	 4.6	 2.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55554	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55555	 1	 4.83	 2.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55556	 1	 6.31	 3.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55557	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55558	 1	 4.14	 2.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55559	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55560	 1	 4.44	 2.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55561	 1	 4.4	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55562	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55563	 1	 5.66	 3.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55564	 1	 6.5	 3.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55565	 1	 11.47	 4.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55566	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55567	 1	 4.53	 2.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55568	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55569	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55570	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55571	 1	 8.08	 4.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55572	 1	 10.55	 5.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55573	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55574	 1	 4.36	 2.12	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55575	 1	 2.42	 1.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55576	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55577	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55578	 1	 2.95	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55579	 1	 5.07	 2.77	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55580	 1	 4.57	 2.18	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55581	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55582	 1	 9.15	 4.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55583	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55584	 1	 8.82	 5.07	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55585	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55586	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55587	 1	 3.98	 1.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55588	 1	 4.4	 2.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55589	 1	 11.26	 6.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55590	 1	 3.59	 1.84	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55591	 1	 11.26	 4.47	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55592	 1	 9.49	 5.38	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55593	 1	 4.85	 2.81	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55594	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55595	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55596	 1	 10.83	 5.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55597	 1	 14.96	 3.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55598	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55599	 1	 7.93	 1.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55600	 1	 2.77	 1.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55601	 1	 55.96	 28.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55602	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55603	 1	 2.84	 1.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55604	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55605	 1	 2.8	 1.64	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55606	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55607	 1	 11.75	 2.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55608	 1	 33.79	 14.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55609	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55610	 1	 62.6	 29.15	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55611	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55612	 1	 16.66	 5.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55613	 1	 170.71	 68.45	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55614	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55615	 1	 3.9	 2.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55616	 1	 2.99	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55617	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55618	 1	 9.11	 4.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55619	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55620	 1	 4.85	 2.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55621	 1	 8.62	 4.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55622	 1	 6.75	 2.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55623	 1	 3.84	 2.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55624	 1	 5.93	 2.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55625	 1	 4.04	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55626	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55627	 1	 9.49	 4.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55628	 1	 9.92	 5.17	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55629	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55630	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55631	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55632	 1	 13.16	 4.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55633	 1	 5.48	 2.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55634	 1	 2.81	 1.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55635	 1	 7.56	 4.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55636	 1	 8.42	 3.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55637	 1	 5.75	 2.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55638	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55639	 1	 11.1	 4.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55640	 1	 3.83	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55641	 1	 11.99	 6.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55642	 1	 8.2	 4.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55643	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55644	 1	 31.7	 13.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55645	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55646	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55647	 1	 3.88	 2.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55648	 1	 3.93	 2.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55649	 1	 11.0	 5.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55650	 1	 4.36	 2.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55651	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55652	 1	 1.78	 1.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55653	 1	 3.67	 2.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55654	 1	 7.29	 3.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55655	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55656	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55657	 1	 2.77	 1.62	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55658	 1	 9.34	 5.5	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55659	 1	 9.52	 4.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55660	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55661	 1	 9.17	 4.13	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55662	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55663	 1	 2.35	 1.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55664	 1	 3.67	 2.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55665	 1	 3.12	 1.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55666	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55667	 1	 4.74	 2.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55668	 1	 42.45	 19.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55669	 1	 4.67	 1.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55670	 1	 7.14	 2.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55671	 1	 12.7	 2.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55672	 1	 14.76	 6.85	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55673	 1	 14.85	 8.7	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55674	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55675	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55676	 1	 4.11	 2.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55677	 1	 54.76	 28.37	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55678	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55679	 1	 8.46	 4.11	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55680	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55681	 1	 5.47	 2.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55682	 1	 11.0	 6.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55683	 1	 4.44	 2.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55684	 1	 5.22	 2.83	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55685	 1	 2.21	 1.34	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55686	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55687	 1	 8.27	 5.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55688	 1	 5.77	 3.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55689	 1	 8.5	 4.22	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55690	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55691	 1	 11.83	 4.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55692	 1	 17.8	 6.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55693	 1	 6.43	 2.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55694	 1	 86.16	 44.18	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55695	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55696	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55697	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55698	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55699	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55700	 1	 5.52	 2.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55701	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55702	 1	 15.28	 9.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55703	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55704	 1	 5.76	 3.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55705	 1	 5.53	 3.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55706	 1	 8.56	 1.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55707	 1	 14.62	 3.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55708	 1	 8.21	 1.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55709	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55710	 1	 12.16	 5.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55711	 1	 4.92	 2.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55712	 1	 8.85	 4.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55713	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55714	 1	 8.83	 2.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55715	 1	 30.65	 15.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55716	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55717	 1	 8.81	 2.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55718	 1	 20.35	 10.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55719	 1	 10.29	 5.9	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55720	 1	 13.65	 7.59	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55721	 1	 15.46	 9.26	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55722	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55723	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55724	 1	 10.66	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55725	 1	 8.86	 2.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55726	 1	 8.03	 1.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55727	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55728	 1	 3.41	 0.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55729	 1	 16.01	 3.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55730	 1	 7.19	 1.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55731	 1	 8.41	 1.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55732	 1	 2.41	 1.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55733	 1	 7.86	 1.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55734	 1	 4.75	 2.6	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55735	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55736	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55737	 1	 7.35	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55738	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55739	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55740	 1	 9.88	 5.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55741	 1	 5.05	 3.2	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55742	 1	 23.73	 12.28	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55743	 1	 44.73	 24.46	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55744	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55745	 1	 10.09	 5.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55746	 1	 29.14	 10.02	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55747	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55748	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55749	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55750	 1	 12.83	 6.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55751	 1	 10.45	 5.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55752	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55753	 1	 6.93	 3.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55754	 1	 44.62	 14.87	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55755	 1	 44.38	 26.01	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55756	 1	 20.85	 12.49	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55757	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55758	 1	 16.98	 9.29	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55759	 1	 10.3	 5.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55760	 1	 11.52	 6.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55761	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55762	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55763	 1	 4.22	 2.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55764	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55765	 1	 4.83	 2.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55766	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55767	 1	 4.89	 2.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55768	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55769	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55770	 1	 19.08	 9.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55771	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55772	 1	 13.03	 2.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55773	 1	 12.26	 2.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55774	 1	 29.15	 9.17	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55775	 1	 63.3	 19.8	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55776	 1	 10.28	 2.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55777	 1	 6.1	 1.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55778	 1	 19.49	 4.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55779	 1	 8.2	 1.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55780	 1	 35.44	 8.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55781	 1	 19.22	 4.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55782	 1	 7.74	 1.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55783	 1	 5.85	 1.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55784	 1	 79.39	 29.93	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55785	 1	 11.69	 5.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55786	 1	 6.14	 2.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55787	 1	 10.68	 2.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55788	 1	 10.07	 2.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55789	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55790	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55791	 1	 4.03	 0.93	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55792	 1	 3.04	 0.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55793	 1	 1.94	 0.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55794	 1	 2.85	 0.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55795	 1	 7.65	 1.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55796	 1	 10.15	 2.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55797	 1	 3.27	 0.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55798	 1	 3.31	 0.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55799	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55800	 1	 2.32	 0.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55801	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55802	 1	 5.09	 1.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55803	 1	 4.92	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55804	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55805	 1	 6.13	 1.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55806	 1	 16.12	 3.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55807	 1	 11.29	 2.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55808	 1	 7.73	 1.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55809	 1	 44.43	 15.6	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55810	 1	 4.74	 1.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55811	 1	 16.8	 3.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55812	 1	 6.93	 3.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55813	 1	 7.41	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55814	 1	 2.84	 1.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55815	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55816	 1	 117.29	 41.14	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55817	 1	 2.61	 1.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55818	 1	 5.15	 2.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55819	 1	 20.48	 9.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55820	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55821	 1	 7.97	 3.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55822	 1	 8.08	 3.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55823	 1	 16.75	 8.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55824	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55825	 1	 8.49	 4.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55826	 1	 7.59	 3.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55827	 1	 4.98	 2.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55828	 1	 4.62	 2.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55829	 1	 8.35	 4.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55830	 1	 4.98	 2.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55831	 1	 4.39	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55832	 1	 14.4	 6.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55833	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55834	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55835	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55836	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55837	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55838	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55839	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55840	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55841	 1	 4.3	 2.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55842	 1	 6.54	 3.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55843	 1	 5.81	 2.63	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55844	 1	 8.16	 3.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55845	 1	 7.14	 3.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55846	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55847	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55848	 1	 4.18	 2.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55849	 1	 5.85	 2.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55850	 1	 8.47	 4.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55851	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55852	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55853	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55854	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55855	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55856	 1	 7.81	 3.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55857	 1	 7.75	 4.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55858	 1	 6.8	 3.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55859	 1	 6.85	 1.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55860	 1	 6.04	 2.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55861	 1	 4.41	 2.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55862	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55863	 1	 8.01	 5.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55864	 1	 56.55	 24.63	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55865	 1	 18.0	 9.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55866	 1	 5.37	 1.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55867	 1	 3.76	 0.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55868	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55869	 1	 2.82	 1.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55870	 1	 10.23	 4.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55871	 1	 6.71	 3.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55872	 1	 23.62	 7.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55873	 1	 8.82	 2.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55874	 1	 4.31	 0.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55875	 1	 3.32	 0.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55876	 1	 6.52	 1.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55877	 1	 3.49	 0.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55878	 1	 23.09	 5.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55879	 1	 3.21	 0.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55880	 1	 4.89	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55881	 1	 3.88	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55882	 1	 15.41	 3.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55883	 1	 48.62	 11.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55884	 1	 8.22	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55885	 1	 8.16	 3.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55886	 1	 7.78	 1.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55887	 1	 4.62	 2.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55888	 1	 4.93	 2.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55889	 1	 7.2	 3.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55890	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55891	 1	 10.17	 4.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55892	 1	 5.78	 3.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55893	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55894	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55895	 1	 11.45	 5.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55896	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55897	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55898	 1	 5.08	 2.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55899	 1	 6.57	 3.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55900	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55901	 1	 8.34	 3.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55902	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55903	 1	 5.62	 3.11	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55904	 1	 5.99	 3.51	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55905	 1	 4.23	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55906	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55907	 1	 2.01	 0.94	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55908	 1	 6.29	 3.37	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55909	 1	 3.15	 1.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55910	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55911	 1	 7.34	 3.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55912	 1	 8.18	 3.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55913	 1	 7.87	 3.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55914	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55915	 1	 7.76	 4.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55916	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55917	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55918	 1	 64.64	 32.7	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55919	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55920	 1	 8.38	 4.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55921	 1	 5.19	 2.87	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55922	 1	 148.05	 76.33	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55923	 1	 2.43	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55924	 1	 1.82	 0.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55925	 1	 7.09	 3.52	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55926	 1	 3.37	 1.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55927	 1	 6.83	 3.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55928	 1	 8.34	 4.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55929	 1	 8.7	 4.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55930	 1	 10.62	 4.93	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55931	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55932	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55933	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55934	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55935	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55936	 1	 6.24	 3.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55937	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55938	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55939	 1	 7.97	 4.21	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	55940	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55941	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	55942	 1	 19.47	 4.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55943	 1	 9.3	 5.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55944	 1	 6.5	 1.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55945	 1	 6.77	 3.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55946	 1	 9.44	 4.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55947	 1	 8.73	 3.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55948	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55949	 1	 2.58	 1.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55950	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55951	 1	 9.67	 5.13	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55952	 1	 5.75	 3.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55953	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55954	 1	 5.88	 1.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55955	 1	 5.93	 1.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55956	 1	 4.2	 0.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55957	 1	 4.49	 1.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55958	 1	 7.5	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55959	 1	 6.94	 1.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55960	 1	 4.09	 0.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55961	 1	 4.44	 1.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55962	 1	 4.99	 1.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55963	 1	 15.83	 3.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55964	 1	 4.41	 1.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55965	 1	 2.79	 0.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55966	 1	 5.5	 1.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55967	 1	 8.43	 1.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55968	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55969	 1	 8.53	 1.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55970	 1	 4.96	 1.14	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55971	 1	 9.77	 2.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55972	 1	 14.89	 3.42	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55973	 1	 4.13	 0.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55974	 1	 8.84	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55975	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55976	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55977	 1	 7.78	 1.8	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55978	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55979	 1	 3.37	 0.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55980	 1	 4.36	 1.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55981	 1	 6.39	 1.47	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55982	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55983	 1	 5.51	 1.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55984	 1	 4.42	 1.02	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55985	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55986	 1	 3.26	 0.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55987	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55988	 1	 9.15	 4.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55989	 1	 3.69	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55990	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55991	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55992	 1	 4.02	 2.02	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55993	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55994	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55995	 1	 3.1	 1.49	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55996	 1	 3.82	 0.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	55997	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55998	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	55999	 1	 8.01	 1.84	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56000	 1	 9.55	 2.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56001	 1	 5.01	 1.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56002	 1	 7.11	 1.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56003	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56004	 1	 4.92	 1.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56005	 1	 3.4	 0.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56006	 1	 5.65	 1.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56007	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56008	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56009	 1	 5.84	 1.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56010	 1	 5.28	 1.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56011	 1	 3.66	 1.92	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56012	 1	 3.34	 1.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56013	 1	 7.57	 3.82	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56014	 1	 7.51	 1.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56015	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56016	 1	 2.32	 0.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56017	 1	 4.86	 1.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56018	 1	 6.0	 1.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56019	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56020	 1	 6.97	 1.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56021	 1	 5.69	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56022	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56023	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56024	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56025	 1	 4.63	 1.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56026	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56027	 1	 4.2	 2.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56028	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56029	 1	 3.99	 0.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56030	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56031	 1	 7.1	 1.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56032	 1	 6.83	 3.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56033	 1	 1.9	 0.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56034	 1	 7.22	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56035	 1	 8.85	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56036	 1	 1.36	 0.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56037	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56038	 1	 4.42	 1.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56039	 1	 4.87	 1.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56040	 1	 3.58	 0.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56041	 1	 5.25	 1.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56042	 1	 10.32	 2.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56043	 1	 6.03	 1.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56044	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56045	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56046	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56047	 1	 4.68	 1.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56048	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56049	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56050	 1	 5.89	 1.36	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56051	 1	 2.65	 0.61	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56052	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56053	 1	 10.18	 2.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56054	 1	 6.11	 1.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56055	 1	 4.65	 1.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56056	 1	 7.88	 1.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56057	 1	 7.62	 1.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56058	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56059	 1	 5.41	 1.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56060	 1	 6.1	 1.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56061	 1	 5.01	 1.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56062	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56063	 1	 7.01	 1.62	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56064	 1	 7.78	 1.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56065	 1	 8.29	 1.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56066	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56067	 1	 6.98	 1.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56068	 1	 8.96	 2.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56069	 1	 9.38	 2.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56070	 1	 8.43	 1.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56071	 1	 8.89	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56072	 1	 6.23	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56073	 1	 4.42	 1.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56074	 1	 12.08	 2.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56075	 1	 6.13	 1.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56076	 1	 5.74	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56077	 1	 4.19	 0.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56078	 1	 5.05	 1.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56079	 1	 5.29	 1.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56080	 1	 6.8	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56081	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56082	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56083	 1	 8.03	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56084	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56085	 1	 11.69	 6.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56086	 1	 1.73	 0.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56087	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56088	 1	 8.94	 2.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56089	 1	 8.8	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56090	 1	 5.39	 1.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56091	 1	 6.6	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56092	 1	 9.39	 2.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56093	 1	 2.14	 1.1	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56094	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56095	 1	 4.08	 0.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56096	 1	 6.59	 1.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56097	 1	 7.05	 1.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56098	 1	 6.95	 1.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56099	 1	 3.65	 0.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56100	 1	 9.47	 2.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56101	 1	 3.29	 0.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56102	 1	 7.5	 1.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56103	 1	 4.13	 0.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56104	 1	 9.31	 2.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56105	 1	 6.82	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56106	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56107	 1	 6.04	 1.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56108	 1	 5.02	 1.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56109	 1	 7.99	 4.82	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56110	 1	 3.1	 1.85	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56111	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56112	 1	 15.05	 3.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56113	 1	 6.15	 1.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56114	 1	 12.3	 2.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56115	 1	 5.98	 1.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56116	 1	 11.44	 2.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56117	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56118	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56119	 1	 10.6	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56120	 1	 5.48	 1.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56121	 1	 7.55	 1.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56122	 1	 5.0	 1.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56123	 1	 9.43	 2.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56124	 1	 4.23	 0.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56125	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56126	 1	 18.4	 9.96	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56127	 1	 3.09	 0.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56128	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56129	 1	 3.09	 0.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56130	 1	 7.77	 1.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56131	 1	 4.65	 1.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56132	 1	 3.76	 0.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56133	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56134	 1	 8.76	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56135	 1	 3.63	 0.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56136	 1	 12.7	 2.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56137	 1	 9.6	 4.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56138	 1	 3.44	 1.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56139	 1	 4.25	 2.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56140	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56141	 1	 7.75	 3.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56142	 1	 8.94	 2.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56143	 1	 13.14	 3.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56144	 1	 2.86	 0.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56145	 1	 7.05	 1.64	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56146	 1	 8.68	 2.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56147	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56148	 1	 13.34	 3.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56149	 1	 3.47	 0.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56150	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56151	 1	 3.19	 1.63	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56152	 1	 7.09	 1.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56153	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56154	 1	 5.24	 2.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56155	 1	 26.59	 6.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56156	 1	 6.89	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56157	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56158	 1	 4.13	 0.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56159	 1	 9.58	 2.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56160	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56161	 1	 9.99	 2.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56162	 1	 49.7	 15.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56163	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56164	 1	 7.28	 1.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56165	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56166	 1	 5.37	 1.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56167	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56168	 1	 4.25	 0.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56169	 1	 2.96	 0.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56170	 1	 13.83	 3.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56171	 1	 8.24	 1.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56172	 1	 17.06	 3.94	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56173	 1	 11.01	 2.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56174	 1	 5.73	 1.32	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56175	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56176	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56177	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56178	 1	 7.83	 1.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56179	 1	 7.36	 1.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56180	 1	 2.75	 0.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56181	 1	 2.48	 0.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56182	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56183	 1	 7.36	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56184	 1	 8.44	 3.89	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56185	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56186	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56187	 1	 21.55	 5.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56188	 1	 23.72	 5.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56189	 1	 6.79	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56190	 1	 7.67	 3.32	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56191	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56192	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56193	 1	 4.28	 0.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56194	 1	 9.75	 2.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56195	 1	 9.92	 2.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56196	 1	 10.92	 2.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56197	 1	 11.23	 2.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56198	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56199	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56200	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56201	 1	 2.71	 0.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56202	 1	 9.95	 2.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56203	 1	 6.04	 1.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56204	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56205	 1	 12.13	 2.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56206	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56207	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56208	 1	 5.59	 1.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56209	 1	 4.49	 1.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56210	 1	 3.12	 0.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56211	 1	 9.05	 2.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56212	 1	 2.03	 0.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56213	 1	 4.95	 1.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56214	 1	 4.7	 1.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56215	 1	 6.88	 1.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56216	 1	 2.32	 0.54	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56217	 1	 18.06	 6.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56218	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56219	 1	 3.67	 0.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56220	 1	 7.2	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56221	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56222	 1	 24.63	 12.73	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56223	 1	 10.07	 5.12	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56224	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56225	 1	 8.13	 4.22	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56226	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56227	 1	 5.43	 3.18	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56228	 1	 2.0	 0.96	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56229	 1	 5.95	 1.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56230	 1	 2.22	 0.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56231	 1	 7.71	 1.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56232	 1	 3.18	 0.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56233	 1	 6.48	 1.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56234	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56235	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56236	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56237	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56238	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56239	 1	 13.69	 7.09	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56240	 1	 7.11	 4.21	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56241	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56242	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56243	 1	 13.55	 7.33	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56244	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56245	 1	 2.98	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56246	 1	 55.72	 18.1	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56247	 1	 9.83	 2.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56248	 1	 12.11	 2.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56249	 1	 17.14	 3.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56250	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56251	 1	 9.41	 2.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56252	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56253	 1	 5.18	 1.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56254	 1	 3.23	 0.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56255	 1	 8.23	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56256	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56257	 1	 78.95	 18.28	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56258	 1	 2.47	 0.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56259	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56260	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56261	 1	 44.81	 10.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56262	 1	 13.44	 3.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56263	 1	 7.46	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56264	 1	 10.36	 2.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56265	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56266	 1	 3.65	 0.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56267	 1	 14.84	 3.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56268	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56269	 1	 6.11	 1.42	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56270	 1	 5.38	 1.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56271	 1	 12.05	 2.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56272	 1	 33.34	 7.76	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56273	 1	 9.02	 2.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56274	 1	 9.25	 2.15	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56275	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56276	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56277	 1	 15.44	 3.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56278	 1	 17.13	 10.3	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56279	 1	 17.21	 3.99	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56280	 1	 9.06	 2.1	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56281	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56282	 1	 3.81	 0.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56283	 1	 8.59	 4.44	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56284	 1	 13.4	 5.54	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56285	 1	 7.39	 4.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56286	 1	 12.49	 6.87	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56287	 1	 8.31	 4.12	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56288	 1	 14.44	 6.98	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56289	 1	 16.37	 3.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56290	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56291	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56292	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56293	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56294	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56295	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56296	 1	 16.64	 3.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56297	 1	 12.68	 6.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56298	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56299	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56300	 1	 3.65	 2.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56301	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56302	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56303	 1	 4.1	 2.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56304	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56305	 1	 3.33	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56306	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56307	 1	 9.0	 4.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56308	 1	 4.11	 2.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56309	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56310	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56311	 1	 8.86	 2.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56312	 1	 13.15	 3.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56313	 1	 4.64	 1.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56314	 1	 8.6	 1.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56315	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56316	 1	 8.48	 1.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56317	 1	 13.37	 3.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56318	 1	 8.9	 2.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56319	 1	 3.84	 0.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56320	 1	 6.52	 1.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56321	 1	 4.59	 1.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56322	 1	 10.43	 2.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56323	 1	 4.92	 1.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56324	 1	 6.24	 1.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56325	 1	 9.86	 2.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56326	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56327	 1	 7.95	 3.89	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56328	 1	 6.9	 3.3	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56329	 1	 8.99	 2.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56330	 1	 13.07	 3.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56331	 1	 10.05	 2.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56332	 1	 5.65	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56333	 1	 5.51	 1.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56334	 1	 7.07	 1.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56335	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56336	 1	 8.22	 1.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56337	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56338	 1	 7.48	 4.11	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56339	 1	 12.41	 7.04	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56340	 1	 7.29	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56341	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56342	 1	 4.25	 0.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56343	 1	 2.45	 1.19	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56344	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56345	 1	 10.66	 2.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56346	 1	 4.26	 1.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56347	 1	 5.59	 1.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56348	 1	 1.23	 0.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56349	 1	 12.63	 2.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56350	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56351	 1	 11.51	 4.42	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56352	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56353	 1	 15.33	 7.83	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56354	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56355	 1	 8.92	 4.81	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56356	 1	 6.81	 1.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56357	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56358	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56359	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56360	 1	 16.79	 3.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56361	 1	 27.25	 6.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56362	 1	 9.61	 2.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56363	 1	 11.28	 5.03	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56364	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56365	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56366	 1	 9.05	 4.74	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56367	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56368	 1	 1.28	 0.75	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56369	 1	 9.77	 4.67	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56370	 1	 5.04	 2.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56371	 1	 5.62	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56372	 1	 13.88	 3.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56373	 1	 9.29	 4.58	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56374	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56375	 1	 4.81	 1.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56376	 1	 6.97	 4.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56377	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56378	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56379	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56380	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56381	 1	 75.57	 17.76	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56382	 1	 5.21	 3.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56383	 1	 36.03	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56384	 1	 8.43	 4.8	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56385	 1	 19.47	 9.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56386	 1	 20.48	 7.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56387	 1	 15.37	 7.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56388	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56389	 1	 9.55	 5.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56390	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56391	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56392	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56393	 1	 6.48	 3.48	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56394	 1	 8.36	 4.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56395	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56396	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56397	 1	 3.24	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56398	 1	 4.9	 2.64	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56399	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56400	 1	 7.81	 4.38	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56401	 1	 12.23	 4.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56402	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56403	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56404	 1	 19.42	 8.29	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56405	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56406	 1	 7.81	 3.96	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56407	 1	 3.29	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56408	 1	 5.43	 1.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56409	 1	 9.7	 2.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56410	 1	 7.34	 1.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56411	 1	 6.6	 1.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56412	 1	 3.95	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56413	 1	 7.44	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56414	 1	 5.54	 1.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56415	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56416	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56417	 1	 7.89	 4.46	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56418	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56419	 1	 11.05	 5.74	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56420	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56421	 1	 5.12	 2.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56422	 1	 10.19	 5.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56423	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56424	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56425	 1	 6.19	 3.62	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56426	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56427	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56428	 1	 3.57	 2.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56429	 1	 4.56	 2.87	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56430	 1	 6.6	 3.22	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56431	 1	 5.49	 3.04	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56432	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56433	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56434	 1	 2.73	 1.48	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56435	 1	 2.61	 1.62	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56436	 1	 12.25	 5.96	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56437	 1	 9.74	 4.99	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56438	 1	 8.79	 5.09	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56439	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56440	 1	 10.13	 2.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56441	 1	 6.57	 3.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56442	 1	 10.7	 6.5	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56443	 1	 7.94	 3.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56444	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56445	 1	 8.74	 4.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56446	 1	 6.25	 3.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56447	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56448	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56449	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56450	 1	 4.91	 3.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56451	 1	 10.24	 6.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56452	 1	 8.86	 3.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56453	 1	 44.02	 23.74	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56454	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56455	 1	 2.83	 1.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56456	 1	 11.82	 6.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56457	 1	 11.11	 6.58	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56458	 1	 9.16	 5.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56459	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56460	 1	 4.23	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56461	 1	 9.22	 5.18	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56462	 1	 15.24	 9.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56463	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56464	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56465	 1	 8.41	 4.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56466	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56467	 1	 6.88	 4.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56468	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56469	 1	 5.1	 2.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56470	 1	 8.1	 3.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56471	 1	 10.01	 5.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56472	 1	 16.47	 7.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56473	 1	 14.91	 8.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56474	 1	 6.66	 3.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56475	 1	 7.86	 3.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56476	 1	 8.96	 5.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56477	 1	 5.51	 2.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56478	 1	 10.25	 4.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56479	 1	 4.68	 2.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56480	 1	 5.22	 2.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56481	 1	 15.59	 7.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56482	 1	 13.45	 7.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56483	 1	 6.25	 3.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56484	 1	 5.29	 3.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56485	 1	 8.95	 4.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56486	 1	 8.81	 4.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56487	 1	 10.65	 5.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56488	 1	 6.71	 2.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56489	 1	 4.72	 2.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56490	 1	 11.75	 6.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56491	 1	 6.65	 3.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56492	 1	 8.78	 4.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56493	 1	 6.79	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56494	 1	 11.62	 2.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56495	 1	 4.28	 0.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56496	 1	 6.43	 1.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56497	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56498	 1	 4.66	 1.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56499	 1	 4.68	 1.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56500	 1	 10.59	 2.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56501	 1	 12.03	 2.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56502	 1	 6.0	 3.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56503	 1	 7.04	 3.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56504	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56505	 1	 3.05	 0.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56506	 1	 6.5	 1.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56507	 1	 5.4	 1.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56508	 1	 10.84	 2.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56509	 1	 4.42	 1.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56510	 1	 8.21	 1.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56511	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56512	 1	 6.59	 3.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56513	 1	 5.71	 3.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56514	 1	 20.58	 11.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56515	 1	 8.15	 4.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56516	 1	 9.77	 5.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56517	 1	 10.36	 5.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56518	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56519	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56520	 1	 3.59	 2.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56521	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56522	 1	 8.03	 4.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56523	 1	 11.57	 6.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56524	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56525	 1	 7.4	 3.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56526	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56527	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56528	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56529	 1	 5.37	 2.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56530	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56531	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56532	 1	 10.06	 5.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56533	 1	 11.51	 6.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56534	 1	 4.31	 2.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56535	 1	 6.1	 3.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56536	 1	 6.15	 3.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56537	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56538	 1	 5.46	 2.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56539	 1	 20.87	 13.22	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56540	 1	 7.77	 4.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56541	 1	 8.7	 4.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56542	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56543	 1	 6.96	 3.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56544	 1	 5.47	 3.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56545	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56546	 1	 8.27	 3.94	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56547	 1	 1.62	 0.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56548	 1	 8.89	 4.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56549	 1	 6.26	 3.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56550	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56551	 1	 8.92	 4.66	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56552	 1	 11.12	 4.65	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56553	 1	 0.33	 0.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56554	 1	 19.0	 10.28	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56555	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56556	 1	 2.3	 1.14	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56557	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56558	 1	 1.32	 0.72	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56559	 1	 3.67	 2.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56560	 1	 8.39	 3.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56561	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56562	 1	 4.25	 1.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56563	 1	 9.5	 5.2	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56564	 1	 5.87	 3.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56565	 1	 2.15	 1.27	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56566	 1	 13.46	 5.77	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56567	 1	 6.94	 4.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56568	 1	 15.08	 8.11	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56569	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56570	 1	 1.95	 1.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56571	 1	 8.76	 3.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56572	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56573	 1	 4.92	 2.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56574	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56575	 1	 9.32	 5.91	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56576	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56577	 1	 5.34	 3.29	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56578	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56579	 1	 5.7	 3.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56580	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56581	 1	 5.11	 2.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56582	 1	 3.79	 2.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56583	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56584	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56585	 1	 5.97	 2.86	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56586	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56587	 1	 9.0	 4.76	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56588	 1	 11.07	 5.48	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56589	 1	 8.04	 4.81	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56590	 1	 3.83	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56591	 1	 15.65	 3.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56592	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56593	 1	 4.39	 2.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56594	 1	 5.94	 2.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56595	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56596	 1	 5.94	 2.64	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56597	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56598	 1	 49.5	 19.41	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56599	 1	 2.0	 1.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56600	 1	 2.22	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56601	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56602	 1	 5.32	 3.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56603	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56604	 1	 3.29	 1.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56605	 1	 6.14	 3.13	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56606	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56607	 1	 5.03	 2.63	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56608	 1	 14.05	 -6.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56609	 1	 5.35	 2.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56610	 1	 3.64	 1.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56611	 1	 4.0	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56612	 1	 14.46	 8.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56613	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56614	 1	 7.81	 4.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56615	 1	 15.13	 7.76	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56616	 1	 4.09	 2.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56617	 1	 6.07	 3.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56618	 1	 6.12	 3.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56619	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56620	 1	 9.76	 4.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56621	 1	 34.28	 14.42	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56622	 1	 42.04	 25.1	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56623	 1	 6.75	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56624	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56625	 1	 6.12	 3.02	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56626	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56627	 1	 2.96	 0.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56628	 1	 5.27	 3.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56629	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56630	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56631	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56632	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56633	 1	 21.47	 10.99	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56634	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56635	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56636	 1	 4.52	 2.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56637	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56638	 1	 22.98	 12.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56639	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56640	 1	 7.2	 3.71	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56641	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56642	 1	 13.65	 7.44	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56643	 1	 7.72	 4.01	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56644	 1	 25.64	 11.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56645	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56646	 1	 4.63	 2.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56647	 1	 5.37	 2.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56648	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56649	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56650	 1	 3.32	 0.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56651	 1	 11.43	 4.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56652	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56653	 1	 3.27	 1.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56654	 1	 6.03	 3.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56655	 1	 7.18	 3.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56656	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56657	 1	 5.47	 2.63	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56658	 1	 3.65	 2.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56659	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56660	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56661	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56662	 1	 5.3	 2.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56663	 1	 7.76	 4.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56664	 1	 6.52	 3.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56665	 1	 4.24	 2.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56666	 1	 2.51	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56667	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56668	 1	 15.14	 6.22	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56669	 1	 23.43	 9.6	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56670	 1	 5.19	 2.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56671	 1	 14.81	 8.48	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56672	 1	 10.62	 5.56	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56673	 1	 3.27	 1.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56674	 1	 2.42	 1.26	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56675	 1	 8.3	 4.18	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56676	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56677	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56678	 1	 3.36	 1.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56679	 1	 5.05	 2.76	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56680	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56681	 1	 23.12	 9.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56682	 1	 1.48	 0.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56683	 1	 5.54	 3.41	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56684	 1	 3.58	 2.07	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56685	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56686	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56687	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56688	 1	 4.21	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56689	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56690	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56691	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56692	 1	 2.02	 1.04	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56693	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56694	 1	 8.41	 4.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56695	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56696	 1	 51.1	 23.21	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56697	 1	 3.48	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56698	 1	 1.72	 0.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56699	 1	 2.92	 1.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56700	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56701	 1	 3.84	 2.44	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56702	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56703	 1	 7.64	 3.59	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56704	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56705	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56706	 1	 74.0	 31.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56707	 1	 4.17	 2.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56708	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56709	 1	 5.2	 2.97	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56710	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56711	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56712	 1	 3.55	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56713	 1	 0.51	 0.29	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56714	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56715	 1	 8.65	 4.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56716	 1	 126.49	 53.42	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56717	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56718	 1	 3.64	 1.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56719	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56720	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56721	 1	 5.0	 1.97	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56722	 1	 3.77	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56723	 1	 2.57	 1.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56724	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56725	 1	 9.66	 5.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56726	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56727	 1	 9.69	 2.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56728	 1	 6.56	 1.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56729	 1	 9.78	 2.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56730	 1	 4.03	 0.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56731	 1	 8.29	 4.43	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56732	 1	 23.06	 10.29	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56733	 1	 9.76	 5.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56734	 1	 5.67	 3.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56735	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56736	 1	 7.3	 4.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56737	 1	 5.95	 3.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56738	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56739	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56740	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56741	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56742	 1	 8.71	 4.08	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56743	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56744	 1	 4.86	 2.31	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56745	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56746	 1	 6.52	 1.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56747	 1	 8.2	 1.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56748	 1	 19.3	 4.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56749	 1	 17.01	 4.03	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56750	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56751	 1	 29.0	 11.63	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56752	 1	 11.3	 6.46	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56753	 1	 9.76	 5.15	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56754	 1	 34.45	 13.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56755	 1	 4.68	 2.81	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56756	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56757	 1	 4.18	 2.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56758	 1	 4.56	 2.93	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56759	 1	 9.51	 4.79	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56760	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56761	 1	 7.02	 4.36	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56762	 1	 4.29	 2.38	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56763	 1	 3.85	 1.79	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56764	 1	 6.13	 3.12	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56765	 1	 7.16	 4.04	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56766	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56767	 1	 37.17	 14.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56768	 1	 21.69	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56769	 1	 5.43	 2.8	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56770	 1	 7.81	 4.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56771	 1	 7.92	 1.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56772	 1	 5.84	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56773	 1	 7.03	 1.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56774	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56775	 1	 8.19	 4.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56776	 1	 7.21	 3.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56777	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56778	 1	 14.32	 7.67	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56779	 1	 8.95	 2.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56780	 1	 3.14	 1.51	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56781	 1	 5.83	 3.31	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56782	 1	 9.86	 5.95	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56783	 1	 2.86	 0.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56784	 1	 10.99	 2.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56785	 1	 4.28	 2.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56786	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56787	 1	 14.55	 8.15	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56788	 1	 14.91	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56789	 1	 7.37	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56790	 1	 6.77	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56791	 1	 8.52	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56792	 1	 7.75	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56793	 1	 9.17	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56794	 1	 2.42	 1.46	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56795	 1	 2.13	 1.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56796	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56797	 1	 4.35	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56798	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56799	 1	 10.79	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56800	 1	 2.13	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56801	 1	 7.61	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56802	 1	 7.88	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56803	 1	 8.76	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56804	 1	 5.46	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56805	 1	 4.54	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56806	 1	 10.78	 5.26	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56807	 1	 4.2	 2.32	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56808	 1	 1.29	 0.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56809	 1	 9.58	 5.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56810	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56811	 1	 12.73	 7.89	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56812	 1	 7.18	 4.43	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56813	 1	 8.47	 4.3	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56814	 1	 11.1	 6.62	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56815	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56816	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56817	 1	 19.07	 10.86	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56818	 1	 10.09	 5.32	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56819	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56820	 1	 6.5	 3.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56821	 1	 4.67	 2.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56822	 1	 7.47	 4.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56823	 1	 5.4	 3.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56824	 1	 32.45	 10.36	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56825	 1	 34.94	 13.03	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56826	 1	 13.55	 7.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56827	 1	 9.63	 4.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56828	 1	 5.41	 3.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56829	 1	 6.44	 3.25	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56830	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56831	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56832	 1	 5.96	 2.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56833	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56834	 1	 4.03	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56835	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56836	 1	 3.83	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56837	 1	 7.78	 3.43	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56838	 1	 5.71	 3.27	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56839	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56840	 1	 9.24	 2.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56841	 1	 8.09	 1.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56842	 1	 3.36	 0.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56843	 1	 19.65	 6.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56844	 1	 4.96	 1.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56845	 1	 7.87	 3.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56846	 1	 6.07	 3.95	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56847	 1	 6.73	 3.32	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56848	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56849	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56850	 1	 10.25	 5.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56851	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56852	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56853	 1	 9.77	 4.77	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56854	 1	 7.18	 4.11	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56855	 1	 10.4	 5.44	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56856	 1	 8.08	 4.32	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56857	 1	 21.17	 10.94	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56858	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56859	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56860	 1	 14.14	 7.5	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56861	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56862	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56863	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56864	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56865	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56866	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56867	 1	 4.2	 1.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56868	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56869	 1	 3.48	 1.99	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56870	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56871	 1	 3.99	 2.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56872	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56873	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56874	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56875	 1	 7.91	 1.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56876	 1	 2.88	 0.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56877	 1	 58.65	 24.17	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56878	 1	 3.82	 2.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56879	 1	 3.46	 1.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56880	 1	 2.54	 0.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56881	 1	 4.14	 1.91	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56882	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56883	 1	 3.82	 2.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56884	 1	 4.4	 2.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56885	 1	 8.97	 5.47	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56886	 1	 3.78	 2.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56887	 1	 0.42	 0.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56888	 1	 6.49	 2.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56889	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56890	 1	 4.07	 2.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56891	 1	 8.61	 4.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56892	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56893	 1	 4.74	 2.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56894	 1	 5.17	 2.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56895	 1	 8.68	 4.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56896	 1	 13.53	 6.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56897	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56898	 1	 3.09	 1.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56899	 1	 0.89	 0.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56900	 1	 3.81	 1.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56901	 1	 7.25	 3.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56902	 1	 13.52	 6.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56903	 1	 7.27	 3.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56904	 1	 5.11	 2.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56905	 1	 7.17	 3.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56906	 1	 6.47	 3.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56907	 1	 2.78	 1.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56908	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56909	 1	 5.31	 2.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56910	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56911	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56912	 1	 8.23	 4.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56913	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56914	 1	 4.68	 2.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56915	 1	 4.05	 2.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56916	 1	 5.16	 2.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56917	 1	 5.38	 2.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56918	 1	 5.31	 2.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56919	 1	 4.64	 2.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56920	 1	 9.7	 4.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56921	 1	 6.78	 3.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56922	 1	 6.75	 3.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56923	 1	 5.72	 2.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56924	 1	 4.67	 2.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56925	 1	 9.73	 4.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56926	 1	 6.7	 3.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56927	 1	 5.51	 2.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56928	 1	 4.54	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56929	 1	 6.57	 3.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56930	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56931	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56932	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	56933	 1	 1.97	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56934	 1	 4.45	 2.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56935	 1	 20.3	 7.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56936	 1	 4.61	 2.47	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56937	 1	 5.1	 2.43	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56938	 1	 3.05	 1.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56939	 1	 6.18	 3.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56940	 1	 4.06	 2.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56941	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56942	 1	 8.26	 4.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56943	 1	 10.77	 5.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56944	 1	 11.91	 2.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56945	 1	 3.07	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56946	 1	 5.45	 3.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56947	 1	 4.97	 2.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56948	 1	 6.56	 2.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56949	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56950	 1	 2.7	 1.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56951	 1	 2.08	 0.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56952	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56953	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56954	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56955	 1	 0.67	 0.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56956	 1	 3.56	 2.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56957	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56958	 1	 2.32	 1.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56959	 1	 16.88	 3.93	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56960	 1	 4.43	 1.03	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56961	 1	 2.32	 0.54	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56962	 1	 7.12	 1.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56963	 1	 13.4	 3.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56964	 1	 5.17	 1.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56965	 1	 8.68	 1.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56966	 1	 8.49	 1.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56967	 1	 9.92	 2.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56968	 1	 2.94	 1.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56969	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56970	 1	 2.9	 0.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56971	 1	 7.91	 4.64	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56972	 1	 3.3	 0.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56973	 1	 2.57	 1.27	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56974	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56975	 1	 5.71	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56976	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56977	 1	 14.79	 6.03	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56978	 1	 38.6	 20.78	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56979	 1	 6.35	 1.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56980	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	56981	 1	 5.96	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56982	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56983	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56984	 1	 5.6	 2.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56985	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56986	 1	 3.39	 1.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56987	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56988	 1	 4.92	 2.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56989	 1	 6.75	 3.16	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56990	 1	 4.61	 2.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56991	 1	 3.94	 2.15	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56992	 1	 4.79	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56993	 1	 2.73	 0.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56994	 1	 9.44	 2.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56995	 1	 5.3	 2.81	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56996	 1	 3.8	 1.81	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56997	 1	 3.07	 1.48	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56998	 1	 3.92	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	56999	 1	 6.91	 3.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57000	 1	 21.68	 11.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57001	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57002	 1	 8.74	 4.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57003	 1	 7.99	 4.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57004	 1	 15.24	 7.27	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57005	 1	 16.76	 6.83	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57006	 1	 7.24	 1.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57007	 1	 7.72	 1.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57008	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57009	 1	 9.55	 5.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57010	 1	 4.65	 2.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57011	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57012	 1	 0.83	 0.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57013	 1	 4.05	 2.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57014	 1	 4.23	 2.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57015	 1	 4.0	 2.2	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57016	 1	 3.08	 1.65	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57017	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57018	 1	 2.94	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57019	 1	 3.25	 1.68	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57020	 1	 3.67	 2.1	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57021	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57022	 1	 8.71	 3.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57023	 1	 4.06	 2.03	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57024	 1	 2.14	 0.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57025	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57026	 1	 3.32	 2.08	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57027	 1	 13.07	 8.06	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57028	 1	 4.82	 2.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57029	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57030	 1	 6.24	 3.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57031	 1	 2.11	 1.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57032	 1	 3.12	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57033	 1	 49.24	 22.32	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57034	 1	 14.61	 8.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57035	 1	 31.21	 18.36	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57036	 1	 8.33	 1.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57037	 1	 6.05	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57038	 1	 10.27	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57039	 1	 8.19	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57040	 1	 3.6	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57041	 1	 8.61	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57042	 1	 3.12	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57043	 1	 8.34	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57044	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57045	 1	 7.27	 1.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57046	 1	 14.21	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57047	 1	 1.74	 1.01	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57048	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57049	 1	 5.74	 3.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57050	 1	 4.72	 2.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57051	 1	 10.59	 5.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57052	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57053	 1	 5.23	 2.59	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57054	 1	 5.99	 2.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57055	 1	 10.22	 5.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57056	 1	 5.44	 3.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57057	 1	 4.21	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57058	 1	 7.26	 3.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57059	 1	 5.55	 2.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57060	 1	 4.06	 2.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57061	 1	 6.7	 3.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57062	 1	 12.37	 5.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57063	 1	 4.85	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57064	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57065	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57066	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57067	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57068	 1	 4.7	 2.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57069	 1	 6.28	 3.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57070	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57071	 1	 6.63	 3.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57072	 1	 7.06	 4.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57073	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57074	 1	 3.33	 1.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57075	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57076	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57077	 1	 53.33	 23.12	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57078	 1	 125.71	 53.04	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57079	 1	 9.71	 4.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57080	 1	 3.13	 1.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57081	 1	 3.11	 0.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57082	 1	 5.49	 2.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57083	 1	 4.41	 1.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57084	 1	 5.48	 2.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57085	 1	 2.91	 0.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57086	 1	 10.19	 5.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57087	 1	 10.43	 4.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57088	 1	 3.36	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57089	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57090	 1	 9.25	 5.51	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57091	 1	 2.38	 1.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57092	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57093	 1	 2.42	 0.58	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57094	 1	 4.3	 1.01	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57095	 1	 6.7	 3.13	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57096	 1	 10.32	 5.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57097	 1	 2.31	 0.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57098	 1	 10.12	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57099	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57100	 1	 8.93	 4.07	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57101	 1	 6.92	 3.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57102	 1	 5.57	 3.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57103	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57104	 1	 7.81	 4.13	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57105	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57106	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57107	 1	 13.72	 7.75	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57108	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57109	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57110	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57111	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57112	 1	 7.47	 3.78	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57113	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57114	 1	 5.51	 3.02	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57115	 1	 13.56	 7.04	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57116	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57117	 1	 3.79	 2.33	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57118	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57119	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57120	 1	 10.71	 6.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57121	 1	 14.72	 5.8	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57122	 1	 25.6	 13.02	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57123	 1	 6.22	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57124	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57125	 1	 18.33	 9.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57126	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57127	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57128	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57129	 1	 5.39	 1.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57130	 1	 16.88	 3.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57131	 1	 8.13	 4.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57132	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57133	 1	 3.7	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57134	 1	 8.46	 4.25	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57135	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57136	 1	 7.73	 3.73	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57137	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57138	 1	 7.75	 4.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57139	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57140	 1	 9.04	 5.47	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57141	 1	 15.9	 9.34	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57142	 1	 6.35	 3.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57143	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57144	 1	 12.93	 6.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57145	 1	 51.76	 26.75	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57146	 1	 11.26	 5.44	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57147	 1	 28.28	 6.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57148	 1	 7.07	 1.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57149	 1	 9.83	 6.33	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57150	 1	 11.65	 6.75	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57151	 1	 13.64	 7.14	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57152	 1	 9.9	 6.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57153	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57154	 1	 8.82	 5.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57155	 1	 7.13	 3.52	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57156	 1	 3.57	 2.2	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57157	 1	 19.3	 9.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57158	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57159	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57160	 1	 6.67	 4.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57161	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57162	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57163	 1	 6.79	 2.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57164	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57165	 1	 7.45	 3.6	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57166	 1	 5.48	 2.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57167	 1	 18.13	 7.73	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57168	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57169	 1	 8.8	 4.75	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57170	 1	 4.88	 1.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57171	 1	 4.98	 1.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57172	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57173	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57174	 1	 12.6	 2.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57175	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57176	 1	 7.96	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57177	 1	 6.39	 1.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57178	 1	 9.6	 5.28	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57179	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57180	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57181	 1	 6.0	 2.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57182	 1	 4.28	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57183	 1	 4.71	 2.65	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57184	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57185	 1	 11.83	 6.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57186	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57187	 1	 4.81	 2.73	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57188	 1	 2.37	 1.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57189	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57190	 1	 2.66	 1.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57191	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57192	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57193	 1	 6.04	 3.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57194	 1	 8.62	 4.17	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57195	 1	 6.88	 3.49	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57196	 1	 21.26	 9.71	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57197	 1	 1.64	 1.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57198	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57199	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57200	 1	 68.85	 39.91	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57201	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57202	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57203	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57204	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57205	 1	 4.75	 3.05	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57206	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57207	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57208	 1	 4.67	 2.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57209	 1	 4.64	 2.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57210	 1	 7.95	 4.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57211	 1	 6.15	 2.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57212	 1	 9.22	 5.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57213	 1	 7.02	 3.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57214	 1	 10.33	 5.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57215	 1	 4.91	 2.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57216	 1	 5.74	 3.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57217	 1	 5.59	 3.02	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57218	 1	 3.96	 1.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57219	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57220	 1	 3.39	 1.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57221	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57222	 1	 5.01	 3.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57223	 1	 5.61	 3.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57224	 1	 6.77	 3.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57225	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57226	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57227	 1	 2.63	 1.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57228	 1	 2.88	 1.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57229	 1	 7.75	 2.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57230	 1	 5.27	 2.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57231	 1	 5.34	 3.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57232	 1	 6.09	 3.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57233	 1	 3.26	 1.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57234	 1	 85.17	 49.81	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57235	 1	 6.18	 3.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57236	 1	 7.19	 4.08	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57237	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57238	 1	 5.13	 3.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57239	 1	 4.99	 3.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57240	 1	 6.92	 4.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57241	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57242	 1	 4.28	 2.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57243	 1	 6.64	 3.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57244	 1	 4.89	 2.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57245	 1	 6.82	 3.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57246	 1	 5.63	 3.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57247	 1	 6.15	 3.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57248	 1	 43.15	 18.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57249	 1	 7.87	 5.15	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57250	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57251	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57252	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57253	 1	 6.69	 3.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57254	 1	 2.28	 1.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57255	 1	 52.58	 24.04	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57256	 1	 2.51	 1.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57257	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57258	 1	 3.64	 1.8	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57259	 1	 3.65	 2.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57260	 1	 5.18	 3.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57261	 1	 4.75	 2.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57262	 1	 2.72	 1.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57263	 1	 1.87	 0.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57264	 1	 5.8	 3.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57265	 1	 3.7	 1.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57266	 1	 4.68	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57267	 1	 16.12	 8.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57268	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57269	 1	 6.87	 4.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57270	 1	 73.91	 26.56	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57271	 1	 105.57	 47.45	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57272	 1	 44.95	 26.33	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57273	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57274	 1	 32.13	 15.72	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57275	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57276	 1	 5.99	 3.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57277	 1	 5.62	 2.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57278	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57279	 1	 6.77	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57280	 1	 7.03	 1.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57281	 1	 2.85	 1.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57282	 1	 11.37	 5.7	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57283	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57284	 1	 17.0	 8.22	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57285	 1	 8.43	 4.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57286	 1	 3.11	 1.61	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57287	 1	 5.97	 3.38	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57288	 1	 12.81	 4.62	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57289	 1	 4.96	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57290	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57291	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57292	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57293	 1	 2.51	 1.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57294	 1	 7.26	 4.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57295	 1	 5.12	 2.78	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57296	 1	 8.5	 4.09	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57297	 1	 2.91	 1.69	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57298	 1	 13.46	 7.46	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57299	 1	 38.72	 18.59	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57300	 1	 16.46	 8.49	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57301	 1	 11.05	 5.36	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57302	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57303	 1	 4.24	 2.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57304	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57305	 1	 4.4	 2.59	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57306	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57307	 1	 1.73	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57308	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57309	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57310	 1	 7.0	 2.98	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57311	 1	 3.06	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57312	 1	 8.7	 1.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57313	 1	 8.86	 4.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57314	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57315	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57316	 1	 2.73	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57317	 1	 2.57	 1.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57318	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57319	 1	 23.03	 8.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57320	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57321	 1	 7.74	 4.8	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57322	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57323	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57324	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57325	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57326	 1	 3.89	 2.09	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57327	 1	 3.39	 2.19	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57328	 1	 4.43	 2.8	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57329	 1	 8.55	 5.04	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57330	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57331	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57332	 1	 16.57	 9.47	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57333	 1	 9.4	 5.18	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57334	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57335	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57336	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57337	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57338	 1	 10.73	 5.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57339	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57340	 1	 5.88	 1.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57341	 1	 8.19	 1.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57342	 1	 53.23	 22.56	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57343	 1	 18.63	 10.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57344	 1	 11.81	 6.37	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57345	 1	 6.85	 3.89	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57346	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57347	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57348	 1	 3.96	 2.36	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57349	 1	 4.12	 2.43	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57350	 1	 15.82	 7.07	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57351	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57352	 1	 16.37	 7.44	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57353	 1	 1.92	 1.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57354	 1	 2.27	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57355	 1	 5.92	 2.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57356	 1	 6.33	 3.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57357	 1	 6.83	 3.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57358	 1	 4.56	 2.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57359	 1	 2.61	 1.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57360	 1	 4.44	 2.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57361	 1	 5.5	 2.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57362	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57363	 1	 5.03	 2.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57364	 1	 3.17	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57365	 1	 3.55	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57366	 1	 8.99	 4.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57367	 1	 3.21	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57368	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57369	 1	 1.67	 1.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57370	 1	 1.95	 1.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57371	 1	 6.21	 3.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57372	 1	 82.29	 43.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57373	 1	 4.35	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57374	 1	 6.04	 2.6	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57375	 1	 54.69	 18.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57376	 1	 65.33	 27.22	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57377	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57378	 1	 6.55	 3.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57379	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57380	 1	 9.57	 4.37	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57381	 1	 7.21	 4.43	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57382	 1	 3.25	 1.93	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57383	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57384	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57385	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57386	 1	 9.01	 4.05	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57387	 1	 5.28	 1.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57388	 1	 8.13	 1.85	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57389	 1	 8.78	 5.36	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57390	 1	 6.54	 3.1	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57391	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57392	 1	 3.37	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57393	 1	 1.96	 1.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57394	 1	 2.51	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57395	 1	 3.93	 2.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57396	 1	 3.82	 1.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57397	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57398	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57399	 1	 5.07	 3.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57400	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57401	 1	 3.34	 1.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57402	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57403	 1	 6.56	 3.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57404	 1	 5.45	 3.03	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57405	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57406	 1	 3.58	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57407	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57408	 1	 3.6	 1.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57409	 1	 6.06	 3.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57410	 1	 6.85	 3.99	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57411	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57412	 1	 7.1	 3.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57413	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57414	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57415	 1	 6.49	 3.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57416	 1	 6.03	 3.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57417	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57418	 1	 9.05	 4.31	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57419	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57420	 1	 19.71	 10.29	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57421	 1	 6.59	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57422	 1	 4.42	 2.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57423	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57424	 1	 2.72	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57425	 1	 2.67	 1.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57426	 1	 7.51	 3.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57427	 1	 4.78	 2.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57428	 1	 3.99	 1.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57429	 1	 4.38	 2.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57430	 1	 1.3	 0.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57431	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57432	 1	 12.68	 6.58	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57433	 1	 11.46	 5.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57434	 1	 2.67	 1.62	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57435	 1	 2.13	 1.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57436	 1	 6.61	 4.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57437	 1	 3.91	 2.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57438	 1	 94.8	 53.65	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57439	 1	 6.84	 1.69	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57440	 1	 7.97	 1.96	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57441	 1	 9.76	 2.41	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57442	 1	 6.49	 1.6	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57443	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57444	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57445	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57446	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57447	 1	 8.14	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57448	 1	 11.94	 2.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57449	 1	 6.84	 1.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57450	 1	 1.7	 0.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57451	 1	 6.18	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57452	 1	 3.62	 1.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57453	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57454	 1	 7.04	 3.56	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57455	 1	 3.4	 2.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57456	 1	 28.87	 12.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57457	 1	 7.99	 4.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57458	 1	 18.29	 11.33	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57459	 1	 4.76	 2.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57460	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57461	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57462	 1	 5.39	 3.32	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57463	 1	 9.46	 5.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57464	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57465	 1	 4.78	 2.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57466	 1	 3.03	 1.9	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57467	 1	 2.78	 0.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57468	 1	 14.88	 4.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57469	 1	 6.87	 1.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57470	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57471	 1	 3.7	 1.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57472	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57473	 1	 9.94	 5.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57474	 1	 12.29	 6.82	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57475	 1	 5.61	 3.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57476	 1	 5.25	 2.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57477	 1	 6.27	 3.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57478	 1	 9.44	 5.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57479	 1	 7.12	 3.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57480	 1	 52.58	 28.13	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57481	 1	 20.96	 7.15	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57482	 1	 7.12	 3.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57483	 1	 6.3	 3.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57484	 1	 3.12	 1.77	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57485	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57486	 1	 88.39	 28.69	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57487	 1	 10.96	 5.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57488	 1	 8.7	 5.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57489	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57490	 1	 4.88	 2.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57491	 1	 3.35	 0.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57492	 1	 6.39	 3.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57493	 1	 4.42	 2.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57494	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57495	 1	 12.2	 6.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57496	 1	 16.19	 8.47	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57497	 1	 4.32	 1.85	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57498	 1	 9.74	 5.07	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57499	 1	 19.72	 11.7	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57500	 1	 5.6	 3.2	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57501	 1	 14.18	 7.74	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57502	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57503	 1	 5.21	 2.87	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57504	 1	 51.66	 23.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57505	 1	 3.36	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57506	 1	 3.47	 1.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57507	 1	 4.99	 3.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57508	 1	 10.39	 2.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57509	 1	 4.34	 1.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57510	 1	 2.14	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57511	 1	 29.25	 8.66	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57512	 1	 8.86	 2.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57513	 1	 6.14	 2.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57514	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57515	 1	 10.11	 2.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57516	 1	 8.46	 4.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57517	 1	 5.99	 2.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57518	 1	 6.26	 1.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57519	 1	 6.94	 1.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57520	 1	 6.05	 1.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57521	 1	 7.49	 1.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57522	 1	 4.11	 0.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57523	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57524	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57525	 1	 6.48	 3.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57526	 1	 27.47	 12.64	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57527	 1	 20.02	 6.86	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57528	 1	 23.74	 11.69	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57529	 1	 7.28	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57530	 1	 35.33	 17.77	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57531	 1	 29.94	 16.03	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57532	 1	 12.14	 6.64	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57533	 1	 11.33	 2.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57534	 1	 6.6	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57535	 1	 17.24	 4.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57536	 1	 5.62	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57537	 1	 6.68	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57538	 1	 10.26	 2.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57539	 1	 6.69	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57540	 1	 7.51	 1.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57541	 1	 8.02	 1.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57542	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57543	 1	 8.32	 1.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57544	 1	 8.8	 4.33	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57545	 1	 4.79	 2.86	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57546	 1	 5.98	 2.92	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57547	 1	 7.59	 3.59	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57548	 1	 0.67	 0.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57549	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57550	 1	 5.08	 2.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57551	 1	 3.59	 2.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57552	 1	 4.7	 1.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57553	 1	 4.04	 0.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57554	 1	 3.37	 1.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57555	 1	 3.99	 2.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57556	 1	 4.46	 1.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57557	 1	 2.96	 1.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57558	 1	 3.84	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57559	 1	 5.25	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57560	 1	 6.34	 3.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57561	 1	 7.46	 3.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57562	 1	 6.53	 3.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57563	 1	 7.27	 4.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57564	 1	 3.87	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57565	 1	 3.4	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57566	 1	 5.77	 3.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57567	 1	 4.91	 2.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57568	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57569	 1	 2.8	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57570	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57571	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57572	 1	 3.33	 1.73	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57573	 1	 5.82	 3.29	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57574	 1	 2.62	 1.3	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57575	 1	 6.48	 1.56	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57576	 1	 5.46	 3.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57577	 1	 5.54	 3.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57578	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57579	 1	 14.26	 6.16	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57580	 1	 7.91	 4.42	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57581	 1	 9.92	 5.84	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57582	 1	 8.4	 5.25	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57583	 1	 2.34	 0.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57584	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57585	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57586	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57587	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57588	 1	 77.96	 18.78	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57589	 1	 31.78	 7.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57590	 1	 7.33	 3.61	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57591	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57592	 1	 5.2	 1.26	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57593	 1	 4.96	 1.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57594	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57595	 1	 6.28	 1.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57596	 1	 8.61	 2.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57597	 1	 32.76	 12.14	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57598	 1	 7.73	 3.72	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57599	 1	 4.64	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57600	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57601	 1	 6.29	 1.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57602	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57603	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57604	 1	 4.8	 1.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57605	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57606	 1	 3.51	 1.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57607	 1	 6.55	 3.43	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57608	 1	 6.57	 3.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57609	 1	 14.83	 3.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57610	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57611	 1	 2.76	 1.74	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57612	 1	 3.07	 1.75	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57613	 1	 4.63	 2.58	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57614	 1	 2.76	 1.5	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57615	 1	 8.71	 3.05	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57616	 1	 3.76	 0.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57617	 1	 5.84	 3.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57618	 1	 3.58	 0.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57619	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57620	 1	 6.05	 1.45	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57621	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57622	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57623	 1	 5.47	 1.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57624	 1	 8.51	 2.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57625	 1	 4.31	 1.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57626	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57627	 1	 4.4	 1.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57628	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57629	 1	 4.08	 0.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57630	 1	 5.52	 1.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57631	 1	 8.11	 1.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57632	 1	 5.57	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57633	 1	 7.75	 1.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57634	 1	 23.46	 5.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57635	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57636	 1	 55.46	 13.3	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57637	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57638	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57639	 1	 8.41	 1.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57640	 1	 7.8	 4.7	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57641	 1	 4.52	 2.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57642	 1	 3.1	 1.93	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57643	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57644	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57645	 1	 4.3	 1.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57646	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57647	 1	 5.3	 2.93	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57648	 1	 8.98	 4.37	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57649	 1	 6.05	 1.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57650	 1	 7.51	 4.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57651	 1	 8.53	 4.95	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57652	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57653	 1	 7.9	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57654	 1	 7.42	 1.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57655	 1	 5.81	 1.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57656	 1	 2.85	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57657	 1	 7.68	 3.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57658	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57659	 1	 3.65	 2.12	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57660	 1	 4.3	 2.16	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57661	 1	 11.31	 5.36	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57662	 1	 6.95	 1.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57663	 1	 4.95	 1.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57664	 1	 7.09	 1.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57665	 1	 10.48	 2.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57666	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57667	 1	 15.22	 3.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57668	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57669	 1	 8.41	 2.02	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57670	 1	 3.76	 0.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57671	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57672	 1	 3.61	 1.63	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57673	 1	 7.18	 1.74	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57674	 1	 3.71	 0.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57675	 1	 5.34	 1.29	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57676	 1	 2.55	 0.62	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57677	 1	 20.09	 4.82	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57678	 1	 8.7	 2.09	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57679	 1	 11.91	 2.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57680	 1	 4.36	 1.05	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57681	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57682	 1	 6.55	 1.58	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57683	 1	 3.78	 0.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57684	 1	 9.28	 2.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57685	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57686	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57687	 1	 3.6	 0.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57688	 1	 2.13	 0.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57689	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57690	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57691	 1	 4.07	 0.98	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57692	 1	 9.64	 2.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57693	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57694	 1	 54.1	 13.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57695	 1	 6.97	 1.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57696	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57697	 1	 4.96	 3.08	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57698	 1	 8.79	 4.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57699	 1	 4.45	 2.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57700	 1	 8.44	 4.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57701	 1	 5.34	 1.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57702	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57703	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57704	 1	 4.52	 2.42	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57705	 1	 9.98	 5.72	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57706	 1	 3.82	 1.67	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57707	 1	 1.82	 1.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57708	 1	 6.03	 1.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57709	 1	 2.95	 1.37	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57710	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57711	 1	 5.66	 2.98	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57712	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57713	 1	 16.47	 3.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57714	 1	 24.08	 9.51	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57715	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57716	 1	 3.81	 2.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57717	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57718	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57719	 1	 11.4	 2.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57720	 1	 4.7	 2.84	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57721	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57722	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57723	 1	 2.53	 1.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57724	 1	 9.8	 2.36	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57725	 1	 6.2	 3.17	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57726	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57727	 1	 6.84	 1.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57728	 1	 6.5	 1.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57729	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57730	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57731	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57732	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57733	 1	 10.7	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57734	 1	 7.94	 1.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57735	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57736	 1	 7.84	 1.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57737	 1	 7.05	 1.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57738	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57739	 1	 6.76	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57740	 1	 4.11	 0.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57741	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57742	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57743	 1	 20.77	 4.94	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57744	 1	 7.68	 1.82	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57745	 1	 7.86	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57746	 1	 6.22	 1.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57747	 1	 5.16	 1.22	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57748	 1	 4.26	 1.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57749	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57750	 1	 5.31	 1.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57751	 1	 7.68	 1.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57752	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57753	 1	 10.51	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57754	 1	 8.5	 2.02	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57755	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57756	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57757	 1	 9.0	 2.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57758	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57759	 1	 3.97	 0.95	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57760	 1	 9.88	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57761	 1	 5.44	 1.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57762	 1	 11.33	 2.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57763	 1	 5.85	 1.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57764	 1	 6.24	 1.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57765	 1	 22.03	 5.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57766	 1	 9.14	 2.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57767	 1	 7.68	 1.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57768	 1	 10.5	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57769	 1	 8.79	 2.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57770	 1	 5.89	 1.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57771	 1	 6.47	 1.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57772	 1	 8.76	 2.07	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57773	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57774	 1	 3.24	 0.78	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57775	 1	 8.65	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57776	 1	 18.4	 4.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57777	 1	 8.61	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57778	 1	 6.66	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57779	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57780	 1	 7.65	 1.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57781	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57782	 1	 9.59	 2.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57783	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57784	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57785	 1	 13.22	 3.17	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57786	 1	 5.28	 1.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57787	 1	 3.37	 0.8	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57788	 1	 4.34	 1.05	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57789	 1	 4.9	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57790	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57791	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57792	 1	 2.86	 0.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57793	 1	 3.92	 0.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57794	 1	 7.02	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57795	 1	 6.03	 1.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57796	 1	 4.74	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57797	 1	 6.97	 1.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57798	 1	 4.17	 0.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57799	 1	 7.64	 1.81	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57800	 1	 5.71	 1.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57801	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57802	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57803	 1	 4.73	 1.12	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57804	 1	 6.57	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57805	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57806	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57807	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57808	 1	 5.07	 1.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57809	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57810	 1	 6.33	 1.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57811	 1	 7.82	 1.87	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57812	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57813	 1	 8.73	 2.09	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57814	 1	 9.71	 2.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57815	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57816	 1	 7.05	 1.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57817	 1	 5.52	 1.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57818	 1	 11.53	 2.74	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57819	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57820	 1	 5.31	 1.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57821	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57822	 1	 4.54	 1.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57823	 1	 4.39	 1.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57824	 1	 5.19	 1.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57825	 1	 7.81	 1.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57826	 1	 6.15	 1.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57827	 1	 7.64	 1.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57828	 1	 15.34	 3.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57829	 1	 5.48	 1.3	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57830	 1	 10.66	 2.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57831	 1	 5.97	 1.42	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57832	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57833	 1	 5.9	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57834	 1	 7.04	 1.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57835	 1	 3.92	 0.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57836	 1	 7.83	 1.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57837	 1	 3.59	 0.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57838	 1	 5.04	 1.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57839	 1	 6.81	 1.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57840	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57841	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57842	 1	 4.73	 1.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57843	 1	 6.85	 1.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57844	 1	 5.95	 1.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57845	 1	 4.92	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57846	 1	 7.74	 1.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57847	 1	 22.46	 5.27	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57848	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57849	 1	 4.89	 1.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57850	 1	 6.24	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57851	 1	 3.71	 0.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57852	 1	 6.62	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57853	 1	 6.23	 1.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57854	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57855	 1	 5.46	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57856	 1	 9.55	 2.29	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57857	 1	 9.9	 2.38	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57858	 1	 6.91	 1.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57859	 1	 6.23	 1.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57860	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57861	 1	 5.59	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57862	 1	 5.08	 1.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57863	 1	 8.89	 2.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57864	 1	 13.33	 3.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57865	 1	 7.87	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57866	 1	 8.71	 2.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57867	 1	 10.32	 2.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57868	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57869	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57870	 1	 5.29	 1.26	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57871	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57872	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57873	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57874	 1	 6.7	 1.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57875	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57876	 1	 22.6	 5.38	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57877	 1	 3.77	 0.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57878	 1	 4.46	 1.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57879	 1	 4.19	 0.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57880	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57881	 1	 15.94	 3.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57882	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57883	 1	 18.48	 4.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57884	 1	 59.68	 14.28	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57885	 1	 8.71	 2.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57886	 1	 7.14	 3.43	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57887	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57888	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57889	 1	 10.34	 5.9	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57890	 1	 52.57	 24.61	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57891	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57892	 1	 6.42	 3.82	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57893	 1	 9.5	 5.28	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57894	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57895	 1	 5.41	 2.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57896	 1	 11.88	 6.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57897	 1	 11.07	 2.67	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57898	 1	 8.34	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57899	 1	 3.93	 0.94	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57900	 1	 3.27	 0.79	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57901	 1	 5.78	 1.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57902	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57903	 1	 2.63	 0.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57904	 1	 6.87	 1.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57905	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57906	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57907	 1	 5.38	 1.28	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57908	 1	 12.82	 3.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57909	 1	 9.14	 2.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57910	 1	 7.08	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57911	 1	 5.57	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57912	 1	 4.31	 1.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57913	 1	 6.76	 1.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57914	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	57915	 1	 5.47	 1.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57916	 1	 9.08	 2.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57917	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57918	 1	 4.13	 0.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57919	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57920	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57921	 1	 5.0	 1.19	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57922	 1	 4.93	 1.17	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57923	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57924	 1	 7.1	 3.33	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57925	 1	 9.7	 3.86	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57926	 1	 30.17	 14.02	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57927	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57928	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57929	 1	 5.02	 1.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57930	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57931	 1	 25.56	 5.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57932	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57933	 1	 6.97	 3.56	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57934	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57935	 1	 2.08	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57936	 1	 4.63	 2.28	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57937	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57938	 1	 4.28	 2.63	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57939	 1	 2.42	 1.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57940	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57941	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57942	 1	 3.75	 1.93	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57943	 1	 4.63	 2.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57944	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57945	 1	 2.86	 1.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57946	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57947	 1	 3.16	 1.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57948	 1	 3.7	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57949	 1	 9.83	 5.41	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57950	 1	 0.46	 0.29	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57951	 1	 6.21	 2.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57952	 1	 5.76	 3.54	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57953	 1	 33.65	 19.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57954	 1	 4.95	 2.6	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57955	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57956	 1	 10.39	 6.2	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57957	 1	 4.73	 2.76	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57958	 1	 5.48	 2.64	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57959	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57960	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57961	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57962	 1	 15.09	 5.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57963	 1	 11.72	 4.68	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57964	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57965	 1	 15.63	 7.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57966	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57967	 1	 8.32	 4.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57968	 1	 11.18	 5.18	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	57969	 1	 3.68	 2.21	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57970	 1	 4.99	 2.84	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57971	 1	 7.48	 1.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57972	 1	 8.1	 1.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57973	 1	 10.77	 4.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57974	 1	 3.25	 1.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57975	 1	 2.08	 1.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57976	 1	 2.77	 1.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57977	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57978	 1	 6.04	 3.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57979	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57980	 1	 11.82	 6.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57981	 1	 1.74	 1.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57982	 1	 7.65	 3.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57983	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57984	 1	 4.72	 1.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57985	 1	 38.91	 9.15	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57986	 1	 9.84	 2.31	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57987	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57988	 1	 5.72	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57989	 1	 5.87	 1.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57990	 1	 3.74	 0.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57991	 1	 9.94	 2.32	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57992	 1	 9.98	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57993	 1	 6.69	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57994	 1	 7.99	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57995	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57996	 1	 7.2	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57997	 1	 7.26	 1.69	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57998	 1	 7.47	 1.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	57999	 1	 7.89	 1.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58000	 1	 10.54	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58001	 1	 4.12	 1.9	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58002	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58003	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58004	 1	 5.43	 1.27	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58005	 1	 8.88	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58006	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58007	 1	 3.35	 0.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58008	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58009	 1	 4.84	 2.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58010	 1	 5.21	 2.99	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58011	 1	 5.98	 2.94	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58012	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58013	 1	 4.66	 2.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58014	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58015	 1	 3.01	 1.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58016	 1	 3.52	 1.77	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58017	 1	 4.0	 2.03	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58018	 1	 1.69	 1.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58019	 1	 4.53	 2.14	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58020	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58021	 1	 5.47	 2.95	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58022	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58023	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58024	 1	 8.09	 4.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58025	 1	 9.02	 4.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58026	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58027	 1	 3.7	 2.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58028	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58029	 1	 2.27	 1.21	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58030	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58031	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58032	 1	 3.94	 1.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58033	 1	 17.53	 10.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58034	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58035	 1	 3.51	 2.15	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58036	 1	 4.9	 2.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58037	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58038	 1	 3.46	 1.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58039	 1	 2.64	 1.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58040	 1	 3.77	 2.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58041	 1	 2.8	 1.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58042	 1	 2.12	 1.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58043	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58044	 1	 11.45	 4.97	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58045	 1	 15.88	 7.64	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58046	 1	 5.17	 2.84	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58047	 1	 7.61	 3.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58048	 1	 5.02	 2.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58049	 1	 5.28	 2.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58050	 1	 5.04	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58051	 1	 2.39	 1.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58052	 1	 4.94	 2.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58053	 1	 4.28	 2.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58054	 1	 9.76	 4.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58055	 1	 5.63	 2.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58056	 1	 3.93	 2.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58057	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58058	 1	 4.97	 2.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58059	 1	 7.72	 3.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58060	 1	 4.08	 2.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58061	 1	 7.23	 3.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58062	 1	 7.53	 4.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58063	 1	 5.89	 2.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58064	 1	 7.24	 4.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58065	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58066	 1	 11.25	 5.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58067	 1	 6.4	 3.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58068	 1	 5.27	 1.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58069	 1	 7.73	 1.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58070	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58071	 1	 4.87	 2.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58072	 1	 6.54	 3.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58073	 1	 7.08	 3.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58074	 1	 7.92	 4.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58075	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58076	 1	 3.05	 1.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58077	 1	 4.54	 2.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58078	 1	 7.47	 4.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58079	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58080	 1	 5.69	 2.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58081	 1	 4.62	 2.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58082	 1	 1.91	 0.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58083	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58084	 1	 7.25	 3.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58085	 1	 5.87	 1.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58086	 1	 16.02	 3.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58087	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58088	 1	 8.83	 1.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58089	 1	 5.64	 2.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58090	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58091	 1	 4.51	 1.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58092	 1	 5.18	 2.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58093	 1	 10.01	 2.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58094	 1	 9.0	 4.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58095	 1	 5.24	 2.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58096	 1	 4.1	 1.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58097	 1	 5.8	 3.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58098	 1	 4.53	 1.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58099	 1	 6.31	 1.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58100	 1	 6.79	 1.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58101	 1	 2.22	 1.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58102	 1	 4.89	 2.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58103	 1	 5.61	 1.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58104	 1	 6.82	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58105	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58106	 1	 4.98	 2.92	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58107	 1	 9.29	 5.75	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58108	 1	 6.86	 3.75	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58109	 1	 5.81	 2.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58110	 1	 4.17	 2.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58111	 1	 9.13	 4.84	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58112	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58113	 1	 11.21	 4.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58114	 1	 7.71	 3.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58115	 1	 4.54	 2.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58116	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58117	 1	 7.58	 4.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58118	 1	 7.49	 4.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58119	 1	 8.56	 4.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58120	 1	 1.71	 1.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58121	 1	 3.25	 1.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58122	 1	 4.9	 2.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58123	 1	 5.43	 2.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58124	 1	 3.3	 1.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58125	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58126	 1	 35.58	 18.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58127	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58128	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58129	 1	 10.88	 4.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58130	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58131	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58132	 1	 2.71	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58133	 1	 3.96	 1.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58134	 1	 4.41	 2.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58135	 1	 2.51	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58136	 1	 8.68	 4.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58137	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58138	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58139	 1	 5.85	 3.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58140	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58141	 1	 3.55	 2.08	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58142	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58143	 1	 18.09	 9.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58144	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58145	 1	 14.76	 5.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58146	 1	 20.14	 10.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58147	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58148	 1	 4.15	 2.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58149	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58150	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58151	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58152	 1	 27.55	 9.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58153	 1	 7.78	 3.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58154	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58155	 1	 7.84	 3.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58156	 1	 3.28	 1.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58157	 1	 5.45	 2.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58158	 1	 4.8	 2.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58159	 1	 5.94	 2.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58160	 1	 6.27	 3.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58161	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58162	 1	 4.65	 2.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58163	 1	 2.6	 1.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58164	 1	 8.55	 4.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58165	 1	 3.16	 1.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58166	 1	 4.61	 2.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58167	 1	 6.01	 3.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58168	 1	 5.01	 2.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58169	 1	 3.17	 1.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58170	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58171	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58172	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58173	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58174	 1	 4.78	 2.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58175	 1	 4.77	 2.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58176	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58177	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58178	 1	 3.86	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58179	 1	 7.45	 3.59	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58180	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58181	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58182	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58183	 1	 12.43	 6.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58184	 1	 4.08	 1.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58185	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58186	 1	 1.05	 0.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58187	 1	 4.1	 2.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58188	 1	 5.54	 2.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58189	 1	 20.42	 7.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58190	 1	 7.85	 4.17	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58191	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58192	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58193	 1	 9.06	 4.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58194	 1	 3.24	 1.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58195	 1	 5.06	 2.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58196	 1	 5.45	 3.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58197	 1	 7.37	 4.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58198	 1	 1.92	 1.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58199	 1	 10.34	 5.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58200	 1	 12.38	 4.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58201	 1	 6.66	 3.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58202	 1	 3.81	 1.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58203	 1	 3.72	 2.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58204	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58205	 1	 5.71	 3.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58206	 1	 4.4	 2.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58207	 1	 4.51	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58208	 1	 15.05	 7.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58209	 1	 6.5	 3.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58210	 1	 5.32	 2.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58211	 1	 3.34	 1.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58212	 1	 2.92	 1.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58213	 1	 8.52	 4.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58214	 1	 10.06	 4.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58215	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58216	 1	 4.09	 2.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58217	 1	 3.38	 1.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58218	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58219	 1	 11.06	 4.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58220	 1	 7.74	 4.2	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58221	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58222	 1	 9.47	 5.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58223	 1	 15.64	 8.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58224	 1	 9.92	 5.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58225	 1	 7.03	 3.83	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58226	 1	 3.5	 0.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58227	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58228	 1	 2.78	 1.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58229	 1	 5.14	 2.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58230	 1	 4.57	 2.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58231	 1	 2.95	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58232	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58233	 1	 8.34	 4.75	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58234	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58235	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58236	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58237	 1	 4.88	 3.08	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58238	 1	 10.84	 5.5	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58239	 1	 14.97	 6.12	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58240	 1	 9.25	 4.6	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58241	 1	 5.79	 2.65	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58242	 1	 5.07	 3.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58243	 1	 18.74	 4.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58244	 1	 8.9	 4.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58245	 1	 4.22	 2.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58246	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58247	 1	 7.44	 1.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58248	 1	 4.32	 0.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58249	 1	 7.81	 1.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58250	 1	 12.06	 7.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58251	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58252	 1	 7.74	 4.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58253	 1	 5.99	 3.46	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58254	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58255	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58256	 1	 4.01	 2.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58257	 1	 8.87	 4.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58258	 1	 11.9	 5.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58259	 1	 0.68	 0.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58260	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58261	 1	 7.01	 2.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58262	 1	 5.0	 2.71	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58263	 1	 6.96	 3.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58264	 1	 5.44	 2.71	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58265	 1	 10.33	 2.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58266	 1	 5.83	 1.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58267	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58268	 1	 7.15	 1.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58269	 1	 7.75	 1.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58270	 1	 2.86	 1.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58271	 1	 6.58	 3.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58272	 1	 9.9	 5.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58273	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58274	 1	 4.35	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58275	 1	 3.32	 1.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58276	 1	 9.2	 5.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58277	 1	 4.73	 2.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58278	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58279	 1	 5.9	 2.79	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58280	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58281	 1	 2.24	 1.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58282	 1	 4.96	 2.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58283	 1	 22.7	 11.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58284	 1	 3.81	 2.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58285	 1	 3.43	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58286	 1	 8.29	 4.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58287	 1	 6.38	 4.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58288	 1	 6.45	 3.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58289	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58290	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58291	 1	 115.5	 52.3	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58292	 1	 0.33	 0.17	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58293	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58294	 1	 4.46	 2.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58295	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58296	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58297	 1	 14.12	 8.87	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58298	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58299	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58300	 1	 8.34	 4.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58301	 1	 8.1	 4.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58302	 1	 7.21	 3.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58303	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58304	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58305	 1	 24.13	 10.99	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58306	 1	 10.18	 5.22	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58307	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58308	 1	 8.81	 4.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58309	 1	 15.45	 8.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58310	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58311	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58312	 1	 3.94	 2.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58313	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58314	 1	 20.49	 9.09	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58315	 1	 17.71	 8.23	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58316	 1	 9.3	 5.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58317	 1	 6.81	 3.77	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58318	 1	 10.09	 2.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58319	 1	 3.04	 0.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58320	 1	 4.21	 1.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58321	 1	 3.23	 0.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58322	 1	 3.76	 0.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58323	 1	 2.32	 0.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58324	 1	 7.97	 1.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58325	 1	 2.8	 0.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58326	 1	 3.49	 2.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58327	 1	 2.87	 1.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58328	 1	 4.09	 2.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58329	 1	 3.32	 1.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58330	 1	 5.17	 1.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58331	 1	 2.61	 1.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58332	 1	 3.27	 0.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58333	 1	 5.38	 1.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58334	 1	 2.5	 0.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58335	 1	 3.1	 0.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58336	 1	 4.84	 1.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58337	 1	 1.75	 0.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58338	 1	 3.78	 0.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58339	 1	 3.65	 0.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58340	 1	 3.5	 2.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58341	 1	 3.29	 1.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58342	 1	 4.17	 2.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58343	 1	 6.48	 3.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58344	 1	 3.7	 1.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58345	 1	 3.45	 2.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58346	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58347	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58348	 1	 4.42	 1.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58349	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58350	 1	 8.35	 4.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58351	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58352	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58353	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58354	 1	 18.59	 4.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58355	 1	 4.02	 1.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58356	 1	 8.75	 5.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58357	 1	 6.81	 4.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58358	 1	 24.08	 12.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58359	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58360	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58361	 1	 6.85	 3.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58362	 1	 2.67	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58363	 1	 6.97	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58364	 1	 5.83	 1.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58365	 1	 8.33	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58366	 1	 7.03	 1.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58367	 1	 6.5	 1.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58368	 1	 5.62	 2.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58369	 1	 4.42	 1.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58370	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58371	 1	 2.09	 1.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58372	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58373	 1	 1.71	 0.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58374	 1	 7.64	 1.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58375	 1	 6.45	 1.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58376	 1	 3.58	 0.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58377	 1	 5.58	 1.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58378	 1	 1.34	 0.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58379	 1	 24.69	 9.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58380	 1	 6.55	 3.02	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58381	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58382	 1	 8.19	 4.26	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58383	 1	 4.22	 2.02	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58384	 1	 13.12	 6.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58385	 1	 9.8	 4.76	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58386	 1	 4.49	 2.79	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58387	 1	 17.17	 3.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58388	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58389	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58390	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58391	 1	 5.41	 1.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58392	 1	 9.48	 4.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58393	 1	 3.4	 1.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58394	 1	 2.7	 1.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58395	 1	 4.1	 1.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58396	 1	 2.57	 1.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58397	 1	 3.57	 1.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58398	 1	 2.07	 1.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58399	 1	 9.81	 5.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58400	 1	 40.09	 18.52	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58401	 1	 3.92	 2.37	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58402	 1	 17.53	 4.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58403	 1	 3.2	 1.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58404	 1	 10.79	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58405	 1	 7.41	 3.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58406	 1	 3.95	 2.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58407	 1	 4.65	 2.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58408	 1	 4.41	 2.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58409	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58410	 1	 3.76	 2.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58411	 1	 6.96	 3.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58412	 1	 7.22	 4.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58413	 1	 30.74	 13.56	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58414	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58415	 1	 3.02	 1.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58416	 1	 19.52	 9.44	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58417	 1	 14.55	 5.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58418	 1	 3.37	 1.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58419	 1	 42.03	 14.99	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58420	 1	 11.85	 6.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58421	 1	 1.36	 0.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58422	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58423	 1	 7.85	 3.79	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58424	 1	 18.81	 7.09	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58425	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58426	 1	 2.75	 1.59	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58427	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58428	 1	 0.33	 0.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58429	 1	 5.33	 2.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58430	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58431	 1	 7.93	 4.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58432	 1	 4.38	 2.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58433	 1	 5.92	 2.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58434	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58435	 1	 3.37	 1.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58436	 1	 2.52	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58437	 1	 4.87	 2.8	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58438	 1	 4.93	 2.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58439	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58440	 1	 4.79	 2.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58441	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58442	 1	 4.94	 1.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58443	 1	 5.43	 1.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58444	 1	 6.5	 3.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58445	 1	 7.97	 1.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58446	 1	 8.29	 4.37	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58447	 1	 7.55	 4.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58448	 1	 3.22	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58449	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58450	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58451	 1	 3.14	 1.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58452	 1	 6.55	 3.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58453	 1	 8.2	 3.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58454	 1	 6.57	 1.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58455	 1	 4.89	 1.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58456	 1	 5.53	 3.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58457	 1	 7.44	 1.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58458	 1	 10.6	 2.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58459	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58460	 1	 6.65	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58461	 1	 7.55	 3.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58462	 1	 7.44	 1.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58463	 1	 10.36	 5.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58464	 1	 5.52	 1.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58465	 1	 9.9	 2.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58466	 1	 2.06	 0.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58467	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58468	 1	 3.14	 0.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58469	 1	 5.77	 1.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58470	 1	 4.58	 1.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58471	 1	 8.89	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58472	 1	 7.32	 1.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58473	 1	 7.72	 1.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58474	 1	 2.79	 1.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58475	 1	 4.51	 1.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58476	 1	 13.73	 6.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58477	 1	 10.19	 4.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58478	 1	 8.19	 4.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58479	 1	 5.58	 3.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58480	 1	 7.37	 3.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58481	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58482	 1	 9.22	 5.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58483	 1	 12.61	 5.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58484	 1	 5.75	 3.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58485	 1	 9.56	 5.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58486	 1	 4.01	 1.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58487	 1	 6.61	 3.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58488	 1	 7.17	 3.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58489	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58490	 1	 10.15	 4.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58491	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58492	 1	 8.35	 1.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58493	 1	 6.7	 3.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58494	 1	 8.53	 4.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58495	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58496	 1	 7.81	 4.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58497	 1	 4.19	 2.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58498	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58499	 1	 7.18	 3.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58500	 1	 6.98	 3.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58501	 1	 11.63	 5.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58502	 1	 16.83	 7.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58503	 1	 6.94	 2.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58504	 1	 6.78	 3.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58505	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58506	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58507	 1	 11.67	 6.27	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58508	 1	 10.68	 3.69	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58509	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58510	 1	 2.82	 1.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58511	 1	 3.53	 2.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58512	 1	 6.12	 2.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58513	 1	 6.29	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58514	 1	 10.5	 6.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58515	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58516	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58517	 1	 7.47	 3.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58518	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58519	 1	 8.85	 5.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58520	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58521	 1	 2.98	 1.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58522	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58523	 1	 9.95	 5.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58524	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58525	 1	 4.12	 1.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58526	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58527	 1	 4.22	 2.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58528	 1	 4.56	 2.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58529	 1	 4.44	 2.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58530	 1	 2.8	 1.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58531	 1	 3.21	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58532	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58533	 1	 2.98	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58534	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58535	 1	 6.2	 3.78	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58536	 1	 27.84	 11.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58537	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58538	 1	 2.26	 1.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58539	 1	 5.36	 2.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58540	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58541	 1	 5.62	 1.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58542	 1	 12.31	 7.34	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58543	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58544	 1	 3.53	 0.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58545	 1	 19.26	 8.47	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58546	 1	 7.77	 3.88	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58547	 1	 4.71	 2.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58548	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58549	 1	 9.36	 4.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58550	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58551	 1	 4.96	 2.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58552	 1	 4.85	 2.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58553	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58554	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58555	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58556	 1	 7.07	 4.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58557	 1	 3.67	 2.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58558	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58559	 1	 6.82	 3.95	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58560	 1	 6.69	 3.58	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58561	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58562	 1	 3.5	 1.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58563	 1	 44.58	 26.04	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58564	 1	 10.81	 5.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58565	 1	 9.74	 5.75	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58566	 1	 9.04	 5.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58567	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58568	 1	 4.33	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58569	 1	 5.31	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58570	 1	 11.39	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58571	 1	 2.89	 1.79	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58572	 1	 2.19	 1.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58573	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58574	 1	 7.19	 3.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75433	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75434	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75435	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75436	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75437	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75438	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75439	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75440	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75441	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75442	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75443	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75444	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75445	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75446	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75447	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75448	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75449	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75450	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75451	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75452	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75453	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75454	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75455	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75456	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75457	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75458	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75459	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75460	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75461	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75462	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75463	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75464	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75465	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75466	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75467	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75468	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75469	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75470	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75471	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75472	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75473	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75474	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75475	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75476	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75477	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75478	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75479	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75480	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75481	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75482	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75483	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75484	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75485	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75486	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75487	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75488	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75489	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75490	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75491	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75492	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75493	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75494	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75495	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75496	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75497	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75498	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75499	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75500	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75501	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75502	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75503	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75504	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75505	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75506	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75507	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75508	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75509	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75510	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75511	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75512	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75513	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75514	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75515	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75516	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75517	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75518	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75519	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75520	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75521	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75522	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75523	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75524	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75525	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75526	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75527	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75528	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75529	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75530	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75531	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75532	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75533	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75534	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75535	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75536	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75537	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75538	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75539	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75540	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75541	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75542	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75543	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75544	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75545	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75546	 2	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75547	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75548	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75549	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75550	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75551	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75552	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75553	 2	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75554	 2	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75555	 2	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75556	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75557	 2	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75558	 1	 7.41	 3.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75559	 1	 11.13	 5.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75560	 1	 5.91	 2.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75561	 1	 19.19	 8.19	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75562	 1	 20.61	 9.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75563	 1	 4.45	 2.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75564	 1	 6.72	 2.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75565	 1	 7.44	 3.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75566	 1	 7.11	 3.26	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75567	 1	 10.35	 4.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75568	 1	 6.17	 2.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75569	 1	 6.85	 3.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75570	 1	 2.92	 1.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75571	 1	 8.92	 4.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75572	 1	 3.23	 1.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75573	 1	 3.38	 1.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75574	 1	 4.26	 2.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75575	 1	 12.92	 6.86	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75576	 1	 3.48	 1.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75577	 1	 8.01	 4.4	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75578	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75579	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75580	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75581	 1	 20.41	 10.4	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75582	 1	 6.09	 3.3	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75583	 1	 4.49	 2.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75584	 1	 5.88	 2.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75585	 1	 4.11	 2.41	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75586	 1	 8.33	 3.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75587	 1	 8.54	 3.91	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75588	 1	 8.34	 4.74	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75589	 1	 5.58	 2.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75590	 1	 18.94	 10.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75591	 1	 4.68	 2.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75592	 1	 27.51	 12.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75593	 1	 22.49	 11.27	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75594	 1	 7.16	 2.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75595	 1	 5.66	 2.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75596	 1	 5.95	 3.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75597	 1	 7.76	 3.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75598	 1	 34.66	 18.71	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75599	 1	 12.76	 5.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75600	 1	 7.72	 3.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75601	 1	 11.06	 5.01	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75602	 1	 24.65	 9.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75603	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75604	 1	 29.04	 9.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75605	 1	 19.4	 9.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75606	 1	 12.73	 5.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75607	 1	 4.56	 1.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75608	 1	 7.6	 3.76	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75609	 1	 18.7	 7.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75610	 1	 5.2	 2.37	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75611	 1	 10.09	 4.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75612	 1	 48.64	 22.19	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75613	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75614	 1	 6.71	 3.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75615	 1	 4.09	 2.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75616	 1	 5.39	 2.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75617	 1	 12.51	 5.65	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75618	 1	 4.57	 2.25	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75619	 1	 12.12	 5.65	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75620	 1	 6.34	 2.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75621	 1	 15.68	 7.11	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75622	 1	 12.91	 6.69	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75623	 1	 2.38	 1.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75624	 1	 3.64	 1.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75625	 1	 5.55	 2.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75626	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75627	 1	 28.11	 13.94	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75628	 1	 15.94	 7.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75629	 1	 9.41	 4.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75630	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75631	 1	 3.62	 1.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75632	 1	 16.67	 6.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75633	 1	 10.48	 4.95	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75634	 1	 17.56	 7.02	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75635	 1	 3.53	 1.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75636	 1	 23.44	 10.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75637	 1	 7.53	 3.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75638	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75639	 1	 22.14	 11.77	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75640	 1	 5.02	 2.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75641	 1	 2.21	 1.06	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75642	 1	 2.01	 1.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75643	 1	 13.25	 5.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75644	 1	 20.47	 7.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75645	 1	 5.84	 3.02	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75646	 1	 4.97	 1.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75647	 1	 28.24	 12.01	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75648	 1	 4.88	 2.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75649	 1	 4.07	 1.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75650	 1	 17.01	 7.17	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75651	 1	 9.07	 4.25	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75652	 1	 29.91	 11.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75653	 1	 6.45	 3.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75654	 1	 5.17	 2.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75655	 1	 7.96	 3.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75656	 1	 10.63	 4.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75657	 1	 8.9	 3.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75658	 1	 24.24	 11.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75659	 1	 4.38	 2.25	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75660	 1	 2.43	 1.22	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75661	 1	 20.71	 7.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75662	 1	 8.54	 4.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75663	 1	 1.82	 0.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75664	 1	 11.21	 5.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75665	 1	 6.49	 3.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75666	 1	 10.64	 4.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75667	 1	 8.6	 4.01	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75668	 1	 10.62	 5.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75669	 1	 17.71	 8.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75670	 1	 12.15	 5.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75671	 1	 11.5	 5.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75672	 1	 7.4	 1.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75673	 1	 15.91	 7.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75674	 1	 5.7	 2.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75675	 1	 8.04	 3.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75676	 1	 5.19	 2.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75677	 1	 8.83	 3.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75678	 1	 19.03	 8.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75679	 1	 15.56	 7.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75680	 1	 7.98	 3.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75681	 1	 4.66	 2.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75682	 1	 6.75	 2.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75683	 1	 6.78	 2.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75684	 1	 7.64	 3.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75685	 1	 6.75	 3.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75686	 1	 26.46	 12.95	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75687	 1	 3.21	 1.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75688	 1	 16.36	 6.67	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75689	 1	 6.85	 3.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75690	 1	 15.46	 6.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75691	 1	 12.52	 5.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75692	 1	 17.22	 8.95	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75693	 1	 8.89	 4.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75694	 1	 7.1	 3.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75695	 1	 7.88	 4.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75696	 1	 7.77	 3.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75697	 1	 15.61	 7.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75698	 1	 91.54	 40.11	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75699	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75700	 1	 10.5	 3.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75701	 1	 8.29	 4.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75702	 1	 10.24	 4.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75703	 1	 7.2	 3.15	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75704	 1	 17.69	 8.37	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75705	 1	 7.94	 3.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75706	 1	 6.8	 3.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75707	 1	 10.68	 5.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75708	 1	 11.66	 5.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75709	 1	 19.09	 8.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75710	 1	 12.15	 6.06	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75711	 1	 15.43	 6.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75712	 1	 4.18	 1.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75713	 1	 6.15	 3.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75714	 1	 6.24	 2.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75715	 1	 4.56	 2.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75716	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75717	 1	 37.52	 17.16	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75718	 1	 8.96	 3.63	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75719	 1	 6.01	 3.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75720	 1	 4.44	 2.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75721	 1	 6.01	 2.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75722	 1	 8.9	 3.76	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75723	 1	 17.25	 8.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75724	 1	 8.87	 4.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75725	 1	 29.88	 15.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75726	 1	 5.58	 3.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75727	 1	 13.5	 6.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75728	 1	 5.69	 2.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75729	 1	 12.11	 6.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75730	 1	 4.68	 2.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75731	 1	 2.72	 1.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75732	 1	 30.17	 11.4	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75733	 1	 13.83	 6.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75734	 1	 27.08	 11.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75735	 1	 11.03	 4.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75736	 1	 15.66	 8.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75737	 1	 11.8	 5.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75738	 1	 23.04	 10.85	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75739	 1	 10.73	 4.94	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75740	 1	 13.66	 6.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75741	 1	 10.76	 4.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75742	 1	 15.76	 6.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75743	 1	 15.73	 5.11	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75744	 1	 42.27	 22.44	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75745	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75746	 1	 16.43	 8.77	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75747	 1	 6.42	 3.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75748	 1	 3.14	 1.37	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75749	 1	 7.12	 3.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75750	 1	 6.49	 3.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75751	 1	 21.37	 8.74	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75752	 1	 3.74	 1.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75753	 1	 6.59	 3.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75754	 1	 20.59	 9.25	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75755	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75756	 1	 28.31	 14.15	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75757	 1	 5.4	 2.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75758	 1	 2.94	 1.65	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75759	 1	 16.55	 8.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75760	 1	 14.23	 6.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75761	 1	 6.82	 3.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75762	 1	 8.5	 4.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75763	 1	 7.41	 3.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75764	 1	 9.2	 4.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75765	 1	 21.14	 8.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75766	 1	 9.96	 4.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75767	 1	 10.46	 5.22	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75768	 1	 3.73	 1.86	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75769	 1	 63.85	 25.43	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75770	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75771	 1	 4.95	 1.92	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75772	 1	 14.42	 7.14	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75773	 1	 8.2	 3.42	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75774	 1	 18.17	 8.31	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75775	 1	 26.22	 9.82	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75776	 1	 13.23	 4.9	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75777	 1	 8.19	 4.61	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75778	 1	 6.52	 3.12	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75779	 1	 10.68	 2.89	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75780	 1	 15.88	 7.43	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75781	 1	 12.44	 4.7	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75782	 1	 8.45	 2.81	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75783	 1	 10.02	 5.22	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75784	 1	 4.32	 2.2	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75785	 1	 14.45	 5.8	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75786	 1	 8.28	 3.2	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75787	 1	 14.41	 4.74	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75788	 1	 21.69	 8.96	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75789	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75790	 1	 31.74	 14.83	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75791	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75792	 1	 4.57	 2.21	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75793	 1	 20.85	 9.03	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75794	 1	 4.29	 1.95	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75795	 1	 11.08	 5.3	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75796	 1	 7.99	 4.52	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75797	 1	 10.28	 5.28	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75798	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75799	 1	 34.2	 15.79	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75800	 1	 15.05	 7.17	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75801	 1	 7.24	 3.29	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75802	 1	 9.29	 4.48	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75803	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75804	 1	 16.11	 6.96	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75805	 1	 22.18	 7.06	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75806	 1	 32.15	 9.89	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75807	 1	 8.62	 3.71	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75808	 1	 15.35	 6.95	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75809	 1	 12.42	 5.38	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75810	 1	 33.01	 14.46	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75811	 1	 2.65	 1.45	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75812	 1	 5.62	 2.79	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75813	 1	 5.41	 2.6	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75814	 1	 8.32	 3.64	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75815	 1	 26.55	 11.59	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75816	 1	 18.83	 8.05	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75817	 1	 20.18	 8.36	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75818	 1	 17.75	 6.03	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75819	 1	 7.15	 2.44	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75820	 1	 5.25	 2.88	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75821	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75822	 1	 18.61	 6.23	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75823	 1	 6.87	 3.76	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75824	 1	 10.1	 4.94	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75825	 1	 12.24	 6.12	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75826	 1	 50.78	 27.52	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75827	 1	 34.66	 18.31	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75828	 1	 1.89	 1.04	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75829	 1	 12.53	 6.75	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75830	 1	 6.25	 3.56	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75831	 1	 3.33	 1.65	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75832	 1	 7.35	 3.28	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75833	 1	 5.01	 2.7	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75834	 1	 22.83	 10.51	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75835	 1	 3.82	 1.85	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75836	 1	 23.92	 9.74	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75837	 1	 18.64	 7.88	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75838	 1	 9.68	 4.85	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75839	 1	 9.44	 3.61	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75840	 1	 8.9	 3.58	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75841	 1	 11.06	 5.05	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75842	 1	 11.04	 4.39	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75843	 1	 25.06	 9.88	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75844	 1	 11.82	 4.57	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75845	 1	 25.52	 10.31	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75846	 1	 18.74	 7.68	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75847	 1	 49.29	 26.41	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75848	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75849	 1	 16.37	 7.7	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75850	 1	 11.57	 5.73	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75851	 1	 28.05	 9.81	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75852	 1	 10.22	 4.97	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75853	 1	 8.65	 3.47	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75854	 1	 22.0	 9.12	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75855	 1	 7.17	 3.78	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75856	 1	 8.25	 3.5	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75857	 1	 33.88	 10.25	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75858	 1	 21.07	 9.53	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75859	 1	 9.1	 4.19	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75860	 1	 5.78	 2.04	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75861	 1	 14.82	 7.62	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75862	 1	 9.58	 4.65	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75863	 1	 10.65	 5.08	 0.0	 0.0	 14	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75864	 1	 6.93	 3.12	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75865	 1	 12.85	 6.28	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75866	 1	 6.34	 2.75	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75867	 1	 4.53	 2.04	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75868	 1	 8.05	 4.2	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75869	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75870	 1	 9.16	 4.22	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75871	 1	 4.03	 2.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75872	 1	 28.96	 12.01	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75873	 1	 10.72	 5.05	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75874	 1	 11.25	 5.01	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75875	 1	 6.98	 3.52	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75876	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75877	 1	 29.09	 10.95	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75878	 1	 12.18	 5.55	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75879	 1	 1.89	 1.04	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75880	 1	 8.32	 3.55	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75881	 1	 13.42	 5.09	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75882	 1	 7.66	 3.15	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75883	 1	 5.28	 2.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75884	 1	 8.53	 3.73	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75885	 1	 8.57	 3.42	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75886	 1	 10.47	 4.4	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75887	 1	 9.03	 4.2	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75888	 1	 19.08	 8.38	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75889	 1	 6.36	 3.32	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75890	 1	 6.55	 3.15	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75891	 1	 3.38	 1.84	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75892	 1	 9.38	 4.45	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75893	 1	 24.5	 10.86	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75894	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75895	 1	 27.99	 12.66	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75896	 1	 16.64	 8.09	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75897	 1	 12.04	 4.18	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75898	 1	 7.35	 3.34	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75899	 1	 5.7	 2.87	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75900	 1	 10.9	 4.89	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75901	 1	 21.76	 10.39	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75902	 1	 11.8	 4.08	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75903	 1	 21.42	 8.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75904	 1	 16.6	 7.91	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75905	 1	 27.78	 11.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75906	 1	 11.81	 5.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75907	 1	 8.7	 4.16	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75908	 1	 32.15	 11.49	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75909	 1	 13.42	 7.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75910	 1	 7.06	 3.63	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75911	 1	 8.22	 3.29	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75912	 1	 14.94	 6.48	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75913	 1	 8.17	 4.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75914	 1	 8.4	 4.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75915	 1	 10.93	 4.58	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75916	 1	 24.06	 11.95	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75917	 1	 10.05	 4.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75918	 1	 9.85	 4.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75919	 1	 7.52	 3.21	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75920	 1	 22.08	 11.09	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75921	 1	 8.63	 3.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75922	 1	 6.75	 3.06	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75923	 1	 3.45	 1.39	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75924	 1	 5.99	 2.75	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75925	 1	 4.74	 1.85	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75926	 1	 10.72	 4.99	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75927	 1	 21.09	 9.57	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75928	 1	 6.38	 3.29	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75929	 1	 14.03	 6.42	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75930	 1	 10.35	 3.61	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75931	 1	 6.13	 3.32	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75932	 1	 18.48	 7.29	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75933	 1	 11.57	 5.48	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75934	 1	 9.13	 4.11	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75935	 1	 7.93	 3.22	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75936	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75937	 1	 6.68	 2.87	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75938	 1	 17.32	 7.09	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75939	 1	 3.6	 1.78	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75940	 1	 8.71	 3.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75941	 1	 3.14	 1.44	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75942	 1	 6.24	 2.99	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75943	 1	 8.56	 3.39	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75944	 1	 10.3	 4.34	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75945	 1	 20.87	 7.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75946	 1	 10.51	 4.25	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75947	 1	 9.57	 4.8	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75948	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75949	 1	 21.94	 9.11	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75950	 1	 8.67	 3.82	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75951	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75952	 1	 31.15	 13.26	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75953	 1	 5.06	 2.29	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75954	 1	 4.21	 2.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75955	 1	 31.32	 12.51	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75956	 1	 9.24	 4.5	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75957	 1	 9.84	 3.74	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75958	 1	 20.51	 8.66	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75959	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75960	 1	 31.51	 11.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75961	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75962	 1	 13.73	 6.34	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75963	 1	 6.14	 2.66	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75964	 1	 7.0	 2.67	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75965	 1	 6.22	 3.18	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75966	 1	 11.48	 5.91	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75967	 1	 9.11	 3.89	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75968	 1	 16.86	 7.55	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75969	 1	 49.1	 21.13	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75970	 1	 16.74	 7.91	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75971	 1	 13.33	 5.86	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75972	 1	 11.73	 5.76	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75973	 1	 6.69	 2.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75974	 1	 12.43	 6.33	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75975	 1	 4.36	 1.92	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75976	 1	 18.83	 7.12	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75977	 1	 13.11	 4.97	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75978	 1	 13.76	 5.6	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75979	 1	 8.67	 4.77	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75980	 1	 13.22	 5.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75981	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75982	 1	 23.52	 10.27	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75983	 1	 7.99	 4.1	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75984	 1	 7.58	 3.93	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75985	 1	 12.02	 5.75	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75986	 1	 33.83	 14.31	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75987	 1	 6.12	 3.32	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75988	 1	 29.21	 10.59	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75989	 1	 10.4	 5.2	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75990	 1	 22.06	 10.4	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75991	 1	 14.25	 6.13	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75992	 1	 13.45	 5.68	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75993	 1	 7.85	 4.18	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75994	 1	 9.32	 4.65	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75995	 1	 10.41	 4.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75996	 1	 5.07	 2.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75997	 1	 5.29	 2.58	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75998	 1	 16.36	 7.51	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75999	 1	 15.74	 7.33	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76000	 1	 14.61	 6.65	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76001	 1	 12.67	 5.88	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76002	 1	 4.46	 2.2	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76003	 1	 3.15	 1.55	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76004	 1	 8.07	 3.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76005	 1	 19.84	 7.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76006	 1	 8.99	 4.46	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76007	 1	 3.52	 1.45	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76008	 1	 12.99	 4.42	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76009	 1	 11.71	 4.05	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76010	 1	 11.47	 5.22	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76011	 1	 10.09	 4.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76012	 1	 9.18	 3.89	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76013	 1	 26.29	 12.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76014	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76015	 1	 26.47	 10.67	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76016	 1	 8.02	 3.05	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76017	 1	 10.7	 4.77	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76018	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76019	 1	 34.45	 14.66	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76020	 1	 6.97	 2.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76021	 1	 6.38	 2.63	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76022	 1	 20.8	 7.12	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76023	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76024	 1	 38.97	 12.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76025	 1	 9.48	 4.46	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76026	 1	 12.63	 4.42	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76027	 1	 18.9	 8.32	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76028	 1	 12.42	 4.52	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76029	 1	 24.66	 9.35	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76030	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76031	 1	 39.24	 17.88	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76032	 1	 12.18	 5.13	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76033	 1	 4.7	 2.17	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76034	 1	 5.96	 2.45	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76035	 1	 3.32	 1.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76036	 1	 5.36	 2.51	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76037	 1	 7.96	 4.19	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76038	 1	 8.22	 4.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76039	 1	 8.4	 4.46	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76040	 1	 8.4	 4.16	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76041	 1	 12.54	 6.05	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76042	 1	 15.92	 6.21	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76043	 1	 6.68	 2.81	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76044	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76045	 1	 53.32	 26.89	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76046	 1	 7.07	 3.14	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76047	 1	 7.52	 4.12	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76048	 1	 5.39	 2.8	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76049	 1	 2.84	 1.07	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76050	 1	 3.29	 1.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76051	 1	 8.78	 3.84	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76052	 1	 4.04	 1.91	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76053	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76054	 1	 21.5	 9.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76055	 1	 1.83	 0.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76056	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76057	 1	 31.06	 14.41	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76058	 1	 30.76	 14.48	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76059	 1	 2.81	 1.38	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76060	 1	 24.83	 12.22	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76061	 1	 20.6	 8.55	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76062	 1	 23.16	 9.84	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76063	 1	 11.46	 4.91	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76064	 1	 6.81	 3.21	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76065	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76066	 1	 26.47	 9.53	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76067	 1	 4.89	 2.61	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76068	 1	 4.38	 2.25	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76069	 1	 7.15	 3.59	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76070	 1	 4.64	 1.77	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76071	 1	 7.13	 3.38	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76072	 1	 4.65	 2.43	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76073	 1	 12.9	 4.69	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76074	 1	 16.61	 7.31	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76075	 1	 41.02	 18.57	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76076	 1	 26.66	 9.96	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76077	 1	 4.75	 2.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76078	 1	 10.59	 5.31	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76079	 1	 11.14	 5.2	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76080	 1	 7.9	 3.92	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76081	 1	 3.3	 1.34	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76082	 1	 14.62	 4.87	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76083	 1	 6.12	 2.77	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76084	 1	 13.12	 6.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76085	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76086	 1	 26.77	 9.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76087	 1	 15.57	 7.58	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76088	 1	 11.14	 4.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76089	 1	 2.44	 1.17	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76090	 1	 17.34	 7.7	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76091	 1	 23.47	 8.65	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76092	 1	 15.65	 6.72	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76093	 1	 6.12	 2.53	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76094	 1	 13.05	 6.21	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76095	 1	 8.98	 4.48	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76096	 1	 21.34	 9.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76097	 1	 11.08	 5.69	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76098	 1	 12.89	 6.15	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76099	 1	 13.04	 6.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76100	 1	 11.7	 5.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76101	 1	 7.86	 2.69	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76102	 1	 7.73	 3.55	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76103	 1	 8.88	 4.26	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76104	 1	 8.86	 4.38	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76105	 1	 7.48	 3.5	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76106	 1	 10.94	 5.13	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76107	 1	 7.14	 3.01	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76108	 1	 20.98	 7.59	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76109	 1	 5.76	 2.88	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76110	 1	 9.32	 4.66	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76111	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76112	 1	 8.01	 4.36	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76113	 1	 15.65	 7.4	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76114	 1	 13.02	 6.05	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76115	 1	 18.15	 7.12	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76116	 1	 7.32	 3.04	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76117	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76118	 1	 23.14	 9.68	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76119	 1	 8.64	 3.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76120	 1	 5.67	 2.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76121	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76122	 1	 24.28	 9.28	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76123	 1	 10.11	 5.21	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76124	 1	 4.88	 2.36	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76125	 1	 5.06	 2.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76126	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76127	 1	 22.07	 9.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76128	 1	 9.41	 4.19	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76129	 1	 11.53	 4.89	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76130	 1	 5.66	 2.75	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76131	 1	 3.37	 1.52	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76132	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76133	 1	 39.25	 15.43	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76134	 1	 23.34	 9.85	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76135	 1	 11.95	 4.88	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76136	 1	 14.9	 6.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76137	 1	 7.59	 3.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76138	 1	 21.04	 7.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76139	 1	 7.43	 3.74	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76140	 1	 14.85	 6.47	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76141	 1	 10.95	 4.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76142	 1	 8.7	 4.52	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76143	 1	 17.93	 9.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76144	 1	 13.13	 5.96	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76145	 1	 13.28	 4.53	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76146	 1	 16.75	 8.76	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76147	 1	 13.57	 6.96	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76148	 1	 10.71	 5.04	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76149	 1	 10.09	 3.93	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76150	 1	 5.18	 2.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76151	 1	 12.23	 6.26	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76152	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76153	 1	 14.88	 7.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76154	 1	 5.15	 2.12	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76155	 1	 9.7	 4.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76156	 1	 9.51	 3.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76157	 1	 7.24	 3.77	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76158	 1	 15.64	 8.01	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76159	 1	 5.29	 2.57	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76160	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76161	 1	 18.81	 8.38	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76162	 1	 5.96	 2.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76163	 1	 3.67	 1.62	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76164	 1	 7.43	 3.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76165	 1	 8.2	 4.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76166	 1	 9.33	 4.24	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76167	 1	 10.39	 3.85	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76168	 1	 4.46	 2.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76169	 1	 9.36	 4.17	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76170	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76171	 1	 17.69	 6.85	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76172	 1	 8.72	 4.18	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76173	 1	 4.02	 2.01	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76174	 1	 6.36	 2.77	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76175	 1	 3.78	 1.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76176	 1	 14.13	 5.84	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76177	 1	 9.66	 5.16	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76178	 1	 10.96	 5.31	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76179	 1	 15.92	 7.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76180	 1	 9.49	 4.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76181	 1	 10.86	 4.75	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76182	 1	 8.7	 4.13	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76183	 1	 5.23	 2.24	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76184	 1	 12.44	 5.99	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76185	 1	 4.04	 1.81	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76186	 1	 4.51	 1.99	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76187	 1	 19.87	 9.13	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76188	 1	 19.67	 9.22	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76189	 1	 32.45	 14.11	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76190	 1	 10.56	 5.71	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76191	 1	 13.17	 5.4	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76192	 1	 4.98	 2.36	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76193	 1	 2.61	 1.33	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76194	 1	 19.74	 7.8	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76195	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76196	 1	 32.13	 14.49	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76197	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76198	 1	 14.56	 7.32	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76199	 1	 3.62	 1.99	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76200	 1	 16.87	 7.31	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76201	 1	 8.69	 3.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76202	 1	 13.16	 6.02	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76203	 1	 23.19	 9.92	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76204	 1	 8.76	 3.57	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76205	 1	 9.93	 5.16	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76206	 1	 4.99	 2.4	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76207	 1	 3.1	 1.43	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76208	 1	 8.18	 3.25	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76209	 1	 5.39	 2.92	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76210	 1	 5.83	 3.08	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76211	 1	 6.82	 2.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76212	 1	 3.62	 1.93	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76213	 1	 3.2	 1.31	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76214	 1	 2.87	 1.3	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76215	 1	 3.3	 1.55	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76216	 1	 4.58	 2.1	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76217	 1	 6.89	 3.63	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76218	 1	 6.98	 2.96	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76219	 1	 8.17	 3.58	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76220	 1	 16.07	 6.4	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76221	 1	 7.84	 3.46	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76222	 1	 11.63	 4.81	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76223	 1	 21.08	 8.08	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76224	 1	 13.1	 5.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76225	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76226	 1	 27.15	 13.77	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76227	 1	 18.14	 7.1	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76228	 1	 14.85	 7.48	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76229	 1	 14.96	 5.24	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76230	 1	 10.14	 3.96	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76231	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76232	 1	 23.17	 10.64	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76233	 1	 6.69	 2.7	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76234	 1	 21.45	 7.83	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76235	 1	 17.25	 6.13	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76236	 1	 5.67	 2.27	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76237	 1	 18.4	 7.56	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76238	 1	 9.8	 4.86	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76239	 1	 6.47	 3.17	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76240	 1	 5.76	 2.29	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76241	 1	 15.75	 6.4	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76242	 1	 10.46	 4.94	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76243	 1	 10.88	 4.39	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76244	 1	 14.15	 5.5	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76245	 1	 5.8	 3.03	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76246	 1	 10.58	 5.09	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76247	 1	 21.35	 8.13	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76248	 1	 5.59	 2.79	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76249	 1	 3.71	 1.86	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76250	 1	 5.21	 2.27	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76251	 1	 9.18	 3.91	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76252	 1	 42.43	 19.56	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76253	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76254	 1	 7.22	 2.64	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76255	 1	 16.3	 7.32	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76256	 1	 3.25	 1.54	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76257	 1	 6.52	 2.36	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76258	 1	 9.9	 4.23	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76259	 1	 11.77	 5.63	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76260	 1	 17.66	 8.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76261	 1	 14.51	 6.55	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76262	 1	 2.9	 1.42	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76263	 1	 6.68	 3.32	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76264	 1	 26.31	 11.98	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76265	 1	 6.46	 3.37	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76266	 1	 10.53	 4.76	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76267	 1	 15.3	 6.29	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76268	 1	 10.08	 3.99	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76269	 1	 9.2	 3.43	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76270	 1	 9.59	 4.81	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76271	 1	 9.13	 4.22	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76272	 1	 35.4	 13.95	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76273	 1	 7.25	 3.68	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76274	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76275	 1	 8.82	 4.76	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76276	 1	 8.19	 4.3	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76277	 1	 1.97	 0.95	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76278	 1	 4.86	 1.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76279	 1	 14.47	 5.6	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76280	 1	 9.38	 3.67	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76281	 1	 14.68	 6.53	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76282	 1	 23.89	 10.29	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76283	 1	 13.03	 4.9	 0.0	 0.0	 16	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76284	 1	 14.47	 5.14	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76285	 1	 8.96	 3.52	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76286	 1	 16.47	 5.01	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76287	 1	 8.63	 1.98	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76288	 1	 12.64	 5.43	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76289	 1	 10.43	 4.53	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76290	 1	 16.83	 8.14	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76291	 1	 5.54	 2.78	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76292	 1	 5.31	 2.24	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76293	 1	 7.65	 3.44	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76294	 1	 17.11	 8.24	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76295	 1	 19.96	 8.79	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76296	 1	 8.74	 2.02	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76297	 1	 3.29	 1.65	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76298	 1	 4.09	 1.9	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76299	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76300	 1	 23.44	 9.59	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76301	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76302	 1	 34.92	 16.51	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76303	 1	 16.21	 6.23	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76304	 1	 6.44	 2.99	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76305	 1	 11.16	 4.57	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76306	 1	 4.82	 1.91	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76307	 1	 7.04	 2.93	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76308	 1	 14.88	 7.22	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76309	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76310	 1	 21.0	 7.96	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76311	 1	 14.79	 6.25	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76312	 1	 10.93	 5.33	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76313	 1	 22.55	 8.17	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76314	 1	 14.64	 6.1	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76315	 1	 14.27	 5.56	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76316	 1	 9.01	 3.07	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76317	 1	 12.71	 6.14	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76318	 1	 29.6	 10.57	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76319	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76320	 1	 34.11	 14.11	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76321	 1	 10.81	 5.18	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76322	 1	 14.07	 6.17	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76323	 1	 5.72	 2.42	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76324	 1	 20.33	 9.57	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76325	 1	 15.2	 7.2	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76326	 1	 19.43	 6.89	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76327	 1	 8.02	 3.28	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76328	 1	 12.83	 5.88	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76329	 1	 12.91	 6.62	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76330	 1	 5.79	 2.49	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76331	 1	 11.09	 5.24	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76332	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76333	 1	 26.79	 13.05	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76334	 1	 3.62	 1.89	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76335	 1	 10.05	 4.76	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76336	 1	 17.81	 7.01	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76337	 1	 4.0	 1.96	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76338	 1	 4.46	 1.92	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76339	 1	 7.74	 3.09	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76340	 1	 11.07	 5.94	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76341	 1	 11.22	 4.34	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76342	 1	 14.58	 7.18	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76343	 1	 19.42	 8.2	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76344	 1	 14.0	 6.47	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76345	 1	 5.39	 2.76	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76346	 1	 7.38	 3.33	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76347	 1	 8.97	 4.31	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76348	 1	 6.31	 3.26	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76349	 1	 15.5	 6.76	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76350	 1	 14.52	 6.68	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76351	 1	 16.27	 6.39	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76352	 1	 7.21	 2.83	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76353	 1	 12.1	 5.33	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76354	 1	 13.82	 6.45	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76355	 1	 20.87	 10.27	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76356	 1	 37.67	 14.06	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76357	 1	 7.01	 3.39	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76358	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76359	 1	 19.87	 8.43	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76360	 1	 5.45	 2.3	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76361	 1	 16.73	 6.4	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76362	 1	 11.4	 4.79	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76363	 1	 13.29	 5.67	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76364	 1	 14.24	 6.62	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76365	 1	 9.6	 3.76	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76366	 1	 0.0	 0.0	 0.0	 0.0	 22	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76367	 1	 18.08	 8.29	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76368	 1	 20.92	 8.57	 0.0	 0.0	 22	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76369	 1	 5.98	 3.31	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76370	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76371	 1	 6.78	 2.83	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76372	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76373	 1	 7.38	 3.15	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76374	 1	 11.84	 5.91	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76375	 1	 7.0	 2.89	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76376	 1	 20.57	 10.8	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76377	 1	 3.03	 1.77	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76378	 1	 4.04	 1.94	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76379	 1	 3.27	 1.67	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76380	 1	 13.87	 7.46	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76381	 1	 7.17	 4.07	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76382	 1	 16.59	 7.7	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76383	 1	 26.72	 12.13	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76384	 1	 8.37	 4.54	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76385	 1	 5.32	 2.38	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76386	 1	 27.47	 13.5	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76387	 1	 0.0	 0.0	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76388	 1	 7.09	 3.44	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76389	 1	 16.87	 9.8	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76390	 1	 5.44	 2.9	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76391	 1	 8.64	 3.88	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76392	 1	 5.51	 3.22	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76393	 1	 7.0	 3.75	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76394	 1	 12.14	 5.89	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76395	 1	 4.52	 2.39	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76396	 1	 6.48	 3.26	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76397	 1	 5.82	 3.32	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76398	 1	 4.2	 1.88	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76399	 1	 12.15	 6.42	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76400	 1	 7.23	 3.95	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76401	 1	 14.99	 6.63	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76402	 1	 3.17	 1.9	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76403	 1	 7.0	 3.57	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76404	 1	 31.69	 17.04	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76405	 1	 12.71	 5.5	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76406	 1	 6.26	 3.11	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76407	 1	 9.21	 4.98	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76408	 1	 6.76	 3.36	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76409	 1	 3.85	 1.88	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76410	 1	 4.0	 1.66	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76411	 1	 7.53	 3.63	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76412	 1	 11.7	 4.66	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76413	 1	 6.87	 3.35	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76414	 1	 4.89	 2.71	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76415	 1	 11.84	 6.27	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76416	 1	 4.19	 2.38	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76417	 1	 6.37	 2.95	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76418	 1	 7.83	 3.71	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76419	 1	 8.01	 4.29	 0.0	 0.0	 30	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76420	 1	 2.58	 1.37	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76421	 1	 9.62	 2.57	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76422	 1	 17.45	 5.15	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76423	 1	 6.75	 3.43	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76424	 1	 14.57	 6.01	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76425	 1	 6.21	 2.15	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76426	 1	 4.44	 2.4	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76427	 1	 8.52	 4.0	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76428	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76429	 1	 21.53	 11.66	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76430	 1	 13.3	 5.97	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76431	 1	 19.35	 9.17	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76432	 1	 10.69	 5.33	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76433	 1	 14.85	 7.39	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76434	 1	 6.69	 2.44	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76435	 1	 14.47	 5.72	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76436	 1	 15.75	 5.0	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76437	 1	 10.62	 2.48	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76438	 1	 11.96	 4.43	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76439	 1	 6.0	 1.38	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76440	 1	 7.6	 1.75	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76441	 1	 7.72	 3.13	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76442	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76443	 1	 18.53	 7.29	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76444	 1	 6.54	 2.55	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76445	 1	 3.93	 1.68	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76446	 1	 18.25	 8.5	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76447	 1	 8.57	 3.62	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76448	 1	 5.53	 2.22	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76449	 1	 0.0	 0.0	 0.0	 0.0	 35	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76450	 1	 24.55	 8.09	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76451	 1	 3.38	 1.63	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76452	 1	 14.19	 6.22	 0.0	 0.0	 35	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76453	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76454	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76455	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76456	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76457	 1	 5.16	 2.83	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76458	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76459	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76460	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76461	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76462	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76463	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76464	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76465	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76466	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76467	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76468	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76469	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76470	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76471	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76472	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76473	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76474	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76475	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76476	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76477	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76478	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76479	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76480	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76481	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76482	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76483	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76484	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76485	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76486	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76487	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76488	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76489	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76490	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76491	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76492	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76493	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76494	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76495	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76496	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76497	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76498	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76499	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76500	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76501	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76502	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76503	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76504	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76505	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76506	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76507	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76508	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76509	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76510	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76511	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76512	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76513	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76514	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76515	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76516	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76517	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76518	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76519	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76520	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76521	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76522	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76523	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76524	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76525	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76526	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76527	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76528	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76529	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76530	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76531	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76532	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76533	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76534	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76535	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76536	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76537	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76538	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76539	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76540	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76541	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76542	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76543	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76544	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76545	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76546	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76547	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76548	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76549	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76550	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76551	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76552	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76553	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76554	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76555	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76556	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76557	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76558	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76559	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76560	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76561	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76562	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76563	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76564	 2	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76565	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76566	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76567	 1	 13.0	 5.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76568	 1	 14.96	 6.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76569	 1	 35.14	 19.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76570	 1	 7.17	 3.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76571	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76572	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76573	 1	 17.65	 4.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76574	 1	 9.17	 2.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76575	 1	 22.02	 5.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76576	 1	 6.4	 1.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76577	 1	 6.17	 3.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76578	 1	 22.08	 10.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76579	 1	 30.46	 15.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76580	 1	 16.27	 5.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76581	 1	 5.49	 2.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76582	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76583	 1	 29.61	 7.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76584	 1	 5.89	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76585	 1	 16.92	 4.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76586	 1	 12.22	 2.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76587	 1	 11.28	 2.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76588	 1	 8.9	 2.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76589	 1	 7.59	 1.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76590	 1	 21.28	 5.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76591	 1	 5.31	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76592	 1	 9.73	 2.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76593	 1	 6.72	 1.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76594	 1	 8.62	 2.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76595	 1	 6.67	 1.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76596	 1	 7.12	 1.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76597	 1	 9.15	 2.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76598	 1	 6.77	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76599	 1	 23.55	 5.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76600	 1	 11.54	 2.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76601	 1	 14.39	 3.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76602	 1	 4.56	 1.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76603	 1	 6.85	 1.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76604	 1	 6.17	 1.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76605	 1	 8.45	 2.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76606	 1	 6.29	 1.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76607	 1	 9.93	 2.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76608	 1	 8.53	 2.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76609	 1	 6.48	 1.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76610	 1	 6.1	 1.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76611	 1	 7.07	 1.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76612	 1	 6.75	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76613	 1	 8.89	 2.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76614	 1	 8.43	 2.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76615	 1	 18.69	 4.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76616	 1	 5.9	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76617	 1	 6.04	 1.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76618	 1	 8.38	 2.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76619	 1	 6.26	 1.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76620	 1	 7.5	 1.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76621	 1	 28.95	 6.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76622	 1	 11.86	 2.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76623	 1	 12.84	 3.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76624	 1	 24.59	 5.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76625	 1	 11.59	 2.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76626	 1	 4.66	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76627	 1	 11.01	 2.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76628	 1	 4.18	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76629	 1	 6.05	 1.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76630	 1	 4.99	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76631	 1	 8.23	 1.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76632	 1	 3.93	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76633	 1	 5.94	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76634	 1	 1.46	 0.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76635	 1	 8.08	 1.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76636	 1	 11.97	 2.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76637	 1	 4.37	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76638	 1	 6.79	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76639	 1	 5.86	 1.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76640	 1	 9.94	 2.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76641	 1	 21.65	 5.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76642	 1	 4.35	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76643	 1	 7.03	 1.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76644	 1	 23.39	 5.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76645	 1	 8.37	 2.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76646	 1	 28.94	 6.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76647	 1	 6.14	 1.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76648	 1	 7.79	 1.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76649	 1	 4.76	 1.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76650	 1	 2.83	 0.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76651	 1	 9.22	 2.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76652	 1	 3.6	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76653	 1	 6.04	 1.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76654	 1	 41.21	 23.76	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76655	 1	 21.37	 5.18	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76656	 1	 12.08	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76657	 1	 10.07	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76658	 1	 3.15	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76659	 1	 2.03	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76660	 1	 11.54	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76661	 1	 2.75	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76662	 1	 3.01	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76663	 1	 21.01	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76664	 1	 12.33	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76665	 1	 26.1	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76666	 1	 10.45	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76667	 1	 23.45	 8.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76668	 1	 3.52	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76669	 1	 6.83	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76670	 1	 10.7	 2.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76671	 1	 26.05	 6.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76672	 1	 13.57	 3.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76673	 1	 21.05	 7.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76674	 1	 9.79	 4.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76675	 1	 12.55	 5.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76676	 1	 9.87	 5.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76677	 1	 11.6	 6.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76678	 1	 34.15	 15.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76679	 1	 17.62	 4.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76680	 1	 13.31	 3.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76681	 1	 8.22	 1.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76682	 1	 18.32	 4.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76683	 1	 11.07	 5.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76684	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76685	 1	 3.46	 1.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76686	 1	 5.66	 2.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76687	 1	 17.24	 7.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76688	 1	 7.68	 1.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76689	 1	 4.3	 2.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76690	 1	 8.9	 4.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76691	 1	 7.33	 3.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76692	 1	 7.7	 4.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76693	 1	 6.64	 3.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76694	 1	 12.1	 5.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76695	 1	 2.65	 1.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76696	 1	 2.43	 1.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76697	 1	 4.12	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76698	 1	 17.0	 3.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76699	 1	 13.61	 3.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76700	 1	 8.6	 2.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76701	 1	 21.58	 9.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76702	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76703	 1	 15.34	 7.68	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76704	 1	 7.61	 3.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76705	 1	 29.63	 10.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76706	 1	 5.9	 3.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76707	 1	 19.25	 8.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76708	 1	 5.61	 2.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76709	 1	 6.92	 3.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76710	 1	 6.33	 1.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76711	 1	 3.74	 1.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76712	 1	 16.36	 8.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76713	 1	 7.1	 3.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76714	 1	 4.04	 2.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76715	 1	 6.41	 3.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76716	 1	 10.57	 2.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76717	 1	 11.22	 3.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76718	 1	 7.98	 4.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76719	 1	 8.44	 4.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76720	 1	 8.27	 3.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76721	 1	 35.59	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76722	 1	 1.96	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76723	 1	 3.52	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76724	 1	 5.97	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76725	 1	 9.29	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76726	 1	 5.02	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76727	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76728	 1	 4.49	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76729	 1	 3.26	 1.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76730	 1	 3.4	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76731	 1	 15.75	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76732	 1	 4.05	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76733	 1	 1.91	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76734	 1	 12.96	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76735	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76736	 1	 24.01	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76737	 1	 9.57	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76738	 1	 6.43	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76739	 1	 1.6	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76740	 1	 19.45	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76741	 1	 7.43	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76742	 1	 19.8	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76743	 1	 14.23	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76744	 1	 3.53	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76745	 1	 4.88	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76746	 1	 10.52	 4.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76747	 1	 12.87	 6.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76748	 1	 8.39	 3.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76749	 1	 16.42	 8.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76750	 1	 4.8	 2.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76751	 1	 19.31	 10.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76752	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76753	 1	 19.55	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76754	 1	 13.73	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76755	 1	 10.83	 5.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76756	 1	 24.31	 9.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76757	 1	 25.81	 5.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76758	 1	 8.1	 1.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76759	 1	 4.57	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76760	 1	 7.98	 4.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76761	 1	 21.98	 9.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76762	 1	 1.99	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76763	 1	 9.46	 3.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76764	 1	 9.51	 2.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76765	 1	 6.29	 3.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76766	 1	 2.73	 1.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76767	 1	 3.37	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76768	 1	 14.6	 4.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76769	 1	 15.67	 3.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76770	 1	 14.12	 3.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76771	 1	 17.4	 4.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76772	 1	 4.74	 1.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76773	 1	 17.51	 4.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76774	 1	 22.33	 5.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76775	 1	 11.64	 2.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76776	 1	 9.79	 2.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76777	 1	 8.21	 2.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76778	 1	 20.55	 5.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76779	 1	 45.71	 18.37	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76780	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76781	 1	 14.12	 3.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76782	 1	 14.52	 3.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76783	 1	 14.6	 3.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76784	 1	 9.66	 2.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76785	 1	 5.67	 1.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76786	 1	 26.78	 6.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76787	 1	 6.57	 1.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76788	 1	 7.74	 1.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76789	 1	 4.85	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76790	 1	 13.21	 3.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76791	 1	 5.66	 1.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76792	 1	 5.35	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76793	 1	 5.19	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76794	 1	 3.69	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76795	 1	 3.37	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76796	 1	 13.84	 3.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76797	 1	 4.01	 0.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76798	 1	 4.7	 1.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76799	 1	 6.32	 1.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76800	 1	 6.0	 1.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76801	 1	 16.31	 3.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76802	 1	 4.8	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76803	 1	 4.32	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76804	 1	 6.17	 1.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76805	 1	 10.13	 2.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76806	 1	 3.65	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76807	 1	 5.03	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76808	 1	 5.55	 1.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76809	 1	 11.42	 2.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76810	 1	 5.29	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76811	 1	 5.84	 1.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76812	 1	 4.99	 1.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76813	 1	 4.22	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76814	 1	 9.47	 2.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76815	 1	 2.82	 0.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76816	 1	 3.88	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76817	 1	 8.34	 2.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76818	 1	 2.66	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76819	 1	 9.36	 2.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76820	 1	 7.85	 1.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76821	 1	 5.43	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76822	 1	 2.33	 0.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76823	 1	 7.7	 1.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76824	 1	 8.73	 2.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76825	 1	 3.96	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76826	 1	 7.19	 1.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76827	 1	 4.15	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76828	 1	 3.01	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76829	 1	 4.96	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76830	 1	 7.44	 1.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76831	 1	 6.71	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76832	 1	 5.48	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76833	 1	 5.4	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76834	 1	 2.77	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76835	 1	 5.04	 1.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76836	 1	 16.52	 3.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76837	 1	 10.2	 2.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76838	 1	 6.33	 1.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76839	 1	 8.0	 1.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76840	 1	 7.54	 1.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76841	 1	 4.11	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76842	 1	 9.82	 2.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76843	 1	 10.44	 2.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76844	 1	 7.39	 1.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76845	 1	 11.13	 2.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76846	 1	 7.37	 1.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76847	 1	 5.48	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76848	 1	 5.57	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76849	 1	 3.31	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76850	 1	 4.43	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76851	 1	 5.46	 1.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76852	 1	 3.12	 0.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76853	 1	 3.77	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76854	 1	 4.66	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76855	 1	 4.65	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76856	 1	 8.08	 1.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76857	 1	 5.27	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76858	 1	 5.55	 1.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76859	 1	 6.11	 1.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76860	 1	 9.13	 2.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76861	 1	 5.32	 1.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76862	 1	 41.51	 20.63	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76863	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76864	 1	 4.84	 1.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76865	 1	 7.85	 1.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76866	 1	 5.4	 1.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76867	 1	 5.48	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76868	 1	 9.32	 2.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76869	 1	 10.61	 2.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76870	 1	 12.84	 3.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76871	 1	 6.94	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76872	 1	 5.35	 1.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76873	 1	 8.87	 2.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76874	 1	 6.49	 1.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76875	 1	 5.66	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76876	 1	 8.24	 1.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76877	 1	 4.58	 1.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76878	 1	 3.43	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76879	 1	 6.78	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76880	 1	 4.24	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76881	 1	 5.55	 1.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76882	 1	 7.46	 1.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76883	 1	 10.5	 2.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76884	 1	 4.21	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76885	 1	 8.82	 2.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76886	 1	 9.21	 2.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76887	 1	 9.88	 2.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76888	 1	 6.3	 1.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76889	 1	 3.87	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76890	 1	 4.66	 1.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76891	 1	 5.26	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76892	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76893	 1	 18.93	 4.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76894	 1	 7.32	 1.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76895	 1	 6.01	 1.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76896	 1	 4.09	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76897	 1	 11.98	 2.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76898	 1	 10.27	 2.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76899	 1	 8.88	 2.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76900	 1	 17.17	 4.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76901	 1	 1.29	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76902	 1	 7.03	 1.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76903	 1	 7.89	 1.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76904	 1	 16.56	 3.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76905	 1	 2.79	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76906	 1	 6.18	 1.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76907	 1	 9.18	 2.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76908	 1	 7.7	 1.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76909	 1	 24.04	 5.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76910	 1	 12.9	 3.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76911	 1	 8.41	 1.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76912	 1	 8.04	 1.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76913	 1	 5.32	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76914	 1	 6.09	 1.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76915	 1	 8.98	 2.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76916	 1	 6.83	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76917	 1	 2.06	 0.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76918	 1	 7.2	 1.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76919	 1	 7.05	 1.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76920	 1	 10.44	 2.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76921	 1	 6.74	 1.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76922	 1	 26.07	 10.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76923	 1	 16.95	 4.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76924	 1	 25.55	 6.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76925	 1	 4.56	 2.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76926	 1	 10.78	 4.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76927	 1	 5.86	 3.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76928	 1	 21.0	 5.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76929	 1	 31.82	 7.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76930	 1	 3.91	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76931	 1	 5.31	 1.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76932	 1	 28.33	 6.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76933	 1	 2.43	 0.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76934	 1	 1.92	 0.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76935	 1	 9.28	 2.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76936	 1	 6.94	 1.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76937	 1	 2.93	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76938	 1	 36.02	 8.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76939	 1	 2.54	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76940	 1	 2.59	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76941	 1	 3.1	 0.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76942	 1	 3.68	 2.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76943	 1	 6.01	 2.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76944	 1	 17.18	 7.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76945	 1	 6.75	 1.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76946	 1	 18.18	 4.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76947	 1	 5.17	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76948	 1	 7.42	 1.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76949	 1	 10.99	 2.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76950	 1	 13.35	 3.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76951	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76952	 1	 34.8	 8.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76953	 1	 15.47	 3.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76954	 1	 14.91	 3.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76955	 1	 26.23	 6.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76956	 1	 4.33	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76957	 1	 10.9	 2.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76958	 1	 1.56	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76959	 1	 15.3	 3.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76960	 1	 12.38	 2.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76961	 1	 16.31	 4.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76962	 1	 32.26	 7.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76963	 1	 20.22	 4.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76964	 1	 8.38	 2.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76965	 1	 16.72	 4.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76966	 1	 1.54	 0.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76967	 1	 4.92	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76968	 1	 10.09	 2.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76969	 1	 18.72	 4.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76970	 1	 13.46	 3.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76971	 1	 10.78	 2.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76972	 1	 6.51	 1.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76973	 1	 6.41	 1.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76974	 1	 3.89	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76975	 1	 4.07	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76976	 1	 3.63	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76977	 1	 11.59	 2.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76978	 1	 9.83	 2.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76979	 1	 7.89	 1.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76980	 1	 40.93	 19.81	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76981	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76982	 1	 9.64	 2.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76983	 1	 6.21	 1.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76984	 1	 5.04	 1.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76985	 1	 8.87	 2.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76986	 1	 15.37	 3.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76987	 1	 6.99	 1.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76988	 1	 6.83	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76989	 1	 5.95	 1.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76990	 1	 28.42	 6.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76991	 1	 21.11	 5.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76992	 1	 13.95	 3.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76993	 1	 2.83	 0.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76994	 1	 6.96	 1.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76995	 1	 9.26	 2.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76996	 1	 19.22	 4.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76997	 1	 20.52	 5.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76998	 1	 7.7	 1.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76999	 1	 3.39	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77000	 1	 8.86	 2.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77001	 1	 22.92	 5.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77002	 1	 4.75	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77003	 1	 4.03	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77004	 1	 25.87	 6.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77005	 1	 8.06	 3.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77006	 1	 10.66	 2.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77007	 1	 24.55	 5.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77008	 1	 7.27	 1.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77009	 1	 1.21	 0.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77010	 1	 20.71	 5.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77011	 1	 6.51	 2.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77012	 1	 12.01	 2.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77013	 1	 4.82	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77014	 1	 8.69	 2.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77015	 1	 0.81	 0.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77016	 1	 12.19	 3.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77017	 1	 10.44	 2.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77018	 1	 9.71	 2.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77019	 1	 9.62	 2.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77020	 1	 11.97	 2.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77021	 1	 3.52	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77022	 1	 15.59	 3.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77023	 1	 9.26	 2.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77024	 1	 10.9	 2.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77025	 1	 11.17	 2.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77026	 1	 19.84	 4.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77027	 1	 12.46	 3.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77028	 1	 21.75	 5.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77029	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77030	 1	 19.09	 4.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77031	 1	 16.59	 4.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77032	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77033	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77034	 1	 27.88	 6.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77035	 1	 10.3	 2.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77036	 1	 16.13	 3.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77037	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77038	 1	 26.58	 6.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77039	 1	 11.98	 2.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77040	 1	 22.53	 5.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77041	 1	 21.89	 5.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77042	 1	 60.65	 29.06	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77043	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77044	 1	 16.72	 4.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77045	 1	 7.49	 1.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77046	 1	 15.34	 3.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77047	 1	 27.69	 6.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77048	 1	 10.92	 2.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77049	 1	 19.59	 4.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77050	 1	 16.35	 3.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77051	 1	 17.29	 4.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77052	 1	 24.79	 6.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77053	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77054	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77055	 1	 32.63	 7.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77056	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77057	 1	 22.38	 5.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77058	 1	 11.91	 2.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77059	 1	 25.62	 6.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77060	 1	 18.8	 4.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77061	 1	 7.61	 1.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77062	 1	 18.98	 4.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77063	 1	 16.09	 3.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77064	 1	 9.49	 2.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77065	 1	 16.04	 3.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77066	 1	 11.58	 2.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77067	 1	 19.81	 4.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77068	 1	 14.92	 3.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77069	 1	 13.56	 3.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77070	 1	 20.82	 5.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77071	 1	 8.3	 2.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77072	 1	 30.49	 7.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77073	 1	 16.39	 3.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77074	 1	 9.61	 2.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77075	 1	 22.65	 5.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77076	 1	 10.75	 2.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77077	 1	 6.48	 1.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77078	 1	 15.69	 3.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77079	 1	 21.31	 5.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77080	 1	 22.61	 5.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77081	 1	 17.89	 4.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77082	 1	 3.96	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77083	 1	 7.72	 1.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77084	 1	 16.55	 4.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77085	 1	 6.62	 1.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77086	 1	 8.65	 2.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77087	 1	 15.31	 3.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77088	 1	 4.32	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77089	 1	 12.36	 2.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77090	 1	 7.09	 1.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77091	 1	 5.78	 1.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77092	 1	 14.69	 3.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77093	 1	 21.4	 5.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77094	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77095	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77096	 1	 29.03	 7.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77097	 1	 12.71	 3.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77098	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77099	 1	 9.18	 2.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77100	 1	 10.41	 2.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77101	 1	 9.68	 2.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77102	 1	 13.76	 3.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77103	 1	 19.56	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77104	 1	 23.45	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77105	 1	 3.6	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77106	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77107	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77108	 1	 11.3	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77109	 1	 34.72	 10.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77110	 1	 36.76	 14.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77111	 1	 6.34	 3.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77112	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77113	 1	 13.09	 3.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77114	 1	 4.2	 0.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77115	 1	 16.92	 3.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77116	 1	 3.91	 0.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77117	 1	 3.37	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77118	 1	 6.79	 1.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77119	 1	 5.75	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77120	 1	 12.26	 2.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77121	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77122	 1	 29.4	 6.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77123	 1	 10.16	 3.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77124	 1	 6.35	 1.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77125	 1	 5.63	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77126	 1	 12.13	 2.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77127	 1	 7.88	 1.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77128	 1	 4.47	 1.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77129	 1	 4.63	 2.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77130	 1	 11.34	 2.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77131	 1	 12.86	 3.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77132	 1	 26.97	 6.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77133	 1	 18.36	 4.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77134	 1	 4.08	 2.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77135	 1	 1.49	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77136	 1	 3.69	 1.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77137	 1	 1.74	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77138	 1	 2.47	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77139	 1	 2.39	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77140	 1	 3.51	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77141	 1	 3.29	 1.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77142	 1	 4.22	 2.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77143	 1	 17.96	 4.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77144	 1	 12.93	 5.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77145	 1	 2.37	 1.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77146	 1	 1.57	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77147	 1	 4.7	 2.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77148	 1	 3.98	 1.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77149	 1	 3.1	 1.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77150	 1	 2.13	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77151	 1	 11.06	 4.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77152	 1	 7.83	 1.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77153	 1	 9.94	 3.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77154	 1	 5.71	 3.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77155	 1	 22.59	 11.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77156	 1	 6.03	 2.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77157	 1	 71.12	 25.76	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77158	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77159	 1	 19.51	 9.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77160	 1	 11.07	 5.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77161	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77162	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77163	 1	 6.06	 3.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77164	 1	 12.5	 2.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77165	 1	 2.07	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77166	 1	 8.77	 2.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77167	 1	 3.77	 0.89	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77168	 1	 4.57	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77169	 1	 7.48	 1.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77170	 1	 16.25	 3.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77171	 1	 9.81	 5.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77172	 1	 4.29	 2.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77173	 1	 19.34	 7.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77174	 1	 9.64	 2.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77175	 1	 12.83	 5.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77176	 1	 27.39	 8.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77177	 1	 27.6	 12.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77178	 1	 6.79	 1.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77179	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77180	 1	 29.98	 16.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77181	 1	 5.18	 2.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77182	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77183	 1	 38.17	 17.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77184	 1	 26.74	 12.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77185	 1	 19.12	 9.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77186	 1	 16.74	 8.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77187	 1	 8.31	 4.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77188	 1	 9.69	 4.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77189	 1	 19.2	 4.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77190	 1	 5.39	 2.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77191	 1	 6.72	 3.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77192	 1	 5.54	 2.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77193	 1	 7.55	 3.07	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77194	 1	 34.13	 13.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77195	 1	 13.1	 4.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77196	 1	 10.89	 5.1	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77197	 1	 1.89	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77198	 1	 6.67	 2.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77199	 1	 3.25	 1.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77200	 1	 9.98	 5.39	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77201	 1	 2.09	 0.49	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77202	 1	 19.73	 4.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77203	 1	 7.8	 1.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77204	 1	 18.39	 4.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77205	 1	 5.74	 3.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77206	 1	 9.22	 3.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77207	 1	 6.16	 2.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77208	 1	 16.46	 3.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77209	 1	 11.35	 2.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77210	 1	 4.08	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77211	 1	 3.97	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77212	 1	 4.38	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77213	 1	 6.03	 1.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77214	 1	 5.2	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77215	 1	 7.24	 1.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77216	 1	 10.49	 2.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77217	 1	 6.95	 1.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77218	 1	 4.07	 1.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77219	 1	 5.43	 1.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77220	 1	 2.71	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77221	 1	 1.77	 0.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77222	 1	 3.81	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77223	 1	 3.91	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77224	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77225	 1	 3.81	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77226	 1	 4.58	 1.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77227	 1	 5.47	 1.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77228	 1	 1.33	 0.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77229	 1	 3.38	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77230	 1	 5.97	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77231	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77232	 1	 4.29	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77233	 1	 2.12	 1.07	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77234	 1	 4.1	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77235	 1	 2.37	 0.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77236	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77237	 1	 3.06	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77238	 1	 10.52	 2.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77239	 1	 26.18	 6.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77240	 1	 17.25	 4.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77241	 1	 3.23	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77242	 1	 23.27	 5.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77243	 1	 14.75	 3.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77244	 1	 9.66	 2.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77245	 1	 4.41	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77246	 1	 8.13	 1.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77247	 1	 4.26	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77248	 1	 11.25	 2.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77249	 1	 4.07	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77250	 1	 7.98	 1.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77251	 1	 4.92	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77252	 1	 5.82	 1.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77253	 1	 4.44	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77254	 1	 3.03	 0.74	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77255	 1	 3.9	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77256	 1	 2.53	 0.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77257	 1	 17.18	 4.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77258	 1	 4.98	 1.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77259	 1	 8.51	 2.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77260	 1	 10.72	 2.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77261	 1	 11.02	 2.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77262	 1	 6.17	 1.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77263	 1	 11.51	 2.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77264	 1	 8.76	 2.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77265	 1	 12.95	 3.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77266	 1	 12.06	 2.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77267	 1	 6.59	 1.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77268	 1	 4.36	 1.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77269	 1	 5.61	 1.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77270	 1	 6.2	 1.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77271	 1	 14.47	 3.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77272	 1	 4.24	 1.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77273	 1	 5.38	 1.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77274	 1	 3.35	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77275	 1	 4.26	 1.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77276	 1	 1.5	 0.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77277	 1	 4.42	 1.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77278	 1	 5.93	 1.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77279	 1	 24.9	 5.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77280	 1	 6.23	 1.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77281	 1	 4.06	 0.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77282	 1	 3.62	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77283	 1	 4.79	 1.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77284	 1	 3.49	 0.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77285	 1	 26.32	 6.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77286	 1	 14.73	 3.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77287	 1	 6.72	 1.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77288	 1	 6.92	 1.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77289	 1	 5.87	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77290	 1	 4.21	 1.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77291	 1	 6.59	 1.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77292	 1	 9.3	 2.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77293	 1	 5.78	 1.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77294	 1	 3.3	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77295	 1	 5.41	 1.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77296	 1	 3.0	 0.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77297	 1	 1.67	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77298	 1	 14.83	 3.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77299	 1	 3.98	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77300	 1	 5.77	 1.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77301	 1	 6.32	 1.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77302	 1	 6.41	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77303	 1	 4.92	 1.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77304	 1	 3.27	 0.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77305	 1	 0.92	 0.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77306	 1	 2.72	 0.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77307	 1	 1.66	 0.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77308	 1	 9.7	 2.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77309	 1	 4.83	 1.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77310	 1	 2.62	 0.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77311	 1	 4.96	 1.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77312	 1	 5.37	 1.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77313	 1	 0.84	 0.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77314	 1	 3.85	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77315	 1	 2.6	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77316	 1	 3.43	 0.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77317	 1	 3.0	 0.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77318	 1	 12.62	 3.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77319	 1	 3.6	 0.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77320	 1	 10.6	 2.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77321	 1	 16.25	 3.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77322	 1	 11.07	 2.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77323	 1	 30.59	 7.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77324	 1	 13.3	 3.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77325	 1	 3.17	 0.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77326	 1	 10.75	 2.59	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77327	 1	 11.18	 2.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77328	 1	 2.81	 0.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77329	 1	 9.23	 2.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77330	 1	 1.86	 0.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77331	 1	 5.55	 1.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77332	 1	 5.36	 1.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77333	 1	 8.86	 2.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77334	 1	 12.57	 3.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77335	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77336	 1	 31.74	 7.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77337	 1	 11.45	 2.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77338	 1	 3.99	 0.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77339	 1	 5.44	 1.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77340	 1	 10.9	 2.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77341	 1	 14.45	 3.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77342	 1	 13.18	 3.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77343	 1	 9.91	 2.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77344	 1	 1.24	 0.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77345	 1	 15.74	 3.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77346	 1	 16.5	 3.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77347	 1	 4.4	 1.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77348	 1	 3.77	 0.91	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77349	 1	 8.19	 1.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77350	 1	 8.41	 2.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77351	 1	 13.88	 3.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77352	 1	 7.76	 1.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77353	 1	 1.44	 0.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77354	 1	 11.92	 2.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77355	 1	 8.51	 2.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77356	 1	 13.62	 3.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77357	 1	 20.14	 4.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77358	 1	 6.05	 1.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77359	 1	 58.32	 28.39	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77360	 1	 20.78	 7.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77361	 1	 12.97	 6.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77362	 1	 25.37	 12.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77363	 1	 8.01	 4.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77364	 1	 9.56	 2.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77365	 1	 8.85	 2.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77366	 1	 11.38	 5.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77367	 1	 7.05	 1.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77368	 1	 6.99	 1.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77369	 1	 12.88	 6.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77370	 1	 4.68	 2.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77371	 1	 10.4	 5.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77372	 1	 4.06	 2.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77373	 1	 13.05	 6.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77374	 1	 12.9	 5.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77375	 1	 8.55	 4.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77376	 1	 14.02	 7.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77377	 1	 3.62	 1.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77378	 1	 4.53	 2.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77379	 1	 5.98	 3.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77380	 1	 4.12	 1.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77381	 1	 8.69	 5.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77382	 1	 7.23	 3.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77383	 1	 6.59	 3.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77384	 1	 6.01	 3.58	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77385	 1	 5.05	 2.41	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77386	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77387	 1	 4.21	 2.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77388	 1	 5.35	 2.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77389	 1	 10.88	 6.25	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77390	 1	 26.04	 12.21	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77391	 1	 9.59	 4.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77392	 1	 4.58	 2.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77393	 1	 17.74	 9.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77394	 1	 15.06	 6.72	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77395	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77396	 1	 16.84	 7.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77397	 1	 10.28	 5.73	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77398	 1	 10.81	 5.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77399	 1	 3.39	 1.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77400	 1	 13.56	 7.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77401	 1	 2.03	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77402	 1	 26.38	 12.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77403	 1	 18.72	 9.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77404	 1	 10.54	 5.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77405	 1	 10.12	 5.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77406	 1	 2.59	 1.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77407	 1	 18.48	 9.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77408	 1	 7.68	 3.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77409	 1	 19.37	 4.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77410	 1	 13.61	 5.33	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77411	 1	 18.22	 10.84	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77412	 1	 5.55	 2.64	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77413	 1	 35.47	 10.68	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77414	 1	 7.34	 3.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77415	 1	 11.13	 4.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77416	 1	 20.73	 9.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77417	 1	 10.44	 5.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77418	 1	 7.31	 3.67	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77419	 1	 8.16	 4.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77420	 1	 23.33	 8.64	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77421	 1	 8.2	 4.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77422	 1	 9.15	 4.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77423	 1	 11.95	 5.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77424	 1	 7.77	 3.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77425	 1	 3.85	 0.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77426	 1	 79.69	 37.26	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77427	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77428	 1	 32.0	 7.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77429	 1	 11.98	 2.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77430	 1	 11.26	 2.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77431	 1	 15.59	 3.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77432	 1	 6.91	 3.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77433	 1	 3.58	 2.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77434	 1	 12.72	 3.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77435	 1	 11.06	 2.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77436	 1	 13.03	 3.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77437	 1	 25.42	 5.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77438	 1	 11.42	 2.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77439	 1	 13.17	 3.23	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77440	 1	 7.76	 1.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77441	 1	 27.44	 6.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77442	 1	 12.03	 6.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77443	 1	 3.97	 1.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77444	 1	 8.03	 4.69	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77445	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77446	 1	 16.17	 7.16	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77447	 1	 1.69	 0.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77448	 1	 18.63	 9.88	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77449	 1	 7.55	 3.33	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77450	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77451	 1	 37.13	 14.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77452	 1	 28.21	 6.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77453	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77454	 1	 2.0	 1.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77455	 1	 4.62	 2.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77456	 1	 8.69	 4.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77457	 1	 5.01	 2.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77458	 1	 29.96	 14.95	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77459	 1	 5.62	 1.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77460	 1	 17.4	 4.2	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77461	 1	 20.65	 5.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77462	 1	 21.3	 5.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77463	 1	 9.85	 2.38	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77464	 1	 19.52	 8.06	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77465	 1	 42.96	 17.98	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77466	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77467	 1	 11.76	 5.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77468	 1	 3.62	 1.71	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77469	 1	 11.3	 5.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77470	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77471	 1	 21.34	 10.7	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77472	 1	 8.59	 5.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77473	 1	 13.74	 6.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77474	 1	 13.38	 4.82	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77475	 1	 3.4	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77476	 1	 1.52	 0.36	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77477	 1	 6.88	 3.5	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77478	 1	 16.85	 7.87	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77479	 1	 22.48	 10.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77480	 1	 5.33	 2.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77481	 1	 6.86	 3.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77482	 1	 10.89	 5.51	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77483	 1	 8.51	 4.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77484	 1	 14.43	 8.21	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77485	 1	 13.45	 7.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77486	 1	 2.72	 1.61	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77487	 1	 3.86	 2.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77488	 1	 42.32	 23.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77489	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77490	 1	 10.81	 6.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77491	 1	 15.43	 8.12	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77492	 1	 19.11	 10.77	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77493	 1	 15.03	 6.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77494	 1	 16.06	 8.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77495	 1	 16.17	 8.62	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77496	 1	 6.97	 3.43	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77497	 1	 7.72	 4.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77498	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77499	 1	 5.95	 3.19	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77500	 1	 4.05	 2.14	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77501	 1	 2.17	 0.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77502	 1	 3.46	 1.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77503	 1	 5.42	 1.26	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77504	 1	 5.62	 1.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77505	 1	 18.39	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77506	 1	 8.4	 2.05	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77507	 1	 16.86	 4.17	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77508	 1	 3.01	 1.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77509	 1	 4.82	 1.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77510	 1	 3.41	 0.8	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77511	 1	 7.29	 3.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77512	 1	 6.81	 3.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77513	 1	 4.24	 1.84	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77514	 1	 18.06	 6.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77515	 1	 7.5	 1.74	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77516	 1	 10.34	 2.39	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77517	 1	 7.46	 3.56	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77518	 1	 9.3	 3.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77519	 1	 5.39	 2.35	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77520	 1	 6.88	 2.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77521	 1	 1.43	 0.66	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77522	 1	 4.51	 2.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77523	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77524	 1	 32.58	 13.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77525	 1	 10.49	 3.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77526	 1	 24.66	 10.47	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77527	 1	 12.56	 3.04	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77528	 1	 9.49	 3.29	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77529	 1	 11.35	 2.75	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77530	 1	 1.71	 0.83	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77531	 1	 13.52	 3.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77532	 1	 10.68	 2.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77533	 1	 2.61	 0.63	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77534	 1	 4.76	 1.15	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77535	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77536	 1	 9.91	 2.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77537	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77538	 1	 17.23	 4.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77539	 1	 3.3	 0.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77540	 1	 14.15	 6.87	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77541	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77542	 1	 9.79	 5.06	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77543	 1	 6.01	 1.45	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77544	 1	 6.32	 1.53	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77545	 1	 9.44	 2.3	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77546	 1	 8.66	 2.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77547	 1	 2.1	 0.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77548	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77549	 1	 6.05	 1.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77550	 1	 5.23	 1.27	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77551	 1	 5.55	 1.34	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77552	 1	 5.03	 1.22	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77553	 1	 6.03	 1.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77554	 1	 6.39	 1.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77555	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77556	 1	 44.17	 18.98	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77557	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77558	 1	 4.03	 0.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77559	 1	 10.37	 2.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77560	 1	 8.84	 2.13	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77561	 1	 6.13	 1.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77562	 1	 8.76	 2.11	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77563	 1	 31.38	 7.57	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77564	 1	 12.46	 3.01	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77565	 1	 8.46	 2.02	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77566	 1	 7.39	 1.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77567	 1	 14.24	 3.4	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77568	 1	 5.91	 1.42	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77569	 1	 15.9	 3.79	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77570	 1	 24.22	 5.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77571	 1	 14.4	 3.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77572	 1	 19.26	 4.6	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77573	 1	 9.7	 2.32	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77574	 1	 12.38	 2.98	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77575	 1	 9.03	 2.18	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77576	 1	 8.78	 2.09	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77577	 1	 2.22	 0.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77578	 1	 12.44	 2.99	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77579	 1	 3.91	 0.94	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77580	 1	 5.74	 1.37	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77581	 1	 3.51	 0.85	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77582	 1	 7.12	 1.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77583	 1	 2.66	 1.39	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77584	 1	 10.49	 2.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77585	 1	 16.76	 4.08	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77586	 1	 24.62	 5.96	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77587	 1	 10.96	 2.65	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77588	 1	 3.24	 0.78	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77589	 1	 7.83	 1.9	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77590	 1	 0.0	 0.0	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77591	 1	 11.75	 2.86	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77592	 1	 5.52	 2.72	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77593	 1	 10.18	 4.95	 0.0	 0.0	 24	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77594	 1	 5.4	 3.1	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77595	 1	 10.15	 2.44	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77596	 1	 10.19	 4.54	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77597	 1	 19.07	 4.52	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77598	 1	 18.49	 10.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77599	 1	 8.83	 4.81	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77600	 1	 13.51	 5.97	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77601	 1	 8.58	 3.76	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77602	 1	 15.69	 6.93	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77603	 1	 2.65	 1.48	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77604	 1	 10.09	 4.92	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77605	 1	 12.62	 5.46	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77606	 1	 14.1	 8.03	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77607	 1	 23.07	 5.55	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77608	 1	 32.21	 15.24	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77609	 1	 19.19	 8.28	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77610	 1	 5.29	 1.31	 0.0	 0.0	 24	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77611	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77612	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77613	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77614	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77615	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77616	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77617	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77618	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77619	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77620	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77621	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77622	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77623	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77624	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77625	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77626	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77627	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77628	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77629	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77630	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77631	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77632	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77633	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77634	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77635	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77636	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77637	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77638	 1	 60.83	 46.72	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77639	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77640	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77641	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77642	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77643	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77644	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77645	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77646	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77647	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77648	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77649	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77650	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77651	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77652	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77653	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77654	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77655	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77656	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77657	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77658	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77659	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77660	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77661	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77662	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77663	 2	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77664	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77665	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77666	 1	 9.47	 3.25	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77667	 1	 35.4	 9.86	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77668	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77669	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77670	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77671	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77672	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77673	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77674	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77675	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77676	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77677	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77678	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77679	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77680	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77681	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77682	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77683	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77684	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77685	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77686	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77687	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77688	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77689	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77690	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77691	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77692	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77693	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77694	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77695	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77696	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77697	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77698	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77699	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77700	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77701	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77702	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77703	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77704	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77705	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77706	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77707	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77708	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77709	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77710	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77711	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77712	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77713	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77714	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77715	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77716	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77717	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77718	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77719	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77720	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77721	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77722	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77723	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77724	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77725	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77726	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77727	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77728	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77729	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77730	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77731	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77732	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77733	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77734	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77735	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77736	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77737	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77738	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77739	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77740	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77741	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77742	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77743	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77744	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77745	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77746	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77747	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77748	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77749	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77750	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77751	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77752	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77753	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77754	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77755	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77756	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77757	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77758	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77759	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77760	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77761	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77762	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77763	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77764	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77765	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77766	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77767	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77768	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77769	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77770	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77771	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77772	 2	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77773	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77774	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77775	 1	 8.11	 5.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77776	 1	 18.29	 11.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77777	 1	 3.84	 2.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77778	 1	 2.07	 1.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77779	 1	 12.32	 7.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77780	 1	 7.25	 4.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77781	 1	 7.84	 4.78	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77782	 1	 26.69	 21.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77783	 1	 13.34	 9.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77784	 1	 6.54	 4.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77785	 1	 6.77	 4.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77786	 1	 7.71	 5.96	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77787	 1	 10.47	 8.35	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77788	 1	 1.43	 0.96	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77789	 1	 4.83	 3.65	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77790	 1	 3.43	 2.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77791	 1	 3.12	 0.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77792	 1	 6.9	 1.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77793	 1	 1.71	 0.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77794	 1	 3.95	 0.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77795	 1	 11.09	 2.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77796	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77797	 1	 6.73	 1.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77798	 1	 7.25	 1.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77799	 1	 9.72	 2.37	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77800	 1	 27.02	 6.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77801	 1	 6.96	 1.7	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77802	 1	 6.35	 1.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77803	 1	 7.19	 1.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77804	 1	 16.06	 3.93	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77805	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77806	 1	 18.35	 4.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77807	 1	 8.42	 2.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77808	 1	 5.2	 1.29	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77809	 1	 6.71	 1.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77810	 1	 7.58	 1.86	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77811	 1	 13.3	 3.28	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77812	 1	 4.68	 1.16	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77813	 1	 8.79	 2.18	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77814	 1	 6.36	 1.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77815	 1	 8.14	 2.02	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77816	 1	 12.98	 3.2	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77817	 1	 10.58	 2.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77818	 1	 17.95	 10.24	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77819	 1	 7.55	 1.86	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77820	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77821	 1	 19.45	 10.4	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77822	 1	 14.61	 3.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77823	 1	 5.67	 1.36	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77824	 1	 4.62	 1.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77825	 1	 9.3	 2.28	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77826	 1	 15.47	 3.74	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77827	 1	 6.4	 1.54	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77828	 1	 9.49	 2.27	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77829	 1	 14.88	 3.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77830	 1	 5.82	 1.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77831	 1	 8.95	 2.17	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77832	 1	 7.37	 1.81	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77833	 1	 10.43	 2.56	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77834	 1	 4.68	 1.14	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77835	 1	 13.19	 3.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77836	 1	 4.55	 1.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77837	 1	 6.23	 1.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77838	 1	 5.34	 1.3	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77839	 1	 11.88	 2.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77840	 1	 3.55	 0.86	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77841	 1	 11.83	 8.1	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77842	 1	 19.18	 12.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77843	 1	 6.33	 4.17	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77844	 1	 4.86	 2.92	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77845	 1	 10.92	 8.28	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77846	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77847	 1	 10.2	 7.26	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77848	 1	 2.94	 2.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77849	 1	 1.72	 1.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77850	 1	 7.84	 5.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77851	 1	 10.6	 8.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77852	 1	 5.13	 3.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77853	 1	 3.69	 2.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77854	 1	 2.22	 1.54	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77855	 1	 3.85	 2.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77856	 1	 18.63	 11.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77857	 1	 7.77	 4.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77858	 1	 5.2	 3.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77859	 1	 19.26	 11.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77860	 1	 20.9	 12.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77861	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77862	 1	 16.52	 10.17	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77863	 1	 4.88	 3.39	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77864	 1	 7.42	 4.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77865	 1	 4.44	 2.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77866	 1	 12.28	 6.86	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77867	 1	 3.66	 2.82	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77868	 1	 5.96	 3.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77869	 1	 8.38	 4.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77870	 1	 4.68	 2.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77871	 1	 4.8	 3.47	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77872	 1	 13.1	 7.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77873	 1	 8.66	 6.26	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77874	 1	 13.49	 9.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77875	 1	 4.25	 2.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77876	 1	 5.39	 3.34	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77877	 1	 5.74	 3.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77878	 1	 3.99	 2.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77879	 1	 1.97	 1.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77880	 1	 3.88	 2.56	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77881	 1	 3.24	 2.5	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77882	 1	 9.55	 6.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77883	 1	 6.62	 5.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77884	 1	 4.11	 2.46	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77885	 1	 5.14	 3.18	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77886	 1	 7.61	 4.56	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77887	 1	 3.11	 1.88	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77888	 1	 2.55	 1.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77889	 1	 6.46	 4.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77890	 1	 10.12	 2.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77891	 1	 9.31	 5.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77892	 1	 5.53	 3.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77893	 1	 9.73	 5.37	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77894	 1	 7.73	 4.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77895	 1	 10.32	 7.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77896	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77897	 1	 26.79	 19.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77898	 1	 23.25	 15.36	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77899	 1	 3.99	 2.5	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77900	 1	 14.78	 8.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77901	 1	 6.53	 4.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77902	 1	 5.16	 3.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77903	 1	 3.4	 2.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77904	 1	 4.75	 3.51	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77905	 1	 11.96	 9.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77906	 1	 7.37	 4.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77907	 1	 5.97	 4.1	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77908	 1	 1.53	 1.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77909	 1	 3.72	 2.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77910	 1	 4.68	 3.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77911	 1	 4.48	 2.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77912	 1	 5.25	 3.3	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77913	 1	 4.93	 3.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77914	 1	 4.85	 3.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77915	 1	 9.91	 5.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77916	 1	 19.22	 12.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77917	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77918	 1	 16.02	 9.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77919	 1	 8.89	 4.96	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77920	 1	 17.38	 13.36	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77921	 1	 2.79	 1.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77922	 1	 5.36	 3.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77923	 1	 3.63	 2.18	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77924	 1	 5.85	 4.47	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77925	 1	 3.66	 2.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77926	 1	 7.09	 4.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77927	 1	 2.78	 1.92	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77928	 1	 1.09	 0.71	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77929	 1	 2.47	 1.86	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77930	 1	 2.25	 1.46	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77931	 1	 2.4	 1.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77932	 1	 11.3	 7.3	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77933	 1	 2.24	 1.43	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77934	 1	 5.07	 3.8	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77935	 1	 2.74	 1.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77936	 1	 2.72	 1.95	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77937	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77938	 1	 20.57	 13.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77939	 1	 4.76	 2.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77940	 1	 5.55	 4.1	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77941	 1	 13.69	 9.89	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77942	 1	 4.32	 2.75	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77943	 1	 9.9	 6.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77944	 1	 11.91	 8.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77945	 1	 3.04	 2.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77946	 1	 7.55	 5.46	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77947	 1	 12.09	 9.19	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77948	 1	 7.4	 4.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77949	 1	 2.91	 2.15	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77950	 1	 4.43	 3.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77951	 1	 3.86	 2.54	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77952	 1	 5.45	 3.92	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77953	 1	 3.88	 2.5	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77954	 1	 2.22	 1.5	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77955	 1	 8.15	 1.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77956	 1	 7.91	 1.93	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77957	 1	 4.75	 3.41	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77958	 1	 2.5	 1.67	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77959	 1	 5.89	 4.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77960	 1	 18.77	 12.02	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77961	 1	 3.25	 2.01	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77962	 1	 11.06	 7.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77963	 1	 10.67	 2.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77964	 1	 2.59	 1.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77965	 1	 2.74	 1.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77966	 1	 2.28	 1.43	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77967	 1	 3.37	 2.21	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77968	 1	 6.18	 4.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77969	 1	 9.26	 5.36	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77970	 1	 6.63	 4.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77971	 1	 9.87	 6.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77972	 1	 5.14	 3.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77973	 1	 3.63	 2.43	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77974	 1	 6.82	 4.33	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77975	 1	 8.91	 5.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77976	 1	 11.57	 6.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77977	 1	 4.41	 3.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77978	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77979	 1	 36.25	 26.47	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77980	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77981	 1	 3.96	 2.47	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77982	 1	 5.07	 3.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77983	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77984	 1	 17.87	 12.3	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77985	 1	 14.11	 9.71	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77986	 1	 1.74	 1.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77987	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77988	 1	 82.38	 51.63	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77989	 1	 11.03	 8.29	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77990	 1	 32.92	 21.02	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77991	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77992	 1	 28.54	 16.89	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77993	 1	 9.52	 7.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77994	 1	 6.33	 3.71	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77995	 1	 4.69	 2.9	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77996	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77997	 1	 13.14	 9.02	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77998	 1	 5.52	 3.95	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77999	 1	 2.8	 1.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78000	 1	 6.3	 3.86	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78001	 1	 4.43	 3.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78002	 1	 3.58	 2.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78003	 1	 11.59	 8.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78004	 1	 6.72	 4.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78005	 1	 4.77	 2.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78006	 1	 6.04	 3.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78007	 1	 10.67	 6.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78008	 1	 41.71	 30.85	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78009	 1	 4.39	 1.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78010	 1	 11.03	 6.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78011	 1	 9.53	 6.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78012	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78013	 1	 8.91	 6.74	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78014	 1	 3.07	 1.92	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78015	 1	 6.07	 3.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78016	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78017	 1	 4.3	 3.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78018	 1	 12.25	 8.33	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78019	 1	 3.86	 2.96	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78020	 1	 9.9	 7.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78021	 1	 9.22	 5.9	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78022	 1	 10.21	 6.14	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78023	 1	 4.62	 3.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78024	 1	 9.22	 6.92	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78025	 1	 6.57	 4.38	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78026	 1	 6.83	 5.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78027	 1	 2.79	 1.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78028	 1	 6.33	 4.37	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78029	 1	 6.48	 1.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78030	 1	 9.11	 6.02	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78031	 1	 3.05	 1.77	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78032	 1	 14.07	 3.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78033	 1	 8.46	 5.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78034	 1	 11.65	 7.26	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78035	 1	 5.91	 3.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78036	 1	 90.64	 67.08	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78037	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78038	 1	 3.13	 2.42	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78039	 1	 5.13	 3.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78040	 1	 79.75	 58.65	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78041	 1	 2.39	 1.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78042	 1	 1.27	 0.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78043	 1	 2.37	 1.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78044	 1	 8.62	 6.1	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78045	 1	 5.75	 1.41	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78046	 1	 4.99	 1.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78047	 1	 7.49	 1.84	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78048	 1	 22.35	 5.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78049	 1	 8.01	 5.04	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78050	 1	 7.14	 1.75	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78051	 1	 5.6	 1.38	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78052	 1	 5.32	 1.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78053	 1	 6.03	 1.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78054	 1	 6.56	 1.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78055	 1	 5.32	 1.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78056	 1	 4.22	 1.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78057	 1	 5.03	 1.24	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78058	 1	 2.49	 0.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78059	 1	 2.54	 0.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78060	 1	 4.85	 1.19	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78061	 1	 5.18	 1.29	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78062	 1	 2.36	 0.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78063	 1	 2.96	 0.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78064	 1	 2.79	 0.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78065	 1	 10.01	 2.46	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78066	 1	 4.46	 1.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78067	 1	 8.5	 2.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78068	 1	 5.35	 1.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78069	 1	 11.31	 8.2	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78070	 1	 2.05	 1.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78071	 1	 7.5	 5.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78072	 1	 14.82	 8.78	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78073	 1	 21.25	 15.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78074	 1	 7.53	 4.54	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78075	 1	 4.72	 3.21	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78076	 1	 4.05	 2.93	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78077	 1	 3.01	 1.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78078	 1	 3.08	 1.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78079	 1	 5.95	 4.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78080	 1	 8.66	 5.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78081	 1	 3.91	 2.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78082	 1	 4.35	 2.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78083	 1	 5.43	 3.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78084	 1	 6.99	 4.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78085	 1	 17.53	 11.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78086	 1	 4.87	 3.33	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78087	 1	 7.84	 6.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78088	 1	 13.29	 8.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78089	 1	 9.23	 7.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78090	 1	 11.5	 7.38	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78091	 1	 6.79	 5.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78092	 1	 8.45	 6.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78093	 1	 18.51	 11.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78094	 1	 12.85	 8.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78095	 1	 2.89	 2.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78096	 1	 10.07	 7.36	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78097	 1	 22.39	 16.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78098	 1	 3.3	 2.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78099	 1	 6.6	 4.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78100	 1	 14.8	 8.65	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78101	 1	 6.45	 4.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78102	 1	 11.69	 7.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78103	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78104	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78105	 1	 35.64	 20.69	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78106	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78107	 1	 14.27	 8.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78108	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78109	 1	 4.76	 3.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78110	 1	 5.73	 4.16	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78111	 1	 8.49	 6.39	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78112	 1	 17.08	 11.74	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78113	 1	 11.53	 7.84	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78114	 1	 5.58	 3.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78115	 1	 8.68	 5.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78116	 1	 5.66	 4.3	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78117	 1	 4.08	 2.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78118	 1	 9.57	 6.8	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78119	 1	 2.99	 2.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78120	 1	 3.22	 2.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78121	 1	 5.95	 4.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78122	 1	 5.36	 3.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78123	 1	 3.18	 2.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78124	 1	 9.46	 6.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78125	 1	 16.66	 11.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78126	 1	 25.29	 16.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78127	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78128	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78129	 1	 18.04	 14.7	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78130	 1	 18.32	 11.47	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78131	 1	 3.31	 2.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78132	 1	 29.28	 19.88	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78133	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78134	 1	 4.6	 3.14	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78135	 1	 6.71	 4.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78136	 1	 6.6	 5.16	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78137	 1	 16.73	 12.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78138	 1	 6.46	 4.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78139	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78140	 1	 7.33	 5.26	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78141	 1	 4.69	 3.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78142	 1	 8.91	 5.05	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78143	 1	 11.67	 8.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78144	 1	 2.36	 1.46	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78145	 1	 26.94	 16.56	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78146	 1	 4.58	 2.88	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78147	 1	 2.29	 1.29	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78148	 1	 5.83	 3.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78149	 1	 6.36	 3.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78150	 1	 6.85	 3.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78151	 1	 3.99	 2.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78152	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78153	 1	 11.2	 6.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78154	 1	 4.51	 3.45	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78155	 1	 9.66	 6.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78156	 1	 3.92	 3.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78157	 1	 11.09	 8.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78158	 1	 6.22	 4.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78159	 1	 5.43	 3.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78160	 1	 3.34	 2.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78161	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78162	 1	 11.92	 7.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78163	 1	 4.39	 2.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78164	 1	 5.42	 3.77	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78165	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78166	 1	 25.36	 19.33	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78167	 1	 11.7	 9.16	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78168	 1	 56.68	 32.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78169	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78170	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78171	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78172	 1	 4.83	 3.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78173	 1	 8.71	 6.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78174	 1	 6.84	 5.24	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78175	 1	 4.63	 3.16	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78176	 1	 6.21	 4.82	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78177	 1	 4.77	 3.49	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78178	 1	 10.67	 6.16	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78179	 1	 7.68	 5.89	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78180	 1	 24.35	 14.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78181	 1	 4.75	 3.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78182	 1	 6.59	 4.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78183	 1	 8.95	 5.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78184	 1	 7.34	 5.01	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78185	 1	 5.27	 3.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78186	 1	 5.06	 2.81	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78187	 1	 6.62	 4.3	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78188	 1	 7.42	 5.5	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78189	 1	 10.92	 6.51	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78190	 1	 6.57	 4.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78191	 1	 3.09	 2.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78192	 1	 4.95	 3.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78193	 1	 7.29	 4.4	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78194	 1	 16.82	 11.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78195	 1	 7.93	 6.01	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78196	 1	 4.42	 2.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78197	 1	 1.09	 0.71	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78198	 1	 5.57	 3.65	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78199	 1	 8.25	 5.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78200	 1	 21.73	 15.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78201	 1	 4.72	 3.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78202	 1	 5.23	 3.74	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78203	 1	 10.1	 6.64	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78204	 1	 7.24	 5.46	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78205	 1	 7.53	 4.89	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78206	 1	 15.7	 11.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78207	 1	 8.9	 4.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78208	 1	 3.58	 2.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78209	 1	 4.96	 3.14	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78210	 1	 3.63	 2.4	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78211	 1	 40.71	 29.03	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78212	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78213	 1	 9.43	 6.37	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78214	 1	 8.27	 2.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78215	 1	 7.48	 1.8	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78216	 1	 11.86	 6.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78217	 1	 4.06	 0.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78218	 1	 7.37	 4.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78219	 1	 3.31	 0.8	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78220	 1	 19.82	 4.77	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78221	 1	 2.65	 1.84	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78222	 1	 15.73	 10.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78223	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78224	 1	 25.68	 15.28	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78225	 1	 21.74	 13.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78226	 1	 2.98	 1.91	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78227	 1	 5.7	 3.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78228	 1	 8.21	 5.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78229	 1	 11.71	 8.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78230	 1	 4.79	 3.17	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78231	 1	 15.44	 10.77	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78232	 1	 4.84	 1.15	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78233	 1	 3.17	 1.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78234	 1	 14.13	 10.9	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78235	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78236	 1	 7.82	 4.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78237	 1	 6.26	 4.34	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78238	 1	 8.33	 5.85	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78239	 1	 11.6	 8.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78240	 1	 13.43	 8.84	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78241	 1	 0.94	 0.64	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78242	 1	 3.81	 2.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78243	 1	 6.97	 4.7	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78244	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78245	 1	 23.1	 16.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78246	 1	 4.8	 2.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78247	 1	 27.25	 18.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78248	 1	 12.2	 9.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78249	 1	 9.18	 6.26	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78250	 1	 4.85	 2.84	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78251	 1	 5.27	 4.1	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78252	 1	 4.63	 3.08	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78253	 1	 7.94	 5.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78254	 1	 7.63	 5.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78255	 1	 6.71	 4.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78256	 1	 4.0	 2.67	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78257	 1	 4.4	 3.24	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78258	 1	 6.48	 4.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78259	 1	 7.32	 5.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78260	 1	 21.94	 13.71	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78261	 1	 3.0	 1.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78262	 1	 8.79	 6.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78263	 1	 6.34	 4.71	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78264	 1	 8.48	 4.8	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78265	 1	 4.77	 3.64	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78266	 1	 13.72	 8.59	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78267	 1	 4.54	 2.72	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78268	 1	 10.52	 6.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78269	 1	 7.93	 5.35	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78270	 1	 3.63	 2.17	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78271	 1	 18.9	 14.13	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78272	 1	 8.99	 5.77	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78273	 1	 5.65	 3.77	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78274	 1	 6.57	 4.88	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78275	 1	 4.16	 2.5	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78276	 1	 3.79	 2.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78277	 1	 2.75	 1.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78278	 1	 2.18	 1.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78279	 1	 5.96	 4.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78280	 1	 2.79	 1.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78281	 1	 7.04	 4.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78282	 1	 4.0	 2.79	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78283	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78284	 1	 3.01	 2.22	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78285	 1	 5.53	 3.56	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78286	 1	 10.4	 2.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78287	 1	 5.87	 1.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78288	 1	 16.9	 4.12	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78289	 1	 12.16	 2.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78290	 1	 4.71	 1.16	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78291	 1	 6.31	 1.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78292	 1	 10.76	 2.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78293	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78294	 1	 5.18	 1.27	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78295	 1	 6.68	 1.63	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78296	 1	 5.77	 1.41	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78297	 1	 7.08	 1.73	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78298	 1	 6.52	 1.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78299	 1	 3.71	 0.91	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78300	 1	 6.4	 1.57	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78301	 1	 8.54	 2.09	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78302	 1	 3.58	 0.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78303	 1	 9.8	 2.35	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78304	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78305	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78306	 1	 22.18	 5.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78307	 1	 14.01	 3.38	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78308	 1	 7.81	 1.91	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78309	 1	 3.99	 0.97	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78310	 1	 18.31	 4.44	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78311	 1	 5.8	 1.38	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78312	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78313	 1	 11.13	 2.74	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78314	 1	 7.78	 5.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78315	 1	 2.99	 2.2	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78316	 1	 1.89	 1.35	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78317	 1	 6.83	 5.11	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78318	 1	 4.02	 2.14	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78319	 1	 0.64	 0.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78320	 1	 8.11	 6.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78321	 1	 12.06	 8.01	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78322	 1	 16.66	 10.01	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78323	 1	 22.43	 14.79	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78324	 1	 7.05	 3.48	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78325	 1	 11.85	 7.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78326	 1	 9.61	 5.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78327	 1	 5.99	 4.02	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78328	 1	 6.96	 3.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78329	 1	 21.02	 13.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78330	 1	 8.82	 6.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78331	 1	 4.92	 3.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78332	 1	 5.9	 3.15	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78333	 1	 10.03	 5.37	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78334	 1	 12.05	 8.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78335	 1	 5.61	 4.03	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78336	 1	 14.41	 8.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78337	 1	 7.91	 5.27	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78338	 1	 6.5	 1.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78339	 1	 4.89	 1.15	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78340	 1	 10.88	 2.55	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78341	 1	 2.25	 0.52	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78342	 1	 4.97	 1.16	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78343	 1	 5.14	 1.21	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78344	 1	 2.56	 0.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78345	 1	 6.46	 1.53	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78346	 1	 7.13	 1.68	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78347	 1	 7.03	 1.66	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78348	 1	 1.9	 1.43	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78349	 1	 3.77	 2.67	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78350	 1	 1.54	 0.86	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78351	 1	 4.81	 3.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78352	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78353	 1	 7.47	 4.64	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78354	 1	 6.07	 4.07	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78355	 1	 7.96	 5.41	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78356	 1	 5.49	 3.34	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78357	 1	 5.17	 3.62	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78358	 1	 13.93	 9.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78359	 1	 4.12	 2.58	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78360	 1	 12.94	 7.4	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78361	 1	 6.24	 4.5	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78362	 1	 19.34	 14.32	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78363	 1	 19.61	 4.76	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78364	 1	 18.53	 11.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78365	 1	 11.06	 7.98	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78366	 1	 4.82	 2.87	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78367	 1	 3.97	 2.26	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78368	 1	 17.24	 10.19	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78369	 1	 5.53	 3.95	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78370	 1	 144.48	 105.43	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78371	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78372	 1	 6.39	 4.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78373	 1	 13.41	 8.31	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78374	 1	 3.68	 2.81	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78375	 1	 8.89	 6.61	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78376	 1	 4.24	 2.88	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78377	 1	 3.41	 1.96	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78378	 1	 12.03	 7.71	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78379	 1	 13.88	 9.06	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78380	 1	 13.26	 7.6	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78381	 1	 7.28	 4.04	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78382	 1	 7.18	 4.99	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78383	 1	 7.63	 4.88	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78384	 1	 8.25	 6.4	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78385	 1	 6.86	 3.94	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78386	 1	 5.49	 3.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78387	 1	 3.39	 2.23	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78388	 1	 6.19	 4.3	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78389	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78390	 1	 9.61	 5.69	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78391	 1	 24.89	 19.35	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78392	 1	 15.0	 10.25	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78393	 1	 6.26	 4.27	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78394	 1	 7.75	 1.83	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78395	 1	 3.39	 2.14	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78396	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78397	 1	 7.23	 5.15	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78398	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78399	 1	 0.0	 0.0	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78400	 1	 8.77	 4.98	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78401	 1	 4.11	 2.89	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78402	 1	 8.37	 5.8	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78403	 1	 12.84	 9.24	 0.0	 0.0	 23	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78404	 1	 4.48	 3.36	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78405	 1	 7.4	 5.0	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78406	 1	 4.33	 3.27	 0.0	 0.0	 23	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78407	 1	 8.84	 2.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78408	 1	 30.31	 8.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78409	 1	 20.67	 5.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78410	 1	 5.71	 2.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78411	 1	 20.17	 4.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78412	 1	 15.72	 4.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78413	 1	 13.45	 4.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78414	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78415	 1	 20.72	 6.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78416	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78417	 1	 217.87	 53.87	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78418	 1	 19.51	 3.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78419	 1	 25.06	 6.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78420	 1	 2.22	 0.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78421	 1	 12.31	 3.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78422	 1	 36.01	 6.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78423	 1	 23.91	 6.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78424	 1	 12.79	 2.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78425	 1	 13.58	 4.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78426	 1	 9.35	 2.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78427	 1	 28.78	 7.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78428	 1	 19.95	 4.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78429	 1	 14.63	 4.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78430	 1	 13.55	 3.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78431	 1	 35.77	 9.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78432	 1	 5.49	 1.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78433	 1	 5.12	 1.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78434	 1	 13.7	 4.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78435	 1	 19.04	 3.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78436	 1	 3.46	 1.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78437	 1	 3.33	 1.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78438	 1	 4.32	 1.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78439	 1	 3.38	 1.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78440	 1	 6.62	 1.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78441	 1	 0.92	 0.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78442	 1	 13.1	 3.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78443	 1	 22.09	 4.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78444	 1	 7.16	 2.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78445	 1	 12.13	 3.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78446	 1	 20.73	 6.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78447	 1	 15.04	 4.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78448	 1	 13.37	 4.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78449	 1	 15.39	 4.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78450	 1	 42.08	 9.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78451	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78452	 1	 34.53	 7.73	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78453	 1	 68.24	 14.21	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78454	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78455	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78456	 1	 28.37	 6.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78457	 1	 23.0	 6.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78458	 1	 15.26	 3.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78459	 1	 9.46	 2.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78460	 1	 1.94	 0.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78461	 1	 14.41	 4.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78462	 1	 17.31	 5.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78463	 1	 27.96	 6.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78464	 1	 12.39	 3.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78465	 1	 19.9	 5.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78466	 1	 3.35	 1.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78467	 1	 10.32	 2.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78468	 1	 9.38	 2.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78469	 1	 20.3	 4.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78470	 1	 15.92	 3.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78471	 1	 14.99	 3.61	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78472	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78473	 1	 51.83	 12.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78474	 1	 45.28	 12.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78475	 1	 15.99	 3.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78476	 1	 55.26	 12.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78477	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	78478	 1	 180.6	 51.89	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78479	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78480	 1	 12.44	 3.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78481	 1	 14.81	 4.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78482	 1	 9.71	 3.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78483	 1	 6.76	 2.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78484	 1	 5.59	 2.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78485	 1	 12.19	 3.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78486	 1	 5.69	 1.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78487	 1	 21.83	 6.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78488	 1	 12.97	 3.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78489	 1	 25.49	 7.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78490	 1	 8.11	 2.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78491	 1	 21.28	 6.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78492	 1	 6.71	 2.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78493	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78494	 1	 38.87	 10.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78495	 1	 19.63	 4.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78496	 1	 15.32	 3.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78497	 1	 13.98	 4.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78498	 1	 38.77	 9.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78499	 1	 53.97	 13.76	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78500	 1	 5.73	 1.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78501	 1	 12.5	 3.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78502	 1	 26.71	 7.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78503	 1	 11.5	 3.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78504	 1	 29.23	 7.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78505	 1	 30.18	 6.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78506	 1	 27.12	 7.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78507	 1	 16.9	 4.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78508	 1	 13.53	 4.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78509	 1	 16.66	 4.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78510	 1	 15.17	 4.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78511	 1	 7.34	 2.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78512	 1	 18.28	 4.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78513	 1	 16.15	 3.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78514	 1	 8.3	 2.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78515	 1	 9.12	 2.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78516	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78517	 1	 59.02	 14.76	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78518	 1	 15.49	 4.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78519	 1	 9.71	 2.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78520	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78521	 1	 16.66	 4.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78522	 1	 10.38	 3.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78523	 1	 12.52	 2.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78524	 1	 13.18	 3.96	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78525	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78526	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78527	 1	 20.75	 4.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78528	 1	 2.6	 1.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78529	 1	 38.51	 10.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78530	 1	 13.03	 4.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78531	 1	 12.3	 2.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78532	 1	 7.81	 2.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78533	 1	 12.81	 3.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78534	 1	 28.63	 7.35	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78535	 1	 3.3	 1.58	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78536	 1	 11.64	 4.31	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78537	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78538	 1	 31.32	 5.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78539	 1	 4.99	 2.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78540	 1	 3.54	 1.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78541	 1	 12.82	 3.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78542	 1	 12.76	 4.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78543	 1	 2.12	 0.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78544	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78545	 1	 7.18	 2.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78546	 1	 10.6	 3.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78547	 1	 52.43	 9.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78548	 1	 12.43	 3.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78549	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78550	 1	 81.13	 20.18	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78551	 1	 24.46	 6.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78552	 1	 28.73	 6.58	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78553	 1	 14.4	 3.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78554	 1	 22.69	 7.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78555	 1	 10.83	 3.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78556	 1	 13.98	 3.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78557	 1	 23.51	 7.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78558	 1	 23.72	 6.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78559	 1	 16.64	 5.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78560	 1	 7.67	 2.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78561	 1	 17.69	 5.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78562	 1	 5.23	 1.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78563	 1	 42.27	 8.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78564	 1	 18.61	 5.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78565	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78566	 1	 59.71	 18.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78567	 1	 38.78	 8.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78568	 1	 9.44	 3.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78569	 1	 12.48	 3.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78570	 1	 27.79	 6.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78571	 1	 44.96	 13.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78572	 1	 5.36	 2.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78573	 1	 21.24	 5.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78574	 1	 31.34	 9.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78575	 1	 25.8	 8.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78576	 1	 4.32	 1.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78577	 1	 2.93	 1.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78578	 1	 42.16	 10.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78579	 1	 9.71	 3.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78580	 1	 23.86	 6.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78581	 1	 31.04	 8.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78582	 1	 2.84	 1.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78583	 1	 105.92	 25.26	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78584	 1	 35.01	 11.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78585	 1	 37.15	 8.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78586	 1	 24.42	 7.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78587	 1	 30.38	 7.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78588	 1	 20.3	 5.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78589	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78590	 1	 15.6	 4.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78591	 1	 12.13	 2.93	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78592	 1	 14.09	 5.37	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78593	 1	 66.03	 15.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78594	 1	 19.06	 4.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78595	 1	 29.71	 7.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78596	 1	 4.45	 1.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78597	 1	 34.08	 7.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78598	 1	 10.49	 2.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78599	 1	 7.87	 2.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78600	 1	 6.33	 2.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78601	 1	 34.67	 7.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78602	 1	 13.0	 3.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78603	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	78604	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78605	 1	 134.6	 30.46	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78606	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78607	 1	 14.86	 5.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78608	 1	 70.82	 16.33	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78609	 1	 15.94	 4.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78610	 1	 30.58	 6.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78611	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78612	 1	 55.52	 16.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78613	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78614	 1	 9.81	 3.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78615	 1	 6.09	 2.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78616	 1	 6.63	 2.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78617	 1	 12.35	 4.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78618	 1	 14.89	 4.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78619	 1	 39.8	 8.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78620	 1	 10.37	 3.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78621	 1	 70.88	 20.25	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78622	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78623	 1	 6.54	 2.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78624	 1	 22.73	 5.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78625	 1	 21.19	 5.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78626	 1	 5.83	 1.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78627	 1	 4.08	 1.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78628	 1	 14.35	 4.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78629	 1	 2.06	 0.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78630	 1	 8.81	 3.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78631	 1	 21.05	 5.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78632	 1	 20.97	 5.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78633	 1	 5.3	 2.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78634	 1	 11.83	 2.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78635	 1	 12.15	 4.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78636	 1	 31.03	 10.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78637	 1	 9.6	 2.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78638	 1	 6.93	 2.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78639	 1	 24.86	 7.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78640	 1	 18.43	 5.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78641	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78642	 1	 5.82	 2.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78643	 1	 7.94	 3.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78644	 1	 51.71	 12.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78645	 1	 202.94	 47.79	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78646	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78647	 1	 19.74	 4.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78648	 1	 9.32	 2.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78649	 1	 14.47	 3.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78650	 1	 28.03	 8.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78651	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78652	 1	 15.41	 4.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78653	 1	 12.56	 3.5	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78654	 1	 13.06	 4.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78655	 1	 8.62	 2.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78656	 1	 13.3	 3.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78657	 1	 47.19	 8.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78658	 1	 32.97	 9.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78659	 1	 43.27	 10.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78660	 1	 18.0	 5.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78661	 1	 16.39	 4.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78662	 1	 13.31	 3.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78663	 1	 12.22	 3.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78664	 1	 6.35	 1.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78665	 1	 37.29	 8.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78666	 1	 4.3	 1.45	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78667	 1	 40.51	 9.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78668	 1	 14.5	 4.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78669	 1	 19.21	 5.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78670	 1	 13.39	 4.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78671	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78672	 1	 5.64	 1.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78673	 1	 2.25	 0.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78674	 1	 9.75	 3.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78675	 1	 7.74	 2.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78676	 1	 6.8	 2.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78677	 1	 10.82	 2.85	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78678	 1	 16.15	 4.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78679	 1	 19.03	 5.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78680	 1	 16.5	 3.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78681	 1	 11.08	 4.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78682	 1	 18.91	 6.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78683	 1	 92.85	 28.39	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78684	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78685	 1	 13.79	 4.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78686	 1	 66.05	 18.51	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78687	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78688	 1	 24.3	 5.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78689	 1	 7.54	 3.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78690	 1	 14.36	 3.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78691	 1	 23.72	 5.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78692	 1	 39.95	 8.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78693	 1	 6.42	 2.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78694	 1	 9.85	 2.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78695	 1	 4.95	 2.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78696	 1	 11.27	 2.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78697	 1	 5.74	 2.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78698	 1	 20.77	 5.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78699	 1	 19.54	 6.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78700	 1	 4.46	 1.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78701	 1	 11.66	 4.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78702	 1	 141.41	 31.65	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78703	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78704	 1	 12.64	 4.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78705	 1	 10.87	 3.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78706	 1	 37.04	 8.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78707	 1	 49.92	 12.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78708	 1	 13.81	 3.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78709	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78710	 1	 59.25	 15.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78711	 1	 3.98	 1.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78712	 1	 15.43	 5.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78713	 1	 14.39	 3.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78714	 1	 20.72	 4.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78715	 1	 18.98	 5.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78716	 1	 41.84	 10.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78717	 1	 30.16	 6.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78718	 1	 12.15	 3.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78719	 1	 14.06	 4.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78720	 1	 3.21	 1.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78721	 1	 13.06	 4.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78722	 1	 4.56	 1.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78723	 1	 21.36	 6.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78724	 1	 23.32	 4.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78725	 1	 11.94	 3.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78726	 1	 5.34	 2.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78727	 1	 9.8	 3.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78728	 1	 8.36	 2.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78729	 1	 13.33	 4.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78730	 1	 4.23	 1.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78731	 1	 10.85	 2.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78732	 1	 35.49	 10.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78733	 1	 24.21	 6.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78734	 1	 18.23	 5.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78735	 1	 5.0	 2.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78736	 1	 23.06	 7.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78737	 1	 8.66	 2.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78738	 1	 27.87	 7.18	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78739	 1	 20.09	 7.08	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78740	 1	 32.2	 8.77	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78741	 1	 15.66	 3.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78742	 1	 17.89	 4.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78743	 1	 3.89	 1.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78744	 1	 34.05	 7.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78745	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78746	 1	 22.21	 4.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78747	 1	 37.35	 8.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78748	 1	 16.69	 4.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78749	 1	 20.23	 5.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78750	 1	 35.15	 8.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78751	 1	 19.91	 4.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78752	 1	 17.71	 4.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78753	 1	 16.88	 3.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78754	 1	 7.15	 1.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78755	 1	 25.73	 5.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78756	 1	 22.17	 4.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78757	 1	 33.0	 7.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78758	 1	 20.7	 4.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78759	 1	 5.95	 2.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78760	 1	 17.72	 5.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78761	 1	 15.73	 5.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78762	 1	 7.41	 2.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78763	 1	 6.43	 2.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78764	 1	 70.75	 19.35	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78765	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78766	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	78767	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78768	 1	 136.36	 35.67	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78769	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78770	 1	 17.99	 6.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78771	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78772	 1	 61.39	 18.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78773	 1	 19.38	 5.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78774	 1	 22.08	 7.38	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78775	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78776	 1	 30.71	 9.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78777	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78778	 1	 10.88	 4.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78779	 1	 8.4	 2.95	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78780	 1	 21.93	 7.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78781	 1	 24.15	 6.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78782	 1	 4.64	 1.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78783	 1	 6.88	 1.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78784	 1	 36.87	 10.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78785	 1	 24.5	 6.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78786	 1	 37.48	 9.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78787	 1	 10.79	 3.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78788	 1	 11.65	 3.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78789	 1	 14.4	 4.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78790	 1	 25.15	 5.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78791	 1	 7.71	 2.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78792	 1	 6.08	 2.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78793	 1	 55.87	 14.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78794	 1	 30.18	 9.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78795	 1	 32.33	 8.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78796	 1	 32.84	 9.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78797	 1	 32.82	 8.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78798	 1	 15.57	 3.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78799	 1	 11.31	 3.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78800	 1	 22.29	 5.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78801	 1	 7.64	 3.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78802	 1	 17.53	 5.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78803	 1	 20.05	 5.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78804	 1	 10.71	 3.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78805	 1	 10.42	 3.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78806	 1	 11.61	 3.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78807	 1	 25.7	 6.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78808	 1	 1.8	 0.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78809	 1	 7.28	 2.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78810	 1	 12.23	 3.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78811	 1	 5.69	 2.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78812	 1	 5.26	 2.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78813	 1	 9.22	 2.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78814	 1	 7.11	 2.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78815	 1	 13.9	 3.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78816	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78817	 1	 10.1	 2.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78818	 1	 5.6	 1.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78819	 1	 3.57	 1.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78820	 1	 20.2	 5.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78821	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	78822	 1	 17.08	 3.91	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78823	 1	 10.29	 2.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78824	 1	 11.79	 3.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78825	 1	 13.45	 4.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78826	 1	 16.27	 4.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78827	 1	 3.58	 1.42	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78828	 1	 1.99	 0.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78829	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78830	 1	 6.79	 2.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78831	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	78832	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78833	 1	 21.21	 5.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78834	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	78835	 1	 27.28	 8.61	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78836	 1	 5.78	 2.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78837	 1	 15.7	 4.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78838	 1	 4.85	 1.78	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78839	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	78840	 1	 6.61	 1.61	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78841	 1	 7.5	 2.53	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78842	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	78843	 1	 3.27	 1.39	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78844	 1	 4.15	 1.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78845	 1	 3.04	 1.05	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78846	 1	 13.12	 3.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78847	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78848	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78849	 1	 30.5	 8.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78850	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	78851	 1	 84.65	 16.29	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78852	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78853	 1	 258.74	 57.51	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78854	 1	 40.11	 11.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78855	 1	 10.91	 3.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78856	 1	 7.86	 3.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78857	 1	 13.33	 4.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78858	 1	 4.02	 1.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78859	 1	 19.82	 6.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78860	 1	 10.76	 3.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78861	 1	 2.64	 1.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78862	 1	 19.5	 5.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78863	 1	 6.73	 2.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78864	 1	 16.02	 4.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78865	 1	 16.48	 5.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78866	 1	 9.41	 3.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78867	 1	 6.78	 2.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78868	 1	 7.33	 2.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78869	 1	 21.5	 5.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78870	 1	 1.72	 0.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78871	 1	 9.92	 3.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78872	 1	 4.75	 1.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78873	 1	 2.65	 1.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78874	 1	 16.78	 5.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78875	 1	 36.21	 9.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78876	 1	 12.21	 4.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78877	 1	 19.7	 4.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78878	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78879	 1	 29.46	 7.95	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78880	 1	 19.75	 5.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78881	 1	 34.19	 9.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78882	 1	 22.87	 6.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78883	 1	 53.11	 -7.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78884	 1	 28.9	 6.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78885	 1	 13.17	 2.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78886	 1	 92.26	 18.7	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78887	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78888	 1	 48.3	 11.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78889	 1	 34.61	 7.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78890	 1	 20.84	 4.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78891	 1	 7.19	 1.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78892	 1	 23.15	 5.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78893	 1	 18.16	 4.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78894	 1	 50.98	 11.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78895	 1	 26.51	 5.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78896	 1	 34.26	 10.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78897	 1	 4.83	 1.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78898	 1	 47.07	 10.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78899	 1	 29.05	 6.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78900	 1	 8.5	 1.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78901	 1	 6.28	 2.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78902	 1	 15.58	 4.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78903	 1	 8.24	 2.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78904	 1	 5.37	 1.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78905	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78906	 1	 9.96	 4.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78907	 1	 4.21	 1.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78908	 1	 9.28	 2.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78909	 1	 9.7	 2.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78910	 1	 6.19	 2.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78911	 1	 21.75	 8.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78912	 1	 9.83	 2.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78913	 1	 2.88	 1.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78914	 1	 24.26	 7.81	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78915	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	78916	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78917	 1	 135.7	 35.79	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78918	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78919	 1	 20.46	 6.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78920	 1	 25.11	 6.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78921	 1	 22.84	 8.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78922	 1	 15.0	 4.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78923	 1	 16.43	 3.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78924	 1	 10.15	 4.09	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78925	 1	 33.41	 7.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78926	 1	 11.19	 3.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78927	 1	 6.06	 2.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78928	 1	 5.84	 1.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78929	 1	 2.7	 1.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78930	 1	 11.03	 3.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78931	 1	 8.0	 2.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78932	 1	 15.35	 5.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78933	 1	 7.04	 2.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78934	 1	 28.02	 7.16	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78935	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78936	 1	 19.44	 6.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78937	 1	 3.69	 1.28	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78938	 1	 9.38	 2.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78939	 1	 18.02	 4.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78940	 1	 21.28	 5.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78941	 1	 10.94	 3.26	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78942	 1	 7.78	 2.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78943	 1	 21.08	 6.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78944	 1	 14.96	 4.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78945	 1	 6.59	 1.88	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78946	 1	 20.64	 4.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78947	 1	 4.82	 1.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78948	 1	 4.6	 1.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78949	 1	 3.28	 0.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78950	 1	 1.61	 0.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78951	 1	 2.28	 0.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78952	 1	 5.78	 1.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78953	 1	 8.1	 1.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78954	 1	 22.6	 5.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78955	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78956	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78957	 1	 51.93	 12.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78958	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78959	 1	 31.96	 7.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78960	 1	 9.32	 2.15	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78961	 1	 13.71	 3.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78962	 1	 39.04	 8.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78963	 1	 14.36	 3.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78964	 1	 22.77	 5.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78965	 1	 16.24	 4.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78966	 1	 5.25	 1.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78967	 1	 4.59	 1.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78968	 1	 12.22	 3.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78969	 1	 27.25	 7.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78970	 1	 29.34	 6.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78971	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78972	 1	 38.91	 10.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78973	 1	 18.46	 5.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78974	 1	 7.22	 2.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78975	 1	 28.46	 7.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78976	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78977	 1	 31.9	 9.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78978	 1	 25.04	 6.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78979	 1	 35.76	 10.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78980	 1	 14.75	 5.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78981	 1	 74.22	 20.14	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78982	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78983	 1	 15.31	 3.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78984	 1	 24.94	 7.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78985	 1	 27.29	 5.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78986	 1	 6.93	 1.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78987	 1	 8.46	 2.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78988	 1	 25.83	 8.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78989	 1	 33.65	 9.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78990	 1	 37.8	 9.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78991	 1	 43.56	 8.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78992	 1	 37.73	 7.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78993	 1	 41.38	 9.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78994	 1	 45.02	 10.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78995	 1	 11.09	 2.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78996	 1	 6.48	 2.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78997	 1	 5.73	 1.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78998	 1	 16.12	 5.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78999	 1	 6.11	 2.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79000	 1	 2.82	 1.08	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79001	 1	 5.16	 2.26	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79002	 1	 4.4	 1.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79003	 1	 33.04	 8.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79004	 1	 7.6	 2.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79005	 1	 22.11	 7.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79006	 1	 8.9	 3.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79007	 1	 8.52	 2.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79008	 1	 23.26	 4.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79009	 1	 11.46	 2.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79010	 1	 20.59	 4.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79011	 1	 19.13	 5.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79012	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79013	 1	 18.16	 5.36	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79014	 1	 14.51	 4.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79015	 1	 12.79	 4.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79016	 1	 30.05	 8.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79017	 1	 8.22	 2.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79018	 1	 18.72	 5.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79019	 1	 29.63	 6.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79020	 1	 18.75	 6.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79021	 1	 100.88	 26.72	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79022	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79023	 1	 20.25	 6.55	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79024	 1	 34.66	 8.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79025	 1	 15.95	 4.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79026	 1	 28.29	 6.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79027	 1	 27.6	 7.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79028	 1	 12.52	 3.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79029	 1	 34.54	 8.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79030	 1	 5.28	 2.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79031	 1	 15.32	 5.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79032	 1	 52.76	 15.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79033	 1	 17.48	 4.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79034	 1	 22.98	 5.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79035	 1	 11.1	 3.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79036	 1	 3.92	 1.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79037	 1	 2.02	 0.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79038	 1	 37.86	 9.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79039	 1	 11.33	 4.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79040	 1	 22.59	 7.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79041	 1	 12.17	 4.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79042	 1	 33.13	 11.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79043	 1	 41.19	 11.96	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79044	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	79045	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79046	 1	 129.85	 30.84	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79047	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79048	 1	 11.77	 4.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79049	 1	 33.74	 10.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79050	 1	 8.53	 3.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79051	 1	 13.02	 4.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79052	 1	 17.44	 5.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79053	 1	 7.18	 2.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79054	 1	 1.16	 0.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79055	 1	 12.03	 3.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79056	 1	 3.99	 1.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79057	 1	 18.55	 4.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79058	 1	 11.79	 2.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79059	 1	 23.35	 7.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79060	 1	 5.38	 1.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79061	 1	 31.08	 7.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79062	 1	 14.28	 3.1	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79063	 1	 13.06	 4.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79064	 1	 6.44	 2.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79065	 1	 5.27	 2.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79066	 1	 14.45	 3.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79067	 1	 20.35	 5.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79068	 1	 4.64	 1.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79069	 1	 2.39	 0.92	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79070	 1	 4.24	 1.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79071	 1	 9.69	 2.74	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79072	 1	 39.37	 7.96	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79073	 1	 1.35	 0.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79074	 1	 3.74	 1.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79075	 1	 6.45	 1.95	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79076	 1	 20.24	 6.65	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79077	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	79078	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79079	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	79080	 1	 8.05	 3.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79081	 1	 7.21	 2.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79082	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	79083	 1	 45.44	 12.8	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79084	 1	 14.11	 3.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79085	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79086	 1	 4.97	 1.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79087	 1	 4.85	 2.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79088	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	79089	 1	 13.41	 3.57	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79090	 1	 13.38	 4.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79091	 1	 29.99	 8.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79092	 1	 76.87	 13.32	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79093	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79094	 1	 20.07	 4.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79095	 1	 12.44	 4.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79096	 1	 6.29	 2.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79097	 1	 52.01	 14.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79098	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79099	 1	 24.69	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79100	 1	 39.83	 9.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79101	 1	 9.83	 2.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79102	 1	 27.77	 6.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79103	 1	 42.11	 9.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79104	 1	 32.47	 7.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79105	 1	 28.27	 6.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79106	 1	 30.44	 6.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79107	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79108	 1	 27.09	 8.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79109	 1	 3.54	 1.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79110	 1	 38.73	 8.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79111	 1	 24.53	 6.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79112	 1	 6.47	 1.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79113	 1	 6.44	 1.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79114	 1	 7.49	 1.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79115	 1	 34.94	 8.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79116	 1	 4.09	 1.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79117	 1	 13.33	 4.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79118	 1	 18.16	 4.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79119	 1	 27.81	 8.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79120	 1	 11.28	 4.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79121	 1	 5.12	 1.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79122	 1	 5.51	 2.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79123	 1	 8.26	 3.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79124	 1	 9.15	 3.99	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79125	 1	 7.61	 1.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79126	 1	 24.65	 7.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79127	 1	 12.67	 3.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79128	 1	 48.76	 12.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79129	 1	 11.3	 3.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79130	 1	 14.63	 3.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79131	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	79132	 1	 92.54	 20.25	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79133	 1	 25.0	 6.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79134	 1	 18.53	 4.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79135	 1	 8.11	 3.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79136	 1	 2.44	 1.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79137	 1	 16.41	 3.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79138	 1	 30.62	 7.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79139	 1	 52.04	 15.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79140	 1	 30.07	 8.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79141	 1	 16.44	 4.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79142	 1	 15.84	 4.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79143	 1	 11.27	 3.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79144	 1	 12.86	 3.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79145	 1	 22.9	 4.76	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79146	 1	 7.73	 2.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79147	 1	 17.27	 4.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79148	 1	 7.65	 2.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79149	 1	 13.47	 4.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79150	 1	 13.14	 3.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79151	 1	 13.31	 3.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79152	 1	 23.49	 5.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79153	 1	 15.74	 3.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79154	 1	 15.84	 4.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79155	 1	 5.45	 2.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79156	 1	 13.45	 4.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79157	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79158	 1	 43.92	 11.25	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79159	 1	 9.98	 2.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79160	 1	 13.13	 4.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79161	 1	 9.0	 3.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79162	 1	 6.49	 2.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79163	 1	 38.32	 10.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79164	 1	 8.55	 3.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79165	 1	 7.63	 2.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79166	 1	 9.08	 3.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79167	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	79168	 1	 67.14	 18.04	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79169	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79170	 1	 12.87	 3.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79171	 1	 10.42	 3.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79172	 1	 37.34	 10.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79173	 1	 17.04	 4.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79174	 1	 26.75	 8.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79175	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79176	 1	 28.01	 6.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79177	 1	 11.38	 3.44	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79178	 1	 5.69	 2.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79179	 1	 18.75	 6.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79180	 1	 32.06	 6.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79181	 1	 4.6	 2.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79182	 1	 5.92	 2.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79183	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79184	 1	 18.91	 4.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79185	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79186	 1	 22.62	 7.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79187	 1	 12.36	 3.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79188	 1	 6.58	 2.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79189	 1	 5.02	 1.63	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79190	 1	 39.35	 12.42	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79191	 1	 10.38	 3.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79192	 1	 11.61	 4.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79193	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79194	 1	 5.64	 2.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79195	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79196	 1	 12.82	 4.09	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79197	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	79198	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79199	 1	 25.2	 7.11	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79200	 1	 32.84	 10.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79201	 1	 19.74	 4.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79202	 1	 29.05	 6.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79203	 1	 4.26	 1.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79204	 1	 27.28	 9.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79205	 1	 25.39	 5.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79206	 1	 11.03	 3.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79207	 1	 26.63	 6.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79208	 1	 12.43	 5.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79209	 1	 56.04	 15.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79210	 1	 18.0	 5.04	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79211	 1	 2.85	 1.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79212	 1	 11.41	 3.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79213	 1	 18.46	 4.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79214	 1	 4.24	 1.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79215	 1	 18.78	 5.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79216	 1	 11.16	 3.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79217	 1	 41.63	 12.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79218	 1	 20.02	 6.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79219	 1	 16.79	 5.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79220	 1	 36.57	 7.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79221	 1	 41.12	 9.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79222	 1	 23.92	 5.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79223	 1	 12.38	 3.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79224	 1	 4.48	 2.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79225	 1	 12.11	 4.66	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79226	 1	 3.96	 1.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79227	 1	 32.55	 6.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79228	 1	 44.82	 10.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79229	 1	 52.63	 14.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79230	 1	 30.26	 8.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79231	 1	 51.09	 13.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79232	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79233	 1	 8.68	 3.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79234	 1	 2.67	 1.12	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79235	 1	 4.46	 1.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79236	 1	 17.58	 4.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79237	 1	 7.4	 2.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79238	 1	 4.01	 1.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79239	 1	 8.75	 3.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79240	 1	 2.82	 1.26	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79241	 1	 17.94	 4.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79242	 1	 12.27	 3.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79243	 1	 8.15	 2.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79244	 1	 4.02	 1.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79245	 1	 10.18	 3.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79246	 1	 8.56	 3.39	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79247	 1	 10.63	 3.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79248	 1	 6.72	 2.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79249	 1	 11.66	 3.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79250	 1	 3.5	 1.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79251	 1	 9.28	 3.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79252	 1	 5.25	 2.01	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79253	 1	 21.21	 6.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79254	 1	 17.66	 4.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79255	 1	 17.94	 5.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79256	 1	 10.63	 3.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79257	 1	 8.65	 3.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79258	 1	 40.14	 11.14	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79259	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	79260	 1	 5.69	 2.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79261	 1	 10.47	 4.27	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79262	 1	 11.78	 3.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79263	 1	 8.31	 2.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79264	 1	 7.38	 2.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79265	 1	 7.33	 2.91	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79266	 1	 7.33	 2.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79267	 1	 5.78	 1.69	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79268	 1	 17.81	 5.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79269	 1	 6.99	 2.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79270	 1	 9.23	 2.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79271	 1	 8.04	 2.78	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79272	 1	 9.02	 3.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79273	 1	 0.92	 0.46	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79274	 1	 4.46	 1.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79275	 1	 11.46	 3.16	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79276	 1	 9.67	 2.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79277	 1	 4.34	 1.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79278	 1	 15.29	 3.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79279	 1	 7.02	 2.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79280	 1	 9.7	 3.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79281	 1	 17.94	 4.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79282	 1	 6.94	 2.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79283	 1	 11.15	 2.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79284	 1	 9.28	 2.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79285	 1	 12.27	 4.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79286	 1	 1.89	 0.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79287	 1	 10.13	 3.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79288	 1	 10.51	 3.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79289	 1	 17.05	 4.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79290	 1	 10.56	 3.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79291	 1	 6.74	 2.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79292	 1	 26.03	 6.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79293	 1	 18.68	 5.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79294	 1	 10.22	 2.89	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79295	 1	 15.31	 5.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79296	 1	 10.56	 3.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79297	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79298	 1	 50.45	 12.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79299	 1	 33.44	 10.4	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79300	 1	 6.4	 2.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79301	 1	 9.37	 3.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79302	 1	 8.05	 2.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79303	 1	 12.05	 3.27	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79304	 1	 9.97	 3.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79305	 1	 4.06	 1.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79306	 1	 7.7	 2.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79307	 1	 15.02	 3.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79308	 1	 2.25	 0.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79309	 1	 1.79	 0.71	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79310	 1	 4.27	 1.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79311	 1	 4.53	 1.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79312	 1	 5.31	 1.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79313	 1	 5.98	 1.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79314	 1	 3.77	 1.56	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79315	 1	 3.56	 1.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79316	 1	 16.36	 5.13	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79317	 1	 15.85	 4.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79318	 1	 10.84	 2.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79319	 1	 20.26	 5.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79320	 1	 23.84	 7.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79321	 1	 10.69	 3.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79322	 1	 16.03	 3.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79323	 1	 9.55	 2.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79324	 1	 20.02	 6.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79325	 1	 5.79	 2.51	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79326	 1	 11.88	 4.3	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79327	 1	 12.09	 3.9	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79328	 1	 21.0	 6.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79329	 1	 8.75	 3.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79330	 1	 8.02	 2.87	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79331	 1	 6.58	 2.59	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79332	 1	 12.91	 4.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79333	 1	 11.91	 3.28	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79334	 1	 11.96	 4.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79335	 1	 8.94	 2.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79336	 1	 10.47	 3.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79337	 1	 3.99	 1.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79338	 1	 32.99	 7.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79339	 1	 13.28	 4.57	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79340	 1	 10.56	 3.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79341	 1	 84.83	 19.7	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79342	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79343	 1	 8.28	 2.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79344	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79345	 1	 73.76	 20.79	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79346	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79347	 1	 52.76	 10.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79348	 1	 18.39	 5.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79349	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79350	 1	 47.61	 12.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79351	 1	 7.7	 2.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79352	 1	 4.67	 1.19	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79353	 1	 66.68	 18.35	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79354	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79355	 1	 52.78	 14.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79356	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	79357	 1	 256.89	 68.43	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79358	 1	 3.24	 0.75	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79359	 1	 2.62	 0.62	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79360	 1	 1.54	 0.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79361	 1	 9.71	 2.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79362	 1	 7.38	 1.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79363	 1	 6.79	 1.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79364	 1	 3.54	 0.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79365	 1	 35.66	 7.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79366	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79367	 1	 5.9	 1.44	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79368	 1	 13.04	 4.66	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79369	 1	 13.17	 3.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79370	 1	 5.11	 1.52	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79371	 1	 3.16	 1.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79372	 1	 16.36	 4.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79373	 1	 33.13	 10.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79374	 1	 13.21	 4.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79375	 1	 17.96	 5.48	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79376	 1	 14.76	 4.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79377	 1	 14.84	 4.03	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79378	 1	 21.87	 7.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79379	 1	 21.48	 5.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79380	 1	 10.84	 3.88	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79381	 1	 8.62	 3.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79382	 1	 8.35	 2.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79383	 1	 13.0	 2.94	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79384	 1	 12.41	 2.83	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79385	 1	 11.64	 2.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79386	 1	 23.1	 5.2	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79387	 1	 25.98	 5.82	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79388	 1	 14.06	 4.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79389	 1	 21.83	 7.22	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79390	 1	 9.67	 3.32	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79391	 1	 11.27	 3.07	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79392	 1	 38.95	 12.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79393	 1	 18.35	 5.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79394	 1	 5.15	 1.73	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79395	 1	 35.91	 9.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79396	 1	 8.3	 2.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79397	 1	 8.25	 2.84	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79398	 1	 31.31	 8.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79399	 1	 32.75	 9.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79400	 1	 24.56	 5.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79401	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79402	 1	 10.51	 3.02	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79403	 1	 33.7	 10.31	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79404	 1	 17.79	 5.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79405	 1	 39.04	 11.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79406	 1	 4.6	 1.61	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79407	 1	 6.56	 2.17	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79408	 1	 18.21	 5.98	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79409	 1	 11.36	 4.2	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79410	 1	 28.33	 8.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79411	 1	 15.1	 4.53	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79412	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79413	 1	 47.36	 9.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79414	 1	 18.23	 4.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79415	 1	 22.22	 6.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79416	 1	 17.96	 4.18	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79417	 1	 10.35	 2.41	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79418	 1	 4.01	 0.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79419	 1	 2.34	 1.09	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79420	 1	 3.0	 1.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79421	 1	 13.75	 3.43	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79422	 1	 5.48	 2.45	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79423	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79424	 1	 19.22	 5.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79425	 1	 35.27	 7.86	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79426	 1	 41.17	 10.23	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79427	 1	 22.17	 4.67	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79428	 1	 17.83	 5.64	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79429	 1	 7.81	 2.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79430	 1	 4.53	 1.85	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79431	 1	 6.68	 2.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79432	 1	 25.53	 7.06	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79433	 1	 24.21	 6.6	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79434	 1	 42.02	 11.08	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79435	 1	 12.05	 3.05	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79436	 1	 47.24	 10.54	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79437	 1	 12.46	 3.7	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79438	 1	 21.09	 4.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79439	 1	 32.07	 7.81	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79440	 1	 37.43	 9.46	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79441	 1	 5.83	 1.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79442	 1	 12.93	 3.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79443	 1	 6.67	 1.63	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79444	 1	 24.67	 5.97	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79445	 1	 9.34	 2.24	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79446	 1	 10.74	 3.49	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79447	 1	 28.43	 8.68	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79448	 1	 28.46	 9.34	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79449	 1	 18.6	 5.47	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79450	 1	 37.82	 8.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79451	 1	 9.24	 4.21	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79452	 1	 7.69	 2.93	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79453	 1	 10.5	 3.33	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79454	 1	 68.96	 21.71	 0.0	 0.0	 29	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79455	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79456	 1	 40.71	 12.11	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79457	 1	 44.79	 10.58	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79458	 1	 8.62	 3.79	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79459	 1	 38.25	 8.77	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79460	 1	 27.12	 6.65	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79461	 1	 24.45	 6.35	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79462	 1	 36.3	 11.8	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79463	 1	 7.98	 3.29	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79464	 1	 26.17	 5.72	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79465	 1	 14.1	 4.37	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79466	 1	 3.27	 1.26	 0.0	 0.0	 29	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79467	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79468	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79469	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79470	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79471	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79472	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79473	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79474	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79475	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79476	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79477	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79478	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79479	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79480	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79481	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79482	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79483	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79484	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79485	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79486	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79487	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79488	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79489	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79490	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79491	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79492	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79493	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79494	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79495	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79496	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79497	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79498	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79499	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79500	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79501	 2	 4.53	 2.25	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79502	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79503	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79504	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79505	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79506	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79507	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79508	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79509	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79510	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79511	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79512	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79513	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79514	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79515	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79516	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79517	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79518	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79519	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79520	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79521	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79522	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79523	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79524	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79525	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79526	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79527	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79528	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79529	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79530	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79531	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79532	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79533	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79534	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79535	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79536	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79537	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79538	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79539	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79540	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79541	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79542	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79543	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79544	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79545	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79546	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79547	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79548	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79549	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79550	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79551	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79552	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79553	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79554	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79555	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79556	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79557	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79558	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79559	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79560	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79561	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79562	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79563	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79564	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79565	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79566	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79567	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79568	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79569	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79570	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79571	 2	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79572	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79573	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79574	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79575	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79576	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79577	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79578	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79579	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79580	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79581	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79582	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79583	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79584	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79585	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79586	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79587	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79588	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79589	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79590	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79591	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79592	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79593	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79594	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79595	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79596	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79597	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79598	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79599	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79600	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79601	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79602	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79603	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79604	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79605	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79606	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79607	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79608	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79609	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79610	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79611	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79612	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79613	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79614	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79615	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79616	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79617	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79618	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79619	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79620	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79621	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79622	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79623	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79624	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79625	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79626	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79627	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79628	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79629	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79630	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79631	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79632	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79633	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79634	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79635	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79636	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79637	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79638	 2	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79639	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79640	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79641	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79642	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79643	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79644	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79645	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79646	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79647	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79648	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79649	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79650	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79651	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79652	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79653	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79654	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79655	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79656	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79657	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79658	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79659	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79660	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79661	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79662	 2	 6.1	 2.11	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79663	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79664	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79665	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79666	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79667	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79668	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79669	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79670	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79671	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79672	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79673	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79674	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79675	 2	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79676	 1	 24.4	 10.08	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79677	 1	 19.65	 8.22	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79678	 1	 20.67	 10.36	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79679	 1	 34.87	 14.39	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79680	 1	 16.1	 5.35	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79681	 1	 4.93	 2.13	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79682	 1	 15.77	 5.88	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79683	 1	 11.22	 5.44	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79684	 1	 4.21	 1.83	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79685	 1	 10.16	 4.02	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79686	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79687	 1	 94.06	 38.59	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79688	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79689	 1	 15.37	 6.09	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79690	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79691	 1	 26.81	 8.62	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79692	 1	 12.22	 6.17	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79693	 1	 10.48	 5.1	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79694	 1	 10.73	 4.67	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79695	 1	 36.27	 13.23	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79696	 1	 30.37	 11.35	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79697	 1	 17.0	 5.99	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79698	 1	 58.97	 20.43	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79699	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79700	 1	 2.11	 1.13	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79701	 1	 16.78	 6.92	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79702	 1	 10.6	 4.05	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79703	 1	 23.6	 8.19	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79704	 1	 23.35	 9.83	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79705	 1	 17.83	 7.84	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79706	 1	 29.89	 11.6	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79707	 1	 14.23	 5.77	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79708	 1	 19.29	 7.46	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79709	 1	 16.09	 6.46	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79710	 1	 22.77	 7.43	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79711	 1	 32.55	 11.14	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79712	 1	 25.42	 9.92	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79713	 1	 9.3	 3.9	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79714	 1	 9.82	 5.07	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79715	 1	 36.93	 15.72	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79716	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79717	 1	 29.01	 13.02	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79718	 1	 16.63	 7.86	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79719	 1	 16.4	 5.76	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79720	 1	 6.08	 3.06	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79721	 1	 15.6	 6.3	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79722	 1	 21.37	 9.15	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79723	 1	 15.3	 6.97	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79724	 1	 10.24	 3.71	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79725	 1	 4.97	 2.56	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79726	 1	 7.08	 3.77	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79727	 1	 17.32	 8.19	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79728	 1	 5.62	 3.08	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79729	 1	 5.5	 2.57	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79730	 1	 8.75	 3.32	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79731	 1	 6.02	 2.5	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79732	 1	 9.49	 4.91	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79733	 1	 2.61	 0.59	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79734	 1	 13.61	 3.06	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79735	 1	 21.58	 4.84	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79736	 1	 22.34	 5.01	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79737	 1	 27.54	 6.19	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79738	 1	 15.5	 3.48	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79739	 1	 9.9	 4.7	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79740	 1	 31.35	 16.28	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79741	 1	 8.62	 4.17	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79742	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79743	 1	 10.4	 4.73	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79744	 1	 9.86	 4.44	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79745	 1	 7.6	 3.35	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79746	 1	 8.61	 4.72	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79747	 1	 6.22	 3.3	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79748	 1	 16.79	 7.23	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79749	 1	 16.23	 5.95	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79750	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79751	 1	 10.56	 4.75	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79752	 1	 3.93	 1.62	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79753	 1	 10.4	 5.31	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79754	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79755	 1	 23.21	 11.27	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79756	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79757	 1	 31.6	 14.07	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79758	 1	 19.28	 9.82	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79759	 1	 5.18	 2.41	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79760	 1	 9.2	 4.26	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79761	 1	 17.84	 7.29	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79762	 1	 29.3	 13.62	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79763	 1	 5.06	 2.89	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79764	 1	 2.73	 1.55	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79765	 1	 3.91	 1.83	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79766	 1	 5.69	 2.88	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79767	 1	 8.46	 3.98	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79768	 1	 8.71	 4.26	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79769	 1	 11.34	 4.82	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79770	 1	 6.42	 2.64	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79771	 1	 16.68	 8.76	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79772	 1	 5.38	 2.67	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79773	 1	 7.51	 3.39	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79774	 1	 6.18	 2.91	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79775	 1	 22.48	 10.68	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79776	 1	 6.79	 3.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79777	 1	 9.94	 4.96	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79778	 1	 9.08	 4.06	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79779	 1	 3.78	 1.97	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79780	 1	 7.64	 3.35	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79781	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79782	 1	 16.05	 8.48	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79783	 1	 14.82	 6.59	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79784	 1	 15.9	 6.71	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79785	 1	 5.51	 2.92	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79786	 1	 6.0	 3.17	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79787	 1	 2.53	 1.38	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79788	 1	 3.69	 1.61	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79789	 1	 10.67	 5.51	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79790	 1	 3.99	 1.64	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79791	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79792	 1	 35.81	 19.26	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79793	 1	 21.98	 10.19	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79794	 1	 21.79	 4.88	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79795	 1	 19.65	 9.9	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79796	 1	 12.82	 6.59	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79797	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79798	 1	 44.09	 17.75	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79799	 1	 20.71	 10.46	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79800	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79801	 1	 54.11	 24.92	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79802	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79803	 1	 5.51	 2.24	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79804	 1	 11.94	 5.07	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79805	 1	 7.32	 2.94	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79806	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79807	 1	 9.36	 4.71	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79808	 1	 10.32	 4.19	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79809	 1	 2.41	 1.12	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79810	 1	 7.25	 3.85	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79811	 1	 23.42	 7.55	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79812	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79813	 1	 16.38	 7.94	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79814	 1	 19.91	 9.07	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79815	 1	 9.39	 4.04	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79816	 1	 7.87	 3.29	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79817	 1	 28.49	 12.4	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79818	 1	 6.9	 3.66	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79819	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79820	 1	 13.6	 5.55	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79821	 1	 27.86	 10.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79822	 1	 10.08	 4.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79823	 1	 21.69	 8.48	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79824	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79825	 1	 25.85	 12.41	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79826	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79827	 1	 43.08	 17.5	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79828	 1	 7.74	 3.85	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79829	 1	 10.67	 4.37	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79830	 1	 7.37	 3.39	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79831	 1	 18.34	 7.98	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79832	 1	 12.01	 4.88	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79833	 1	 6.63	 3.02	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79834	 1	 7.51	 3.92	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79835	 1	 13.06	 6.51	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79836	 1	 13.78	 5.64	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79837	 1	 10.42	 4.36	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79838	 1	 3.24	 1.68	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79839	 1	 15.02	 6.44	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79840	 1	 6.08	 2.47	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79841	 1	 19.4	 7.17	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79842	 1	 14.18	 5.89	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79843	 1	 20.2	 7.92	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79844	 1	 4.28	 2.2	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79845	 1	 12.08	 5.57	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79846	 1	 17.05	 6.17	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79847	 1	 18.51	 6.75	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79848	 1	 18.17	 7.83	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79849	 1	 23.31	 9.13	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79850	 1	 25.06	 8.83	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79851	 1	 16.74	 6.44	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79852	 1	 2.71	 1.24	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79853	 1	 10.8	 4.25	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79854	 1	 6.65	 1.51	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79855	 1	 7.85	 1.79	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79856	 1	 22.03	 8.57	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79857	 1	 4.27	 0.97	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79858	 1	 13.12	 2.98	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79859	 1	 10.16	 2.31	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79860	 1	 14.67	 7.05	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79861	 1	 8.62	 4.17	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79862	 1	 10.33	 4.11	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79863	 1	 8.41	 1.9	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79864	 1	 9.12	 3.63	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79865	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79866	 1	 24.34	 11.15	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79867	 1	 9.9	 4.82	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79868	 1	 5.46	 2.42	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79869	 1	 19.81	 6.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79870	 1	 13.94	 5.96	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79871	 1	 5.37	 2.18	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79872	 1	 8.05	 3.3	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79873	 1	 5.19	 2.07	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79874	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79875	 1	 10.63	 4.68	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79876	 1	 24.54	 9.68	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79877	 1	 12.3	 4.75	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79878	 1	 7.02	 2.85	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79879	 1	 10.84	 4.43	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79880	 1	 6.51	 3.34	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79881	 1	 13.87	 5.78	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79882	 1	 4.65	 2.01	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79883	 1	 4.51	 2.2	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79884	 1	 8.97	 3.49	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79885	 1	 6.59	 3.25	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79886	 1	 8.67	 4.21	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79887	 1	 6.58	 3.18	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79888	 1	 9.07	 4.34	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79889	 1	 5.26	 2.24	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79890	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79891	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79892	 1	 4.89	 2.49	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79893	 1	 6.78	 2.92	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79894	 1	 7.08	 3.28	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79895	 1	 25.39	 8.97	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79896	 1	 6.09	 2.82	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79897	 1	 10.38	 4.37	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79898	 1	 11.04	 4.83	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79899	 1	 13.96	 6.07	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79900	 1	 9.33	 4.34	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79901	 1	 26.7	 8.88	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79902	 1	 12.01	 5.88	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79903	 1	 6.49	 3.08	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79904	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79905	 1	 11.42	 4.41	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79906	 1	 26.36	 8.51	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79907	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79908	 1	 31.6	 13.35	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79909	 1	 12.44	 4.71	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79910	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79911	 1	 6.11	 3.51	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79912	 1	 11.85	 5.47	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79913	 1	 30.21	 9.19	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79914	 1	 22.91	 9.66	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79915	 1	 4.9	 2.17	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79916	 1	 9.46	 4.57	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79917	 1	 8.57	 3.13	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79918	 1	 13.38	 6.19	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79919	 1	 6.16	 2.47	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79920	 1	 13.96	 5.9	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79921	 1	 9.89	 4.18	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79922	 1	 7.35	 3.39	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79923	 1	 3.42	 1.77	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79924	 1	 25.33	 9.28	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79925	 1	 9.44	 4.34	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79926	 1	 10.01	 5.37	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79927	 1	 7.28	 3.75	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79928	 1	 11.62	 4.7	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79929	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79930	 1	 6.75	 2.98	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79931	 1	 10.66	 4.12	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79932	 1	 16.05	 5.58	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79933	 1	 4.95	 2.31	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79934	 1	 9.14	 4.54	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79935	 1	 12.41	 4.25	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79936	 1	 19.12	 8.47	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79937	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79938	 1	 20.44	 8.65	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79939	 1	 4.29	 2.16	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79940	 1	 13.91	 6.08	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79941	 1	 7.75	 3.08	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79942	 1	 10.74	 4.75	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79943	 1	 8.45	 3.04	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79944	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79945	 1	 10.25	 4.14	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79946	 1	 15.1	 6.52	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79947	 1	 7.41	 3.68	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79948	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79949	 1	 25.44	 8.7	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79950	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79951	 1	 9.97	 4.3	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79952	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79953	 1	 30.78	 9.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79954	 1	 9.43	 3.14	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79955	 1	 19.18	 8.16	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79956	 1	 12.82	 6.58	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79957	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79958	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79959	 1	 11.06	 5.68	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79960	 1	 12.78	 5.81	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79961	 1	 6.82	 2.98	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79962	 1	 6.63	 3.48	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79963	 1	 20.09	 9.75	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79964	 1	 15.4	 5.68	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79965	 1	 9.19	 3.68	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79966	 1	 6.93	 3.63	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79967	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79968	 1	 21.9	 9.19	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79969	 1	 7.65	 3.01	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79970	 1	 8.35	 4.6	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79971	 1	 11.94	 6.19	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79972	 1	 11.6	 4.22	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79973	 1	 13.34	 5.98	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79974	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79975	 1	 16.06	 6.58	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79976	 1	 10.37	 3.92	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79977	 1	 3.07	 1.43	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79978	 1	 9.95	 4.07	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79979	 1	 12.55	 5.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79980	 1	 8.41	 3.56	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79981	 1	 9.51	 4.39	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79982	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79983	 1	 37.13	 14.01	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79984	 1	 18.23	 7.19	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79985	 1	 8.25	 4.08	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79986	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79987	 1	 6.11	 3.38	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79988	 1	 8.58	 4.15	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79989	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79990	 1	 11.85	 4.5	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79991	 1	 10.37	 4.91	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79992	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79993	 1	 19.16	 5.85	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79994	 1	 6.24	 2.79	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79995	 1	 10.36	 5.06	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79996	 1	 5.89	 3.09	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79997	 1	 5.49	 2.42	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79998	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79999	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80000	 1	 29.14	 9.7	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80001	 1	 7.08	 3.42	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80002	 1	 6.3	 2.87	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80003	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80004	 1	 22.55	 9.28	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80005	 1	 13.01	 6.67	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80006	 1	 8.4	 4.3	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80007	 1	 4.35	 1.88	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80008	 1	 5.4	 2.43	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80009	 1	 10.65	 5.3	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80010	 1	 9.28	 4.88	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80011	 1	 13.75	 5.89	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80012	 1	 9.99	 4.81	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80013	 1	 3.57	 1.52	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80014	 1	 10.99	 3.96	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80015	 1	 9.16	 4.7	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80016	 1	 13.02	 5.84	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80017	 1	 22.05	 10.12	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80018	 1	 4.06	 2.17	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80019	 1	 8.49	 4.44	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80020	 1	 8.63	 3.39	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80021	 1	 7.82	 3.03	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80022	 1	 11.94	 5.21	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80023	 1	 11.77	 4.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80024	 1	 10.77	 4.69	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80025	 1	 12.58	 6.07	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80026	 1	 19.12	 8.38	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80027	 1	 45.43	 20.05	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80028	 1	 10.85	 4.91	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80029	 1	 8.67	 1.97	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80030	 1	 23.24	 5.26	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80031	 1	 13.47	 3.05	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80032	 1	 6.87	 1.56	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80033	 1	 14.35	 3.26	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80034	 1	 11.93	 5.47	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80035	 1	 13.58	 3.07	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80036	 1	 9.67	 2.18	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80037	 1	 10.05	 2.26	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80038	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80039	 1	 24.99	 5.68	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80040	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80041	 1	 25.5	 10.17	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80042	 1	 6.89	 3.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80043	 1	 10.19	 4.43	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80044	 1	 19.18	 8.68	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80045	 1	 21.09	 7.72	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80046	 1	 21.64	 9.24	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80047	 1	 6.61	 2.53	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80048	 1	 9.38	 4.2	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80049	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80050	 1	 7.2	 3.69	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80051	 1	 7.95	 3.61	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80052	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80053	 1	 5.34	 2.44	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80054	 1	 9.83	 4.5	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80055	 1	 4.56	 2.43	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80056	 1	 7.42	 3.61	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80057	 1	 2.76	 1.39	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80058	 1	 9.39	 4.87	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80059	 1	 20.57	 8.69	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80060	 1	 8.29	 3.41	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80061	 1	 7.02	 3.62	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80062	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80063	 1	 10.5	 4.81	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80064	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80065	 1	 14.0	 5.25	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80066	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80067	 1	 13.06	 6.38	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80068	 1	 11.5	 5.43	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80069	 1	 14.14	 5.03	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80070	 1	 10.89	 4.13	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80071	 1	 8.32	 3.74	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80072	 1	 6.13	 2.42	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80073	 1	 6.88	 3.03	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80074	 1	 20.65	 8.48	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80075	 1	 9.34	 3.92	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80076	 1	 17.41	 6.05	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80077	 1	 8.45	 3.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80078	 1	 16.49	 7.87	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80079	 1	 12.09	 5.32	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80080	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80081	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80082	 1	 35.93	 16.16	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80083	 1	 10.77	 5.36	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80084	 1	 21.0	 7.43	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80085	 1	 4.8	 2.01	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80086	 1	 9.0	 4.07	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80087	 1	 13.17	 2.98	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80088	 1	 13.62	 4.99	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80089	 1	 7.15	 3.08	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80090	 1	 4.44	 1.95	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80091	 1	 9.96	 3.74	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80092	 1	 19.76	 8.8	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80093	 1	 8.49	 3.55	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80094	 1	 11.54	 4.99	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80095	 1	 11.97	 4.55	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80096	 1	 10.17	 4.51	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80097	 1	 6.94	 2.93	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80098	 1	 13.98	 4.94	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80099	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80100	 1	 36.65	 14.69	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80101	 1	 16.18	 5.7	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80102	 1	 16.23	 3.66	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80103	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80104	 1	 9.82	 4.71	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80105	 1	 8.08	 1.82	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80106	 1	 3.54	 0.81	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80107	 1	 7.84	 1.77	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80108	 1	 4.57	 1.91	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80109	 1	 4.1	 1.76	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80110	 1	 7.91	 3.36	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80111	 1	 9.37	 4.05	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80112	 1	 18.57	 7.24	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80113	 1	 9.47	 4.6	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80114	 1	 10.01	 4.09	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80115	 1	 13.47	 4.57	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80116	 1	 10.28	 4.53	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80117	 1	 10.77	 4.76	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80118	 1	 19.63	 7.56	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80119	 1	 7.37	 3.11	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80120	 1	 16.75	 5.8	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80121	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80122	 1	 52.57	 17.99	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80123	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80124	 1	 10.59	 4.31	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80125	 1	 10.38	 2.33	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80126	 1	 8.43	 4.13	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80127	 1	 10.99	 4.5	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80128	 1	 15.86	 7.01	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80129	 1	 5.94	 2.3	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80130	 1	 14.97	 5.97	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80131	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80132	 1	 13.71	 4.97	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80133	 1	 13.99	 6.04	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80134	 1	 4.13	 1.84	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80135	 1	 12.33	 5.7	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80136	 1	 7.44	 3.33	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80137	 1	 5.4	 2.14	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80138	 1	 5.97	 2.86	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80139	 1	 3.59	 1.56	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80140	 1	 18.36	 6.89	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80141	 1	 7.04	 3.11	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80142	 1	 11.89	 4.97	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80143	 1	 8.37	 3.81	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80144	 1	 47.99	 17.14	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80145	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80146	 1	 10.14	 4.11	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80147	 1	 5.98	 2.63	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80148	 1	 22.15	 8.29	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80149	 1	 8.87	 3.67	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80150	 1	 7.61	 3.96	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80151	 1	 11.16	 4.87	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80152	 1	 4.66	 2.05	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80153	 1	 6.64	 2.86	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80154	 1	 16.66	 7.01	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80155	 1	 2.44	 1.08	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80156	 1	 11.16	 4.92	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80157	 1	 5.27	 2.18	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80158	 1	 7.52	 2.85	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80159	 1	 10.16	 4.91	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80160	 1	 8.24	 3.48	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80161	 1	 10.12	 4.1	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80162	 1	 7.74	 2.85	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80163	 1	 6.65	 2.84	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80164	 1	 13.64	 5.34	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80165	 1	 13.71	 6.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80166	 1	 15.49	 5.77	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80167	 1	 13.37	 5.21	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80168	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80169	 1	 7.84	 3.18	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80170	 1	 12.29	 5.29	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80171	 1	 28.69	 9.79	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80172	 1	 17.91	 7.29	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80173	 1	 9.16	 4.02	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80174	 1	 3.42	 1.78	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80175	 1	 4.26	 2.11	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80176	 1	 6.76	 2.73	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80177	 1	 13.89	 6.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80178	 1	 9.63	 2.18	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80179	 1	 4.1	 1.75	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80180	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80181	 1	 22.26	 8.12	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80182	 1	 15.76	 3.57	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80183	 1	 15.09	 5.82	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80184	 1	 4.56	 1.7	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80185	 1	 12.45	 5.48	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80186	 1	 12.98	 5.34	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80187	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80188	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80189	 1	 27.15	 10.3	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80190	 1	 14.25	 5.59	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80191	 1	 15.47	 6.42	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80192	 1	 10.76	 5.18	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80193	 1	 18.52	 6.62	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80194	 1	 16.26	 3.68	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80195	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80196	 1	 19.74	 7.49	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80197	 1	 27.81	 11.04	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80198	 1	 10.01	 4.28	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80199	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80200	 1	 46.14	 19.18	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80201	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80202	 1	 6.46	 2.58	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80203	 1	 11.52	 5.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80204	 1	 26.26	 10.29	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80205	 1	 11.49	 5.87	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80206	 1	 11.29	 4.3	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80207	 1	 10.83	 5.23	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80208	 1	 9.75	 4.95	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80209	 1	 4.21	 2.05	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80210	 1	 10.2	 4.35	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80211	 1	 23.24	 9.38	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80212	 1	 6.13	 2.86	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80213	 1	 11.96	 4.71	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80214	 1	 25.55	 11.83	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80215	 1	 15.6	 7.37	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80216	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80217	 1	 28.97	 9.1	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80218	 1	 12.16	 5.64	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80219	 1	 10.99	 4.91	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80220	 1	 7.99	 3.98	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80221	 1	 12.69	 5.2	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80222	 1	 23.09	 7.22	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80223	 1	 9.4	 4.43	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80224	 1	 14.0	 6.62	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80225	 1	 7.71	 3.46	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80226	 1	 9.12	 4.17	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80227	 1	 4.56	 1.62	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80228	 1	 8.1	 3.16	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80229	 1	 5.32	 2.08	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80230	 1	 6.31	 3.05	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80231	 1	 10.49	 4.7	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80232	 1	 19.36	 8.57	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80233	 1	 5.92	 3.15	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80234	 1	 24.89	 9.03	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80235	 1	 14.86	 5.82	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80236	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80237	 1	 18.13	 8.74	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80238	 1	 16.34	 7.28	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80239	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80240	 1	 16.85	 6.72	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80241	 1	 8.24	 3.12	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80242	 1	 9.61	 4.32	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80243	 1	 5.98	 2.64	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80244	 1	 11.77	 4.76	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80245	 1	 14.03	 6.36	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80246	 1	 11.08	 4.21	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80247	 1	 11.67	 5.21	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80248	 1	 9.78	 3.99	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80249	 1	 6.31	 2.55	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80250	 1	 4.16	 1.61	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80251	 1	 5.8	 2.52	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80252	 1	 8.3	 3.85	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80253	 1	 5.54	 2.23	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80254	 1	 12.52	 4.93	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80255	 1	 7.84	 3.05	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80256	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80257	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80258	 1	 39.54	 14.56	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80259	 1	 25.42	 8.12	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80260	 1	 17.28	 7.14	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80261	 1	 7.28	 3.33	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80262	 1	 5.74	 2.58	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80263	 1	 82.86	 30.57	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80264	 1	 82.76	 28.79	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80265	 1	 10.06	 4.22	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80266	 1	 9.38	 4.87	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80267	 1	 7.25	 3.66	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80268	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80269	 1	 7.87	 3.05	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80270	 1	 5.94	 2.46	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80271	 1	 34.76	 12.7	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80272	 1	 68.81	 21.86	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80273	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80274	 1	 9.57	 3.96	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80275	 1	 7.14	 2.92	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80276	 1	 9.46	 4.11	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80277	 1	 9.95	 4.42	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80278	 1	 12.71	 5.32	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80279	 1	 14.46	 6.82	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80280	 1	 12.99	 5.58	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80281	 1	 7.48	 3.36	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80282	 1	 15.83	 7.45	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80283	 1	 16.45	 7.52	 0.0	 0.0	 15	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80284	 1	 12.23	 2.78	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80285	 1	 8.29	 1.87	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80286	 1	 24.68	 5.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80287	 1	 3.53	 0.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80288	 1	 22.86	 5.1	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80289	 1	 7.71	 1.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80290	 1	 26.43	 6.02	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80291	 1	 10.34	 2.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80292	 1	 2.69	 1.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80293	 1	 6.7	 2.95	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80294	 1	 6.39	 3.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80295	 1	 30.43	 6.87	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80296	 1	 3.19	 0.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80297	 1	 9.76	 2.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80298	 1	 7.67	 1.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80299	 1	 14.35	 4.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80300	 1	 17.97	 9.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80301	 1	 15.19	 6.01	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80302	 1	 2.45	 1.52	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80303	 1	 15.22	 5.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80304	 1	 6.65	 3.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80305	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80306	 1	 7.84	 3.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80307	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80308	 1	 8.87	 4.06	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80309	 1	 6.26	 3.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80310	 1	 21.47	 4.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80311	 1	 10.09	 2.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80312	 1	 31.17	 7.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80313	 1	 8.86	 2.02	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80314	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80315	 1	 20.27	 6.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80316	 1	 8.02	 3.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80317	 1	 19.3	 6.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80318	 1	 5.02	 2.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80319	 1	 14.13	 5.74	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80320	 1	 7.79	 3.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80321	 1	 8.58	 3.85	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80322	 1	 6.87	 1.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80323	 1	 10.56	 4.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80324	 1	 18.59	 4.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80325	 1	 10.07	 2.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80326	 1	 9.4	 2.1	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80327	 1	 18.93	 4.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80328	 1	 26.24	 5.95	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80329	 1	 14.67	 3.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80330	 1	 15.58	 3.62	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80331	 1	 6.92	 1.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80332	 1	 17.27	 3.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80333	 1	 22.07	 4.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80334	 1	 20.66	 5.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80335	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80336	 1	 9.98	 4.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80337	 1	 10.58	 4.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80338	 1	 9.68	 4.94	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80339	 1	 6.65	 3.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80340	 1	 12.39	 4.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80341	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80342	 1	 8.4	 3.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80343	 1	 12.87	 4.48	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80344	 1	 7.6	 3.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80345	 1	 14.09	 5.06	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80346	 1	 14.67	 5.1	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80347	 1	 14.03	 3.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80348	 1	 5.42	 2.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80349	 1	 32.12	 13.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80350	 1	 45.1	 10.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80351	 1	 31.72	 6.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80352	 1	 16.76	 3.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80353	 1	 5.21	 2.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80354	 1	 7.87	 1.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80355	 1	 6.75	 1.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80356	 1	 17.41	 3.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80357	 1	 42.54	 9.44	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80358	 1	 24.23	 5.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80359	 1	 6.49	 1.48	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80360	 1	 6.71	 1.52	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80361	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80362	 1	 7.25	 3.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80363	 1	 9.98	 4.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80364	 1	 4.51	 2.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80365	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80366	 1	 12.41	 4.05	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80367	 1	 16.03	 5.76	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80368	 1	 18.92	 8.36	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80369	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80370	 1	 38.32	 11.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80371	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80372	 1	 64.42	 15.92	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80373	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80374	 1	 37.86	 10.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80375	 1	 37.8	 12.04	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80376	 1	 6.7	 3.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80377	 1	 7.44	 3.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80378	 1	 44.75	 17.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80379	 1	 26.71	 6.82	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80380	 1	 14.68	 6.76	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80381	 1	 20.98	 7.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80382	 1	 24.76	 5.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80383	 1	 15.95	 3.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80384	 1	 16.97	 6.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80385	 1	 21.36	 5.06	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80386	 1	 23.45	 9.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80387	 1	 18.57	 5.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80388	 1	 7.26	 3.08	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80389	 1	 1.1	 0.61	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80390	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80391	 1	 15.42	 6.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80392	 1	 18.2	 5.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80393	 1	 3.77	 1.96	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80394	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80395	 1	 30.07	 7.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80396	 1	 2.69	 1.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80397	 1	 12.1	 5.06	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80398	 1	 4.7	 2.23	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80399	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80400	 1	 130.25	 50.46	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80401	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80402	 1	 6.8	 2.83	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80403	 1	 16.26	 6.01	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80404	 1	 4.89	 2.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80405	 1	 7.84	 3.94	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80406	 1	 20.55	 7.51	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80407	 1	 10.56	 4.96	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80408	 1	 8.02	 3.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80409	 1	 12.79	 5.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80410	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80411	 1	 35.87	 15.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80412	 1	 9.07	 5.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80413	 1	 10.09	 4.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80414	 1	 7.71	 3.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80415	 1	 12.75	 7.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80416	 1	 8.46	 4.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80417	 1	 8.87	 4.76	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80418	 1	 7.36	 4.15	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80419	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80420	 1	 50.23	 19.49	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80421	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80422	 1	 3.51	 1.95	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80423	 1	 1.68	 1.06	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80424	 1	 1.97	 1.1	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80425	 1	 10.43	 4.52	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80426	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80427	 1	 26.94	 6.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80428	 1	 6.14	 1.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80429	 1	 8.57	 2.05	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80430	 1	 17.44	 7.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80431	 1	 21.06	 8.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80432	 1	 12.7	 5.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80433	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80434	 1	 40.11	 9.73	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80435	 1	 28.8	 11.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80436	 1	 8.65	 2.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80437	 1	 17.66	 6.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80438	 1	 10.04	 4.99	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80439	 1	 7.74	 2.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80440	 1	 10.49	 4.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80441	 1	 4.38	 2.19	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80442	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80443	 1	 33.57	 7.3	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80444	 1	 11.72	 4.4	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80445	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80446	 1	 12.48	 4.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80447	 1	 19.24	 4.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80448	 1	 9.4	 4.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80449	 1	 20.57	 7.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80450	 1	 20.14	 6.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80451	 1	 3.01	 1.61	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80452	 1	 20.31	 8.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80453	 1	 11.04	 3.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80454	 1	 7.77	 3.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80455	 1	 9.47	 3.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80456	 1	 17.17	 4.63	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80457	 1	 11.9	 4.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80458	 1	 57.29	 24.5	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80459	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80460	 1	 24.54	 9.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80461	 1	 22.44	 7.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80462	 1	 7.97	 3.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80463	 1	 5.65	 3.44	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80464	 1	 13.38	 6.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80465	 1	 7.68	 3.59	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80466	 1	 26.94	 9.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80467	 1	 10.07	 4.73	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80468	 1	 9.18	 4.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80469	 1	 4.29	 2.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80470	 1	 21.99	 5.02	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80471	 1	 7.52	 3.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80472	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80473	 1	 31.24	 13.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80474	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80475	 1	 45.32	 18.53	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80476	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80477	 1	 164.03	 50.58	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80478	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80479	 1	 10.66	 2.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80480	 1	 25.94	 5.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80481	 1	 3.52	 0.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80482	 1	 5.72	 1.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80483	 1	 5.94	 2.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80484	 1	 1.75	 0.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80485	 1	 22.97	 9.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80486	 1	 10.7	 4.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80487	 1	 14.8	 6.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80488	 1	 4.97	 2.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80489	 1	 18.43	 5.61	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80490	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80491	 1	 19.99	 7.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80492	 1	 6.45	 3.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80493	 1	 20.82	 7.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80494	 1	 15.27	 5.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80495	 1	 21.7	 8.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80496	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80497	 1	 28.46	 10.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80498	 1	 20.57	 5.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80499	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80500	 1	 4.55	 2.47	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80501	 1	 3.57	 2.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80502	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80503	 1	 3.1	 1.95	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80504	 1	 11.89	 5.43	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80505	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80506	 1	 16.46	 6.55	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80507	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80508	 1	 30.84	 10.44	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80509	 1	 7.53	 3.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80510	 1	 5.56	 3.32	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80511	 1	 25.26	 8.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80512	 1	 14.65	 5.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80513	 1	 7.83	 3.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80514	 1	 5.29	 3.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80515	 1	 2.77	 1.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80516	 1	 2.91	 1.39	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80517	 1	 4.64	 2.06	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80518	 1	 15.29	 6.59	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80519	 1	 13.06	 4.48	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80520	 1	 11.68	 5.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80521	 1	 15.07	 4.99	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80522	 1	 4.64	 2.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80523	 1	 20.04	 7.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80524	 1	 14.02	 6.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80525	 1	 5.7	 2.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80526	 1	 18.58	 7.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80527	 1	 2.92	 1.48	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80528	 1	 19.23	 4.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80529	 1	 5.13	 1.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80530	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80531	 1	 38.04	 9.44	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80532	 1	 12.68	 4.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80533	 1	 6.49	 3.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80534	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80535	 1	 7.17	 3.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80536	 1	 5.04	 2.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80537	 1	 4.63	 2.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80538	 1	 26.98	 7.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80539	 1	 5.4	 2.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80540	 1	 2.87	 1.55	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80541	 1	 13.47	 4.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80542	 1	 15.33	 3.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80543	 1	 6.45	 3.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80544	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80545	 1	 30.01	 11.93	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80546	 1	 23.68	 8.43	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80547	 1	 29.46	 12.55	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80548	 1	 5.21	 1.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80549	 1	 17.63	 5.48	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80550	 1	 3.96	 1.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80551	 1	 24.4	 7.82	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80552	 1	 7.37	 2.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80553	 1	 8.36	 3.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80554	 1	 29.12	 11.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80555	 1	 25.9	 9.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80556	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80557	 1	 40.7	 9.61	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80558	 1	 102.99	 36.81	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80559	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80560	 1	 4.93	 2.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80561	 1	 4.85	 2.61	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80562	 1	 104.63	 34.93	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80563	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80564	 1	 9.28	 3.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80565	 1	 15.1	 6.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80566	 1	 28.66	 11.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80567	 1	 20.26	 7.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80568	 1	 15.66	 6.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80569	 1	 14.84	 4.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80570	 1	 14.76	 6.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80571	 1	 90.45	 26.51	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80572	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80573	 1	 19.94	 7.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80574	 1	 12.88	 7.17	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80575	 1	 9.15	 4.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80576	 1	 7.89	 3.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80577	 1	 17.23	 6.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80578	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80579	 1	 348.73	 110.51	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80580	 1	 14.28	 5.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80581	 1	 35.64	 12.63	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80582	 1	 52.22	 19.29	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80583	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80584	 1	 42.4	 14.94	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80585	 1	 8.37	 3.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80586	 1	 16.04	 3.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80587	 1	 7.08	 1.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80588	 1	 21.69	 8.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80589	 1	 7.74	 3.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80590	 1	 4.97	 2.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80591	 1	 6.01	 2.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80592	 1	 14.93	 6.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80593	 1	 17.83	 6.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80594	 1	 7.85	 4.05	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80595	 1	 22.38	 8.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80596	 1	 2.84	 1.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80597	 1	 4.77	 2.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80598	 1	 4.17	 2.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80599	 1	 3.55	 2.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80600	 1	 12.86	 6.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80601	 1	 33.38	 8.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80602	 1	 16.74	 6.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80603	 1	 9.74	 2.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80604	 1	 11.06	 2.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80605	 1	 15.8	 3.55	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80606	 1	 17.14	 3.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80607	 1	 19.6	 7.83	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80608	 1	 20.23	 4.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80609	 1	 10.76	 5.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80610	 1	 3.1	 1.78	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80611	 1	 15.22	 5.3	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80612	 1	 37.25	 10.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80613	 1	 12.35	 6.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80614	 1	 67.52	 26.7	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80615	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80616	 1	 12.33	 3.09	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80617	 1	 9.58	 3.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80618	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80619	 1	 27.47	 7.62	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80620	 1	 7.04	 3.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80621	 1	 26.64	 11.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80622	 1	 17.6	 7.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80623	 1	 11.52	 4.61	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80624	 1	 20.69	 10.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80625	 1	 4.09	 1.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80626	 1	 227.79	 74.51	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80627	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80628	 1	 24.82	 11.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80629	 1	 20.71	 8.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80630	 1	 9.84	 4.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80631	 1	 18.26	 7.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80632	 1	 7.11	 4.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80633	 1	 6.26	 3.31	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80634	 1	 9.47	 2.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80635	 1	 21.84	 6.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80636	 1	 18.8	 7.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80637	 1	 8.55	 4.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80638	 1	 51.25	 17.53	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80639	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80640	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80641	 1	 8.87	 3.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80642	 1	 23.26	 5.15	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80643	 1	 1.95	 0.44	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80644	 1	 14.06	 3.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80645	 1	 13.83	 3.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80646	 1	 15.81	 3.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80647	 1	 5.14	 1.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80648	 1	 19.37	 7.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80649	 1	 9.27	 4.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80650	 1	 8.32	 2.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80651	 1	 9.97	 3.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80652	 1	 20.17	 8.71	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80653	 1	 16.9	 3.88	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80654	 1	 18.43	 4.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80655	 1	 4.89	 2.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80656	 1	 4.78	 2.36	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80657	 1	 14.55	 5.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80658	 1	 13.42	 4.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80659	 1	 10.83	 4.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80660	 1	 15.89	 5.44	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80661	 1	 10.82	 4.36	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80662	 1	 22.18	 7.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80663	 1	 21.45	 9.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80664	 1	 5.44	 2.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80665	 1	 5.24	 2.94	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80666	 1	 6.96	 3.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80667	 1	 10.22	 4.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80668	 1	 4.41	 1.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80669	 1	 8.9	 4.02	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80670	 1	 11.85	 6.05	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80671	 1	 6.78	 3.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80672	 1	 5.39	 2.55	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80673	 1	 7.34	 2.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80674	 1	 16.05	 6.69	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80675	 1	 7.43	 3.56	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80676	 1	 7.01	 4.09	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80677	 1	 9.22	 4.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80678	 1	 15.62	 5.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80679	 1	 5.7	 2.63	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80680	 1	 6.21	 3.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80681	 1	 7.81	 2.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80682	 1	 22.97	 7.5	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80683	 1	 21.35	 7.35	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80684	 1	 7.48	 4.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80685	 1	 8.97	 3.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80686	 1	 11.6	 5.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80687	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80688	 1	 24.35	 9.85	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80689	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80690	 1	 47.99	 20.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80691	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80692	 1	 67.3	 27.6	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80693	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80694	 1	 58.96	 23.32	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80695	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80696	 1	 16.13	 7.01	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80697	 1	 7.04	 3.23	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80698	 1	 32.2	 12.83	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80699	 1	 29.75	 12.63	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80700	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80701	 1	 33.41	 14.06	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80702	 1	 6.91	 3.03	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80703	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80704	 1	 22.29	 7.55	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80705	 1	 4.41	 2.11	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80706	 1	 2.11	 1.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80707	 1	 4.51	 2.43	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80708	 1	 24.88	 8.59	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80709	 1	 20.27	 9.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80710	 1	 7.67	 4.23	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80711	 1	 5.64	 3.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80712	 1	 5.03	 2.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80713	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80714	 1	 32.91	 11.11	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80715	 1	 5.76	 2.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80716	 1	 9.29	 4.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80717	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80718	 1	 38.06	 8.96	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80719	 1	 6.2	 3.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80720	 1	 9.54	 4.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80721	 1	 7.46	 3.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80722	 1	 7.22	 3.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80723	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80724	 1	 17.03	 6.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80725	 1	 26.73	 11.73	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80726	 1	 22.79	 9.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80727	 1	 66.32	 21.69	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80728	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80729	 1	 30.17	 12.15	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80730	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80731	 1	 143.87	 49.03	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80732	 1	 9.13	 5.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80733	 1	 5.53	 2.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80734	 1	 4.56	 2.61	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80735	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80736	 1	 5.64	 3.44	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80737	 1	 4.72	 2.73	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80738	 1	 22.05	 9.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80739	 1	 6.69	 3.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80740	 1	 8.23	 4.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80741	 1	 8.43	 3.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80742	 1	 18.09	 7.19	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80743	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80744	 1	 64.92	 21.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80745	 1	 8.66	 3.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80746	 1	 14.8	 3.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80747	 1	 29.47	 11.87	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80748	 1	 18.5	 6.47	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80749	 1	 9.43	 3.52	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80750	 1	 8.13	 3.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80751	 1	 3.78	 1.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80752	 1	 7.9	 3.51	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80753	 1	 8.52	 3.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80754	 1	 8.56	 3.87	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80755	 1	 28.1	 11.47	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80756	 1	 11.34	 2.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80757	 1	 22.17	 5.1	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80758	 1	 24.89	 8.47	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80759	 1	 18.98	 4.36	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80760	 1	 6.94	 1.59	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80761	 1	 14.49	 3.32	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80762	 1	 12.66	 5.02	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80763	 1	 10.79	 5.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80764	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80765	 1	 29.6	 12.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80766	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80767	 1	 137.49	 53.45	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80768	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80769	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80770	 1	 1.91	 1.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80771	 1	 83.15	 33.45	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80772	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80773	 1	 23.45	 10.39	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80774	 1	 113.4	 46.85	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80775	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80776	 1	 20.07	 6.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80777	 1	 7.65	 4.19	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80778	 1	 11.14	 5.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80779	 1	 7.74	 3.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80780	 1	 10.52	 5.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80781	 1	 21.69	 6.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80782	 1	 17.78	 8.15	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80783	 1	 14.18	 3.23	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80784	 1	 7.89	 3.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80785	 1	 21.72	 4.94	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80786	 1	 102.84	 42.7	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80787	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80788	 1	 24.55	 9.15	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80789	 1	 12.99	 6.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80790	 1	 23.13	 5.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80791	 1	 4.58	 2.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80792	 1	 13.03	 5.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80793	 1	 20.23	 4.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80794	 1	 8.41	 1.82	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80795	 1	 10.63	 2.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80796	 1	 5.31	 1.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80797	 1	 4.95	 1.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80798	 1	 15.36	 3.57	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80799	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80800	 1	 29.65	 11.67	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80801	 1	 7.47	 4.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80802	 1	 5.18	 2.23	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80803	 1	 4.92	 2.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80804	 1	 4.79	 1.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80805	 1	 15.24	 3.52	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80806	 1	 5.87	 3.99	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80807	 1	 12.66	 5.31	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80808	 1	 16.61	 6.77	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80809	 1	 28.09	 10.07	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80810	 1	 8.32	 4.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80811	 1	 15.49	 3.4	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80812	 1	 28.23	 6.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80813	 1	 10.07	 2.23	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80814	 1	 37.51	 8.36	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80815	 1	 5.48	 1.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80816	 1	 6.54	 1.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80817	 1	 4.06	 0.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80818	 1	 24.89	 5.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80819	 1	 10.22	 2.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80820	 1	 6.46	 1.51	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80821	 1	 22.9	 5.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80822	 1	 15.44	 3.45	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80823	 1	 44.67	 9.95	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80824	 1	 8.68	 1.96	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80825	 1	 15.72	 3.42	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80826	 1	 20.29	 4.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80827	 1	 6.38	 1.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80828	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80829	 1	 57.02	 14.63	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80830	 1	 6.59	 1.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80831	 1	 22.73	 8.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80832	 1	 9.95	 4.81	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80833	 1	 18.76	 7.91	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80834	 1	 43.0	 16.38	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80835	 1	 10.57	 4.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80836	 1	 9.99	 4.51	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80837	 1	 17.45	 5.53	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80838	 1	 7.93	 4.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80839	 1	 14.56	 6.95	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80840	 1	 16.37	 6.39	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80841	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80842	 1	 19.04	 8.27	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80843	 1	 4.76	 2.49	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80844	 1	 6.18	 2.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80845	 1	 4.35	 1.99	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80846	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80847	 1	 5.93	 2.15	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80848	 1	 6.59	 2.11	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80849	 1	 12.78	 4.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80850	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80851	 1	 12.28	 6.21	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80852	 1	 94.92	 39.23	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80853	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80854	 1	 11.08	 5.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80855	 1	 28.19	 10.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80856	 1	 31.41	 11.37	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80857	 1	 10.26	 3.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80858	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80859	 1	 15.7	 6.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80860	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80861	 1	 29.53	 7.61	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80862	 1	 11.77	 5.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80863	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80864	 1	 13.04	 4.99	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80865	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80866	 1	 30.93	 13.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80867	 1	 5.84	 2.34	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80868	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80869	 1	 27.42	 12.62	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80870	 1	 18.56	 7.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80871	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80872	 1	 10.07	 3.78	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80873	 1	 7.62	 3.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80874	 1	 27.94	 9.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80875	 1	 19.59	 8.92	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80876	 1	 12.31	 4.87	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80877	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80878	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80879	 1	 25.32	 8.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80880	 1	 26.24	 7.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80881	 1	 3.05	 1.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80882	 1	 10.48	 4.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80883	 1	 18.81	 8.19	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80884	 1	 15.72	 4.96	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80885	 1	 6.27	 3.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80886	 1	 14.3	 6.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80887	 1	 20.6	 4.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80888	 1	 8.78	 1.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80889	 1	 16.94	 3.8	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80890	 1	 20.87	 4.69	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80891	 1	 8.48	 1.89	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80892	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80893	 1	 40.97	 18.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80894	 1	 17.9	 4.05	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80895	 1	 9.24	 2.11	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80896	 1	 3.23	 1.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80897	 1	 20.96	 8.9	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80898	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80899	 1	 36.95	 10.25	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80900	 1	 4.46	 2.52	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80901	 1	 10.57	 4.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80902	 1	 10.19	 3.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80903	 1	 19.33	 6.78	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80904	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80905	 1	 74.46	 29.4	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80906	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80907	 1	 13.48	 5.22	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80908	 1	 16.02	 7.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80909	 1	 2.75	 1.07	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80910	 1	 17.97	 5.26	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80911	 1	 12.0	 2.73	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80912	 1	 9.4	 2.14	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80913	 1	 11.19	 2.55	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80914	 1	 8.46	 3.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80915	 1	 16.2	 5.65	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80916	 1	 9.46	 4.19	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80917	 1	 26.32	 8.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80918	 1	 3.98	 2.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80919	 1	 6.32	 3.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80920	 1	 28.48	 12.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80921	 1	 24.61	 5.6	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80922	 1	 14.01	 6.51	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80923	 1	 29.4	 12.17	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80924	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80925	 1	 16.45	 8.09	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80926	 1	 6.17	 3.44	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80927	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80928	 1	 54.9	 20.33	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80929	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80930	 1	 11.56	 5.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80931	 1	 7.05	 3.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80932	 1	 9.69	 4.54	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80933	 1	 7.03	 3.33	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80934	 1	 3.92	 1.32	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80935	 1	 6.34	 2.84	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80936	 1	 7.77	 3.74	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80937	 1	 4.36	 2.41	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80938	 1	 11.42	 5.16	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80939	 1	 14.17	 6.01	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80940	 1	 72.67	 30.31	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80941	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80942	 1	 5.23	 2.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80943	 1	 16.74	 7.81	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80944	 1	 12.27	 4.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80945	 1	 7.88	 3.24	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80946	 1	 12.45	 4.58	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80947	 1	 15.91	 4.73	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80948	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80949	 1	 22.68	 8.01	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80950	 1	 6.15	 2.85	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80951	 1	 11.37	 5.13	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80952	 1	 3.05	 1.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80953	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80954	 1	 34.76	 14.69	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80955	 1	 10.29	 4.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80956	 1	 22.44	 9.16	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80957	 1	 12.24	 5.7	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80958	 1	 4.91	 2.51	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80959	 1	 16.83	 7.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80960	 1	 9.19	 3.68	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80961	 1	 2.99	 1.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80962	 1	 39.82	 15.75	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80963	 1	 14.52	 6.19	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80964	 1	 5.06	 1.87	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80965	 1	 8.23	 2.43	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80966	 1	 51.85	 18.44	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80967	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80968	 1	 7.29	 3.29	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80969	 1	 7.01	 3.46	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80970	 1	 9.07	 4.3	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80971	 1	 26.1	 5.96	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80972	 1	 14.03	 3.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80973	 1	 30.49	 11.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80974	 1	 7.52	 2.79	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80975	 1	 3.6	 1.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80976	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80977	 1	 2.61	 1.49	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80978	 1	 18.73	 8.08	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80979	 1	 10.99	 5.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80980	 1	 32.6	 12.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80981	 1	 12.64	 5.28	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80982	 1	 49.62	 19.02	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80983	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80984	 1	 7.81	 4.43	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80985	 1	 20.18	 8.2	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80986	 1	 14.17	 4.93	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80987	 1	 10.81	 2.43	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80988	 1	 16.65	 3.72	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80989	 1	 11.78	 2.64	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80990	 1	 3.78	 0.86	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80991	 1	 13.33	 2.98	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80992	 1	 34.52	 7.85	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80993	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80994	 1	 36.65	 12.66	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80995	 1	 2.85	 0.97	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80996	 1	 9.4	 2.12	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80997	 1	 20.92	 7.18	 0.0	 0.0	 25	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80998	 1	 17.59	 6.99	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	80999	 1	 7.57	 1.88	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81000	 1	 17.05	 8.23	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81001	 1	 13.81	 6.18	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81002	 1	 11.74	 5.79	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81003	 1	 19.28	 6.86	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81004	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81005	 1	 20.65	 8.93	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81006	 1	 18.51	 5.26	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81007	 1	 17.08	 6.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81008	 1	 26.55	 10.58	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81009	 1	 11.24	 5.46	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81010	 1	 4.4	 1.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81011	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81012	 1	 6.95	 3.19	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81013	 1	 33.21	 10.63	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81014	 1	 6.01	 2.65	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81015	 1	 3.18	 1.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81016	 1	 14.91	 5.2	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81017	 1	 12.4	 4.35	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81018	 1	 9.2	 3.98	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81019	 1	 14.96	 5.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81020	 1	 1.11	 0.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81021	 1	 5.29	 2.8	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81022	 1	 17.9	 6.81	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81023	 1	 20.95	 8.68	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81024	 1	 24.85	 5.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81025	 1	 4.76	 1.84	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81026	 1	 12.06	 5.02	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81027	 1	 6.79	 2.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81028	 1	 11.17	 4.05	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81029	 1	 10.5	 5.13	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81030	 1	 15.96	 5.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81031	 1	 5.25	 2.25	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81032	 1	 9.11	 3.93	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81033	 1	 14.36	 5.7	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81034	 1	 7.4	 2.67	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81035	 1	 19.73	 6.71	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81036	 1	 33.39	 13.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81037	 1	 20.26	 7.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81038	 1	 7.07	 3.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81039	 1	 12.75	 5.18	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81040	 1	 7.28	 3.29	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81041	 1	 5.66	 2.75	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81042	 1	 22.75	 9.22	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81043	 1	 24.98	 9.33	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81044	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81045	 1	 9.93	 5.27	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81046	 1	 19.88	 8.5	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81047	 1	 24.51	 7.5	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81048	 1	 15.23	 5.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81049	 1	 5.89	 2.58	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81050	 1	 7.45	 3.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81051	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81052	 1	 9.75	 3.31	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81053	 1	 7.47	 2.83	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81054	 1	 11.47	 2.6	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81055	 1	 15.89	 3.57	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81056	 1	 7.16	 1.61	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81057	 1	 6.32	 1.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81058	 1	 4.55	 2.3	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81059	 1	 14.38	 6.13	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81060	 1	 11.21	 5.81	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81061	 1	 18.38	 7.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81062	 1	 4.54	 2.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81063	 1	 15.81	 6.15	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81064	 1	 31.02	 10.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81065	 1	 9.23	 4.04	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81066	 1	 3.63	 1.58	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81067	 1	 4.22	 1.91	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81068	 1	 28.26	 12.71	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81069	 1	 8.65	 3.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81070	 1	 12.4	 2.98	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81071	 1	 76.55	 26.95	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81072	 1	 8.02	 3.17	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81073	 1	 12.39	 4.67	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81074	 1	 14.23	 7.28	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81075	 1	 13.79	 6.26	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81076	 1	 48.03	 19.59	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81077	 1	 6.04	 3.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81078	 1	 5.69	 3.07	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81079	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81080	 1	 25.36	 10.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81081	 1	 13.12	 5.62	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81082	 1	 21.69	 7.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81083	 1	 20.83	 8.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81084	 1	 22.58	 8.99	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81085	 1	 6.97	 2.88	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81086	 1	 3.18	 1.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81087	 1	 5.68	 2.27	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81088	 1	 9.66	 5.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81089	 1	 26.86	 10.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81090	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81091	 1	 10.48	 6.04	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81092	 1	 37.92	 15.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81093	 1	 24.89	 10.11	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81094	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81095	 1	 15.33	 5.34	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81096	 1	 7.62	 3.14	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81097	 1	 20.86	 7.64	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81098	 1	 30.95	 10.07	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81099	 1	 14.15	 5.76	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81100	 1	 7.85	 3.91	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81101	 1	 10.97	 4.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81102	 1	 9.96	 3.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81103	 1	 12.17	 5.7	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81104	 1	 2.82	 1.15	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81105	 1	 6.02	 2.58	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81106	 1	 17.23	 7.28	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81107	 1	 11.95	 4.5	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81108	 1	 14.99	 6.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81109	 1	 23.72	 10.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81110	 1	 11.56	 4.44	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81111	 1	 4.12	 2.36	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81112	 1	 15.19	 5.71	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81113	 1	 17.93	 5.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81114	 1	 9.16	 4.15	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81115	 1	 7.68	 3.25	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81116	 1	 9.34	 4.68	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81117	 1	 3.79	 2.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81118	 1	 22.42	 8.09	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81119	 1	 13.44	 5.36	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81120	 1	 9.93	 4.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81121	 1	 1.99	 1.07	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81122	 1	 6.12	 2.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81123	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81124	 1	 25.27	 8.98	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81125	 1	 6.02	 2.34	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81126	 1	 8.56	 3.46	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81127	 1	 4.11	 1.97	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81128	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81129	 1	 5.51	 2.44	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81130	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81131	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81132	 1	 42.23	 12.96	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81133	 1	 11.31	 4.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81134	 1	 10.42	 3.61	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81135	 1	 7.9	 3.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81136	 1	 15.52	 6.52	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81137	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81138	 1	 19.3	 8.65	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81139	 1	 9.88	 3.8	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81140	 1	 9.26	 4.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81141	 1	 28.37	 10.6	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81142	 1	 14.08	 5.19	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81143	 1	 4.67	 2.23	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81144	 1	 17.09	 5.63	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81145	 1	 9.62	 3.5	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81146	 1	 11.51	 5.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81147	 1	 8.56	 4.1	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81148	 1	 9.3	 2.09	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81149	 1	 23.62	 10.3	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81150	 1	 6.93	 3.31	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81151	 1	 19.33	 8.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81152	 1	 11.28	 5.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81153	 1	 4.59	 2.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81154	 1	 5.62	 2.47	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81155	 1	 28.38	 10.13	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81156	 1	 10.91	 5.22	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81157	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81158	 1	 24.18	 8.21	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81159	 1	 2.78	 1.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81160	 1	 6.45	 2.46	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81161	 1	 8.48	 3.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81162	 1	 17.93	 7.17	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81163	 1	 7.57	 3.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81164	 1	 18.19	 7.06	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81165	 1	 9.3	 4.66	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81166	 1	 5.52	 2.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81167	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81168	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81169	 1	 25.96	 10.13	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81170	 1	 15.88	 6.18	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81171	 1	 11.05	 4.8	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81172	 1	 67.28	 25.32	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81173	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81174	 1	 11.19	 4.35	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81175	 1	 7.07	 2.89	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81176	 1	 7.1	 3.05	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81177	 1	 5.63	 3.02	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81178	 1	 5.79	 2.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81179	 1	 5.77	 2.73	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81180	 1	 4.8	 2.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81181	 1	 17.18	 7.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81182	 1	 14.92	 6.43	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81183	 1	 6.25	 2.78	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81184	 1	 14.5	 5.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81185	 1	 5.72	 2.54	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81186	 1	 5.78	 1.91	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81187	 1	 7.21	 3.36	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81188	 1	 4.95	 2.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81189	 1	 9.84	 4.02	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81190	 1	 16.16	 6.47	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81191	 1	 15.62	 3.54	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81192	 1	 9.35	 4.83	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81193	 1	 17.53	 6.7	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81194	 1	 16.93	 7.45	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81195	 1	 4.71	 2.4	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81196	 1	 12.27	 5.37	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81197	 1	 11.42	 3.94	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81198	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81199	 1	 45.39	 11.43	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81200	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81201	 1	 9.15	 4.39	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81202	 1	 15.84	 7.3	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81203	 1	 12.97	 6.34	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81204	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81205	 1	 46.76	 17.88	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81206	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81207	 1	 46.64	 11.66	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81208	 1	 23.49	 7.6	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81209	 1	 7.29	 4.08	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81210	 1	 19.1	 7.3	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81211	 1	 13.9	 6.63	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81212	 1	 6.96	 3.79	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81213	 1	 34.77	 9.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81214	 1	 21.78	 10.6	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81215	 1	 16.61	 5.3	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81216	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81217	 1	 10.18	 5.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81218	 1	 23.05	 9.25	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81219	 1	 21.78	 8.07	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81220	 1	 20.4	 5.92	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81221	 1	 11.25	 4.81	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81222	 1	 16.5	 5.18	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81223	 1	 25.67	 9.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81224	 1	 29.44	 11.66	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81225	 1	 25.15	 9.91	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81226	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81227	 1	 48.2	 17.5	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81228	 1	 7.65	 4.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81229	 1	 22.88	 10.22	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81230	 1	 15.71	 8.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81231	 1	 6.29	 2.91	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81232	 1	 12.2	 5.99	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81233	 1	 2.44	 1.21	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81234	 1	 22.92	 11.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81235	 1	 8.19	 4.71	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81236	 1	 6.42	 3.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81237	 1	 17.61	 6.99	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81238	 1	 3.67	 1.45	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81239	 1	 15.9	 5.53	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81240	 1	 7.34	 4.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81241	 1	 9.44	 3.31	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81242	 1	 9.98	 5.04	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81243	 1	 7.33	 3.65	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81244	 1	 34.71	 8.87	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81245	 1	 28.55	 10.11	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81246	 1	 5.59	 2.78	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81247	 1	 14.21	 5.23	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81248	 1	 14.86	 5.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81249	 1	 6.5	 3.46	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81250	 1	 13.52	 7.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81251	 1	 14.99	 6.43	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81252	 1	 9.12	 4.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81253	 1	 12.43	 4.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81254	 1	 8.76	 3.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81255	 1	 11.16	 5.64	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81256	 1	 12.97	 6.62	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81257	 1	 6.1	 2.73	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81258	 1	 13.91	 6.96	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81259	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81260	 1	 34.86	 11.81	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81261	 1	 20.31	 7.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81262	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81263	 1	 11.97	 3.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81264	 1	 13.43	 5.7	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81265	 1	 10.62	 4.79	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81266	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81267	 1	 39.56	 10.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81268	 1	 32.5	 7.32	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81269	 1	 13.23	 4.53	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81270	 1	 6.52	 2.67	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81271	 1	 16.93	 8.13	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81272	 1	 10.94	 4.63	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81273	 1	 10.8	 5.05	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81274	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81275	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81276	 1	 24.75	 9.57	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81277	 1	 16.36	 6.76	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81278	 1	 10.67	 4.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81279	 1	 17.73	 7.65	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81280	 1	 5.43	 3.09	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81281	 1	 6.42	 2.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81282	 1	 25.14	 10.29	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81283	 1	 18.19	 6.19	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81284	 1	 16.66	 3.7	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81285	 1	 6.45	 3.44	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81286	 1	 3.39	 1.89	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81287	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81288	 1	 23.91	 10.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81289	 1	 14.83	 5.41	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81290	 1	 14.54	 6.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81291	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81292	 1	 28.32	 12.8	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81293	 1	 13.0	 5.73	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81294	 1	 7.88	 4.07	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81295	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81296	 1	 24.68	 10.06	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81297	 1	 5.88	 3.06	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81298	 1	 7.44	 2.69	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81299	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81300	 1	 5.02	 2.46	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81301	 1	 2.09	 1.16	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81302	 1	 11.06	 5.93	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81303	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81304	 1	 39.83	 11.87	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81305	 1	 4.81	 2.58	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81306	 1	 16.88	 5.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81307	 1	 28.3	 10.7	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81308	 1	 11.71	 5.32	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81309	 1	 6.07	 3.1	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81310	 1	 5.97	 3.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81311	 1	 19.11	 6.77	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81312	 1	 24.8	 5.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81313	 1	 19.13	 9.35	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81314	 1	 19.14	 6.43	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81315	 1	 8.09	 3.2	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81316	 1	 27.47	 12.73	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81317	 1	 22.61	 9.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81318	 1	 4.97	 2.31	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81319	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81320	 1	 49.2	 15.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81321	 1	 4.16	 2.27	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81322	 1	 8.67	 4.87	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81323	 1	 14.29	 6.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81324	 1	 11.25	 5.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81325	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81326	 1	 38.5	 10.32	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81327	 1	 26.54	 9.76	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81328	 1	 15.74	 5.23	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81329	 1	 16.58	 6.06	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81330	 1	 19.34	 8.13	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81331	 1	 11.15	 5.25	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81332	 1	 21.99	 8.26	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81333	 1	 20.42	 7.11	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81334	 1	 32.98	 9.99	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81335	 1	 35.55	 11.63	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81336	 1	 26.1	 9.93	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81337	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81338	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81339	 1	 40.11	 16.17	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81340	 1	 20.96	 7.27	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81341	 1	 14.72	 3.3	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81342	 1	 5.99	 2.81	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81343	 1	 18.81	 5.6	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81344	 1	 10.34	 3.94	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81345	 1	 8.82	 3.05	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81346	 1	 7.78	 3.99	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81347	 1	 24.58	 9.54	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81348	 1	 8.1	 3.77	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81349	 1	 23.17	 10.17	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81350	 1	 7.87	 3.46	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81351	 1	 27.39	 12.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81352	 1	 18.43	 7.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81353	 1	 2.18	 1.18	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81354	 1	 17.62	 7.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81355	 1	 13.69	 4.45	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81356	 1	 8.2	 3.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81357	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81358	 1	 41.07	 15.2	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81359	 1	 9.61	 4.49	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81360	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81361	 1	 17.47	 8.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81362	 1	 14.13	 6.2	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81363	 1	 12.87	 5.89	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81364	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81365	 1	 20.51	 8.31	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81366	 1	 11.33	 4.97	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81367	 1	 16.5	 6.12	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81368	 1	 11.61	 6.15	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81369	 1	 8.14	 4.35	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81370	 1	 8.39	 4.02	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81371	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81372	 1	 11.32	 5.11	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81373	 1	 8.47	 3.81	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81374	 1	 5.13	 2.43	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81375	 1	 14.94	 6.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81376	 1	 21.91	 9.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81377	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81378	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81379	 1	 48.65	 17.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81380	 1	 29.35	 8.5	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81381	 1	 3.72	 1.66	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81382	 1	 6.24	 3.42	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81383	 1	 6.22	 3.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81384	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81385	 1	 22.08	 10.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81386	 1	 23.9	 8.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81387	 1	 19.39	 6.95	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81388	 1	 35.19	 12.18	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81389	 1	 23.83	 5.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81390	 1	 32.08	 7.22	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81391	 1	 18.25	 4.08	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81392	 1	 11.86	 4.67	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81393	 1	 16.62	 4.6	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81394	 1	 19.73	 5.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81395	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81396	 1	 10.14	 3.67	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81397	 1	 19.43	 7.91	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81398	 1	 10.16	 5.4	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81399	 1	 13.08	 3.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81400	 1	 28.75	 11.44	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81401	 1	 11.11	 4.1	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81402	 1	 31.09	 13.3	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81403	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81404	 1	 18.22	 7.08	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81405	 1	 34.89	 12.95	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81406	 1	 9.81	 4.49	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81407	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81408	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81409	 1	 35.34	 11.85	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81410	 1	 23.74	 6.93	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81411	 1	 19.48	 4.45	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81412	 1	 18.61	 4.25	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81413	 1	 31.11	 10.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81414	 1	 24.25	 5.53	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81415	 1	 14.53	 7.06	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81416	 1	 9.58	 3.87	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81417	 1	 18.42	 4.78	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81418	 1	 5.14	 3.09	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81419	 1	 4.1	 2.11	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81420	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81421	 1	 8.46	 4.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81422	 1	 36.06	 13.56	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81423	 1	 17.05	 7.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81424	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81425	 1	 13.12	 5.35	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81426	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81427	 1	 20.92	 7.36	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81428	 1	 6.32	 3.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81429	 1	 4.6	 2.8	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81430	 1	 8.44	 4.93	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81431	 1	 9.04	 4.26	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81432	 1	 3.94	 1.89	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81433	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81434	 1	 12.43	 6.04	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81435	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81436	 1	 15.3	 6.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81437	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81438	 1	 4.82	 2.6	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81439	 1	 12.49	 6.19	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81440	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81441	 1	 28.58	 12.46	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81442	 1	 12.06	 5.11	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81443	 1	 11.91	 4.47	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81444	 1	 14.03	 4.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81445	 1	 45.3	 10.09	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81446	 1	 4.16	 0.93	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81447	 1	 25.97	 7.08	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81448	 1	 17.97	 7.71	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81449	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81450	 1	 33.07	 11.19	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81451	 1	 18.65	 6.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81452	 1	 4.07	 2.32	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81453	 1	 13.91	 4.84	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81454	 1	 5.97	 2.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81455	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81456	 1	 12.88	 5.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81457	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81458	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81459	 1	 25.08	 9.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81460	 1	 27.92	 11.15	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81461	 1	 12.36	 4.53	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81462	 1	 40.83	 12.57	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81463	 1	 46.57	 18.69	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81464	 1	 20.68	 6.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81465	 1	 11.46	 5.61	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81466	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81467	 1	 17.38	 6.67	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81468	 1	 14.85	 5.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81469	 1	 14.38	 6.36	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81470	 1	 17.76	 7.88	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81471	 1	 10.12	 5.15	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81472	 1	 14.11	 5.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81473	 1	 9.55	 3.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81474	 1	 13.17	 5.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81475	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81476	 1	 11.59	 5.17	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81477	 1	 17.16	 4.56	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81478	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81479	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81480	 1	 36.12	 15.28	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81481	 1	 11.07	 4.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81482	 1	 14.53	 6.46	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81483	 1	 13.51	 5.28	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81484	 1	 3.81	 1.82	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81485	 1	 14.52	 7.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81486	 1	 10.13	 4.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81487	 1	 22.23	 9.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81488	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81489	 1	 57.8	 16.81	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81490	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81491	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81492	 1	 33.18	 12.13	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81493	 1	 10.11	 5.44	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81494	 1	 7.08	 3.5	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81495	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81496	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81497	 1	 29.13	 9.97	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81498	 1	 6.29	 2.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81499	 1	 7.57	 3.36	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81500	 1	 9.43	 3.2	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81501	 1	 36.05	 14.27	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81502	 1	 22.26	 9.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81503	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81504	 1	 39.84	 12.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81505	 1	 9.32	 3.63	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81506	 1	 25.24	 12.4	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81507	 1	 23.54	 9.46	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81508	 1	 14.15	 5.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81509	 1	 13.65	 5.94	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81510	 1	 21.36	 8.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81511	 1	 37.38	 15.31	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81512	 1	 19.73	 7.3	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81513	 1	 12.41	 5.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81514	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81515	 1	 21.91	 8.87	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81516	 1	 8.58	 3.53	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81517	 1	 20.77	 8.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81518	 1	 10.81	 5.15	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81519	 1	 19.27	 7.13	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81520	 1	 6.32	 3.09	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81521	 1	 15.15	 5.09	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81522	 1	 17.64	 6.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81523	 1	 17.12	 5.75	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81524	 1	 20.13	 5.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81525	 1	 17.81	 7.54	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81526	 1	 28.93	 11.56	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81527	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81528	 1	 34.43	 12.22	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81529	 1	 15.49	 6.67	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81530	 1	 16.1	 5.77	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81531	 1	 24.52	 8.86	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81532	 1	 6.98	 3.06	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81533	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81534	 1	 21.04	 7.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81535	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81536	 1	 44.1	 13.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81537	 1	 6.44	 3.29	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81538	 1	 13.66	 4.31	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81539	 1	 12.0	 6.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81540	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81541	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81542	 1	 49.73	 12.18	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81543	 1	 14.34	 4.97	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81544	 1	 5.9	 2.62	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81545	 1	 6.57	 2.62	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81546	 1	 4.3	 1.74	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81547	 1	 9.95	 5.1	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81548	 1	 17.7	 6.83	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81549	 1	 11.46	 5.36	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81550	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81551	 1	 25.76	 10.85	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81552	 1	 27.35	 8.42	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81553	 1	 13.26	 5.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81554	 1	 11.99	 4.32	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81555	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81556	 1	 24.97	 9.08	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81557	 1	 10.36	 4.32	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81558	 1	 11.29	 4.53	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81559	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81560	 1	 52.03	 16.66	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81561	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81562	 1	 23.82	 9.31	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81563	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81564	 1	 29.93	 12.32	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81565	 1	 14.47	 6.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81566	 1	 31.83	 12.62	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81567	 1	 13.54	 5.69	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81568	 1	 32.16	 8.35	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81569	 1	 25.02	 10.52	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81570	 1	 24.43	 8.27	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81571	 1	 33.17	 10.63	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81572	 1	 15.13	 8.27	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81573	 1	 20.43	 7.92	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81574	 1	 7.51	 4.01	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81575	 1	 9.88	 3.85	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81576	 1	 9.51	 4.94	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81577	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81578	 1	 4.47	 2.03	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81579	 1	 20.22	 8.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81580	 1	 11.16	 4.79	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81581	 1	 11.17	 3.26	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81582	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81583	 1	 27.89	 7.49	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81584	 1	 6.22	 2.85	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81585	 1	 6.7	 3.36	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81586	 1	 5.54	 3.02	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81587	 1	 9.92	 4.17	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81588	 1	 4.24	 1.64	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81589	 1	 3.92	 1.95	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81590	 1	 6.92	 3.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81591	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81592	 1	 22.77	 7.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81593	 1	 9.53	 4.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81594	 1	 8.35	 3.77	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81595	 1	 8.99	 3.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81596	 1	 25.75	 10.35	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81597	 1	 27.09	 10.68	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81598	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81599	 1	 42.87	 15.27	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81600	 1	 28.21	 11.04	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81601	 1	 13.67	 5.52	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81602	 1	 10.54	 4.55	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81603	 1	 7.72	 3.61	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81604	 1	 14.34	 6.02	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81605	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81606	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81607	 1	 40.7	 11.1	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81608	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81609	 1	 35.67	 13.4	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81610	 1	 9.03	 3.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81611	 1	 21.83	 6.87	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81612	 1	 9.89	 5.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81613	 1	 12.31	 4.11	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81614	 1	 16.42	 8.6	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81615	 1	 13.44	 5.04	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81616	 1	 11.99	 4.78	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81617	 1	 7.0	 3.61	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81618	 1	 9.42	 4.26	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81619	 1	 31.31	 11.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81620	 1	 7.51	 2.72	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81621	 1	 7.46	 3.04	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81622	 1	 6.84	 3.21	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81623	 1	 7.41	 3.18	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81624	 1	 7.25	 3.35	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81625	 1	 35.93	 11.67	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81626	 1	 63.81	 24.21	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81627	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81628	 1	 69.54	 17.5	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81629	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81630	 1	 9.45	 4.41	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81631	 1	 6.24	 2.87	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81632	 1	 4.65	 2.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81633	 1	 7.5	 2.86	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81634	 1	 7.63	 3.84	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81635	 1	 7.64	 2.68	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81636	 1	 4.49	 2.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81637	 1	 8.63	 3.68	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81638	 1	 12.39	 5.28	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81639	 1	 17.12	 6.38	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81640	 1	 9.46	 4.14	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81641	 1	 9.02	 4.28	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81642	 1	 5.89	 2.64	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81643	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81644	 1	 38.01	 11.76	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81645	 1	 43.26	 13.18	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81646	 1	 9.86	 4.15	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81647	 1	 24.68	 8.79	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81648	 1	 5.85	 1.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81649	 1	 36.4	 8.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81650	 1	 18.89	 4.27	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81651	 1	 19.92	 4.54	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81652	 1	 26.21	 5.93	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81653	 1	 15.34	 3.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81654	 1	 19.57	 4.43	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81655	 1	 19.33	 4.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81656	 1	 4.47	 1.02	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81657	 1	 20.19	 4.56	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81658	 1	 25.55	 5.81	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81659	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81660	 1	 85.24	 24.08	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81661	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81662	 1	 20.15	 4.58	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81663	 1	 15.08	 5.88	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81664	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81665	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81666	 1	 37.76	 13.59	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81667	 1	 11.45	 4.26	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81668	 1	 10.69	 3.81	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81669	 1	 17.97	 5.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81670	 1	 19.92	 6.48	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81671	 1	 7.07	 3.58	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81672	 1	 3.79	 1.88	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81673	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81674	 1	 36.79	 9.99	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81675	 1	 8.3	 4.33	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81676	 1	 10.65	 5.43	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81677	 1	 19.05	 6.64	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81678	 1	 10.07	 4.53	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81679	 1	 6.45	 1.49	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81680	 1	 9.18	 2.12	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81681	 1	 13.83	 5.39	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81682	 1	 4.42	 1.02	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81683	 1	 19.65	 4.51	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81684	 1	 18.17	 4.21	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81685	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81686	 1	 37.35	 12.82	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81687	 1	 12.39	 2.85	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81688	 1	 12.52	 5.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81689	 1	 12.18	 5.65	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81690	 1	 6.39	 3.27	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81691	 1	 9.86	 2.29	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81692	 1	 13.51	 6.47	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81693	 1	 7.53	 4.07	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81694	 1	 7.87	 4.16	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81695	 1	 5.31	 2.92	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81696	 1	 38.49	 13.24	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81697	 1	 8.35	 4.32	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81698	 1	 13.18	 5.9	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81699	 1	 14.59	 6.77	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81700	 1	 20.2	 8.19	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81701	 1	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81702	 1	 20.05	 7.67	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81703	 1	 16.55	 6.65	 0.0	 0.0	 36	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81704	 1	 34.4	 9.47	 0.0	 0.0	 36	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81705	 1	 9.51	 3.26	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81706	 1	 41.82	 13.49	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81707	 1	 16.74	 4.71	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81708	 1	 74.1	 15.1	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81709	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81710	 1	 44.14	 14.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81711	 1	 20.27	 6.83	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81712	 1	 6.02	 2.1	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81713	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81714	 1	 7.81	 2.4	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81715	 1	 15.8	 4.6	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81716	 1	 20.28	 5.22	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81717	 1	 125.26	 27.8	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81718	 1	 138.08	 41.77	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81719	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81720	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81721	 1	 20.24	 6.89	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81722	 1	 16.05	 5.95	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81723	 1	 20.39	 5.14	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81724	 1	 8.33	 2.75	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81725	 1	 19.39	 5.09	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81726	 1	 19.75	 7.41	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81727	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81728	 1	 20.95	 7.82	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81729	 1	 13.42	 4.92	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81730	 1	 13.5	 3.69	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81731	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81732	 1	 9.56	 3.53	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81733	 1	 17.55	 5.16	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81734	 1	 15.14	 3.99	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81735	 1	 9.37	 3.17	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81736	 1	 12.72	 4.56	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81737	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81738	 1	 19.16	 4.03	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81739	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81740	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81741	 1	 52.04	 12.91	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81742	 1	 21.64	 7.98	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81743	 1	 6.35	 1.89	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81744	 1	 14.61	 4.97	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81745	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81746	 1	 5.75	 2.03	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81747	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81748	 1	 15.89	 5.09	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81749	 1	 2.31	 0.77	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81750	 1	 4.98	 1.55	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81751	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81752	 1	 39.34	 8.3	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81753	 1	 17.16	 6.18	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81754	 1	 9.91	 2.73	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81755	 1	 5.16	 1.39	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81756	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81757	 1	 9.63	 3.38	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81758	 1	 19.61	 5.76	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81759	 1	 27.16	 6.58	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81760	 1	 12.3	 3.78	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81761	 1	 27.88	 9.44	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81762	 1	 14.51	 4.76	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81763	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81764	 1	 383.66	 60.78	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81765	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81766	 1	 49.42	 18.15	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81767	 1	 14.06	 5.45	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81768	 1	 19.96	 6.28	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81769	 1	 23.58	 9.03	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81770	 1	 19.56	 6.53	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81771	 1	 177.48	 45.05	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81772	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81773	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81774	 1	 33.42	 10.41	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81775	 1	 171.89	 35.96	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81776	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81777	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81778	 1	 18.21	 6.11	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81779	 1	 29.63	 11.59	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81780	 1	 17.4	 6.08	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81781	 1	 11.58	 3.29	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81782	 1	 14.0	 4.16	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81783	 1	 11.16	 2.86	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81784	 1	 9.94	 3.28	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81785	 1	 3.18	 0.72	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81786	 1	 3.58	 0.81	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81787	 1	 9.39	 2.14	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81788	 1	 20.72	 6.41	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81789	 1	 18.96	 5.86	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81790	 1	 9.02	 2.97	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81791	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81792	 1	 6.08	 1.88	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81793	 1	 12.98	 4.41	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81794	 1	 135.81	 31.15	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81795	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81796	 1	 25.7	 9.2	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81797	 1	 49.37	 9.36	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81798	 1	 21.31	 5.17	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81799	 1	 10.62	 3.14	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81800	 1	 14.01	 3.17	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81801	 1	 11.78	 3.11	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81802	 1	 10.45	 2.38	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81803	 1	 123.55	 42.93	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81804	 1	 14.92	 5.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81805	 1	 8.98	 2.28	 0.0	 0.0	 37	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	81806	 1	 15.16	 5.09	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81807	 1	 23.29	 8.16	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81808	 1	 9.89	 3.13	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81809	 1	 10.52	 3.72	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81810	 1	 10.83	 3.24	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81811	 1	 8.25	 2.75	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81812	 1	 16.09	 4.12	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81813	 1	 5.63	 1.75	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81814	 1	 10.92	 3.77	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81815	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81816	 1	 16.4	 5.77	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81817	 1	 4.33	 1.51	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81818	 1	 5.27	 1.29	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81819	 1	 14.52	 4.4	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81820	 1	 28.24	 9.37	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81821	 1	 19.97	 6.86	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81822	 1	 4.16	 1.36	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81823	 1	 99.85	 22.05	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81824	 1	 18.21	 6.04	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81825	 1	 17.28	 6.15	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81826	 1	 12.63	 4.64	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81827	 1	 10.42	 3.78	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81828	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81829	 1	 18.2	 6.5	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81830	 1	 14.7	 5.19	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81831	 1	 14.98	 4.6	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81832	 1	 18.27	 5.91	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81833	 1	 13.0	 3.36	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81834	 1	 11.7	 3.51	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81835	 1	 11.58	 3.76	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81836	 1	 15.17	 5.38	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81837	 1	 19.55	 6.82	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81838	 1	 17.39	 5.24	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81839	 1	 14.8	 4.37	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81840	 1	 8.32	 3.31	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81841	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81842	 1	 15.07	 3.86	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81843	 1	 12.05	 4.09	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81844	 1	 44.66	 17.51	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81845	 1	 36.54	 10.74	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81846	 1	 15.23	 5.4	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81847	 1	 7.68	 2.55	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81848	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81849	 1	 8.07	 2.49	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81850	 1	 76.38	 20.73	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81851	 1	 11.19	 3.42	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81852	 1	 11.39	 3.26	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81853	 1	 16.56	 3.69	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81854	 1	 13.1	 3.95	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81855	 1	 8.36	 2.3	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81856	 1	 9.02	 2.78	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81857	 1	 154.08	 43.17	 0.0	 0.0	 37	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81858	 1	 18.93	 5.42	 0.0	 0.0	 37	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81859	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81860	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81861	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81862	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81863	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81864	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81865	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81866	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81867	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81868	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81869	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81870	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81871	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81872	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81873	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81874	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81875	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81876	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81877	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81878	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81879	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81880	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81881	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81882	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81883	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81884	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81885	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81886	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81887	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81888	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81889	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81890	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81891	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81892	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81893	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81894	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81895	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81896	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81897	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81898	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81899	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81900	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81901	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81902	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81903	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81904	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81905	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81906	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81907	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81908	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81909	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81910	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81911	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81912	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81913	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81914	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81915	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81916	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81917	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81918	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81919	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81920	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81921	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81922	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81923	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81924	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81925	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81926	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81927	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81928	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81929	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81930	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81931	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81932	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81933	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81934	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81935	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81936	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81937	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81938	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81939	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81940	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81941	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81942	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81943	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81944	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81945	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81946	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81947	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81948	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81949	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81950	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81951	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81952	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81953	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81954	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81955	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81956	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81957	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81958	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81959	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81960	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81961	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81962	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81963	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81964	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81965	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81966	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81967	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81968	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81969	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81970	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81971	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81972	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81973	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81974	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81975	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81976	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81977	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81978	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81979	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81980	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81981	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81982	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81983	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81984	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81985	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81986	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81987	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81988	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81989	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81990	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81991	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81992	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81993	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81994	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81995	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81996	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81997	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81998	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81999	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82000	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82001	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82002	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82003	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82004	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82005	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82006	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82007	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82008	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82009	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82010	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82011	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82012	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82013	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82014	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82015	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82016	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82017	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82018	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82019	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82020	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82021	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82022	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82023	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82024	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82025	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82026	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82027	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82028	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82029	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82030	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82031	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82032	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82033	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82034	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82035	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82036	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82037	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82038	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82039	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82040	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82041	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82042	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82043	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82044	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82045	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82046	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82047	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82048	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82049	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82050	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82051	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82052	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82053	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82054	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82055	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82056	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82057	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82058	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82059	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82060	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82061	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82062	 1	 19.91	 4.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82063	 1	 41.55	 9.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82064	 1	 4.9	 1.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82065	 1	 4.99	 1.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82066	 1	 111.86	 23.91	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82067	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82068	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82069	 1	 15.6	 3.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82070	 1	 38.87	 8.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82071	 1	 52.61	 11.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82072	 1	 7.37	 1.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82073	 1	 4.46	 0.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82074	 1	 21.52	 4.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82075	 1	 16.0	 3.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82076	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82077	 1	 41.82	 9.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82078	 1	 9.77	 2.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82079	 1	 50.62	 10.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82080	 1	 9.44	 2.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82081	 1	 8.28	 1.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82082	 1	 51.55	 11.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82083	 1	 11.98	 2.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82084	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82085	 1	 35.46	 7.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82086	 1	 15.38	 3.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82087	 1	 10.45	 2.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82088	 1	 8.5	 1.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82089	 1	 6.58	 1.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82090	 1	 10.41	 2.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82091	 1	 53.86	 12.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82092	 1	 12.51	 2.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82093	 1	 62.23	 18.49	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82094	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82095	 1	 14.79	 3.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82096	 1	 22.18	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82097	 1	 42.29	 9.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82098	 1	 37.59	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82099	 1	 54.01	 11.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82100	 1	 5.4	 1.79	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82101	 1	 62.63	 13.62	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82102	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82103	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82104	 1	 40.77	 11.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82105	 1	 10.63	 3.7	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82106	 1	 4.41	 2.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82107	 1	 15.17	 4.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82108	 1	 12.38	 5.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82109	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82110	 1	 32.9	 11.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82111	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82112	 1	 15.3	 4.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82113	 1	 23.01	 7.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82114	 1	 113.33	 24.38	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82115	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82116	 1	 28.11	 11.26	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82117	 1	 8.65	 1.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82118	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82119	 1	 47.42	 13.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82120	 1	 17.62	 8.32	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82121	 1	 15.13	 6.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82122	 1	 3.64	 1.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82123	 1	 5.46	 2.37	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82124	 1	 14.1	 4.4	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82125	 1	 25.18	 5.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82126	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82127	 1	 12.22	 3.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82128	 1	 9.22	 3.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82129	 1	 22.51	 6.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82130	 1	 4.36	 1.92	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82131	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82132	 1	 143.14	 25.31	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82133	 1	 16.97	 6.18	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82134	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82135	 1	 44.19	 11.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82136	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82137	 1	 20.87	 6.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82138	 1	 27.02	 7.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82139	 1	 14.4	 6.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82140	 1	 112.74	 33.73	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82141	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82142	 1	 28.78	 8.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82143	 1	 13.72	 3.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82144	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82145	 1	 14.12	 4.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82146	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82147	 1	 18.01	 4.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82148	 1	 7.24	 2.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82149	 1	 7.28	 2.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82150	 1	 5.36	 2.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82151	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82152	 1	 12.63	 4.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82153	 1	 24.11	 8.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82154	 1	 52.91	 16.18	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82155	 1	 15.09	 5.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82156	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82157	 1	 36.26	 11.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82158	 1	 24.03	 6.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82159	 1	 43.54	 14.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82160	 1	 25.94	 7.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82161	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82162	 1	 15.85	 4.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82163	 1	 29.63	 6.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82164	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82165	 1	 73.96	 16.02	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82166	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82167	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82168	 1	 36.86	 8.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82169	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82170	 1	 5.07	 1.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82171	 1	 15.32	 5.3	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82172	 1	 9.04	 3.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82173	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82174	 1	 25.64	 7.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82175	 1	 10.5	 3.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82176	 1	 10.54	 3.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82177	 1	 17.61	 5.43	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82178	 1	 22.55	 4.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82179	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82180	 1	 49.22	 13.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82181	 1	 12.37	 4.79	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82182	 1	 8.55	 3.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82183	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82184	 1	 16.91	 4.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82185	 1	 33.18	 11.33	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82186	 1	 9.75	 3.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82187	 1	 8.26	 3.31	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82188	 1	 9.77	 3.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82189	 1	 106.59	 29.79	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82190	 1	 32.26	 11.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82191	 1	 32.97	 9.65	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82192	 1	 62.61	 20.32	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82193	 1	 8.68	 1.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82194	 1	 149.7	 31.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82195	 1	 31.94	 6.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82196	 1	 21.73	 4.79	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82197	 1	 78.97	 20.21	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82198	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82199	 1	 171.53	 38.9	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82200	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82201	 1	 31.5	 6.89	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82202	 1	 113.19	 20.18	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82203	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82204	 1	 26.28	 5.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82205	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82206	 1	 97.01	 26.67	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82207	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82208	 1	 29.19	 6.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82209	 1	 80.24	 15.65	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82210	 1	 47.59	 10.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82211	 1	 8.76	 3.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82212	 1	 17.56	 5.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82213	 1	 39.66	 14.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82214	 1	 14.31	 5.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82215	 1	 4.76	 2.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82216	 1	 5.05	 2.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82217	 1	 17.73	 5.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82218	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82219	 1	 18.86	 6.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82220	 1	 7.2	 2.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82221	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82222	 1	 16.29	 4.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82223	 1	 8.7	 4.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82224	 1	 8.07	 3.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82225	 1	 6.94	 2.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82226	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82227	 1	 8.99	 4.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82228	 1	 2.54	 1.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82229	 1	 24.14	 7.8	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82230	 1	 24.34	 6.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82231	 1	 32.56	 8.63	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82232	 1	 6.37	 3.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82233	 1	 20.0	 7.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82234	 1	 30.46	 6.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82235	 1	 19.71	 5.64	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82236	 1	 35.88	 13.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82237	 1	 24.69	 5.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82238	 1	 21.97	 4.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82239	 1	 26.5	 5.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82240	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82241	 1	 32.68	 7.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82242	 1	 9.95	 3.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82243	 1	 4.83	 1.85	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82244	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82245	 1	 21.67	 4.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82246	 1	 7.41	 3.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82247	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82248	 1	 23.51	 7.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82249	 1	 21.29	 7.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82250	 1	 64.56	 21.16	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82251	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82252	 1	 25.0	 10.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82253	 1	 16.1	 6.05	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82254	 1	 6.81	 2.77	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82255	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82256	 1	 16.63	 4.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82257	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82258	 1	 25.39	 11.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82259	 1	 12.47	 6.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82260	 1	 10.74	 4.89	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82261	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82262	 1	 7.35	 3.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82263	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82264	 1	 14.15	 6.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82265	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82266	 1	 9.15	 3.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82267	 1	 17.63	 5.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82268	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82269	 1	 16.49	 4.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82270	 1	 22.39	 7.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82271	 1	 80.04	 16.82	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82272	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82273	 1	 14.95	 5.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82274	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82275	 1	 23.6	 8.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82276	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82277	 1	 36.48	 9.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82278	 1	 60.99	 24.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82279	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82280	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82281	 1	 10.59	 5.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82282	 1	 9.73	 4.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82283	 1	 22.41	 6.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82284	 1	 22.07	 8.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82285	 1	 45.38	 15.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82286	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82287	 1	 16.43	 5.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82288	 1	 6.95	 2.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82289	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82290	 1	 46.25	 10.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82291	 1	 20.66	 4.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82292	 1	 13.59	 3.99	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82293	 1	 16.97	 4.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82294	 1	 14.92	 3.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82295	 1	 57.56	 10.6	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82296	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82297	 1	 23.62	 6.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82298	 1	 51.03	 11.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82299	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82300	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82301	 1	 48.79	 10.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82302	 1	 12.21	 2.73	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82303	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82304	 1	 7.53	 2.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82305	 1	 6.63	 2.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82306	 1	 14.44	 5.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82307	 1	 19.86	 5.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82308	 1	 1.88	 0.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82309	 1	 17.93	 5.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82310	 1	 12.45	 5.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82311	 1	 11.19	 3.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82312	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82313	 1	 38.39	 7.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82314	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82315	 1	 21.5	 7.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82316	 1	 17.64	 5.37	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82317	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82318	 1	 10.55	 2.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82319	 1	 24.79	 5.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82320	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82321	 1	 45.07	 10.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82322	 1	 15.15	 4.83	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82323	 1	 13.49	 5.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82324	 1	 11.14	 3.97	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82325	 1	 57.8	 19.7	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82326	 1	 46.73	 11.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82327	 1	 7.2	 2.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82328	 1	 40.82	 11.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82329	 1	 86.73	 27.49	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82330	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82331	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82332	 1	 29.48	 9.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82333	 1	 24.65	 7.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82334	 1	 15.15	 4.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82335	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82336	 1	 25.72	 5.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82337	 1	 27.38	 5.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82338	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82339	 1	 24.64	 5.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82340	 1	 17.22	 3.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82341	 1	 4.0	 1.59	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82342	 1	 22.06	 4.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82343	 1	 37.26	 7.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82344	 1	 19.09	 4.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82345	 1	 47.79	 10.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82346	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82347	 1	 38.79	 9.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82348	 1	 215.37	 48.56	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82349	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82350	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82351	 1	 55.92	 17.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82352	 1	 7.42	 2.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82353	 1	 1.75	 0.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82354	 1	 25.95	 6.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82355	 1	 3.4	 1.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82356	 1	 2.93	 1.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82357	 1	 4.58	 1.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82358	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82359	 1	 33.73	 10.33	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82360	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82361	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82362	 1	 52.93	 13.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82363	 1	 548.41	 148.26	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82364	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82365	 1	 362.07	 84.88	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82366	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82367	 1	 40.98	 8.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82368	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82369	 1	 18.38	 5.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82370	 1	 6.39	 2.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82371	 1	 78.25	 18.01	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82372	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82373	 1	 11.6	 3.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82374	 1	 8.97	 3.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82375	 1	 11.24	 4.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82376	 1	 10.77	 4.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82377	 1	 19.88	 6.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82378	 1	 10.8	 3.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82379	 1	 116.99	 34.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82380	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82381	 1	 20.56	 8.33	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82382	 1	 11.32	 3.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82383	 1	 11.56	 5.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82384	 1	 19.2	 4.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82385	 1	 35.27	 7.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82386	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82387	 1	 18.04	 6.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82388	 1	 5.92	 1.78	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82389	 1	 1.34	 0.64	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82390	 1	 41.11	 9.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82391	 1	 83.61	 23.39	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82392	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82393	 1	 20.37	 6.4	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82394	 1	 12.93	 5.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82395	 1	 6.4	 2.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82396	 1	 27.72	 9.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82397	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82398	 1	 25.84	 8.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82399	 1	 23.75	 7.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82400	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82401	 1	 26.64	 8.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82402	 1	 8.57	 3.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82403	 1	 16.39	 4.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82404	 1	 17.52	 5.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82405	 1	 9.33	 3.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82406	 1	 7.6	 2.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82407	 1	 25.53	 5.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82408	 1	 25.33	 6.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82409	 1	 3.65	 1.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82410	 1	 2.41	 1.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82411	 1	 11.98	 4.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82412	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82413	 1	 192.19	 60.56	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82414	 1	 8.93	 3.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82415	 1	 67.2	 15.85	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82416	 1	 19.87	 6.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82417	 1	 46.91	 14.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82418	 1	 19.53	 7.19	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82419	 1	 6.07	 2.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82420	 1	 11.98	 4.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82421	 1	 4.66	 1.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82422	 1	 19.01	 6.39	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82423	 1	 5.92	 2.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82424	 1	 13.39	 5.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82425	 1	 7.35	 3.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82426	 1	 8.38	 3.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82427	 1	 12.5	 5.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82428	 1	 6.85	 3.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82429	 1	 11.44	 4.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82430	 1	 15.07	 6.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82431	 1	 4.65	 2.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82432	 1	 3.42	 1.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82433	 1	 5.57	 2.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82434	 1	 9.21	 3.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82435	 1	 3.84	 1.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82436	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82437	 1	 29.32	 7.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82438	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82439	 1	 30.92	 8.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82440	 1	 17.42	 6.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82441	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82442	 1	 27.38	 7.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82443	 1	 6.99	 2.55	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82444	 1	 6.68	 3.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82445	 1	 9.96	 3.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82446	 1	 12.86	 5.52	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82447	 1	 18.63	 6.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82448	 1	 14.2	 4.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82449	 1	 36.04	 13.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82450	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82451	 1	 3.73	 1.65	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82452	 1	 9.91	 4.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82453	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82454	 1	 176.03	 55.92	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82455	 1	 25.34	 6.7	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82456	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82457	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82458	 1	 166.48	 38.17	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82459	 1	 17.9	 4.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82460	 1	 2.7	 1.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82461	 1	 7.51	 3.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82462	 1	 4.48	 1.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82463	 1	 4.35	 1.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82464	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82465	 1	 3.33	 1.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82466	 1	 27.02	 6.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82467	 1	 47.17	 9.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82468	 1	 12.13	 3.8	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82469	 1	 13.32	 4.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82470	 1	 5.14	 1.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82471	 1	 4.0	 1.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82472	 1	 10.99	 3.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82473	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82474	 1	 5.52	 2.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82475	 1	 4.63	 1.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82476	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82477	 1	 30.98	 9.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82478	 1	 27.1	 6.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82479	 1	 4.83	 1.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82480	 1	 42.88	 12.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82481	 1	 5.14	 1.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82482	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82483	 1	 53.22	 13.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82484	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82485	 1	 34.26	 8.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82486	 1	 78.67	 22.33	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82487	 1	 89.89	 23.62	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82488	 1	 27.45	 7.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82489	 1	 66.35	 19.12	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82490	 1	 52.06	 16.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82491	 1	 11.23	 4.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82492	 1	 14.91	 4.88	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82493	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82494	 1	 29.24	 8.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82495	 1	 45.76	 13.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82496	 1	 23.43	 7.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82497	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82498	 1	 23.56	 6.91	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82499	 1	 20.66	 7.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82500	 1	 6.12	 2.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82501	 1	 10.23	 3.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82502	 1	 6.6	 2.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82503	 1	 11.64	 4.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82504	 1	 10.62	 4.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82505	 1	 58.54	 18.92	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82506	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82507	 1	 16.05	 6.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82508	 1	 18.67	 6.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82509	 1	 5.09	 2.34	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82510	 1	 71.36	 16.65	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82511	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82512	 1	 121.53	 28.36	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82513	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82514	 1	 40.64	 8.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82515	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82516	 1	 5.97	 2.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82517	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82518	 1	 21.16	 6.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82519	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82520	 1	 6.62	 1.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82521	 1	 8.46	 2.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82522	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82523	 1	 30.0	 8.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82524	 1	 15.54	 5.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82525	 1	 12.59	 3.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82526	 1	 3.6	 1.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82527	 1	 70.22	 23.24	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82528	 1	 12.22	 5.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82529	 1	 11.25	 4.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82530	 1	 26.25	 6.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82531	 1	 9.87	 3.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82532	 1	 10.48	 3.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82533	 1	 6.44	 2.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82534	 1	 7.43	 2.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82535	 1	 13.7	 4.21	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82536	 1	 11.49	 3.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82537	 1	 78.06	 24.28	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82538	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82539	 1	 23.66	 7.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82540	 1	 6.87	 2.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82541	 1	 3.8	 1.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82542	 1	 33.44	 9.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82543	 1	 8.72	 3.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82544	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82545	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82546	 1	 54.9	 12.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82547	 1	 20.1	 6.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82548	 1	 21.95	 6.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82549	 1	 12.09	 5.56	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82550	 1	 10.1	 3.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82551	 1	 18.23	 5.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82552	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82553	 1	 31.09	 9.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82554	 1	 59.86	 12.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82555	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82556	 1	 34.4	 7.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82557	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82558	 1	 7.78	 1.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82559	 1	 81.65	 17.82	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82560	 1	 17.41	 4.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82561	 1	 13.31	 5.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82562	 1	 16.78	 5.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82563	 1	 5.35	 2.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82564	 1	 4.87	 2.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82565	 1	 6.68	 3.06	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82566	 1	 5.99	 2.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82567	 1	 14.18	 5.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82568	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82569	 1	 45.52	 12.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82570	 1	 29.23	 8.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82571	 1	 22.4	 8.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82572	 1	 15.18	 3.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82573	 1	 11.89	 4.81	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82574	 1	 20.48	 6.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82575	 1	 50.41	 16.1	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82576	 1	 50.34	 11.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82577	 1	 6.77	 3.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82578	 1	 5.57	 2.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82579	 1	 27.67	 7.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82580	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82581	 1	 9.29	 3.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82582	 1	 32.62	 10.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82583	 1	 140.23	 27.25	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82584	 1	 26.98	 7.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82585	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82586	 1	 35.79	 7.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82587	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82588	 1	 8.41	 3.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82589	 1	 23.86	 7.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82590	 1	 49.4	 12.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82591	 1	 26.37	 6.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82592	 1	 29.58	 6.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82593	 1	 18.23	 4.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82594	 1	 34.67	 7.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82595	 1	 7.34	 1.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82596	 1	 20.33	 5.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82597	 1	 15.57	 3.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82598	 1	 23.06	 8.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82599	 1	 51.6	 11.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82600	 1	 17.47	 4.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82601	 1	 5.87	 2.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82602	 1	 28.73	 6.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82603	 1	 3.43	 0.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82604	 1	 4.51	 1.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82605	 1	 17.15	 3.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82606	 1	 14.9	 3.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82607	 1	 8.44	 2.56	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82608	 1	 4.33	 1.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82609	 1	 5.98	 2.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82610	 1	 81.44	 16.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82611	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82612	 1	 5.36	 1.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82613	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82614	 1	 11.78	 2.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82615	 1	 20.0	 4.96	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82616	 1	 45.4	 9.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82617	 1	 79.08	 17.88	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82618	 1	 14.23	 5.21	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82619	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82620	 1	 8.24	 1.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82621	 1	 14.33	 3.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82622	 1	 39.3	 8.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82623	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82624	 1	 19.0	 5.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82625	 1	 5.65	 2.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82626	 1	 13.74	 5.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82627	 1	 11.01	 2.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82628	 1	 9.16	 3.21	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82629	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82630	 1	 35.37	 9.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82631	 1	 11.16	 3.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82632	 1	 12.01	 3.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82633	 1	 37.98	 11.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82634	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82635	 1	 31.13	 7.52	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82636	 1	 55.53	 14.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82637	 1	 33.34	 10.4	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82638	 1	 13.83	 3.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82639	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82640	 1	 22.91	 7.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82641	 1	 25.4	 8.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82642	 1	 12.96	 3.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82643	 1	 25.18	 6.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82644	 1	 15.06	 5.39	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82645	 1	 16.96	 4.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82646	 1	 37.03	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82647	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82648	 1	 25.26	 5.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82649	 1	 25.75	 9.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82650	 1	 12.82	 4.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82651	 1	 12.01	 4.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82652	 1	 10.91	 3.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82653	 1	 40.54	 11.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82654	 1	 8.51	 3.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82655	 1	 73.19	 15.19	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82656	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82657	 1	 38.02	 7.29	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82658	 1	 20.1	 6.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82659	 1	 10.16	 4.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82660	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82661	 1	 16.72	 5.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82662	 1	 92.78	 28.12	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82663	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82664	 1	 13.07	 4.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82665	 1	 28.16	 6.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82666	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82667	 1	 33.87	 10.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82668	 1	 29.86	 9.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82669	 1	 16.86	 6.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82670	 1	 3.48	 1.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82671	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82672	 1	 21.56	 6.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82673	 1	 11.54	 4.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82674	 1	 30.77	 6.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82675	 1	 55.0	 17.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82676	 1	 6.82	 2.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82677	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82678	 1	 39.57	 14.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82679	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82680	 1	 56.19	 16.74	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82681	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82682	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82683	 1	 11.58	 4.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82684	 1	 25.12	 9.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82685	 1	 51.08	 11.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82686	 1	 13.01	 4.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82687	 1	 5.0	 2.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82688	 1	 8.93	 3.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82689	 1	 9.62	 2.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82690	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82691	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82692	 1	 38.42	 10.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82693	 1	 29.68	 9.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82694	 1	 46.77	 9.05	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82695	 1	 34.46	 12.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82696	 1	 35.81	 15.65	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82697	 1	 22.34	 7.41	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82698	 1	 23.27	 5.22	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82699	 1	 60.45	 15.95	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82700	 1	 24.85	 7.99	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82701	 1	 37.35	 8.01	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82702	 1	 19.63	 5.06	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82703	 1	 7.83	 2.58	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82704	 1	 11.3	 5.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82705	 1	 14.3	 4.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82706	 1	 22.6	 6.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82707	 1	 12.86	 4.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82708	 1	 99.83	 18.33	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82709	 1	 33.54	 9.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82710	 1	 36.22	 9.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82711	 1	 10.1	 4.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82712	 1	 8.23	 2.78	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82713	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82714	 1	 5.54	 2.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82715	 1	 28.42	 7.18	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82716	 1	 11.13	 4.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82717	 1	 15.38	 4.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82718	 1	 23.59	 7.82	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82719	 1	 5.41	 1.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82720	 1	 11.3	 2.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82721	 1	 16.51	 3.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82722	 1	 47.19	 10.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82723	 1	 43.28	 9.21	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82724	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82725	 1	 11.98	 8.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82726	 1	 1.58	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82727	 1	 7.07	 5.41	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82728	 1	 10.83	 5.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82729	 1	 17.71	 10.83	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82730	 1	 5.99	 3.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82731	 1	 5.19	 3.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82732	 1	 1.51	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82733	 1	 9.66	 6.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82734	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82735	 1	 16.01	 9.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82736	 1	 10.51	 6.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82737	 1	 15.81	 8.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82738	 1	 13.19	 6.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82739	 1	 29.38	 14.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82740	 1	 60.87	 18.3	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82741	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82742	 1	 7.1	 4.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82743	 1	 9.06	 4.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82744	 1	 9.23	 4.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82745	 1	 18.22	 9.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82746	 1	 1.71	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82747	 1	 2.85	 1.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82748	 1	 12.65	 6.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82749	 1	 4.8	 3.03	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82750	 1	 13.38	 7.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82751	 1	 8.79	 6.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82752	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82753	 1	 22.64	 12.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82754	 1	 7.84	 5.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82755	 1	 10.28	 6.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82756	 1	 14.4	 5.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82757	 1	 2.69	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82758	 1	 4.04	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82759	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82760	 1	 17.04	 7.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82761	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82762	 1	 14.29	 4.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82763	 1	 5.34	 2.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82764	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82765	 1	 5.39	 2.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82766	 1	 5.24	 3.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82767	 1	 13.45	 7.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82768	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82769	 1	 7.88	 4.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82770	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82771	 1	 8.83	 4.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82772	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82773	 1	 4.81	 3.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82774	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82775	 1	 8.87	 5.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82776	 1	 14.47	 7.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82777	 1	 3.93	 2.44	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82778	 1	 6.31	 3.03	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82779	 1	 2.88	 1.45	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82780	 1	 17.87	 6.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82781	 1	 27.31	 5.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82782	 1	 5.34	 3.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82783	 1	 13.22	 2.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82784	 1	 7.92	 1.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82785	 1	 41.09	 18.44	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82786	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82787	 1	 8.12	 1.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82788	 1	 3.97	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82789	 1	 4.22	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82790	 1	 9.88	 2.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82791	 1	 29.29	 14.93	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82792	 1	 26.89	 6.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82793	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82794	 1	 19.18	 4.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82795	 1	 6.25	 3.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82796	 1	 4.29	 2.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82797	 1	 12.75	 6.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82798	 1	 8.93	 5.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82799	 1	 9.65	 4.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82800	 1	 3.45	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82801	 1	 2.23	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82802	 1	 2.19	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82803	 1	 24.96	 12.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82804	 1	 1.63	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82805	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82806	 1	 13.45	 6.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82807	 1	 2.73	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82808	 1	 3.52	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82809	 1	 10.09	 4.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82810	 1	 24.17	 9.18	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82811	 1	 6.08	 3.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82812	 1	 8.62	 4.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82813	 1	 24.75	 9.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82814	 1	 7.69	 3.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82815	 1	 2.79	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82816	 1	 7.05	 4.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82817	 1	 11.51	 4.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82818	 1	 3.64	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82819	 1	 5.2	 2.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82820	 1	 1.77	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82821	 1	 1.32	 1.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82822	 1	 2.5	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82823	 1	 1.4	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82824	 1	 2.55	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82825	 1	 4.66	 2.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82826	 1	 3.1	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82827	 1	 2.32	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82828	 1	 5.29	 2.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82829	 1	 6.46	 2.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82830	 1	 8.31	 5.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82831	 1	 4.95	 3.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82832	 1	 2.1	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82833	 1	 2.37	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82834	 1	 7.89	 4.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82835	 1	 2.42	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82836	 1	 1.53	 0.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82837	 1	 3.16	 1.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82838	 1	 2.67	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82839	 1	 4.71	 2.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82840	 1	 4.69	 3.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82841	 1	 2.57	 2.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82842	 1	 3.15	 2.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82843	 1	 4.85	 3.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82844	 1	 11.06	 6.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82845	 1	 6.92	 4.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82846	 1	 12.47	 4.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82847	 1	 4.13	 2.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82848	 1	 6.75	 4.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82849	 1	 4.6	 3.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82850	 1	 7.67	 5.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82851	 1	 1.4	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82852	 1	 2.81	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82853	 1	 12.34	 6.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82854	 1	 2.51	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82855	 1	 6.56	 3.6	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82856	 1	 7.27	 3.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82857	 1	 8.1	 4.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82858	 1	 8.23	 4.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82859	 1	 2.64	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82860	 1	 2.94	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82861	 1	 3.06	 2.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82862	 1	 11.86	 2.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82863	 1	 10.3	 4.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82864	 1	 11.42	 5.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82865	 1	 8.27	 3.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82866	 1	 4.62	 2.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82867	 1	 6.82	 3.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82868	 1	 7.48	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82869	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82870	 1	 22.64	 10.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82871	 1	 9.16	 5.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82872	 1	 15.76	 7.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82873	 1	 13.01	 7.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82874	 1	 8.02	 4.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82875	 1	 17.89	 10.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82876	 1	 4.87	 3.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82877	 1	 2.75	 2.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82878	 1	 3.34	 2.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82879	 1	 25.29	 5.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82880	 1	 7.46	 3.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82881	 1	 8.94	 3.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82882	 1	 7.8	 4.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82883	 1	 12.48	 6.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82884	 1	 3.9	 2.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82885	 1	 5.13	 3.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82886	 1	 4.84	 2.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82887	 1	 10.18	 3.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82888	 1	 1.71	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82889	 1	 7.47	 5.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82890	 1	 2.24	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82891	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82892	 1	 17.25	 10.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82893	 1	 7.02	 3.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82894	 1	 4.92	 3.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82895	 1	 7.51	 4.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82896	 1	 22.36	 12.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82897	 1	 7.31	 2.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82898	 1	 5.97	 3.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82899	 1	 6.36	 3.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82900	 1	 6.01	 3.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82901	 1	 6.78	 3.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82902	 1	 7.82	 3.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82903	 1	 6.85	 3.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82904	 1	 7.85	 4.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82905	 1	 9.28	 4.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82906	 1	 12.69	 8.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82907	 1	 2.43	 1.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82908	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82909	 1	 14.04	 8.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82910	 1	 11.24	 5.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82911	 1	 12.36	 7.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82912	 1	 2.55	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82913	 1	 24.69	 11.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82914	 1	 6.0	 3.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82915	 1	 6.15	 4.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82916	 1	 21.49	 11.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82917	 1	 9.63	 5.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82918	 1	 10.73	 6.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82919	 1	 5.64	 2.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82920	 1	 4.11	 2.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82921	 1	 2.44	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82922	 1	 6.0	 3.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82923	 1	 10.73	 4.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82924	 1	 10.36	 4.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82925	 1	 13.74	 7.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82926	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82927	 1	 30.38	 14.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82928	 1	 16.75	 3.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82929	 1	 45.67	 16.05	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82930	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82931	 1	 6.13	 3.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82932	 1	 9.6	 6.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82933	 1	 12.86	 5.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82934	 1	 11.04	 5.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82935	 1	 4.6	 2.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82936	 1	 5.96	 4.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82937	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82938	 1	 7.76	 3.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82939	 1	 10.4	 6.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82940	 1	 11.55	 2.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82941	 1	 24.6	 11.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82942	 1	 13.02	 4.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82943	 1	 5.37	 2.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82944	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82945	 1	 6.48	 2.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82946	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82947	 1	 8.06	 3.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82948	 1	 3.93	 2.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82949	 1	 4.9	 2.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82950	 1	 4.39	 2.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82951	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82952	 1	 23.0	 10.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82953	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82954	 1	 18.43	 5.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82955	 1	 7.14	 3.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82956	 1	 7.96	 5.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82957	 1	 4.49	 2.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82958	 1	 4.44	 3.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82959	 1	 3.71	 2.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82960	 1	 17.86	 7.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82961	 1	 11.66	 5.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82962	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82963	 1	 24.7	 13.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82964	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82965	 1	 30.38	 15.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82966	 1	 26.18	 13.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82967	 1	 8.43	 4.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82968	 1	 21.35	 8.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82969	 1	 42.03	 18.62	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82970	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82971	 1	 4.93	 2.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82972	 1	 31.61	 12.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82973	 1	 41.15	 13.16	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82974	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82975	 1	 15.14	 8.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82976	 1	 10.53	 5.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82977	 1	 12.8	 6.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82978	 1	 13.7	 5.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82979	 1	 4.34	 2.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82980	 1	 7.55	 3.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82981	 1	 27.58	 9.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82982	 1	 16.65	 7.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82983	 1	 18.47	 11.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82984	 1	 7.19	 3.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82985	 1	 1.47	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82986	 1	 3.48	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82987	 1	 1.59	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82988	 1	 1.12	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82989	 1	 5.92	 3.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82990	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82991	 1	 23.36	 13.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82992	 1	 6.46	 3.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82993	 1	 3.05	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82994	 1	 2.0	 0.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82995	 1	 12.72	 2.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82996	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82997	 1	 31.55	 7.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82998	 1	 6.17	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82999	 1	 23.7	 5.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83000	 1	 5.37	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83001	 1	 7.71	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83002	 1	 1.25	 0.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83003	 1	 3.13	 0.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83004	 1	 2.55	 0.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83005	 1	 1.47	 0.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83006	 1	 11.17	 4.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83007	 1	 15.3	 3.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83008	 1	 0.94	 0.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83009	 1	 16.06	 3.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83010	 1	 1.34	 0.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83011	 1	 9.19	 2.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83012	 1	 5.2	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83013	 1	 1.95	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83014	 1	 19.04	 4.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83015	 1	 8.25	 1.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83016	 1	 1.3	 0.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83017	 1	 6.98	 3.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83018	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83019	 1	 9.4	 5.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83020	 1	 13.39	 7.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83021	 1	 8.99	 3.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83022	 1	 4.85	 3.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83023	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83024	 1	 12.6	 6.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83025	 1	 7.36	 3.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83026	 1	 6.06	 3.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83027	 1	 26.15	 9.75	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83028	 1	 5.22	 2.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83029	 1	 4.5	 3.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83030	 1	 4.2	 2.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83031	 1	 3.78	 2.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83032	 1	 13.3	 7.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83033	 1	 32.85	 15.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83034	 1	 5.12	 2.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83035	 1	 2.04	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83036	 1	 2.32	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83037	 1	 2.9	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83038	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83039	 1	 2.96	 1.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83040	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83041	 1	 4.13	 2.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83042	 1	 3.91	 2.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83043	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83044	 1	 4.64	 2.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83045	 1	 4.14	 2.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83046	 1	 4.85	 2.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83047	 1	 4.55	 3.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83048	 1	 4.72	 2.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83049	 1	 8.48	 4.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83050	 1	 9.12	 4.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83051	 1	 5.51	 3.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83052	 1	 5.52	 3.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83053	 1	 7.73	 4.07	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83054	 1	 8.47	 4.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83055	 1	 18.17	 7.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83056	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83057	 1	 24.99	 8.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83058	 1	 7.01	 3.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83059	 1	 4.84	 2.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83060	 1	 5.13	 2.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83061	 1	 2.52	 1.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83062	 1	 3.15	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83063	 1	 4.57	 3.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83064	 1	 19.96	 10.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83065	 1	 3.35	 2.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83066	 1	 3.44	 1.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83067	 1	 11.58	 4.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83068	 1	 10.46	 4.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83069	 1	 6.54	 3.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83070	 1	 5.44	 3.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83071	 1	 8.15	 4.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83072	 1	 35.57	 14.1	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83073	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83074	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	83075	 1	 57.45	 21.21	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83076	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83077	 1	 16.59	 9.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83078	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83079	 1	 14.6	 5.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83080	 1	 4.8	 3.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83081	 1	 41.49	 15.15	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83082	 1	 9.88	 4.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83083	 1	 4.81	 2.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83084	 1	 3.58	 1.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83085	 1	 1.69	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83086	 1	 13.49	 4.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83087	 1	 22.81	 8.76	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83088	 1	 8.18	 5.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83089	 1	 5.45	 3.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83090	 1	 3.44	 2.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83091	 1	 3.28	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83092	 1	 24.42	 9.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83093	 1	 4.11	 2.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83094	 1	 6.16	 3.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83095	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	83096	 1	 187.48	 79.27	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83097	 1	 6.73	 4.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83098	 1	 4.05	 2.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83099	 1	 4.45	 2.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83100	 1	 5.36	 3.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83101	 1	 5.35	 3.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83102	 1	 11.46	 4.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83103	 1	 10.97	 2.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83104	 1	 4.04	 2.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83105	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83106	 1	 19.74	 8.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83107	 1	 6.82	 4.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83108	 1	 7.63	 4.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83109	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83110	 1	 10.79	 6.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83111	 1	 5.69	 4.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83112	 1	 5.22	 2.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83113	 1	 22.72	 12.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83114	 1	 13.4	 7.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83115	 1	 4.6	 2.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83116	 1	 41.73	 15.07	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83117	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83118	 1	 9.42	 4.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83119	 1	 9.5	 5.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83120	 1	 1.91	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83121	 1	 16.85	 9.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83122	 1	 1.57	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83123	 1	 22.27	 12.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83124	 1	 17.15	 7.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83125	 1	 5.41	 3.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83126	 1	 14.78	 6.92	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83127	 1	 20.63	 7.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83128	 1	 20.31	 10.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83129	 1	 1.42	 0.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83130	 1	 8.73	 5.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83131	 1	 5.95	 3.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83132	 1	 18.83	 7.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83133	 1	 4.94	 2.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83134	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83135	 1	 10.13	 5.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83136	 1	 4.97	 2.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83137	 1	 4.69	 2.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83138	 1	 1.56	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83139	 1	 3.33	 2.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83140	 1	 6.46	 3.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83141	 1	 5.48	 2.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83142	 1	 3.21	 2.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83143	 1	 6.47	 3.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83144	 1	 5.93	 3.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83145	 1	 17.93	 8.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83146	 1	 2.71	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83147	 1	 11.84	 6.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83148	 1	 3.26	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83149	 1	 3.04	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83150	 1	 1.37	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83151	 1	 3.69	 2.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83152	 1	 3.18	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83153	 1	 7.77	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83154	 1	 3.73	 2.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83155	 1	 3.68	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83156	 1	 41.68	 20.74	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83157	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83158	 1	 12.13	 5.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83159	 1	 9.4	 4.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83160	 1	 1.18	 0.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83161	 1	 7.17	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83162	 1	 29.31	 6.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83163	 1	 12.48	 2.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83164	 1	 12.98	 2.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83165	 1	 9.45	 2.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83166	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83167	 1	 21.48	 12.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83168	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83169	 1	 31.0	 15.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83170	 1	 13.1	 5.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83171	 1	 5.69	 3.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83172	 1	 10.66	 5.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83173	 1	 13.57	 8.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83174	 1	 6.6	 3.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83175	 1	 13.28	 7.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83176	 1	 16.59	 3.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83177	 1	 3.04	 1.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83178	 1	 4.39	 2.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83179	 1	 5.25	 1.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83180	 1	 9.66	 2.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83181	 1	 4.25	 0.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83182	 1	 4.54	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83183	 1	 18.17	 5.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83184	 1	 9.68	 2.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83185	 1	 1.51	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83186	 1	 3.02	 1.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83187	 1	 4.44	 2.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83188	 1	 3.18	 2.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83189	 1	 2.57	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83190	 1	 2.35	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83191	 1	 3.67	 2.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83192	 1	 6.48	 3.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83193	 1	 6.93	 4.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83194	 1	 8.16	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83195	 1	 14.29	 7.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83196	 1	 2.97	 1.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83197	 1	 17.15	 3.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83198	 1	 13.15	 6.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83199	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83200	 1	 11.93	 5.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83201	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83202	 1	 22.7	 7.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83203	 1	 3.9	 1.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83204	 1	 22.42	 12.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83205	 1	 27.3	 9.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83206	 1	 7.68	 3.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83207	 1	 10.8	 6.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83208	 1	 2.12	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83209	 1	 4.26	 2.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83210	 1	 4.87	 2.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83211	 1	 2.33	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83212	 1	 3.85	 2.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83213	 1	 5.13	 2.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83214	 1	 5.31	 2.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83215	 1	 10.93	 5.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83216	 1	 4.09	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83217	 1	 5.36	 3.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83218	 1	 6.53	 4.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83219	 1	 2.96	 1.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83220	 1	 3.22	 2.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83221	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83222	 1	 18.34	 9.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83223	 1	 2.74	 1.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83224	 1	 16.48	 8.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83225	 1	 15.21	 6.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83226	 1	 5.68	 3.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83227	 1	 6.24	 3.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83228	 1	 11.61	 6.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83229	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83230	 1	 12.99	 7.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83231	 1	 6.77	 4.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83232	 1	 4.67	 2.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83233	 1	 14.05	 8.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83234	 1	 7.16	 4.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83235	 1	 13.67	 6.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83236	 1	 3.45	 2.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83237	 1	 5.77	 3.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83238	 1	 16.0	 9.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83239	 1	 6.1	 3.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83240	 1	 18.37	 7.84	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83241	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83242	 1	 4.16	 2.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83243	 1	 6.86	 4.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83244	 1	 4.66	 2.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83245	 1	 2.89	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83246	 1	 11.29	 6.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83247	 1	 50.5	 16.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83248	 1	 9.44	 5.51	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83249	 1	 9.29	 5.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83250	 1	 6.28	 4.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83251	 1	 43.47	 19.32	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83252	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83253	 1	 13.31	 8.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83254	 1	 13.7	 6.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83255	 1	 4.45	 2.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83256	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83257	 1	 14.09	 4.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83258	 1	 10.67	 5.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83259	 1	 1.94	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83260	 1	 3.8	 2.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83261	 1	 5.58	 3.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83262	 1	 6.06	 3.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83263	 1	 1.51	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83264	 1	 2.99	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83265	 1	 8.31	 6.37	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83266	 1	 10.64	 5.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83267	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83268	 1	 4.24	 2.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83269	 1	 4.76	 3.41	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83270	 1	 1.37	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83271	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83272	 1	 21.86	 10.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83273	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83274	 1	 20.61	 7.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83275	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83276	 1	 6.25	 3.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83277	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83278	 1	 7.78	 4.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83279	 1	 2.14	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83280	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83281	 1	 7.92	 4.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83282	 1	 7.5	 3.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83283	 1	 4.04	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83284	 1	 14.67	 4.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83285	 1	 5.11	 3.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83286	 1	 4.45	 2.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83287	 1	 5.61	 3.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83288	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83289	 1	 6.15	 4.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83290	 1	 5.73	 3.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83291	 1	 24.06	 7.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83292	 1	 16.69	 9.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83293	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83294	 1	 7.65	 3.89	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83295	 1	 14.24	 7.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83296	 1	 7.44	 4.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83297	 1	 7.29	 4.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83298	 1	 4.4	 2.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83299	 1	 2.39	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83300	 1	 11.81	 2.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83301	 1	 12.45	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83302	 1	 27.74	 5.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83303	 1	 3.7	 0.81	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83304	 1	 27.58	 5.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83305	 1	 4.2	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83306	 1	 11.72	 7.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83307	 1	 14.7	 7.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83308	 1	 17.78	 7.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83309	 1	 28.55	 15.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83310	 1	 2.93	 0.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83311	 1	 10.46	 5.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83312	 1	 4.15	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83313	 1	 2.29	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83314	 1	 13.71	 7.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83315	 1	 8.27	 4.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83316	 1	 3.5	 2.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83317	 1	 16.29	 8.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83318	 1	 19.4	 7.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83319	 1	 5.96	 2.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83320	 1	 5.54	 3.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83321	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83322	 1	 23.94	 13.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83323	 1	 10.61	 5.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83324	 1	 3.95	 2.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83325	 1	 9.91	 5.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83326	 1	 8.76	 2.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83327	 1	 1.37	 0.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83328	 1	 3.0	 0.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83329	 1	 11.26	 6.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83330	 1	 4.66	 2.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83331	 1	 6.19	 3.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83332	 1	 7.15	 3.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83333	 1	 3.55	 2.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83334	 1	 1.86	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83335	 1	 14.33	 3.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83336	 1	 2.74	 1.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83337	 1	 5.58	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83338	 1	 9.29	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83339	 1	 7.25	 4.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83340	 1	 20.01	 4.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83341	 1	 19.67	 11.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83342	 1	 2.61	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83343	 1	 5.56	 3.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83344	 1	 1.56	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83345	 1	 5.6	 2.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83346	 1	 3.3	 2.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83347	 1	 2.77	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83348	 1	 1.85	 1.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83349	 1	 10.92	 5.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83350	 1	 11.73	 4.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83351	 1	 14.6	 5.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83352	 1	 39.04	 17.67	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83353	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83354	 1	 2.08	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83355	 1	 2.28	 1.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83356	 1	 1.64	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83357	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83358	 1	 19.05	 11.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83359	 1	 9.66	 3.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83360	 1	 11.35	 7.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83361	 1	 20.92	 11.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83362	 1	 1.33	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83363	 1	 6.16	 3.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83364	 1	 2.51	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83365	 1	 5.97	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83366	 1	 3.53	 2.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83367	 1	 3.04	 2.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83368	 1	 3.62	 2.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83369	 1	 3.34	 2.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83370	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83371	 1	 3.49	 2.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83372	 1	 1.79	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83373	 1	 55.77	 24.18	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83374	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83375	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83376	 1	 17.64	 7.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83377	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83378	 1	 13.87	 7.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83379	 1	 2.39	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83380	 1	 6.49	 3.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83381	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83382	 1	 2.45	 1.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83383	 1	 1.93	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83384	 1	 1.97	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83385	 1	 1.7	 0.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83386	 1	 4.15	 2.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83387	 1	 1.06	 0.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83388	 1	 7.92	 2.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83389	 1	 6.98	 4.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83390	 1	 9.09	 4.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83391	 1	 3.01	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83392	 1	 1.64	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83393	 1	 11.47	 5.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83394	 1	 7.91	 2.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83395	 1	 3.27	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83396	 1	 3.19	 2.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83397	 1	 3.12	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83398	 1	 3.32	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83399	 1	 2.89	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83400	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83401	 1	 17.71	 8.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83402	 1	 11.8	 5.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83403	 1	 7.99	 4.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83404	 1	 11.79	 2.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83405	 1	 1.86	 1.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83406	 1	 2.04	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83407	 1	 2.66	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83408	 1	 2.9	 1.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83409	 1	 5.04	 2.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83410	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83411	 1	 3.02	 2.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83412	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	83413	 1	 97.0	 49.11	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83414	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83415	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83416	 1	 6.27	 2.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83417	 1	 2.14	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83418	 1	 1.55	 1.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83419	 1	 10.57	 5.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83420	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83421	 1	 6.93	 4.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83422	 1	 8.77	 4.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83423	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83424	 1	 14.41	 6.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83425	 1	 3.89	 2.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83426	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83427	 1	 2.76	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83428	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83429	 1	 2.31	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83430	 1	 13.12	 7.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83431	 1	 12.39	 5.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83432	 1	 3.65	 2.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83433	 1	 6.06	 2.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83434	 1	 1.86	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83435	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83436	 1	 22.0	 10.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83437	 1	 3.27	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83438	 1	 3.31	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83439	 1	 3.14	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83440	 1	 4.5	 2.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83441	 1	 3.27	 2.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83442	 1	 2.27	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83443	 1	 2.72	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83444	 1	 2.69	 1.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83445	 1	 14.91	 8.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83446	 1	 4.05	 2.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83447	 1	 1.55	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83448	 1	 2.1	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83449	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83450	 1	 22.16	 11.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83451	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83452	 1	 20.61	 10.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83453	 1	 3.85	 2.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83454	 1	 3.16	 2.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83455	 1	 4.6	 3.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83456	 1	 12.09	 6.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83457	 1	 2.37	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83458	 1	 7.25	 4.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83459	 1	 16.77	 9.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83460	 1	 1.89	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83461	 1	 5.91	 3.54	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83462	 1	 12.69	 7.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83463	 1	 5.2	 2.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83464	 1	 1.96	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83465	 1	 5.2	 2.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83466	 1	 9.78	 5.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83467	 1	 40.22	 16.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83468	 1	 16.11	 7.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83469	 1	 2.8	 1.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83470	 1	 5.36	 2.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83471	 1	 11.11	 6.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83472	 1	 18.53	 10.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83473	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83474	 1	 12.37	 6.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83475	 1	 14.93	 6.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83476	 1	 11.73	 5.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83477	 1	 3.83	 2.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83478	 1	 39.15	 18.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83479	 1	 3.19	 2.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83480	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83481	 1	 22.18	 12.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83482	 1	 10.54	 5.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83483	 1	 4.93	 3.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83484	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83485	 1	 26.76	 12.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83486	 1	 3.5	 2.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83487	 1	 15.84	 9.35	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83488	 1	 2.47	 1.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83489	 1	 4.48	 2.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83490	 1	 8.7	 5.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83491	 1	 10.71	 4.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83492	 1	 3.79	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83493	 1	 40.67	 18.93	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83494	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83495	 1	 56.7	 24.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83496	 1	 7.39	 4.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83497	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83498	 1	 28.1	 11.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83499	 1	 10.27	 4.43	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83500	 1	 8.95	 3.68	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83501	 1	 20.63	 7.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83502	 1	 17.98	 4.99	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83503	 1	 6.33	 2.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83504	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83505	 1	 29.12	 9.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83506	 1	 19.24	 6.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83507	 1	 10.15	 3.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83508	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	83509	 1	 186.26	 61.97	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83510	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83511	 1	 70.99	 24.66	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83512	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83513	 1	 10.67	 2.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83514	 1	 3.58	 1.36	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83515	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83516	 1	 19.65	 8.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83517	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83518	 1	 3.69	 1.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83519	 1	 1.12	 0.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83520	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83521	 1	 26.82	 6.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83522	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83523	 1	 35.93	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83524	 1	 8.34	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83525	 1	 16.2	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83526	 1	 37.42	 15.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83527	 1	 131.7	 31.23	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83528	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83529	 1	 17.54	 5.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83530	 1	 20.61	 8.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83531	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83532	 1	 7.99	 3.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83533	 1	 18.0	 6.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83534	 1	 9.89	 4.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83535	 1	 28.01	 11.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83536	 1	 5.08	 2.55	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83537	 1	 10.76	 4.84	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83538	 1	 17.07	 6.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83539	 1	 4.1	 1.85	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83540	 1	 8.65	 3.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83541	 1	 6.27	 3.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83542	 1	 25.99	 5.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83543	 1	 11.95	 2.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83544	 1	 14.35	 3.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83545	 1	 13.12	 3.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83546	 1	 18.67	 4.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83547	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83548	 1	 9.73	 4.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83549	 1	 5.73	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83550	 1	 10.5	 4.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83551	 1	 6.58	 2.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83552	 1	 5.06	 2.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83553	 1	 17.92	 5.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83554	 1	 9.74	 2.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83555	 1	 5.33	 2.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83556	 1	 17.65	 8.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83557	 1	 13.43	 5.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83558	 1	 5.35	 2.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83559	 1	 8.32	 3.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83560	 1	 12.42	 5.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83561	 1	 4.31	 2.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83562	 1	 7.33	 3.29	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83563	 1	 5.66	 2.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83564	 1	 10.0	 4.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83565	 1	 32.07	 10.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83566	 1	 4.97	 2.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83567	 1	 13.7	 5.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83568	 1	 5.13	 2.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83569	 1	 14.78	 7.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83570	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83571	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83572	 1	 5.37	 2.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83573	 1	 14.46	 7.34	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83574	 1	 8.15	 3.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83575	 1	 7.37	 3.74	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83576	 1	 134.65	 41.42	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83577	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83578	 1	 10.52	 5.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83579	 1	 6.32	 3.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83580	 1	 29.69	 9.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83581	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83582	 1	 38.31	 12.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83583	 1	 60.83	 22.51	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83584	 1	 7.98	 3.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83585	 1	 4.6	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83586	 1	 24.41	 8.19	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83587	 1	 2.67	 1.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83588	 1	 2.25	 1.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83589	 1	 5.21	 1.96	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83590	 1	 2.85	 1.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83591	 1	 25.86	 7.92	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83592	 1	 36.72	 10.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83593	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83594	 1	 25.7	 5.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83595	 1	 14.5	 4.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83596	 1	 25.37	 8.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83597	 1	 12.08	 4.5	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83598	 1	 5.17	 1.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83599	 1	 15.69	 5.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83600	 1	 15.96	 3.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83601	 1	 21.26	 4.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83602	 1	 21.53	 4.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83603	 1	 17.93	 4.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83604	 1	 6.94	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83605	 1	 14.21	 3.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83606	 1	 31.55	 7.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83607	 1	 18.7	 4.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83608	 1	 22.5	 5.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83609	 1	 32.25	 7.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83610	 1	 5.7	 1.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83611	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83612	 1	 30.07	 6.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83613	 1	 12.85	 2.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83614	 1	 7.32	 1.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83615	 1	 7.6	 1.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83616	 1	 14.93	 3.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83617	 1	 10.63	 4.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83618	 1	 2.36	 1.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83619	 1	 7.96	 3.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83620	 1	 9.43	 4.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83621	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83622	 1	 9.77	 3.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83623	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83624	 1	 5.08	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83625	 1	 8.35	 3.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83626	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83627	 1	 17.35	 6.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83628	 1	 7.1	 3.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83629	 1	 22.99	 7.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83630	 1	 11.51	 4.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83631	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83632	 1	 35.05	 10.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83633	 1	 9.33	 4.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83634	 1	 9.72	 4.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83635	 1	 6.69	 3.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83636	 1	 10.85	 4.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83637	 1	 11.95	 4.98	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83638	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83639	 1	 43.29	 16.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83640	 1	 20.48	 7.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83641	 1	 9.82	 3.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83642	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83643	 1	 12.48	 4.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83644	 1	 18.92	 6.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83645	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83646	 1	 28.19	 8.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83647	 1	 5.35	 1.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83648	 1	 18.4	 8.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83649	 1	 10.84	 3.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83650	 1	 6.73	 3.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83651	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83652	 1	 8.59	 4.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83653	 1	 19.55	 8.75	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83654	 1	 131.37	 44.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83655	 1	 3.68	 1.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83656	 1	 5.9	 2.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83657	 1	 4.24	 2.07	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83658	 1	 26.95	 9.01	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83659	 1	 19.82	 5.04	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83660	 1	 51.29	 15.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83661	 1	 2.26	 1.14	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83662	 1	 6.83	 2.67	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83663	 1	 6.05	 3.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83664	 1	 22.72	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83665	 1	 16.1	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83666	 1	 4.47	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83667	 1	 10.87	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83668	 1	 35.92	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83669	 1	 5.58	 1.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83670	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83671	 1	 3.85	 1.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83672	 1	 9.26	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83673	 1	 6.66	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83674	 1	 13.71	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83675	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83676	 1	 5.8	 2.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83677	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83678	 1	 5.8	 2.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83679	 1	 10.38	 4.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83680	 1	 54.43	 16.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83681	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83682	 1	 1.56	 0.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83683	 1	 3.22	 1.39	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83684	 1	 84.78	 30.2	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83685	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83686	 1	 6.46	 2.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83687	 1	 13.08	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83688	 1	 5.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83689	 1	 12.35	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83690	 1	 24.57	 8.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83691	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83692	 1	 6.86	 2.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83693	 1	 10.35	 2.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83694	 1	 24.3	 7.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83695	 1	 1.61	 0.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83696	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83697	 1	 22.66	 5.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83698	 1	 4.89	 2.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83699	 1	 12.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83700	 1	 21.35	 7.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83701	 1	 9.97	 3.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83702	 1	 13.5	 5.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83703	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83704	 1	 11.0	 3.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83705	 1	 7.68	 3.77	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83706	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83707	 1	 24.12	 6.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83708	 1	 22.5	 5.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83709	 1	 9.51	 4.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83710	 1	 5.98	 2.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83711	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83712	 1	 9.26	 3.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83713	 1	 5.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83714	 1	 3.4	 1.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83715	 1	 2.59	 1.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83716	 1	 20.35	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83717	 1	 13.88	 3.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83718	 1	 8.92	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83719	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83720	 1	 41.94	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83721	 1	 9.15	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83722	 1	 37.41	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83723	 1	 30.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83724	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83725	 1	 33.29	 11.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83726	 1	 14.62	 5.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83727	 1	 11.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83728	 1	 46.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83729	 1	 38.45	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83730	 1	 20.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83731	 1	 10.56	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83732	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83733	 1	 17.14	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83734	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83735	 1	 19.27	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83736	 1	 40.9	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83737	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83738	 1	 23.23	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83739	 1	 7.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83740	 1	 13.32	 3.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83741	 1	 6.6	 3.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83742	 1	 11.51	 4.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83743	 1	 107.67	 30.93	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83744	 1	 9.11	 3.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83745	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83746	 1	 30.69	 8.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83747	 1	 1.64	 0.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83748	 1	 14.68	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83749	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83750	 1	 24.66	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83751	 1	 10.76	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83752	 1	 27.39	 7.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83753	 1	 23.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83754	 1	 21.15	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83755	 1	 7.03	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83756	 1	 15.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83757	 1	 7.3	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83758	 1	 8.12	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83759	 1	 9.58	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83760	 1	 5.61	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83761	 1	 9.3	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83762	 1	 14.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83763	 1	 3.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83764	 1	 9.77	 4.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83765	 1	 7.51	 2.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83766	 1	 23.74	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83767	 1	 5.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83768	 1	 9.27	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83769	 1	 9.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83770	 1	 6.72	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83771	 1	 7.95	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83772	 1	 10.9	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83773	 1	 11.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83774	 1	 7.02	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83775	 1	 11.26	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83776	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83777	 1	 43.35	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83778	 1	 6.16	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83779	 1	 17.76	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83780	 1	 6.18	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83781	 1	 5.95	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83782	 1	 7.19	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83783	 1	 6.42	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83784	 1	 13.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83785	 1	 11.63	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83786	 1	 14.65	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83787	 1	 11.24	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83788	 1	 10.9	 3.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83789	 1	 2.46	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83790	 1	 2.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83791	 1	 4.05	 1.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83792	 1	 114.84	 26.5	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83793	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83794	 1	 15.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83795	 1	 7.67	 3.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83796	 1	 17.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83797	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83798	 1	 46.03	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83799	 1	 3.61	 1.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83800	 1	 22.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83801	 1	 16.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83802	 1	 24.12	 7.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83803	 1	 13.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83804	 1	 17.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83805	 1	 40.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83806	 1	 10.17	 3.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83807	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	83808	 1	 153.52	 37.5	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83809	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83810	 1	 21.65	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83811	 1	 9.79	 4.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83812	 1	 3.81	 1.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83813	 1	 45.35	 17.82	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83814	 1	 31.16	 7.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83815	 1	 20.29	 7.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83816	 1	 8.59	 1.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83817	 1	 7.0	 1.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83818	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83819	 1	 40.56	 9.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83820	 1	 9.79	 2.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83821	 1	 9.29	 2.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83822	 1	 13.03	 3.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83823	 1	 12.37	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83824	 1	 12.14	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83825	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83826	 1	 5.59	 1.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83827	 1	 8.53	 3.48	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83828	 1	 13.18	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83829	 1	 11.78	 5.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83830	 1	 33.47	 12.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83831	 1	 28.91	 6.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83832	 1	 5.16	 2.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83833	 1	 6.96	 2.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83834	 1	 15.47	 6.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83835	 1	 29.88	 8.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83836	 1	 46.56	 15.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83837	 1	 4.34	 1.66	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83838	 1	 8.7	 3.97	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83839	 1	 10.66	 2.92	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83840	 1	 5.16	 2.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83841	 1	 9.64	 2.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83842	 1	 15.81	 6.76	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83843	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83844	 1	 47.89	 14.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83845	 1	 13.53	 4.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83846	 1	 8.12	 3.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83847	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83848	 1	 23.35	 10.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83849	 1	 10.05	 2.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83850	 1	 12.47	 5.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83851	 1	 25.93	 9.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83852	 1	 5.39	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83853	 1	 3.78	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83854	 1	 4.89	 1.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83855	 1	 2.95	 0.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83856	 1	 3.31	 0.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83857	 1	 5.66	 1.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83858	 1	 12.82	 2.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83859	 1	 4.68	 1.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83860	 1	 13.56	 3.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83861	 1	 11.21	 2.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83862	 1	 5.02	 1.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83863	 1	 3.09	 0.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83864	 1	 22.44	 5.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83865	 1	 16.32	 3.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83866	 1	 5.41	 1.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83867	 1	 2.3	 0.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83868	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83869	 1	 27.66	 6.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83870	 1	 5.61	 1.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83871	 1	 4.3	 0.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83872	 1	 8.78	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83873	 1	 21.38	 4.95	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83874	 1	 3.27	 0.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83875	 1	 3.05	 0.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83876	 1	 7.35	 1.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83877	 1	 4.95	 1.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83878	 1	 4.1	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83879	 1	 4.11	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83880	 1	 6.86	 1.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83881	 1	 20.11	 4.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83882	 1	 18.6	 4.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83883	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83884	 1	 25.77	 5.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83885	 1	 5.8	 1.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83886	 1	 5.31	 1.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83887	 1	 8.23	 1.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83888	 1	 6.3	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83889	 1	 11.72	 2.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83890	 1	 7.72	 1.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83891	 1	 6.1	 1.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83892	 1	 5.12	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83893	 1	 9.53	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83894	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83895	 1	 8.96	 2.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83896	 1	 18.71	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83897	 1	 4.79	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83898	 1	 6.57	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83899	 1	 7.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83900	 1	 12.06	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83901	 1	 14.25	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83902	 1	 6.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83903	 1	 8.31	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83904	 1	 4.46	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83905	 1	 8.69	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83906	 1	 32.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83907	 1	 32.09	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83908	 1	 6.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83909	 1	 4.86	 1.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83910	 1	 5.58	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83911	 1	 4.29	 0.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83912	 1	 11.56	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83913	 1	 5.33	 1.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83914	 1	 5.74	 1.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83915	 1	 3.12	 0.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83916	 1	 11.29	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83917	 1	 20.59	 4.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83918	 1	 18.27	 4.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83919	 1	 16.92	 3.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83920	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83921	 1	 33.01	 7.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83922	 1	 28.64	 6.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83923	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83924	 1	 15.79	 3.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83925	 1	 134.89	 44.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83926	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83927	 1	 4.89	 1.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83928	 1	 14.32	 3.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83929	 1	 7.41	 1.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83930	 1	 8.71	 2.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83931	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83932	 1	 30.18	 6.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83933	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83934	 1	 44.56	 10.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83935	 1	 31.3	 7.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83936	 1	 7.31	 3.42	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83937	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83938	 1	 6.11	 1.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83939	 1	 5.4	 1.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83940	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83941	 1	 7.52	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83942	 1	 4.79	 1.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83943	 1	 12.66	 2.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83944	 1	 2.72	 0.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83945	 1	 6.6	 1.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83946	 1	 9.04	 2.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83947	 1	 33.01	 7.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83948	 1	 2.45	 1.07	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83949	 1	 4.96	 1.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83950	 1	 19.5	 4.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83951	 1	 17.33	 7.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83952	 1	 7.03	 2.93	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83953	 1	 12.31	 2.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83954	 1	 26.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83955	 1	 29.73	 6.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83956	 1	 32.96	 10.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83957	 1	 52.49	 16.11	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83958	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83959	 1	 35.06	 11.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83960	 1	 4.18	 2.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83961	 1	 7.17	 2.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83962	 1	 17.27	 6.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83963	 1	 3.53	 1.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83964	 1	 17.98	 5.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83965	 1	 7.1	 2.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83966	 1	 27.63	 7.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83967	 1	 50.36	 18.05	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83968	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83969	 1	 43.9	 14.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83970	 1	 15.11	 3.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83971	 1	 11.51	 3.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83972	 1	 7.2	 3.01	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83973	 1	 11.37	 4.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83974	 1	 24.85	 6.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83975	 1	 12.51	 2.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83976	 1	 2.57	 1.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83977	 1	 241.78	 92.39	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83978	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83979	 1	 6.14	 3.18	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83980	 1	 13.4	 4.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83981	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83982	 1	 16.69	 6.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83983	 1	 27.67	 10.55	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83984	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	83985	 1	 18.56	 8.44	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83986	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83987	 1	 5.29	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83988	 1	 9.88	 3.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83989	 1	 18.6	 4.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83990	 1	 8.92	 4.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83991	 1	 25.38	 7.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83992	 1	 10.68	 4.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83993	 1	 10.62	 4.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83994	 1	 120.47	 46.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83995	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83996	 1	 9.05	 2.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83997	 1	 6.32	 2.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83998	 1	 47.56	 12.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83999	 1	 4.37	 1.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84000	 1	 3.9	 1.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84001	 1	 3.05	 1.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84002	 1	 4.33	 1.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84003	 1	 5.48	 2.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84004	 1	 5.42	 2.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84005	 1	 4.59	 2.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84006	 1	 4.96	 2.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84007	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84008	 1	 5.19	 2.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84009	 1	 11.49	 4.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84010	 1	 17.2	 6.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84011	 1	 62.2	 27.09	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84012	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84013	 1	 4.5	 2.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84014	 1	 2.53	 0.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84015	 1	 8.4	 3.3	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84016	 1	 41.31	 11.48	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84017	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84018	 1	 4.74	 2.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84019	 1	 13.87	 5.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84020	 1	 5.96	 2.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84021	 1	 8.62	 3.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84022	 1	 10.82	 4.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84023	 1	 5.04	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84024	 1	 4.13	 2.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84025	 1	 10.18	 3.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84026	 1	 4.87	 2.35	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84027	 1	 10.91	 4.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84028	 1	 8.99	 4.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84029	 1	 3.7	 1.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84030	 1	 6.0	 2.75	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84031	 1	 4.98	 2.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84032	 1	 6.16	 3.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84033	 1	 7.04	 2.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84034	 1	 7.28	 3.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84035	 1	 7.2	 2.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84036	 1	 6.27	 2.67	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84037	 1	 5.17	 1.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84038	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84039	 1	 3.81	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84040	 1	 6.79	 2.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84041	 1	 8.38	 3.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84042	 1	 4.18	 1.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84043	 1	 14.68	 6.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84044	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84045	 1	 54.86	 13.78	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84046	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84047	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84048	 1	 86.52	 30.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84049	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84050	 1	 26.41	 7.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84051	 1	 25.52	 9.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84052	 1	 42.53	 13.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84053	 1	 37.28	 12.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84054	 1	 11.4	 4.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84055	 1	 17.38	 6.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84056	 1	 9.99	 4.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84057	 1	 9.91	 3.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84058	 1	 13.12	 4.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84059	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84060	 1	 24.86	 8.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84061	 1	 8.35	 3.82	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84062	 1	 9.31	 4.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84063	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84064	 1	 12.86	 6.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84065	 1	 13.79	 3.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84066	 1	 11.21	 3.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84067	 1	 151.69	 38.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84068	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84069	 1	 16.3	 6.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84070	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84071	 1	 25.97	 8.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84072	 1	 22.63	 9.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84073	 1	 16.9	 4.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84074	 1	 15.68	 6.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84075	 1	 17.38	 6.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84076	 1	 9.27	 2.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84077	 1	 26.84	 8.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84078	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84079	 1	 30.17	 6.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84080	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84081	 1	 37.89	 8.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84082	 1	 29.47	 6.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84083	 1	 5.76	 1.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84084	 1	 9.8	 2.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84085	 1	 15.2	 3.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84086	 1	 93.01	 28.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84087	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84088	 1	 29.2	 7.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84089	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84090	 1	 16.24	 5.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84091	 1	 13.28	 4.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84092	 1	 4.33	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84093	 1	 5.39	 2.61	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84094	 1	 18.14	 6.9	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84095	 1	 18.91	 6.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84096	 1	 16.9	 7.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84097	 1	 16.75	 6.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84098	 1	 8.15	 3.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84099	 1	 10.26	 3.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84100	 1	 18.98	 6.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84101	 1	 16.62	 5.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84102	 1	 13.06	 3.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84103	 1	 7.14	 2.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84104	 1	 33.02	 10.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84105	 1	 7.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84106	 1	 30.88	 9.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84107	 1	 5.81	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84108	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84109	 1	 8.06	 3.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84110	 1	 5.98	 3.06	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84111	 1	 11.9	 5.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84112	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84113	 1	 10.32	 4.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84114	 1	 15.67	 4.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84115	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84116	 1	 8.79	 4.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84117	 1	 5.74	 2.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84118	 1	 17.84	 6.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84119	 1	 16.12	 5.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84120	 1	 6.17	 2.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84121	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84122	 1	 25.95	 9.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84123	 1	 9.6	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84124	 1	 7.8	 3.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84125	 1	 6.36	 2.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84126	 1	 15.36	 5.27	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84127	 1	 38.66	 11.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84128	 1	 21.31	 5.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84129	 1	 53.69	 15.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84130	 1	 26.48	 8.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84131	 1	 18.02	 7.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84132	 1	 5.17	 2.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84133	 1	 5.98	 3.04	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84134	 1	 6.14	 3.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84135	 1	 12.45	 4.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84136	 1	 9.81	 5.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84137	 1	 10.27	 3.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84138	 1	 14.28	 4.44	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84139	 1	 21.63	 10.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84140	 1	 57.66	 16.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84141	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84142	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84143	 1	 8.88	 3.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84144	 1	 33.52	 11.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84145	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84146	 1	 20.45	 8.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84147	 1	 76.42	 29.53	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84148	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84149	 1	 7.71	 3.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84150	 1	 18.73	 7.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84151	 1	 34.77	 11.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84152	 1	 9.35	 3.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84153	 1	 12.91	 2.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84154	 1	 13.18	 3.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84155	 1	 23.96	 5.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84156	 1	 12.84	 2.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84157	 1	 13.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84158	 1	 9.33	 2.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84159	 1	 9.16	 2.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84160	 1	 9.35	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84161	 1	 3.16	 1.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84162	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84163	 1	 2.96	 0.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84164	 1	 7.65	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84165	 1	 28.53	 6.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84166	 1	 30.76	 6.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84167	 1	 65.2	 21.76	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84168	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84169	 1	 23.11	 10.63	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84170	 1	 7.58	 3.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84171	 1	 4.28	 1.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84172	 1	 16.13	 6.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84173	 1	 22.08	 7.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84174	 1	 7.25	 3.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84175	 1	 26.35	 7.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84176	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84177	 1	 15.05	 5.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84178	 1	 11.85	 4.06	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84179	 1	 30.18	 9.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84180	 1	 11.96	 4.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84181	 1	 11.04	 4.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84182	 1	 26.59	 8.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84183	 1	 34.05	 8.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84184	 1	 8.4	 3.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84185	 1	 5.09	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84186	 1	 9.52	 4.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84187	 1	 18.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84188	 1	 43.19	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84189	 1	 27.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84190	 1	 2.96	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84191	 1	 18.02	 7.65	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84192	 1	 5.92	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84193	 1	 9.38	 3.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84194	 1	 4.88	 2.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84195	 1	 30.47	 9.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84196	 1	 22.81	 8.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84197	 1	 3.2	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84198	 1	 6.87	 2.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84199	 1	 13.21	 3.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84200	 1	 1.79	 0.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84201	 1	 15.28	 3.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84202	 1	 31.83	 10.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84203	 1	 5.75	 2.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84204	 1	 25.87	 8.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84205	 1	 6.06	 2.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84206	 1	 6.12	 2.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84207	 1	 2.88	 1.18	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84208	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84209	 1	 4.84	 1.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84210	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84211	 1	 2.96	 1.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84212	 1	 7.55	 3.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84213	 1	 5.45	 2.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84214	 1	 57.07	 14.9	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84215	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84216	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84217	 1	 8.85	 3.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84218	 1	 24.44	 7.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84219	 1	 7.95	 3.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84220	 1	 11.3	 3.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84221	 1	 4.28	 1.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84222	 1	 7.19	 3.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84223	 1	 20.0	 6.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84224	 1	 23.34	 6.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84225	 1	 5.38	 2.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84226	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84227	 1	 10.7	 4.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84228	 1	 81.98	 25.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84229	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84230	 1	 27.59	 11.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84231	 1	 2.58	 1.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84232	 1	 17.11	 3.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84233	 1	 25.69	 6.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84234	 1	 16.12	 3.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84235	 1	 5.47	 1.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84236	 1	 1.35	 0.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84237	 1	 3.44	 0.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84238	 1	 4.72	 1.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84239	 1	 10.06	 2.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84240	 1	 6.7	 1.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84241	 1	 10.07	 3.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84242	 1	 10.77	 2.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84243	 1	 6.53	 2.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84244	 1	 25.81	 11.94	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84245	 1	 15.21	 5.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84246	 1	 13.02	 4.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84247	 1	 13.16	 5.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84248	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84249	 1	 16.92	 6.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84250	 1	 3.8	 0.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84251	 1	 24.12	 5.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84252	 1	 14.24	 5.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84253	 1	 14.92	 6.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84254	 1	 9.82	 2.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84255	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84256	 1	 17.2	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84257	 1	 13.52	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84258	 1	 23.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84259	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84260	 1	 10.89	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84261	 1	 11.67	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84262	 1	 9.84	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84263	 1	 32.36	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84264	 1	 16.21	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84265	 1	 14.41	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84266	 1	 16.06	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84267	 1	 25.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84268	 1	 7.31	 3.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84269	 1	 5.15	 2.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84270	 1	 5.8	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84271	 1	 5.2	 2.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84272	 1	 7.08	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84273	 1	 16.36	 3.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84274	 1	 8.76	 1.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84275	 1	 12.38	 2.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84276	 1	 2.14	 0.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84277	 1	 8.91	 2.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84278	 1	 30.07	 6.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84279	 1	 20.89	 4.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84280	 1	 30.33	 6.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84281	 1	 24.53	 5.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84282	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84283	 1	 46.68	 10.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84284	 1	 24.33	 5.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84285	 1	 16.66	 3.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84286	 1	 8.84	 1.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84287	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84288	 1	 6.62	 2.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84289	 1	 4.38	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84290	 1	 8.97	 3.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84291	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84292	 1	 3.04	 1.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84293	 1	 3.27	 1.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84294	 1	 17.85	 7.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84295	 1	 40.3	 9.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84296	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84297	 1	 26.32	 8.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84298	 1	 3.6	 1.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84299	 1	 4.32	 2.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84300	 1	 11.42	 4.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84301	 1	 17.83	 7.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84302	 1	 33.89	 10.63	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84303	 1	 8.16	 2.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84304	 1	 13.12	 5.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84305	 1	 7.11	 2.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84306	 1	 5.48	 2.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84307	 1	 5.55	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84308	 1	 17.19	 6.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84309	 1	 14.65	 5.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84310	 1	 9.11	 3.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84311	 1	 4.24	 1.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84312	 1	 4.99	 2.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84313	 1	 10.34	 3.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84314	 1	 12.34	 4.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84315	 1	 5.17	 1.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84316	 1	 12.97	 5.34	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84317	 1	 17.38	 6.96	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84318	 1	 6.08	 2.55	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84319	 1	 10.69	 4.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84320	 1	 15.43	 6.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84321	 1	 10.55	 4.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84322	 1	 10.67	 4.97	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84323	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84324	 1	 8.86	 3.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84325	 1	 14.03	 5.71	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84326	 1	 35.22	 13.61	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84327	 1	 19.19	 7.9	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84328	 1	 4.89	 1.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84329	 1	 40.25	 14.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84330	 1	 1.98	 0.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84331	 1	 11.2	 3.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84332	 1	 6.73	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84333	 1	 11.5	 5.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84334	 1	 9.84	 4.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84335	 1	 18.13	 6.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84336	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84337	 1	 9.32	 4.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84338	 1	 5.78	 1.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84339	 1	 10.26	 4.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84340	 1	 6.09	 2.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84341	 1	 12.69	 2.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84342	 1	 10.54	 2.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84343	 1	 18.31	 4.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84344	 1	 14.52	 3.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84345	 1	 32.44	 7.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84346	 1	 22.37	 5.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84347	 1	 15.87	 3.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84348	 1	 16.38	 3.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84349	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84350	 1	 17.71	 7.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84351	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84352	 1	 13.15	 4.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84353	 1	 18.64	 6.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84354	 1	 7.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84355	 1	 6.18	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84356	 1	 17.79	 5.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84357	 1	 11.37	 4.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84358	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84359	 1	 27.42	 9.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84360	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84361	 1	 15.1	 4.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84362	 1	 4.83	 1.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84363	 1	 5.16	 2.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84364	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	84365	 1	 18.76	 6.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84366	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84367	 1	 2.78	 1.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84368	 1	 11.25	 3.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84369	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84370	 1	 13.08	 4.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84371	 1	 7.04	 2.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84372	 1	 26.98	 8.28	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84373	 1	 34.44	 7.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84374	 1	 14.65	 5.84	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84375	 1	 17.51	 6.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84376	 1	 18.39	 6.78	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84377	 1	 19.3	 5.87	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84378	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84379	 1	 6.45	 2.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84380	 1	 5.54	 2.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84381	 1	 10.61	 3.63	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84382	 1	 3.49	 1.53	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84383	 1	 5.54	 2.55	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84384	 1	 121.35	 30.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84385	 1	 108.61	 34.99	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84386	 1	 17.86	 7.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84387	 1	 22.88	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84388	 1	 9.85	 2.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84389	 1	 1.98	 0.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84390	 1	 17.29	 3.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84391	 1	 5.36	 2.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84392	 1	 18.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84393	 1	 24.09	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84394	 1	 14.49	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84395	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84396	 1	 13.58	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84397	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84398	 1	 36.88	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84399	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84400	 1	 31.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84401	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84402	 1	 38.84	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84403	 1	 21.92	 7.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84404	 1	 3.89	 1.81	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84405	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84406	 1	 13.8	 4.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84407	 1	 15.14	 6.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84408	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84409	 1	 18.89	 7.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84410	 1	 27.73	 10.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84411	 1	 2.65	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84412	 1	 9.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84413	 1	 6.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84414	 1	 3.27	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84415	 1	 7.91	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84416	 1	 33.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84417	 1	 6.52	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84418	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84419	 1	 13.5	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84420	 1	 15.92	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84421	 1	 16.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84422	 1	 19.64	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84423	 1	 7.31	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84424	 1	 4.01	 1.89	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84425	 1	 29.59	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84426	 1	 8.67	 3.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84427	 1	 17.07	 6.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84428	 1	 6.49	 2.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84429	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84430	 1	 9.77	 3.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84431	 1	 6.97	 2.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84432	 1	 5.5	 2.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84433	 1	 25.26	 8.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84434	 1	 56.63	 22.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84435	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84436	 1	 33.6	 10.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84437	 1	 22.52	 4.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84438	 1	 29.75	 9.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84439	 1	 30.48	 9.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84440	 1	 23.49	 6.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84441	 1	 6.98	 3.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84442	 1	 5.88	 2.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84443	 1	 5.85	 2.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84444	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	84445	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84446	 1	 9.24	 3.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84447	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84448	 1	 10.78	 4.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84449	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84450	 1	 18.39	 6.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84451	 1	 7.92	 2.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84452	 1	 15.51	 3.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84453	 1	 24.77	 5.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84454	 1	 17.26	 3.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84455	 1	 8.25	 1.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84456	 1	 27.76	 6.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84457	 1	 22.18	 4.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84458	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84459	 1	 10.16	 3.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84460	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84461	 1	 19.37	 6.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84462	 1	 19.05	 7.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84463	 1	 36.54	 12.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84464	 1	 132.42	 25.55	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84465	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84466	 1	 33.8	 8.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84467	 1	 7.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84468	 1	 3.72	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84469	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84470	 1	 7.51	 2.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84471	 1	 6.09	 2.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84472	 1	 10.16	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84473	 1	 7.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84474	 1	 19.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84475	 1	 17.95	 6.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84476	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84477	 1	 21.7	 8.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84478	 1	 48.71	 19.35	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84479	 1	 47.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84480	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84481	 1	 14.72	 5.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84482	 1	 6.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84483	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84484	 1	 8.99	 3.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84485	 1	 44.06	 14.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84486	 1	 16.54	 4.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84487	 1	 6.12	 2.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84488	 1	 4.95	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84489	 1	 10.72	 3.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84490	 1	 14.88	 4.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84491	 1	 28.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84492	 1	 39.59	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84493	 1	 5.07	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84494	 1	 8.17	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84495	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84496	 1	 13.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84497	 1	 37.31	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84498	 1	 15.85	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84499	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84500	 1	 5.8	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84501	 1	 16.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84502	 1	 88.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84503	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84504	 1	 6.64	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84505	 1	 5.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84506	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84507	 1	 19.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84508	 1	 6.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84509	 1	 7.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84510	 1	 18.16	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84511	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84512	 1	 9.89	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84513	 1	 16.41	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84514	 1	 3.07	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84515	 1	 9.26	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84516	 1	 20.93	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84517	 1	 11.95	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84518	 1	 4.87	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84519	 1	 4.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84520	 1	 9.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84521	 1	 28.81	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84522	 1	 4.56	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84523	 1	 8.84	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84524	 1	 11.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84525	 1	 6.88	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84526	 1	 8.02	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84527	 1	 43.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84528	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84529	 1	 24.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84530	 1	 10.68	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84531	 1	 5.95	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84532	 1	 28.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84533	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84534	 1	 20.07	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84535	 1	 15.54	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84536	 1	 10.85	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84537	 1	 129.19	 35.83	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84538	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84539	 1	 7.49	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84540	 1	 42.61	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84541	 1	 12.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84542	 1	 13.01	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84543	 1	 18.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84544	 1	 10.58	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84545	 1	 2.98	 0.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84546	 1	 9.81	 2.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84547	 1	 32.95	 7.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84548	 1	 14.46	 3.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84549	 1	 5.78	 1.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84550	 1	 25.87	 6.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84551	 1	 18.59	 4.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84552	 1	 43.06	 9.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84553	 1	 10.15	 2.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84554	 1	 12.71	 2.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84555	 1	 15.91	 3.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84556	 1	 21.28	 4.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84557	 1	 15.65	 3.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84558	 1	 10.1	 2.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84559	 1	 14.72	 3.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84560	 1	 10.37	 2.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84561	 1	 4.83	 1.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84562	 1	 8.57	 1.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84563	 1	 10.6	 2.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84564	 1	 13.63	 3.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84565	 1	 12.63	 3.38	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84566	 1	 27.49	 11.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84567	 1	 52.39	 13.06	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84568	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84569	 1	 17.85	 5.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84570	 1	 11.53	 4.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84571	 1	 6.59	 2.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84572	 1	 21.2	 6.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84573	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84574	 1	 22.03	 4.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84575	 1	 69.02	 19.89	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84576	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84577	 1	 18.28	 5.26	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84578	 1	 9.28	 3.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84579	 1	 23.93	 8.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84580	 1	 21.36	 6.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84581	 1	 22.26	 6.6	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84582	 1	 4.26	 2.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84583	 1	 6.85	 2.27	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84584	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84585	 1	 28.39	 9.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84586	 1	 24.89	 8.44	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84587	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84588	 1	 34.1	 15.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84589	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84590	 1	 10.9	 4.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84591	 1	 11.36	 3.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84592	 1	 31.68	 10.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84593	 1	 19.17	 9.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84594	 1	 19.39	 6.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84595	 1	 21.84	 8.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84596	 1	 9.33	 3.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84597	 1	 49.32	 13.98	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84598	 1	 6.09	 2.87	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84599	 1	 10.2	 3.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84600	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84601	 1	 47.37	 11.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84602	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84603	 1	 25.03	 7.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84604	 1	 8.76	 4.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84605	 1	 6.64	 2.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84606	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84607	 1	 19.71	 4.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84608	 1	 21.58	 7.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84609	 1	 38.79	 11.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84610	 1	 9.08	 3.53	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84611	 1	 10.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84612	 1	 5.04	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84613	 1	 31.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84614	 1	 7.08	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84615	 1	 18.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84616	 1	 8.57	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84617	 1	 3.8	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84618	 1	 5.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84619	 1	 6.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84620	 1	 2.35	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84621	 1	 12.04	 2.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84622	 1	 33.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84623	 1	 7.37	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84624	 1	 15.01	 5.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84625	 1	 44.82	 10.51	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84626	 1	 4.97	 2.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84627	 1	 6.93	 2.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84628	 1	 37.84	 10.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84629	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84630	 1	 44.14	 15.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84631	 1	 13.59	 5.33	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84632	 1	 14.7	 4.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84633	 1	 8.78	 3.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84634	 1	 28.41	 9.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84635	 1	 5.46	 2.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84636	 1	 11.11	 4.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84637	 1	 22.61	 9.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84638	 1	 13.56	 3.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84639	 1	 28.87	 6.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84640	 1	 5.68	 1.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84641	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84642	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84643	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84644	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84645	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84646	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84647	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84648	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84649	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84650	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84651	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84652	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84653	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84654	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84655	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84656	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84657	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84658	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84659	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84660	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84661	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84662	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84663	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84664	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84665	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84666	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84667	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84668	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84669	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84670	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84671	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84672	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84673	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84674	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84675	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84676	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84677	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84678	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84679	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84680	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84681	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84682	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84683	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84684	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84685	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84686	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84687	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84688	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84689	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84690	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84691	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84692	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84693	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84694	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84695	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84696	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84697	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84698	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84699	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84700	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84701	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84702	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84703	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84704	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84705	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84706	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84707	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84708	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84709	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84710	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84711	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84712	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84713	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84714	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84715	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84716	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84717	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84718	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84719	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84720	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84721	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84722	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84723	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84724	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84725	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84726	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84727	 1	 5.81	 3.58	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84728	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84729	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84730	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84731	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84732	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84733	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84734	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84735	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84736	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84737	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84738	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84739	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84740	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84741	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84742	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84743	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84744	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84745	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84746	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84747	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84748	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84749	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84750	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84751	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84752	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84753	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84754	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84755	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84756	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84757	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84758	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84759	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84760	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84761	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84762	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84763	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84764	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84765	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84766	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84767	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84768	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84769	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84770	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84771	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84772	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84773	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84774	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84775	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84776	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84777	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84778	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84779	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84780	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84781	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84782	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84783	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84784	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84785	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84786	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84787	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84788	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84789	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84790	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84791	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84792	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84793	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84794	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84795	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84796	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84797	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84798	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84799	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84800	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84801	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84802	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84803	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84804	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84805	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84806	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84807	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84808	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84809	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84810	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84811	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84812	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84813	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84814	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84815	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84816	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84817	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84818	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84819	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84820	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84821	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84822	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84823	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84824	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84825	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84826	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84827	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84828	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84829	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84830	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84831	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84832	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84833	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84834	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84835	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84836	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84837	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84838	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84839	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84840	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84841	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84842	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84843	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84844	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84845	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84846	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84847	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84848	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84849	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84850	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84851	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84852	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84853	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84854	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84855	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84856	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84857	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84858	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84859	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84860	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84861	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84862	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84863	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84864	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84865	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84866	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84867	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84868	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84869	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84870	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84871	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84872	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84873	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84874	 2	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84875	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84876	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84877	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84878	 1	 33.79	 15.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84879	 1	 22.66	 11.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84880	 1	 12.77	 7.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84881	 1	 12.21	 7.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84882	 1	 11.09	 6.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84883	 1	 13.55	 8.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84884	 1	 3.59	 1.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84885	 1	 8.64	 5.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84886	 1	 8.27	 4.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84887	 1	 17.89	 11.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84888	 1	 11.65	 5.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84889	 1	 11.06	 6.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84890	 1	 13.75	 6.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84891	 1	 12.27	 7.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84892	 1	 41.84	 19.86	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84893	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84894	 1	 32.56	 17.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84895	 1	 30.34	 17.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84896	 1	 14.61	 7.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84897	 1	 9.49	 4.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84898	 1	 3.98	 2.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84899	 1	 17.08	 8.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84900	 1	 20.26	 10.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84901	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84902	 1	 30.72	 14.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84903	 1	 6.89	 3.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84904	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84905	 1	 13.06	 6.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84906	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84907	 1	 20.22	 11.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84908	 1	 14.44	 8.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84909	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84910	 1	 8.0	 4.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84911	 1	 10.53	 5.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84912	 1	 7.76	 4.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84913	 1	 33.32	 18.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84914	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84915	 1	 8.44	 5.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84916	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84917	 1	 10.11	 5.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84918	 1	 7.99	 4.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84919	 1	 24.4	 12.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84920	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84921	 1	 15.33	 8.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84922	 1	 13.55	 7.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84923	 1	 16.44	 8.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84924	 1	 157.56	 91.73	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84925	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84926	 1	 26.47	 13.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84927	 1	 27.76	 11.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84928	 1	 11.19	 5.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84929	 1	 10.43	 5.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84930	 1	 13.41	 6.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84931	 1	 11.42	 5.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84932	 1	 7.16	 3.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84933	 1	 13.09	 7.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84934	 1	 22.49	 11.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84935	 1	 8.73	 4.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84936	 1	 13.02	 6.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84937	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84938	 1	 16.21	 7.73	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84939	 1	 16.19	 9.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84940	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84941	 1	 6.35	 3.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84942	 1	 9.06	 4.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84943	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84944	 1	 14.73	 7.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84945	 1	 6.03	 3.29	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84946	 1	 25.03	 14.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84947	 1	 6.96	 3.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84948	 1	 18.68	 4.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84949	 1	 8.99	 2.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84950	 1	 6.14	 1.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84951	 1	 28.95	 6.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84952	 1	 13.49	 3.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84953	 1	 11.94	 2.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84954	 1	 15.36	 3.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84955	 1	 10.04	 2.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84956	 1	 8.11	 1.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84957	 1	 7.95	 1.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84958	 1	 3.81	 0.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84959	 1	 7.01	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84960	 1	 15.33	 3.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84961	 1	 13.16	 3.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84962	 1	 9.41	 2.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84963	 1	 10.59	 2.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84964	 1	 15.13	 3.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84965	 1	 9.21	 2.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84966	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84967	 1	 51.38	 22.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84968	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84969	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84970	 1	 24.91	 6.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84971	 1	 27.15	 6.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84972	 1	 5.77	 1.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84973	 1	 9.5	 5.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84974	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84975	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84976	 1	 7.04	 4.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84977	 1	 69.78	 32.77	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84978	 1	 15.15	 8.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84979	 1	 22.09	 5.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84980	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	84981	 1	 41.43	 17.71	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84982	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84983	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84984	 1	 14.61	 9.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84985	 1	 10.7	 2.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84986	 1	 11.75	 2.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84987	 1	 15.93	 3.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84988	 1	 14.5	 3.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84989	 1	 6.76	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84990	 1	 5.2	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84991	 1	 8.28	 2.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84992	 1	 4.9	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84993	 1	 6.6	 1.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84994	 1	 6.87	 3.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84995	 1	 23.75	 5.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84996	 1	 7.77	 1.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84997	 1	 13.38	 3.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84998	 1	 12.11	 2.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84999	 1	 44.87	 24.37	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85000	 1	 18.79	 4.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85001	 1	 10.45	 2.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85002	 1	 22.8	 5.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85003	 1	 16.93	 4.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85004	 1	 6.8	 3.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85005	 1	 8.76	 2.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85006	 1	 6.67	 3.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85007	 1	 21.65	 9.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85008	 1	 109.08	 61.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85009	 1	 10.43	 6.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85010	 1	 7.52	 3.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85011	 1	 13.13	 7.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85012	 1	 9.58	 4.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85013	 1	 14.74	 3.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85014	 1	 9.65	 2.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85015	 1	 8.24	 4.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85016	 1	 13.24	 6.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85017	 1	 6.58	 3.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85018	 1	 8.87	 2.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85019	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85020	 1	 26.9	 15.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85021	 1	 10.9	 2.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85022	 1	 13.18	 3.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85023	 1	 17.34	 4.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85024	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85025	 1	 31.57	 18.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85026	 1	 14.43	 3.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85027	 1	 16.07	 3.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85028	 1	 56.38	 29.73	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85029	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85030	 1	 29.27	 15.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85031	 1	 17.37	 9.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85032	 1	 10.24	 5.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85033	 1	 17.57	 9.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85034	 1	 13.89	 8.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85035	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85036	 1	 32.26	 17.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85037	 1	 11.28	 2.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85038	 1	 9.03	 5.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85039	 1	 26.5	 6.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85040	 1	 10.43	 5.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85041	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85042	 1	 29.31	 13.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85043	 1	 13.2	 7.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85044	 1	 28.13	 15.51	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85045	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85046	 1	 10.67	 5.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85047	 1	 18.71	 9.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85048	 1	 5.47	 3.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85049	 1	 2.54	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85050	 1	 8.63	 5.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85051	 1	 14.15	 7.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85052	 1	 18.95	 8.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85053	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85054	 1	 11.32	 6.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85055	 1	 10.28	 5.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85056	 1	 13.77	 6.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85057	 1	 88.52	 47.62	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85058	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85059	 1	 17.99	 10.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85060	 1	 18.68	 9.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85061	 1	 14.03	 6.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85062	 1	 26.79	 15.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85063	 1	 41.77	 16.04	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85064	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85065	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85066	 1	 13.34	 3.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85067	 1	 62.36	 32.73	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85068	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85069	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85070	 1	 19.35	 4.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85071	 1	 29.69	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85072	 1	 6.79	 3.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85073	 1	 31.49	 15.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85074	 1	 14.02	 7.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85075	 1	 5.51	 3.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85076	 1	 11.97	 6.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85077	 1	 15.17	 6.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85078	 1	 15.67	 9.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85079	 1	 12.56	 6.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85080	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	85081	 1	 15.86	 9.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85082	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85083	 1	 11.95	 6.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85084	 1	 73.27	 38.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85085	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85086	 1	 26.58	 11.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85087	 1	 9.11	 5.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85088	 1	 7.29	 4.31	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85089	 1	 8.88	 4.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85090	 1	 27.22	 12.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85091	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85092	 1	 13.63	 5.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85093	 1	 11.47	 5.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85094	 1	 70.24	 39.89	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85095	 1	 42.03	 21.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85096	 1	 55.33	 27.75	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85097	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85098	 1	 17.43	 9.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85099	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85100	 1	 7.94	 3.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85101	 1	 8.01	 4.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85102	 1	 7.55	 4.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85103	 1	 8.4	 5.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85104	 1	 5.5	 2.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85105	 1	 17.78	 8.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85106	 1	 105.12	 55.81	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85107	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85108	 1	 60.25	 33.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85109	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85110	 1	 33.08	 14.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85111	 1	 12.24	 6.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85112	 1	 22.04	 10.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85113	 1	 3.56	 2.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85114	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	85115	 1	 192.47	 87.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85116	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85117	 1	 13.27	 6.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85118	 1	 21.82	 10.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85119	 1	 28.57	 11.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85120	 1	 35.06	 14.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85121	 1	 6.59	 3.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85122	 1	 10.85	 6.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85123	 1	 26.44	 6.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85124	 1	 20.46	 8.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85125	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85126	 1	 31.75	 15.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85127	 1	 14.64	 6.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85128	 1	 23.19	 13.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85129	 1	 12.12	 6.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85130	 1	 23.56	 11.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85131	 1	 9.98	 5.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85132	 1	 7.02	 3.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85133	 1	 11.41	 6.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85134	 1	 11.48	 7.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85135	 1	 13.21	 7.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85136	 1	 5.9	 3.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85137	 1	 11.19	 6.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85138	 1	 12.46	 5.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85139	 1	 14.04	 8.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85140	 1	 18.23	 8.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85141	 1	 15.26	 7.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85142	 1	 20.07	 8.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85143	 1	 28.29	 11.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85144	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85145	 1	 28.49	 12.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85146	 1	 27.5	 12.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85147	 1	 8.88	 4.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85148	 1	 11.98	 4.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85149	 1	 13.59	 7.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85150	 1	 7.78	 4.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85151	 1	 67.99	 36.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85152	 1	 93.69	 41.91	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85153	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85154	 1	 30.49	 12.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85155	 1	 40.79	 20.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85156	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85157	 1	 15.41	 6.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85158	 1	 23.4	 12.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85159	 1	 22.56	 12.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85160	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85161	 1	 17.12	 7.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85162	 1	 30.26	 17.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85163	 1	 24.81	 13.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85164	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85165	 1	 7.9	 1.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85166	 1	 10.97	 2.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85167	 1	 8.07	 1.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85168	 1	 10.55	 2.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85169	 1	 8.23	 1.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85170	 1	 34.47	 7.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85171	 1	 8.55	 1.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85172	 1	 12.82	 5.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85173	 1	 15.03	 8.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85174	 1	 11.44	 6.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85175	 1	 16.79	 8.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85176	 1	 12.96	 6.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85177	 1	 10.63	 5.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85178	 1	 4.37	 2.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85179	 1	 20.75	 10.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85180	 1	 12.1	 6.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85181	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85182	 1	 16.4	 9.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85183	 1	 27.66	 14.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85184	 1	 8.35	 4.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85185	 1	 20.7	 11.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85186	 1	 14.66	 8.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85187	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85188	 1	 23.96	 12.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85189	 1	 6.91	 4.14	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85190	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85191	 1	 7.77	 4.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85192	 1	 8.39	 4.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85193	 1	 10.33	 5.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85194	 1	 3.29	 1.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85195	 1	 7.77	 4.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85196	 1	 7.06	 4.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85197	 1	 23.65	 8.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85198	 1	 10.46	 5.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85199	 1	 7.94	 3.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85200	 1	 4.92	 3.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85201	 1	 4.96	 2.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85202	 1	 4.77	 2.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85203	 1	 5.49	 3.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85204	 1	 3.72	 2.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85205	 1	 3.01	 1.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85206	 1	 8.04	 4.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85207	 1	 6.22	 3.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85208	 1	 21.79	 12.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85209	 1	 11.49	 6.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85210	 1	 17.71	 9.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85211	 1	 9.49	 5.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85212	 1	 23.05	 12.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85213	 1	 12.12	 5.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85214	 1	 14.52	 7.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85215	 1	 10.85	 6.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85216	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85217	 1	 24.2	 10.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85218	 1	 5.29	 2.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85219	 1	 6.45	 3.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85220	 1	 22.14	 12.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85221	 1	 6.73	 4.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85222	 1	 3.86	 1.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85223	 1	 7.87	 3.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85224	 1	 8.69	 4.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85225	 1	 6.19	 3.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85226	 1	 19.54	 10.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85227	 1	 10.94	 6.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85228	 1	 16.99	 8.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85229	 1	 3.92	 2.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85230	 1	 36.5	 19.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85231	 1	 98.34	 48.49	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85232	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85233	 1	 33.61	 16.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85234	 1	 1.14	 0.63	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85235	 1	 2.17	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85236	 1	 2.97	 1.51	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85237	 1	 3.19	 1.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85238	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85239	 1	 12.59	 5.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85240	 1	 11.77	 5.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85241	 1	 11.45	 5.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85242	 1	 22.0	 11.88	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85243	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	85244	 1	 232.74	 107.78	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85245	 1	 10.11	 4.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85246	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85247	 1	 9.91	 5.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85248	 1	 8.34	 4.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85249	 1	 5.14	 2.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85250	 1	 2.47	 1.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85251	 1	 8.79	 4.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85252	 1	 6.03	 3.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85253	 1	 49.62	 22.22	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85254	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85255	 1	 55.83	 24.56	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85256	 1	 5.65	 3.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85257	 1	 14.29	 5.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85258	 1	 9.51	 5.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85259	 1	 10.82	 2.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85260	 1	 9.02	 4.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85261	 1	 20.82	 10.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85262	 1	 32.16	 16.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85263	 1	 6.18	 3.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85264	 1	 18.77	 10.19	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85265	 1	 10.63	 4.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85266	 1	 10.44	 4.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85267	 1	 13.61	 6.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85268	 1	 6.79	 3.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85269	 1	 24.03	 13.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85270	 1	 10.18	 5.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85271	 1	 10.26	 5.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85272	 1	 15.05	 7.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85273	 1	 19.57	 8.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85274	 1	 7.07	 3.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85275	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	85276	 1	 65.4	 29.9	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85277	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85278	 1	 11.82	 6.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85279	 1	 1.29	 0.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85280	 1	 41.46	 17.73	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85281	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85282	 1	 9.05	 4.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85283	 1	 8.09	 4.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85284	 1	 14.16	 7.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85285	 1	 8.97	 4.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85286	 1	 13.61	 7.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85287	 1	 31.64	 18.04	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85288	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85289	 1	 10.59	 6.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85290	 1	 52.09	 25.8	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85291	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85292	 1	 13.3	 6.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85293	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85294	 1	 5.2	 2.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85295	 1	 15.9	 7.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85296	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85297	 1	 5.68	 3.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85298	 1	 9.48	 4.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85299	 1	 7.92	 4.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85300	 1	 10.4	 6.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85301	 1	 9.09	 5.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85302	 1	 8.64	 4.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85303	 1	 8.7	 4.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85304	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85305	 1	 7.23	 3.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85306	 1	 32.34	 13.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85307	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85308	 1	 126.96	 66.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85309	 1	 10.61	 4.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85310	 1	 9.16	 4.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85311	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85312	 1	 21.28	 7.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85313	 1	 4.43	 2.37	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	85314	 1	 8.8	 5.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85315	 1	 7.11	 3.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85316	 1	 7.43	 4.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85317	 1	 11.01	 5.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85318	 1	 7.97	 4.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85319	 1	 2.16	 1.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85320	 1	 8.13	 4.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85321	 1	 6.82	 3.98	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	85322	 1	 6.98	 4.23	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85323	 1	 3.12	 1.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85324	 1	 4.03	 2.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85325	 1	 3.1	 1.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85326	 1	 1.03	 0.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85327	 1	 7.05	 3.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85328	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85329	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85330	 1	 5.93	 3.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85331	 1	 3.86	 2.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85332	 1	 12.03	 6.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85333	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85334	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85335	 1	 20.45	 4.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85336	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	85337	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85338	 1	 13.74	 6.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85339	 1	 11.73	 6.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85340	 1	 4.18	 2.41	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85341	 1	 1.78	 0.97	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85342	 1	 2.01	 0.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85343	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85344	 1	 13.93	 7.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85345	 1	 7.03	 3.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85346	 1	 4.92	 2.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85347	 1	 7.34	 3.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85348	 1	 7.68	 3.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85349	 1	 9.8	 4.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85350	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	85351	 1	 5.5	 2.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85352	 1	 5.05	 2.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85353	 1	 16.64	 3.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85354	 1	 20.29	 4.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85355	 1	 9.63	 5.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85356	 1	 15.91	 8.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85357	 1	 8.48	 4.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85358	 1	 7.87	 3.76	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85359	 1	 8.0	 4.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85360	 1	 17.37	 8.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85361	 1	 11.26	 4.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85362	 1	 6.44	 3.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85363	 1	 3.73	 2.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85364	 1	 17.66	 4.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85365	 1	 16.26	 3.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85366	 1	 3.68	 0.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85367	 1	 5.24	 2.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85368	 1	 17.54	 10.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85369	 1	 1.98	 0.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85370	 1	 17.74	 8.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85371	 1	 21.42	 11.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85372	 1	 11.54	 2.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85373	 1	 2.65	 0.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85374	 1	 11.53	 6.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85375	 1	 7.15	 4.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85376	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85377	 1	 16.13	 8.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85378	 1	 32.17	 7.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85379	 1	 19.54	 11.33	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85380	 1	 19.36	 8.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85381	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	85382	 1	 5.42	 2.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85383	 1	 4.25	 2.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85384	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	85385	 1	 39.7	 18.38	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85386	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85387	 1	 30.96	 7.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85388	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	85389	 1	 44.77	 21.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85390	 1	 39.52	 17.21	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85391	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85392	 1	 27.68	 11.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85393	 1	 8.37	 4.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85394	 1	 21.86	 5.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85395	 1	 23.95	 5.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85396	 1	 22.71	 5.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85397	 1	 9.18	 4.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85398	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85399	 1	 32.12	 14.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85400	 1	 27.7	 6.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85401	 1	 29.1	 6.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85402	 1	 4.18	 0.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85403	 1	 12.48	 2.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85404	 1	 7.47	 1.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85405	 1	 6.0	 3.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85406	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85407	 1	 8.54	 4.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85408	 1	 15.42	 7.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85409	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85410	 1	 11.29	 5.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85411	 1	 11.44	 2.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85412	 1	 20.67	 11.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85413	 1	 6.82	 3.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85414	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85415	 1	 32.1	 15.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85416	 1	 7.57	 4.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85417	 1	 6.34	 2.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85418	 1	 21.71	 5.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85419	 1	 3.78	 0.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85420	 1	 10.71	 2.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85421	 1	 18.58	 4.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85422	 1	 14.31	 6.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85423	 1	 26.82	 13.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85424	 1	 16.14	 9.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85425	 1	 18.55	 9.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85426	 1	 14.93	 7.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85427	 1	 6.39	 3.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85428	 1	 21.1	 11.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85429	 1	 15.72	 9.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85430	 1	 30.22	 12.98	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85431	 1	 7.15	 3.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85432	 1	 8.47	 4.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85433	 1	 4.07	 2.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85434	 1	 13.34	 7.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85435	 1	 8.4	 4.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85436	 1	 10.48	 6.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85437	 1	 10.69	 5.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85438	 1	 7.54	 3.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85439	 1	 13.02	 7.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85440	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85441	 1	 26.41	 15.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85442	 1	 1.52	 0.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85443	 1	 21.32	 10.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85444	 1	 17.45	 7.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85445	 1	 13.69	 6.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85446	 1	 9.85	 5.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85447	 1	 17.86	 7.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85448	 1	 15.88	 7.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85449	 1	 18.84	 9.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85450	 1	 68.55	 33.97	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85451	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85452	 1	 7.61	 4.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85453	 1	 24.76	 12.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85454	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85455	 1	 4.64	 2.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85456	 1	 6.65	 3.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85457	 1	 13.06	 5.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85458	 1	 6.1	 3.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85459	 1	 6.17	 3.81	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85460	 1	 13.46	 8.15	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85461	 1	 9.27	 4.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85462	 1	 7.17	 3.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85463	 1	 5.01	 2.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85464	 1	 4.54	 2.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85465	 1	 10.33	 5.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85466	 1	 7.58	 1.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85467	 1	 10.07	 2.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85468	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85469	 1	 32.07	 17.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85470	 1	 25.6	 5.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85471	 1	 13.6	 3.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85472	 1	 9.33	 4.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85473	 1	 8.5	 4.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85474	 1	 15.11	 7.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85475	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85476	 1	 23.9	 11.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85477	 1	 17.21	 3.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85478	 1	 20.68	 10.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85479	 1	 6.19	 3.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85480	 1	 8.36	 4.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85481	 1	 13.06	 5.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85482	 1	 24.1	 11.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85483	 1	 24.85	 5.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85484	 1	 3.74	 1.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85485	 1	 7.18	 3.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85486	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85487	 1	 14.13	 8.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85488	 1	 9.7	 5.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85489	 1	 5.46	 3.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85490	 1	 30.84	 17.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85491	 1	 12.75	 5.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85492	 1	 14.84	 7.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85493	 1	 7.66	 3.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85494	 1	 21.35	 11.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85495	 1	 4.18	 2.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85496	 1	 6.35	 3.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85497	 1	 30.01	 17.02	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85498	 1	 13.61	 3.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85499	 1	 9.57	 2.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85500	 1	 8.29	 1.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85501	 1	 5.71	 1.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85502	 1	 12.72	 3.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85503	 1	 25.21	 5.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85504	 1	 12.53	 2.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85505	 1	 11.96	 2.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85506	 1	 8.65	 2.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85507	 1	 9.22	 2.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85508	 1	 7.86	 1.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85509	 1	 16.65	 3.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85510	 1	 24.4	 5.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85511	 1	 32.92	 7.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85512	 1	 32.77	 7.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85513	 1	 13.78	 3.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85514	 1	 13.26	 3.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85515	 1	 10.31	 2.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85516	 1	 6.26	 1.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85517	 1	 8.1	 1.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85518	 1	 10.8	 2.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85519	 1	 21.6	 5.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85520	 1	 10.14	 2.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85521	 1	 8.51	 1.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85522	 1	 11.17	 2.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85523	 1	 4.26	 1.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85524	 1	 4.7	 1.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85525	 1	 4.88	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85526	 1	 10.6	 2.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85527	 1	 20.49	 4.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85528	 1	 10.58	 2.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85529	 1	 10.12	 2.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85530	 1	 10.11	 2.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85531	 1	 7.65	 1.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85532	 1	 9.8	 2.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85533	 1	 9.43	 2.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85534	 1	 14.87	 3.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85535	 1	 7.59	 1.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85536	 1	 7.21	 1.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85537	 1	 10.85	 2.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85538	 1	 10.06	 2.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85539	 1	 13.82	 3.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85540	 1	 13.42	 3.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85541	 1	 1.33	 0.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85542	 1	 17.6	 4.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85543	 1	 5.04	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85544	 1	 6.16	 1.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85545	 1	 6.32	 1.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85546	 1	 5.19	 1.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85547	 1	 16.38	 3.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85548	 1	 8.38	 1.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85549	 1	 11.67	 2.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85550	 1	 10.57	 2.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85551	 1	 8.06	 1.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85552	 1	 8.11	 1.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85553	 1	 12.32	 2.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85554	 1	 6.97	 1.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85555	 1	 10.76	 2.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85556	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85557	 1	 5.58	 1.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85558	 1	 15.56	 3.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85559	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85560	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85561	 1	 18.41	 7.68	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85562	 1	 11.94	 2.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85563	 1	 8.97	 5.43	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85564	 1	 10.11	 2.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85565	 1	 9.35	 2.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85566	 1	 8.25	 1.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85567	 1	 5.97	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85568	 1	 5.41	 1.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85569	 1	 4.02	 0.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85570	 1	 6.06	 1.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85571	 1	 12.42	 2.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85572	 1	 8.43	 2.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85573	 1	 10.81	 2.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85574	 1	 10.03	 2.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85575	 1	 14.03	 6.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85576	 1	 8.75	 4.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85577	 1	 9.14	 4.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85578	 1	 13.44	 8.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85579	 1	 6.83	 3.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85580	 1	 28.95	 13.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85581	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	85582	 1	 20.06	 10.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85583	 1	 8.11	 1.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85584	 1	 13.45	 3.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85585	 1	 9.07	 2.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85586	 1	 10.8	 2.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85587	 1	 9.61	 2.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85588	 1	 6.7	 1.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85589	 1	 7.89	 1.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85590	 1	 7.26	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85591	 1	 7.62	 1.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85592	 1	 6.5	 1.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85593	 1	 6.21	 1.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85594	 1	 11.31	 2.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85595	 1	 8.12	 1.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85596	 1	 10.05	 2.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85597	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85598	 1	 12.49	 2.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85599	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	85600	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85601	 1	 17.56	 9.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85602	 1	 13.76	 8.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85603	 1	 64.78	 35.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85604	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85605	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85606	 1	 20.89	 10.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85607	 1	 313.79	 135.26	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85608	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85609	 1	 4.93	 2.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85610	 1	 10.25	 5.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85611	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85612	 1	 12.27	 5.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85613	 1	 12.88	 3.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85614	 1	 92.37	 23.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85615	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85616	 1	 5.21	 1.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85617	 1	 29.23	 13.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85618	 1	 19.71	 10.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85619	 1	 16.79	 7.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85620	 1	 17.96	 7.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85621	 1	 14.29	 7.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85622	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	85623	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85624	 1	 7.18	 3.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85625	 1	 19.66	 8.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85626	 1	 16.22	 8.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85627	 1	 11.64	 2.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85628	 1	 82.64	 42.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85629	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85630	 1	 20.09	 4.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85631	 1	 5.03	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85632	 1	 10.92	 2.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85633	 1	 17.48	 4.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85634	 1	 11.91	 2.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85635	 1	 21.88	 5.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85636	 1	 10.09	 2.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85637	 1	 32.41	 14.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85638	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85639	 1	 13.95	 6.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85640	 1	 11.2	 6.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85641	 1	 9.34	 5.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85642	 1	 8.19	 3.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85643	 1	 10.97	 4.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85644	 1	 26.78	 11.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85645	 1	 7.83	 3.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85646	 1	 17.4	 9.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85647	 1	 11.33	 5.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85648	 1	 9.54	 5.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85649	 1	 11.54	 5.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85650	 1	 7.98	 3.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85651	 1	 5.43	 2.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85652	 1	 4.81	 2.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85653	 1	 2.42	 1.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85654	 1	 8.75	 3.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85655	 1	 8.71	 4.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85656	 1	 7.25	 3.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85657	 1	 20.21	 10.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85658	 1	 24.94	 11.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85659	 1	 9.1	 5.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85660	 1	 15.97	 7.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85661	 1	 15.57	 7.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85662	 1	 14.17	 8.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85663	 1	 7.54	 3.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85664	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85665	 1	 26.16	 11.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85666	 1	 8.4	 4.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85667	 1	 9.86	 5.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85668	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	85669	 1	 38.76	 20.51	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85670	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85671	 1	 18.82	 7.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85672	 1	 11.05	 4.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85673	 1	 21.21	 8.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85674	 1	 7.78	 3.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85675	 1	 3.32	 1.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85676	 1	 10.96	 5.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85677	 1	 2.38	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85678	 1	 2.94	 1.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85679	 1	 5.31	 2.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85680	 1	 15.05	 7.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85681	 1	 18.79	 8.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85682	 1	 16.1	 8.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85683	 1	 7.71	 3.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85684	 1	 11.01	 5.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85685	 1	 6.78	 3.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85686	 1	 18.87	 9.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85687	 1	 13.67	 5.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85688	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85689	 1	 10.8	 5.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85690	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85691	 1	 15.26	 7.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85692	 1	 8.88	 4.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85693	 1	 6.79	 4.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85694	 1	 5.78	 3.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85695	 1	 15.94	 7.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85696	 1	 7.05	 3.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85697	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85698	 1	 21.48	 10.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85699	 1	 88.59	 49.59	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85700	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85701	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85702	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85703	 1	 16.26	 9.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85704	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85705	 1	 22.2	 12.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85706	 1	 13.45	 6.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85707	 1	 78.89	 43.15	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85708	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85709	 1	 6.29	 3.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85710	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85711	 1	 10.4	 4.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85712	 1	 11.11	 5.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85713	 1	 17.55	 10.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85714	 1	 29.64	 15.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85715	 1	 33.27	 7.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85716	 1	 15.74	 8.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85717	 1	 28.22	 15.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85718	 1	 7.23	 4.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85719	 1	 16.31	 9.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85720	 1	 31.86	 16.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85721	 1	 21.99	 10.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85722	 1	 47.94	 24.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85723	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85724	 1	 8.78	 4.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85725	 1	 27.07	 10.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85726	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85727	 1	 35.63	 15.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85728	 1	 32.02	 16.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85729	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85730	 1	 36.99	 16.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85731	 1	 11.22	 5.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85732	 1	 25.92	 14.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85733	 1	 13.77	 7.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85734	 1	 29.97	 16.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85735	 1	 20.36	 12.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85736	 1	 17.45	 7.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85737	 1	 15.19	 7.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85738	 1	 31.83	 14.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85739	 1	 7.81	 3.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85740	 1	 15.58	 7.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85741	 1	 12.76	 6.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85742	 1	 18.9	 9.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85743	 1	 32.65	 15.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85744	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85745	 1	 10.39	 5.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85746	 1	 8.86	 5.12	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85747	 1	 25.26	 14.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85748	 1	 4.94	 2.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85749	 1	 0.61	 0.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85750	 1	 10.35	 5.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85751	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85752	 1	 16.79	 9.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85753	 1	 16.33	 3.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85754	 1	 4.98	 1.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85755	 1	 9.53	 5.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85756	 1	 28.93	 13.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85757	 1	 4.1	 2.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85758	 1	 9.58	 4.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85759	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	85760	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85761	 1	 25.71	 9.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85762	 1	 43.49	 22.37	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85763	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85764	 1	 14.74	 7.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85765	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85766	 1	 12.56	 5.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85767	 1	 13.76	 7.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85768	 1	 4.49	 2.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85769	 1	 8.87	 3.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85770	 1	 7.66	 4.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85771	 1	 12.08	 5.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85772	 1	 21.61	 5.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85773	 1	 11.93	 6.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85774	 1	 11.79	 6.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85775	 1	 11.01	 6.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85776	 1	 9.16	 2.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85777	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85778	 1	 23.67	 10.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85779	 1	 3.95	 2.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85780	 1	 7.45	 4.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85781	 1	 9.32	 4.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85782	 1	 12.29	 2.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85783	 1	 12.54	 7.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85784	 1	 5.25	 2.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85785	 1	 14.29	 7.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85786	 1	 14.99	 3.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85787	 1	 5.37	 3.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85788	 1	 5.4	 1.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85789	 1	 9.5	 2.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85790	 1	 9.64	 4.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85791	 1	 9.21	 4.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85792	 1	 8.71	 4.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85793	 1	 23.18	 5.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85794	 1	 8.22	 3.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85795	 1	 7.05	 3.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85796	 1	 7.46	 3.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85797	 1	 9.26	 2.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85798	 1	 46.6	 21.74	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85799	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85800	 1	 7.95	 1.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85801	 1	 7.04	 1.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85802	 1	 7.44	 1.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85803	 1	 13.56	 3.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85804	 1	 11.79	 2.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85805	 1	 9.34	 2.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85806	 1	 9.67	 2.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85807	 1	 5.8	 1.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85808	 1	 4.6	 1.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85809	 1	 2.35	 0.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85810	 1	 9.46	 2.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85811	 1	 7.25	 1.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85812	 1	 5.32	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85813	 1	 5.2	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85814	 1	 7.91	 1.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85815	 1	 2.78	 0.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85816	 1	 6.27	 1.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85817	 1	 9.23	 2.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85818	 1	 11.7	 2.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85819	 1	 6.05	 1.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85820	 1	 7.57	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85821	 1	 17.05	 3.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85822	 1	 13.84	 3.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85823	 1	 18.26	 4.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85824	 1	 18.3	 4.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85825	 1	 12.58	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85826	 1	 15.05	 3.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85827	 1	 9.64	 2.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85828	 1	 8.24	 4.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85829	 1	 2.35	 1.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85830	 1	 9.54	 4.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85831	 1	 10.34	 6.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85832	 1	 15.51	 8.39	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85833	 1	 67.69	 33.95	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85834	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85835	 1	 7.07	 3.53	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85836	 1	 1.89	 1.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85837	 1	 13.06	 7.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85838	 1	 5.79	 3.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85839	 1	 3.59	 1.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85840	 1	 6.16	 3.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85841	 1	 5.86	 2.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85842	 1	 3.33	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85843	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85844	 1	 7.17	 3.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85845	 1	 23.98	 13.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85846	 1	 6.47	 3.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85847	 1	 8.9	 4.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85848	 1	 5.24	 2.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85849	 1	 8.6	 4.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85850	 1	 7.52	 3.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85851	 1	 3.87	 1.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85852	 1	 6.91	 4.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85853	 1	 5.74	 3.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85854	 1	 3.22	 1.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85855	 1	 5.88	 2.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85856	 1	 7.48	 4.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85857	 1	 9.65	 5.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85858	 1	 16.02	 7.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85859	 1	 12.54	 6.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85860	 1	 6.8	 4.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85861	 1	 6.05	 3.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85862	 1	 6.58	 3.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85863	 1	 4.72	 2.48	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85864	 1	 11.61	 5.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85865	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85866	 1	 16.52	 7.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85867	 1	 13.66	 6.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85868	 1	 4.05	 2.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85869	 1	 14.4	 6.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85870	 1	 8.13	 4.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85871	 1	 13.51	 5.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85872	 1	 7.21	 3.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85873	 1	 8.11	 4.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85874	 1	 7.43	 4.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85875	 1	 4.2	 2.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85876	 1	 3.44	 1.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85877	 1	 8.44	 3.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85878	 1	 3.6	 1.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85879	 1	 16.07	 8.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85880	 1	 4.62	 2.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85881	 1	 17.44	 7.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85882	 1	 6.03	 3.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85883	 1	 18.49	 9.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85884	 1	 7.79	 4.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85885	 1	 6.06	 2.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85886	 1	 11.87	 7.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85887	 1	 147.38	 57.75	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85888	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85889	 1	 27.65	 13.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85890	 1	 6.85	 4.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85891	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85892	 1	 21.94	 11.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85893	 1	 10.67	 5.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85894	 1	 7.9	 3.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85895	 1	 22.14	 11.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85896	 1	 10.72	 5.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85897	 1	 14.45	 5.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85898	 1	 32.05	 11.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85899	 1	 33.38	 13.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85900	 1	 8.48	 4.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85901	 1	 8.49	 1.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85902	 1	 12.18	 2.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85903	 1	 11.5	 5.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85904	 1	 9.04	 3.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85905	 1	 39.11	 19.81	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85906	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85907	 1	 4.53	 2.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85908	 1	 26.3	 12.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85909	 1	 13.29	 6.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85910	 1	 12.89	 6.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85911	 1	 5.99	 3.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85912	 1	 8.8	 4.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85913	 1	 13.74	 8.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85914	 1	 10.0	 5.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85915	 1	 9.04	 3.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85916	 1	 25.4	 12.61	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85917	 1	 6.19	 3.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85918	 1	 16.93	 7.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85919	 1	 24.91	 9.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85920	 1	 2.46	 1.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85921	 1	 25.99	 11.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85922	 1	 13.79	 6.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85923	 1	 9.83	 4.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85924	 1	 5.69	 2.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85925	 1	 7.13	 4.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85926	 1	 6.83	 3.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85927	 1	 23.51	 12.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85928	 1	 6.83	 3.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85929	 1	 9.28	 5.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85930	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85931	 1	 23.65	 13.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85932	 1	 6.36	 3.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85933	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85934	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85935	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85936	 1	 12.14	 4.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85937	 1	 3.44	 1.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85938	 1	 4.42	 2.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85939	 1	 8.79	 5.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85940	 1	 8.94	 5.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85941	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85942	 1	 4.9	 2.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85943	 1	 3.41	 1.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85944	 1	 3.24	 1.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85945	 1	 3.52	 1.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85946	 1	 10.64	 4.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85947	 1	 15.66	 8.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85948	 1	 7.28	 4.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85949	 1	 13.48	 6.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85950	 1	 7.89	 3.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85951	 1	 3.61	 2.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85952	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85953	 1	 28.08	 15.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85954	 1	 18.56	 11.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85955	 1	 6.84	 3.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85956	 1	 15.61	 7.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85957	 1	 17.2	 7.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85958	 1	 35.09	 14.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85959	 1	 18.69	 9.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85960	 1	 15.61	 8.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85961	 1	 9.48	 5.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85962	 1	 3.73	 1.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85963	 1	 25.29	 10.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85964	 1	 80.64	 43.55	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85965	 1	 10.85	 6.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85966	 1	 199.58	 92.71	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85967	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85968	 1	 11.49	 6.45	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85969	 1	 3.53	 2.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85970	 1	 14.68	 7.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85971	 1	 6.45	 2.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85972	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85973	 1	 19.38	 6.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85974	 1	 12.68	 7.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85975	 1	 7.38	 4.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85976	 1	 8.91	 4.19	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85977	 1	 5.97	 2.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85978	 1	 11.37	 6.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85979	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85980	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85981	 1	 31.99	 17.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85982	 1	 16.43	 7.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85983	 1	 7.7	 4.82	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85984	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85985	 1	 7.68	 4.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85986	 1	 7.98	 4.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85987	 1	 26.69	 6.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85988	 1	 15.39	 3.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85989	 1	 9.73	 4.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85990	 1	 3.43	 1.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85991	 1	 8.87	 4.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85992	 1	 14.45	 8.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85993	 1	 32.63	 19.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85994	 1	 8.48	 4.72	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	85995	 1	 22.75	 5.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85996	 1	 19.55	 4.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85997	 1	 4.06	 0.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85998	 1	 8.75	 2.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	85999	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86000	 1	 15.58	 7.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86001	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86002	 1	 16.06	 7.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86003	 1	 5.27	 3.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86004	 1	 12.29	 4.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86005	 1	 8.24	 4.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86006	 1	 8.01	 4.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86007	 1	 35.12	 19.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86008	 1	 11.94	 5.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86009	 1	 13.4	 7.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86010	 1	 8.09	 4.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86011	 1	 12.38	 6.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86012	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86013	 1	 27.92	 13.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86014	 1	 32.6	 16.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86015	 1	 10.88	 6.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86016	 1	 18.75	 11.92	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86017	 1	 15.31	 9.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86018	 1	 4.12	 1.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86019	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86020	 1	 12.43	 6.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86021	 1	 6.73	 3.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86022	 1	 21.09	 9.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86023	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86024	 1	 5.04	 2.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86025	 1	 16.26	 7.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86026	 1	 8.37	 4.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86027	 1	 7.7	 1.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86028	 1	 11.37	 2.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86029	 1	 18.69	 4.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86030	 1	 18.16	 4.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86031	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86032	 1	 25.54	 5.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86033	 1	 4.08	 0.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86034	 1	 6.13	 1.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86035	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	86036	 1	 37.86	 15.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86037	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86038	 1	 9.09	 2.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86039	 1	 8.42	 3.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86040	 1	 4.72	 2.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86041	 1	 5.7	 1.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86042	 1	 13.39	 3.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86043	 1	 6.09	 1.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86044	 1	 7.5	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86045	 1	 7.5	 1.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86046	 1	 16.22	 3.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86047	 1	 12.43	 2.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86048	 1	 17.48	 4.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86049	 1	 13.44	 3.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86050	 1	 6.55	 1.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86051	 1	 11.28	 6.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86052	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	86053	 1	 42.07	 24.69	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86054	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86055	 1	 25.67	 5.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86056	 1	 19.69	 4.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86057	 1	 4.18	 0.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86058	 1	 3.03	 0.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86059	 1	 7.57	 3.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86060	 1	 9.72	 4.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86061	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	86062	 1	 68.95	 30.15	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86063	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86064	 1	 18.58	 10.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86065	 1	 16.47	 9.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86066	 1	 7.77	 3.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86067	 1	 8.95	 5.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86068	 1	 18.76	 7.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86069	 1	 19.36	 8.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86070	 1	 7.0	 3.4	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86071	 1	 12.39	 6.19	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86072	 1	 8.66	 5.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86073	 1	 12.34	 5.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86074	 1	 11.57	 5.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86075	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86076	 1	 23.9	 12.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86077	 1	 9.28	 4.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86078	 1	 8.51	 4.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86079	 1	 7.48	 4.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86080	 1	 14.01	 7.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86081	 1	 8.54	 3.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86082	 1	 19.35	 10.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86083	 1	 15.42	 8.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86084	 1	 18.78	 8.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86085	 1	 8.64	 4.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86086	 1	 10.51	 5.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86087	 1	 7.65	 3.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86088	 1	 7.67	 2.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86089	 1	 7.78	 3.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86090	 1	 5.83	 3.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86091	 1	 40.99	 24.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86092	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86093	 1	 13.91	 5.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86094	 1	 9.1	 4.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86095	 1	 12.17	 7.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86096	 1	 10.36	 4.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86097	 1	 15.83	 8.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86098	 1	 27.3	 12.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86099	 1	 27.56	 6.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86100	 1	 5.24	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86101	 1	 5.29	 1.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86102	 1	 12.37	 2.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86103	 1	 7.81	 1.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86104	 1	 9.07	 2.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86105	 1	 6.92	 2.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86106	 1	 9.81	 5.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86107	 1	 8.99	 4.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86108	 1	 6.74	 3.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86109	 1	 20.77	 4.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86110	 1	 5.08	 2.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86111	 1	 5.36	 2.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86112	 1	 11.86	 6.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86113	 1	 7.75	 4.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86114	 1	 4.91	 2.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86115	 1	 4.84	 2.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86116	 1	 3.06	 1.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86117	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86118	 1	 6.28	 3.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86119	 1	 6.19	 3.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86120	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	86121	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86122	 1	 12.46	 5.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86123	 1	 6.64	 3.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86124	 1	 20.73	 8.34	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86125	 1	 11.82	 2.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86126	 1	 10.54	 5.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86127	 1	 12.85	 5.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86128	 1	 6.38	 3.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86129	 1	 11.1	 5.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86130	 1	 6.76	 4.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86131	 1	 6.19	 3.46	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86132	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86133	 1	 12.44	 7.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86134	 1	 7.42	 4.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86135	 1	 11.13	 5.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86136	 1	 8.27	 4.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86137	 1	 7.17	 4.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86138	 1	 12.46	 7.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86139	 1	 7.9	 4.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86140	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86141	 1	 34.38	 18.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86142	 1	 7.84	 4.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86143	 1	 15.35	 8.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86144	 1	 9.81	 5.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86145	 1	 17.2	 9.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86146	 1	 14.03	 4.61	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86147	 1	 4.91	 1.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86148	 1	 13.33	 3.22	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86149	 1	 16.86	 5.37	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86150	 1	 5.12	 1.89	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86151	 1	 30.66	 6.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86152	 1	 5.7	 1.66	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86153	 1	 11.88	 3.93	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86154	 1	 5.81	 2.08	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86155	 1	 18.56	 7.36	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86156	 1	 41.07	 9.22	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86157	 1	 8.88	 3.45	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86158	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86159	 1	 42.43	 14.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86160	 1	 6.74	 2.12	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86161	 1	 3.36	 0.76	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86162	 1	 9.54	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86163	 1	 56.56	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86164	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86165	 1	 7.06	 2.88	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86166	 1	 4.94	 1.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86167	 1	 5.88	 2.04	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86168	 1	 16.79	 6.43	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86169	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86170	 1	 40.25	 15.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86171	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86172	 1	 5.63	 2.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86173	 1	 13.18	 4.97	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86174	 1	 9.07	 3.37	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86175	 1	 7.45	 2.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86176	 1	 6.3	 2.56	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86177	 1	 3.13	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86178	 1	 5.6	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86179	 1	 6.33	 2.11	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86180	 1	 6.28	 2.46	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86181	 1	 23.16	 8.26	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86182	 1	 24.21	 8.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86183	 1	 7.64	 2.79	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86184	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86185	 1	 18.56	 6.7	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86186	 1	 11.5	 4.66	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86187	 1	 116.42	 44.43	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86188	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86189	 1	 23.9	 8.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86190	 1	 13.84	 5.59	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86191	 1	 9.76	 4.05	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86192	 1	 36.19	 9.87	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86193	 1	 17.8	 6.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86194	 1	 3.48	 1.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86195	 1	 35.45	 7.76	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86196	 1	 6.22	 2.09	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86197	 1	 21.09	 7.9	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86198	 1	 20.73	 7.68	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86199	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	86200	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86201	 1	 4.97	 1.97	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86202	 1	 13.7	 5.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86203	 1	 4.9	 2.03	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86204	 1	 41.28	 15.87	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86205	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86206	 1	 9.26	 4.21	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86207	 1	 27.74	 7.88	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86208	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86209	 1	 14.34	 4.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86210	 1	 31.4	 12.58	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86211	 1	 23.43	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86212	 1	 13.12	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86213	 1	 26.14	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86214	 1	 11.7	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86215	 1	 13.55	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86216	 1	 13.4	 3.02	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86217	 1	 9.97	 2.25	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86218	 1	 10.43	 2.36	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86219	 1	 33.15	 12.03	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86220	 1	 16.23	 6.96	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86221	 1	 3.59	 1.45	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86222	 1	 32.39	 10.12	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86223	 1	 22.57	 8.89	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86224	 1	 17.8	 6.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86225	 1	 44.45	 11.71	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86226	 1	 19.61	 4.41	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86227	 1	 22.95	 7.94	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86228	 1	 3.96	 1.53	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86229	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86230	 1	 25.89	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86231	 1	 37.61	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86232	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86233	 1	 15.37	 4.18	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86234	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86235	 1	 38.64	 9.52	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86236	 1	 3.45	 1.25	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86237	 1	 4.3	 1.68	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86238	 1	 7.36	 2.61	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86239	 1	 6.72	 2.59	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86240	 1	 23.96	 5.37	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86241	 1	 12.98	 2.91	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86242	 1	 4.39	 1.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86243	 1	 23.42	 5.27	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86244	 1	 12.72	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86245	 1	 4.27	 0.97	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86246	 1	 9.12	 2.08	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86247	 1	 30.05	 6.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86248	 1	 30.95	 7.02	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86249	 1	 5.14	 1.17	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86250	 1	 5.81	 1.33	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86251	 1	 9.27	 2.11	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86252	 1	 6.64	 2.07	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86253	 1	 10.83	 2.45	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86254	 1	 7.72	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86255	 1	 3.83	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86256	 1	 8.52	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86257	 1	 6.75	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86258	 1	 5.39	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86259	 1	 6.2	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86260	 1	 13.88	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86261	 1	 97.39	 34.29	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86262	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86263	 1	 10.57	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86264	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86265	 1	 10.09	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86266	 1	 10.16	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86267	 1	 10.9	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86268	 1	 10.06	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86269	 1	 7.94	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86270	 1	 35.21	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86271	 1	 6.72	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86272	 1	 5.29	 2.06	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86273	 1	 6.24	 1.42	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86274	 1	 17.31	 6.46	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86275	 1	 36.15	 8.19	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86276	 1	 9.59	 2.19	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86277	 1	 3.59	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86278	 1	 14.96	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86279	 1	 12.38	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86280	 1	 31.2	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86281	 1	 5.77	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86282	 1	 10.65	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86283	 1	 10.83	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86284	 1	 6.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86285	 1	 9.89	 2.74	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86286	 1	 12.48	 4.86	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86287	 1	 4.27	 1.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86288	 1	 7.9	 3.28	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86289	 1	 14.44	 5.65	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86290	 1	 16.04	 5.68	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86291	 1	 25.57	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86292	 1	 8.87	 3.65	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86293	 1	 5.58	 2.42	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86294	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86295	 1	 48.51	 16.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86296	 1	 10.62	 3.23	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86297	 1	 8.6	 3.87	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86298	 1	 26.67	 6.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86299	 1	 15.16	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86300	 1	 39.72	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86301	 1	 35.04	 8.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86302	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86303	 1	 30.35	 11.14	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86304	 1	 12.91	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86305	 1	 32.13	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86306	 1	 28.48	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86307	 1	 15.79	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86308	 1	 29.23	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86309	 1	 24.15	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86310	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	86311	 1	 135.79	 46.7	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86312	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86313	 1	 4.27	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86314	 1	 8.51	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86315	 1	 10.88	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86316	 1	 7.44	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86317	 1	 5.45	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86318	 1	 29.53	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86319	 1	 73.02	 26.77	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86320	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86321	 1	 12.74	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86322	 1	 16.25	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86323	 1	 10.46	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86324	 1	 6.48	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86325	 1	 8.1	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86326	 1	 38.21	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86327	 1	 7.84	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86328	 1	 8.25	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86329	 1	 19.54	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86330	 1	 16.47	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86331	 1	 9.97	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86332	 1	 12.86	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86333	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86334	 1	 7.71	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86335	 1	 2.91	 1.19	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86336	 1	 9.45	 3.85	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86337	 1	 1.73	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86338	 1	 20.95	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86339	 1	 7.42	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86340	 1	 20.39	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86341	 1	 29.59	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86342	 1	 16.66	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86343	 1	 40.83	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86344	 1	 28.1	 8.42	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86345	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86346	 1	 17.96	 6.72	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86347	 1	 46.92	 10.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86348	 1	 6.15	 2.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86349	 1	 15.53	 3.52	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86350	 1	 5.84	 1.99	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86351	 1	 11.47	 4.14	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86352	 1	 4.45	 1.98	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86353	 1	 9.41	 4.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86354	 1	 4.0	 1.64	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86355	 1	 7.38	 2.04	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86356	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86357	 1	 15.25	 6.79	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86358	 1	 9.7	 3.89	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86359	 1	 14.98	 4.2	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86360	 1	 18.27	 6.11	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86361	 1	 26.86	 9.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86362	 1	 6.59	 2.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86363	 1	 14.7	 4.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86364	 1	 42.39	 10.26	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86365	 1	 4.6	 1.61	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86366	 1	 7.61	 3.02	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86367	 1	 7.38	 2.63	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86368	 1	 7.47	 2.87	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86369	 1	 18.88	 5.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86370	 1	 18.46	 7.51	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86371	 1	 29.64	 10.49	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86372	 1	 8.7	 3.5	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86373	 1	 5.79	 2.1	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86374	 1	 19.85	 5.56	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86375	 1	 12.13	 4.47	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86376	 1	 8.76	 3.56	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86377	 1	 4.62	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86378	 1	 4.25	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86379	 1	 8.34	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86380	 1	 3.3	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86381	 1	 4.87	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86382	 1	 45.43	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86383	 1	 12.21	 4.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86384	 1	 8.56	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86385	 1	 14.68	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86386	 1	 20.3	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86387	 1	 4.76	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86388	 1	 7.17	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86389	 1	 2.77	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86390	 1	 1.32	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86391	 1	 2.03	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86392	 1	 3.67	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86393	 1	 6.43	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86394	 1	 9.69	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86395	 1	 13.78	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86396	 1	 11.07	 3.64	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86397	 1	 4.34	 1.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86398	 1	 20.6	 6.34	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86399	 1	 10.25	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86400	 1	 3.94	 1.51	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86401	 1	 3.15	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86402	 1	 29.4	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86403	 1	 3.81	 1.45	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86404	 1	 5.51	 2.23	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86405	 1	 8.99	 2.97	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86406	 1	 70.27	 15.28	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86407	 1	 6.6	 2.03	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86408	 1	 5.18	 1.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86409	 1	 15.21	 6.07	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86410	 1	 2.84	 1.16	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86411	 1	 8.52	 2.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86412	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86413	 1	 11.58	 3.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86414	 1	 10.36	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86415	 1	 13.54	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86416	 1	 9.19	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86417	 1	 3.57	 1.54	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86418	 1	 4.11	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86419	 1	 6.45	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86420	 1	 5.42	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86421	 1	 5.69	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86422	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	86423	 1	 73.85	 21.08	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86424	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86425	 1	 11.58	 4.17	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86426	 1	 12.43	 4.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86427	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	86428	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86429	 1	 49.07	 18.18	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86430	 1	 14.69	 5.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86431	 1	 8.66	 2.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86432	 1	 3.42	 1.2	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86433	 1	 17.76	 4.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86434	 1	 17.1	 4.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86435	 1	 33.71	 10.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86436	 1	 9.19	 3.38	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86437	 1	 4.99	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86438	 1	 33.81	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86439	 1	 12.43	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86440	 1	 33.13	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86441	 1	 10.43	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86442	 1	 15.35	 3.46	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86443	 1	 14.76	 3.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86444	 1	 3.56	 1.61	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86445	 1	 3.17	 1.26	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86446	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86447	 1	 50.73	 20.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86448	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86449	 1	 14.86	 4.53	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86450	 1	 46.24	 13.34	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86451	 1	 18.74	 4.8	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86452	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86453	 1	 35.07	 10.06	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86454	 1	 22.42	 8.17	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86455	 1	 23.36	 7.8	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86456	 1	 50.69	 16.77	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86457	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86458	 1	 4.68	 1.43	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86459	 1	 15.59	 4.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86460	 1	 1.37	 0.58	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86461	 1	 28.85	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86462	 1	 28.84	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86463	 1	 23.4	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86464	 1	 17.63	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86465	 1	 20.14	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86466	 1	 15.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86467	 1	 48.8	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86468	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	86469	 1	 76.42	 24.92	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86470	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86471	 1	 65.03	 21.74	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86472	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86473	 1	 18.03	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86474	 1	 10.42	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86475	 1	 14.91	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86476	 1	 9.41	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86477	 1	 17.12	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86478	 1	 10.58	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86479	 1	 8.23	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86480	 1	 19.14	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86481	 1	 6.12	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86482	 1	 48.09	 15.66	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86483	 1	 11.69	 4.26	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86484	 1	 14.95	 5.88	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86485	 1	 19.49	 7.08	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86486	 1	 11.39	 3.8	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86487	 1	 8.61	 3.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86488	 1	 6.41	 2.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86489	 1	 19.0	 4.26	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86490	 1	 16.31	 3.64	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86491	 1	 29.54	 6.72	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86492	 1	 8.26	 1.87	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86493	 1	 4.72	 1.66	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86494	 1	 3.72	 0.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86495	 1	 7.84	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86496	 1	 4.52	 1.61	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86497	 1	 8.69	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86498	 1	 19.69	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86499	 1	 16.47	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86500	 1	 33.33	 7.58	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86501	 1	 4.44	 1.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86502	 1	 6.04	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86503	 1	 15.77	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86504	 1	 28.4	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86505	 1	 12.34	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86506	 1	 13.65	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86507	 1	 34.41	 10.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86508	 1	 9.49	 3.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86509	 1	 7.63	 2.97	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86510	 1	 16.96	 4.51	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86511	 1	 10.0	 3.41	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86512	 1	 18.27	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86513	 1	 6.35	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86514	 1	 16.79	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86515	 1	 30.14	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86516	 1	 11.59	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86517	 1	 11.64	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86518	 1	 17.46	 3.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86519	 1	 26.05	 6.85	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86520	 1	 2.95	 1.14	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86521	 1	 6.02	 2.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86522	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86523	 1	 7.09	 2.91	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86524	 1	 17.58	 4.66	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86525	 1	 18.42	 6.47	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86526	 1	 15.16	 5.23	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86527	 1	 17.23	 4.74	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86528	 1	 9.37	 3.12	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86529	 1	 18.57	 5.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86530	 1	 9.31	 2.86	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86531	 1	 9.93	 3.93	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86532	 1	 32.12	 7.54	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86533	 1	 17.07	 6.03	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86534	 1	 14.35	 5.59	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86535	 1	 5.47	 2.5	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86536	 1	 11.12	 3.96	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86537	 1	 19.93	 5.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86538	 1	 5.56	 2.36	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86539	 1	 9.18	 3.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86540	 1	 17.95	 6.33	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86541	 1	 6.61	 2.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86542	 1	 9.06	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86543	 1	 13.19	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86544	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86545	 1	 8.89	 3.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86546	 1	 14.64	 5.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86547	 1	 14.27	 3.79	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86548	 1	 49.97	 14.96	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86549	 1	 55.89	 9.99	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86550	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86551	 1	 17.8	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86552	 1	 3.86	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86553	 1	 20.51	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86554	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86555	 1	 11.68	 3.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86556	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86557	 1	 13.24	 5.57	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86558	 1	 20.77	 6.89	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86559	 1	 4.5	 1.61	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86560	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86561	 1	 19.62	 7.2	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86562	 1	 7.32	 2.9	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86563	 1	 1.78	 0.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86564	 1	 11.01	 2.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86565	 1	 11.9	 4.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86566	 1	 10.79	 3.58	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86567	 1	 10.38	 3.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86568	 1	 3.96	 1.28	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86569	 1	 11.28	 4.18	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86570	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	86571	 1	 29.86	 12.1	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86572	 1	 25.33	 6.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86573	 1	 8.13	 3.77	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86574	 1	 24.82	 8.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86575	 1	 10.47	 4.59	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86576	 1	 5.93	 2.33	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86577	 1	 9.15	 3.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86578	 1	 6.03	 2.49	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86579	 1	 3.73	 1.57	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86580	 1	 25.64	 5.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86581	 1	 2.39	 0.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86582	 1	 22.61	 8.98	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86583	 1	 26.9	 9.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86584	 1	 6.02	 2.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86585	 1	 16.25	 5.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86586	 1	 8.67	 3.16	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86587	 1	 15.41	 5.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86588	 1	 8.57	 3.01	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86589	 1	 39.1	 7.85	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86590	 1	 23.76	 5.43	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86591	 1	 19.62	 7.19	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86592	 1	 3.58	 1.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86593	 1	 9.58	 2.64	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86594	 1	 22.19	 7.49	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86595	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86596	 1	 14.84	 4.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86597	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86598	 1	 13.63	 4.14	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86599	 1	 11.11	 4.15	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86600	 1	 10.23	 3.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86601	 1	 13.67	 5.21	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86602	 1	 20.3	 7.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86603	 1	 2.66	 1.05	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86604	 1	 2.07	 0.86	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86605	 1	 5.16	 1.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86606	 1	 11.91	 4.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86607	 1	 10.9	 4.72	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86608	 1	 10.11	 2.31	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86609	 1	 18.77	 6.7	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86610	 1	 16.8	 5.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86611	 1	 4.75	 1.09	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86612	 1	 18.35	 5.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86613	 1	 14.68	 4.72	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86614	 1	 11.95	 3.1	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86615	 1	 1.51	 0.71	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86616	 1	 17.45	 4.38	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86617	 1	 12.57	 5.02	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86618	 1	 16.0	 4.14	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86619	 1	 14.08	 5.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86620	 1	 22.04	 7.34	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86621	 1	 9.98	 4.16	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86622	 1	 13.3	 4.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86623	 1	 5.54	 2.19	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86624	 1	 13.1	 3.06	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86625	 1	 9.71	 3.16	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86626	 1	 6.15	 2.03	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86627	 1	 6.99	 2.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86628	 1	 6.01	 2.07	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86629	 1	 30.92	 6.29	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86630	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86631	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86632	 1	 47.64	 17.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86633	 1	 19.66	 6.26	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86634	 1	 9.58	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86635	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86636	 1	 34.69	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86637	 1	 16.02	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86638	 1	 5.04	 2.07	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86639	 1	 2.52	 1.11	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86640	 1	 11.13	 3.04	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86641	 1	 7.87	 3.29	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86642	 1	 5.75	 2.42	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86643	 1	 16.6	 4.41	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86644	 1	 4.45	 1.5	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86645	 1	 19.11	 5.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86646	 1	 14.92	 5.19	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86647	 1	 30.51	 11.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86648	 1	 5.83	 2.29	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86649	 1	 17.66	 4.79	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86650	 1	 11.05	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86651	 1	 16.8	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86652	 1	 20.12	 6.99	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86653	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86654	 1	 5.25	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86655	 1	 1.36	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86656	 1	 13.18	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86657	 1	 12.06	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86658	 1	 21.17	 7.61	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86659	 1	 13.42	 3.74	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86660	 1	 19.64	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86661	 1	 21.3	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86662	 1	 9.13	 4.09	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86663	 1	 10.0	 3.5	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86664	 1	 11.07	 3.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86665	 1	 2.76	 1.1	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86666	 1	 10.71	 3.34	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86667	 1	 15.52	 6.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86668	 1	 8.1	 2.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86669	 1	 21.41	 7.2	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86670	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86671	 1	 15.45	 5.37	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86672	 1	 7.74	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86673	 1	 1.8	 0.7	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86674	 1	 7.89	 3.21	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86675	 1	 17.17	 4.34	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86676	 1	 11.95	 4.93	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86677	 1	 15.41	 4.65	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86678	 1	 9.49	 3.57	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86679	 1	 5.47	 2.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86680	 1	 11.29	 4.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86681	 1	 4.68	 1.63	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86682	 1	 11.95	 4.7	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86683	 1	 22.45	 6.5	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86684	 1	 35.86	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86685	 1	 32.75	 0.0	 0.0	 40.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86686	 1	 26.93	 7.64	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86687	 1	 5.69	 2.1	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86688	 1	 19.31	 6.76	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86689	 1	 17.07	 7.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86690	 1	 39.77	 9.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86691	 1	 2.74	 0.93	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86692	 1	 1.26	 0.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86693	 1	 5.09	 1.2	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86694	 1	 26.81	 9.81	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86695	 1	 15.2	 3.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86696	 1	 36.1	 11.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86697	 1	 97.36	 30.21	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86698	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86699	 1	 58.38	 19.38	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86700	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86701	 1	 6.89	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86702	 1	 1.61	 0.74	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86703	 1	 13.92	 4.51	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86704	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	86705	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86706	 1	 6.33	 2.14	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86707	 1	 15.26	 5.16	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86708	 1	 5.23	 2.76	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86709	 1	 7.89	 4.16	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86710	 1	 8.5	 3.66	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86711	 1	 36.49	 16.1	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86712	 1	 20.13	 7.84	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86713	 1	 21.74	 10.91	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86714	 1	 21.95	 12.97	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86715	 1	 8.23	 5.32	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86716	 1	 28.7	 9.66	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86717	 1	 57.29	 25.84	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86718	 1	 11.75	 6.59	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86719	 1	 11.8	 6.07	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86720	 1	 12.45	 7.3	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86721	 1	 12.08	 7.16	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86722	 1	 19.28	 9.66	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86723	 1	 9.39	 5.24	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86724	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86725	 1	 27.58	 14.13	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86726	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86727	 1	 5.51	 3.08	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86728	 1	 17.5	 7.73	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86729	 1	 12.45	 6.18	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86730	 1	 42.37	 20.77	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86731	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86732	 1	 32.82	 11.53	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86733	 1	 25.73	 12.25	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86734	 1	 21.15	 10.11	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86735	 1	 17.53	 8.76	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86736	 1	 14.16	 7.61	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86737	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86738	 1	 32.31	 18.13	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86739	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86740	 1	 33.39	 12.89	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86741	 1	 16.53	 7.16	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86742	 1	 15.22	 6.19	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86743	 1	 15.55	 8.91	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86744	 1	 18.15	 7.83	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86745	 1	 27.86	 13.76	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86746	 1	 34.39	 15.33	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86747	 1	 82.65	 42.76	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86748	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86749	 1	 14.51	 8.95	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86750	 1	 20.02	 10.4	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86751	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86752	 1	 21.01	 11.12	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86753	 1	 9.56	 5.47	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86754	 1	 10.61	 6.24	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86755	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86756	 1	 5.77	 2.9	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86757	 1	 14.36	 7.99	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86758	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86759	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86760	 1	 6.47	 4.11	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86761	 1	 5.58	 3.62	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86762	 1	 14.03	 8.55	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86763	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86764	 1	 33.79	 11.57	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86765	 1	 15.59	 7.43	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86766	 1	 5.58	 2.52	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86767	 1	 5.99	 3.69	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86768	 1	 14.85	 6.95	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86769	 1	 7.06	 3.61	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86770	 1	 9.17	 5.21	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86771	 1	 4.63	 2.53	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86772	 1	 62.33	 30.23	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86773	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86774	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86775	 1	 15.37	 8.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86776	 1	 13.63	 8.04	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86777	 1	 81.7	 38.93	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86778	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86779	 1	 18.84	 11.01	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86780	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86781	 1	 19.52	 10.94	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86782	 1	 8.4	 4.3	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86783	 1	 8.06	 4.25	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86784	 1	 10.66	 6.2	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86785	 1	 7.84	 4.31	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86786	 1	 17.41	 9.18	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86787	 1	 11.52	 5.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86788	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86789	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86790	 1	 9.66	 5.09	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86791	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	86792	 1	 129.27	 69.43	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86793	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86794	 1	 6.77	 3.38	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86795	 1	 11.63	 5.89	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86796	 1	 21.43	 10.15	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86797	 1	 20.25	 10.47	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86798	 1	 23.14	 7.84	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86799	 1	 19.72	 8.42	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86800	 1	 16.8	 8.78	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86801	 1	 22.6	 7.04	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86802	 1	 8.18	 3.12	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86803	 1	 47.32	 16.56	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86804	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86805	 1	 25.72	 9.74	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86806	 1	 11.57	 4.61	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86807	 1	 11.61	 6.74	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86808	 1	 26.17	 8.94	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86809	 1	 7.37	 3.93	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86810	 1	 13.26	 7.94	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86811	 1	 4.09	 2.75	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86812	 1	 13.24	 7.41	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86813	 1	 3.98	 2.22	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86814	 1	 15.63	 8.85	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86815	 1	 7.67	 4.11	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86816	 1	 18.26	 10.82	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86817	 1	 23.61	 10.96	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86818	 1	 12.35	 6.96	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86819	 1	 45.75	 15.2	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86820	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86821	 1	 24.28	 11.47	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86822	 1	 10.49	 5.15	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86823	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86824	 1	 26.68	 10.62	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86825	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86826	 1	 10.67	 4.7	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86827	 1	 16.56	 8.66	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86828	 1	 17.83	 8.92	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86829	 1	 14.68	 8.05	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86830	 1	 5.76	 2.92	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86831	 1	 17.23	 8.36	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86832	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86833	 1	 33.45	 17.45	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86834	 1	 34.93	 20.39	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86835	 1	 15.77	 7.5	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86836	 1	 25.07	 9.14	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86837	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86838	 1	 31.28	 14.28	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86839	 1	 11.51	 5.78	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86840	 1	 30.4	 14.43	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86841	 1	 20.69	 11.72	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86842	 1	 23.82	 8.78	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86843	 1	 11.67	 5.29	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86844	 1	 14.57	 7.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86845	 1	 9.02	 4.16	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86846	 1	 11.25	 5.87	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86847	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86848	 1	 10.96	 2.52	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86849	 1	 5.0	 3.02	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86850	 1	 11.75	 6.9	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86851	 1	 13.53	 8.08	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86852	 1	 18.99	 7.89	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86853	 1	 8.08	 4.02	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86854	 1	 18.22	 10.67	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86855	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	86856	 1	 53.7	 21.89	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86857	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86858	 1	 5.53	 3.2	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86859	 1	 25.63	 5.8	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86860	 1	 7.39	 1.68	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86861	 1	 14.33	 3.24	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86862	 1	 27.24	 6.24	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86863	 1	 20.41	 4.77	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86864	 1	 28.19	 6.48	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86865	 1	 14.28	 3.28	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86866	 1	 8.26	 1.88	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86867	 1	 4.61	 1.06	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86868	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86869	 1	 9.49	 2.16	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86870	 1	 13.58	 3.06	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86871	 1	 31.77	 7.23	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86872	 1	 67.12	 18.5	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86873	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86874	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86875	 1	 22.31	 5.09	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86876	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86877	 1	 35.12	 8.13	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86878	 1	 39.0	 17.34	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86879	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86880	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86881	 1	 9.84	 5.29	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86882	 1	 28.99	 6.6	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86883	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86884	 1	 24.63	 10.96	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86885	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	86886	 1	 133.57	 46.86	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86887	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86888	 1	 12.92	 2.97	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86889	 1	 9.88	 2.26	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86890	 1	 20.82	 4.74	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86891	 1	 15.11	 7.29	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86892	 1	 15.85	 7.63	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86893	 1	 30.56	 13.53	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86894	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86895	 1	 9.39	 4.01	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86896	 1	 7.97	 4.67	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86897	 1	 7.05	 4.26	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86898	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86899	 1	 9.97	 6.01	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86900	 1	 13.38	 6.57	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86901	 1	 4.95	 1.16	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86902	 1	 4.61	 1.07	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86903	 1	 4.88	 1.14	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86904	 1	 11.43	 2.69	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86905	 1	 5.94	 3.28	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86906	 1	 7.92	 5.11	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86907	 1	 12.87	 6.67	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86908	 1	 43.26	 20.94	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86909	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86910	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86911	 1	 15.44	 8.27	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86912	 1	 16.43	 6.81	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86913	 1	 22.13	 8.9	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86914	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86915	 1	 19.6	 9.15	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86916	 1	 3.35	 2.1	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86917	 1	 15.78	 9.55	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86918	 1	 20.5	 9.36	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86919	 1	 40.53	 17.94	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86920	 1	 22.35	 5.12	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86921	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86922	 1	 4.46	 2.47	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86923	 1	 15.06	 3.45	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86924	 1	 9.18	 2.12	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86925	 1	 26.73	 6.08	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86926	 1	 4.1	 2.08	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86927	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86928	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86929	 1	 29.27	 15.24	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86930	 1	 9.39	 4.75	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86931	 1	 3.95	 2.33	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86932	 1	 15.31	 8.42	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86933	 1	 13.73	 7.9	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86934	 1	 8.14	 3.98	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86935	 1	 27.24	 10.74	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86936	 1	 12.7	 4.84	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86937	 1	 4.51	 2.65	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86938	 1	 6.59	 3.52	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86939	 1	 14.94	 6.92	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86940	 1	 7.32	 4.02	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86941	 1	 7.29	 3.59	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86942	 1	 6.22	 3.62	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86943	 1	 3.84	 2.21	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86944	 1	 33.85	 13.48	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86945	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86946	 1	 19.34	 7.34	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86947	 1	 6.56	 4.06	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86948	 1	 6.19	 3.84	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86949	 1	 11.17	 6.66	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86950	 1	 3.87	 2.44	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86951	 1	 12.43	 5.41	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86952	 1	 15.98	 9.06	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86953	 1	 7.25	 3.92	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86954	 1	 2.96	 1.92	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86955	 1	 17.59	 6.83	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86956	 1	 46.1	 22.2	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86957	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86958	 1	 16.0	 6.21	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86959	 1	 27.23	 11.37	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86960	 1	 30.3	 12.53	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86961	 1	 7.98	 4.75	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86962	 1	 24.21	 10.6	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86963	 1	 3.6	 2.27	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86964	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86965	 1	 19.84	 11.05	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86966	 1	 9.52	 5.19	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86967	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86968	 1	 28.72	 15.69	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86969	 1	 3.06	 1.66	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86970	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86971	 1	 12.4	 6.86	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86972	 1	 34.87	 14.22	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86973	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86974	 1	 8.99	 5.57	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86975	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86976	 1	 27.69	 11.81	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86977	 1	 24.09	 12.52	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86978	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86979	 1	 21.67	 13.4	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86980	 1	 16.55	 8.77	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86981	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	86982	 1	 48.37	 23.43	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86983	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86984	 1	 5.8	 3.76	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86985	 1	 13.84	 7.4	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86986	 1	 25.66	 13.25	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86987	 1	 5.67	 2.75	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86988	 1	 16.65	 3.88	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86989	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	86990	 1	 34.56	 14.83	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86991	 1	 11.42	 4.06	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86992	 1	 11.69	 2.71	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86993	 1	 20.07	 8.95	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86994	 1	 6.14	 3.12	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86995	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86996	 1	 3.8	 2.12	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86997	 1	 11.96	 6.53	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86998	 1	 3.33	 1.91	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	86999	 1	 9.95	 5.49	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87000	 1	 4.87	 2.69	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87001	 1	 24.1	 9.9	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87002	 1	 21.63	 4.97	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87003	 1	 36.54	 17.8	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87004	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87005	 1	 8.84	 5.35	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87006	 1	 12.11	 8.04	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87007	 1	 12.75	 7.3	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87008	 1	 13.0	 7.97	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87009	 1	 9.07	 5.76	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87010	 1	 3.43	 2.14	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87011	 1	 15.77	 3.62	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87012	 1	 3.63	 1.78	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87013	 1	 6.31	 1.45	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87014	 1	 23.05	 10.59	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87015	 1	 30.07	 6.74	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87016	 1	 27.11	 12.51	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87017	 1	 14.31	 7.83	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87018	 1	 13.11	 4.93	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87019	 1	 23.82	 14.06	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87020	 1	 21.72	 11.87	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87021	 1	 16.63	 8.65	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87022	 1	 109.24	 46.81	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87023	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87024	 1	 12.74	 6.07	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87025	 1	 15.56	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87026	 1	 17.02	 3.88	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87027	 1	 16.1	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87028	 1	 32.04	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87029	 1	 31.87	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87030	 1	 79.47	 37.69	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87031	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87032	 1	 11.84	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87033	 1	 83.0	 18.88	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87034	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87035	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87036	 1	 6.81	 1.56	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87037	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87038	 1	 11.16	 2.55	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87039	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87040	 1	 8.21	 1.87	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87041	 1	 34.42	 7.8	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87042	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87043	 1	 73.49	 36.52	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87044	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87045	 1	 20.56	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87046	 1	 20.45	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87047	 1	 25.49	 5.79	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87048	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87049	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87050	 1	 10.5	 4.34	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87051	 1	 10.44	 5.33	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87052	 1	 18.42	 8.48	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87053	 1	 84.16	 33.79	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87054	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87055	 1	 20.78	 8.95	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87056	 1	 34.96	 16.18	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87057	 1	 33.73	 12.5	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87058	 1	 9.97	 4.59	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87059	 1	 9.22	 4.63	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87060	 1	 3.07	 1.86	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87061	 1	 7.48	 4.33	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87062	 1	 2.4	 1.24	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87063	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87064	 1	 3.87	 2.25	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87065	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87066	 1	 96.24	 34.72	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87067	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87068	 1	 18.88	 9.77	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87069	 1	 12.23	 7.75	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87070	 1	 19.71	 10.14	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87071	 1	 21.24	 7.45	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87072	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87073	 1	 43.94	 19.41	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87074	 1	 10.59	 5.68	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87075	 1	 27.25	 10.66	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87076	 1	 5.48	 3.58	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87077	 1	 10.31	 6.2	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87078	 1	 5.04	 3.0	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87079	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87080	 1	 17.28	 9.34	 0.0	 0.0	 31	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87081	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87082	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87083	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87084	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87085	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87086	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87087	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87088	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87089	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87090	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87091	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87092	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87093	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87094	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87095	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87096	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87097	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87098	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87099	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87100	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87101	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87102	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87104	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87105	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87106	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87107	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87108	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87109	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87110	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87111	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87114	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87115	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87117	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87118	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87120	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87121	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87122	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87123	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87124	 1	 8.61	 4.59	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87125	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87127	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87129	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87131	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87132	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87133	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87134	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87136	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87137	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87138	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87139	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87140	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87141	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87142	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87143	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87144	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87145	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87146	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87147	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87148	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87149	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87150	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87151	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87152	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87153	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87154	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87155	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87156	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87157	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87158	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87159	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87160	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87161	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87162	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87163	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87164	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87165	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87166	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87167	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87168	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87169	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87170	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87171	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87172	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87173	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87174	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87175	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87176	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87177	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87178	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87179	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87180	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87181	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87182	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87183	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87184	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87185	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87186	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87187	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87188	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87189	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87190	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87191	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87192	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87193	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87194	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87195	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87196	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87197	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87198	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87199	 2	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87200	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87201	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87202	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87203	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87204	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87205	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87206	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87207	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87208	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87209	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87210	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87211	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87212	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87213	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87214	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87215	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87216	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87217	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87218	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87219	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87220	 1	 68.88	 24.1	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87221	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87222	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87223	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87224	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87225	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87226	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87227	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87228	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87229	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87230	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87231	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87232	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87233	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87234	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87235	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87236	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87237	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87238	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87239	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87240	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87241	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87242	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87243	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87244	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87245	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87246	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87247	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87248	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87249	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87250	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87251	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87252	 2	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87253	 1	 5.52	 2.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87254	 1	 6.0	 3.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87255	 1	 16.51	 7.55	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87256	 1	 10.76	 4.91	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87257	 1	 24.86	 5.89	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87258	 1	 3.46	 1.76	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87259	 1	 25.97	 8.47	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87260	 1	 11.11	 4.79	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87261	 1	 7.36	 2.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87262	 1	 11.98	 4.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87263	 1	 35.48	 8.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87264	 1	 21.97	 5.01	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87265	 1	 5.94	 2.67	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87266	 1	 8.78	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87267	 1	 6.28	 1.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87268	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87269	 1	 33.35	 8.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87270	 1	 6.82	 2.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87271	 1	 17.73	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87272	 1	 20.52	 8.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87273	 1	 14.81	 3.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87274	 1	 18.83	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87275	 1	 6.89	 1.57	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87276	 1	 13.63	 5.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87277	 1	 15.09	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87278	 1	 12.09	 4.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87279	 1	 8.9	 3.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87280	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87281	 1	 20.36	 6.44	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87282	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87283	 1	 3.5	 1.73	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87284	 1	 4.64	 2.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87285	 1	 7.51	 2.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87286	 1	 23.47	 8.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87287	 1	 14.44	 6.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87288	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87289	 1	 12.7	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87290	 1	 18.5	 5.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87291	 1	 6.02	 2.82	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87292	 1	 7.16	 2.79	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87293	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87294	 1	 114.02	 47.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87295	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87296	 1	 18.5	 7.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87297	 1	 4.18	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87298	 1	 7.52	 2.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87300	 1	 11.02	 3.76	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87301	 1	 9.64	 3.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87302	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87303	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87304	 1	 21.72	 9.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87305	 1	 14.32	 7.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87306	 1	 12.07	 4.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87307	 1	 23.68	 8.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87308	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87309	 1	 33.14	 13.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87310	 1	 33.42	 8.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87311	 1	 3.93	 1.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87312	 1	 15.76	 5.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87313	 1	 19.06	 7.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87314	 1	 11.06	 5.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87315	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87316	 1	 1.95	 0.78	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87317	 1	 7.78	 3.67	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87318	 1	 4.66	 1.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87319	 1	 6.75	 2.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87320	 1	 9.76	 3.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87321	 1	 12.58	 4.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87322	 1	 5.88	 2.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87323	 1	 27.43	 6.21	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87324	 1	 38.08	 8.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87325	 1	 9.06	 3.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87326	 1	 25.76	 10.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87327	 1	 91.86	 40.39	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87328	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87329	 1	 14.11	 4.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87330	 1	 8.4	 3.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87331	 1	 8.24	 3.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87332	 1	 6.79	 2.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87333	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87334	 1	 5.05	 1.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87335	 1	 7.36	 2.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87336	 1	 3.35	 1.57	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87337	 1	 8.53	 3.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87338	 1	 15.91	 6.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87339	 1	 6.38	 2.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87340	 1	 7.21	 3.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87341	 1	 15.9	 5.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87342	 1	 12.91	 5.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87343	 1	 13.04	 6.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87344	 1	 10.46	 4.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87345	 1	 42.3	 17.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87346	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87347	 1	 15.64	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87348	 1	 28.0	 10.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87349	 1	 15.17	 4.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87350	 1	 18.99	 6.26	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87351	 1	 13.85	 4.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87352	 1	 17.27	 4.57	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87353	 1	 18.67	 6.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87354	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87355	 1	 28.49	 12.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87356	 1	 17.87	 7.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87357	 1	 9.66	 4.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87358	 1	 23.75	 8.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87359	 1	 17.78	 5.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87360	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87361	 1	 16.7	 5.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87362	 1	 5.03	 2.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87363	 1	 11.43	 5.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87364	 1	 17.06	 7.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87365	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87366	 1	 9.13	 3.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87367	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87368	 1	 9.46	 3.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87369	 1	 23.84	 9.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87370	 1	 5.08	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87371	 1	 7.32	 3.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87372	 1	 12.17	 5.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87373	 1	 23.7	 6.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87374	 1	 45.1	 16.02	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87375	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87376	 1	 4.43	 1.96	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87377	 1	 15.63	 7.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87378	 1	 23.68	 9.15	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87379	 1	 18.96	 7.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87380	 1	 27.89	 9.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87381	 1	 15.78	 4.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87382	 1	 8.93	 3.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87383	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87384	 1	 6.6	 2.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87385	 1	 5.52	 2.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87386	 1	 7.76	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87387	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87388	 1	 8.36	 3.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87389	 1	 3.43	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87390	 1	 7.57	 3.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87391	 1	 10.75	 3.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87392	 1	 11.69	 4.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87393	 1	 7.55	 3.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87394	 1	 2.64	 1.08	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87395	 1	 4.31	 2.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87396	 1	 13.51	 5.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87397	 1	 12.56	 4.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87398	 1	 9.16	 3.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87399	 1	 7.22	 2.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87400	 1	 6.77	 2.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87401	 1	 10.29	 4.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87402	 1	 23.71	 9.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87403	 1	 12.14	 3.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87404	 1	 11.04	 4.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87405	 1	 12.16	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87406	 1	 30.57	 12.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87407	 1	 17.17	 6.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87408	 1	 37.6	 12.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87409	 1	 13.61	 3.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87410	 1	 46.18	 16.33	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87411	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87412	 1	 20.46	 6.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87413	 1	 5.65	 2.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87414	 1	 38.31	 12.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87415	 1	 6.63	 2.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87416	 1	 15.21	 6.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87417	 1	 12.5	 4.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87418	 1	 7.12	 2.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87419	 1	 89.89	 24.41	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87420	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87421	 1	 11.54	 4.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87422	 1	 9.35	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87423	 1	 42.41	 9.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87424	 1	 6.41	 2.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87425	 1	 3.49	 1.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87426	 1	 6.91	 3.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87427	 1	 12.27	 5.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87428	 1	 12.18	 5.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87429	 1	 81.51	 31.76	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87430	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87431	 1	 14.66	 6.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87432	 1	 5.66	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87433	 1	 6.98	 3.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87434	 1	 12.83	 4.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87435	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87436	 1	 17.55	 8.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87437	 1	 21.44	 6.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87438	 1	 9.9	 4.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87439	 1	 10.85	 5.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87440	 1	 6.85	 3.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87441	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87442	 1	 2.19	 0.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87443	 1	 15.69	 6.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87444	 1	 22.23	 8.46	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87445	 1	 13.67	 4.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87446	 1	 9.23	 3.68	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87447	 1	 13.33	 5.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87448	 1	 11.72	 5.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87449	 1	 16.22	 5.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87450	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87451	 1	 9.93	 5.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87452	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87453	 1	 5.85	 3.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87454	 1	 7.13	 3.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87455	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87456	 1	 7.55	 3.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87457	 1	 6.29	 3.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87458	 1	 3.27	 1.33	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87460	 1	 11.76	 3.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87461	 1	 12.6	 5.26	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87462	 1	 9.63	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87463	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87464	 1	 18.32	 6.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87465	 1	 25.34	 10.94	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87466	 1	 36.17	 8.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87467	 1	 1.34	 0.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87468	 1	 2.95	 1.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87469	 1	 2.19	 1.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87470	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87471	 1	 5.46	 1.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87472	 1	 8.07	 1.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87474	 1	 2.11	 0.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87475	 1	 15.5	 3.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87476	 1	 15.54	 5.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87477	 1	 16.52	 5.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87478	 1	 9.86	 2.26	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87479	 1	 5.13	 2.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87480	 1	 9.28	 3.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87481	 1	 15.06	 6.36	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87482	 1	 12.76	 4.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87483	 1	 10.77	 2.47	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87484	 1	 10.12	 2.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87485	 1	 13.37	 5.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87486	 1	 7.63	 2.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87487	 1	 23.62	 5.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87488	 1	 9.43	 4.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87489	 1	 12.37	 5.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87490	 1	 9.84	 4.46	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87491	 1	 15.58	 6.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87492	 1	 138.02	 59.71	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87493	 1	 10.71	 4.03	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87494	 1	 19.04	 8.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87495	 1	 2.74	 1.36	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87496	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87497	 1	 22.56	 8.96	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87498	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87499	 1	 22.28	 7.36	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87500	 1	 26.42	 10.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87501	 1	 10.65	 3.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87502	 1	 11.2	 4.17	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87503	 1	 19.66	 4.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87504	 1	 32.73	 7.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87505	 1	 19.77	 4.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87506	 1	 34.32	 7.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87507	 1	 12.14	 2.75	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87508	 1	 7.9	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87509	 1	 9.12	 4.23	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87510	 1	 1.77	 0.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87511	 1	 2.77	 1.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87512	 1	 4.2	 1.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87513	 1	 113.19	 41.68	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87514	 1	 13.54	 4.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87515	 1	 4.05	 1.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87516	 1	 2.88	 1.01	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87517	 1	 10.54	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87518	 1	 9.9	 3.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87519	 1	 21.94	 9.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87520	 1	 11.0	 5.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87521	 1	 5.53	 2.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87522	 1	 7.17	 3.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87523	 1	 8.89	 3.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87524	 1	 2.33	 0.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87525	 1	 3.34	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87526	 1	 10.2	 4.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87527	 1	 0.89	 0.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87528	 1	 7.52	 3.72	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87529	 1	 6.51	 3.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87530	 1	 4.94	 2.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87531	 1	 4.7	 2.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87532	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87533	 1	 89.83	 37.74	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87534	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87535	 1	 6.77	 2.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87536	 1	 24.04	 9.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87537	 1	 2.53	 0.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87538	 1	 8.43	 3.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87539	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87540	 1	 21.11	 7.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87541	 1	 76.97	 32.54	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87542	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87543	 1	 17.72	 7.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87544	 1	 11.95	 5.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87545	 1	 14.63	 6.26	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87546	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87547	 1	 19.13	 8.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87548	 1	 11.96	 5.78	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87549	 1	 19.21	 7.42	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87550	 1	 8.96	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87551	 1	 10.32	 4.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87552	 1	 43.06	 17.67	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87553	 1	 11.9	 4.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87554	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87555	 1	 137.31	 27.13	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87556	 1	 33.3	 12.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87557	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87558	 1	 26.11	 10.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87559	 1	 5.93	 2.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87560	 1	 34.12	 10.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87561	 1	 16.89	 7.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87562	 1	 9.35	 3.46	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87563	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87564	 1	 12.48	 5.85	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87565	 1	 7.68	 2.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87566	 1	 8.25	 3.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87567	 1	 10.29	 5.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87568	 1	 6.24	 2.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87569	 1	 6.19	 2.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87570	 1	 10.55	 4.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87571	 1	 18.77	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87572	 1	 37.92	 13.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87573	 1	 15.64	 6.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87574	 1	 16.81	 5.45	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87575	 1	 66.32	 23.6	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87576	 1	 46.67	 23.36	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87577	 1	 17.26	 6.46	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87578	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87579	 1	 34.17	 9.23	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87580	 1	 21.91	 8.57	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87581	 1	 17.97	 7.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87582	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87583	 1	 301.1	 117.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87584	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87585	 1	 29.18	 9.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87586	 1	 11.98	 5.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87587	 1	 6.97	 3.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87588	 1	 18.64	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87589	 1	 8.33	 3.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87590	 1	 9.43	 4.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87591	 1	 10.07	 4.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87592	 1	 5.45	 2.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87593	 1	 6.88	 3.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87594	 1	 4.55	 1.95	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87595	 1	 6.58	 2.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87596	 1	 6.24	 2.36	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87597	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87598	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87599	 1	 9.09	 3.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87600	 1	 30.46	 11.89	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87601	 1	 9.66	 4.63	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87602	 1	 18.03	 6.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87604	 1	 13.06	 2.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87605	 1	 26.29	 6.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87606	 1	 9.73	 4.36	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87607	 1	 10.19	 4.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87608	 1	 7.04	 2.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87609	 1	 22.92	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87610	 1	 34.69	 12.42	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87611	 1	 7.71	 2.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87612	 1	 5.92	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87613	 1	 5.91	 2.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87614	 1	 14.36	 7.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87615	 1	 10.87	 3.21	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87616	 1	 5.72	 2.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87617	 1	 5.43	 2.71	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87618	 1	 41.57	 14.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87619	 1	 7.89	 3.29	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87620	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87621	 1	 6.57	 2.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87622	 1	 24.81	 7.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87623	 1	 13.52	 3.94	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87624	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87625	 1	 6.19	 2.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87626	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87627	 1	 7.28	 3.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87628	 1	 28.94	 8.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87629	 1	 6.99	 3.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87630	 1	 25.56	 9.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87631	 1	 34.22	 8.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87632	 1	 3.43	 1.44	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87633	 1	 7.36	 3.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87634	 1	 4.4	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87635	 1	 36.38	 17.17	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87636	 1	 19.59	 6.52	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87637	 1	 11.88	 4.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87638	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87639	 1	 22.15	 6.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87640	 1	 4.93	 2.46	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87641	 1	 26.52	 8.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87642	 1	 19.3	 6.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87643	 1	 9.51	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87644	 1	 19.14	 7.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87645	 1	 7.06	 2.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87646	 1	 15.36	 4.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87647	 1	 14.33	 6.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87648	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87649	 1	 45.01	 15.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87650	 1	 16.79	 6.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87651	 1	 6.54	 2.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87652	 1	 14.55	 6.21	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87653	 1	 12.01	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87654	 1	 7.26	 3.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87655	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87656	 1	 98.96	 26.89	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87657	 1	 43.07	 11.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87658	 1	 2.49	 1.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87659	 1	 7.18	 2.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87660	 1	 18.63	 7.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87661	 1	 1.79	 8.22	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87662	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87663	 1	 0.29	 1.63	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87664	 1	 5.54	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87665	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87666	 1	 2.74	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87667	 1	 1.27	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87668	 1	 0.37	 0.08	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87669	 1	 1.7	 0.39	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87670	 1	 1.99	 11.87	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87671	 1	 3.47	 15.03	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87672	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87673	 1	 17.76	 50.42	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87674	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87675	 1	 1.77	 9.61	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87676	 1	 1.61	 10.32	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87677	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87678	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87679	 1	 1.28	 6.72	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87680	 1	 2.99	 13.13	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87681	 1	 2.67	 14.21	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87682	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87683	 1	 1.58	 4.76	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87684	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87685	 1	 1.55	 7.31	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87686	 1	 3.41	 15.28	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87687	 1	 11.84	 47.11	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87688	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87689	 1	 1.57	 7.62	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87690	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87691	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87692	 1	 0.36	 1.75	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87693	 1	 0.72	 4.41	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87694	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87695	 1	 1.97	 10.34	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87696	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87697	 1	 0.69	 4.43	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87698	 1	 0.96	 4.93	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87699	 1	 1.03	 4.59	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87700	 1	 1.2	 6.78	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87701	 1	 1.59	 7.26	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87702	 1	 2.7	 12.84	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87703	 1	 1.74	 9.92	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87704	 1	 1.15	 5.96	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87705	 1	 5.02	 13.81	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87706	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87707	 1	 1.9	 8.03	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87708	 1	 0.73	 3.94	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87709	 1	 0.89	 4.77	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87710	 1	 1.67	 9.4	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87711	 1	 1.97	 8.23	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87712	 1	 1.99	 9.25	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87713	 1	 1.54	 7.1	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87714	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87715	 1	 0.52	 3.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87716	 1	 1.71	 7.78	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87717	 1	 14.51	 72.63	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87718	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87719	 1	 1.12	 6.51	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87720	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87721	 1	 0.66	 3.49	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87722	 1	 1.26	 6.67	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87723	 1	 8.03	 31.11	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87724	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87725	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87726	 1	 8.94	 51.7	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87727	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87728	 1	 0.52	 3.15	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87729	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87730	 1	 2.18	 9.15	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87731	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87732	 1	 2.1	 11.73	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87733	 1	 1.56	 0.36	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87734	 1	 1.3	 5.62	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87735	 1	 0.79	 4.77	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87736	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87737	 1	 1.34	 6.44	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87738	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87739	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87740	 1	 2.15	 11.11	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87741	 1	 1.08	 5.98	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87742	 1	 1.16	 7.45	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87743	 1	 1.04	 5.75	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87744	 1	 3.76	 18.86	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87745	 1	 0.68	 3.7	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87746	 1	 2.71	 16.23	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87747	 1	 0.7	 3.34	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87748	 1	 1.11	 6.41	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87749	 1	 2.22	 11.36	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87750	 1	 2.03	 6.91	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87751	 1	 0.95	 3.81	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87752	 1	 0.86	 3.52	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87753	 1	 1.85	 10.16	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87754	 1	 1.25	 6.24	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87755	 1	 1.47	 7.23	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87756	 1	 0.9	 3.94	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87757	 1	 0.54	 3.19	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87758	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87759	 1	 1.7	 7.58	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87760	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87761	 1	 1.08	 5.71	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87762	 1	 1.34	 8.54	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87763	 1	 0.46	 2.77	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87764	 1	 1.15	 5.46	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87765	 1	 0.62	 3.89	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87766	 1	 0.51	 3.11	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87767	 1	 2.2	 8.38	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87768	 1	 5.36	 25.52	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87769	 1	 1.36	 6.31	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87770	 1	 0.87	 4.48	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87771	 1	 4.05	 14.91	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87772	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87773	 1	 2.42	 10.9	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87774	 1	 0.98	 4.98	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87775	 1	 0.39	 2.24	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87776	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87777	 1	 7.68	 40.32	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87778	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87779	 1	 0.78	 3.97	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87780	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87781	 1	 1.09	 5.49	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87782	 1	 1.03	 5.63	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87783	 1	 1.23	 6.19	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87784	 1	 2.1	 0.51	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87785	 1	 1.82	 0.43	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87786	 1	 1.89	 10.76	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87787	 1	 1.71	 10.34	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87788	 1	 2.26	 12.69	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87789	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87790	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87791	 1	 2.35	 10.16	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87792	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87793	 1	 4.48	 23.58	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87794	 1	 0.87	 5.24	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87795	 1	 1.82	 10.47	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87796	 1	 3.07	 14.91	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87797	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87798	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87799	 1	 2.43	 14.37	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87800	 1	 1.36	 8.21	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87801	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87802	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87803	 1	 0.49	 2.28	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87804	 1	 1.21	 6.76	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87805	 1	 0.81	 3.81	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87806	 1	 1.17	 6.03	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87807	 1	 7.13	 27.59	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87808	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87809	 1	 3.23	 19.35	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87810	 1	 1.53	 7.37	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87811	 1	 1.38	 7.45	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87812	 1	 6.25	 21.52	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87813	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87814	 1	 0.96	 6.09	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87815	 1	 0.7	 0.16	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87816	 1	 1.2	 0.29	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87817	 1	 1.39	 0.34	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87818	 1	 0.64	 0.15	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87819	 1	 0.41	 2.08	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87820	 1	 3.03	 13.57	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87821	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87822	 1	 0.73	 3.34	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87823	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87824	 1	 2.84	 15.43	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87825	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87826	 1	 0.49	 3.23	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87827	 1	 0.7	 4.35	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87828	 1	 1.54	 8.77	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87829	 1	 1.33	 0.3	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87830	 1	 1.62	 7.62	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87831	 1	 1.83	 10.57	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87832	 1	 0.96	 3.7	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87833	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87834	 1	 9.03	 35.01	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87835	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87836	 1	 1.91	 10.22	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87837	 1	 2.16	 10.07	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87838	 1	 1.32	 6.44	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87839	 1	 0.51	 2.63	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87840	 1	 0.87	 4.47	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87841	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87842	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87843	 1	 1.65	 6.66	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87844	 1	 5.35	 27.39	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87845	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87846	 1	 0.49	 2.74	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87847	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87848	 1	 0.63	 3.83	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87849	 1	 1.06	 5.35	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87850	 1	 0.66	 3.87	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87851	 1	 0.78	 4.46	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87852	 1	 0.66	 4.1	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87853	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87854	 1	 1.1	 6.46	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87855	 1	 0.65	 4.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87856	 1	 0.58	 2.85	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87857	 1	 0.6	 3.47	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87858	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87859	 1	 0.96	 5.1	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87860	 1	 0.66	 3.94	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87861	 1	 0.75	 4.34	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87862	 1	 0.98	 5.49	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87863	 1	 1.13	 7.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87864	 1	 3.94	 14.35	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87865	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87866	 1	 0.73	 4.54	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87867	 1	 2.1	 11.89	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87868	 1	 1.43	 8.83	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87869	 1	 0.86	 5.2	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87870	 1	 0.87	 4.3	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87871	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87872	 1	 1.42	 7.01	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87873	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87874	 1	 0.89	 4.39	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87875	 1	 0.76	 4.8	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87876	 1	 0.38	 2.47	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87877	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87878	 1	 5.6	 26.41	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87879	 1	 2.27	 11.99	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87880	 1	 1.31	 6.27	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87881	 1	 0.91	 5.41	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87882	 1	 0.8	 3.99	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87883	 1	 0.68	 4.14	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87884	 1	 0.88	 4.82	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87885	 1	 0.9	 4.39	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87886	 1	 1.85	 8.83	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87887	 1	 2.29	 12.23	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87888	 1	 0.99	 4.97	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87889	 1	 2.72	 10.62	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87890	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87891	 1	 1.25	 7.77	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87892	 1	 0.96	 5.34	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87893	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87894	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87895	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87896	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87897	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87898	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87899	 1	 4.03	 25.48	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87900	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87901	 1	 0.78	 4.48	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87902	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87903	 1	 31.15	 137.44	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87904	 1	 8.22	 42.64	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87905	 1	 2.62	 14.12	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87906	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87907	 1	 9.97	 53.18	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87908	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87909	 1	 2.96	 13.91	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87910	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87911	 1	 2.14	 11.31	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87912	 1	 0.54	 3.17	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87913	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87914	 1	 2.03	 11.94	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87915	 1	 1.23	 5.64	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87916	 1	 0.71	 4.18	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87917	 1	 1.92	 9.29	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87918	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87919	 1	 0.75	 4.02	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87920	 1	 1.65	 8.94	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87921	 1	 0.75	 4.3	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87922	 1	 1.84	 10.39	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87923	 1	 0.74	 3.58	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87924	 1	 0.96	 4.05	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87925	 1	 1.16	 6.57	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87926	 1	 1.3	 7.72	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87927	 1	 2.62	 13.44	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87928	 1	 1.04	 6.18	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87929	 1	 2.05	 0.47	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87930	 1	 0.26	 0.07	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87931	 1	 2.14	 10.18	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87932	 1	 2.04	 0.47	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87933	 1	 2.08	 0.48	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87934	 1	 1.69	 0.39	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87935	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87936	 1	 2.89	 12.75	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87937	 1	 1.76	 10.69	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87938	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87939	 1	 0.52	 3.37	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87940	 1	 0.53	 0.12	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87941	 1	 1.04	 0.24	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87942	 1	 1.36	 0.32	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87943	 1	 0.96	 0.23	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87944	 1	 1.05	 4.76	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87945	 1	 2.11	 10.77	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87946	 1	 1.65	 7.94	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87947	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87948	 1	 2.85	 12.85	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87949	 1	 1.14	 5.49	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87950	 1	 3.19	 17.84	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87951	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87952	 1	 2.86	 12.02	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87953	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87954	 1	 1.42	 9.03	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87955	 1	 1.58	 8.32	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87956	 1	 1.54	 8.66	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87957	 1	 2.1	 13.28	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87958	 1	 3.26	 20.12	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87959	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87960	 1	 0.82	 4.85	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87961	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87962	 1	 2.47	 14.61	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87963	 1	 15.9	 71.39	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87964	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87965	 1	 1.29	 6.23	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87966	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87967	 1	 0.59	 2.85	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87968	 1	 3.3	 15.27	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87969	 1	 3.13	 17.02	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87970	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87971	 1	 5.67	 23.65	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87972	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87973	 1	 1.95	 9.2	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87974	 1	 1.72	 6.55	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87975	 1	 5.69	 28.99	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87976	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87977	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87978	 1	 27.49	 139.06	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87979	 1	 2.09	 9.41	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87980	 1	 1.12	 5.77	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87981	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87982	 1	 2.7	 17.54	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87983	 1	 2.55	 11.41	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87984	 1	 3.18	 9.86	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87985	 1	 2.16	 9.7	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87986	 1	 0.35	 1.97	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87987	 1	 0.39	 2.36	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87988	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87989	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	87990	 1	 2.27	 11.38	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87991	 1	 0.56	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87992	 1	 0.8	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87993	 1	 1.89	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87994	 1	 1.05	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87995	 1	 1.86	 10.25	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87996	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	87997	 1	 2.19	 9.44	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87998	 1	 0.91	 4.78	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	87999	 1	 1.64	 8.27	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88000	 1	 4.15	 14.13	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88001	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88002	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88003	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88004	 1	 0.32	 2.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88005	 1	 1.3	 6.88	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88006	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88007	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88008	 1	 2.28	 7.85	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88009	 1	 1.27	 7.64	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88010	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88011	 1	 1.44	 7.49	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88012	 1	 1.42	 8.04	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88013	 1	 4.45	 18.28	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88014	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88015	 1	 1.23	 7.18	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88016	 1	 1.88	 10.26	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88017	 1	 0.97	 6.05	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88018	 1	 1.84	 7.66	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88019	 1	 1.87	 9.74	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88020	 1	 1.47	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88021	 1	 1.46	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88022	 1	 0.53	 0.12	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88023	 1	 0.24	 0.06	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88024	 1	 2.24	 0.54	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88025	 1	 1.23	 0.3	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88026	 1	 0.57	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88027	 1	 0.71	 4.11	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88028	 1	 2.41	 0.53	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88029	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88030	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88031	 1	 0.92	 4.7	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88032	 1	 0.28	 1.7	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88033	 1	 1.75	 8.86	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88034	 1	 2.97	 14.71	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88035	 1	 1.75	 10.35	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88036	 1	 2.04	 10.99	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88037	 1	 0.78	 3.54	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88038	 1	 1.39	 6.33	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88039	 1	 1.68	 7.11	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88040	 1	 5.95	 27.83	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88041	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88042	 1	 2.44	 9.33	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88043	 1	 1.63	 8.29	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88044	 1	 9.38	 28.19	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88045	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88046	 1	 2.17	 8.85	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88047	 1	 5.62	 16.81	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88048	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88049	 1	 0.89	 5.46	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88050	 1	 0.27	 1.38	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88051	 1	 1.9	 9.74	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88052	 1	 1.31	 6.86	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88053	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88054	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88055	 1	 1.01	 6.18	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88056	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88057	 1	 2.95	 15.92	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88058	 1	 1.73	 9.98	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88059	 1	 1.07	 5.48	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88060	 1	 1.81	 10.77	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88061	 1	 1.66	 0.4	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88062	 1	 1.45	 8.43	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88063	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88064	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88065	 1	 7.14	 32.7	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88066	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88067	 1	 1.73	 8.7	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88068	 1	 1.35	 6.35	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88069	 1	 1.01	 6.83	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88070	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88071	 1	 1.5	 0.35	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88072	 1	 2.15	 10.12	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88073	 1	 0.69	 3.61	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88074	 1	 0.71	 3.37	 0.0	 0.0	 12	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88075	 1	 3.91	 1.93	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88076	 1	 23.62	 12.41	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88077	 1	 5.33	 3.15	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88078	 1	 23.44	 10.19	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88079	 1	 6.85	 4.65	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88080	 1	 5.66	 3.08	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88081	 1	 3.91	 1.94	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88082	 1	 7.31	 4.57	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88083	 1	 10.23	 5.47	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88084	 1	 4.49	 1.81	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88085	 1	 5.26	 2.76	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88086	 1	 8.71	 3.9	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88087	 1	 6.05	 2.93	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88088	 1	 12.03	 7.06	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88089	 1	 7.95	 4.3	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88090	 1	 9.14	 4.57	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88091	 1	 10.8	 4.49	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88092	 1	 10.51	 5.72	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88093	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88094	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88095	 1	 5.26	 2.24	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88096	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88097	 1	 5.56	 3.43	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88098	 1	 2.15	 1.19	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88099	 1	 6.53	 3.86	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88100	 1	 10.22	 6.2	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88101	 1	 5.72	 3.13	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88102	 1	 7.78	 4.41	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88103	 1	 7.64	 4.44	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88104	 1	 9.58	 5.42	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88105	 1	 23.57	 8.76	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88106	 1	 10.12	 5.21	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88107	 1	 16.12	 8.49	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88108	 1	 3.49	 2.05	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88109	 1	 7.9	 3.71	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88110	 1	 5.79	 3.59	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88111	 1	 16.02	 8.71	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88112	 1	 12.97	 7.04	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88113	 1	 18.84	 7.8	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88114	 1	 30.99	 15.94	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88115	 1	 10.42	 5.27	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88116	 1	 7.79	 3.72	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88117	 1	 7.33	 3.84	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88118	 1	 12.23	 5.15	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88119	 1	 31.9	 7.35	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88120	 1	 5.61	 3.37	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88121	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88122	 1	 29.06	 18.92	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88123	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88124	 1	 7.94	 4.61	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88125	 1	 9.34	 5.84	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88126	 1	 11.89	 4.23	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88127	 1	 25.48	 12.94	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88128	 1	 7.22	 4.74	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88129	 1	 9.25	 4.51	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88130	 1	 33.53	 17.42	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88131	 1	 12.33	 6.55	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88132	 1	 7.36	 3.89	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88133	 1	 5.23	 2.69	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88134	 1	 21.11	 12.01	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88135	 1	 8.35	 4.78	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88136	 1	 25.13	 13.41	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88137	 1	 9.07	 5.77	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88138	 1	 3.78	 1.99	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88139	 1	 2.27	 1.41	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88140	 1	 3.95	 2.29	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88141	 1	 14.57	 4.65	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88142	 1	 4.05	 2.22	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88143	 1	 2.23	 1.29	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88144	 1	 7.52	 3.73	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88145	 1	 6.33	 3.06	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88146	 1	 4.54	 2.46	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88147	 1	 16.73	 8.47	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88148	 1	 2.93	 1.64	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88149	 1	 5.28	 3.57	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88150	 1	 8.15	 4.11	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88151	 1	 3.7	 2.14	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88152	 1	 7.28	 3.28	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88153	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88154	 1	 23.37	 11.34	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88155	 1	 2.36	 1.14	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88156	 1	 5.43	 2.53	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88157	 1	 6.89	 3.31	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88158	 1	 5.78	 3.67	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88159	 1	 1.61	 0.96	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88160	 1	 9.0	 3.79	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88161	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88162	 1	 23.15	 11.74	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88163	 1	 8.22	 4.64	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88164	 1	 6.83	 3.54	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88165	 1	 15.39	 6.23	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88166	 1	 4.42	 2.6	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88167	 1	 9.68	 5.15	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88168	 1	 3.04	 1.46	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88169	 1	 7.9	 3.84	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88170	 1	 24.32	 14.16	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88171	 1	 4.59	 2.73	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88172	 1	 4.6	 2.65	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88173	 1	 4.78	 2.23	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88174	 1	 6.89	 4.24	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88175	 1	 21.5	 11.35	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88176	 1	 5.16	 2.71	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88177	 1	 4.88	 2.22	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88178	 1	 25.54	 15.05	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88179	 1	 14.09	 7.01	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88180	 1	 16.14	 5.92	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88181	 1	 14.76	 9.18	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88182	 1	 5.41	 3.11	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88183	 1	 8.23	 3.53	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88184	 1	 14.8	 7.58	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88185	 1	 6.43	 3.04	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88186	 1	 8.52	 3.82	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88187	 1	 34.86	 11.68	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88188	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88189	 1	 4.48	 2.23	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88190	 1	 10.52	 5.76	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88191	 1	 9.06	 3.7	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88192	 1	 4.49	 2.73	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88193	 1	 20.44	 14.71	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88194	 1	 11.91	 6.18	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88195	 1	 14.57	 5.47	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88196	 1	 6.3	 2.6	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88197	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88198	 1	 19.36	 10.93	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88199	 1	 12.22	 8.01	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88200	 1	 20.41	 10.9	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88201	 1	 7.77	 4.92	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88202	 1	 0.86	 0.45	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88203	 1	 2.93	 1.56	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88204	 1	 8.83	 4.43	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88205	 1	 5.97	 3.59	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88206	 1	 6.53	 3.07	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88207	 1	 10.41	 3.73	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88208	 1	 14.86	 7.37	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88209	 1	 25.87	 11.48	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88210	 1	 16.61	 6.18	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88211	 1	 13.35	 7.59	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88212	 1	 10.87	 5.39	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88213	 1	 13.64	 4.86	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88214	 1	 6.8	 4.02	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88215	 1	 2.58	 1.27	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88216	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88217	 1	 11.28	 5.85	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88218	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88219	 1	 14.56	 6.92	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88220	 1	 13.19	 7.6	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88221	 1	 5.56	 2.82	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88222	 1	 14.43	 9.44	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88223	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88224	 1	 17.11	 9.17	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88225	 1	 5.49	 2.88	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88226	 1	 16.91	 3.81	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88227	 1	 7.26	 1.6	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88228	 1	 19.63	 4.4	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88229	 1	 3.54	 2.02	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88230	 1	 15.94	 7.73	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88231	 1	 10.37	 4.76	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88232	 1	 3.07	 1.66	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88233	 1	 15.2	 8.09	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88234	 1	 21.17	 9.83	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88235	 1	 11.65	 4.64	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88236	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88237	 1	 20.32	 9.12	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88238	 1	 13.08	 3.02	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88239	 1	 2.16	 1.27	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88240	 1	 7.08	 4.18	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88241	 1	 5.75	 2.67	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88242	 1	 15.14	 7.8	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88243	 1	 8.87	 5.41	 0.0	 0.0	 19	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88244	 1	 5.49	 2.95	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88245	 1	 10.53	 6.77	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88246	 1	 20.97	 10.67	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88247	 1	 15.69	 8.5	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88248	 1	 10.97	 6.04	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88249	 1	 0.0	 0.0	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88250	 1	 4.21	 2.55	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88251	 1	 9.34	 4.6	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88252	 1	 41.01	 15.03	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88253	 1	 10.23	 4.99	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88254	 1	 5.53	 2.61	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88255	 1	 29.1	 17.01	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88256	 1	 2.23	 1.13	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88257	 1	 10.51	 5.34	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88258	 1	 15.48	 8.15	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88259	 1	 15.28	 9.51	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88260	 1	 8.29	 4.2	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88261	 1	 2.53	 1.73	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88262	 1	 7.23	 3.72	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88263	 1	 11.03	 7.79	 0.0	 0.0	 19	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88264	 1	 2.9	 1.78	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88265	 1	 11.15	 3.27	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88266	 1	 10.13	 4.41	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88267	 1	 22.46	 11.83	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88268	 1	 6.16	 3.4	 0.0	 0.0	 19	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88269	 1	 48.63	 12.72	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88270	 1	 3.0	 1.17	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88271	 1	 12.58	 4.35	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88272	 1	 32.99	 7.36	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88273	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88274	 1	 139.02	 42.25	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88275	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88276	 1	 30.96	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88277	 1	 18.17	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88278	 1	 25.33	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88279	 1	 6.67	 2.37	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88280	 1	 22.53	 5.45	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88281	 1	 15.18	 4.9	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88282	 1	 13.18	 4.56	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88283	 1	 27.32	 7.88	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88284	 1	 69.2	 20.32	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88285	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88286	 1	 35.29	 7.94	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88287	 1	 42.82	 9.94	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88288	 1	 15.76	 4.7	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88289	 1	 7.37	 2.29	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88290	 1	 22.55	 6.27	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88291	 1	 19.22	 6.54	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88292	 1	 14.49	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88293	 1	 33.31	 10.18	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88294	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88295	 1	 52.94	 14.88	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88296	 1	 19.64	 4.36	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88297	 1	 16.84	 3.6	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88298	 1	 17.89	 3.97	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88299	 1	 32.82	 10.95	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88300	 1	 11.25	 3.65	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88301	 1	 8.93	 2.03	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88302	 1	 22.11	 5.04	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88303	 1	 15.91	 3.6	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88304	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88305	 1	 9.84	 3.61	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88306	 1	 12.82	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88307	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88308	 1	 39.86	 9.28	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88309	 1	 21.69	 5.6	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88310	 1	 33.85	 10.11	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88311	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88312	 1	 60.89	 20.89	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88313	 1	 15.35	 4.24	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88314	 1	 50.74	 13.14	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88315	 1	 24.15	 5.42	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88316	 1	 21.93	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88317	 1	 92.85	 30.59	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88318	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88319	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88320	 1	 31.71	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88321	 1	 20.3	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88322	 1	 12.65	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88323	 1	 27.5	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88324	 1	 9.08	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88325	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88326	 1	 39.79	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88327	 1	 59.21	 21.67	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88328	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88329	 1	 86.73	 23.91	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88330	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88331	 1	 208.21	 56.1	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88332	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88333	 1	 14.07	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88334	 1	 23.67	 6.49	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88335	 1	 27.23	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88336	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88337	 1	 18.04	 6.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88338	 1	 37.28	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88339	 1	 4.67	 1.68	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88340	 1	 4.55	 1.37	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88341	 1	 22.8	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88342	 1	 33.98	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88343	 1	 19.92	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88344	 1	 18.39	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88345	 1	 16.59	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88346	 1	 29.99	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88347	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88348	 1	 76.38	 23.05	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88349	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88350	 1	 29.93	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88351	 1	 17.95	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88352	 1	 27.27	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88353	 1	 41.2	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88354	 1	 15.63	 4.46	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88355	 1	 96.36	 25.04	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88356	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88357	 1	 46.31	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88358	 1	 43.92	 15.23	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88359	 1	 82.93	 27.94	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88360	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88361	 1	 10.94	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88362	 1	 14.55	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88363	 1	 20.09	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88364	 1	 48.9	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88365	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88366	 1	 50.63	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88367	 1	 12.44	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88368	 1	 38.8	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88369	 1	 39.37	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88370	 1	 14.23	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88371	 1	 6.86	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88372	 1	 21.36	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88373	 1	 14.06	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88374	 1	 5.22	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88375	 1	 10.89	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88376	 1	 31.22	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88377	 1	 15.8	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88378	 1	 27.85	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88379	 1	 22.27	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88380	 1	 16.71	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88381	 1	 114.85	 33.67	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88382	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88383	 1	 73.4	 22.96	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88384	 1	 0.0	 0.0	 0.0	 800.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88385	 1	 167.28	 55.61	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88386	 1	 79.33	 23.13	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88387	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88388	 1	 38.86	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88389	 1	 22.2	 7.02	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88390	 1	 23.31	 7.51	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88391	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88392	 1	 37.37	 10.38	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88393	 1	 7.9	 3.02	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88394	 1	 27.2	 7.18	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88395	 1	 29.88	 10.03	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88396	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88397	 1	 38.56	 11.43	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88398	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88399	 1	 45.35	 15.9	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88400	 1	 8.94	 2.79	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88401	 1	 15.4	 5.07	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88402	 1	 25.2	 6.55	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88403	 1	 13.45	 4.28	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88404	 1	 21.48	 5.49	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88405	 1	 9.94	 3.66	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88406	 1	 10.76	 2.95	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88407	 1	 42.0	 8.59	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88408	 1	 23.05	 6.53	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88409	 1	 32.91	 6.5	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88410	 1	 6.93	 2.47	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88411	 1	 12.66	 3.66	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88412	 1	 63.98	 16.85	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88413	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88414	 1	 24.61	 7.15	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88415	 1	 21.81	 6.31	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88416	 1	 24.09	 7.65	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88417	 1	 25.1	 6.33	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88418	 1	 9.7	 2.78	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88419	 1	 18.42	 4.15	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88420	 1	 41.43	 9.26	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88421	 1	 31.91	 7.22	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88422	 1	 73.65	 20.92	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88423	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88424	 1	 13.27	 3.85	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88425	 1	 41.83	 11.62	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88426	 1	 33.68	 9.98	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88427	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88428	 1	 17.59	 4.67	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88429	 1	 25.58	 8.8	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88430	 1	 43.16	 12.93	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88431	 1	 79.92	 26.65	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88432	 1	 42.06	 11.58	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88433	 1	 29.0	 9.52	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88434	 1	 29.53	 10.22	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88435	 1	 10.07	 3.77	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88436	 1	 22.03	 6.93	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88437	 1	 6.15	 2.14	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88438	 1	 19.62	 5.87	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88439	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88440	 1	 18.21	 5.72	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88441	 1	 13.12	 4.22	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88442	 1	 10.13	 3.64	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88443	 1	 12.96	 4.18	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88444	 1	 35.03	 8.67	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88445	 1	 15.0	 4.45	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88446	 1	 11.65	 3.92	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88447	 1	 76.89	 21.92	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88448	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88449	 1	 34.4	 8.48	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88450	 1	 20.08	 6.52	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88451	 1	 15.58	 4.84	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88452	 1	 81.5	 23.71	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88453	 1	 21.53	 6.55	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88454	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88455	 1	 196.07	 49.38	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88456	 1	 5.06	 1.8	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88457	 1	 32.59	 7.42	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88458	 1	 14.98	 5.52	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88459	 1	 27.87	 9.04	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88460	 1	 39.56	 10.14	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88461	 1	 37.77	 11.38	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88462	 1	 18.65	 4.09	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88463	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88464	 1	 13.7	 4.09	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88465	 1	 45.12	 10.03	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88466	 1	 19.18	 6.83	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88467	 1	 22.84	 7.44	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88468	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88469	 1	 42.06	 14.26	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88470	 1	 4.71	 1.57	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88471	 1	 26.73	 10.29	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88472	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88473	 1	 48.77	 13.89	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88474	 1	 8.89	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88475	 1	 12.13	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88476	 1	 34.37	 7.65	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88477	 1	 26.73	 7.15	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88478	 1	 9.11	 2.87	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88479	 1	 8.61	 2.8	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88480	 1	 13.96	 3.59	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88481	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88482	 1	 122.9	 31.81	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88483	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88484	 1	 18.31	 4.86	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88485	 1	 17.26	 6.29	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88486	 1	 25.45	 7.66	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88487	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88488	 1	 12.55	 4.81	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88489	 1	 11.45	 3.64	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88490	 1	 20.5	 7.64	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88491	 1	 9.27	 3.42	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88492	 1	 5.1	 1.9	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88493	 1	 11.86	 3.67	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88494	 1	 30.58	 9.75	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88495	 1	 10.25	 3.49	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88496	 1	 37.97	 8.96	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88497	 1	 10.94	 3.1	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88498	 1	 22.9	 7.71	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88499	 1	 16.61	 5.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88500	 1	 5.77	 1.94	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88501	 1	 13.57	 4.96	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88502	 1	 6.58	 2.28	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88503	 1	 5.8	 1.95	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88504	 1	 15.96	 5.87	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88505	 1	 22.03	 6.93	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88506	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88507	 1	 29.25	 8.67	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88508	 1	 15.65	 4.18	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88509	 1	 17.39	 4.53	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88510	 1	 41.71	 12.56	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88511	 1	 5.52	 1.69	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88512	 1	 11.06	 3.61	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88513	 1	 21.34	 7.55	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88514	 1	 37.2	 8.88	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88515	 1	 8.68	 2.64	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88516	 1	 12.0	 3.32	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88517	 1	 25.23	 5.72	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88518	 1	 31.41	 7.06	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88519	 1	 25.84	 5.82	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88520	 1	 9.88	 2.23	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88521	 1	 10.22	 3.19	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88522	 1	 38.02	 10.03	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88523	 1	 22.84	 7.3	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88524	 1	 5.94	 2.15	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88525	 1	 26.11	 6.31	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88526	 1	 24.12	 5.82	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88527	 1	 24.36	 7.2	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88528	 1	 8.83	 2.87	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88529	 1	 23.21	 6.66	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88530	 1	 4.73	 1.41	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88531	 1	 5.76	 2.28	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88532	 1	 33.7	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88533	 1	 27.7	 7.34	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88534	 1	 21.57	 6.97	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88535	 1	 17.07	 4.95	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88536	 1	 20.46	 6.44	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88537	 1	 50.14	 14.48	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88538	 1	 24.12	 6.78	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88539	 1	 9.5	 2.83	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88540	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88541	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88542	 1	 23.56	 6.53	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88543	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88544	 1	 15.31	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88545	 1	 28.51	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88546	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88547	 1	 26.42	 9.02	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88548	 1	 29.13	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88549	 1	 7.63	 2.76	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88550	 1	 6.99	 2.13	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88551	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88552	 1	 27.16	 6.97	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88553	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88554	 1	 16.59	 6.18	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88555	 1	 6.78	 2.71	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88556	 1	 8.87	 3.62	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88557	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88558	 1	 44.23	 17.69	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88559	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88560	 1	 23.77	 8.09	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88561	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88562	 1	 42.99	 11.67	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88563	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88564	 1	 22.42	 7.04	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88565	 1	 13.84	 5.54	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88566	 1	 18.85	 4.88	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88567	 1	 8.69	 2.73	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88568	 1	 17.63	 5.5	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88569	 1	 32.84	 9.72	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88570	 1	 16.77	 5.34	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88571	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88572	 1	 19.04	 6.84	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88573	 1	 14.12	 4.62	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88574	 1	 36.67	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88575	 1	 15.67	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88576	 1	 41.5	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88577	 1	 12.89	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88578	 1	 50.84	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88579	 1	 53.48	 11.36	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88580	 1	 46.98	 14.37	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88581	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88582	 1	 12.98	 5.01	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88583	 1	 52.35	 15.36	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88584	 1	 16.72	 6.84	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88585	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88586	 1	 253.12	 95.42	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88587	 1	 14.36	 5.49	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88588	 1	 20.41	 7.06	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88589	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88590	 1	 35.56	 10.25	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88591	 1	 20.02	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88592	 1	 70.84	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88593	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88594	 1	 16.89	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88595	 1	 16.28	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88596	 1	 9.51	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88597	 1	 15.4	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88598	 1	 11.9	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88599	 1	 22.26	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88600	 1	 28.71	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88601	 1	 12.5	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88602	 1	 21.92	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88603	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88604	 1	 18.21	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88605	 1	 43.27	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88606	 1	 26.86	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88607	 1	 18.82	 5.53	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88608	 1	 30.51	 6.97	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88609	 1	 14.21	 3.65	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88610	 1	 26.41	 7.84	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88611	 1	 13.88	 4.92	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88612	 1	 24.69	 6.28	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88613	 1	 10.09	 2.88	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88614	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88615	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88616	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88617	 1	 26.01	 6.12	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88618	 1	 12.75	 2.29	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88619	 1	 31.82	 7.84	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88620	 1	 11.61	 2.6	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88621	 1	 10.97	 2.41	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88622	 1	 8.07	 2.29	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88623	 1	 13.98	 4.33	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88624	 1	 8.24	 2.51	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88625	 1	 32.82	 10.64	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88626	 1	 28.88	 9.42	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88627	 1	 35.07	 11.23	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88628	 1	 29.11	 9.71	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88629	 1	 8.37	 2.23	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88630	 1	 15.33	 4.11	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88631	 1	 13.02	 2.84	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88632	 1	 12.59	 3.59	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88633	 1	 8.48	 2.49	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88634	 1	 31.9	 10.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88635	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88636	 1	 31.72	 10.79	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88637	 1	 13.66	 4.14	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88638	 1	 11.8	 4.32	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88639	 1	 16.13	 5.17	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88640	 1	 9.6	 3.23	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88641	 1	 13.93	 3.1	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88642	 1	 16.79	 4.68	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88643	 1	 25.67	 9.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88644	 1	 15.9	 3.51	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88645	 1	 16.08	 3.56	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88646	 1	 11.96	 2.64	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88647	 1	 11.7	 2.58	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88648	 1	 16.09	 3.57	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88649	 1	 17.5	 5.19	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88650	 1	 17.46	 5.89	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88651	 1	 18.47	 5.64	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88652	 1	 11.74	 3.36	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88653	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88654	 1	 19.13	 5.03	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88655	 1	 4.01	 1.22	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88656	 1	 47.3	 13.79	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88657	 1	 7.61	 2.47	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88658	 1	 6.24	 1.96	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88659	 1	 73.91	 21.58	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88660	 1	 46.9	 11.82	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88661	 1	 12.52	 4.52	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88662	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88663	 1	 40.17	 8.55	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88664	 1	 13.15	 2.91	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88665	 1	 7.44	 1.64	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88666	 1	 15.48	 3.41	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88667	 1	 34.86	 7.63	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88668	 1	 10.14	 2.25	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88669	 1	 13.81	 3.05	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88670	 1	 8.14	 1.8	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88671	 1	 5.11	 1.13	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88672	 1	 20.78	 4.55	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88673	 1	 17.05	 3.73	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88674	 1	 10.8	 2.39	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88675	 1	 8.5	 1.9	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88676	 1	 9.85	 2.19	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88677	 1	 19.34	 4.29	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88678	 1	 41.2	 9.08	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88679	 1	 30.02	 6.58	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88680	 1	 12.83	 2.85	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88681	 1	 16.34	 3.65	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88682	 1	 13.01	 2.89	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88683	 1	 20.96	 4.7	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88684	 1	 14.04	 3.14	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88685	 1	 16.95	 4.92	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88686	 1	 7.67	 2.57	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88687	 1	 14.2	 3.17	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88688	 1	 15.03	 3.36	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88689	 1	 22.89	 7.63	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88690	 1	 27.41	 8.6	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88691	 1	 12.46	 3.91	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88692	 1	 7.96	 2.75	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88693	 1	 9.16	 2.76	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88694	 1	 15.8	 5.2	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88695	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88696	 1	 22.9	 7.2	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88697	 1	 13.65	 4.32	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88698	 1	 10.45	 3.64	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88699	 1	 8.54	 3.08	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88700	 1	 15.72	 4.73	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88701	 1	 22.27	 7.61	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88702	 1	 15.48	 5.68	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88703	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88704	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88705	 1	 20.19	 6.44	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88706	 1	 13.47	 5.03	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88707	 1	 12.61	 4.11	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88708	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88709	 1	 80.39	 26.78	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88710	 1	 12.05	 4.66	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88711	 1	 81.6	 27.65	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88712	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88713	 1	 163.33	 51.99	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88714	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88715	 1	 19.22	 5.75	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88716	 1	 43.36	 14.04	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88717	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88718	 1	 297.84	 88.06	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88719	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88720	 1	 16.86	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88721	 1	 14.06	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88722	 1	 35.36	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88723	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88724	 1	 15.06	 3.87	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88725	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88726	 1	 347.15	 88.59	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88727	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88728	 1	 23.11	 7.45	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88729	 1	 24.47	 8.34	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88730	 1	 4.97	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88731	 1	 14.73	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88732	 1	 53.08	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88733	 1	 28.53	 6.11	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88734	 1	 23.53	 8.6	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88735	 1	 6.63	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88736	 1	 14.84	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88737	 1	 52.1	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88738	 1	 9.86	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88739	 1	 37.92	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88740	 1	 50.26	 13.31	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88741	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88742	 1	 10.6	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88743	 1	 10.98	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88744	 1	 46.51	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88745	 1	 29.95	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88746	 1	 17.74	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88747	 1	 11.9	 2.61	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88748	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88749	 1	 32.74	 10.26	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88750	 1	 7.53	 2.49	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88751	 1	 13.01	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88752	 1	 17.3	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88753	 1	 35.48	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88754	 1	 18.07	 5.81	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88755	 1	 16.22	 5.33	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88756	 1	 20.07	 6.44	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88757	 1	 42.38	 9.22	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88758	 1	 11.36	 3.72	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88759	 1	 24.07	 7.61	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88760	 1	 24.57	 7.32	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88761	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88762	 1	 37.44	 12.13	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88763	 1	 11.79	 3.38	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88764	 1	 17.9	 5.71	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88765	 1	 9.07	 2.7	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88766	 1	 25.56	 8.55	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88767	 1	 44.97	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88768	 1	 7.63	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88769	 1	 10.29	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88770	 1	 12.74	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88771	 1	 35.6	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88772	 1	 8.81	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88773	 1	 37.36	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88774	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88775	 1	 14.79	 4.18	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88776	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88777	 1	 41.68	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88778	 1	 0.0	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88779	 1	 34.18	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88780	 1	 19.72	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88781	 1	 22.96	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88782	 1	 25.89	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88783	 1	 16.98	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88784	 1	 23.46	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88785	 1	 21.12	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88786	 1	 35.5	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88787	 1	 25.17	 0.0	 0.0	 0.0	 33	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88788	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88789	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88790	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88791	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88792	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88793	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88794	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88795	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88796	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88797	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88798	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88799	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88800	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88801	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88802	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88803	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88804	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88805	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88806	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88807	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88808	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88809	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88810	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88811	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88812	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88813	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88814	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88815	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88816	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88817	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88818	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88819	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88820	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88821	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88822	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88823	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88824	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88825	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88826	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88827	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88828	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88829	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88830	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88831	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88832	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88833	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88834	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88835	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88836	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88837	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88838	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88839	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88840	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88841	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88842	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88843	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88844	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88845	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88846	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88847	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88848	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88849	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88850	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88851	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88852	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88853	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88854	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88855	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88856	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88857	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88858	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88859	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88860	 2	 11.38	 21.54	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88861	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88862	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88863	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88864	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88865	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88866	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88867	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88868	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88869	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88870	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88871	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88872	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88873	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88874	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88875	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88876	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88877	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88878	 1	 5.54	 10.12	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88879	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88880	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88881	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88882	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88883	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88884	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88885	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88886	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88887	 1	 2.56	 5.17	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88888	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88889	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88890	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88891	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88892	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88893	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88894	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88895	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88896	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88897	 1	 4.0	 7.08	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88898	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88899	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88900	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88901	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88902	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88903	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88904	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88905	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88906	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88907	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88908	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88909	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88910	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88911	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88912	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88913	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88914	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88915	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88916	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88917	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88918	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88919	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88920	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88921	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88922	 2	 10.79	 16.5	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88923	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88924	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88925	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88926	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88927	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88928	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88929	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88930	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88931	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88932	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88933	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88934	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88935	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88936	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88937	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88938	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88939	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88940	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88941	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88942	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88943	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88944	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88945	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88946	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88947	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88948	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88949	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88950	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88951	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88952	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88953	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88954	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88955	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88956	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88957	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88958	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88959	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88960	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88961	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88962	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88963	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88964	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88965	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88966	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88967	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88968	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88969	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88970	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88971	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88972	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88973	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88974	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88975	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88976	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88977	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88978	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88979	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88980	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88981	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88982	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88983	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88984	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88985	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88986	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88987	 2	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88988	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88989	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88990	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88991	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88992	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88993	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88994	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88995	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	88996	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88997	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88998	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	88999	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89000	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89001	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89002	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89003	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89004	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89005	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89006	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89007	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89008	 1	 3.0	 5.34	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89009	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89010	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89011	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89012	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89013	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89014	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89015	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89016	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89017	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89018	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89019	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89020	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89021	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89022	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89023	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89024	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89025	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89026	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89027	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89028	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89029	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89030	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89031	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89032	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89033	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89034	 2	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89035	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89036	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89037	 1	 8.96	 10.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89038	 1	 2.69	 4.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89039	 1	 5.11	 9.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89040	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89041	 1	 9.12	 16.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89042	 1	 5.93	 9.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89043	 1	 3.89	 6.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89044	 1	 3.29	 6.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89045	 1	 3.58	 6.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89046	 1	 3.67	 5.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89047	 1	 3.04	 3.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89048	 1	 1.72	 3.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89049	 1	 2.77	 4.18	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89050	 1	 7.07	 10.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89051	 1	 1.48	 2.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89052	 1	 5.21	 9.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89053	 1	 5.86	 8.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89054	 1	 4.06	 6.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89055	 1	 0.79	 1.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89056	 1	 0.87	 1.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89057	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89058	 1	 9.73	 16.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89059	 1	 4.26	 7.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89060	 1	 2.92	 5.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89061	 1	 5.41	 9.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89062	 1	 9.66	 12.79	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89063	 1	 4.78	 9.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89064	 1	 7.78	 12.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89065	 1	 3.4	 5.93	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89066	 1	 5.65	 10.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89067	 1	 3.86	 7.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89068	 1	 8.63	 14.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89069	 1	 1.86	 3.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89070	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89071	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89072	 1	 3.63	 5.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89073	 1	 1.18	 2.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89074	 1	 6.72	 12.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89075	 1	 1.79	 4.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89076	 1	 5.89	 8.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89077	 1	 6.51	 11.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89078	 1	 7.57	 11.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89079	 1	 1.53	 0.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89080	 1	 1.64	 0.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89081	 1	 1.39	 0.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89082	 1	 2.28	 0.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89083	 1	 1.56	 0.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89084	 1	 2.04	 3.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89085	 1	 1.28	 2.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89086	 1	 3.07	 5.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89087	 1	 1.85	 3.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89088	 1	 3.02	 5.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89089	 1	 0.9	 1.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89090	 1	 1.3	 2.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89091	 1	 1.06	 2.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89092	 1	 1.57	 0.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89093	 1	 1.75	 3.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89094	 1	 1.27	 2.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89095	 1	 1.04	 2.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89096	 1	 1.3	 0.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89097	 1	 1.66	 2.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89098	 1	 1.62	 2.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89099	 1	 2.03	 2.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89100	 1	 1.17	 2.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89101	 1	 2.88	 3.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89102	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89103	 1	 3.43	 4.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89104	 1	 1.98	 3.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89105	 1	 0.91	 1.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89106	 1	 2.15	 3.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89107	 1	 1.02	 1.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89108	 1	 0.55	 0.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89109	 1	 0.69	 1.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89110	 1	 2.66	 4.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89111	 1	 2.12	 4.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89112	 1	 1.08	 2.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89113	 1	 1.1	 1.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89114	 1	 1.31	 2.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89115	 1	 1.21	 2.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89116	 1	 1.93	 3.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89117	 1	 3.13	 5.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89118	 1	 1.33	 2.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89119	 1	 1.39	 2.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89120	 1	 1.59	 2.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89121	 1	 0.97	 1.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89122	 1	 1.36	 1.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89123	 1	 1.88	 3.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89124	 1	 1.58	 1.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89125	 1	 0.5	 1.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89126	 1	 0.82	 1.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89127	 1	 1.62	 2.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89128	 1	 1.4	 2.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89129	 1	 0.99	 2.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89130	 1	 0.92	 1.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89131	 1	 1.08	 1.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89132	 1	 6.52	 12.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89133	 1	 2.04	 3.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89134	 1	 0.76	 1.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89135	 1	 0.8	 1.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89136	 1	 0.4	 0.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89137	 1	 0.56	 1.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89138	 1	 0.79	 1.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89139	 1	 1.19	 2.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89140	 1	 1.34	 2.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89141	 1	 1.07	 1.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89142	 1	 0.55	 1.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89143	 1	 4.6	 7.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89144	 1	 3.31	 5.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89145	 1	 2.04	 3.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89146	 1	 1.29	 2.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89147	 1	 1.45	 2.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89148	 1	 3.53	 4.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89149	 1	 0.79	 1.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89150	 1	 1.42	 2.74	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89151	 1	 2.87	 5.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89152	 1	 5.82	 8.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89153	 1	 3.82	 4.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89154	 1	 1.53	 2.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89155	 1	 1.36	 3.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89156	 1	 1.93	 3.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89157	 1	 1.69	 2.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89158	 1	 1.05	 2.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89159	 1	 1.74	 3.04	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89160	 1	 5.35	 9.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89161	 1	 2.18	 4.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89162	 1	 1.29	 2.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89163	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89164	 1	 5.28	 8.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89165	 1	 1.43	 2.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89166	 1	 1.21	 2.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89167	 1	 1.96	 3.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89168	 1	 0.45	 0.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89169	 1	 1.69	 2.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89170	 1	 1.61	 2.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89171	 1	 1.59	 3.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89172	 1	 1.16	 2.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89173	 1	 1.32	 2.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89174	 1	 1.0	 2.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89175	 1	 22.7	 24.32	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89176	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89177	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89178	 1	 26.32	 28.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89179	 1	 4.66	 8.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89180	 1	 4.64	 7.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89181	 1	 6.66	 1.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89182	 1	 2.1	 0.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89183	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89184	 1	 6.56	 7.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89185	 1	 16.22	 27.81	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89186	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89187	 1	 4.86	 8.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89188	 1	 1.79	 3.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89189	 1	 1.97	 3.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89190	 1	 1.23	 2.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89191	 1	 8.5	 13.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89192	 1	 2.96	 5.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89193	 1	 3.91	 6.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89194	 1	 1.75	 3.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89195	 1	 1.91	 3.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89196	 1	 4.22	 7.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89197	 1	 4.77	 6.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89198	 1	 2.19	 3.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89199	 1	 11.43	 18.49	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89200	 1	 1.87	 3.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89201	 1	 1.66	 3.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89202	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89203	 1	 12.83	 18.7	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89204	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89205	 1	 1.59	 2.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89206	 1	 0.84	 1.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89207	 1	 1.63	 3.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89208	 1	 0.92	 2.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89209	 1	 1.47	 2.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89210	 1	 1.16	 2.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89211	 1	 6.69	 10.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89212	 1	 0.8	 1.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89213	 1	 1.27	 2.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89214	 1	 0.84	 1.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89215	 1	 2.47	 4.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89216	 1	 1.67	 2.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89217	 1	 2.34	 3.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89218	 1	 15.24	 24.45	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89219	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89220	 1	 5.66	 6.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89221	 1	 2.8	 4.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89222	 1	 2.09	 4.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89223	 1	 5.08	 6.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89224	 1	 1.37	 2.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89225	 1	 3.01	 3.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89226	 1	 3.42	 6.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89227	 1	 1.41	 2.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89228	 1	 4.21	 7.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89229	 1	 1.31	 2.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89230	 1	 13.03	 18.16	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89231	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89232	 1	 4.69	 1.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89233	 1	 6.76	 1.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89234	 1	 14.59	 19.77	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89235	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89236	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89237	 1	 9.45	 2.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89238	 1	 2.39	 4.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89239	 1	 2.72	 0.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89240	 1	 3.25	 0.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89241	 1	 3.83	 4.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89242	 1	 2.3	 3.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89243	 1	 0.8	 1.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89244	 1	 2.03	 3.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89245	 1	 7.37	 11.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89246	 1	 4.92	 6.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89247	 1	 11.68	 13.73	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89248	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89249	 1	 23.17	 31.79	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89250	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89251	 1	 1.36	 2.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89252	 1	 1.74	 3.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89253	 1	 1.02	 2.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89254	 1	 0.82	 1.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89255	 1	 1.59	 3.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89256	 1	 1.23	 2.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89257	 1	 2.99	 5.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89258	 1	 2.61	 4.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89259	 1	 2.5	 4.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89260	 1	 3.89	 6.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89261	 1	 2.04	 3.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89262	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89263	 1	 6.35	 11.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89264	 1	 2.97	 5.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89265	 1	 3.71	 5.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89266	 1	 1.59	 3.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89267	 1	 1.19	 2.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89268	 1	 1.46	 2.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89269	 1	 2.94	 4.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89270	 1	 5.23	 6.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89271	 1	 1.81	 3.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89272	 1	 8.6	 12.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89273	 1	 4.82	 6.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89274	 1	 2.39	 4.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89275	 1	 2.39	 4.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89276	 1	 5.44	 7.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89277	 1	 11.27	 17.41	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89278	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89279	 1	 1.75	 3.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89280	 1	 3.35	 5.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89281	 1	 1.89	 3.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89282	 1	 2.36	 4.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89283	 1	 2.81	 4.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89284	 1	 3.73	 5.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89285	 1	 1.0	 2.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89286	 1	 5.11	 9.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89287	 1	 0.38	 0.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89288	 1	 4.77	 7.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89289	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89290	 1	 36.05	 52.01	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89291	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89292	 1	 6.72	 9.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89293	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89294	 1	 31.47	 39.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89295	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89296	 1	 9.32	 16.65	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89297	 1	 20.69	 29.3	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89298	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89299	 1	 36.62	 46.08	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89300	 1	 5.05	 7.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89301	 1	 0.96	 1.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89302	 1	 4.53	 6.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89303	 1	 8.91	 13.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89304	 1	 3.32	 5.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89305	 1	 1.76	 3.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89306	 1	 1.19	 2.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89307	 1	 1.09	 2.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89308	 1	 3.02	 4.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89309	 1	 8.55	 15.18	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89310	 1	 17.3	 25.55	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89311	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89312	 1	 5.88	 9.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89313	 1	 2.0	 3.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89314	 1	 3.23	 6.33	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89315	 1	 1.45	 2.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89316	 1	 1.02	 1.82	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89317	 1	 3.18	 5.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89318	 1	 1.67	 3.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89319	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89320	 1	 13.29	 24.6	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89321	 1	 1.77	 3.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89322	 1	 1.69	 3.48	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89323	 1	 1.64	 2.95	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89324	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89325	 1	 2.38	 3.66	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89326	 1	 1.96	 3.73	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89327	 1	 1.01	 2.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89328	 1	 2.42	 4.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89329	 1	 1.16	 2.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89330	 1	 1.65	 3.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89331	 1	 3.42	 6.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89332	 1	 2.59	 3.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89333	 1	 1.5	 3.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89334	 1	 2.73	 5.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89335	 1	 1.75	 2.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89336	 1	 1.22	 2.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89337	 1	 1.6	 3.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89338	 1	 2.22	 4.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89339	 1	 1.58	 3.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89340	 1	 1.19	 2.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89341	 1	 1.19	 2.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89342	 1	 2.39	 4.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89343	 1	 1.89	 3.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89344	 1	 9.61	 12.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89345	 1	 3.61	 5.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89346	 1	 1.19	 2.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89347	 1	 1.35	 2.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89348	 1	 6.94	 9.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89349	 1	 0.91	 1.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89350	 1	 0.95	 1.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89351	 1	 5.93	 8.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89352	 1	 2.19	 4.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89353	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89354	 1	 1.55	 2.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89355	 1	 2.57	 3.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89356	 1	 4.87	 6.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89357	 1	 2.01	 3.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89358	 1	 2.24	 4.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89359	 1	 1.68	 3.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89360	 1	 5.14	 9.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89361	 1	 0.71	 1.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89362	 1	 4.29	 5.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89363	 1	 1.74	 3.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89364	 1	 7.58	 11.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89365	 1	 2.62	 5.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89366	 1	 2.28	 4.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89367	 1	 1.13	 2.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89368	 1	 1.41	 2.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89369	 1	 2.22	 3.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89370	 1	 7.63	 13.19	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89371	 1	 5.85	 9.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89372	 1	 1.86	 2.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89373	 1	 5.32	 5.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89374	 1	 2.25	 2.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89375	 1	 2.93	 5.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89376	 1	 4.76	 1.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89377	 1	 0.73	 0.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89378	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89379	 1	 6.23	 9.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89380	 1	 5.19	 7.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89381	 1	 2.36	 4.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89382	 1	 0.87	 1.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89383	 1	 1.95	 3.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89384	 1	 2.52	 3.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89385	 1	 4.33	 7.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89386	 1	 0.45	 0.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89387	 1	 0.81	 1.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89388	 1	 4.86	 8.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89389	 1	 35.14	 43.21	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89390	 1	 12.16	 19.49	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89391	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89392	 1	 1.23	 2.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89393	 1	 5.08	 6.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89394	 1	 1.59	 2.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89395	 1	 1.78	 3.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89396	 1	 0.51	 1.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89397	 1	 1.48	 1.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89398	 1	 9.56	 16.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89399	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89400	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89401	 1	 6.13	 7.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89402	 1	 6.56	 11.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89403	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89404	 1	 6.9	 11.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89405	 1	 19.46	 30.55	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89406	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89407	 1	 7.7	 8.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89408	 1	 2.89	 3.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89409	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89410	 1	 8.88	 9.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89411	 1	 6.34	 10.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89412	 1	 5.69	 1.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89413	 1	 2.19	 2.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89414	 1	 1.02	 1.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89415	 1	 2.62	 4.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89416	 1	 3.34	 0.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89417	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89418	 1	 1.97	 3.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89419	 1	 4.02	 7.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89420	 1	 3.87	 6.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89421	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89422	 1	 2.02	 4.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89423	 1	 4.25	 6.35	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89424	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89425	 1	 4.88	 7.25	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89426	 1	 1.2	 2.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89427	 1	 2.61	 4.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89428	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89429	 1	 7.43	 11.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89430	 1	 2.81	 5.03	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89431	 1	 4.23	 7.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89432	 1	 11.63	 14.98	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89433	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89434	 1	 13.69	 15.43	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89435	 1	 1.03	 1.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89436	 1	 1.38	 2.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89437	 1	 4.36	 7.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89438	 1	 7.15	 10.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89439	 1	 3.5	 4.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89440	 1	 1.54	 2.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89441	 1	 1.29	 2.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89442	 1	 4.49	 6.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89443	 1	 0.99	 1.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89444	 1	 0.8	 1.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89445	 1	 0.9	 1.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89446	 1	 3.6	 6.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89447	 1	 0.82	 1.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89448	 1	 0.55	 1.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89449	 1	 3.83	 4.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89450	 1	 6.12	 9.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89451	 1	 1.22	 2.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89452	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89453	 1	 1.54	 3.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89454	 1	 1.48	 2.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89455	 1	 16.05	 16.21	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89456	 1	 1.12	 1.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89457	 1	 0.42	 0.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89458	 1	 1.4	 2.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89459	 1	 2.36	 3.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89460	 1	 0.84	 1.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89461	 1	 0.94	 2.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89462	 1	 2.33	 3.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89463	 1	 1.26	 2.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89464	 1	 2.54	 3.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89465	 1	 0.95	 1.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89466	 1	 2.19	 3.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89467	 1	 1.75	 3.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89468	 1	 0.7	 1.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89469	 1	 1.92	 3.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89470	 1	 4.28	 7.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89471	 1	 1.76	 3.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89472	 1	 1.2	 2.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89473	 1	 1.78	 2.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89474	 1	 2.54	 4.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89475	 1	 3.77	 5.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89476	 1	 1.22	 2.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89477	 1	 1.35	 2.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89478	 1	 2.29	 3.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89479	 1	 1.6	 3.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89480	 1	 1.43	 2.76	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89481	 1	 0.91	 2.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89482	 1	 6.18	 8.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89483	 1	 1.37	 2.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89484	 1	 1.57	 2.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89485	 1	 9.8	 16.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89486	 1	 6.64	 7.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89487	 1	 2.33	 3.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89488	 1	 2.54	 4.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89489	 1	 1.0	 2.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89490	 1	 1.6	 3.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89491	 1	 2.05	 4.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89492	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89493	 1	 2.99	 5.78	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89494	 1	 2.12	 4.24	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89495	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89496	 1	 1.11	 2.46	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89497	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89498	 1	 1.25	 2.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89499	 1	 16.42	 27.06	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89500	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89501	 1	 2.66	 3.79	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89502	 1	 3.52	 6.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89503	 1	 0.79	 1.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89504	 1	 0.93	 1.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89505	 1	 1.04	 2.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89506	 1	 1.57	 3.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89507	 1	 1.43	 2.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89508	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89509	 1	 9.48	 11.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89510	 1	 20.77	 25.7	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89511	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89512	 1	 2.41	 4.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89513	 1	 6.79	 11.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89514	 1	 4.82	 8.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89515	 1	 6.14	 8.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89516	 1	 1.51	 2.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89517	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89518	 1	 0.95	 2.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89519	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89520	 1	 6.27	 10.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89521	 1	 1.92	 3.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89522	 1	 2.79	 5.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89523	 1	 3.37	 6.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89524	 1	 3.2	 5.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89525	 1	 3.08	 4.86	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89526	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89527	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89528	 1	 5.2	 10.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89529	 1	 3.7	 6.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89530	 1	 3.58	 5.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89531	 1	 1.94	 3.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89532	 1	 3.52	 6.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89533	 1	 4.71	 9.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89534	 1	 1.32	 2.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89535	 1	 1.38	 2.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89536	 1	 5.73	 8.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89537	 1	 4.76	 7.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89538	 1	 2.87	 4.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89539	 1	 3.13	 3.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89540	 1	 4.18	 5.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89541	 1	 5.65	 9.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89542	 1	 4.33	 8.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89543	 1	 5.67	 7.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89544	 1	 2.36	 4.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89545	 1	 2.62	 5.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89546	 1	 3.36	 5.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89547	 1	 0.66	 1.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89548	 1	 4.73	 6.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89549	 1	 1.48	 2.92	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89550	 1	 4.03	 6.58	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89551	 1	 2.52	 4.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89552	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89553	 1	 5.12	 8.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89554	 1	 0.75	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89555	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89556	 1	 3.41	 6.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89557	 1	 4.14	 8.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89558	 1	 4.54	 8.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89559	 1	 3.94	 7.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89560	 1	 2.77	 5.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89561	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89562	 1	 4.24	 6.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89563	 1	 2.54	 3.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89564	 1	 3.25	 5.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89565	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89566	 1	 5.7	 11.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89567	 1	 9.15	 13.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89568	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89569	 1	 4.95	 7.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89570	 1	 2.13	 3.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89571	 1	 4.87	 7.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89572	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89573	 1	 2.22	 4.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89574	 1	 4.67	 8.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89575	 1	 2.2	 3.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89576	 1	 1.45	 3.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89577	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89578	 1	 3.76	 6.51	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89579	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89580	 1	 3.72	 5.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89581	 1	 1.56	 2.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89582	 1	 3.01	 4.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89583	 1	 9.54	 16.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89584	 1	 3.77	 6.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89585	 1	 2.1	 3.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89586	 1	 3.07	 4.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89587	 1	 1.96	 4.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89588	 1	 2.84	 3.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89589	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89590	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89591	 1	 8.21	 8.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89592	 1	 1.48	 3.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89593	 1	 4.56	 8.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89594	 1	 5.08	 8.57	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89595	 1	 3.47	 5.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89596	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89597	 1	 4.72	 8.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89598	 1	 3.19	 5.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89599	 1	 4.93	 8.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89600	 1	 8.98	 12.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89601	 1	 1.59	 2.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89602	 1	 4.36	 6.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89603	 1	 3.41	 6.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89604	 1	 2.85	 5.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89605	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89606	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89607	 1	 6.7	 12.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89608	 1	 7.51	 15.32	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89609	 1	 6.56	 10.61	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89610	 1	 5.66	 10.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89611	 1	 4.31	 7.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89612	 1	 2.0	 3.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89613	 1	 3.81	 6.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89614	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89615	 1	 4.91	 8.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89616	 1	 1.76	 2.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89617	 1	 2.6	 4.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89618	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89619	 1	 8.33	 2.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89620	 1	 2.21	 0.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89621	 1	 0.69	 0.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89622	 1	 2.17	 0.59	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89623	 1	 0.8	 0.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89624	 1	 1.32	 0.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89625	 1	 0.58	 0.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89626	 1	 2.83	 0.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89627	 1	 1.02	 0.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89628	 1	 1.01	 0.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89629	 1	 4.26	 1.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89630	 1	 1.98	 0.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89631	 1	 1.36	 0.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89632	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89633	 1	 9.13	 2.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89634	 1	 1.52	 0.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89635	 1	 3.51	 0.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89636	 1	 0.66	 0.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89637	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89638	 1	 1.1	 0.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89639	 1	 1.04	 0.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89640	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89641	 1	 5.99	 1.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89642	 1	 2.11	 0.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89643	 1	 0.75	 0.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89644	 1	 3.68	 0.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89645	 1	 1.2	 0.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89646	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89647	 1	 6.85	 1.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89648	 1	 0.89	 0.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89649	 1	 0.89	 0.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89650	 1	 3.61	 0.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89651	 1	 1.2	 0.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89652	 1	 3.57	 0.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89653	 1	 5.23	 1.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89654	 1	 1.7	 0.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89655	 1	 2.89	 0.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89656	 1	 4.09	 1.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89657	 1	 4.5	 1.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89658	 1	 2.3	 0.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89659	 1	 6.11	 10.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89660	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89661	 1	 9.76	 14.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89662	 1	 6.21	 1.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89663	 1	 4.57	 1.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89664	 1	 0.33	 0.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89665	 1	 4.4	 1.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89666	 1	 3.5	 0.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89667	 1	 3.26	 0.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89668	 1	 6.45	 1.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89669	 1	 1.94	 3.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89670	 1	 6.48	 12.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89671	 1	 2.54	 5.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89672	 1	 2.41	 4.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89673	 1	 2.65	 4.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89674	 1	 2.38	 3.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89675	 1	 8.33	 15.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89676	 1	 6.59	 11.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89677	 1	 4.13	 7.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89678	 1	 6.27	 11.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89679	 1	 2.98	 0.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89680	 1	 2.12	 3.76	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89681	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89682	 1	 4.81	 9.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89683	 1	 6.52	 9.28	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89684	 1	 4.89	 8.25	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89685	 1	 5.46	 8.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89686	 1	 1.6	 2.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89687	 1	 3.25	 5.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89688	 1	 4.27	 6.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89689	 1	 2.21	 4.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89690	 1	 4.24	 6.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89691	 1	 3.83	 5.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89692	 1	 3.79	 5.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89693	 1	 2.1	 3.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89694	 1	 3.17	 4.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89695	 1	 2.62	 4.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89696	 1	 5.74	 8.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89697	 1	 3.0	 5.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89698	 1	 3.75	 5.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89699	 1	 2.88	 4.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89700	 1	 1.67	 2.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89701	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89702	 1	 6.6	 8.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89703	 1	 3.57	 5.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89704	 1	 5.9	 11.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89705	 1	 2.36	 5.2	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89706	 1	 0.98	 1.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89707	 1	 1.48	 2.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89708	 1	 1.97	 3.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89709	 1	 6.13	 10.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89710	 1	 2.26	 4.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89711	 1	 7.55	 15.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89712	 1	 2.59	 5.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89713	 1	 4.48	 8.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89714	 1	 3.59	 6.15	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89715	 1	 2.05	 3.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89716	 1	 0.89	 1.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89717	 1	 1.84	 3.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89718	 1	 3.43	 6.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89719	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89720	 1	 2.71	 3.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89721	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89722	 1	 2.14	 3.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89723	 1	 1.78	 3.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89724	 1	 4.02	 7.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89725	 1	 2.02	 3.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89726	 1	 3.58	 5.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89727	 1	 7.02	 12.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89728	 1	 2.75	 4.22	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89729	 1	 1.56	 2.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89730	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89731	 1	 29.42	 34.4	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89732	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89733	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89734	 1	 4.04	 6.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89735	 1	 3.26	 5.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89736	 1	 2.86	 5.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89737	 1	 1.7	 2.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89738	 1	 2.02	 3.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89739	 1	 1.17	 2.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89740	 1	 0.42	 1.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89741	 1	 1.52	 3.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89742	 1	 0.77	 1.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89743	 1	 1.77	 3.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89744	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89745	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89746	 1	 5.15	 8.37	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89747	 1	 6.89	 7.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89748	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89749	 1	 4.74	 8.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89750	 1	 10.67	 14.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89751	 1	 1.46	 2.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89752	 1	 2.83	 5.32	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89753	 1	 3.24	 5.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89754	 1	 2.18	 4.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89755	 1	 5.71	 9.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89756	 1	 2.03	 4.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89757	 1	 1.85	 4.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89758	 1	 2.02	 3.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89759	 1	 2.93	 6.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89760	 1	 2.1	 4.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89761	 1	 5.94	 10.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89762	 1	 9.67	 12.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89763	 1	 1.1	 2.32	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89764	 1	 7.23	 10.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89765	 1	 3.18	 5.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89766	 1	 2.29	 4.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89767	 1	 2.3	 3.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89768	 1	 3.12	 4.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89769	 1	 3.39	 5.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89770	 1	 5.32	 9.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89771	 1	 2.38	 3.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89772	 1	 5.52	 8.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89773	 1	 1.79	 3.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89774	 1	 3.17	 6.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89775	 1	 4.21	 7.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89776	 1	 2.98	 5.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89777	 1	 3.41	 0.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89778	 1	 3.43	 0.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89779	 1	 2.81	 5.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89780	 1	 4.59	 6.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89781	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89782	 1	 5.06	 10.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89783	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89784	 1	 11.65	 16.45	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89785	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89786	 1	 2.67	 4.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89787	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89788	 1	 5.75	 7.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89789	 1	 2.8	 5.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89790	 1	 3.78	 5.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89791	 1	 0.4	 0.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89792	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89793	 1	 8.3	 11.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89794	 1	 0.95	 2.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89795	 1	 2.57	 3.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89796	 1	 4.2	 7.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89797	 1	 0.85	 1.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89798	 1	 1.14	 2.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89799	 1	 1.85	 3.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89800	 1	 1.7	 3.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89801	 1	 1.31	 2.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89802	 1	 2.66	 4.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89803	 1	 2.42	 4.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89804	 1	 9.15	 17.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89805	 1	 4.77	 6.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89806	 1	 3.5	 6.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89807	 1	 6.25	 9.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89808	 1	 4.0	 6.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89809	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89810	 1	 10.73	 18.28	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89811	 1	 7.4	 11.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89812	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89813	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89814	 1	 4.9	 8.33	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89815	 1	 2.12	 4.24	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89816	 1	 4.03	 6.53	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89817	 1	 4.88	 9.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89818	 1	 5.02	 9.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89819	 1	 2.65	 4.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89820	 1	 2.04	 3.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89821	 1	 1.38	 2.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89822	 1	 10.02	 17.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89823	 1	 2.76	 5.07	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89824	 1	 1.85	 3.78	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89825	 1	 2.54	 3.89	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89826	 1	 4.53	 7.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89827	 1	 0.45	 1.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89828	 1	 1.45	 2.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89829	 1	 2.12	 4.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89830	 1	 3.94	 5.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89831	 1	 3.04	 5.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89832	 1	 1.45	 2.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89833	 1	 2.88	 4.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89834	 1	 9.7	 12.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89835	 1	 19.76	 26.76	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89836	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89837	 1	 0.87	 1.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89838	 1	 5.27	 6.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89839	 1	 1.53	 3.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89840	 1	 0.57	 1.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89841	 1	 0.53	 1.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89842	 1	 3.3	 6.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89843	 1	 3.12	 5.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89844	 1	 3.63	 7.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89845	 1	 19.91	 28.21	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89846	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89847	 1	 8.72	 12.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89848	 1	 3.06	 6.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89849	 1	 7.72	 10.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89850	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89851	 1	 18.4	 28.04	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89852	 1	 2.3	 4.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89853	 1	 2.48	 3.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89854	 1	 1.92	 3.9	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89855	 1	 4.93	 8.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89856	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89857	 1	 2.44	 4.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89858	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89859	 1	 7.23	 12.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89860	 1	 2.34	 4.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89861	 1	 7.44	 11.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89862	 1	 1.89	 3.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89863	 1	 3.65	 5.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89864	 1	 1.56	 3.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89865	 1	 1.46	 1.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89866	 1	 3.05	 6.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89867	 1	 2.23	 3.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89868	 1	 2.21	 4.06	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89869	 1	 1.97	 3.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89870	 1	 2.05	 4.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89871	 1	 2.97	 4.79	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89872	 1	 2.05	 3.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89873	 1	 2.92	 5.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89874	 1	 1.28	 2.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89875	 1	 2.58	 4.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89876	 1	 2.09	 3.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89877	 1	 3.47	 6.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89878	 1	 1.35	 2.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89879	 1	 4.69	 9.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89880	 1	 3.67	 5.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89881	 1	 0.99	 1.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89882	 1	 4.82	 8.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89883	 1	 3.43	 5.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89884	 1	 2.41	 4.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89885	 1	 5.59	 10.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89886	 1	 0.9	 1.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89887	 1	 5.66	 10.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89888	 1	 4.79	 8.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89889	 1	 8.15	 14.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89890	 1	 3.56	 6.51	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89891	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89892	 1	 8.25	 9.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89893	 1	 2.24	 4.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89894	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89895	 1	 5.11	 10.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89896	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89897	 1	 4.36	 5.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89898	 1	 2.56	 5.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89899	 1	 2.25	 4.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89900	 1	 6.6	 12.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89901	 1	 3.66	 7.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89902	 1	 3.7	 7.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89903	 1	 3.88	 7.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89904	 1	 3.09	 5.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89905	 1	 3.2	 6.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89906	 1	 5.9	 10.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89907	 1	 5.09	 6.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89908	 1	 6.38	 10.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89909	 1	 3.1	 6.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89910	 1	 2.15	 4.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89911	 1	 4.67	 8.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89912	 1	 3.48	 4.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89913	 1	 1.99	 3.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89914	 1	 4.36	 7.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89915	 1	 3.96	 5.89	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89916	 1	 3.47	 5.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89917	 1	 6.78	 12.3	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89918	 1	 3.67	 7.06	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89919	 1	 3.87	 7.26	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89920	 1	 4.1	 5.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89921	 1	 0.83	 1.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89922	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89923	 1	 1.39	 2.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89924	 1	 0.64	 1.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89925	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89926	 1	 2.27	 3.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89927	 1	 3.15	 5.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89928	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89929	 1	 25.95	 31.8	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89930	 1	 2.77	 4.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89931	 1	 1.64	 3.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89932	 1	 1.04	 2.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89933	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89934	 1	 2.45	 5.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89935	 1	 3.33	 6.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89936	 1	 4.91	 10.59	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89937	 1	 1.47	 3.04	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89938	 1	 1.25	 2.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89939	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89940	 1	 1.78	 3.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89941	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89942	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89943	 1	 2.12	 3.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89944	 1	 1.1	 2.34	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89945	 1	 1.61	 3.2	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89946	 1	 2.56	 5.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89947	 1	 0.91	 1.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89948	 1	 1.0	 2.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89949	 1	 2.0	 3.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89950	 1	 0.65	 1.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89951	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89952	 1	 3.36	 6.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89953	 1	 0.89	 2.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89954	 1	 1.67	 3.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89955	 1	 3.15	 5.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89956	 1	 0.63	 1.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89957	 1	 0.57	 1.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89958	 1	 0.68	 1.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89959	 1	 1.3	 2.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89960	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89961	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89962	 1	 1.68	 3.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89963	 1	 4.14	 6.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89964	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89965	 1	 9.5	 14.75	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89966	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89967	 1	 4.55	 8.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89968	 1	 0.53	 1.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89969	 1	 1.13	 2.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89970	 1	 1.38	 2.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89971	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89972	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89973	 1	 1.31	 2.38	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89974	 1	 2.25	 5.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89975	 1	 1.39	 2.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89976	 1	 40.6	 54.3	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89977	 1	 2.51	 4.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89978	 1	 5.87	 10.12	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89979	 1	 1.52	 3.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89980	 1	 2.88	 5.42	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89981	 1	 1.27	 2.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89982	 1	 3.9	 6.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89983	 1	 2.17	 3.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89984	 1	 0.64	 1.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89985	 1	 2.95	 5.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89986	 1	 1.39	 2.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89987	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89988	 1	 1.46	 2.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89989	 1	 2.3	 2.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89990	 1	 0.89	 2.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89991	 1	 0.9	 1.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89992	 1	 2.76	 4.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89993	 1	 3.02	 4.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89994	 1	 5.0	 8.4	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89995	 1	 2.68	 4.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89996	 1	 2.05	 3.68	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89997	 1	 2.37	 4.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	89998	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	89999	 1	 8.71	 17.21	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90000	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90001	 1	 1.88	 3.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90002	 1	 1.81	 3.06	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90003	 1	 2.11	 2.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90004	 1	 7.81	 11.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90005	 1	 4.72	 7.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90006	 1	 1.55	 2.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90007	 1	 1.98	 3.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90008	 1	 5.97	 10.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90009	 1	 2.85	 5.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90010	 1	 12.13	 22.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90011	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90012	 1	 4.4	 6.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90013	 1	 3.09	 5.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90014	 1	 2.81	 4.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90015	 1	 2.99	 4.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90016	 1	 4.0	 5.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90017	 1	 4.14	 7.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90018	 1	 4.25	 6.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90019	 1	 4.02	 7.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90020	 1	 2.76	 5.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90021	 1	 1.68	 2.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90022	 1	 10.98	 19.82	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90023	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90024	 1	 4.67	 6.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90025	 1	 2.61	 4.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90026	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90027	 1	 10.6	 17.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90028	 1	 9.02	 9.71	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90029	 1	 6.59	 9.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90030	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90031	 1	 3.3	 6.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90032	 1	 4.01	 5.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90033	 1	 2.77	 5.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90034	 1	 3.46	 6.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90035	 1	 6.23	 6.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90036	 1	 5.72	 4.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90037	 1	 0.92	 1.67	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90038	 1	 1.87	 2.92	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90039	 1	 0.8	 2.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90040	 1	 1.99	 4.36	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90041	 1	 1.64	 2.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90042	 1	 8.41	 8.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90043	 1	 2.77	 6.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90044	 1	 1.04	 2.23	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90045	 1	 0.76	 1.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90046	 1	 4.0	 3.96	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90047	 1	 8.4	 7.17	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90048	 1	 8.8	 5.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90049	 1	 6.88	 8.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90050	 1	 2.39	 2.96	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90051	 1	 2.31	 4.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90052	 1	 6.88	 9.52	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90053	 1	 4.65	 5.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90054	 1	 2.49	 5.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90055	 1	 3.13	 5.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90056	 1	 1.08	 2.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90057	 1	 1.56	 2.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90058	 1	 0.94	 1.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90059	 1	 2.5	 2.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90060	 1	 4.31	 3.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90061	 1	 5.51	 6.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90062	 1	 0.74	 1.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90063	 1	 12.99	 9.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90064	 1	 1.49	 3.02	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90065	 1	 1.12	 2.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90066	 1	 4.05	 6.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90067	 1	 4.23	 4.82	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90068	 1	 1.04	 2.47	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90069	 1	 2.74	 3.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90070	 1	 3.48	 3.89	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90071	 1	 2.04	 2.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90072	 1	 29.12	 31.69	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90073	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90074	 1	 4.79	 5.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90075	 1	 0.7	 1.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90076	 1	 11.7	 12.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90077	 1	 6.13	 7.71	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90078	 1	 1.65	 3.13	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90079	 1	 1.66	 2.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90080	 1	 2.66	 3.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90081	 1	 16.51	 11.67	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90082	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90083	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90084	 1	 6.89	 8.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90085	 1	 1.8	 3.67	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90086	 1	 25.65	 19.03	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90087	 1	 0.73	 1.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90088	 1	 0.75	 1.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90089	 1	 11.89	 14.01	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90090	 1	 6.03	 5.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90091	 1	 2.16	 4.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90092	 1	 2.42	 3.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90093	 1	 1.62	 3.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90094	 1	 1.91	 4.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90095	 1	 8.31	 8.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90096	 1	 5.75	 7.17	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90097	 1	 1.12	 2.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90098	 1	 1.57	 2.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90099	 1	 9.3	 10.57	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90100	 1	 1.89	 3.23	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90101	 1	 5.42	 5.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90102	 1	 15.79	 14.33	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90103	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90104	 1	 2.69	 3.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90105	 1	 0.56	 1.27	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90106	 1	 1.23	 2.47	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90107	 1	 5.58	 5.45	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90108	 1	 3.76	 4.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90109	 1	 3.67	 3.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90110	 1	 6.08	 7.58	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90111	 1	 5.3	 5.16	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90112	 1	 1.24	 2.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90113	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90114	 1	 9.31	 10.01	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90115	 1	 4.94	 5.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90116	 1	 4.08	 4.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90117	 1	 4.03	 5.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90118	 1	 3.07	 4.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90119	 1	 5.35	 7.4	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90120	 1	 5.87	 6.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90121	 1	 6.95	 7.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90122	 1	 2.67	 2.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90123	 1	 1.89	 3.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90124	 1	 1.65	 2.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90125	 1	 4.6	 4.57	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90126	 1	 6.66	 4.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90127	 1	 1.58	 2.37	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90128	 1	 2.08	 3.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90129	 1	 0.87	 1.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90130	 1	 4.37	 6.17	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90131	 1	 6.76	 1.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90132	 1	 1.68	 0.42	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90133	 1	 3.95	 5.04	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90134	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90135	 1	 9.1	 10.1	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90136	 1	 1.36	 3.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90137	 1	 4.44	 6.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90138	 1	 4.34	 4.96	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90139	 1	 2.89	 2.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90140	 1	 6.24	 7.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90141	 1	 2.42	 3.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90142	 1	 3.19	 3.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90143	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90144	 1	 2.01	 3.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90145	 1	 4.42	 5.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90146	 1	 8.11	 14.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90147	 1	 6.38	 6.13	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90148	 1	 2.79	 4.82	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90149	 1	 0.58	 1.51	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90150	 1	 0.71	 1.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90151	 1	 1.86	 4.04	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90152	 1	 3.56	 4.62	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90153	 1	 1.21	 3.18	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90154	 1	 1.45	 2.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90155	 1	 1.66	 3.16	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90156	 1	 1.44	 2.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90157	 1	 9.07	 8.4	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90158	 1	 8.86	 11.41	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90159	 1	 4.47	 7.31	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90160	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90161	 1	 3.75	 5.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90162	 1	 8.66	 9.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90163	 1	 1.5	 2.37	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90164	 1	 2.05	 3.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90165	 1	 3.25	 4.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90166	 1	 2.67	 4.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90167	 1	 1.15	 2.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90168	 1	 5.12	 7.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90169	 1	 3.42	 4.74	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90170	 1	 1.03	 2.46	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90171	 1	 5.19	 6.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90172	 1	 2.31	 2.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90173	 1	 1.62	 2.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90174	 1	 1.87	 2.43	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90175	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90176	 1	 1.43	 2.15	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90177	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90178	 1	 23.18	 23.16	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90179	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90180	 1	 2.84	 3.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90181	 1	 24.9	 23.51	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90182	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90183	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90184	 1	 11.38	 11.4	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90185	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90186	 1	 6.16	 5.51	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90187	 1	 2.58	 3.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90188	 1	 3.51	 5.57	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90189	 1	 3.3	 5.01	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90190	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90191	 1	 3.21	 3.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90192	 1	 0.61	 1.47	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90193	 1	 14.73	 19.14	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90194	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90195	 1	 0.76	 1.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90196	 1	 0.79	 1.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90197	 1	 0.89	 1.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90198	 1	 1.23	 2.74	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90199	 1	 2.15	 3.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90200	 1	 1.22	 2.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90201	 1	 0.52	 1.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90202	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90203	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90204	 1	 5.3	 7.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90205	 1	 1.86	 2.96	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90206	 1	 1.17	 2.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90207	 1	 1.18	 2.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90208	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90209	 1	 13.83	 15.13	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90210	 1	 6.38	 9.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90211	 1	 3.51	 3.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90212	 1	 3.71	 5.91	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90213	 1	 5.59	 10.59	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90214	 1	 28.1	 36.42	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90215	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90216	 1	 3.39	 6.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90217	 1	 2.47	 5.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90218	 1	 3.81	 6.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90219	 1	 3.6	 5.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90220	 1	 4.24	 8.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90221	 1	 2.88	 4.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90222	 1	 2.13	 3.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90223	 1	 0.87	 1.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90224	 1	 4.73	 5.46	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90225	 1	 3.28	 3.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90226	 1	 1.18	 2.57	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90227	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90228	 1	 2.61	 2.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90229	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90230	 1	 17.33	 22.42	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90231	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90232	 1	 4.76	 6.75	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90233	 1	 2.62	 3.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90234	 1	 1.71	 3.27	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90235	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90236	 1	 1.23	 2.41	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90237	 1	 8.75	 7.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90238	 1	 1.37	 1.71	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90239	 1	 8.66	 7.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90240	 1	 0.53	 1.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90241	 1	 0.67	 1.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90242	 1	 2.32	 2.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90243	 1	 3.82	 6.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90244	 1	 0.34	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90245	 1	 1.46	 2.96	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90246	 1	 8.23	 10.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90247	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90248	 1	 5.43	 6.37	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90249	 1	 2.56	 3.54	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90250	 1	 1.98	 2.77	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90251	 1	 7.11	 6.89	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90252	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90253	 1	 9.81	 12.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90254	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90255	 1	 2.89	 5.43	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90256	 1	 8.42	 8.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90257	 1	 2.64	 3.49	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90258	 1	 8.56	 9.46	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90259	 1	 3.51	 3.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90260	 1	 10.41	 7.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90261	 1	 2.15	 3.36	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90262	 1	 4.92	 1.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90263	 1	 2.43	 3.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90264	 1	 4.7	 4.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90265	 1	 3.28	 3.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90266	 1	 2.6	 2.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90267	 1	 5.33	 6.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90268	 1	 4.77	 6.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90269	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90270	 1	 13.46	 14.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90271	 1	 2.54	 3.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90272	 1	 2.87	 3.33	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90273	 1	 19.29	 16.95	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90274	 1	 3.89	 3.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90275	 1	 2.35	 3.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90276	 1	 1.05	 1.52	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90277	 1	 2.17	 2.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90278	 1	 1.37	 2.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90279	 1	 2.62	 4.05	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90280	 1	 3.94	 5.56	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90281	 1	 2.05	 2.73	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90282	 1	 2.6	 4.59	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90283	 1	 2.28	 3.65	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90284	 1	 3.24	 4.98	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90285	 1	 5.44	 6.14	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90286	 1	 10.76	 11.21	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90287	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90288	 1	 11.77	 12.41	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90289	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90290	 1	 4.15	 5.83	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90291	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90292	 1	 3.49	 0.85	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90293	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90294	 1	 7.58	 10.73	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90295	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90296	 1	 4.36	 6.85	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90297	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90298	 1	 9.07	 10.82	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90299	 1	 3.06	 5.26	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90300	 1	 2.25	 3.48	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90301	 1	 1.25	 2.57	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90302	 1	 1.74	 3.27	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90303	 1	 1.39	 2.69	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90304	 1	 0.82	 1.88	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90305	 1	 2.12	 3.6	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90306	 1	 3.09	 4.9	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90307	 1	 8.6	 10.98	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90308	 1	 4.78	 8.06	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90309	 1	 3.37	 5.62	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90310	 1	 1.39	 2.05	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90311	 1	 7.33	 10.95	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90312	 1	 8.61	 11.62	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90313	 1	 2.55	 4.21	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90314	 1	 2.79	 3.07	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90315	 1	 2.11	 3.73	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90316	 1	 1.73	 3.24	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90317	 1	 4.12	 5.31	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90318	 1	 5.88	 8.95	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90319	 1	 3.16	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90320	 1	 4.34	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90321	 1	 1.69	 2.53	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90322	 1	 1.27	 2.24	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90323	 1	 2.06	 3.48	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90324	 1	 4.86	 5.06	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90325	 1	 1.99	 3.6	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90326	 1	 5.09	 1.24	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90327	 1	 0.44	 0.93	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90328	 1	 3.64	 4.34	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90329	 1	 1.21	 1.96	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90330	 1	 5.36	 8.33	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90331	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90332	 1	 2.74	 4.4	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90333	 1	 1.32	 1.98	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90334	 1	 3.57	 4.47	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90335	 1	 0.62	 1.17	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90336	 1	 2.58	 2.67	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90337	 1	 8.0	 10.47	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90338	 1	 3.25	 4.63	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90339	 1	 0.54	 1.06	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90340	 1	 3.67	 5.78	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90341	 1	 0.53	 1.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90342	 1	 1.64	 2.92	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90343	 1	 1.76	 2.67	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90344	 1	 2.38	 3.28	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90345	 1	 3.41	 4.63	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90346	 1	 6.72	 10.75	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90347	 1	 1.39	 2.31	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90348	 1	 0.68	 1.15	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90349	 1	 3.08	 4.83	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90350	 1	 15.88	 22.61	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90351	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90352	 1	 1.04	 2.28	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90353	 1	 1.29	 2.59	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90354	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90355	 1	 1.9	 3.2	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90356	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90357	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90358	 1	 4.63	 8.22	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90359	 1	 3.27	 4.9	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90360	 1	 3.74	 4.2	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90361	 1	 2.2	 3.3	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90362	 1	 0.65	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90363	 1	 6.82	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90364	 1	 3.34	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90365	 1	 2.95	 3.41	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90366	 1	 3.28	 4.4	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90367	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90368	 1	 1.87	 2.82	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90369	 1	 5.2	 7.76	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90370	 1	 3.04	 4.57	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90371	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90372	 1	 6.32	 8.33	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90373	 1	 3.73	 3.88	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90374	 1	 1.64	 2.72	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90375	 1	 1.9	 3.54	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90376	 1	 11.41	 12.68	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90377	 1	 4.35	 5.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90378	 1	 3.37	 5.74	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90379	 1	 3.56	 5.04	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90380	 1	 1.93	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90381	 1	 3.45	 4.28	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90382	 1	 0.41	 0.77	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90383	 1	 0.49	 1.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90384	 1	 1.21	 2.14	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90385	 1	 0.65	 1.02	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90386	 1	 0.73	 1.5	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90387	 1	 2.46	 3.5	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90388	 1	 5.61	 8.17	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90389	 1	 0.38	 0.71	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90390	 1	 2.75	 4.69	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90391	 1	 9.51	 11.99	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90392	 1	 6.47	 10.44	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90393	 1	 3.4	 4.55	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90394	 1	 1.81	 3.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90395	 1	 0.75	 1.48	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90396	 1	 0.74	 1.18	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90397	 1	 1.51	 2.69	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90398	 1	 1.08	 2.09	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90399	 1	 2.61	 3.88	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90400	 1	 1.21	 2.08	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90401	 1	 2.34	 3.55	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90402	 1	 1.42	 2.46	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90403	 1	 0.95	 1.47	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90404	 1	 1.66	 2.45	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90405	 1	 1.56	 2.43	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90406	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90407	 1	 10.45	 15.83	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90408	 1	 0.75	 1.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90409	 1	 2.8	 3.27	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90410	 1	 2.11	 3.45	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90411	 1	 3.55	 4.84	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90412	 1	 3.61	 5.68	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90413	 1	 14.51	 21.53	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90414	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90415	 1	 3.7	 4.02	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90416	 1	 3.13	 5.4	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90417	 1	 11.06	 11.9	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90418	 1	 1.25	 2.15	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90419	 1	 2.14	 4.41	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90420	 1	 9.01	 7.73	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90421	 1	 2.05	 3.5	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90422	 1	 1.77	 3.05	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90423	 1	 1.28	 2.29	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90424	 1	 2.39	 3.82	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90425	 1	 1.11	 1.79	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90426	 1	 11.04	 15.38	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90427	 1	 1.39	 2.29	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90428	 1	 1.37	 2.13	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90429	 1	 2.79	 5.08	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90430	 1	 1.01	 1.6	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90431	 1	 1.87	 2.64	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90432	 1	 5.08	 7.33	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90433	 1	 3.43	 5.15	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90434	 1	 2.8	 4.1	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90435	 1	 17.31	 19.24	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90436	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90437	 1	 3.11	 3.56	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90438	 1	 5.12	 7.72	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90439	 1	 3.59	 5.83	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90440	 1	 4.6	 6.81	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90441	 1	 0.6	 1.01	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90442	 1	 0.69	 1.23	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90443	 1	 3.71	 3.17	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90444	 1	 1.38	 1.93	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90445	 1	 3.73	 5.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90446	 1	 0.82	 1.29	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90447	 1	 0.75	 1.4	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90448	 1	 1.79	 2.83	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90449	 1	 2.33	 2.76	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90450	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90451	 1	 10.97	 11.77	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90452	 1	 2.44	 3.2	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90453	 1	 7.95	 11.84	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90454	 1	 1.59	 2.67	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90455	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90456	 1	 2.92	 4.45	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90457	 1	 5.21	 6.38	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90458	 1	 1.89	 2.75	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90459	 1	 2.33	 3.2	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90460	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90461	 1	 6.32	 10.56	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90462	 1	 1.98	 3.03	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90463	 1	 1.28	 2.43	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90464	 1	 3.41	 5.99	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90465	 1	 1.78	 0.43	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90466	 1	 2.52	 0.61	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90467	 1	 3.58	 0.86	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90468	 1	 1.94	 0.47	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90469	 1	 3.89	 0.94	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90470	 1	 1.86	 0.45	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90471	 1	 3.03	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90472	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90473	 1	 7.87	 8.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90474	 1	 1.67	 2.79	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90475	 1	 3.24	 4.31	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90476	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90477	 1	 3.32	 4.89	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90478	 1	 3.44	 5.13	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90479	 1	 10.72	 11.96	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90480	 1	 1.79	 2.65	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90481	 1	 7.43	 8.38	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90482	 1	 4.99	 5.87	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90483	 1	 3.06	 3.63	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90484	 1	 4.06	 0.97	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90485	 1	 2.67	 4.27	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90486	 1	 0.95	 1.6	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90487	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90488	 1	 8.98	 14.78	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90489	 1	 4.01	 4.89	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90490	 1	 2.48	 3.83	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90491	 1	 0.91	 1.63	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90492	 1	 2.48	 3.5	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90493	 1	 2.24	 3.63	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90494	 1	 3.97	 5.43	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90495	 1	 1.88	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90496	 1	 2.37	 3.44	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90497	 1	 1.95	 3.65	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90498	 1	 1.66	 2.79	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90499	 1	 2.23	 4.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90500	 1	 3.65	 6.11	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90501	 1	 1.37	 2.61	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90502	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90503	 1	 8.36	 11.01	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90504	 1	 3.51	 5.33	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90505	 1	 0.41	 0.72	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90506	 1	 2.15	 3.13	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90507	 1	 2.32	 3.76	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90508	 1	 5.61	 9.57	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90509	 1	 2.29	 3.51	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90510	 1	 3.26	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90511	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90512	 1	 6.55	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90513	 1	 1.55	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90514	 1	 0.56	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90515	 1	 1.53	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90516	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90517	 1	 4.79	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90518	 1	 3.73	 6.61	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90519	 1	 1.21	 1.85	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90520	 1	 3.54	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90521	 1	 1.62	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90522	 1	 2.92	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90523	 1	 1.13	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90524	 1	 2.74	 3.96	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90525	 1	 5.03	 6.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90526	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90527	 1	 8.83	 12.37	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90528	 1	 3.23	 4.69	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90529	 1	 3.69	 4.78	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90530	 1	 0.81	 1.57	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90531	 1	 5.83	 7.5	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90532	 1	 4.48	 6.09	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90533	 1	 2.46	 3.39	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90534	 1	 1.48	 2.42	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90535	 1	 0.9	 1.4	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90536	 1	 2.72	 4.13	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90537	 1	 8.45	 9.38	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90538	 1	 0.94	 1.86	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90539	 1	 1.75	 2.46	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90540	 1	 2.52	 3.94	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90541	 1	 1.49	 2.61	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90542	 1	 2.77	 4.19	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90543	 1	 1.32	 2.66	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90544	 1	 1.89	 2.83	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90545	 1	 8.09	 12.95	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90546	 1	 4.26	 5.22	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90547	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90548	 1	 3.1	 3.51	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90549	 1	 1.3	 2.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90550	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90551	 1	 15.05	 22.84	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90552	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90553	 1	 2.52	 4.39	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90554	 1	 2.28	 2.84	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90555	 1	 2.65	 4.41	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90556	 1	 6.21	 9.8	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90557	 1	 1.33	 2.25	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90558	 1	 1.18	 1.79	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90559	 1	 1.81	 3.54	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90560	 1	 10.92	 11.17	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90561	 1	 1.99	 3.2	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90562	 1	 3.59	 3.8	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90563	 1	 3.37	 5.25	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90564	 1	 4.0	 4.35	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90565	 1	 4.38	 5.8	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90566	 1	 4.71	 8.64	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90567	 1	 6.76	 9.92	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90568	 1	 4.19	 5.49	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90569	 1	 3.04	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90570	 1	 10.92	 17.37	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90571	 1	 1.12	 2.02	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90572	 1	 0.73	 1.27	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90573	 1	 0.44	 0.82	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90574	 1	 0.41	 0.74	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90575	 1	 0.97	 1.62	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90576	 1	 1.72	 2.6	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90577	 1	 3.64	 5.75	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90578	 1	 1.38	 2.13	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90579	 1	 1.95	 2.93	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90580	 1	 2.12	 3.45	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90581	 1	 4.37	 7.52	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90582	 1	 1.59	 2.73	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90583	 1	 3.01	 3.85	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90584	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90585	 1	 0.81	 1.53	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90586	 1	 2.63	 4.74	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90587	 1	 7.24	 10.11	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90588	 1	 7.56	 12.11	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90589	 1	 6.2	 6.42	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90590	 1	 8.33	 11.37	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90591	 1	 18.57	 22.73	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90592	 1	 3.65	 5.95	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90593	 1	 2.75	 3.87	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90594	 1	 1.79	 2.99	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90595	 1	 3.1	 5.64	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90596	 1	 3.76	 6.28	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90597	 1	 5.32	 8.54	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90598	 1	 4.18	 5.66	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90599	 1	 3.74	 4.89	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90600	 1	 3.34	 5.9	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90601	 1	 2.54	 3.7	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90602	 1	 6.45	 8.42	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90603	 1	 3.55	 4.59	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90604	 1	 4.31	 5.66	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90605	 1	 3.39	 0.81	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90606	 1	 4.96	 6.7	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90607	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90608	 1	 2.38	 4.32	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90609	 1	 11.25	 16.13	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90610	 1	 1.87	 3.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90611	 1	 2.85	 3.74	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90612	 1	 1.81	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90613	 1	 2.99	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90614	 1	 3.87	 6.12	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90615	 1	 1.83	 2.95	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90616	 1	 1.8	 3.17	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90617	 1	 4.37	 6.56	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90618	 1	 1.98	 2.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90619	 1	 6.06	 7.86	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90620	 1	 6.19	 9.97	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90621	 1	 1.46	 2.29	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90622	 1	 2.03	 2.85	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90623	 1	 4.4	 7.75	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90624	 1	 4.32	 5.35	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90625	 1	 2.37	 3.69	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90626	 1	 0.93	 1.81	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90627	 1	 4.08	 6.29	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90628	 1	 3.59	 4.23	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90629	 1	 2.24	 4.58	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90630	 1	 1.47	 2.69	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90631	 1	 1.78	 3.17	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90632	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90633	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90634	 1	 54.72	 61.09	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90635	 1	 5.33	 7.3	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90636	 1	 2.82	 4.36	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90637	 1	 9.55	 14.04	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90638	 1	 3.19	 4.23	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90639	 1	 2.96	 5.21	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90640	 1	 4.1	 6.79	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90641	 1	 0.0	 0.0	 0.0	 0.0	 18	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90642	 1	 3.77	 5.54	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90643	 1	 6.07	 9.16	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90644	 1	 2.42	 3.42	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90645	 1	 2.97	 3.42	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90646	 1	 2.51	 3.44	 0.0	 0.0	 18	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90647	 1	 2.94	 4.68	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90648	 1	 5.21	 8.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90649	 1	 1.72	 3.24	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90650	 1	 0.83	 1.74	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90651	 1	 12.09	 22.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90652	 1	 2.76	 4.43	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90653	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90654	 1	 7.18	 12.9	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90655	 1	 2.12	 3.44	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90656	 1	 3.05	 6.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90657	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90658	 1	 4.65	 9.74	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90659	 1	 4.69	 9.3	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90660	 1	 0.71	 2.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90661	 1	 0.56	 1.99	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90662	 1	 14.17	 27.35	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90663	 1	 3.66	 5.02	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90664	 1	 2.24	 3.93	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90665	 1	 3.43	 7.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90666	 1	 5.28	 12.25	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90667	 1	 0.35	 1.17	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90668	 1	 1.03	 2.31	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90669	 1	 0.54	 1.45	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90670	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90671	 1	 0.99	 2.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90672	 1	 4.14	 5.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90673	 1	 5.15	 10.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90674	 1	 3.42	 7.97	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90675	 1	 8.17	 11.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90676	 1	 1.86	 3.83	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90677	 1	 2.73	 5.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90678	 1	 5.52	 7.82	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90679	 1	 1.57	 3.35	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90680	 1	 1.54	 3.65	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90681	 1	 2.69	 6.39	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90682	 1	 0.8	 2.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90683	 1	 1.91	 4.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90684	 1	 0.93	 2.48	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90685	 1	 2.7	 5.98	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90686	 1	 0.64	 1.6	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90687	 1	 0.88	 2.45	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90688	 1	 2.02	 5.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90689	 1	 1.11	 2.72	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90690	 1	 3.39	 7.94	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90691	 1	 4.17	 9.6	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90692	 1	 1.04	 2.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90693	 1	 1.56	 3.72	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90694	 1	 3.6	 5.74	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90695	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90696	 1	 8.31	 13.23	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90697	 1	 2.55	 5.72	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90698	 1	 7.47	 12.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90699	 1	 10.43	 18.05	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90700	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90701	 1	 2.23	 5.86	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90702	 1	 2.5	 4.67	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90703	 1	 1.86	 4.58	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90704	 1	 2.42	 5.97	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90705	 1	 3.79	 8.23	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90706	 1	 15.96	 26.69	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90707	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90708	 1	 0.62	 1.78	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90709	 1	 2.64	 5.19	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90710	 1	 1.09	 3.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90711	 1	 3.84	 7.44	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90712	 1	 1.9	 3.92	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90713	 1	 1.38	 1.27	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90714	 1	 3.84	 6.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90715	 1	 2.43	 3.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90716	 1	 7.94	 15.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90717	 1	 2.7	 3.63	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90718	 1	 1.63	 3.56	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90719	 1	 2.97	 4.66	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90720	 1	 3.44	 6.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90721	 1	 3.16	 7.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90722	 1	 23.83	 38.37	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90723	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90724	 1	 8.49	 18.51	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90725	 1	 1.48	 3.2	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90726	 1	 1.66	 3.36	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90727	 1	 7.7	 9.53	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90728	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90729	 1	 9.75	 21.17	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90730	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90731	 1	 1.55	 4.25	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90732	 1	 5.34	 8.91	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90733	 1	 0.49	 1.42	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90734	 1	 2.93	 7.03	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90735	 1	 3.37	 5.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90736	 1	 4.73	 9.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90737	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90738	 1	 2.9	 7.2	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90739	 1	 3.59	 5.95	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90740	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90741	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90742	 1	 8.43	 16.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90743	 1	 5.05	 10.99	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90744	 1	 1.02	 1.68	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90745	 1	 3.53	 6.74	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90746	 1	 1.1	 2.69	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90747	 1	 1.31	 2.25	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90748	 1	 1.27	 2.66	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90749	 1	 2.09	 5.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90750	 1	 1.31	 2.39	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90751	 1	 0.9	 2.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90752	 1	 0.82	 2.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90753	 1	 2.48	 5.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90754	 1	 1.31	 2.27	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90755	 1	 2.78	 5.56	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90756	 1	 3.44	 6.95	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90757	 1	 1.08	 2.02	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90758	 1	 0.87	 1.91	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90759	 1	 1.42	 3.09	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90760	 1	 5.9	 9.69	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90761	 1	 4.53	 7.71	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90762	 1	 4.8	 7.75	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90763	 1	 2.14	 4.35	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90764	 1	 2.02	 4.71	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90765	 1	 2.84	 3.83	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90766	 1	 3.53	 6.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90767	 1	 3.68	 6.51	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90768	 1	 0.97	 0.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90769	 1	 5.62	 1.54	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90770	 1	 1.27	 0.36	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90771	 1	 1.76	 0.49	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90772	 1	 2.04	 0.57	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90773	 1	 1.8	 0.5	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90774	 1	 2.13	 0.59	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90775	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90776	 1	 2.08	 0.57	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90777	 1	 18.23	 5.03	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90778	 1	 4.97	 1.35	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90779	 1	 1.24	 0.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90780	 1	 0.62	 0.17	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90781	 1	 2.51	 5.69	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90782	 1	 5.7	 11.32	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90783	 1	 10.67	 20.99	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90784	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90785	 1	 4.13	 6.75	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90786	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90787	 1	 1.34	 1.99	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90788	 1	 2.26	 4.55	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90789	 1	 4.31	 5.84	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90790	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90791	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90792	 1	 5.84	 11.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90793	 1	 2.86	 6.32	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90794	 1	 0.94	 2.59	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90795	 1	 2.26	 4.92	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90796	 1	 2.13	 4.84	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90797	 1	 2.63	 5.01	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90798	 1	 1.25	 2.92	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90799	 1	 2.98	 5.62	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90800	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90801	 1	 6.55	 11.83	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90802	 1	 2.92	 4.41	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90803	 1	 4.2	 6.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90804	 1	 3.59	 6.47	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90805	 1	 4.66	 5.61	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90806	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90807	 1	 2.53	 4.82	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90808	 1	 3.1	 4.93	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90809	 1	 1.51	 2.96	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90810	 1	 1.93	 4.24	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90811	 1	 7.82	 11.02	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90812	 1	 18.24	 5.14	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90813	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90814	 1	 27.98	 7.9	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90815	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90816	 1	 0.94	 0.27	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90817	 1	 1.86	 0.52	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90818	 1	 1.37	 0.39	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90819	 1	 2.07	 0.58	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90820	 1	 6.12	 1.71	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90821	 1	 4.56	 1.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90822	 1	 3.09	 0.87	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90823	 1	 3.07	 0.86	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90824	 1	 0.89	 0.26	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90825	 1	 0.38	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90826	 1	 2.25	 0.63	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90827	 1	 1.86	 0.52	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90828	 1	 0.24	 0.07	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90829	 1	 0.6	 0.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90830	 1	 0.56	 0.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90831	 1	 0.63	 0.17	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90832	 1	 0.72	 0.2	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90833	 1	 0.44	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90834	 1	 0.44	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90835	 1	 1.4	 0.39	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90836	 1	 8.0	 2.24	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90837	 1	 1.07	 0.3	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90838	 1	 1.1	 0.31	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90839	 1	 0.41	 0.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90840	 1	 0.35	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90841	 1	 0.88	 0.24	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90842	 1	 0.37	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90843	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90844	 1	 6.54	 1.84	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90845	 1	 0.44	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90846	 1	 0.89	 0.24	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90847	 1	 1.09	 0.31	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90848	 1	 0.97	 0.27	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90849	 1	 0.77	 0.21	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90850	 1	 0.99	 0.27	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90851	 1	 0.45	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90852	 1	 0.41	 0.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90853	 1	 5.58	 1.57	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90854	 1	 0.38	 0.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90855	 1	 0.42	 0.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90856	 1	 3.04	 0.85	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90857	 1	 1.03	 0.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90858	 1	 1.41	 0.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90859	 1	 0.48	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90860	 1	 0.41	 0.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90861	 1	 6.86	 1.93	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90862	 1	 5.71	 1.6	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90863	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90864	 1	 1.71	 0.48	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90865	 1	 7.99	 2.24	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90866	 1	 0.65	 0.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90867	 1	 0.29	 0.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90868	 1	 7.21	 2.02	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90869	 1	 1.51	 0.42	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90870	 1	 1.48	 0.41	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90871	 1	 0.99	 0.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90872	 1	 2.09	 0.58	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90873	 1	 1.43	 0.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90874	 1	 4.81	 1.34	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90875	 1	 1.56	 0.44	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90876	 1	 2.95	 0.82	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90877	 1	 5.67	 1.59	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90878	 1	 0.78	 0.22	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90879	 1	 1.24	 0.34	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90880	 1	 2.39	 0.67	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90881	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90882	 1	 8.15	 2.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90883	 1	 2.84	 0.8	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90884	 1	 0.47	 0.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90885	 1	 0.29	 0.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90886	 1	 7.29	 2.04	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90887	 1	 2.34	 0.65	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90888	 1	 3.58	 1.01	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90889	 1	 2.67	 0.74	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90890	 1	 1.03	 0.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90891	 1	 1.06	 0.3	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90892	 1	 1.93	 0.54	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90893	 1	 2.78	 0.77	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90894	 1	 14.85	 4.16	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90895	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90896	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90897	 1	 3.86	 1.08	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90898	 1	 26.91	 51.77	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90899	 1	 3.45	 5.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90900	 1	 4.31	 8.49	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90901	 1	 3.2	 5.28	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90902	 1	 1.65	 3.23	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90903	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90904	 1	 7.07	 13.56	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90905	 1	 0.9	 2.2	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90906	 1	 2.26	 3.89	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90907	 1	 2.69	 5.69	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90908	 1	 8.16	 13.91	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90909	 1	 5.91	 12.9	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90910	 1	 0.94	 2.41	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90911	 1	 2.37	 4.58	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90912	 1	 3.44	 5.54	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90913	 1	 3.6	 7.76	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90914	 1	 4.16	 5.34	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90915	 1	 5.13	 10.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90916	 1	 1.94	 3.96	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90917	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90918	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90919	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90920	 1	 3.77	 1.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90921	 1	 3.88	 8.36	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90922	 1	 2.25	 0.64	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90923	 1	 4.36	 1.23	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90924	 1	 1.76	 3.59	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90925	 1	 1.18	 3.15	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90926	 1	 4.24	 8.16	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90927	 1	 3.96	 9.32	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90928	 1	 3.27	 6.49	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90929	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90930	 1	 4.48	 8.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90931	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90932	 1	 2.14	 0.6	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90933	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90934	 1	 4.54	 1.27	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90935	 1	 1.11	 0.32	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90936	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90937	 1	 1.59	 0.45	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90938	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90939	 1	 2.81	 0.79	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90940	 1	 1.19	 0.34	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90941	 1	 1.75	 0.49	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90942	 1	 6.98	 1.95	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90943	 1	 66.74	 18.63	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90944	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90945	 1	 2.85	 0.78	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90946	 1	 8.08	 2.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90947	 1	 0.5	 1.32	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90948	 1	 0.63	 1.87	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90949	 1	 3.62	 6.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90950	 1	 3.44	 7.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90951	 1	 4.63	 8.51	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90952	 1	 4.76	 10.38	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90953	 1	 1.02	 2.47	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90954	 1	 1.75	 3.97	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90955	 1	 2.9	 5.47	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90956	 1	 2.7	 4.39	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90957	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90958	 1	 1.82	 3.65	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90959	 1	 5.46	 7.01	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90960	 1	 2.57	 5.09	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90961	 1	 4.12	 6.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90962	 1	 5.81	 11.65	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90963	 1	 0.69	 1.75	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90964	 1	 3.8	 6.03	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90965	 1	 4.08	 7.03	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90966	 1	 2.76	 5.74	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90967	 1	 1.32	 2.55	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90968	 1	 3.96	 5.6	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90969	 1	 1.92	 3.46	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90970	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90971	 1	 14.14	 27.06	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90972	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90973	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90974	 1	 3.83	 6.72	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90975	 1	 0.55	 1.3	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90976	 1	 1.8	 3.76	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90977	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	90978	 1	 1.58	 4.36	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	90979	 1	 3.35	 5.07	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90980	 1	 2.23	 4.18	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90981	 1	 1.29	 3.22	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90982	 1	 2.37	 3.8	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90983	 1	 0.85	 2.61	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90984	 1	 2.39	 4.74	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90985	 1	 0.67	 1.86	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90986	 1	 4.68	 7.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90987	 1	 3.59	 7.03	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90988	 1	 0.29	 0.8	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90989	 1	 3.37	 5.62	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90990	 1	 2.48	 5.7	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90991	 1	 4.49	 7.09	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90992	 1	 0.79	 1.69	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90993	 1	 0.93	 2.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90994	 1	 4.5	 10.24	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90995	 1	 2.0	 4.56	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90996	 1	 1.65	 3.8	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90997	 1	 4.04	 5.53	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90998	 1	 1.48	 3.81	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	90999	 1	 0.56	 1.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91000	 1	 0.87	 1.63	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91001	 1	 2.69	 4.48	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91002	 1	 7.26	 2.06	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91003	 1	 1.52	 3.43	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91004	 1	 3.05	 0.86	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91005	 1	 1.26	 0.36	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91006	 1	 1.99	 0.56	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91007	 1	 3.4	 0.96	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91008	 1	 4.04	 1.12	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91009	 1	 14.02	 3.91	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91010	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91011	 1	 2.29	 0.64	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91012	 1	 6.21	 1.73	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91013	 1	 6.84	 1.9	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91014	 1	 4.03	 1.13	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91015	 1	 5.25	 1.46	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91016	 1	 1.12	 2.61	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91017	 1	 1.21	 3.14	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91018	 1	 2.43	 4.33	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91019	 1	 4.72	 6.1	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91020	 1	 0.45	 1.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91021	 1	 2.09	 4.72	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91022	 1	 1.58	 3.55	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91023	 1	 1.2	 3.11	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91024	 1	 2.81	 5.42	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91025	 1	 3.17	 6.81	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91026	 1	 4.38	 5.81	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91027	 1	 2.49	 4.94	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91028	 1	 0.33	 0.97	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91029	 1	 3.81	 6.37	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91030	 1	 4.17	 6.63	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91031	 1	 2.53	 3.72	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91032	 1	 2.11	 4.39	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91033	 1	 1.16	 2.74	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91034	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91035	 1	 2.92	 4.97	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91036	 1	 3.81	 7.57	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91037	 1	 3.82	 4.88	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91038	 1	 5.74	 10.4	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91039	 1	 5.96	 10.49	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91040	 1	 4.33	 5.3	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91041	 1	 0.0	 0.0	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91042	 1	 2.73	 4.52	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91043	 1	 4.93	 9.49	 0.0	 0.0	 38	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91044	 1	 1.11	 2.35	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91045	 1	 5.14	 8.05	 0.0	 0.0	 38	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91046	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91047	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91048	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91049	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91050	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91051	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91052	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91053	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91054	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91055	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91056	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91057	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91058	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91059	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91060	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91061	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91062	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91063	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91064	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91065	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91066	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91067	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91068	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91069	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91070	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91071	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91072	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91073	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91074	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91075	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91076	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91077	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91078	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91079	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91080	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91081	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91082	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91083	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91084	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91085	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91086	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91087	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91088	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91089	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91090	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91091	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91092	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91093	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91094	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91095	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91096	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91097	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91098	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91099	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91100	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91101	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91102	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91103	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91104	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91105	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91106	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91107	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91108	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91109	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91110	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91111	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91112	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91113	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91114	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91115	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91116	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91117	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91118	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91119	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91120	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91121	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91122	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91123	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91124	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91125	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91126	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91127	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91128	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91129	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91130	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91131	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91132	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91133	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91134	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91135	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91136	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91137	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91138	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91139	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91140	 1	 340.02	 133.87	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91141	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91142	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91143	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91144	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91145	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91146	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91147	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91148	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91149	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91150	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91151	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91152	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91153	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91154	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91155	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91156	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91157	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91158	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91159	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91160	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91161	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91162	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91163	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91164	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91165	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91166	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91167	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91168	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91169	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91170	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91171	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91172	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91173	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91174	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91175	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91176	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91177	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91178	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91179	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91180	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91181	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91182	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91183	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91184	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91185	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91186	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91187	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91188	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91189	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91190	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91191	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91192	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91193	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91194	 2	 2.98	 2.46	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91195	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91196	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91197	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91198	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91199	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91200	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91201	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91202	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91203	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91204	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91205	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91206	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91207	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91208	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91209	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91210	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91211	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91212	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91213	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91214	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91215	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91216	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91217	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91218	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91219	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91220	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91221	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91222	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91223	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91224	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91225	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91226	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91227	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91228	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91229	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91230	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91231	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91232	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91233	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91234	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91235	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91236	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91237	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91238	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91239	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91240	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91241	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91242	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91243	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91244	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91245	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91246	 2	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91247	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91248	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91249	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91250	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91251	 1	 1.93	 1.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91252	 1	 11.12	 4.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91253	 1	 6.42	 3.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91254	 1	 3.9	 1.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91255	 1	 3.77	 2.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91256	 1	 9.71	 5.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91257	 1	 3.74	 2.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91258	 1	 13.19	 6.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91259	 1	 20.33	 7.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91260	 1	 16.78	 7.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91261	 1	 3.78	 2.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91262	 1	 4.28	 2.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91263	 1	 5.11	 3.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91264	 1	 4.03	 1.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91265	 1	 11.38	 5.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91266	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91267	 1	 15.62	 6.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91268	 1	 4.6	 2.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91269	 1	 3.27	 1.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91270	 1	 3.32	 1.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91271	 1	 19.4	 7.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91272	 1	 5.64	 2.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91273	 1	 2.76	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91274	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91275	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91276	 1	 23.52	 7.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91277	 1	 15.03	 7.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91278	 1	 3.4	 0.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91279	 1	 9.42	 5.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91280	 1	 6.9	 3.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91281	 1	 31.13	 14.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91282	 1	 2.74	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91283	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91284	 1	 4.64	 2.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91285	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91286	 1	 7.81	 3.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91287	 1	 17.4	 8.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91288	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91289	 1	 5.44	 2.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91290	 1	 25.55	 6.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91291	 1	 9.99	 5.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91292	 1	 7.13	 3.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91293	 1	 6.81	 3.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91294	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91295	 1	 9.57	 5.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91296	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91297	 1	 5.6	 3.49	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91298	 1	 6.37	 3.57	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91299	 1	 4.26	 2.67	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91300	 1	 5.75	 3.41	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91301	 1	 24.82	 10.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91302	 1	 7.75	 4.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91303	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91304	 1	 12.16	 5.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91305	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91306	 1	 4.87	 2.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91307	 1	 34.34	 18.55	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91308	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91309	 1	 4.88	 2.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91310	 1	 3.34	 1.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91311	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91312	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91313	 1	 12.54	 7.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91314	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91315	 1	 4.46	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91316	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91317	 1	 9.09	 5.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91318	 1	 15.91	 8.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91319	 1	 8.97	 4.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91320	 1	 4.1	 1.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91321	 1	 8.11	 4.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91322	 1	 7.58	 3.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91323	 1	 3.03	 1.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91324	 1	 3.96	 2.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91325	 1	 10.24	 3.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91326	 1	 12.47	 7.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91327	 1	 3.37	 2.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91328	 1	 12.22	 5.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91329	 1	 5.28	 2.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91330	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91331	 1	 8.89	 5.02	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91332	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91333	 1	 8.92	 5.05	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91334	 1	 21.44	 10.79	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91335	 1	 2.15	 1.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91336	 1	 3.64	 2.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91337	 1	 7.22	 4.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91338	 1	 5.58	 2.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91339	 1	 10.56	 5.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91340	 1	 3.95	 2.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91341	 1	 3.86	 2.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91342	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91343	 1	 2.23	 1.39	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91344	 1	 6.95	 3.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91345	 1	 11.9	 4.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91346	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91347	 1	 8.66	 5.34	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91348	 1	 3.2	 1.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91349	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91350	 1	 20.76	 8.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91351	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91352	 1	 5.82	 3.82	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91353	 1	 4.62	 2.45	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91354	 1	 29.63	 12.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91355	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91356	 1	 10.5	 4.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91357	 1	 2.31	 1.38	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91358	 1	 6.28	 3.56	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91359	 1	 5.8	 3.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91360	 1	 14.76	 7.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91361	 1	 12.84	 6.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91362	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91363	 1	 6.17	 3.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91364	 1	 11.92	 7.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91365	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91366	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91367	 1	 13.52	 7.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91368	 1	 6.35	 2.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91369	 1	 15.7	 6.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91370	 1	 6.69	 3.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91371	 1	 5.92	 3.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91372	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91373	 1	 14.42	 6.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91374	 1	 2.94	 1.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91375	 1	 11.58	 3.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91376	 1	 2.48	 1.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91377	 1	 3.86	 2.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91378	 1	 2.14	 1.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91379	 1	 2.94	 1.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91380	 1	 5.89	 3.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91381	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91382	 1	 17.9	 9.74	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91383	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91384	 1	 26.7	 8.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91385	 1	 7.56	 3.48	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91386	 1	 3.72	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91387	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91388	 1	 12.57	 6.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91389	 1	 12.37	 5.49	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91390	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91391	 1	 9.32	 5.21	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91392	 1	 4.52	 2.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91393	 1	 5.43	 2.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91394	 1	 2.95	 1.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91395	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91396	 1	 5.21	 3.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91397	 1	 8.52	 4.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91398	 1	 8.53	 3.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91399	 1	 10.86	 3.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91400	 1	 8.83	 4.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91401	 1	 4.31	 1.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91402	 1	 7.53	 1.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91403	 1	 7.76	 1.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91404	 1	 5.39	 1.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91405	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91406	 1	 8.92	 4.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91407	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91408	 1	 47.66	 25.15	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91409	 1	 3.41	 2.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91410	 1	 5.61	 3.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91411	 1	 9.88	 5.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91412	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91413	 1	 3.09	 2.14	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91414	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91415	 1	 4.04	 2.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91416	 1	 9.9	 5.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91417	 1	 20.18	 8.06	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91418	 1	 8.47	 5.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91419	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91420	 1	 11.92	 4.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91421	 1	 5.78	 3.66	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91422	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91423	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91424	 1	 9.03	 5.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91425	 1	 3.91	 1.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91426	 1	 7.19	 4.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91427	 1	 11.44	 4.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91428	 1	 6.76	 4.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91429	 1	 18.43	 7.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91430	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91431	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91432	 1	 9.61	 4.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91433	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91434	 1	 18.51	 9.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91435	 1	 8.66	 4.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91436	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91437	 1	 26.25	 13.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91438	 1	 3.46	 1.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91439	 1	 7.14	 3.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91440	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91441	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91442	 1	 38.01	 17.35	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91443	 1	 7.02	 3.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91444	 1	 5.97	 3.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91445	 1	 10.64	 5.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91446	 1	 2.35	 1.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91447	 1	 4.63	 2.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91448	 1	 2.03	 1.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91449	 1	 14.77	 7.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91450	 1	 17.39	 6.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91451	 1	 15.18	 9.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91452	 1	 4.2	 2.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91453	 1	 4.32	 2.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91454	 1	 3.09	 1.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91455	 1	 2.76	 1.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91456	 1	 25.79	 15.1	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91457	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91458	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91459	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91460	 1	 3.96	 2.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91461	 1	 17.01	 10.72	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91462	 1	 29.62	 14.88	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91463	 1	 12.64	 5.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91464	 1	 8.64	 4.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91465	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91466	 1	 3.93	 2.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91467	 1	 4.15	 2.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91468	 1	 5.15	 2.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91469	 1	 6.42	 4.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91470	 1	 18.08	 7.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91471	 1	 3.86	 2.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91472	 1	 6.34	 3.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91473	 1	 2.47	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91474	 1	 9.48	 5.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91475	 1	 4.29	 2.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91476	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91477	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91478	 1	 10.41	 4.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91479	 1	 8.27	 4.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91480	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91481	 1	 11.71	 6.71	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91482	 1	 12.89	 5.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91483	 1	 9.71	 6.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91484	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91485	 1	 49.92	 25.65	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91486	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91487	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91488	 1	 4.76	 3.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91489	 1	 7.52	 4.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91490	 1	 8.23	 3.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91491	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91492	 1	 4.55	 2.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91493	 1	 9.67	 2.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91494	 1	 3.6	 0.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91495	 1	 4.25	 1.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91496	 1	 17.01	 4.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91497	 1	 5.23	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91498	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91499	 1	 22.05	 5.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91500	 1	 6.63	 1.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91501	 1	 11.68	 4.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91502	 1	 3.98	 2.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91503	 1	 3.76	 1.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91504	 1	 8.95	 4.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91505	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91506	 1	 5.74	 2.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91507	 1	 17.97	 9.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91508	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91509	 1	 30.22	 15.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91510	 1	 4.92	 2.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91511	 1	 7.77	 4.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91512	 1	 5.19	 2.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91513	 1	 4.54	 2.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91514	 1	 22.71	 11.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91515	 1	 10.79	 5.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91516	 1	 8.86	 5.07	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91517	 1	 5.12	 2.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91518	 1	 6.34	 4.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91519	 1	 9.82	 5.43	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91520	 1	 4.4	 2.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91521	 1	 3.11	 1.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91522	 1	 23.19	 9.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91523	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91524	 1	 27.33	 14.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91525	 1	 8.98	 5.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91526	 1	 10.73	 5.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91527	 1	 7.22	 4.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91528	 1	 8.51	 3.89	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91529	 1	 6.89	 4.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91530	 1	 26.83	 13.13	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91531	 1	 22.73	 13.14	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91532	 1	 14.89	 8.32	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91533	 1	 16.36	 8.71	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91534	 1	 18.93	 8.96	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91535	 1	 22.61	 9.86	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91536	 1	 12.42	 6.17	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91537	 1	 21.35	 11.01	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91538	 1	 24.5	 12.56	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91539	 1	 582.52	 183.78	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91540	 1	 19.06	 8.56	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91541	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91542	 1	 23.74	 10.18	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91543	 1	 18.65	 4.39	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91544	 1	 26.23	 12.34	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91545	 1	 14.68	 6.96	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91546	 1	 43.29	 23.21	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91547	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91548	 1	 46.81	 26.25	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91549	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91550	 1	 15.01	 8.06	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91551	 1	 23.15	 15.26	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91552	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91553	 1	 12.68	 2.97	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91554	 1	 44.6	 26.6	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91555	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91556	 1	 29.03	 6.62	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91557	 1	 22.15	 5.15	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91558	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91559	 1	 17.34	 10.19	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91560	 1	 11.34	 5.65	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91561	 1	 45.47	 24.3	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91562	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91563	 1	 4.17	 0.99	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91564	 1	 11.01	 2.57	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91565	 1	 16.53	 3.92	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91566	 1	 25.97	 12.46	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91567	 1	 17.55	 7.66	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91568	 1	 13.4	 5.94	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91569	 1	 24.59	 5.83	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91570	 1	 16.05	 3.8	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91571	 1	 6.93	 1.63	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91572	 1	 32.71	 7.67	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91573	 1	 28.83	 6.66	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91574	 1	 10.31	 2.46	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91575	 1	 11.88	 5.71	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91576	 1	 12.81	 6.46	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91577	 1	 15.38	 8.46	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91578	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91579	 1	 19.03	 11.35	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91580	 1	 11.57	 6.98	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91581	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91582	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91583	 1	 14.0	 7.8	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91584	 1	 14.79	 7.52	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91585	 1	 12.36	 6.9	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91586	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91587	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91588	 1	 12.75	 6.32	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91589	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91590	 1	 164.54	 58.2	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91591	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91592	 1	 24.38	 13.74	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91593	 1	 15.92	 9.01	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91594	 1	 9.34	 4.62	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91595	 1	 394.04	 198.52	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91596	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91597	 1	 8.79	 2.05	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91598	 1	 11.74	 2.75	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91599	 1	 11.19	 2.64	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91600	 1	 4.87	 1.11	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91601	 1	 10.8	 2.49	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91602	 1	 39.52	 14.14	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91603	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91604	 1	 9.89	 4.86	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91605	 1	 6.9	 3.89	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91606	 1	 6.3	 2.84	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91607	 1	 14.81	 7.13	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91608	 1	 14.52	 8.67	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91609	 1	 24.51	 13.44	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91610	 1	 10.09	 5.05	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91611	 1	 11.77	 5.52	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91612	 1	 22.76	 12.65	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91613	 1	 10.02	 5.51	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91614	 1	 11.92	 5.6	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91615	 1	 397.38	 181.16	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91616	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91617	 1	 12.25	 5.73	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91618	 1	 7.41	 3.93	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91619	 1	 18.88	 10.91	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91620	 1	 12.2	 6.07	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91621	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91622	 1	 13.04	 6.34	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91623	 1	 21.19	 10.47	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91624	 1	 16.84	 8.96	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91625	 1	 21.09	 9.63	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91626	 1	 19.82	 11.57	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91627	 1	 16.94	 8.5	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91628	 1	 53.76	 30.79	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91629	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91630	 1	 18.65	 10.69	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91631	 1	 15.47	 8.49	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91632	 1	 27.88	 14.38	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91633	 1	 13.57	 7.71	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91634	 1	 19.2	 10.87	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91635	 1	 13.73	 7.44	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91636	 1	 20.73	 12.34	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91637	 1	 131.53	 59.3	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91638	 1	 10.7	 5.06	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91639	 1	 8.51	 4.55	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91640	 1	 27.33	 11.84	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91641	 1	 11.79	 5.49	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91642	 1	 6.36	 1.47	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91643	 1	 11.04	 6.31	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91644	 1	 52.01	 27.07	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91645	 1	 10.3	 4.73	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91646	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91647	 1	 23.91	 10.16	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91648	 1	 20.07	 4.59	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91649	 1	 7.39	 1.71	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91650	 1	 11.95	 6.44	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91651	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91652	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91653	 1	 16.69	 3.85	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91654	 1	 71.37	 26.22	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91655	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91656	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91657	 1	 271.59	 95.53	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91658	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91659	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91660	 1	 130.62	 69.9	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91661	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91662	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91663	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91664	 1	 10.95	 6.02	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91665	 1	 12.32	 5.32	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91666	 1	 11.59	 5.56	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91667	 1	 6.49	 3.07	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91668	 1	 38.92	 24.08	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91669	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91670	 1	 10.25	 5.8	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91671	 1	 13.04	 7.11	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91672	 1	 14.24	 6.65	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91673	 1	 7.23	 3.7	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91674	 1	 4.11	 2.27	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91675	 1	 6.28	 3.01	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91676	 1	 6.64	 3.44	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91677	 1	 9.9	 5.07	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91678	 1	 12.81	 7.05	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91679	 1	 9.66	 4.58	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91680	 1	 110.14	 53.96	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91681	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91682	 1	 6.52	 3.25	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91683	 1	 3.56	 1.85	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91684	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91685	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91686	 1	 23.71	 13.55	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91687	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91688	 1	 12.18	 5.87	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91689	 1	 8.68	 4.59	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91690	 1	 5.59	 3.01	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91691	 1	 13.75	 8.34	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91692	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91693	 1	 7.29	 4.55	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91694	 1	 30.19	 15.18	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91695	 1	 11.94	 4.76	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91696	 1	 108.27	 49.55	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91697	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91698	 1	 30.61	 15.88	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91699	 1	 77.48	 45.62	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91700	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91701	 1	 8.35	 3.95	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91702	 1	 18.67	 11.68	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91703	 1	 27.25	 14.85	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91704	 1	 15.45	 8.21	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91705	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91706	 1	 17.93	 4.21	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91707	 1	 13.16	 3.07	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91708	 1	 18.22	 4.29	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91709	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91710	 1	 32.38	 14.41	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91711	 1	 10.26	 2.41	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91712	 1	 23.3	 5.5	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91713	 1	 15.44	 3.6	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91714	 1	 16.23	 3.77	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91715	 1	 23.89	 5.49	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91716	 1	 18.82	 4.34	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91717	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91718	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91719	 1	 22.24	 5.13	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91720	 1	 12.75	 2.99	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91721	 1	 129.08	 55.27	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91722	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91723	 1	 20.95	 7.81	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91724	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91725	 1	 21.13	 4.72	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91726	 1	 13.08	 3.05	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91727	 1	 25.03	 5.85	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91728	 1	 16.58	 8.68	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91729	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91730	 1	 28.91	 14.18	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91731	 1	 9.35	 2.21	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91732	 1	 19.94	 10.71	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91733	 1	 17.68	 8.66	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91734	 1	 29.4	 16.82	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91735	 1	 45.08	 20.98	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91736	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91737	 1	 26.85	 13.97	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91738	 1	 18.3	 10.42	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91739	 1	 12.4	 6.36	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91740	 1	 10.4	 5.32	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91741	 1	 10.15	 2.34	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91742	 1	 23.13	 10.34	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91743	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91744	 1	 32.81	 13.67	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91745	 1	 7.78	 4.53	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91746	 1	 8.65	 5.36	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91747	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91748	 1	 8.93	 4.77	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91749	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91750	 1	 10.39	 4.72	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91751	 1	 8.14	 3.98	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91752	 1	 0.87	 0.5	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91753	 1	 1.76	 0.99	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91754	 1	 6.47	 2.89	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91755	 1	 8.2	 3.27	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91756	 1	 3.32	 1.69	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91757	 1	 13.96	 6.11	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91758	 1	 23.55	 11.83	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91759	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91760	 1	 8.1	 4.17	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91761	 1	 9.57	 5.8	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91762	 1	 4.4	 2.13	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91763	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91764	 1	 8.11	 4.66	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91765	 1	 3.78	 1.77	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91766	 1	 7.16	 3.76	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91767	 1	 7.39	 3.49	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91768	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91769	 1	 9.71	 6.16	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91770	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91771	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91772	 1	 129.47	 47.43	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91773	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91774	 1	 9.27	 5.65	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91775	 1	 2.87	 1.52	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91776	 1	 2.79	 1.3	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91777	 1	 3.22	 1.69	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91778	 1	 3.34	 1.69	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91779	 1	 3.54	 2.09	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91780	 1	 7.99	 4.88	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91781	 1	 2.54	 1.16	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91782	 1	 4.96	 2.29	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91783	 1	 7.96	 5.03	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91784	 1	 5.43	 3.11	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91785	 1	 2.99	 1.5	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91786	 1	 8.13	 3.77	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91787	 1	 5.34	 2.82	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91788	 1	 8.35	 4.16	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91789	 1	 11.37	 6.28	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91790	 1	 4.23	 1.91	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91791	 1	 8.94	 5.3	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91792	 1	 2.5	 1.24	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91793	 1	 1.88	 0.85	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91794	 1	 3.35	 1.6	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91795	 1	 10.34	 5.4	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91796	 1	 3.58	 1.67	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91797	 1	 5.64	 3.24	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91798	 1	 6.76	 4.17	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91799	 1	 5.03	 2.29	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91800	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91801	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91802	 1	 10.87	 6.23	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91803	 1	 3.89	 2.01	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91804	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91805	 1	 5.38	 2.64	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91806	 1	 4.39	 1.92	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91807	 1	 65.19	 39.26	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91808	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91809	 1	 2.01	 1.06	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91810	 1	 6.7	 3.14	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91811	 1	 5.81	 2.77	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91812	 1	 12.03	 7.13	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91813	 1	 1.18	 0.75	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91814	 1	 9.69	 5.64	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91815	 1	 9.5	 4.17	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91816	 1	 13.74	 5.47	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91817	 1	 6.62	 3.45	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91818	 1	 3.7	 1.82	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91819	 1	 22.0	 12.83	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91820	 1	 11.93	 7.22	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91821	 1	 8.21	 4.38	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91822	 1	 29.06	 16.31	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91823	 1	 6.09	 3.17	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91824	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91825	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91826	 1	 52.11	 24.73	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91827	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91828	 1	 23.07	 11.8	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91829	 1	 9.16	 5.17	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91830	 1	 18.32	 10.19	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91831	 1	 50.84	 23.28	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91832	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91833	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91834	 1	 10.42	 6.26	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91835	 1	 25.75	 5.98	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91836	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91837	 1	 25.07	 13.88	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91838	 1	 14.45	 8.14	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91839	 1	 11.5	 6.42	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91840	 1	 48.88	 19.75	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91841	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91842	 1	 12.42	 6.83	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91843	 1	 9.58	 4.71	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91844	 1	 12.89	 6.36	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91845	 1	 18.75	 7.77	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91846	 1	 19.24	 9.8	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91847	 1	 26.77	 13.04	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91848	 1	 30.85	 7.25	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91849	 1	 11.24	 5.92	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91850	 1	 18.71	 11.3	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91851	 1	 12.66	 7.37	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91852	 1	 17.05	 8.71	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91853	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91854	 1	 9.08	 3.76	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91855	 1	 13.92	 6.27	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91856	 1	 11.52	 6.66	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91857	 1	 15.23	 8.65	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91858	 1	 76.53	 38.72	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91859	 1	 5.45	 3.03	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91860	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91861	 1	 94.12	 52.33	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91862	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91863	 1	 4.42	 2.37	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91864	 1	 8.66	 4.92	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91865	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91866	 1	 168.32	 71.81	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91867	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91868	 1	 5.64	 2.59	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91869	 1	 7.03	 2.95	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91870	 1	 20.5	 11.86	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91871	 1	 14.66	 7.47	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91872	 1	 15.86	 3.69	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91873	 1	 14.24	 3.32	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91874	 1	 6.66	 1.56	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91875	 1	 13.1	 3.07	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91876	 1	 16.6	 3.91	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91877	 1	 17.78	 4.17	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91878	 1	 18.73	 4.37	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91879	 1	 29.2	 6.7	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91880	 1	 30.96	 18.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91881	 1	 3.71	 1.89	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91882	 1	 11.37	 7.08	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91883	 1	 16.81	 8.84	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91884	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91885	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91886	 1	 30.26	 16.39	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91887	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91888	 1	 14.52	 7.2	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91889	 1	 10.71	 6.58	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91890	 1	 25.94	 13.38	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91891	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91892	 1	 27.22	 12.93	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91893	 1	 19.23	 10.25	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91894	 1	 11.24	 5.1	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91895	 1	 9.47	 4.14	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91896	 1	 16.19	 8.26	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91897	 1	 23.09	 10.75	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91898	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91899	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91900	 1	 11.92	 5.96	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91901	 1	 18.33	 9.87	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91902	 1	 11.34	 5.03	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91903	 1	 11.2	 5.24	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91904	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91905	 1	 25.33	 14.42	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91906	 1	 18.57	 11.44	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91907	 1	 37.87	 13.94	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91908	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91909	 1	 19.85	 9.18	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91910	 1	 24.15	 10.02	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91911	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91912	 1	 18.54	 8.59	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91913	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91914	 1	 11.73	 6.66	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91915	 1	 21.81	 4.9	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91916	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91917	 1	 31.15	 16.82	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91918	 1	 8.0	 3.65	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91919	 1	 11.94	 6.59	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91920	 1	 17.6	 8.79	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91921	 1	 16.34	 7.24	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91922	 1	 21.12	 4.88	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91923	 1	 16.17	 3.7	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91924	 1	 9.96	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91925	 1	 9.48	 4.14	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91926	 1	 17.77	 10.28	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91927	 1	 24.67	 16.06	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91928	 1	 6.14	 3.17	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91929	 1	 7.19	 4.06	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91930	 1	 15.65	 9.73	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91931	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91932	 1	 7.07	 3.66	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91933	 1	 27.12	 15.11	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91934	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91935	 1	 35.06	 10.49	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91936	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91937	 1	 3.58	 0.85	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91938	 1	 27.79	 6.45	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91939	 1	 20.37	 4.75	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91940	 1	 6.52	 1.51	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91941	 1	 15.92	 9.06	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91942	 1	 9.25	 2.15	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91943	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91944	 1	 14.89	 7.78	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91945	 1	 27.62	 15.31	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91946	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91947	 1	 12.41	 6.37	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91948	 1	 13.73	 5.71	 0.0	 0.0	 13	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91949	 1	 13.6	 3.38	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91950	 1	 10.4	 9.46	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91951	 1	 8.7	 7.95	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91952	 1	 12.44	 9.29	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91953	 1	 6.09	 5.22	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91954	 1	 23.66	 16.65	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91955	 1	 7.45	 5.65	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91956	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91957	 1	 10.68	 8.31	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91958	 1	 8.13	 5.49	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91959	 1	 6.56	 5.06	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91960	 1	 6.55	 4.65	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91961	 1	 3.11	 0.75	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91962	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91963	 1	 5.09	 4.29	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91964	 1	 12.64	 9.33	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91965	 1	 9.86	 7.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91966	 1	 11.78	 10.28	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91967	 1	 6.8	 6.37	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91968	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91969	 1	 23.58	 21.4	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91970	 1	 17.61	 15.03	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91971	 1	 9.93	 7.21	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91972	 1	 12.02	 11.05	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91973	 1	 12.51	 9.52	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91974	 1	 11.18	 10.06	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91975	 1	 1.47	 1.34	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91976	 1	 1.78	 1.72	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91977	 1	 15.71	 8.58	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91978	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91979	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	91980	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91981	 1	 6.93	 6.64	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91982	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91983	 1	 15.12	 14.1	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91984	 1	 2.81	 2.39	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91985	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91986	 1	 10.72	 7.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91987	 1	 5.86	 5.79	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91988	 1	 12.66	 9.11	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91989	 1	 6.91	 5.45	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91990	 1	 8.59	 2.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91991	 1	 5.43	 1.34	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91992	 1	 3.17	 0.76	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91993	 1	 13.82	 9.71	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91994	 1	 13.23	 10.59	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91995	 1	 11.25	 10.68	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91996	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	91997	 1	 17.04	 15.96	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	91998	 1	 9.68	 7.63	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	91999	 1	 14.25	 12.81	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92000	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92001	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92002	 1	 16.83	 14.31	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92003	 1	 12.2	 2.96	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92004	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92005	 1	 8.79	 7.63	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92006	 1	 3.97	 3.79	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92007	 1	 9.22	 8.73	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92008	 1	 3.37	 3.11	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92009	 1	 9.96	 6.95	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92010	 1	 7.36	 5.81	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92011	 1	 11.43	 8.06	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92012	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92013	 1	 12.33	 9.31	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92014	 1	 4.07	 3.17	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92015	 1	 3.48	 2.98	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92016	 1	 7.47	 5.09	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92017	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92018	 1	 5.34	 4.47	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92019	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92020	 1	 3.73	 3.42	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92021	 1	 7.0	 5.47	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92022	 1	 7.1	 5.91	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92023	 1	 6.57	 5.58	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92024	 1	 6.93	 6.21	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92025	 1	 11.99	 9.98	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92026	 1	 4.71	 4.33	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92027	 1	 10.1	 8.23	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92028	 1	 8.54	 6.77	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92029	 1	 7.84	 6.15	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92030	 1	 16.04	 12.98	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92031	 1	 7.78	 5.66	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92032	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	92033	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92034	 1	 73.86	 51.42	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92035	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92036	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92037	 1	 14.29	 12.97	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92038	 1	 14.06	 3.48	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92039	 1	 12.78	 3.15	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92040	 1	 7.28	 1.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92041	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92042	 1	 17.62	 13.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92043	 1	 3.78	 0.92	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92044	 1	 9.7	 8.22	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92045	 1	 5.26	 1.27	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92046	 1	 2.4	 0.57	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92047	 1	 10.53	 2.51	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92048	 1	 1.86	 0.44	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92049	 1	 11.85	 2.81	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92050	 1	 5.53	 3.92	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92051	 1	 8.37	 2.04	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92052	 1	 11.68	 10.33	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92053	 1	 5.96	 1.43	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92054	 1	 10.28	 8.25	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92055	 1	 2.45	 2.25	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92056	 1	 22.91	 18.89	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92057	 1	 10.63	 8.43	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92058	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92059	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92060	 1	 22.12	 17.66	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92061	 1	 10.0	 6.28	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92062	 1	 13.43	 10.01	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92063	 1	 23.68	 14.77	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92064	 1	 17.5	 11.74	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92065	 1	 11.24	 2.68	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92066	 1	 9.81	 2.34	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92067	 1	 8.12	 1.94	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92068	 1	 4.98	 3.47	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92069	 1	 4.33	 3.32	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92070	 1	 4.24	 3.6	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92071	 1	 2.45	 2.03	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92072	 1	 14.58	 9.67	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92073	 1	 2.82	 2.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92074	 1	 3.14	 2.46	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92075	 1	 3.24	 2.61	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92076	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92077	 1	 5.38	 4.45	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92078	 1	 5.41	 4.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92079	 1	 8.36	 6.16	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92080	 1	 9.98	 5.79	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92081	 1	 7.57	 6.97	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92082	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92083	 1	 7.32	 6.42	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92084	 1	 15.59	 10.9	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92085	 1	 8.1	 6.47	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92086	 1	 2.75	 2.38	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92087	 1	 9.27	 7.01	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92088	 1	 6.54	 5.7	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92089	 1	 18.14	 12.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92090	 1	 20.5	 14.18	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92091	 1	 16.36	 4.04	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92092	 1	 8.49	 7.52	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92093	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92094	 1	 8.86	 7.27	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92095	 1	 3.57	 3.22	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92096	 1	 12.48	 10.43	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92097	 1	 10.0	 6.86	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92098	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92099	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92100	 1	 7.52	 5.7	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92101	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92102	 1	 11.73	 10.58	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92103	 1	 3.52	 2.99	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92104	 1	 3.68	 2.71	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92105	 1	 5.1	 4.31	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92106	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92107	 1	 5.41	 4.22	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92108	 1	 4.4	 3.93	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92109	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92110	 1	 11.69	 9.37	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92111	 1	 1.59	 1.3	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92112	 1	 1.3	 0.96	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92113	 1	 5.49	 4.87	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92114	 1	 2.61	 1.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92115	 1	 3.85	 3.41	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92116	 1	 4.31	 3.63	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92117	 1	 8.53	 5.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92118	 1	 1.77	 1.27	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92119	 1	 3.03	 2.51	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92120	 1	 7.34	 5.52	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92121	 1	 6.61	 5.88	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92122	 1	 7.57	 5.2	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92123	 1	 4.84	 3.04	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92124	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92125	 1	 4.21	 3.66	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92126	 1	 6.59	 5.31	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92127	 1	 10.89	 9.98	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92128	 1	 4.47	 3.86	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92129	 1	 10.17	 8.29	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92130	 1	 6.64	 5.24	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92131	 1	 5.38	 4.87	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92132	 1	 7.12	 5.19	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92133	 1	 13.15	 10.15	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92134	 1	 4.35	 2.73	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92135	 1	 6.32	 4.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92136	 1	 11.07	 8.2	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92137	 1	 6.6	 6.05	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92138	 1	 8.29	 6.78	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92139	 1	 6.68	 4.7	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92140	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92141	 1	 23.76	 19.56	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92142	 1	 8.06	 7.61	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92143	 1	 4.37	 3.42	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92144	 1	 15.73	 11.66	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92145	 1	 2.07	 1.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92146	 1	 2.12	 1.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92147	 1	 8.08	 6.02	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92148	 1	 16.2	 12.16	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92149	 1	 23.42	 14.79	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92150	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92151	 1	 7.67	 6.05	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92152	 1	 82.02	 58.03	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92153	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92154	 1	 10.41	 8.58	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92155	 1	 25.11	 15.43	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92156	 1	 4.9	 3.28	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92157	 1	 1.89	 1.28	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92158	 1	 16.98	 13.27	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92159	 1	 7.98	 6.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92160	 1	 9.21	 6.85	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92161	 1	 12.51	 7.48	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92162	 1	 15.34	 11.61	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92163	 1	 10.17	 7.25	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92164	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92165	 1	 18.45	 13.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92166	 1	 9.95	 5.66	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92167	 1	 14.68	 8.81	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92168	 1	 19.82	 13.99	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92169	 1	 5.11	 3.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92170	 1	 16.34	 13.12	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92171	 1	 8.35	 6.64	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92172	 1	 7.98	 7.34	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92173	 1	 5.8	 4.57	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92174	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92175	 1	 6.78	 4.81	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92176	 1	 11.8	 2.82	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92177	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92178	 1	 3.82	 3.36	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92179	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92180	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92181	 1	 9.93	 6.87	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92182	 1	 8.22	 7.05	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92183	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92184	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92185	 1	 8.26	 6.29	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92186	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92187	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92188	 1	 8.13	 6.27	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92189	 1	 7.47	 4.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92190	 1	 13.03	 9.61	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92191	 1	 9.2	 7.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92192	 1	 15.09	 10.57	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92193	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92194	 1	 16.03	 10.73	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92195	 1	 7.58	 6.22	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92196	 1	 17.35	 4.14	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92197	 1	 4.85	 4.39	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92198	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92199	 1	 14.91	 9.29	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92200	 1	 7.95	 1.93	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92201	 1	 10.08	 9.03	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92202	 1	 18.18	 4.35	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92203	 1	 20.53	 13.17	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92204	 1	 8.69	 6.2	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92205	 1	 12.14	 8.21	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92206	 1	 7.68	 6.98	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92207	 1	 17.02	 4.12	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92208	 1	 7.24	 1.75	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92209	 1	 13.2	 3.31	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92210	 1	 6.52	 5.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92211	 1	 12.75	 9.08	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92212	 1	 6.79	 5.92	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92213	 1	 9.84	 8.25	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92214	 1	 9.17	 7.5	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92215	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92216	 1	 8.89	 7.32	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92217	 1	 11.34	 2.76	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92218	 1	 4.66	 1.15	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92219	 1	 11.26	 2.81	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92220	 1	 9.18	 2.27	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92221	 1	 5.23	 1.27	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92222	 1	 8.81	 2.12	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92223	 1	 18.36	 13.38	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92224	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92225	 1	 9.0	 6.5	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92226	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92227	 1	 10.71	 7.34	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92228	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	92229	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92230	 1	 6.03	 5.05	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92231	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	92232	 1	 3.33	 2.67	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92233	 1	 7.8	 6.08	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92234	 1	 4.13	 3.1	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92235	 1	 16.95	 12.11	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92236	 1	 12.85	 11.67	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92237	 1	 2.98	 2.17	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92238	 1	 4.97	 3.72	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92239	 1	 4.92	 1.21	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92240	 1	 3.95	 3.15	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92241	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	92242	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	92243	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92244	 1	 10.45	 7.22	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92245	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92246	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92247	 1	 10.54	 8.58	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92248	 1	 8.78	 7.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92249	 1	 15.76	 3.73	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92250	 1	 12.71	 2.98	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92251	 1	 9.29	 2.18	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92252	 1	 11.98	 2.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92253	 1	 2.26	 0.54	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92254	 1	 18.72	 11.76	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92255	 1	 10.67	 6.27	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92256	 1	 8.16	 6.77	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92257	 1	 5.97	 4.46	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92258	 1	 8.55	 7.41	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92259	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92260	 1	 6.4	 4.59	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92261	 1	 4.02	 0.97	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92262	 1	 6.25	 1.5	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92263	 1	 9.28	 2.23	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92264	 1	 12.91	 3.1	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92265	 1	 7.22	 6.2	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92266	 1	 20.2	 16.73	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92267	 1	 2.99	 2.65	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92268	 1	 12.91	 8.72	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92269	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	92270	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	92271	 1	 4.97	 4.09	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92272	 1	 11.33	 2.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92273	 1	 3.38	 0.81	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92274	 1	 13.54	 3.24	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92275	 1	 8.91	 2.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92276	 1	 3.34	 0.8	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92277	 1	 5.3	 1.27	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92278	 1	 6.14	 1.47	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92279	 1	 8.52	 2.04	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92280	 1	 4.81	 1.15	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92281	 1	 8.98	 2.15	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92282	 1	 21.2	 5.08	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92283	 1	 6.29	 1.51	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92284	 1	 8.38	 2.01	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92285	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92286	 1	 22.11	 5.34	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92287	 1	 7.6	 1.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92288	 1	 6.74	 5.17	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92289	 1	 19.52	 4.67	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92290	 1	 4.64	 3.86	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92291	 1	 7.35	 6.2	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92292	 1	 23.69	 20.56	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92293	 1	 4.06	 3.75	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92294	 1	 9.4	 7.33	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92295	 1	 10.94	 7.28	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92296	 1	 4.55	 3.6	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92297	 1	 13.28	 12.19	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92298	 1	 3.66	 0.87	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92299	 1	 3.85	 0.93	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92300	 1	 9.05	 2.17	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92301	 1	 10.5	 2.54	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92302	 1	 9.43	 6.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92303	 1	 5.09	 4.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92304	 1	 8.25	 5.93	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92305	 1	 4.24	 3.68	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92306	 1	 6.47	 5.91	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92307	 1	 3.76	 3.31	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92308	 1	 5.63	 5.1	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92309	 1	 9.65	 6.93	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92310	 1	 6.13	 5.66	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92311	 1	 7.24	 5.15	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92312	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92313	 1	 9.77	 2.36	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92314	 1	 9.47	 2.27	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92315	 1	 6.23	 1.51	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92316	 1	 44.13	 25.26	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92317	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92318	 1	 8.89	 2.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92319	 1	 11.18	 2.68	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92320	 1	 5.52	 1.32	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92321	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92322	 1	 19.53	 4.72	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92323	 1	 3.99	 0.96	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92324	 1	 7.3	 1.75	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92325	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92326	 1	 18.27	 4.37	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92327	 1	 7.78	 1.86	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92328	 1	 8.65	 2.09	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92329	 1	 12.27	 2.93	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92330	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92331	 1	 42.29	 25.4	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92332	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92333	 1	 10.91	 2.61	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92334	 1	 10.78	 2.57	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92335	 1	 12.27	 2.92	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92336	 1	 8.57	 2.05	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92337	 1	 14.53	 3.47	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92338	 1	 14.92	 3.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92339	 1	 15.68	 3.75	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92340	 1	 10.75	 2.59	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92341	 1	 10.48	 2.51	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92342	 1	 7.8	 1.86	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92343	 1	 8.85	 2.12	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92344	 1	 4.89	 1.16	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92345	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92346	 1	 4.46	 1.06	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92347	 1	 8.45	 2.01	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92348	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92349	 1	 11.16	 2.67	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92350	 1	 12.65	 3.03	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92351	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92352	 1	 6.57	 4.68	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92353	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92354	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92355	 1	 15.98	 10.2	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92356	 1	 6.45	 5.83	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92357	 1	 12.11	 2.9	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92358	 1	 6.69	 1.59	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92359	 1	 9.59	 2.29	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92360	 1	 16.37	 3.91	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92361	 1	 36.83	 20.66	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92362	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92363	 1	 9.5	 6.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92364	 1	 15.03	 13.34	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92365	 1	 5.86	 4.44	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92366	 1	 5.18	 3.98	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92367	 1	 9.17	 2.2	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92368	 1	 27.21	 17.07	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92369	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92370	 1	 5.1	 1.24	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92371	 1	 13.88	 10.85	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92372	 1	 6.99	 4.68	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92373	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92374	 1	 10.51	 9.6	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92375	 1	 6.68	 4.12	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92376	 1	 7.81	 5.13	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92377	 1	 10.64	 8.77	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92378	 1	 7.69	 5.29	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92379	 1	 5.67	 4.87	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92380	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92381	 1	 14.66	 13.48	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92382	 1	 6.01	 4.73	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92383	 1	 5.49	 4.75	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92384	 1	 4.98	 4.22	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92385	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92386	 1	 11.72	 10.51	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92387	 1	 5.56	 4.67	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92388	 1	 15.8	 12.84	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92389	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92390	 1	 9.18	 6.78	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92391	 1	 8.25	 7.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92392	 1	 9.35	 7.88	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92393	 1	 14.13	 3.41	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92394	 1	 9.38	 2.26	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92395	 1	 9.47	 2.29	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92396	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92397	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92398	 1	 15.75	 13.48	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92399	 1	 3.52	 2.87	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92400	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	92401	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92402	 1	 5.83	 4.91	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92403	 1	 8.42	 7.3	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92404	 1	 8.86	 5.2	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92405	 1	 4.04	 3.43	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92406	 1	 3.03	 2.87	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92407	 1	 11.28	 8.77	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92408	 1	 8.15	 6.34	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92409	 1	 6.12	 5.06	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92410	 1	 9.87	 6.06	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92411	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92412	 1	 43.8	 29.76	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92413	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92414	 1	 6.73	 1.61	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92415	 1	 2.56	 1.76	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92416	 1	 16.01	 3.85	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92417	 1	 2.48	 0.59	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92418	 1	 6.97	 1.66	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92419	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92420	 1	 4.56	 1.09	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92421	 1	 2.81	 0.67	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92422	 1	 2.98	 0.72	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92423	 1	 8.65	 2.07	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92424	 1	 10.31	 2.47	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92425	 1	 6.05	 5.45	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92426	 1	 11.25	 2.68	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92427	 1	 8.62	 6.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92428	 1	 5.7	 4.41	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92429	 1	 18.63	 4.47	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92430	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92431	 1	 9.43	 2.25	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92432	 1	 3.57	 0.85	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92433	 1	 8.1	 1.95	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92434	 1	 11.23	 9.11	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92435	 1	 37.21	 24.32	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92436	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92437	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92438	 1	 19.71	 4.73	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92439	 1	 6.74	 1.61	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92440	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92441	 1	 18.45	 14.48	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92442	 1	 14.89	 3.55	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92443	 1	 0.0	 0.0	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92444	 1	 11.41	 2.71	 0.0	 0.0	 20	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92445	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92446	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92447	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92448	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92449	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92450	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92451	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92452	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92453	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92454	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92455	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92456	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92457	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92458	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92459	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92460	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92461	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92462	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92463	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92464	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92465	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92466	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92467	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92468	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92469	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92470	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92471	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92472	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92473	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92474	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92475	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92476	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92477	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92478	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92479	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92480	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92481	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92482	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92483	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92484	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92485	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92486	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92487	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92488	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92489	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92490	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92491	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92492	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92493	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92494	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92495	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92496	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92497	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92498	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92499	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92500	 2	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92501	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92502	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92503	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92504	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92505	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92506	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92507	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92508	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92509	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92510	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92511	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92512	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92513	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92514	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92515	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92516	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92517	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92518	 2	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92519	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92520	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92521	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92522	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92523	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92524	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92525	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92526	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92527	 1	 4.19	 3.01	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92528	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92529	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92530	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92531	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92532	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92533	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92534	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92535	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92536	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92537	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92538	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92539	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92540	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92541	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92542	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92543	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92544	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92545	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92546	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92547	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92548	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92549	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92550	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92551	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92552	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92553	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92554	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92555	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92556	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92557	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92558	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92559	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92560	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92561	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92562	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92563	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92564	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92565	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92566	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92567	 2	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92568	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92569	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92570	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92571	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92572	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92573	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92574	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92575	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92576	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92577	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92578	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92579	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92580	 2	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92581	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92582	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92583	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92584	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92585	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92586	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92587	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92588	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92589	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92590	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92591	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92592	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92593	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92594	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92595	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92596	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92597	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92598	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92599	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92600	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92601	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92602	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92603	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92604	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92605	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92606	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92607	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92608	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92609	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92610	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92611	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92612	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92613	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92614	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92615	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92616	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92617	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92618	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92619	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92620	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92621	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92622	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92623	 1	 817.66	 216.89	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92624	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92625	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92626	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92627	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92628	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92629	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92630	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92631	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92632	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92633	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92634	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92635	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92636	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92637	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92638	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92639	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92640	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92641	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92642	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92643	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92644	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92645	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92646	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92647	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92648	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92649	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92650	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92651	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92652	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92653	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92654	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92655	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92656	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92657	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92658	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92659	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92660	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92661	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92662	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92663	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92664	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92665	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92666	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92667	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92668	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92669	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92670	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92671	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92672	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92673	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92674	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92675	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92676	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92677	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92678	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92679	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92680	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92681	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92682	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92683	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92684	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92685	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92686	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92687	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92688	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92689	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92690	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92691	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92692	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92693	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92694	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92695	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92696	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92697	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92698	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92699	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92700	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92701	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92702	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92703	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92704	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92705	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92706	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92707	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92708	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92709	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92710	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92711	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92712	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92713	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92714	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92715	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92716	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92717	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92718	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92719	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92720	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92721	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92722	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92723	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92724	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92725	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92726	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92727	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92728	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92729	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92730	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92731	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92732	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92733	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92734	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92735	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92736	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92737	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92738	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92739	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92740	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92741	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92742	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92743	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92744	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92745	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92746	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92747	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92748	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92749	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92750	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92751	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92752	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92753	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92754	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92755	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92756	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92757	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92758	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92759	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92760	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92761	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92762	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92763	 1	 1.87	 1.01	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92764	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92765	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92766	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92767	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92768	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92769	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92770	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92771	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92772	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92773	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92774	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92775	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92776	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92777	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92778	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92779	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92780	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92781	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92782	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92783	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92784	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92785	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92786	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92787	 2	 4.91	 2.97	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92788	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92789	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92790	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92791	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92792	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92793	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92794	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92795	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92796	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92797	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92798	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92799	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92800	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92801	 2	 320.31	 127.52	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92802	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92803	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92804	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92805	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92806	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92807	 1	 1488.8	 682.76	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92808	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92809	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92810	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92811	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92812	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92813	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92814	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92815	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92816	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92817	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92818	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92819	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92820	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92821	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92822	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92823	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92824	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92825	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92826	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92827	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92828	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92829	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92830	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92831	 2	 4.16	 2.3	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92832	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92833	 2	 11.41	 6.74	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92834	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92835	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92836	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92837	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92838	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92839	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92840	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92841	 2	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92842	 2	 47.48	 27.16	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92843	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92844	 1	 4.74	 1.13	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92845	 1	 3.75	 3.87	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92846	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92847	 1	 8.31	 7.4	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92848	 1	 12.47	 10.76	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92849	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92850	 1	 4.68	 10.07	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92851	 1	 10.18	 6.59	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92852	 1	 16.26	 4.02	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92853	 1	 13.4	 3.39	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92854	 1	 2.8	 4.82	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92855	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92856	 1	 10.88	 6.7	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92857	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92858	 1	 7.41	 4.92	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92859	 1	 7.24	 5.13	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92860	 1	 2.54	 2.45	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92861	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92862	 1	 3.71	 6.06	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92863	 1	 14.28	 7.43	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92864	 1	 8.7	 5.18	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92865	 1	 5.24	 3.4	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92866	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92867	 1	 8.43	 5.1	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92868	 1	 2.67	 3.83	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92869	 1	 3.2	 5.03	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92870	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92871	 1	 14.95	 9.03	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92872	 1	 8.02	 4.23	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92873	 1	 3.31	 5.62	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92874	 1	 3.31	 4.95	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92875	 1	 2.15	 2.79	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92876	 1	 8.09	 7.56	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92877	 1	 7.08	 11.76	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92878	 1	 10.38	 6.53	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92879	 1	 4.62	 3.28	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92880	 1	 5.93	 4.83	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92881	 1	 13.31	 6.12	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92882	 1	 5.68	 3.47	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92883	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92884	 1	 10.07	 7.55	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92885	 1	 18.7	 17.28	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92886	 1	 13.18	 3.11	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92887	 1	 8.71	 5.94	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92888	 1	 33.44	 20.69	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92889	 1	 22.81	 9.53	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92890	 1	 10.16	 4.62	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92891	 1	 4.03	 2.11	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92892	 1	 4.07	 2.55	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92893	 1	 8.33	 4.23	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92894	 1	 10.58	 2.51	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92895	 1	 10.58	 8.84	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92896	 1	 16.21	 9.66	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92897	 1	 9.18	 4.53	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92898	 1	 5.9	 5.54	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92899	 1	 5.21	 4.25	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92900	 1	 7.74	 4.41	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92901	 1	 3.16	 2.18	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92902	 1	 3.32	 2.39	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92903	 1	 4.43	 2.78	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92904	 1	 5.79	 3.5	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92905	 1	 3.65	 2.89	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92906	 1	 2.28	 1.99	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92907	 1	 3.89	 2.68	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92908	 1	 4.18	 3.41	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92909	 1	 7.11	 7.05	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92910	 1	 1.98	 1.68	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92911	 1	 5.34	 3.39	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92912	 1	 4.96	 5.45	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92913	 1	 3.34	 2.74	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92914	 1	 4.63	 2.65	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92915	 1	 10.49	 5.05	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92916	 1	 6.61	 4.58	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92917	 1	 7.13	 6.3	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92918	 1	 2.26	 2.28	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92919	 1	 2.34	 1.89	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92920	 1	 3.72	 2.17	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92921	 1	 3.66	 2.29	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92922	 1	 4.02	 10.17	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92923	 1	 5.06	 4.49	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92924	 1	 2.8	 2.68	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92925	 1	 10.78	 10.17	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92926	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92927	 1	 7.04	 3.44	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92928	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92929	 1	 20.65	 9.85	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92930	 1	 6.55	 1.58	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92931	 1	 2.64	 0.64	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92932	 1	 2.32	 1.68	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92933	 1	 3.57	 3.29	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92934	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92935	 1	 7.99	 11.46	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92936	 1	 1.46	 1.4	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92937	 1	 2.15	 2.02	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92938	 1	 7.33	 4.03	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92939	 1	 6.19	 4.27	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92940	 1	 21.3	 10.44	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92941	 1	 13.26	 7.73	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92942	 1	 5.89	 5.1	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92943	 1	 16.34	 7.11	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92944	 1	 8.52	 7.81	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92945	 1	 4.26	 2.58	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92946	 1	 8.6	 4.25	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92947	 1	 7.12	 7.36	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92948	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92949	 1	 7.86	 6.43	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92950	 1	 6.14	 3.19	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92951	 1	 6.53	 3.55	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92952	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92953	 1	 5.38	 7.86	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92954	 1	 18.35	 9.29	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92955	 1	 2.01	 1.42	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92956	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92957	 1	 2.65	 2.12	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92958	 1	 11.87	 6.46	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92959	 1	 10.25	 6.14	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92960	 1	 3.04	 0.72	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92961	 1	 132.75	 31.19	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92962	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92963	 1	 3.49	 0.84	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92964	 1	 4.2	 0.98	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92965	 1	 13.02	 8.24	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92966	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92967	 1	 3.14	 5.47	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92968	 1	 7.32	 4.81	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92969	 1	 4.34	 2.95	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92970	 1	 16.96	 10.6	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92971	 1	 3.87	 3.35	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92972	 1	 17.28	 4.3	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92973	 1	 13.52	 8.19	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92974	 1	 13.59	 6.08	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92975	 1	 6.91	 8.36	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92976	 1	 7.08	 4.6	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	92977	 1	 7.72	 1.86	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92978	 1	 5.47	 4.14	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92979	 1	 5.66	 3.82	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92980	 1	 5.41	 4.22	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92981	 1	 17.63	 13.65	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92982	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92983	 1	 18.66	 15.39	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92984	 1	 3.55	 2.59	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92985	 1	 3.38	 2.87	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92986	 1	 4.97	 5.14	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92987	 1	 8.53	 5.07	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92988	 1	 22.31	 5.32	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92989	 1	 18.28	 8.19	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92990	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92991	 1	 4.99	 7.11	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92992	 1	 14.64	 7.27	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92993	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92994	 1	 17.62	 14.56	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92995	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92996	 1	 15.71	 13.57	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92997	 1	 21.39	 12.84	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92998	 1	 4.1	 3.74	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	92999	 1	 13.77	 12.05	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93000	 1	 8.01	 3.88	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93001	 1	 2.8	 2.1	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93002	 1	 9.99	 10.96	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93003	 1	 6.3	 4.8	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93004	 1	 7.17	 10.89	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93005	 1	 4.55	 5.26	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93006	 1	 3.62	 3.37	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93007	 1	 35.71	 23.69	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93008	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93009	 1	 3.54	 3.83	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93010	 1	 4.0	 2.75	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93011	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93012	 1	 4.27	 3.64	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93013	 1	 8.25	 7.96	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93014	 1	 3.37	 3.31	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93015	 1	 1.54	 3.25	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93016	 1	 5.6	 4.97	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93017	 1	 2.09	 1.85	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93018	 1	 3.59	 2.73	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93019	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93020	 1	 8.2	 9.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93021	 1	 29.25	 15.25	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93022	 1	 9.09	 5.02	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93023	 1	 11.44	 8.86	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93024	 1	 8.93	 4.95	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93025	 1	 4.36	 3.3	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93026	 1	 15.2	 9.92	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93027	 1	 8.59	 4.48	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93028	 1	 14.4	 3.37	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93029	 1	 16.29	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93030	 1	 8.53	 2.05	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93031	 1	 65.8	 29.8	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93032	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93033	 1	 10.11	 5.26	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93034	 1	 16.31	 3.83	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93035	 1	 10.73	 5.05	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93036	 1	 8.84	 5.99	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93037	 1	 10.75	 6.16	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93038	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93039	 1	 11.38	 2.73	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93040	 1	 17.02	 4.05	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93041	 1	 3.73	 1.99	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93042	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93043	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93044	 1	 0.97	 1.21	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93045	 1	 4.87	 2.82	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93046	 1	 2.98	 1.7	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93047	 1	 3.9	 2.12	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93048	 1	 4.76	 7.41	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93049	 1	 9.53	 9.2	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93050	 1	 2.46	 2.2	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93051	 1	 54.92	 34.73	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93052	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93053	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93054	 1	 2.65	 1.79	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93055	 1	 1.76	 1.47	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93056	 1	 1.7	 1.13	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93057	 1	 4.59	 3.57	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93058	 1	 0.9	 0.82	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93059	 1	 13.09	 7.15	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93060	 1	 22.55	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93061	 1	 32.96	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93062	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93063	 1	 9.22	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93064	 1	 20.03	 -5.15	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93065	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93066	 1	 33.78	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93067	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93068	 1	 30.85	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93069	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93070	 1	 9.3	 7.53	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93071	 1	 6.82	 5.26	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93072	 1	 11.67	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93073	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93074	 1	 7.35	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93075	 1	 17.89	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93076	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93077	 1	 20.59	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93078	 1	 10.84	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93079	 1	 19.41	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93080	 1	 23.83	 5.71	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93081	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93082	 1	 13.72	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93083	 1	 12.68	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93084	 1	 9.33	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93085	 1	 15.88	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93086	 1	 22.36	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93087	 1	 3.64	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93088	 1	 23.88	 13.33	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93089	 1	 18.28	 10.34	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93090	 1	 9.35	 7.57	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93091	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93092	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93093	 1	 18.13	 10.65	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93094	 1	 6.34	 3.43	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93095	 1	 14.77	 7.82	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93096	 1	 10.03	 6.74	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93097	 1	 9.73	 6.54	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93098	 1	 10.29	 6.15	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93099	 1	 2.64	 2.84	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93100	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93101	 1	 3.38	 2.87	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93102	 1	 6.03	 5.62	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93103	 1	 3.7	 3.38	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93104	 1	 2.76	 2.95	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93105	 1	 1.54	 1.48	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93106	 1	 4.03	 3.7	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93107	 1	 8.6	 6.54	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93108	 1	 2.22	 1.88	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93109	 1	 2.63	 2.77	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93110	 1	 20.94	 10.79	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93111	 1	 6.92	 5.08	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93112	 1	 2.65	 2.28	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93113	 1	 2.4	 2.22	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93114	 1	 9.22	 5.75	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93115	 1	 1.92	 1.64	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93116	 1	 8.59	 7.09	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93117	 1	 3.35	 2.81	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93118	 1	 3.64	 3.59	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93119	 1	 2.33	 2.05	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93120	 1	 63.39	 44.72	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93121	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93122	 1	 2.19	 2.43	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93123	 1	 3.42	 2.8	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93124	 1	 2.6	 2.44	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93125	 1	 3.34	 3.06	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93126	 1	 3.82	 2.43	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93127	 1	 7.36	 4.59	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93128	 1	 2.59	 2.45	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93129	 1	 22.71	 17.62	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93130	 1	 40.57	 24.06	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93131	 1	 21.38	 13.57	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93132	 1	 11.61	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93133	 1	 13.84	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93134	 1	 6.92	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93135	 1	 22.26	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93136	 1	 12.32	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93137	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93138	 1	 22.78	 14.78	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93139	 1	 6.38	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93140	 1	 18.47	 4.64	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93141	 1	 1.15	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93142	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93143	 1	 16.59	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93144	 1	 9.88	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93145	 1	 13.79	 9.19	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93146	 1	 3.47	 3.22	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93147	 1	 1.26	 1.35	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93148	 1	 2.05	 2.28	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93149	 1	 3.09	 3.22	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93150	 1	 3.34	 2.95	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93151	 1	 3.7	 3.99	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93152	 1	 2.19	 1.75	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93153	 1	 16.17	 10.45	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93154	 1	 13.84	 10.93	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93155	 1	 4.37	 3.94	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93156	 1	 2.7	 2.2	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93157	 1	 20.63	 10.99	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93158	 1	 8.54	 5.33	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93159	 1	 8.8	 6.27	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93160	 1	 2.44	 2.35	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93161	 1	 1.96	 2.13	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93162	 1	 3.75	 4.14	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93163	 1	 5.95	 4.85	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93164	 1	 1.42	 1.38	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93165	 1	 1.57	 1.44	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93166	 1	 3.36	 3.34	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93167	 1	 3.28	 2.62	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93168	 1	 17.11	 11.43	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93169	 1	 10.54	 8.42	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93170	 1	 6.05	 5.16	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93171	 1	 6.92	 5.82	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93172	 1	 17.2	 4.19	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93173	 1	 31.31	 15.57	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93174	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93175	 1	 16.12	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93176	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93177	 1	 16.17	 11.7	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93178	 1	 9.95	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93179	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93180	 1	 18.22	 11.69	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93181	 1	 7.17	 4.55	 0.0	 0.0	 21	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93182	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93183	 1	 22.14	 14.3	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93184	 1	 11.01	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93185	 1	 16.31	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93186	 1	 55.79	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93187	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93188	 1	 12.43	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93189	 1	 17.3	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93190	 1	 19.28	 13.98	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93191	 1	 14.41	 10.94	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93192	 1	 18.81	 11.11	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93193	 1	 10.91	 7.2	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93194	 1	 3.11	 2.75	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93195	 1	 3.68	 3.5	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93196	 1	 8.37	 4.08	 0.0	 0.0	 21	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93197	 1	 1.18	 1.3	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93198	 1	 4.55	 4.07	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93199	 1	 12.35	 8.09	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93200	 1	 4.87	 4.66	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93201	 1	 4.31	 4.33	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93202	 1	 4.29	 3.94	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93203	 1	 13.05	 3.08	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93204	 1	 16.53	 10.49	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93205	 1	 4.06	 3.67	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93206	 1	 13.6	 -0.95	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93207	 1	 13.02	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93208	 1	 5.61	 -5.02	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93209	 1	 5.96	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93210	 1	 6.7	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93211	 1	 19.51	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93212	 1	 2.1	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93213	 1	 15.47	 9.45	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93214	 1	 0.0	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93215	 1	 10.63	 8.62	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93216	 1	 15.08	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93217	 1	 19.91	 0.0	 0.0	 0.0	 21	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93218	 1	 4.84	 3.01	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93219	 1	 13.88	 8.08	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93220	 1	 6.64	 3.37	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93221	 1	 26.26	 14.85	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93222	 1	 7.37	 4.45	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93223	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93224	 1	 7.54	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93225	 1	 4.56	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93226	 1	 6.88	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93227	 1	 9.27	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93228	 1	 9.75	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93229	 1	 10.28	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93230	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93231	 1	 8.64	 5.21	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93232	 1	 9.17	 5.2	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93233	 1	 0.0	 0.0	 0.0	 120.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93234	 1	 70.98	 41.65	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93235	 1	 5.45	 2.48	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93236	 1	 8.14	 4.77	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93237	 1	 4.61	 2.9	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93238	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93239	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93240	 1	 21.54	 8.78	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93241	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93242	 1	 37.38	 15.31	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93243	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93244	 1	 24.98	 12.67	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93245	 1	 17.53	 4.47	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93246	 1	 10.66	 6.28	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93247	 1	 29.57	 8.21	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93248	 1	 9.63	 4.7	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93249	 1	 19.56	 4.52	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93250	 1	 19.31	 9.61	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93251	 1	 19.15	 6.5	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93252	 1	 3.98	 1.98	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93253	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93254	 1	 24.85	 11.04	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93255	 1	 22.1	 9.75	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93256	 1	 5.29	 2.65	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93257	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93258	 1	 26.61	 12.8	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93259	 1	 13.8	 5.71	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93260	 1	 9.66	 5.4	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93261	 1	 12.05	 7.24	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93262	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93263	 1	 14.29	 7.01	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93264	 1	 5.07	 2.41	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93265	 1	 12.31	 2.92	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93266	 1	 15.15	 3.59	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93267	 1	 133.42	 31.63	 0.0	 0.0	 26	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93268	 1	 0.0	 0.0	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93269	 1	 6.17	 3.79	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93270	 1	 19.06	 7.76	 0.0	 0.0	 26	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93271	 1	 16.01	 9.05	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93272	 1	 16.21	 7.89	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93273	 1	 15.27	 3.66	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93274	 1	 1.57	 0.37	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93275	 1	 19.22	 4.58	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93276	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93277	 1	 12.03	 10.79	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93278	 1	 6.39	 4.86	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93279	 1	 4.83	 4.64	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93280	 1	 39.72	 30.95	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93281	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93282	 1	 18.05	 16.7	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93283	 1	 22.94	 19.21	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93284	 1	 12.85	 3.07	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93285	 1	 4.37	 3.74	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93286	 1	 4.19	 3.85	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93287	 1	 8.48	 6.59	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93288	 1	 9.54	 7.08	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93289	 1	 7.65	 6.33	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93290	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93291	 1	 10.58	 9.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93292	 1	 8.02	 5.45	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93293	 1	 12.86	 10.75	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93294	 1	 19.31	 4.55	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93295	 1	 17.37	 11.06	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93296	 1	 25.89	 18.99	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93297	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93298	 1	 7.75	 1.81	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93299	 1	 3.32	 2.83	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93300	 1	 7.81	 5.25	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93301	 1	 6.97	 6.2	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93302	 1	 13.89	 9.61	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93303	 1	 7.8	 5.42	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93304	 1	 6.0	 4.67	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93305	 1	 5.78	 4.11	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93306	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93307	 1	 29.63	 17.91	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93308	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93309	 1	 19.93	 4.6	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93310	 1	 9.95	 2.32	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93311	 1	 11.6	 2.69	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93312	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93313	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93314	 1	 49.24	 27.69	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93315	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93316	 1	 16.25	 3.85	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93317	 1	 9.63	 7.09	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93318	 1	 9.97	 8.56	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93319	 1	 8.69	 6.87	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93320	 1	 6.45	 4.39	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93321	 1	 9.32	 7.58	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93322	 1	 12.36	 9.36	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93323	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93324	 1	 18.59	 12.08	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93325	 1	 17.35	 10.22	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93326	 1	 11.38	 8.79	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93327	 1	 6.96	 5.7	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93328	 1	 10.28	 8.36	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93329	 1	 6.37	 5.55	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93330	 1	 7.75	 5.71	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93331	 1	 7.26	 5.88	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93332	 1	 6.53	 4.97	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93333	 1	 5.13	 4.01	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93334	 1	 6.73	 5.89	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93335	 1	 7.88	 5.47	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93336	 1	 9.37	 5.67	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93337	 1	 6.71	 4.88	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93338	 1	 10.76	 9.77	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93339	 1	 7.55	 5.3	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93340	 1	 16.66	 13.59	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93341	 1	 22.6	 17.18	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93342	 1	 37.36	 24.35	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93343	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93344	 1	 10.27	 8.36	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93345	 1	 17.19	 10.96	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93346	 1	 6.32	 4.92	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93347	 1	 7.19	 5.77	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93348	 1	 8.97	 7.96	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93349	 1	 5.07	 4.01	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93350	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93351	 1	 10.77	 8.8	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93352	 1	 4.79	 4.21	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93353	 1	 6.22	 3.83	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93354	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93355	 1	 4.24	 2.43	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93356	 1	 16.58	 12.37	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93357	 1	 11.24	 6.41	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93358	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93359	 1	 33.09	 20.78	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93360	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93361	 1	 10.63	 2.58	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93362	 1	 20.0	 4.83	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93363	 1	 7.73	 6.3	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93364	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93365	 1	 23.1	 18.38	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93366	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93367	 1	 4.91	 4.1	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93368	 1	 9.8	 8.36	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93369	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93370	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93371	 1	 8.79	 6.44	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93372	 1	 53.41	 34.81	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93373	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93374	 1	 63.73	 35.39	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93375	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93376	 1	 9.13	 7.89	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93377	 1	 18.16	 12.52	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93378	 1	 19.73	 15.78	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93379	 1	 12.67	 9.19	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93380	 1	 3.32	 0.79	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93381	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93382	 1	 8.62	 6.21	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93383	 1	 9.07	 8.72	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93384	 1	 3.74	 2.99	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93385	 1	 8.0	 6.1	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93386	 1	 18.76	 14.41	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93387	 1	 11.98	 8.81	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93388	 1	 47.66	 38.35	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93389	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93390	 1	 1.98	 0.47	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93391	 1	 10.1	 5.83	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93392	 1	 293.66	 221.3	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93393	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93394	 1	 24.1	 5.28	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93395	 1	 6.39	 4.89	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93396	 1	 15.89	 9.76	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93397	 1	 10.67	 9.46	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93398	 1	 23.92	 5.7	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93399	 1	 5.37	 4.78	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93400	 1	 18.31	 14.88	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93401	 1	 16.49	 11.42	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93402	 1	 30.18	 26.55	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93403	 1	 14.15	 9.7	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93404	 1	 5.72	 5.22	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93405	 1	 17.29	 13.31	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93406	 1	 9.03	 2.09	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93407	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93408	 1	 14.06	 10.85	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93409	 1	 26.36	 18.03	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93410	 1	 15.55	 10.45	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93411	 1	 8.03	 5.2	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93412	 1	 9.69	 6.47	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93413	 1	 4.94	 3.67	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93414	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93415	 1	 9.01	 2.15	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93416	 1	 15.48	 3.66	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93417	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93418	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93419	 1	 91.78	 51.04	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93420	 1	 9.54	 8.35	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93421	 1	 3.93	 3.08	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93422	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93423	 1	 26.56	 14.76	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93424	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93425	 1	 39.34	 32.88	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93426	 1	 6.7	 6.69	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93427	 1	 15.76	 13.94	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93428	 1	 18.8	 14.38	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93429	 1	 7.88	 7.31	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93430	 1	 11.97	 8.33	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93431	 1	 12.46	 3.01	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93432	 1	 14.98	 3.52	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93433	 1	 7.47	 1.74	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93434	 1	 8.69	 2.03	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93435	 1	 5.79	 4.41	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93436	 1	 9.49	 8.22	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93437	 1	 1.68	 1.27	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93438	 1	 10.24	 8.81	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93439	 1	 21.54	 15.02	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93440	 1	 23.3	 11.33	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93441	 1	 11.69	 7.98	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93442	 1	 26.66	 17.78	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93443	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93444	 1	 15.35	 11.43	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93445	 1	 8.37	 7.06	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93446	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93447	 1	 23.53	 14.68	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93448	 1	 30.3	 19.37	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93449	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93450	 1	 17.77	 12.59	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93451	 1	 11.06	 9.26	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93452	 1	 9.2	 6.81	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93453	 1	 8.65	 6.84	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93454	 1	 2.38	 2.11	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93455	 1	 7.78	 6.01	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93456	 1	 3.52	 2.96	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93457	 1	 7.51	 5.8	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93458	 1	 5.48	 4.65	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93459	 1	 6.83	 5.35	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93460	 1	 8.25	 5.74	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93461	 1	 7.57	 6.69	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93462	 1	 8.41	 7.19	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93463	 1	 2.55	 2.06	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93464	 1	 2.37	 1.91	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93465	 1	 24.38	 13.5	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93466	 1	 21.99	 15.84	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93467	 1	 4.77	 3.57	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93468	 1	 3.88	 3.02	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93469	 1	 8.19	 5.58	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93470	 1	 7.13	 6.02	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93471	 1	 6.5	 5.82	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93472	 1	 19.84	 13.27	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93473	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93474	 1	 24.65	 16.41	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93475	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93476	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93477	 1	 67.14	 49.65	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93478	 1	 3.93	 2.91	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93479	 1	 12.4	 8.71	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93480	 1	 5.64	 4.2	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93481	 1	 7.22	 5.08	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93482	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93483	 1	 65.99	 45.38	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93484	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93485	 1	 9.55	 6.5	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93486	 1	 5.58	 4.58	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93487	 1	 8.21	 5.97	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93488	 1	 6.7	 5.56	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93489	 1	 12.18	 10.68	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93490	 1	 5.6	 4.65	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93491	 1	 10.22	 8.96	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93492	 1	 15.19	 10.26	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93493	 1	 5.7	 4.45	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93494	 1	 2.78	 2.17	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93495	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93496	 1	 21.29	 14.35	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93497	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93498	 1	 14.1	 11.5	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93499	 1	 5.41	 4.02	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93500	 1	 4.34	 3.91	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93501	 1	 7.08	 4.97	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93502	 1	 5.84	 5.16	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93503	 1	 8.36	 7.05	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93504	 1	 7.63	 6.43	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93505	 1	 11.81	 8.23	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93506	 1	 10.54	 9.07	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93507	 1	 2.44	 1.86	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93508	 1	 8.38	 6.56	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93509	 1	 22.58	 10.84	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93510	 1	 13.48	 10.76	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93511	 1	 8.51	 2.01	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93512	 1	 6.94	 5.79	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93513	 1	 10.26	 8.75	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93514	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93515	 1	 12.95	 9.11	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93516	 1	 5.34	 3.02	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93517	 1	 6.17	 5.5	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93518	 1	 7.81	 5.68	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93519	 1	 11.17	 6.24	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93520	 1	 51.7	 34.9	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93521	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93522	 1	 5.99	 5.72	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93523	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93524	 1	 20.21	 17.96	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93525	 1	 10.58	 7.3	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93526	 1	 22.75	 5.36	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93527	 1	 8.83	 6.69	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93528	 1	 17.1	 11.91	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93529	 1	 20.69	 14.23	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93530	 1	 20.97	 15.07	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93531	 1	 64.93	 46.76	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93532	 1	 21.14	 14.5	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93533	 1	 20.23	 10.66	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93534	 1	 6.11	 4.53	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93535	 1	 12.35	 11.3	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93536	 1	 6.31	 4.93	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93537	 1	 24.07	 20.32	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93538	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93539	 1	 31.37	 20.58	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93540	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93541	 1	 14.74	 8.83	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93542	 1	 10.38	 8.53	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93543	 1	 3.41	 3.03	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93544	 1	 10.18	 7.12	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93545	 1	 9.7	 4.78	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93546	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93547	 1	 4.65	 3.99	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93548	 1	 6.5	 5.59	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93549	 1	 119.31	 71.48	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93550	 1	 152.26	 91.96	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93551	 1	 5.49	 5.06	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93552	 1	 9.68	 5.09	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93553	 1	 31.99	 20.54	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93554	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93555	 1	 4.08	 3.67	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93556	 1	 6.69	 4.76	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93557	 1	 6.42	 4.72	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93558	 1	 10.89	 8.67	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93559	 1	 6.35	 4.76	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93560	 1	 3.9	 3.56	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93561	 1	 14.68	 6.16	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93562	 1	 11.02	 7.75	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93563	 1	 17.08	 9.91	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93564	 1	 12.35	 2.97	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93565	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93566	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93567	 1	 15.14	 12.44	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93568	 1	 18.68	 10.65	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93569	 1	 17.59	 11.16	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93570	 1	 3.41	 2.87	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93571	 1	 4.01	 3.11	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93572	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93573	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93574	 1	 14.21	 9.75	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93575	 1	 9.49	 5.15	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93576	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93577	 1	 12.44	 6.55	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93578	 1	 6.36	 5.7	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93579	 1	 4.27	 3.04	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93580	 1	 4.34	 3.68	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93581	 1	 17.99	 13.37	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93582	 1	 16.22	 13.31	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93583	 1	 2.74	 2.47	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93584	 1	 7.68	 6.43	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93585	 1	 2.51	 2.31	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93586	 1	 11.5	 10.57	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93587	 1	 92.81	 54.63	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93588	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93589	 1	 7.15	 6.22	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93590	 1	 9.37	 7.28	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93591	 1	 7.36	 6.53	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93592	 1	 14.0	 11.82	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93593	 1	 3.12	 2.88	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93594	 1	 14.2	 9.8	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93595	 1	 9.28	 8.07	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93596	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93597	 1	 3.04	 2.13	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93598	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93599	 1	 189.03	 114.67	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93600	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93601	 1	 19.04	 9.02	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93602	 1	 8.57	 6.93	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93603	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93604	 1	 56.98	 40.75	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93605	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93606	 1	 8.0	 6.05	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93607	 1	 27.65	 12.46	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93608	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93609	 1	 8.46	 3.4	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93610	 1	 9.86	 7.99	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93611	 1	 12.3	 8.09	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93612	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93613	 1	 5.81	 3.24	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93614	 1	 7.18	 4.71	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93615	 1	 6.12	 5.44	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93616	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93617	 1	 17.32	 9.49	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93618	 1	 4.5	 3.69	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93619	 1	 10.5	 8.21	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93620	 1	 5.21	 4.84	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93621	 1	 4.57	 4.37	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93622	 1	 8.0	 6.95	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93623	 1	 6.42	 4.51	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93624	 1	 13.91	 11.01	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93625	 1	 7.1	 6.49	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93626	 1	 8.55	 7.4	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93627	 1	 12.07	 9.62	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93628	 1	 11.28	 8.1	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93629	 1	 8.22	 7.34	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93630	 1	 5.99	 4.52	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93631	 1	 5.85	 4.11	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93632	 1	 19.97	 15.47	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93633	 1	 4.52	 3.37	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93634	 1	 4.54	 3.72	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93635	 1	 19.43	 14.72	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93636	 1	 4.27	 3.72	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93637	 1	 90.39	 48.36	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93638	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93639	 1	 10.27	 7.06	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93640	 1	 12.82	 10.82	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93641	 1	 76.64	 47.62	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93642	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93643	 1	 12.56	 8.27	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93644	 1	 57.69	 33.43	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93645	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93646	 1	 4.11	 3.58	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93647	 1	 18.47	 8.6	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93648	 1	 11.45	 6.54	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93649	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93650	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93651	 1	 9.12	 6.75	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93652	 1	 10.61	 8.1	 0.0	 0.0	 28	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93653	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93654	 1	 12.48	 2.97	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93655	 1	 10.66	 2.54	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93656	 1	 10.17	 2.43	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93657	 1	 8.9	 2.09	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93658	 1	 11.12	 9.89	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93659	 1	 20.29	 16.97	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93660	 1	 20.22	 4.9	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93661	 1	 37.4	 25.47	 0.0	 0.0	 28	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93662	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93663	 1	 14.91	 11.24	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93664	 1	 0.0	 0.0	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93665	 1	 7.62	 5.97	 0.0	 0.0	 28	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93666	 1	 7.94	 3.96	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93667	 1	 4.03	 2.46	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93668	 1	 12.58	 5.22	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93669	 1	 13.28	 6.55	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93670	 1	 12.64	 7.91	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93671	 1	 10.67	 6.43	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93672	 1	 10.63	 3.97	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93673	 1	 4.84	 2.66	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93674	 1	 11.84	 6.08	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93675	 1	 6.99	 3.95	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93676	 1	 3.92	 2.39	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93677	 1	 11.54	 6.31	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93678	 1	 14.87	 7.54	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93679	 1	 5.24	 2.57	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93680	 1	 11.64	 6.93	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93681	 1	 20.16	 11.32	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93682	 1	 24.91	 10.58	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93683	 1	 9.0	 4.79	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93684	 1	 9.03	 4.42	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93685	 1	 11.52	 4.81	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93686	 1	 8.21	 4.38	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93687	 1	 7.53	 3.8	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93688	 1	 13.83	 7.27	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93689	 1	 17.76	 9.65	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93690	 1	 2.15	 1.24	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93691	 1	 2.41	 1.43	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93692	 1	 6.69	 3.6	 0.0	 0.0	 32	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93693	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93694	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93695	 1	 15.2	 9.41	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93696	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93697	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93698	 1	 5.87	 3.34	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93699	 1	 5.81	 2.65	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93700	 1	 3.15	 2.08	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93701	 1	 4.72	 2.64	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93702	 1	 3.11	 1.68	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93703	 1	 8.37	 5.25	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93704	 1	 7.98	 1.94	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93705	 1	 7.5	 1.82	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93706	 1	 10.06	 2.37	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93707	 1	 13.45	 7.07	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93708	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93709	 1	 9.42	 5.64	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93710	 1	 8.44	 5.79	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93711	 1	 2.58	 1.44	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93712	 1	 18.55	 4.51	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93713	 1	 18.02	 4.44	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93714	 1	 7.36	 1.8	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93715	 1	 2.97	 0.73	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93716	 1	 9.38	 2.3	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93717	 1	 8.55	 2.07	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93718	 1	 17.26	 4.22	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93719	 1	 3.05	 0.75	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93720	 1	 6.57	 1.6	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93721	 1	 18.67	 4.6	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93722	 1	 4.44	 2.66	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93723	 1	 2.52	 0.62	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93724	 1	 28.92	 7.12	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93725	 1	 8.1	 4.19	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93726	 1	 12.31	 3.0	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93727	 1	 11.12	 4.96	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93728	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93729	 1	 7.3	 4.25	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93730	 1	 7.28	 4.34	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93731	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93732	 1	 15.85	 8.92	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93733	 1	 52.03	 21.63	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93734	 1	 8.72	 5.5	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93735	 1	 11.08	 3.67	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93736	 1	 2.49	 1.27	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93737	 1	 0.0	 0.0	 0.0	 0.0	 32	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93738	 1	 19.37	 12.35	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93739	 1	 7.81	 4.23	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93740	 1	 2.64	 1.69	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93741	 1	 4.99	 2.73	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93742	 1	 5.78	 3.52	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93743	 1	 17.76	 4.3	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93744	 1	 4.55	 2.26	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93745	 1	 5.63	 2.99	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93746	 1	 5.59	 2.56	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93747	 1	 3.19	 1.91	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93748	 1	 5.0	 2.44	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93749	 1	 22.96	 5.5	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93750	 1	 4.07	 0.98	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93751	 1	 15.76	 3.78	 0.0	 0.0	 32	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93752	 1	 9.27	 4.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93753	 1	 9.53	 5.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93754	 1	 27.44	 15.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93755	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93756	 1	 47.19	 27.68	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93757	 1	 8.54	 4.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93758	 1	 12.41	 2.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93759	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93760	 1	 84.39	 38.6	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93761	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93762	 1	 10.54	 5.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93763	 1	 11.23	 5.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93764	 1	 14.02	 7.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93765	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93766	 1	 28.69	 14.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93767	 1	 14.21	 5.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93768	 1	 9.69	 4.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93769	 1	 16.38	 9.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93770	 1	 13.24	 8.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93771	 1	 7.95	 3.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93772	 1	 20.89	 10.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93773	 1	 9.08	 2.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93774	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93775	 1	 14.91	 3.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93776	 1	 13.73	 3.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93777	 1	 16.16	 3.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93778	 1	 21.32	 4.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93779	 1	 13.37	 3.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93780	 1	 10.59	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93781	 1	 6.84	 1.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93782	 1	 7.98	 1.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93783	 1	 10.68	 5.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93784	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93785	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93786	 1	 14.35	 8.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93787	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93788	 1	 22.54	 5.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93789	 1	 2.87	 1.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93790	 1	 5.08	 2.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93791	 1	 12.25	 4.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93792	 1	 13.64	 5.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93793	 1	 38.85	 16.95	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93794	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93795	 1	 39.84	 18.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93796	 1	 25.22	 5.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93797	 1	 11.35	 6.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93798	 1	 6.23	 2.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93799	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93800	 1	 45.74	 18.25	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93801	 1	 9.56	 4.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93802	 1	 7.17	 4.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93803	 1	 10.39	 5.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93804	 1	 21.57	 4.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93805	 1	 3.26	 1.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93806	 1	 11.79	 6.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93807	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93808	 1	 112.88	 43.68	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93809	 1	 55.16	 21.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93810	 1	 7.01	 4.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93811	 1	 5.15	 2.6	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93812	 1	 13.14	 7.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93813	 1	 39.03	 22.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93814	 1	 48.44	 20.89	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93815	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93816	 1	 6.43	 2.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93817	 1	 3.99	 2.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93818	 1	 4.59	 2.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93819	 1	 3.91	 1.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93820	 1	 26.39	 8.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93821	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93822	 1	 14.18	 7.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93823	 1	 5.45	 3.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93824	 1	 9.35	 4.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93825	 1	 9.82	 5.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93826	 1	 13.44	 5.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93827	 1	 10.97	 4.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93828	 1	 8.84	 4.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93829	 1	 12.89	 4.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93830	 1	 13.93	 5.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93831	 1	 10.78	 6.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93832	 1	 11.49	 6.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93833	 1	 5.29	 2.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93834	 1	 3.97	 2.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93835	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93836	 1	 7.56	 4.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93837	 1	 5.4	 2.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93838	 1	 6.22	 3.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93839	 1	 5.7	 2.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93840	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93841	 1	 27.85	 6.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93842	 1	 23.3	 5.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93843	 1	 14.36	 3.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93844	 1	 4.24	 0.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93845	 1	 3.11	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93846	 1	 9.47	 2.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93847	 1	 14.4	 6.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93848	 1	 18.71	 4.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93849	 1	 6.12	 1.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93850	 1	 4.28	 0.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93851	 1	 24.66	 5.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93852	 1	 15.25	 3.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93853	 1	 3.47	 0.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93854	 1	 5.68	 1.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93855	 1	 14.49	 3.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93856	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93857	 1	 16.15	 3.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93858	 1	 8.51	 3.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93859	 1	 5.85	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93860	 1	 8.0	 1.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93861	 1	 22.04	 7.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93862	 1	 35.86	 14.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93863	 1	 23.64	 5.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93864	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93865	 1	 67.31	 34.03	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93866	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93867	 1	 1.78	 0.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93868	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93869	 1	 30.19	 6.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93870	 1	 158.95	 70.41	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93871	 1	 9.25	 4.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93872	 1	 13.37	 5.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93873	 1	 34.24	 7.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93874	 1	 132.42	 61.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93875	 1	 26.37	 14.2	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93876	 1	 6.17	 3.56	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93877	 1	 2.43	 1.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93878	 1	 11.42	 4.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93879	 1	 14.91	 6.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93880	 1	 22.73	 5.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93881	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93882	 1	 31.84	 18.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93883	 1	 26.12	 13.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93884	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93885	 1	 34.45	 14.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93886	 1	 7.44	 4.55	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93887	 1	 142.79	 47.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93888	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93889	 1	 18.18	 8.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93890	 1	 11.13	 5.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93891	 1	 96.73	 45.81	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93892	 1	 5.78	 2.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93893	 1	 31.95	 17.18	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93894	 1	 3.97	 2.22	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93895	 1	 6.93	 4.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93896	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93897	 1	 12.59	 6.03	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93898	 1	 6.5	 3.79	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93899	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93900	 1	 806.97	 211.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93901	 1	 45.73	 22.61	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93902	 1	 50.84	 25.68	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93903	 1	 16.03	 9.07	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93904	 1	 6.29	 3.67	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93905	 1	 8.12	 5.12	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93906	 1	 9.79	 5.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93907	 1	 11.78	 6.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93908	 1	 5.74	 3.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93909	 1	 6.83	 3.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93910	 1	 9.3	 4.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93911	 1	 2.58	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93912	 1	 6.09	 3.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93913	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93914	 1	 13.3	 8.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93915	 1	 11.41	 5.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93916	 1	 8.87	 5.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93917	 1	 5.82	 1.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93918	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93919	 1	 8.42	 4.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93920	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93921	 1	 4.36	 2.49	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93922	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93923	 1	 6.12	 3.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93924	 1	 45.97	 18.73	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93925	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93926	 1	 5.74	 3.63	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93927	 1	 12.13	 6.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93928	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93929	 1	 18.91	 9.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93930	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93931	 1	 6.7	 3.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93932	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93933	 1	 32.01	 18.48	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93934	 1	 5.69	 3.21	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93935	 1	 6.53	 4.19	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93936	 1	 8.23	 5.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93937	 1	 32.24	 9.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93938	 1	 48.38	 25.59	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93939	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93940	 1	 18.71	 8.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93941	 1	 2.04	 1.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93942	 1	 15.1	 8.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93943	 1	 8.73	 5.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93944	 1	 7.12	 4.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93945	 1	 4.2	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93946	 1	 35.43	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93947	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93948	 1	 5.22	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93949	 1	 2.95	 1.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93950	 1	 15.25	 7.1	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93951	 1	 22.6	 10.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93952	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93953	 1	 18.65	 8.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93954	 1	 26.67	 8.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93955	 1	 238.22	 88.16	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93956	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93957	 1	 227.83	 86.95	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93958	 1	 21.25	 11.77	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93959	 1	 13.92	 8.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93960	 1	 12.79	 7.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93961	 1	 24.12	 7.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93962	 1	 5.63	 3.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93963	 1	 8.9	 4.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93964	 1	 2.63	 1.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93965	 1	 12.66	 5.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93966	 1	 7.28	 1.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93967	 1	 6.83	 1.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93968	 1	 5.25	 1.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93969	 1	 12.58	 2.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93970	 1	 5.99	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93971	 1	 33.79	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93972	 1	 20.07	 4.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93973	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93974	 1	 8.52	 2.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93975	 1	 4.73	 1.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93976	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	93977	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93978	 1	 26.52	 6.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93979	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93980	 1	 9.59	 2.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93981	 1	 6.65	 1.61	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93982	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93983	 1	 24.99	 6.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93984	 1	 6.78	 1.64	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93985	 1	 4.12	 1.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93986	 1	 8.72	 2.1	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93987	 1	 8.61	 2.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93988	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93989	 1	 25.59	 6.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93990	 1	 5.37	 1.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93991	 1	 5.62	 1.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93992	 1	 7.92	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93993	 1	 9.27	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93994	 1	 16.46	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93995	 1	 4.54	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93996	 1	 23.88	 5.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93997	 1	 34.25	 8.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93998	 1	 7.62	 1.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	93999	 1	 9.07	 2.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94000	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94001	 1	 10.69	 2.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94002	 1	 9.67	 2.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94003	 1	 13.91	 8.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94004	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94005	 1	 15.41	 8.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94006	 1	 8.0	 3.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94007	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94008	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94009	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94010	 1	 28.43	 14.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94011	 1	 7.54	 4.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94012	 1	 7.76	 3.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94013	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94014	 1	 4.57	 2.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94015	 1	 3.57	 1.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94016	 1	 13.4	 3.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94017	 1	 3.25	 0.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94018	 1	 5.45	 1.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94019	 1	 6.37	 1.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94020	 1	 27.71	 6.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94021	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94022	 1	 66.17	 15.92	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94023	 1	 8.01	 1.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94024	 1	 8.08	 1.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94025	 1	 7.57	 1.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94026	 1	 3.85	 0.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94027	 1	 3.6	 0.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94028	 1	 4.44	 1.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94029	 1	 2.54	 0.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94030	 1	 6.38	 1.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94031	 1	 6.42	 1.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94032	 1	 5.02	 1.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94033	 1	 17.5	 4.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94034	 1	 3.15	 0.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94035	 1	 3.01	 0.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94036	 1	 7.49	 1.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94037	 1	 8.46	 1.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94038	 1	 6.17	 1.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94039	 1	 14.91	 3.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94040	 1	 8.06	 1.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94041	 1	 15.52	 3.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94042	 1	 12.95	 3.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94043	 1	 9.97	 2.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94044	 1	 3.17	 0.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94045	 1	 11.72	 2.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94046	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94047	 1	 9.39	 2.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94048	 1	 13.13	 3.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94049	 1	 6.99	 1.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94050	 1	 6.92	 1.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94051	 1	 19.17	 4.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94052	 1	 5.97	 1.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94053	 1	 11.89	 2.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94054	 1	 6.53	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94055	 1	 4.18	 0.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94056	 1	 25.25	 5.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94057	 1	 18.52	 4.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94058	 1	 9.33	 2.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94059	 1	 97.82	 23.16	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94060	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94061	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94062	 1	 231.11	 54.6	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94063	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94064	 1	 128.87	 30.63	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94065	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94066	 1	 9.91	 2.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94067	 1	 7.06	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94068	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94069	 1	 18.53	 4.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94070	 1	 4.71	 1.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94071	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94072	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94073	 1	 25.62	 6.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94074	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94075	 1	 25.49	 6.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94076	 1	 7.42	 1.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94077	 1	 11.07	 2.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94078	 1	 5.28	 1.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94079	 1	 12.09	 2.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94080	 1	 15.41	 3.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94081	 1	 5.29	 1.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94082	 1	 5.31	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94083	 1	 25.77	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94084	 1	 34.39	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94085	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94086	 1	 93.74	 21.87	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94087	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94088	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94089	 1	 15.98	 3.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94090	 1	 6.76	 1.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94091	 1	 7.34	 1.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94092	 1	 17.04	 3.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94093	 1	 46.65	 11.15	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94094	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94095	 1	 35.8	 8.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94096	 1	 4.21	 0.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94097	 1	 18.31	 4.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94098	 1	 86.99	 29.74	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94099	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94100	 1	 35.88	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94101	 1	 10.53	 2.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94102	 1	 11.37	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94103	 1	 7.61	 1.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94104	 1	 6.68	 1.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94105	 1	 7.66	 1.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94106	 1	 10.45	 2.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94107	 1	 14.04	 3.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94108	 1	 35.12	 8.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94109	 1	 21.45	 5.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94110	 1	 19.75	 4.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94111	 1	 12.62	 3.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94112	 1	 8.88	 2.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94113	 1	 5.13	 1.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94114	 1	 49.46	 24.37	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94115	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94116	 1	 13.06	 3.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94117	 1	 10.92	 2.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94118	 1	 9.23	 2.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94119	 1	 5.37	 1.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94120	 1	 9.69	 2.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94121	 1	 6.77	 1.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94122	 1	 21.36	 5.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94123	 1	 7.69	 1.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94124	 1	 9.74	 4.71	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94125	 1	 6.45	 1.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94126	 1	 9.1	 2.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94127	 1	 7.04	 1.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94128	 1	 18.84	 4.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94129	 1	 5.69	 1.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94130	 1	 4.31	 1.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94131	 1	 5.98	 1.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94132	 1	 14.51	 3.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94133	 1	 5.29	 1.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94134	 1	 9.47	 2.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94135	 1	 184.58	 44.56	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94136	 1	 8.3	 4.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94137	 1	 130.95	 31.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94138	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94139	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94140	 1	 6.78	 1.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94141	 1	 33.53	 7.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94142	 1	 67.89	 16.13	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94143	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94144	 1	 24.1	 5.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94145	 1	 9.79	 2.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94146	 1	 5.77	 1.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94147	 1	 10.01	 2.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94148	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94149	 1	 16.0	 3.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94150	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94151	 1	 32.07	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94152	 1	 57.66	 13.74	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94153	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94154	 1	 10.03	 4.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94155	 1	 6.46	 1.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94156	 1	 5.48	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94157	 1	 8.86	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94158	 1	 9.41	 2.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94159	 1	 19.04	 4.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94160	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94161	 1	 15.73	 3.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94162	 1	 8.94	 2.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94163	 1	 109.91	 57.52	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94164	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94165	 1	 11.44	 2.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94166	 1	 28.58	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94167	 1	 6.59	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94168	 1	 16.26	 3.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94169	 1	 13.48	 3.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94170	 1	 24.47	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94171	 1	 9.13	 2.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94172	 1	 6.67	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94173	 1	 7.79	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94174	 1	 8.9	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94175	 1	 4.84	 1.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94176	 1	 4.15	 0.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94177	 1	 7.96	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94178	 1	 34.86	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94179	 1	 4.6	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94180	 1	 4.97	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94181	 1	 8.7	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94182	 1	 25.95	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94183	 1	 5.18	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94184	 1	 6.19	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94185	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94186	 1	 5.16	 3.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94187	 1	 21.82	 11.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94188	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94189	 1	 13.3	 6.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94190	 1	 2.4	 1.44	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94191	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94192	 1	 41.87	 19.71	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94193	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94194	 1	 23.89	 11.77	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94195	 1	 7.7	 3.98	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94196	 1	 6.91	 3.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94197	 1	 12.48	 7.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94198	 1	 15.6	 7.84	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94199	 1	 44.71	 17.92	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94200	 1	 5.87	 3.32	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94201	 1	 173.74	 82.34	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94202	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94203	 1	 14.0	 7.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94204	 1	 8.82	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94205	 1	 6.89	 1.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94206	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94207	 1	 4.18	 0.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94208	 1	 10.15	 2.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94209	 1	 16.72	 3.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94210	 1	 29.08	 6.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94211	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94212	 1	 7.68	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94213	 1	 19.04	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94214	 1	 7.21	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94215	 1	 9.68	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94216	 1	 7.85	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94217	 1	 5.27	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94218	 1	 24.44	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94219	 1	 7.95	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94220	 1	 5.63	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94221	 1	 16.54	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94222	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94223	 1	 36.86	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94224	 1	 19.76	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94225	 1	 268.48	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94226	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94227	 1	 8.2	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94228	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94229	 1	 22.63	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94230	 1	 7.52	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94231	 1	 8.04	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94232	 1	 17.46	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94233	 1	 11.74	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94234	 1	 8.98	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94235	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94236	 1	 6.16	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94237	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94238	 1	 7.12	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94239	 1	 8.72	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94240	 1	 49.55	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94241	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94242	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94243	 1	 23.08	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94244	 1	 21.22	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94245	 1	 13.36	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94246	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94247	 1	 20.34	 8.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94248	 1	 14.27	 4.99	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94249	 1	 5.12	 2.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94250	 1	 18.36	 6.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94251	 1	 9.36	 4.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94252	 1	 10.25	 5.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94253	 1	 6.63	 3.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94254	 1	 11.65	 5.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94255	 1	 4.42	 2.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94256	 1	 22.92	 10.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94257	 1	 9.22	 5.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94258	 1	 6.51	 3.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94259	 1	 9.53	 5.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94260	 1	 60.22	 22.82	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94261	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94262	 1	 10.75	 6.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94263	 1	 10.23	 4.78	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94264	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94265	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94266	 1	 9.2	 5.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94267	 1	 31.97	 16.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94268	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94269	 1	 19.5	 4.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94270	 1	 7.61	 4.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94271	 1	 8.89	 4.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94272	 1	 10.66	 5.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94273	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94274	 1	 11.38	 6.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94275	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94276	 1	 14.71	 7.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94277	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94278	 1	 8.04	 4.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94279	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94280	 1	 19.15	 9.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94281	 1	 10.75	 5.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94282	 1	 12.42	 5.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94283	 1	 14.01	 7.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94284	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94285	 1	 6.22	 3.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94286	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94287	 1	 32.73	 12.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94288	 1	 8.49	 5.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94289	 1	 2.43	 1.47	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94290	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94291	 1	 18.17	 10.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94292	 1	 6.55	 4.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94293	 1	 9.1	 5.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94294	 1	 24.46	 14.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94295	 1	 7.56	 3.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94296	 1	 13.83	 7.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94297	 1	 18.59	 9.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94298	 1	 15.95	 8.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94299	 1	 11.61	 4.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94300	 1	 24.93	 10.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94301	 1	 8.82	 4.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94302	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94303	 1	 12.58	 6.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94304	 1	 6.49	 3.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94305	 1	 20.64	 8.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94306	 1	 11.35	 5.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94307	 1	 8.71	 4.97	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94308	 1	 63.95	 26.71	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94309	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94310	 1	 13.78	 7.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94311	 1	 4.19	 2.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94312	 1	 5.38	 3.22	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94313	 1	 8.17	 4.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94314	 1	 641.76	 248.33	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94315	 1	 14.13	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94316	 1	 4.82	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94317	 1	 9.67	 5.17	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94318	 1	 2.92	 1.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94319	 1	 23.89	 10.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94320	 1	 5.61	 3.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94321	 1	 4.47	 2.56	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94322	 1	 12.4	 4.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94323	 1	 22.07	 11.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94324	 1	 14.99	 7.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94325	 1	 8.66	 4.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94326	 1	 52.3	 16.65	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94327	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94328	 1	 5.38	 3.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94329	 1	 9.4	 5.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94330	 1	 9.8	 4.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94331	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94332	 1	 24.9	 11.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94333	 1	 100.99	 43.8	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94334	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94335	 1	 15.59	 7.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94336	 1	 14.71	 5.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94337	 1	 13.63	 7.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94338	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94339	 1	 58.39	 27.83	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94340	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94341	 1	 36.29	 12.23	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94342	 1	 12.11	 6.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94343	 1	 13.05	 5.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94344	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94345	 1	 5.22	 3.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94346	 1	 5.52	 3.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94347	 1	 7.92	 4.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94348	 1	 6.64	 3.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94349	 1	 14.43	 4.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94350	 1	 4.18	 2.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94351	 1	 12.63	 5.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94352	 1	 12.9	 5.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94353	 1	 11.66	 5.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94354	 1	 6.68	 3.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94355	 1	 10.77	 5.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94356	 1	 48.34	 23.67	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94357	 1	 30.58	 13.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94358	 1	 4.81	 2.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94359	 1	 13.57	 6.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94360	 1	 25.86	 11.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94361	 1	 28.13	 13.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94362	 1	 15.57	 9.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94363	 1	 22.59	 9.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94364	 1	 59.18	 29.13	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94365	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94366	 1	 13.06	 3.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94367	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94368	 1	 9.57	 3.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94369	 1	 9.95	 4.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94370	 1	 4.98	 1.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94371	 1	 12.45	 5.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94372	 1	 5.5	 3.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94373	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94374	 1	 139.74	 43.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94375	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94376	 1	 9.18	 4.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94377	 1	 15.38	 5.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94378	 1	 6.9	 3.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94379	 1	 12.97	 3.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94380	 1	 34.04	 16.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94381	 1	 14.4	 7.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94382	 1	 17.19	 8.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94383	 1	 7.7	 4.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94384	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94385	 1	 38.59	 16.41	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94386	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94387	 1	 10.17	 5.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94388	 1	 11.45	 5.56	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94389	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94390	 1	 3.21	 1.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94391	 1	 9.66	 3.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94392	 1	 65.67	 35.51	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94393	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94394	 1	 4.54	 2.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94395	 1	 14.58	 5.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94396	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94397	 1	 27.78	 15.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94398	 1	 23.42	 10.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94399	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94400	 1	 26.38	 13.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94401	 1	 8.66	 5.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94402	 1	 7.74	 3.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94403	 1	 200.37	 51.45	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94404	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94405	 1	 164.37	 76.08	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94406	 1	 5.98	 3.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94407	 1	 8.63	 4.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94408	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94409	 1	 50.11	 17.54	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94410	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94411	 1	 20.55	 8.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94412	 1	 3.63	 1.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94413	 1	 16.71	 8.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94414	 1	 5.15	 2.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94415	 1	 22.97	 5.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94416	 1	 27.78	 6.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94417	 1	 11.13	 2.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94418	 1	 14.93	 3.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94419	 1	 9.8	 4.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94420	 1	 9.3	 2.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94421	 1	 2.23	 1.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94422	 1	 10.98	 5.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94423	 1	 70.43	 20.63	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94424	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94425	 1	 74.39	 32.49	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94426	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94427	 1	 30.82	 18.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94428	 1	 755.61	 311.54	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94429	 1	 151.69	 50.28	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94430	 1	 21.4	 8.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94431	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94432	 1	 280.62	 103.87	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94433	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94434	 1	 11.12	 7.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94435	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94436	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94437	 1	 10.48	 5.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94438	 1	 8.54	 4.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94439	 1	 6.75	 4.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94440	 1	 9.71	 5.72	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94441	 1	 12.83	 4.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94442	 1	 30.97	 7.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94443	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94444	 1	 5.47	 1.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94445	 1	 6.04	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94446	 1	 5.23	 1.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94447	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94448	 1	 66.26	 27.6	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94449	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94450	 1	 24.8	 5.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94451	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94452	 1	 17.08	 7.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94453	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94454	 1	 23.81	 10.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94455	 1	 18.21	 9.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94456	 1	 4.88	 2.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94457	 1	 23.21	 10.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94458	 1	 2.0	 1.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94459	 1	 5.42	 2.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94460	 1	 20.19	 12.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94461	 1	 11.02	 5.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94462	 1	 5.47	 2.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94463	 1	 6.91	 3.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94464	 1	 13.79	 7.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94465	 1	 8.79	 3.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94466	 1	 26.08	 13.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94467	 1	 24.46	 12.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94468	 1	 571.96	 227.08	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94469	 1	 115.65	 53.11	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94470	 1	 8.21	 4.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94471	 1	 7.98	 4.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94472	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94473	 1	 5.93	 3.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94474	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94475	 1	 61.26	 30.43	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94476	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94477	 1	 70.4	 34.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94478	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94479	 1	 23.37	 9.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94480	 1	 12.13	 6.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94481	 1	 9.83	 4.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94482	 1	 172.75	 68.92	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94483	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94484	 1	 42.08	 17.03	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94485	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94486	 1	 7.06	 3.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94487	 1	 10.09	 4.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94488	 1	 19.09	 8.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94489	 1	 10.13	 5.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94490	 1	 7.6	 4.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94491	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94492	 1	 93.64	 42.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94493	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94494	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94495	 1	 10.52	 5.08	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94496	 1	 28.53	 12.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94497	 1	 26.96	 13.24	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94498	 1	 8.05	 4.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94499	 1	 11.01	 6.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94500	 1	 27.61	 16.38	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94501	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94502	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94503	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94504	 1	 6.04	 2.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94505	 1	 8.6	 4.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94506	 1	 6.13	 3.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94507	 1	 11.49	 2.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94508	 1	 11.69	 2.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94509	 1	 32.43	 7.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94510	 1	 12.32	 2.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94511	 1	 6.49	 1.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94512	 1	 4.87	 1.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94513	 1	 4.72	 2.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94514	 1	 3.85	 0.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94515	 1	 9.28	 3.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94516	 1	 7.05	 1.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94517	 1	 6.83	 3.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94518	 1	 3.54	 2.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94519	 1	 7.16	 1.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94520	 1	 11.51	 2.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94521	 1	 10.88	 2.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94522	 1	 17.23	 3.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94523	 1	 12.75	 2.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94524	 1	 9.03	 2.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94525	 1	 8.92	 2.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94526	 1	 3.64	 0.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94527	 1	 7.2	 1.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94528	 1	 5.97	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94529	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94530	 1	 117.46	 48.85	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94531	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94532	 1	 9.58	 4.67	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94533	 1	 7.7	 4.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94534	 1	 4.31	 0.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94535	 1	 6.81	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94536	 1	 5.94	 1.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94537	 1	 6.64	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94538	 1	 9.89	 2.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94539	 1	 15.0	 3.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94540	 1	 6.85	 1.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94541	 1	 10.26	 2.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94542	 1	 10.33	 2.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94543	 1	 13.99	 3.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94544	 1	 8.15	 1.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94545	 1	 14.45	 3.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94546	 1	 22.29	 5.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94547	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94548	 1	 9.83	 2.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94549	 1	 6.74	 1.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94550	 1	 8.5	 1.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94551	 1	 11.4	 2.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94552	 1	 10.18	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94553	 1	 10.05	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94554	 1	 10.33	 2.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94555	 1	 11.89	 2.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94556	 1	 10.08	 2.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94557	 1	 45.81	 16.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94558	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94559	 1	 11.24	 2.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94560	 1	 8.97	 2.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94561	 1	 5.93	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94562	 1	 7.02	 1.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94563	 1	 10.36	 2.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94564	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94565	 1	 22.52	 5.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94566	 1	 5.48	 1.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94567	 1	 8.09	 1.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94568	 1	 13.84	 3.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94569	 1	 36.23	 8.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94570	 1	 22.0	 5.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94571	 1	 8.41	 1.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94572	 1	 7.32	 1.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94573	 1	 55.57	 19.67	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94574	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94575	 1	 8.67	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94576	 1	 4.76	 1.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94577	 1	 7.91	 1.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94578	 1	 19.39	 4.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94579	 1	 6.28	 1.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94580	 1	 11.77	 2.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94581	 1	 7.8	 1.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94582	 1	 6.95	 1.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94583	 1	 27.43	 6.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94584	 1	 18.96	 4.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94585	 1	 14.28	 3.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94586	 1	 8.98	 5.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94587	 1	 10.54	 5.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94588	 1	 10.35	 5.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94589	 1	 9.09	 5.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94590	 1	 12.71	 7.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94591	 1	 3.79	 1.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94592	 1	 9.48	 5.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94593	 1	 7.22	 3.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94594	 1	 42.74	 12.23	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94595	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94596	 1	 170.14	 76.46	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94597	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94598	 1	 8.96	 2.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94599	 1	 22.21	 5.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94600	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94601	 1	 13.04	 2.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94602	 1	 23.48	 5.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94603	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94604	 1	 10.19	 2.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94605	 1	 16.03	 3.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94606	 1	 17.81	 4.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94607	 1	 19.2	 4.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94608	 1	 15.6	 3.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94609	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94610	 1	 60.01	 31.01	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94611	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94612	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94613	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94614	 1	 35.48	 8.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94615	 1	 20.73	 10.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94616	 1	 6.03	 3.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94617	 1	 10.63	 5.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94618	 1	 11.69	 2.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94619	 1	 12.38	 5.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94620	 1	 6.65	 3.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94621	 1	 7.9	 4.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94622	 1	 11.05	 5.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94623	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94624	 1	 17.34	 8.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94625	 1	 17.08	 3.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94626	 1	 13.18	 3.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94627	 1	 16.09	 3.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94628	 1	 10.36	 2.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94629	 1	 17.98	 4.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94630	 1	 8.67	 4.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94631	 1	 4.44	 2.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94632	 1	 9.88	 5.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94633	 1	 13.69	 6.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94634	 1	 8.49	 1.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94635	 1	 4.7	 1.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94636	 1	 21.66	 5.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94637	 1	 6.58	 3.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94638	 1	 6.22	 3.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94639	 1	 12.19	 2.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94640	 1	 13.67	 3.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94641	 1	 11.04	 5.9	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94642	 1	 11.39	 4.81	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94643	 1	 29.47	 6.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94644	 1	 9.92	 5.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94645	 1	 14.35	 7.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94646	 1	 25.15	 13.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94647	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94648	 1	 36.66	 15.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94649	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94650	 1	 18.96	 9.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94651	 1	 10.92	 6.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94652	 1	 8.85	 4.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94653	 1	 109.24	 47.36	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94654	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94655	 1	 13.05	 6.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94656	 1	 6.26	 3.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94657	 1	 19.35	 10.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94658	 1	 7.61	 4.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94659	 1	 16.28	 7.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94660	 1	 11.31	 5.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94661	 1	 9.5	 5.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94662	 1	 39.0	 14.92	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94663	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94664	 1	 12.72	 5.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94665	 1	 12.68	 6.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94666	 1	 20.46	 11.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94667	 1	 7.56	 4.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94668	 1	 11.31	 5.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94669	 1	 8.53	 3.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94670	 1	 6.05	 3.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94671	 1	 5.52	 3.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94672	 1	 17.69	 6.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94673	 1	 8.44	 4.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94674	 1	 12.53	 6.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94675	 1	 11.22	 6.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94676	 1	 9.24	 4.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94677	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94678	 1	 14.65	 7.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94679	 1	 4.88	 2.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94680	 1	 5.9	 3.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94681	 1	 10.59	 5.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94682	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94683	 1	 26.22	 15.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94684	 1	 11.62	 6.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94685	 1	 17.65	 8.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94686	 1	 10.45	 5.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94687	 1	 9.75	 4.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94688	 1	 13.31	 8.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94689	 1	 14.34	 8.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94690	 1	 8.34	 5.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94691	 1	 14.22	 7.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94692	 1	 11.67	 6.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94693	 1	 11.75	 6.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94694	 1	 20.77	 9.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94695	 1	 10.74	 5.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94696	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94697	 1	 23.75	 14.71	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94698	 1	 10.1	 6.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94699	 1	 14.7	 8.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94700	 1	 7.74	 4.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94701	 1	 4.66	 2.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94702	 1	 5.4	 2.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94703	 1	 8.65	 4.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94704	 1	 11.74	 5.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94705	 1	 10.09	 5.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94706	 1	 9.66	 5.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94707	 1	 7.58	 5.01	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94708	 1	 7.29	 4.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94709	 1	 13.3	 8.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94710	 1	 10.04	 5.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94711	 1	 5.21	 3.19	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94712	 1	 7.33	 3.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94713	 1	 15.16	 6.77	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94714	 1	 2.07	 1.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94715	 1	 18.72	 7.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94716	 1	 15.6	 6.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94717	 1	 6.98	 4.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94718	 1	 6.17	 3.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94719	 1	 16.88	 8.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94720	 1	 16.39	 7.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94721	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94722	 1	 27.27	 12.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94723	 1	 6.26	 3.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94724	 1	 6.32	 3.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94725	 1	 28.94	 16.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94726	 1	 6.45	 4.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94727	 1	 7.78	 4.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94728	 1	 8.21	 5.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94729	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94730	 1	 134.33	 58.79	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94731	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94732	 1	 8.21	 3.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94733	 1	 6.64	 3.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94734	 1	 17.43	 8.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94735	 1	 14.63	 8.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94736	 1	 10.59	 4.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94737	 1	 46.1	 12.46	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94738	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94739	 1	 4.3	 2.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94740	 1	 7.38	 3.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94741	 1	 7.44	 4.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94742	 1	 10.98	 6.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94743	 1	 2.47	 1.33	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94744	 1	 6.37	 3.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94745	 1	 10.37	 4.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94746	 1	 21.52	 10.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94747	 1	 7.05	 3.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94748	 1	 10.86	 5.73	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94749	 1	 5.37	 2.36	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94750	 1	 24.59	 7.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94751	 1	 8.2	 5.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94752	 1	 223.92	 99.61	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94753	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94754	 1	 7.59	 3.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94755	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94756	 1	 163.6	 61.72	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94757	 1	 14.88	 6.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94758	 1	 2.96	 1.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94759	 1	 12.98	 6.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94760	 1	 83.55	 31.68	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94761	 1	 8.15	 4.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94762	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94763	 1	 4.96	 2.6	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94764	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94765	 1	 496.31	 172.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94766	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94767	 1	 15.43	 7.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94768	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94769	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94770	 1	 83.79	 34.67	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94771	 1	 309.87	 121.83	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94772	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94773	 1	 25.85	 11.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94774	 1	 10.7	 5.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94775	 1	 17.3	 9.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94776	 1	 11.91	 5.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94777	 1	 8.24	 4.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94778	 1	 4.65	 2.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94779	 1	 6.3	 3.5	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94780	 1	 7.39	 4.39	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94781	 1	 110.99	 58.03	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94782	 1	 13.75	 5.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94783	 1	 17.38	 8.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94784	 1	 11.45	 6.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94785	 1	 72.64	 39.55	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94786	 1	 3.17	 1.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94787	 1	 25.24	 6.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94788	 1	 75.22	 21.13	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94789	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94790	 1	 6.27	 3.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94791	 1	 20.9	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94792	 1	 5.87	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94793	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94794	 1	 104.64	 55.99	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94795	 1	 5.0	 2.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94796	 1	 3.84	 1.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94797	 1	 11.88	 6.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94798	 1	 8.0	 4.74	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94799	 1	 2.2	 1.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94800	 1	 6.52	 3.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94801	 1	 9.38	 2.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94802	 1	 18.52	 9.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94803	 1	 17.29	 6.1	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94804	 1	 12.12	 6.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94805	 1	 37.61	 16.02	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94806	 1	 10.49	 5.78	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94807	 1	 3.16	 1.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94808	 1	 2.81	 1.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94809	 1	 9.33	 5.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94810	 1	 43.56	 15.35	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94811	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94812	 1	 7.87	 4.01	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94813	 1	 22.74	 10.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94814	 1	 12.49	 5.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94815	 1	 16.87	 7.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94816	 1	 28.82	 15.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94817	 1	 2.65	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94818	 1	 9.5	 5.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94819	 1	 3.78	 1.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94820	 1	 5.01	 2.85	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94821	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94822	 1	 5.62	 2.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94823	 1	 23.83	 7.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94824	 1	 19.49	 10.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94825	 1	 17.88	 7.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94826	 1	 3.17	 1.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94827	 1	 11.12	 6.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94828	 1	 10.15	 4.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94829	 1	 10.54	 4.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94830	 1	 6.52	 3.51	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94831	 1	 13.02	 6.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94832	 1	 46.93	 15.92	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94833	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94834	 1	 21.9	 7.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94835	 1	 15.07	 8.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94836	 1	 3.82	 2.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94837	 1	 8.66	 4.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94838	 1	 7.54	 4.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94839	 1	 3.97	 2.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94840	 1	 7.27	 3.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94841	 1	 27.13	 6.22	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94842	 1	 18.14	 4.21	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94843	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94844	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94845	 1	 6.65	 3.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94846	 1	 25.2	 10.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94847	 1	 10.01	 4.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94848	 1	 9.4	 4.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94849	 1	 7.93	 4.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94850	 1	 136.48	 50.26	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94851	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94852	 1	 15.49	 6.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94853	 1	 29.24	 12.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94854	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94855	 1	 6.55	 3.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94856	 1	 8.38	 3.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94857	 1	 3.84	 0.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94858	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94859	 1	 7.34	 3.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94860	 1	 11.64	 7.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94861	 1	 16.81	 3.89	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94862	 1	 11.03	 5.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94863	 1	 8.24	 4.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94864	 1	 6.82	 3.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94865	 1	 8.73	 5.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94866	 1	 10.17	 4.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94867	 1	 8.23	 4.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94868	 1	 4.32	 2.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94869	 1	 26.68	 11.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94870	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94871	 1	 17.1	 7.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94872	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94873	 1	 5.16	 2.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94874	 1	 2.55	 0.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94875	 1	 16.16	 7.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94876	 1	 20.05	 9.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94877	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94878	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94879	 1	 22.6	 12.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94880	 1	 20.66	 10.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94881	 1	 10.86	 5.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94882	 1	 4.4	 2.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94883	 1	 5.28	 3.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94884	 1	 4.12	 2.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94885	 1	 4.43	 2.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94886	 1	 5.73	 2.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94887	 1	 8.62	 3.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94888	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94889	 1	 19.45	 6.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94890	 1	 21.02	 10.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94891	 1	 18.57	 4.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94892	 1	 17.18	 3.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94893	 1	 11.71	 2.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94894	 1	 11.89	 6.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94895	 1	 118.47	 49.41	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94896	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94897	 1	 25.7	 11.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94898	 1	 16.88	 7.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94899	 1	 9.43	 5.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94900	 1	 11.09	 6.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94901	 1	 120.46	 42.07	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94902	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94903	 1	 10.99	 5.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94904	 1	 8.28	 4.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94905	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94906	 1	 60.12	 31.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94907	 1	 2.53	 1.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94908	 1	 13.49	 3.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94909	 1	 8.79	 2.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94910	 1	 27.54	 6.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94911	 1	 24.02	 5.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94912	 1	 14.72	 7.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94913	 1	 8.96	 4.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94914	 1	 89.42	 35.12	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94915	 1	 23.86	 13.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94916	 1	 22.76	 7.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94917	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94918	 1	 14.13	 8.59	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94919	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94920	 1	 39.97	 16.08	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94921	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94922	 1	 166.38	 74.29	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94923	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94924	 1	 8.94	 4.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94925	 1	 6.25	 3.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94926	 1	 4.11	 2.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94927	 1	 6.88	 3.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94928	 1	 9.26	 5.37	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94929	 1	 8.96	 4.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94930	 1	 5.59	 3.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94931	 1	 6.66	 3.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94932	 1	 13.74	 6.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94933	 1	 8.4	 4.61	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94934	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94935	 1	 6.31	 3.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94936	 1	 7.61	 4.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94937	 1	 7.56	 4.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94938	 1	 3.78	 2.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94939	 1	 7.35	 3.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94940	 1	 5.55	 3.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94941	 1	 11.65	 5.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94942	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94943	 1	 12.39	 7.53	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94944	 1	 459.48	 194.49	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94945	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94946	 1	 14.2	 7.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94947	 1	 186.94	 74.65	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94948	 1	 24.15	 8.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94949	 1	 26.58	 13.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94950	 1	 11.47	 5.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94951	 1	 8.87	 5.11	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94952	 1	 4.33	 2.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94953	 1	 10.85	 6.11	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94954	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	94955	 1	 13.74	 5.2	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94956	 1	 4.97	 2.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94957	 1	 22.61	 10.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94958	 1	 65.52	 27.98	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94959	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94960	 1	 14.51	 6.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94961	 1	 14.31	 8.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94962	 1	 14.83	 8.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94963	 1	 9.14	 5.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94964	 1	 20.89	 9.55	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94965	 1	 5.22	 2.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94966	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94967	 1	 12.18	 6.55	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94968	 1	 37.85	 18.22	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94969	 1	 9.07	 5.1	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94970	 1	 15.67	 7.99	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94971	 1	 39.08	 16.79	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94972	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94973	 1	 49.81	 25.43	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94974	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94975	 1	 20.78	 9.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94976	 1	 3.12	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94977	 1	 14.47	 6.75	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94978	 1	 13.82	 7.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94979	 1	 6.33	 2.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94980	 1	 15.64	 8.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94981	 1	 13.61	 7.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94982	 1	 3.12	 1.66	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94983	 1	 6.53	 3.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94984	 1	 27.36	 13.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94985	 1	 3.41	 1.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94986	 1	 13.36	 5.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94987	 1	 8.55	 4.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94988	 1	 6.93	 3.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94989	 1	 6.48	 3.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94990	 1	 5.03	 3.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94991	 1	 7.42	 3.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94992	 1	 3.9	 2.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94993	 1	 25.6	 8.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94994	 1	 29.76	 12.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94995	 1	 12.44	 6.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94996	 1	 46.19	 25.09	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	94997	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94998	 1	 11.18	 4.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	94999	 1	 15.19	 8.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95000	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95001	 1	 13.37	 7.34	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95002	 1	 12.45	 6.54	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95003	 1	 12.55	 3.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95004	 1	 11.46	 2.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95005	 1	 9.25	 4.33	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95006	 1	 2.2	 1.31	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95007	 1	 40.84	 11.27	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95008	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95009	 1	 3.77	 1.99	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95010	 1	 4.73	 2.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95011	 1	 3.79	 1.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95012	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95013	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95014	 1	 2.92	 1.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95015	 1	 11.82	 5.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95016	 1	 5.47	 2.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95017	 1	 11.95	 6.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95018	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95019	 1	 38.42	 13.07	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95020	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95021	 1	 10.61	 5.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95022	 1	 10.75	 5.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95023	 1	 21.16	 4.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95024	 1	 11.3	 5.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95025	 1	 11.81	 7.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95026	 1	 2.48	 1.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95027	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95028	 1	 20.68	 9.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95029	 1	 61.14	 25.31	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95030	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95031	 1	 104.76	 48.83	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95032	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95033	 1	 12.79	 6.47	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95034	 1	 9.72	 4.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95035	 1	 24.97	 10.3	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95036	 1	 9.74	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95037	 1	 6.12	 1.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95038	 1	 4.6	 2.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95039	 1	 6.64	 3.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95040	 1	 8.16	 1.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95041	 1	 3.84	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95042	 1	 11.84	 2.83	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95043	 1	 19.7	 4.64	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95044	 1	 21.49	 5.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95045	 1	 20.72	 4.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95046	 1	 4.69	 1.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95047	 1	 3.02	 0.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95048	 1	 11.63	 2.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95049	 1	 118.01	 47.18	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95050	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95051	 1	 17.59	 4.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95052	 1	 6.79	 3.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95053	 1	 8.91	 2.13	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95054	 1	 8.58	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95055	 1	 9.24	 5.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95056	 1	 4.99	 1.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95057	 1	 58.37	 24.43	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95058	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95059	 1	 8.46	 2.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95060	 1	 6.35	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95061	 1	 12.36	 5.91	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95062	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95063	 1	 91.43	 44.99	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95064	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95065	 1	 22.3	 5.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95066	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95067	 1	 10.68	 2.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95068	 1	 4.84	 1.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95069	 1	 31.63	 7.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95070	 1	 9.96	 2.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95071	 1	 10.89	 4.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95072	 1	 7.65	 4.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95073	 1	 8.21	 3.06	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95074	 1	 3.29	 1.87	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95075	 1	 18.18	 6.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95076	 1	 10.04	 2.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95077	 1	 9.88	 2.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95078	 1	 12.1	 5.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95079	 1	 10.14	 6.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95080	 1	 7.23	 1.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95081	 1	 8.28	 1.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95082	 1	 22.36	 5.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95083	 1	 8.83	 2.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95084	 1	 25.17	 5.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95085	 1	 12.83	 3.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95086	 1	 18.68	 4.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95087	 1	 6.54	 1.54	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95088	 1	 12.83	 3.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95089	 1	 15.56	 3.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95090	 1	 25.84	 6.06	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95091	 1	 17.54	 4.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95092	 1	 15.66	 3.65	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95093	 1	 6.2	 1.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95094	 1	 8.54	 2.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95095	 1	 27.08	 6.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95096	 1	 9.08	 2.15	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95097	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95098	 1	 132.44	 45.6	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95099	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95100	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95101	 1	 100.39	 35.76	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95102	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95103	 1	 7.48	 1.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95104	 1	 6.16	 1.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95105	 1	 6.24	 1.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95106	 1	 5.37	 1.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95107	 1	 6.45	 1.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95108	 1	 5.04	 1.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95109	 1	 8.87	 2.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95110	 1	 7.81	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95111	 1	 8.04	 1.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95112	 1	 28.01	 6.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95113	 1	 7.62	 1.81	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95114	 1	 9.64	 2.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95115	 1	 7.54	 1.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95116	 1	 12.81	 3.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95117	 1	 7.24	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95118	 1	 61.18	 14.49	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95119	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95120	 1	 10.29	 2.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95121	 1	 5.92	 1.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95122	 1	 11.57	 2.71	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95123	 1	 6.64	 1.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95124	 1	 7.65	 1.82	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95125	 1	 6.25	 1.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95126	 1	 8.92	 2.1	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95127	 1	 22.32	 5.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95128	 1	 36.46	 8.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95129	 1	 10.04	 2.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95130	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95131	 1	 16.72	 3.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95132	 1	 30.54	 7.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95133	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95134	 1	 34.81	 17.17	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95135	 1	 5.54	 2.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95136	 1	 7.48	 1.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95137	 1	 22.88	 5.39	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95138	 1	 8.93	 2.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95139	 1	 37.66	 10.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95140	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95141	 1	 13.05	 3.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95142	 1	 5.29	 1.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95143	 1	 6.06	 1.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95144	 1	 8.72	 2.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95145	 1	 11.17	 2.63	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95146	 1	 16.44	 3.88	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95147	 1	 30.52	 7.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95148	 1	 2.63	 1.32	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95149	 1	 4.65	 2.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95150	 1	 17.87	 8.91	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95151	 1	 8.92	 4.47	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95152	 1	 10.88	 6.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95153	 1	 7.05	 4.46	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95154	 1	 6.34	 3.33	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95155	 1	 7.89	 3.78	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95156	 1	 70.6	 40.65	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95157	 1	 2.22	 1.4	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95158	 1	 29.37	 12.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95159	 1	 4.69	 2.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95160	 1	 24.15	 12.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95161	 1	 30.57	 16.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95162	 1	 14.62	 6.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95163	 1	 8.16	 1.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95164	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95165	 1	 21.58	 4.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95166	 1	 8.91	 2.07	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95167	 1	 22.2	 5.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95168	 1	 5.6	 1.29	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95169	 1	 11.11	 2.59	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95170	 1	 5.73	 3.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95171	 1	 5.7	 2.96	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95172	 1	 5.21	 2.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95173	 1	 6.17	 2.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95174	 1	 6.93	 3.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95175	 1	 12.1	 5.84	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95176	 1	 7.69	 4.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95177	 1	 3.15	 1.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95178	 1	 2.4	 1.43	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95179	 1	 2.34	 1.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95180	 1	 18.87	 9.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95181	 1	 9.95	 4.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95182	 1	 7.43	 4.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95183	 1	 6.74	 3.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95184	 1	 25.05	 5.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95185	 1	 11.92	 5.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95186	 1	 7.39	 3.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95187	 1	 15.56	 6.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95188	 1	 16.83	 3.86	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95189	 1	 8.02	 1.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95190	 1	 12.61	 6.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95191	 1	 13.74	 5.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95192	 1	 16.96	 8.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95193	 1	 13.99	 6.41	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95194	 1	 13.73	 5.26	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95195	 1	 4.94	 2.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95196	 1	 8.99	 4.69	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95197	 1	 20.2	 11.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95198	 1	 27.88	 11.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95199	 1	 8.14	 4.75	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95200	 1	 7.71	 4.55	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95201	 1	 36.02	 18.34	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95202	 1	 30.86	 13.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95203	 1	 5.52	 2.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95204	 1	 36.32	 14.87	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95205	 1	 1.33	 0.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95206	 1	 4.49	 2.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95207	 1	 6.64	 3.94	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95208	 1	 11.77	 5.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95209	 1	 12.78	 6.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95210	 1	 9.84	 2.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95211	 1	 8.5	 3.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95212	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95213	 1	 4.66	 2.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95214	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95215	 1	 7.0	 3.42	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95216	 1	 18.21	 8.45	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95217	 1	 4.93	 2.55	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95218	 1	 37.89	 21.26	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95219	 1	 11.2	 5.47	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95220	 1	 2.19	 1.1	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95221	 1	 27.59	 13.4	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95222	 1	 9.15	 5.36	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95223	 1	 20.33	 7.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95224	 1	 23.7	 12.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95225	 1	 5.88	 3.18	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95226	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95227	 1	 28.08	 13.23	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95228	 1	 2.7	 1.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95229	 1	 5.06	 2.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95230	 1	 13.87	 7.62	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95231	 1	 5.29	 2.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95232	 1	 3.3	 1.6	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95233	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95234	 1	 9.85	 5.97	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95235	 1	 18.98	 8.01	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95236	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95237	 1	 12.84	 6.49	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95238	 1	 41.87	 20.16	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95239	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95240	 1	 4.05	 2.12	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95241	 1	 7.35	 3.73	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95242	 1	 10.78	 2.56	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95243	 1	 2.65	 1.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95244	 1	 6.95	 4.19	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95245	 1	 26.72	 12.68	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95246	 1	 4.82	 2.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95247	 1	 17.27	 8.91	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95248	 1	 8.26	 4.99	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95249	 1	 8.11	 4.09	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95250	 1	 29.99	 12.28	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95251	 1	 13.27	 7.77	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95252	 1	 13.54	 7.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95253	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95254	 1	 22.13	 8.52	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95255	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95256	 1	 28.04	 12.91	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95257	 1	 17.08	 9.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95258	 1	 4.64	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95259	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95260	 1	 6.56	 3.42	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95261	 1	 19.08	 8.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95262	 1	 5.48	 3.24	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95263	 1	 5.99	 3.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95264	 1	 7.73	 4.95	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95265	 1	 26.79	 15.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95266	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95267	 1	 25.64	 11.7	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95268	 1	 9.53	 4.79	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95269	 1	 4.64	 2.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95270	 1	 3.51	 2.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95271	 1	 8.63	 2.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95272	 1	 20.06	 11.44	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95273	 1	 2.48	 1.3	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95274	 1	 9.82	 4.66	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95275	 1	 7.49	 3.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95276	 1	 13.3	 8.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95277	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95278	 1	 9.44	 4.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95279	 1	 9.2	 4.53	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95280	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95281	 1	 41.96	 24.54	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95282	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95283	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95284	 1	 24.49	 8.98	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95285	 1	 14.18	 6.89	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95286	 1	 30.4	 12.31	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95287	 1	 11.54	 6.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95288	 1	 5.5	 3.37	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95289	 1	 8.22	 4.4	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95290	 1	 3.23	 1.85	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95291	 1	 6.57	 3.58	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95292	 1	 9.24	 2.14	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95293	 1	 11.79	 2.72	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95294	 1	 5.4	 2.9	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95295	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95296	 1	 11.78	 7.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95297	 1	 11.16	 5.04	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95298	 1	 21.29	 10.38	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95299	 1	 4.45	 2.11	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95300	 1	 4.89	 2.16	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95301	 1	 6.14	 3.5	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95302	 1	 6.81	 3.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95303	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95304	 1	 15.17	 7.57	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95305	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95306	 1	 15.47	 7.48	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95307	 1	 11.38	 5.76	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95308	 1	 10.07	 4.93	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95309	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95310	 1	 40.4	 16.52	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95311	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95312	 1	 3.9	 1.8	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95313	 1	 4.74	 2.57	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95314	 1	 6.54	 3.92	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95315	 1	 6.82	 4.27	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95316	 1	 8.41	 3.97	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95317	 1	 47.08	 20.08	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95318	 1	 14.89	 7.05	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95319	 1	 14.45	 7.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95320	 1	 16.97	 4.03	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95321	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95322	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95323	 1	 16.0	 6.02	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95324	 1	 5.42	 2.46	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95325	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	95326	 1	 9.87	 6.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95327	 1	 16.73	 6.2	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95328	 1	 11.27	 5.35	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95329	 1	 0.0	 0.0	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95330	 1	 14.17	 5.67	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95331	 1	 8.39	 4.25	 0.0	 0.0	 34	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95332	 1	 0.0	 0.0	 0.0	 -30.02	 34	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	95333	 4	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	95334	 4	 0.0	 0.0	 0.0	 -552.5	 32	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	95335	 1	 0.0	 0.0	 0.0	 0.0	 37	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	95336	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	95337	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95338	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	95339	 1	 0.0	 0.0	 0.0	 0.0	 29	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	95340	 1	 0.0	 0.0	 0.0	 0.0	 31	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	95342	 4	 0.0	 0.0	 0.0	 0.0	 36	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	95343	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	95344	 4	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	95345	 1	 0.0	 0.0	 0.0	 0.0	 25	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin	Pc1	Pc2	Qc1min	Qc1max	Qc2min	Qc2max	ramp_agc	ramp_10	ramp_30	ramp_q	apf
mpc.gen = [
	1	 659.0	 0.0	 514.7	 -514.7	 1.0	 100.0	 1	 1253.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NUC
	1	 479.95	 68.7	 440.7	 -303.3	 1.0	 100.0	 1	 909.9	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NUC
	2	 280.0	 34.75	 222.8	 -153.3	 1.0	 100.0	 1	 460.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 460.0; % NG
	3	 265.0	 57.3	 247.9	 -133.3	 1.0	 100.0	 1	 400.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 400.0; % NG
	3	 110.84	 23.35	 101.0	 -54.3	 1.0	 100.0	 1	 163.0	 58.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.0; % NG
	4	 224.5	 41.4	 179.1	 -96.3	 1.0	 100.0	 1	 289.0	 160.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 289.0; % NG
	4	 224.5	 41.4	 179.1	 -96.3	 1.0	 100.0	 1	 289.0	 160.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 289.0; % NG
	5	 212.5	 40.1	 173.5	 -93.3	 1.0	 100.0	 1	 280.0	 145.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 280.0; % NG
	5	 212.5	 40.1	 173.5	 -93.3	 1.0	 100.0	 1	 280.0	 145.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 280.0; % NG
	5	 212.5	 40.1	 173.5	 -93.3	 1.0	 100.0	 1	 280.0	 145.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 280.0; % COW
	6	 137.7	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 95.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	6	 130.05	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 90.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	6	 130.05	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 90.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	7	 169.7	 34.3	 148.4	 -79.8	 1.0	 100.0	 1	 239.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 239.4; % NG
	7	 79.3	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % COW
	7	 269.95	 31.3	 200.9	 -138.3	 1.0	 100.0	 1	 414.9	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 414.9; % NG
	8	 73.0	 20.0	 72.0	 -32.0	 1.0	 100.0	 1	 96.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.0; % NG
	9	 62.0	 0.0	 27.6	 -27.6	 1.0	 100.0	 1	 84.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.0; % NG
	10	 269.95	 31.3	 200.9	 -138.3	 1.0	 100.0	 1	 414.9	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 414.9; % NG
	10	 57.5	 15.65	 56.3	 -25.0	 1.0	 100.0	 1	 75.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	11	 38.5	 9.6	 41.5	 -22.3	 1.0	 100.0	 1	 67.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0; % PEL
	13	 27.5	 5.75	 24.8	 -13.3	 1.0	 100.0	 1	 40.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	13	 36.0	 8.0	 34.7	 -18.7	 1.0	 100.0	 1	 56.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.0; % NG
	14	 33.5	 7.3	 31.6	 -17.0	 1.0	 100.0	 1	 51.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0; % NG
	14	 33.5	 7.3	 31.6	 -17.0	 1.0	 100.0	 1	 51.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0; % NG
	14	 33.5	 7.3	 31.6	 -17.0	 1.0	 100.0	 1	 51.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0; % NG
	14	 33.5	 7.3	 31.6	 -17.0	 1.0	 100.0	 1	 51.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0; % NG
	15	 26.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % PEL
	15	 26.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	15	 26.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	15	 26.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	15	 26.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	16	 33.5	 3.4	 21.8	 -15.0	 1.0	 100.0	 1	 45.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	16	 33.5	 9.4	 33.8	 -15.0	 1.0	 100.0	 1	 45.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % PEL
	17	 34.55	 3.35	 21.4	 -14.7	 1.0	 100.0	 1	 44.1	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.1; % NG
	17	 19.55	 2.55	 16.5	 -11.4	 1.0	 100.0	 1	 34.1	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.1; % PEL
	18	 25.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	18	 25.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	18	 25.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	18	 25.9	 8.75	 31.4	 -13.9	 1.0	 100.0	 1	 41.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	19	 36.1	 5.35	 23.1	 -12.4	 1.0	 100.0	 1	 37.2	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.2; % NG
	20	 18.65	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 31.3	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.3; % NG
	21	 4.215	 0.85	 4.25	 -2.55	 1.0	 100.0	 1	 7.63	 0.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.625; % NG
	21	 4.215	 0.85	 4.25	 -2.55	 1.0	 100.0	 1	 7.63	 0.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.625; % COW
	21	 4.215	 0.85	 4.25	 -2.55	 1.0	 100.0	 1	 7.63	 0.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.625; % PEL
	21	 4.215	 0.85	 4.25	 -2.55	 1.0	 100.0	 1	 7.63	 0.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.625; % COW
	23	 18.9	 3.7	 16.0	 -8.6	 1.0	 100.0	 1	 25.8	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.8; % NG
	25	 23.5	 5.0	 18.0	 -8.0	 1.0	 100.0	 1	 24.0	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % PEL
	26	 19.1	 3.35	 14.4	 -7.7	 1.0	 100.0	 1	 23.2	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.2; % NG
	26	 19.1	 3.35	 14.4	 -7.7	 1.0	 100.0	 1	 23.2	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.2; % PEL
	26	 19.1	 3.35	 14.4	 -7.7	 1.0	 100.0	 1	 23.2	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.2; % NG
	27	 19.6	 3.1	 13.5	 -7.3	 1.0	 100.0	 1	 21.8	 17.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.8; % PEL
	28	 18.95	 3.1	 13.5	 -7.3	 1.0	 100.0	 1	 21.8	 16.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.8; % NG
	29	 19.6	 3.1	 13.5	 -7.3	 1.0	 100.0	 1	 21.8	 17.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.8; % PEL
	30	 13.8	 3.95	 14.6	 -6.7	 1.0	 100.0	 1	 20.2	 7.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.2; % PEL
	31	 19.8	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 19.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	31	 19.55	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 19.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	31	 22.05	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 19.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % COW
	31	 22.05	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 19.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	31	 21.85	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 18.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	32	 375.0	 0.0	 190.6	 -190.6	 1.0	 100.0	 1	 580.0	 170.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 580.0; % COW
	32	 392.5	 0.0	 240.3	 -240.3	 1.0	 100.0	 1	 585.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 585.0; % COW
	33	 70.0	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % COW
	33	 64.185	 6.725	 43.15	 -29.7	 1.0	 100.0	 1	 89.1	 39.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.1; % PEL
	33	 64.185	 6.725	 43.15	 -29.7	 1.0	 100.0	 1	 89.1	 39.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.1; % NG
	33	 64.185	 6.725	 43.15	 -29.7	 1.0	 100.0	 1	 89.1	 39.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.1; % NG
	33	 62.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % PEL
	33	 62.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	33	 62.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	33	 62.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	33	 62.5	 7.95	 50.9	 -35.0	 1.0	 100.0	 1	 105.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0; % NG
	33	 64.185	 6.725	 43.15	 -29.7	 1.0	 100.0	 1	 89.1	 39.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.1; % NG
	33	 64.185	 6.725	 43.15	 -29.7	 1.0	 100.0	 1	 89.1	 39.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.1; % NG
	33	 64.185	 6.725	 43.15	 -29.7	 1.0	 100.0	 1	 89.1	 39.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.1; % NG
	34	 260.0	 22.65	 145.3	 -100.0	 1.0	 100.0	 1	 300.0	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.0; % NG
	34	 260.0	 22.65	 145.3	 -100.0	 1.0	 100.0	 1	 300.0	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.0; % NG
	35	 222.0	 60.25	 216.8	 -96.3	 1.0	 100.0	 1	 289.0	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 289.0; % NG
	36	 219.5	 41.4	 179.1	 -96.3	 1.0	 100.0	 1	 289.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 289.0; % NG
	36	 219.5	 41.4	 179.1	 -96.3	 1.0	 100.0	 1	 289.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 289.0; % NG
	37	 219.5	 41.4	 179.1	 -96.3	 1.0	 100.0	 1	 289.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 289.0; % NG
	37	 219.5	 41.4	 179.1	 -96.3	 1.0	 100.0	 1	 289.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 289.0; % NG
	38	 353.5	 46.55	 298.8	 -205.7	 1.0	 100.0	 1	 617.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 617.0; % NG
	38	 209.3	 39.9	 172.7	 -92.9	 1.0	 100.0	 1	 278.6	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 278.6; % NG
	38	 209.3	 39.9	 172.7	 -92.9	 1.0	 100.0	 1	 278.6	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 278.6; % NG
	38	 209.3	 39.9	 172.7	 -92.9	 1.0	 100.0	 1	 278.6	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 278.6; % NG
	38	 209.3	 39.9	 172.7	 -92.9	 1.0	 100.0	 1	 278.6	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 278.6; % COW
	38	 195.0	 45.1	 195.2	 -105.0	 1.0	 100.0	 1	 315.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 315.0; % NG
	38	 195.0	 45.1	 195.2	 -105.0	 1.0	 100.0	 1	 315.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 315.0; % NG
	39	 209.3	 39.9	 172.7	 -92.9	 1.0	 100.0	 1	 278.6	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 278.6; % NG
	39	 209.3	 39.9	 172.7	 -92.9	 1.0	 100.0	 1	 278.6	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 278.6; % NG
	39	 195.0	 45.1	 195.2	 -105.0	 1.0	 100.0	 1	 315.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 315.0; % NG
	40	 17.0	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % COW
	40	 20.6	 3.9	 16.9	 -9.1	 1.0	 100.0	 1	 27.2	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.2; % NG
	40	 14.0	 4.8	 17.3	 -7.7	 1.0	 100.0	 1	 23.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % PEL
	40	 61.265	 12.98	 54.13	 -28.17	 1.0	 100.0	 1	 84.53	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5333; % NG
	40	 61.265	 12.98	 54.13	 -28.17	 1.0	 100.0	 1	 84.53	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5333; % NG
	40	 61.265	 12.98	 54.13	 -28.17	 1.0	 100.0	 1	 84.53	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5333; % PEL
	40	 138.1	 26.65	 115.4	 -62.1	 1.0	 100.0	 1	 186.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 186.2; % PEL
	41	 262.75	 35.9	 230.3	 -158.5	 1.0	 100.0	 1	 475.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 475.5; % COW
	41	 170.5	 18.2	 116.7	 -80.3	 1.0	 100.0	 1	 241.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 241.0; % NG
	41	 170.5	 18.2	 116.7	 -80.3	 1.0	 100.0	 1	 241.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 241.0; % NG
	41	 496.3	 0.0	 211.2	 -211.2	 1.0	 100.0	 1	 642.6	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 642.6; % COW
	42	 180.0	 0.0	 77.2	 -77.2	 1.0	 100.0	 1	 235.0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 235.0; % NG
	42	 180.0	 0.0	 77.2	 -77.2	 1.0	 100.0	 1	 235.0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 235.0; % COW
	42	 180.0	 0.0	 77.2	 -77.2	 1.0	 100.0	 1	 235.0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 235.0; % COW
	42	 180.0	 0.0	 77.2	 -77.2	 1.0	 100.0	 1	 235.0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 235.0; % NG
	43	 172.5	 0.0	 75.6	 -75.6	 1.0	 100.0	 1	 230.0	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.0; % NG
	43	 97.5	 0.0	 42.7	 -42.7	 1.0	 100.0	 1	 130.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0; % COW
	44	 154.0	 28.6	 123.9	 -66.7	 1.0	 100.0	 1	 200.0	 108.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	45	 98.0	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % COW
	47	 106.85	 0.0	 32.3	 -32.3	 1.0	 100.0	 1	 128.7	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 128.7; % COW
	47	 106.85	 0.0	 32.3	 -32.3	 1.0	 100.0	 1	 128.7	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 128.7; % NG
	47	 79.35	 0.0	 32.3	 -32.3	 1.0	 100.0	 1	 128.7	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 128.7; % NG
	50	 37.0	 5.2	 33.4	 -23.0	 1.0	 100.0	 1	 69.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % PEL
	51	 9.15	 2.15	 7.73	 -3.43	 1.0	 100.0	 1	 10.3	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.3; % NG
	51	 9.15	 2.15	 7.73	 -3.43	 1.0	 100.0	 1	 10.3	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.3; % PEL
	51	 9.15	 2.15	 7.73	 -3.43	 1.0	 100.0	 1	 10.3	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.3; % NG
	51	 9.15	 2.15	 7.73	 -3.43	 1.0	 100.0	 1	 10.3	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.3; % NG
	51	 9.15	 2.15	 7.73	 -3.43	 1.0	 100.0	 1	 10.3	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.3; % NG
	51	 9.15	 2.15	 7.73	 -3.43	 1.0	 100.0	 1	 10.3	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.3; % NG
	52	 71.8	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % NG
	52	 42.5	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % PEL
	52	 42.5	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % NG
	53	 51.45	 8.3	 35.9	 -19.3	 1.0	 100.0	 1	 57.9	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.9; % NG
	53	 18.55	 3.9	 16.8	 -9.0	 1.0	 100.0	 1	 27.1	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.1; % COW
	54	 30.35	 11.2	 40.3	 -17.9	 1.0	 100.0	 1	 53.7	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.7; % NG
	56	 32.5	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	56	 32.5	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % PEL
	56	 32.5	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % PEL
	57	 9.6	 2.035	 8.8	 -4.73	 1.0	 100.0	 1	 14.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2; % COW
	57	 9.6	 2.035	 8.8	 -4.73	 1.0	 100.0	 1	 14.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2; % PEL
	57	 9.6	 2.035	 8.8	 -4.73	 1.0	 100.0	 1	 14.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2; % PEL
	58	 32.85	 0.0	 13.4	 -13.4	 1.0	 100.0	 1	 40.7	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.7; % NG
	58	 32.85	 0.0	 13.4	 -13.4	 1.0	 100.0	 1	 40.7	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.7; % COW
	58	 32.85	 0.0	 13.4	 -13.4	 1.0	 100.0	 1	 40.7	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.7; % NG
	58	 29.7	 0.0	 17.6	 -17.6	 1.0	 100.0	 1	 53.4	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.4; % NG
	59	 24.15	 5.8	 25.0	 -13.4	 1.0	 100.0	 1	 40.3	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.3; % NG
	60	 21.5	 2.6	 16.5	 -11.3	 1.0	 100.0	 1	 34.0	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.0; % NG
	60	 35.25	 4.85	 31.2	 -21.5	 1.0	 100.0	 1	 64.5	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.5; % NG
	61	 12.1	 2.45	 10.45	 -5.55	 1.0	 100.0	 1	 16.7	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.7; % COW
	61	 12.1	 2.45	 10.45	 -5.55	 1.0	 100.0	 1	 16.7	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.7; % NG
	62	 6.665	 2.3	 8.27	 -3.67	 1.0	 100.0	 1	 11.0	 2.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0; % NG
	62	 6.665	 2.3	 8.27	 -3.67	 1.0	 100.0	 1	 11.0	 2.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0; % NG
	62	 6.665	 2.3	 8.27	 -3.67	 1.0	 100.0	 1	 11.0	 2.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0; % NG
	63	 5.915	 2.265	 8.13	 -3.6	 1.0	 100.0	 1	 10.83	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8333; % NG
	63	 5.915	 2.265	 8.13	 -3.6	 1.0	 100.0	 1	 10.83	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8333; % NG
	63	 5.915	 2.265	 8.13	 -3.6	 1.0	 100.0	 1	 10.83	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8333; % NG
	64	 17.0	 1.95	 12.6	 -8.7	 1.0	 100.0	 1	 26.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.0; % PEL
	64	 17.0	 1.95	 12.6	 -8.7	 1.0	 100.0	 1	 26.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.0; % COW
	65	 4.4	 0.975	 4.22	 -2.27	 1.0	 100.0	 1	 6.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8; % PEL
	65	 6.0	 1.575	 6.8	 -3.65	 1.0	 100.0	 1	 11.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0; % NG
	65	 4.4	 0.975	 4.22	 -2.27	 1.0	 100.0	 1	 6.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8; % PEL
	65	 4.4	 0.975	 4.22	 -2.27	 1.0	 100.0	 1	 6.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8; % NG
	65	 4.4	 0.975	 4.22	 -2.27	 1.0	 100.0	 1	 6.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8; % NG
	65	 4.4	 0.975	 4.22	 -2.27	 1.0	 100.0	 1	 6.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8; % PEL
	65	 4.4	 0.975	 4.22	 -2.27	 1.0	 100.0	 1	 6.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8; % NG
	65	 9.25	 1.8	 7.75	 -4.15	 1.0	 100.0	 1	 12.5	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5; % COW
	65	 9.25	 1.8	 7.75	 -4.15	 1.0	 100.0	 1	 12.5	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5; % NG
	65	 6.0	 1.575	 6.8	 -3.65	 1.0	 100.0	 1	 11.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0; % NG
	66	 21.85	 5.15	 18.5	 -8.2	 1.0	 100.0	 1	 24.7	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7; % PEL
	67	 82.5	 7.15	 46.0	 -31.7	 1.0	 100.0	 1	 95.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0; % NG
	67	 13.0	 1.7	 11.1	 -7.7	 1.0	 100.0	 1	 23.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % NG
	67	 25.65	 4.05	 17.5	 -9.4	 1.0	 100.0	 1	 28.3	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.3; % NG
	68	 3.865	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 7.63	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.6333; % NG
	68	 3.865	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 7.63	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.6333; % PEL
	68	 3.865	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 7.63	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.6333; % PEL
	69	 35.8	 0.0	 14.3	 -14.3	 1.0	 100.0	 1	 43.6	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.6; % NG
	69	 18.65	 3.05	 13.2	 -7.1	 1.0	 100.0	 1	 21.3	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.3; % COW
	71	 18.05	 3.05	 13.1	 -7.0	 1.0	 100.0	 1	 21.1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.1; % NG
	75	 144.6	 26.4	 114.2	 -61.4	 1.0	 100.0	 1	 184.2	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.2; % NG
	75	 144.6	 26.4	 114.2	 -61.4	 1.0	 100.0	 1	 184.2	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.2; % NG
	75	 135.25	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % COW
	77	 121.4	 25.45	 110.2	 -59.3	 1.0	 100.0	 1	 177.8	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 177.8; % NG
	77	 121.4	 25.45	 110.2	 -59.3	 1.0	 100.0	 1	 177.8	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 177.8; % NG
	77	 117.3	 27.85	 120.6	 -64.9	 1.0	 100.0	 1	 194.6	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 194.6; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % PEL
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % PEL
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % PEL
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % PEL
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % PEL
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % PEL
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % PEL
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	78	 2.805	 0.335	 2.15	 -1.48	 1.0	 100.0	 1	 4.45	 1.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4516; % NG
	79	 53.8	 9.2	 52.6	 -34.2	 1.0	 100.0	 1	 102.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 102.6; % COW
	82	 28.5	 0.0	 22.5	 -22.5	 1.0	 100.0	 1	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	83	 46.25	 7.8	 33.8	 -18.2	 1.0	 100.0	 1	 54.5	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.5; % NG
	83	 46.25	 7.8	 33.8	 -18.2	 1.0	 100.0	 1	 54.5	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.5; % NG
	83	 46.25	 7.8	 33.8	 -18.2	 1.0	 100.0	 1	 54.5	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.5; % NG
	84	 346.2	 0.0	 249.9	 -249.9	 1.0	 100.0	 1	 632.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 632.4; % COW
	84	 71.8	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % NG
	84	 30.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % PEL
	84	 30.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	85	 26.75	 3.65	 23.5	 -16.2	 1.0	 100.0	 1	 48.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.5; % NG
	85	 36.7	 9.8	 42.4	 -22.8	 1.0	 100.0	 1	 68.4	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.4; % NG
	86	 31.85	 6.55	 28.3	 -15.2	 1.0	 100.0	 1	 45.7	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.7; % NG
	87	 5.795	 0.565	 3.6	 -2.47	 1.0	 100.0	 1	 7.42	 4.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.4167; % NG
	87	 5.795	 0.565	 3.6	 -2.47	 1.0	 100.0	 1	 7.42	 4.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.4167; % COW
	87	 5.795	 0.565	 3.6	 -2.47	 1.0	 100.0	 1	 7.42	 4.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.4167; % PEL
	87	 5.795	 0.565	 3.6	 -2.47	 1.0	 100.0	 1	 7.42	 4.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.4167; % COW
	87	 5.795	 0.565	 3.6	 -2.47	 1.0	 100.0	 1	 7.42	 4.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.4167; % PEL
	87	 5.795	 0.565	 3.6	 -2.47	 1.0	 100.0	 1	 7.42	 4.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.4167; % NG
	88	 21.0	 0.0	 16.6	 -16.6	 1.0	 100.0	 1	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	89	 29.8	 3.0	 19.2	 -13.2	 1.0	 100.0	 1	 39.6	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.6; % COW
	90	 28.8	 3.0	 19.2	 -13.2	 1.0	 100.0	 1	 39.6	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.6; % NG
	91	 26.25	 7.8	 28.1	 -12.5	 1.0	 100.0	 1	 37.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % PEL
	93	 22.5	 2.25	 14.5	 -10.0	 1.0	 100.0	 1	 30.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0; % NG
	93	 22.5	 2.25	 14.5	 -10.0	 1.0	 100.0	 1	 30.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0; % NG
	94	 1.55	 0.0	 0.6	 -0.6	 1.0	 100.0	 1	 2.23	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2308; % PEL
	94	 1.55	 0.0	 0.6	 -0.6	 1.0	 100.0	 1	 2.23	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2308; % PEL
	94	 1.55	 0.0	 0.6	 -0.6	 1.0	 100.0	 1	 2.23	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2308; % PEL
	94	 1.55	 0.0	 0.6	 -0.6	 1.0	 100.0	 1	 2.23	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2308; % PEL
	94	 1.55	 0.0	 0.6	 -0.6	 1.0	 100.0	 1	 2.23	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2308; % PEL
	94	 1.55	 0.0	 0.6	 -0.6	 1.0	 100.0	 1	 2.23	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2308; % PEL
	94	 1.55	 0.0	 0.6	 -0.6	 1.0	 100.0	 1	 2.23	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2308; % PEL
	94	 1.55	 0.0	 0.6	 -0.6	 1.0	 100.0	 1	 2.23	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2308; % PEL
	94	 1.55	 0.0	 0.6	 -0.6	 1.0	 100.0	 1	 2.23	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2308; % COW
	94	 1.55	 0.0	 0.6	 -0.6	 1.0	 100.0	 1	 2.23	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2308; % NG
	94	 1.55	 0.0	 0.6	 -0.6	 1.0	 100.0	 1	 2.23	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2308; % PEL
	94	 1.55	 0.0	 0.6	 -0.6	 1.0	 100.0	 1	 2.23	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2308; % PEL
	94	 1.55	 0.0	 0.6	 -0.6	 1.0	 100.0	 1	 2.23	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2308; % PEL
	95	 8.125	 2.05	 8.85	 -4.75	 1.0	 100.0	 1	 14.25	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.25; % NG
	95	 8.125	 2.05	 8.85	 -4.75	 1.0	 100.0	 1	 14.25	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.25; % COW
	96	 7.2	 1.075	 6.9	 -4.75	 1.0	 100.0	 1	 14.2	 0.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2; % NG
	96	 7.2	 1.075	 6.9	 -4.75	 1.0	 100.0	 1	 14.2	 0.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2; % NG
	98	 16.75	 3.9	 17.0	 -9.2	 1.0	 100.0	 1	 27.5	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % NG
	99	 2.965	 0.745	 2.97	 -1.48	 1.0	 100.0	 1	 4.43	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4333; % NG
	99	 2.965	 0.745	 2.97	 -1.48	 1.0	 100.0	 1	 4.43	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4333; % NG
	99	 2.965	 0.745	 2.97	 -1.48	 1.0	 100.0	 1	 4.43	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4333; % NG
	99	 2.965	 0.745	 2.97	 -1.48	 1.0	 100.0	 1	 4.43	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4333; % NG
	99	 2.965	 0.745	 2.97	 -1.48	 1.0	 100.0	 1	 4.43	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4333; % NG
	99	 2.965	 0.745	 2.97	 -1.48	 1.0	 100.0	 1	 4.43	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4333; % PEL
	100	 12.75	 0.0	 10.1	 -10.1	 1.0	 100.0	 1	 25.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	101	 15.15	 3.65	 15.7	 -8.4	 1.0	 100.0	 1	 25.3	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.3; % PEL
	102	 17.0	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	102	 17.0	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	102	 19.0	 2.25	 14.5	 -10.0	 1.0	 100.0	 1	 30.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0; % NG
	104	 14.0	 3.15	 13.6	 -7.3	 1.0	 100.0	 1	 22.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % COW
	105	 801.0	 0.0	 408.2	 -408.2	 1.0	 100.0	 1	 1242.0	 360.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	106	 237.0	 31.25	 200.5	 -138.0	 1.0	 100.0	 1	 414.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 414.0; % NG
	107	 207.5	 37.2	 161.1	 -86.7	 1.0	 100.0	 1	 260.0	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 260.0; % NG
	107	 207.5	 37.2	 161.1	 -86.7	 1.0	 100.0	 1	 260.0	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 260.0; % NG
	107	 177.5	 38.65	 167.3	 -90.0	 1.0	 100.0	 1	 270.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 270.0; % NG
	108	 152.15	 17.7	 113.5	 -78.1	 1.0	 100.0	 1	 234.3	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 234.3; % COW
	108	 145.3	 26.55	 115.0	 -61.9	 1.0	 100.0	 1	 185.6	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.6; % NG
	108	 145.3	 26.55	 115.0	 -61.9	 1.0	 100.0	 1	 185.6	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.6; % NG
	109	 42.5	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	109	 31.5	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % COW
	109	 31.5	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	109	 13.1	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % PEL
	110	 11.3	 2.675	 11.55	 -6.2	 1.0	 100.0	 1	 18.6	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.6; % COW
	110	 11.3	 2.675	 11.55	 -6.2	 1.0	 100.0	 1	 18.6	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.6; % PEL
	110	 96.8	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % NG
	110	 282.8	 26.1	 167.4	 -115.2	 1.0	 100.0	 1	 345.6	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 345.6; % NG
	112	 20.0	 5.25	 18.8	 -8.3	 1.0	 100.0	 1	 25.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	113	 12.0	 0.0	 9.5	 -9.5	 1.0	 100.0	 1	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	114	 11.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	115	 17.0	 4.15	 15.0	 -6.7	 1.0	 100.0	 1	 20.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	116	 163.0	 40.85	 147.0	 -65.3	 1.0	 100.0	 1	 196.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.0; % NG
	116	 163.0	 40.85	 147.0	 -65.3	 1.0	 100.0	 1	 196.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.0; % NG
	116	 102.0	 42.5	 153.0	 -68.0	 1.0	 100.0	 1	 204.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0; % NG
	117	 127.15	 25.65	 111.1	 -59.8	 1.0	 100.0	 1	 179.3	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.3; % NG
	117	 74.1	 13.35	 57.8	 -31.1	 1.0	 100.0	 1	 93.2	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.2; % COW
	118	 43.0	 9.6	 34.5	 -15.3	 1.0	 100.0	 1	 46.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % NG
	118	 43.0	 9.6	 34.5	 -15.3	 1.0	 100.0	 1	 46.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % NG
	118	 44.0	 10.0	 36.0	 -16.0	 1.0	 100.0	 1	 48.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.0; % PEL
	118	 97.5	 17.9	 77.5	 -41.7	 1.0	 100.0	 1	 125.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	118	 97.5	 17.9	 77.5	 -41.7	 1.0	 100.0	 1	 125.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	118	 97.5	 17.9	 77.5	 -41.7	 1.0	 100.0	 1	 125.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	119	 60.4	 11.85	 51.3	 -27.6	 1.0	 100.0	 1	 82.8	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.8; % NG
	119	 60.4	 11.85	 51.3	 -27.6	 1.0	 100.0	 1	 82.8	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.8; % NG
	119	 59.3	 12.7	 54.9	 -29.5	 1.0	 100.0	 1	 88.6	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.6; % NG
	120	 66.4	 11.85	 51.3	 -27.6	 1.0	 100.0	 1	 82.8	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.8; % NG
	120	 66.4	 11.85	 51.3	 -27.6	 1.0	 100.0	 1	 82.8	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.8; % NG
	120	 64.3	 12.7	 54.9	 -29.5	 1.0	 100.0	 1	 88.6	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.6; % NG
	124	 32.9	 8.75	 31.4	 -13.9	 1.0	 100.0	 1	 41.8	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	125	 8.8	 2.835	 10.2	 -4.53	 1.0	 100.0	 1	 13.6	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6; % PEL
	125	 8.8	 2.835	 10.2	 -4.53	 1.0	 100.0	 1	 13.6	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6; % NG
	125	 8.8	 2.835	 10.2	 -4.53	 1.0	 100.0	 1	 13.6	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6; % PEL
	126	 7.4	 0.0	 5.6	 -5.6	 1.0	 100.0	 1	 11.87	 2.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8667; % COW
	126	 7.4	 0.0	 5.6	 -5.6	 1.0	 100.0	 1	 11.87	 2.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8667; % NG
	126	 7.4	 0.0	 5.6	 -5.6	 1.0	 100.0	 1	 11.87	 2.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8667; % NG
	128	 9.6	 2.335	 8.4	 -3.73	 1.0	 100.0	 1	 11.2	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % PEL
	128	 9.6	 2.335	 8.4	 -3.73	 1.0	 100.0	 1	 11.2	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % PEL
	128	 9.6	 2.335	 8.4	 -3.73	 1.0	 100.0	 1	 11.2	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % NG
	129	 15.25	 3.65	 15.8	 -8.5	 1.0	 100.0	 1	 25.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5; % PEL
	130	 2.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 4.2	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.2; % PEL
	130	 2.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 4.2	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.2; % NG
	130	 2.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 4.2	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.2; % NG
	130	 2.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 4.2	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.2; % NG
	130	 2.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 4.2	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.2; % NG
	130	 2.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 4.2	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.2; % NG
	131	 17.35	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 21.5	 13.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.5; % PEL
	3502	 649.5	 270.65	 974.3	 -433.0	 1.0	 100.0	 1	 1299.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	3503	 506.0	 210.85	 759.0	 -337.3	 1.0	 100.0	 1	 1012.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	3504	 473.4	 0.0	 370.4	 -370.4	 1.0	 100.0	 1	 901.8	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 901.8; % NUC
	3504	 473.4	 0.0	 370.4	 -370.4	 1.0	 100.0	 1	 901.8	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 901.8; % COW
	3505	 442.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 883.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 883.0; % COW
	3506	 441.0	 183.75	 661.5	 -294.0	 1.0	 100.0	 1	 882.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	3507	 402.55	 49.45	 317.3	 -218.4	 1.0	 100.0	 1	 655.1	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 655.1; % COW
	3508	 667.15	 95.05	 609.9	 -419.8	 1.0	 100.0	 1	 1259.3	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	3508	 373.4	 91.95	 397.8	 -213.9	 1.0	 100.0	 1	 641.8	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	3509	 360.5	 46.9	 300.8	 -207.0	 1.0	 100.0	 1	 621.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 621.0; % COW
	3509	 350.5	 46.9	 300.8	 -207.0	 1.0	 100.0	 1	 621.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 621.0; % COW
	3510	 380.5	 46.9	 300.8	 -207.0	 1.0	 100.0	 1	 621.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 621.0; % COW
	3510	 380.5	 46.9	 300.8	 -207.0	 1.0	 100.0	 1	 621.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 621.0; % COW
	3511	 452.5	 0.0	 261.6	 -261.6	 1.0	 100.0	 1	 614.0	 291.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	3512	 79.7	 0.0	 48.8	 -48.8	 1.0	 100.0	 1	 148.4	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 148.4; % NG
	3512	 150.75	 0.0	 98.15	 -98.15	 1.0	 100.0	 1	 223.0	 78.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 223.0; % NG
	3512	 150.75	 0.0	 98.15	 -98.15	 1.0	 100.0	 1	 223.0	 78.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 223.0; % NG
	3512	 70.1	 7.2	 46.1	 -31.7	 1.0	 100.0	 1	 95.2	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.2; % NG
	3512	 70.1	 7.2	 46.1	 -31.7	 1.0	 100.0	 1	 95.2	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.2; % NG
	3512	 70.1	 7.2	 46.1	 -31.7	 1.0	 100.0	 1	 95.2	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.2; % NG
	3513	 213.5	 29.2	 187.4	 -129.0	 1.0	 100.0	 1	 387.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 387.0; % NG
	3513	 213.5	 29.2	 187.4	 -129.0	 1.0	 100.0	 1	 387.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 387.0; % COW
	3513	 213.5	 29.2	 187.4	 -129.0	 1.0	 100.0	 1	 387.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 387.0; % NG
	3513	 208.5	 29.2	 187.4	 -129.0	 1.0	 100.0	 1	 387.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 387.0; % NG
	3514	 342.75	 40.45	 259.4	 -178.5	 1.0	 100.0	 1	 535.5	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 535.5; % NG
	3514	 216.0	 71.25	 256.5	 -114.0	 1.0	 100.0	 1	 342.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 342.0; % NG
	3515	 101.5	 26.9	 116.5	 -62.7	 1.0	 100.0	 1	 188.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.0; % NG
	3515	 22.21	 3.34	 15.32	 -8.64	 1.0	 100.0	 1	 25.93	 18.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.9333; % COW
	3515	 22.21	 3.34	 15.32	 -8.64	 1.0	 100.0	 1	 25.93	 18.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.9333; % NG
	3515	 22.21	 3.34	 15.32	 -8.64	 1.0	 100.0	 1	 25.93	 18.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.9333; % NG
	3515	 22.21	 3.34	 15.32	 -8.64	 1.0	 100.0	 1	 25.93	 18.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.9333; % NG
	3515	 22.21	 3.34	 15.32	 -8.64	 1.0	 100.0	 1	 25.93	 18.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.9333; % NG
	3515	 101.5	 26.9	 116.5	 -62.7	 1.0	 100.0	 1	 188.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.0; % NG
	3515	 22.21	 3.34	 15.32	 -8.64	 1.0	 100.0	 1	 25.93	 18.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.9333; % NG
	3515	 22.21	 3.34	 15.32	 -8.64	 1.0	 100.0	 1	 25.93	 18.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.9333; % PEL
	3515	 22.21	 3.34	 15.32	 -8.64	 1.0	 100.0	 1	 25.93	 18.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.9333; % PEL
	3515	 22.21	 3.34	 15.32	 -8.64	 1.0	 100.0	 1	 25.93	 18.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.9333; % NG
	3515	 22.21	 3.34	 15.32	 -8.64	 1.0	 100.0	 1	 25.93	 18.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.9333; % NG
	3515	 22.21	 3.34	 15.32	 -8.64	 1.0	 100.0	 1	 25.93	 18.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.9333; % NG
	3515	 22.21	 3.34	 15.32	 -8.64	 1.0	 100.0	 1	 25.93	 18.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.9333; % NG
	3516	 115.5	 20.2	 87.4	 -47.0	 1.0	 100.0	 1	 141.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 141.0; % PEL
	3516	 115.5	 20.2	 87.4	 -47.0	 1.0	 100.0	 1	 141.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 141.0; % NG
	3516	 115.5	 20.2	 87.4	 -47.0	 1.0	 100.0	 1	 141.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 141.0; % COW
	3516	 247.0	 42.95	 185.9	 -100.0	 1.0	 100.0	 1	 300.0	 194.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.0; % COW
	3516	 247.0	 42.95	 185.9	 -100.0	 1.0	 100.0	 1	 300.0	 194.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.0; % COW
	3516	 247.0	 42.95	 185.9	 -100.0	 1.0	 100.0	 1	 300.0	 194.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.0; % NG
	3517	 125.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 250.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 250.0; % NG
	3517	 125.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 250.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 250.0; % NG
	3517	 125.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 250.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 250.0; % NG
	3517	 125.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 250.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 250.0; % NG
	3518	 116.35	 0.0	 50.2	 -50.2	 1.0	 100.0	 1	 152.7	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 152.7; % NG
	3518	 160.6	 0.0	 64.5	 -64.5	 1.0	 100.0	 1	 196.2	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.2; % NG
	3519	 132.5	 41.65	 150.0	 -66.7	 1.0	 100.0	 1	 200.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	3519	 100.6	 32.55	 117.2	 -52.1	 1.0	 100.0	 1	 156.2	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.2; % NG
	3519	 145.0	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	3519	 145.0	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	3520	 120.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 180.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	3520	 225.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 376.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 376.0; % NG
	3520	 231.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 387.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 387.0; % NG
	3520	 231.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 387.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 387.0; % NG
	3521	 63.65	 13.375	 56.7	 -29.95	 1.0	 100.0	 1	 89.8	 37.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.8; % NG
	3521	 63.65	 13.375	 56.7	 -29.95	 1.0	 100.0	 1	 89.8	 37.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.8; % NG
	3521	 47.5	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % NG
	3521	 47.5	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % NG
	3521	 24.35	 4.85	 20.9	 -11.2	 1.0	 100.0	 1	 33.7	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.7; % NG
	3521	 24.35	 4.85	 20.9	 -11.2	 1.0	 100.0	 1	 33.7	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.7; % NG
	3521	 20.5	 5.15	 22.3	 -12.0	 1.0	 100.0	 1	 36.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0; % NG
	3522	 134.5	 25.6	 110.9	 -59.7	 1.0	 100.0	 1	 179.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.0; % COW
	3522	 134.5	 25.6	 110.9	 -59.7	 1.0	 100.0	 1	 179.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.0; % COW
	3522	 215.35	 42.35	 183.3	 -98.6	 1.0	 100.0	 1	 295.7	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 295.7; % NG
	3523	 17.5	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	3523	 26.45	 6.15	 26.6	 -14.3	 1.0	 100.0	 1	 42.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.9; % NG
	3523	 26.45	 6.15	 26.6	 -14.3	 1.0	 100.0	 1	 42.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.9; % NG
	3523	 26.45	 6.15	 26.6	 -14.3	 1.0	 100.0	 1	 42.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.9; % NG
	3523	 26.45	 6.15	 26.6	 -14.3	 1.0	 100.0	 1	 42.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.9; % NG
	3523	 26.45	 6.15	 26.6	 -14.3	 1.0	 100.0	 1	 42.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.9; % NG
	3523	 26.45	 6.15	 26.6	 -14.3	 1.0	 100.0	 1	 42.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.9; % NG
	3523	 130.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	3523	 72.5	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % NG
	3523	 17.5	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	3523	 17.5	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	3523	 14.05	 3.05	 13.1	 -7.0	 1.0	 100.0	 1	 21.1	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.1; % NG
	3523	 14.05	 3.05	 13.1	 -7.0	 1.0	 100.0	 1	 21.1	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.1; % NG
	3523	 14.5	 3.15	 13.6	 -7.3	 1.0	 100.0	 1	 22.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	3523	 14.5	 3.15	 13.6	 -7.3	 1.0	 100.0	 1	 22.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	3523	 26.45	 6.15	 26.6	 -14.3	 1.0	 100.0	 1	 42.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.9; % PEL
	3523	 26.45	 6.15	 26.6	 -14.3	 1.0	 100.0	 1	 42.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.9; % NG
	3524	 135.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	3524	 135.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	3524	 187.5	 36.5	 158.0	 -85.0	 1.0	 100.0	 1	 255.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 255.0; % NG
	3525	 85.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 170.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	3525	 85.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 170.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	3525	 94.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 188.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.0; % NG
	3526	 129.6	 35.25	 126.9	 -56.4	 1.0	 100.0	 1	 169.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 169.2; % COW
	3526	 129.6	 35.25	 126.9	 -56.4	 1.0	 100.0	 1	 169.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 169.2; % COW
	3526	 129.6	 35.25	 126.9	 -56.4	 1.0	 100.0	 1	 169.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 169.2; % NG
	3526	 129.75	 35.3	 127.1	 -56.5	 1.0	 100.0	 1	 169.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 169.5; % COW
	3526	 124.75	 18.3	 104.8	 -68.2	 1.0	 100.0	 1	 204.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.5; % NG
	3526	 124.75	 18.3	 104.8	 -68.2	 1.0	 100.0	 1	 204.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.5; % NG
	3527	 108.6	 19.3	 94.3	 -55.7	 1.0	 100.0	 1	 167.2	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.2; % NG
	3527	 102.65	 22.2	 96.2	 -51.8	 1.0	 100.0	 1	 155.3	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 155.3; % NG
	3528	 17.845	 2.95	 12.76	 -6.86	 1.0	 100.0	 1	 20.59	 15.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.5857; % PEL
	3528	 30.25	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 18.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % NG
	3528	 30.25	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 18.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % NG
	3528	 30.25	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 18.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % PEL
	3528	 30.25	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 18.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % NG
	3528	 30.25	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 18.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % PEL
	3528	 30.25	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 18.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % NG
	3528	 30.25	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 18.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % NG
	3528	 30.25	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 18.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % NG
	3528	 30.25	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 18.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % NG
	3528	 30.25	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 18.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % NG
	3528	 17.845	 2.95	 12.76	 -6.86	 1.0	 100.0	 1	 20.59	 15.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.5857; % NG
	3528	 20.7	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 17.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % NG
	3528	 20.55	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 17.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % NG
	3528	 20.4	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % NG
	3528	 20.35	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 16.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % PEL
	3528	 17.845	 2.95	 12.76	 -6.86	 1.0	 100.0	 1	 20.59	 15.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.5857; % NG
	3528	 17.845	 2.95	 12.76	 -6.86	 1.0	 100.0	 1	 20.59	 15.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.5857; % NG
	3528	 17.845	 2.95	 12.76	 -6.86	 1.0	 100.0	 1	 20.59	 15.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.5857; % PEL
	3528	 17.845	 2.95	 12.76	 -6.86	 1.0	 100.0	 1	 20.59	 15.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.5857; % COW
	3528	 17.845	 2.95	 12.76	 -6.86	 1.0	 100.0	 1	 20.59	 15.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.5857; % NG
	3528	 30.25	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 18.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % NG
	3528	 30.25	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 18.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % NG
	3529	 13.16	 4.505	 16.23	 -7.22	 1.0	 100.0	 1	 21.65	 4.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.65; % NG
	3529	 15.3	 5.35	 19.2	 -8.5	 1.0	 100.0	 1	 25.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.6; % COW
	3529	 13.16	 4.505	 16.23	 -7.22	 1.0	 100.0	 1	 21.65	 4.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.65; % NG
	3529	 13.16	 4.505	 16.23	 -7.22	 1.0	 100.0	 1	 21.65	 4.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.65; % PEL
	3529	 13.16	 4.505	 16.23	 -7.22	 1.0	 100.0	 1	 21.65	 4.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.65; % NG
	3529	 13.16	 4.505	 16.23	 -7.22	 1.0	 100.0	 1	 21.65	 4.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.65; % PEL
	3529	 13.16	 4.505	 16.23	 -7.22	 1.0	 100.0	 1	 21.65	 4.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.65; % PEL
	3529	 15.3	 5.35	 19.2	 -8.5	 1.0	 100.0	 1	 25.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.6; % NG
	3529	 15.3	 5.35	 19.2	 -8.5	 1.0	 100.0	 1	 25.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.6; % NG
	3529	 15.3	 5.35	 19.2	 -8.5	 1.0	 100.0	 1	 25.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.6; % PEL
	3530	 66.15	 0.0	 55.6	 -55.6	 1.0	 100.0	 1	 126.0	 6.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	3531	 37.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	3531	 37.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	3531	 105.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 121.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0; % NG
	3531	 105.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 121.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0; % NG
	3532	 71.25	 13.3	 64.6	 -38.0	 1.0	 100.0	 1	 114.0	 28.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0; % NG
	3532	 71.25	 13.3	 64.6	 -38.0	 1.0	 100.0	 1	 114.0	 28.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0; % NG
	3532	 49.55	 4.15	 26.6	 -18.3	 1.0	 100.0	 1	 55.0	 44.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0; % PEL
	3532	 47.5	 4.15	 26.6	 -18.3	 1.0	 100.0	 1	 55.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0; % NG
	3533	 76.0	 16.05	 69.4	 -37.3	 1.0	 100.0	 1	 112.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.0; % NG
	3534	 56.0	 0.0	 49.4	 -49.4	 1.0	 100.0	 1	 112.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	3535	 28.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 56.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.0; % NG
	3535	 54.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 108.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.0; % NG
	3536	 55.91	 0.0	 47.0	 -47.0	 1.0	 100.0	 1	 106.5	 5.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	3537	 42.525	 0.0	 35.7	 -35.7	 1.0	 100.0	 1	 81.0	 4.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	3537	 50.25	 0.0	 44.3	 -44.3	 1.0	 100.0	 1	 100.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	3538	 50.25	 0.0	 44.3	 -44.3	 1.0	 100.0	 1	 100.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	3540	 48.75	 0.0	 43.0	 -43.0	 1.0	 100.0	 1	 97.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	3541	 151.3	 31.2	 134.9	 -72.5	 1.0	 100.0	 1	 217.6	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.6; % NG
	3541	 151.3	 31.2	 134.9	 -72.5	 1.0	 100.0	 1	 217.6	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.6; % NG
	3541	 65.5	 20.0	 72.0	 -32.0	 1.0	 100.0	 1	 96.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.0; % NG
	3541	 65.5	 20.0	 72.0	 -32.0	 1.0	 100.0	 1	 96.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.0; % NG
	3542	 67.6	 7.2	 46.1	 -31.7	 1.0	 100.0	 1	 95.2	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.2; % NG
	3542	 67.6	 7.2	 46.1	 -31.7	 1.0	 100.0	 1	 95.2	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.2; % NG
	3542	 52.6	 7.2	 46.1	 -31.7	 1.0	 100.0	 1	 95.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.2; % NG
	3543	 46.5	 7.9	 34.1	 -18.3	 1.0	 100.0	 1	 55.0	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0; % NG
	3543	 80.5	 13.15	 57.0	 -30.7	 1.0	 100.0	 1	 92.0	 69.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 92.0; % NG
	3544	 43.75	 0.0	 38.6	 -38.6	 1.0	 100.0	 1	 87.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	3545	 73.8	 16.55	 59.6	 -26.5	 1.0	 100.0	 1	 79.5	 68.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 79.5; % NG
	3545	 72.95	 16.55	 59.6	 -26.5	 1.0	 100.0	 1	 79.5	 66.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 79.5; % NG
	3545	 72.7	 16.55	 59.6	 -26.5	 1.0	 100.0	 1	 79.5	 65.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 79.5; % NG
	3547	 93.55	 21.1	 91.2	 -49.0	 1.0	 100.0	 1	 147.1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 147.1; % NG
	3547	 149.7	 34.3	 148.4	 -79.8	 1.0	 100.0	 1	 239.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 239.4; % NG
	3547	 46.0	 10.3	 44.6	 -24.0	 1.0	 100.0	 1	 72.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0; % COW
	3547	 46.75	 10.55	 45.6	 -24.5	 1.0	 100.0	 1	 73.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 73.5; % COW
	3548	 32.8	 2.65	 17.2	 -11.9	 1.0	 100.0	 1	 35.6	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.6; % NG
	3548	 56.25	 5.0	 32.2	 -22.2	 1.0	 100.0	 1	 66.5	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.5; % COW
	3549	 57.5	 5.0	 32.1	 -22.1	 1.0	 100.0	 1	 66.2	 48.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.2; % PEL
	3549	 41.0	 3.6	 23.1	 -15.9	 1.0	 100.0	 1	 47.7	 34.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.7; % PEL
	3550	 55.25	 4.95	 31.7	 -21.8	 1.0	 100.0	 1	 65.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.5; % NG
	3550	 31.1	 2.8	 18.0	 -12.4	 1.0	 100.0	 1	 37.2	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.2; % NG
	3551	 55.6	 4.85	 31.1	 -21.4	 1.0	 100.0	 1	 64.2	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.2; % NG
	3551	 41.35	 3.6	 23.1	 -15.9	 1.0	 100.0	 1	 47.7	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.7; % NG
	3553	 43.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 60.5	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	3554	 40.3	 3.1	 19.7	 -13.5	 1.0	 100.0	 1	 40.6	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.6; % NG
	3554	 44.205	 4.5	 29.0	 -20.0	 1.0	 100.0	 1	 59.9	 28.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.9; % PEL
	3555	 33.35	 12.45	 44.8	 -19.9	 1.0	 100.0	 1	 59.7	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.7; % PEL
	3556	 37.85	 3.15	 20.0	 -13.7	 1.0	 100.0	 1	 41.2	 34.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.2; % COW
	3556	 50.95	 4.35	 27.8	 -19.1	 1.0	 100.0	 1	 57.4	 44.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % NG
	3557	 29.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 57.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % PEL
	3557	 29.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 57.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % NG
	3557	 29.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 57.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % PEL
	3557	 29.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 57.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % NG
	3557	 29.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 57.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % NG
	3557	 29.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 57.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % NG
	3557	 29.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 57.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % PEL
	3557	 29.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 57.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % NG
	3557	 29.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 57.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % PEL
	3557	 29.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 57.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % NG
	3557	 29.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 57.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % COW
	3557	 29.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 57.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % PEL
	3557	 29.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 57.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % NG
	3557	 29.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 57.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % PEL
	3557	 29.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 57.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % NG
	3557	 29.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 57.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % NG
	3558	 49.25	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 41.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % PEL
	3558	 45.9	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 35.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	3558	 48.55	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 40.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	3558	 48.5	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 40.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	3558	 48.4	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 40.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	3558	 47.6	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 38.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	3558	 47.15	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 37.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	3558	 46.75	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 36.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	3558	 46.3	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 35.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	3558	 46.25	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 35.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % PEL
	3559	 36.7	 3.0	 19.1	 -13.1	 1.0	 100.0	 1	 39.4	 34.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.4; % NG
	3559	 50.3	 4.25	 27.4	 -18.9	 1.0	 100.0	 1	 56.6	 44.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.6; % NG
	3560	 38.0	 4.2	 27.1	 -18.7	 1.0	 100.0	 1	 56.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.0; % NG
	3563	 37.0	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	3564	 101.5	 14.2	 91.1	 -62.7	 1.0	 100.0	 1	 188.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.0; % NG
	3564	 101.5	 14.2	 91.1	 -62.7	 1.0	 100.0	 1	 188.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.0; % NG
	3564	 45.0	 4.0	 25.7	 -17.7	 1.0	 100.0	 1	 53.0	 37.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0; % NG
	3564	 45.0	 4.0	 25.7	 -17.7	 1.0	 100.0	 1	 53.0	 37.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0; % NG
	3566	 46.15	 4.0	 25.6	 -17.6	 1.0	 100.0	 1	 52.9	 39.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.9; % NG
	3567	 46.95	 3.95	 25.4	 -17.5	 1.0	 100.0	 1	 52.4	 41.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.4; % NG
	3572	 13.65	 2.335	 10.1	 -5.43	 1.0	 100.0	 1	 16.3	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.3; % NG
	3572	 13.65	 2.335	 10.1	 -5.43	 1.0	 100.0	 1	 16.3	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.3; % NG
	3572	 13.65	 2.335	 10.1	 -5.43	 1.0	 100.0	 1	 16.3	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.3; % NG
	3573	 17.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	3573	 32.4	 6.95	 30.2	 -16.3	 1.0	 100.0	 1	 48.8	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.8; % NG
	3573	 32.4	 6.95	 30.2	 -16.3	 1.0	 100.0	 1	 48.8	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.8; % NG
	3575	 44.85	 3.6	 23.1	 -15.9	 1.0	 100.0	 1	 47.7	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.7; % NG
	3577	 27.5	 9.8	 35.3	 -15.7	 1.0	 100.0	 1	 47.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % NG
	3578	 24.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 47.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % NG
	3578	 24.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 47.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % NG
	3579	 24.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 47.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % PEL
	3579	 24.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 47.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % PEL
	3580	 24.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 47.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % NG
	3581	 24.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 47.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % PEL
	3581	 24.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 47.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % COW
	3582	 24.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 47.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % COW
	3582	 24.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 47.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % PEL
	3583	 24.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 47.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % NG
	3584	 24.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 47.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % NG
	3585	 43.5	 3.55	 22.8	 -15.7	 1.0	 100.0	 1	 47.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % PEL
	3585	 17.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	3586	 35.0	 6.7	 29.1	 -15.7	 1.0	 100.0	 1	 47.0	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % NG
	3588	 39.3	 3.35	 21.6	 -14.9	 1.0	 100.0	 1	 44.6	 34.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.6; % NG
	3588	 37.5	 3.5	 22.3	 -15.3	 1.0	 100.0	 1	 46.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % NG
	3589	 7.265	 1.92	 8.67	 -4.83	 1.0	 100.0	 1	 14.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.5333; % PEL
	3589	 7.265	 1.92	 8.67	 -4.83	 1.0	 100.0	 1	 14.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.5333; % NG
	3589	 7.265	 1.92	 8.67	 -4.83	 1.0	 100.0	 1	 14.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.5333; % NG
	3590	 22.05	 3.2	 20.4	 -14.0	 1.0	 100.0	 1	 42.1	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.1; % NG
	3591	 4.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	3591	 4.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % PEL
	3591	 4.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	3591	 4.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	3591	 4.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % COW
	3592	 34.5	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 42.0	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0; % NG
	3592	 17.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	3594	 32.95	 0.0	 13.4	 -13.4	 1.0	 100.0	 1	 40.9	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.9; % NG
	3594	 16.0	 0.0	 7.2	 -7.2	 1.0	 100.0	 1	 22.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	3595	 21.5	 2.95	 19.1	 -13.2	 1.0	 100.0	 1	 39.5	 3.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.5; % COW
	3596	 13.525	 3.9	 14.05	 -6.25	 1.0	 100.0	 1	 18.75	 8.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.75; % PEL
	3596	 13.525	 3.9	 14.05	 -6.25	 1.0	 100.0	 1	 18.75	 8.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.75; % PEL
	3597	 18.75	 0.0	 14.8	 -14.8	 1.0	 100.0	 1	 37.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	3598	 13.25	 2.65	 11.45	 -6.15	 1.0	 100.0	 1	 18.5	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.5; % PEL
	3598	 13.25	 2.65	 11.45	 -6.15	 1.0	 100.0	 1	 18.5	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.5; % PEL
	3599	 3.46	 1.255	 4.53	 -2.02	 1.0	 100.0	 1	 6.05	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.05; % PEL
	3599	 3.46	 1.255	 4.53	 -2.02	 1.0	 100.0	 1	 6.05	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.05; % NG
	3599	 3.46	 1.255	 4.53	 -2.02	 1.0	 100.0	 1	 6.05	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.05; % NG
	3599	 3.46	 1.255	 4.53	 -2.02	 1.0	 100.0	 1	 6.05	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.05; % NG
	3599	 3.46	 1.255	 4.53	 -2.02	 1.0	 100.0	 1	 6.05	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.05; % NG
	3599	 3.46	 1.255	 4.53	 -2.02	 1.0	 100.0	 1	 6.05	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.05; % NG
	3600	 6.0	 1.875	 6.75	 -3.0	 1.0	 100.0	 1	 9.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0; % PEL
	3600	 6.0	 1.875	 6.75	 -3.0	 1.0	 100.0	 1	 9.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0; % NG
	3600	 6.0	 1.875	 6.75	 -3.0	 1.0	 100.0	 1	 9.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0; % PEL
	3600	 6.0	 1.875	 6.75	 -3.0	 1.0	 100.0	 1	 9.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0; % COW
	3601	 6.1	 2.5	 9.0	 -4.0	 1.0	 100.0	 1	 12.0	 0.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % NG
	3601	 6.1	 2.5	 9.0	 -4.0	 1.0	 100.0	 1	 12.0	 0.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % PEL
	3601	 6.1	 2.5	 9.0	 -4.0	 1.0	 100.0	 1	 12.0	 0.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % COW
	3602	 25.5	 7.5	 27.0	 -12.0	 1.0	 100.0	 1	 36.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0; % COW
	3603	 17.25	 0.0	 13.6	 -13.6	 1.0	 100.0	 1	 34.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	3604	 16.65	 0.0	 13.0	 -13.0	 1.0	 100.0	 1	 33.0	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	3604	 30.75	 0.0	 24.1	 -24.1	 1.0	 100.0	 1	 61.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	3604	 69.05	 0.0	 60.4	 -60.4	 1.0	 100.0	 1	 137.0	 1.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	3604	 45.85	 0.0	 40.1	 -40.1	 1.0	 100.0	 1	 91.0	 0.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	3605	 6.25	 0.82	 5.27	 -3.63	 1.0	 100.0	 1	 10.87	 1.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8667; % PEL
	3605	 6.25	 0.82	 5.27	 -3.63	 1.0	 100.0	 1	 10.87	 1.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8667; % NG
	3605	 6.25	 0.82	 5.27	 -3.63	 1.0	 100.0	 1	 10.87	 1.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8667; % NG
	3607	 18.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 28.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0; % PEL
	3608	 6.075	 0.875	 4.02	 -2.27	 1.0	 100.0	 1	 6.83	 5.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.825; % NG
	3608	 6.075	 0.875	 4.02	 -2.27	 1.0	 100.0	 1	 6.83	 5.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.825; % COW
	3608	 6.075	 0.875	 4.02	 -2.27	 1.0	 100.0	 1	 6.83	 5.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.825; % NG
	3608	 6.075	 0.875	 4.02	 -2.27	 1.0	 100.0	 1	 6.83	 5.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.825; % NG
	3608	 18.35	 3.05	 13.2	 -7.1	 1.0	 100.0	 1	 21.3	 15.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.3; % NG
	3609	 15.95	 2.0	 13.0	 -9.0	 1.0	 100.0	 1	 26.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.9; % PEL
	3610	 13.5	 5.4	 19.5	 -8.7	 1.0	 100.0	 1	 26.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.0; % PEL
	3611	 7.1	 0.0	 4.15	 -4.15	 1.0	 100.0	 1	 12.7	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.7; % NG
	3611	 7.1	 0.0	 4.15	 -4.15	 1.0	 100.0	 1	 12.7	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.7; % NG
	3613	 13.0	 5.25	 18.8	 -8.3	 1.0	 100.0	 1	 25.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	3614	 14.0	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	3614	 14.0	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	3615	 15.3	 1.85	 11.9	 -8.2	 1.0	 100.0	 1	 24.6	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.6; % PEL
	3615	 15.3	 1.85	 11.9	 -8.2	 1.0	 100.0	 1	 24.6	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.6; % COW
	3616	 12.5	 5.0	 18.0	 -8.0	 1.0	 100.0	 1	 24.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % PEL
	3617	 5.45	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 7.8	 3.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.8; % COW
	3617	 5.45	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 7.8	 3.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.8; % PEL
	3617	 5.45	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 7.8	 3.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.8; % NG
	3618	 6.0	 2.3	 8.25	 -3.65	 1.0	 100.0	 1	 11.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0; % NG
	3618	 6.0	 2.3	 8.25	 -3.65	 1.0	 100.0	 1	 11.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0; % COW
	3619	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	3619	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	3619	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	3619	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	3619	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	3619	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	3619	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	3619	 18.9	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 15.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	3619	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	3619	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	3619	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	3619	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	3619	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	3619	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	3619	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	3619	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	3620	 11.05	 0.0	 7.2	 -7.2	 1.0	 100.0	 1	 22.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	3620	 11.05	 0.0	 7.2	 -7.2	 1.0	 100.0	 1	 22.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	3621	 4.65	 1.52	 5.47	 -2.43	 1.0	 100.0	 1	 7.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.3; % PEL
	3621	 4.65	 1.52	 5.47	 -2.43	 1.0	 100.0	 1	 7.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.3; % NG
	3621	 4.65	 1.52	 5.47	 -2.43	 1.0	 100.0	 1	 7.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.3; % PEL
	3623	 11.8	 2.8	 12.8	 -7.2	 1.0	 100.0	 1	 21.6	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6; % PEL
	3624	 16.8	 1.6	 10.2	 -7.0	 1.0	 100.0	 1	 21.1	 12.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.1; % NG
	3625	 11.0	 4.4	 15.8	 -7.0	 1.0	 100.0	 1	 21.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0; % NG
	3626	 7.0	 2.075	 7.5	 -3.35	 1.0	 100.0	 1	 10.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % NG
	3626	 7.0	 2.075	 7.5	 -3.35	 1.0	 100.0	 1	 10.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % NG
	3627	 18.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	3627	 18.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3627	 18.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	3627	 18.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	3627	 18.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3627	 17.8	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 15.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	3627	 17.8	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 15.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3627	 17.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 14.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3627	 18.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3627	 18.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3627	 18.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3627	 18.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	3627	 18.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3627	 18.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3627	 18.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3627	 18.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3628	 10.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3628	 10.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3628	 10.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3628	 10.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3628	 10.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3628	 10.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	3628	 10.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3628	 10.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	3628	 10.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3628	 10.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3628	 10.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3628	 10.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	3629	 10.0	 0.0	 7.9	 -7.9	 1.0	 100.0	 1	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	8510	 778.85	 0.0	 468.5	 -468.5	 1.0	 100.0	 1	 1290.7	 267.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	8511	 40.1	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 38.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8511	 681.5	 88.35	 566.7	 -390.0	 1.0	 100.0	 1	 1170.0	 193.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NUC
	8511	 674.0	 88.35	 566.7	 -390.0	 1.0	 100.0	 1	 1170.0	 178.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	8512	 314.5	 114.6	 412.5	 -183.3	 1.0	 100.0	 1	 550.0	 79.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	8513	 281.915	 34.3	 220.2	 -151.6	 1.0	 100.0	 1	 454.7	 109.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 454.7; % COW
	8513	 439.85	 49.8	 319.5	 -219.9	 1.0	 100.0	 1	 659.7	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 659.7; % COW
	8514	 115.1	 16.5	 71.4	 -38.4	 1.0	 100.0	 1	 115.2	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.2; % NG
	8514	 198.2	 46.75	 202.3	 -108.8	 1.0	 100.0	 1	 326.4	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 326.4; % NG
	8514	 198.2	 46.75	 202.3	 -108.8	 1.0	 100.0	 1	 326.4	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 326.4; % NG
	8515	 165.5	 40.8	 176.6	 -95.0	 1.0	 100.0	 1	 285.0	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 285.0; % NG
	8516	 146.15	 34.7	 150.2	 -80.8	 1.0	 100.0	 1	 242.3	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 242.3; % NG
	8517	 155.75	 27.45	 118.7	 -63.8	 1.0	 100.0	 1	 191.5	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 191.5; % COW
	8517	 155.75	 27.45	 118.7	 -63.8	 1.0	 100.0	 1	 191.5	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 191.5; % COW
	8518	 160.7	 25.95	 112.4	 -60.5	 1.0	 100.0	 1	 181.4	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.4; % NG
	8518	 227.5	 45.1	 195.2	 -105.0	 1.0	 100.0	 1	 315.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 315.0; % NG
	8518	 160.7	 25.95	 112.4	 -60.5	 1.0	 100.0	 1	 181.4	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.4; % NG
	8518	 160.7	 25.95	 112.4	 -60.5	 1.0	 100.0	 1	 181.4	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.4; % NG
	8518	 160.7	 25.95	 112.4	 -60.5	 1.0	 100.0	 1	 181.4	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.4; % COW
	8518	 90.55	 13.8	 59.6	 -32.0	 1.0	 100.0	 1	 96.1	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.1; % PEL
	8518	 90.55	 13.8	 59.6	 -32.0	 1.0	 100.0	 1	 96.1	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.1; % NG
	8518	 89.55	 13.8	 59.6	 -32.0	 1.0	 100.0	 1	 96.1	 83.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.1; % NG
	8518	 88.05	 13.8	 59.6	 -32.0	 1.0	 100.0	 1	 96.1	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.1; % NG
	8518	 227.5	 45.1	 195.2	 -105.0	 1.0	 100.0	 1	 315.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 315.0; % NG
	8519	 150.1	 25.8	 111.7	 -60.1	 1.0	 100.0	 1	 180.2	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.2; % NG
	8519	 150.1	 25.8	 111.7	 -60.1	 1.0	 100.0	 1	 180.2	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.2; % COW
	8519	 150.1	 25.8	 111.7	 -60.1	 1.0	 100.0	 1	 180.2	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.2; % NG
	8519	 170.25	 40.15	 173.8	 -93.5	 1.0	 100.0	 1	 280.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 280.5; % NG
	8521	 103.0	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % NG
	8521	 121.6	 23.35	 101.1	 -54.4	 1.0	 100.0	 1	 163.2	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2; % NG
	8521	 108.2	 13.3	 85.4	 -58.8	 1.0	 100.0	 1	 176.4	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.4; % NG
	8522	 77.4	 8.5	 54.6	 -37.6	 1.0	 100.0	 1	 112.8	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.8; % COW
	8523	 154.3	 26.3	 113.8	 -61.2	 1.0	 100.0	 1	 183.6	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.6; % NG
	8523	 154.3	 26.3	 113.8	 -61.2	 1.0	 100.0	 1	 183.6	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.6; % NG
	8523	 191.7	 37.0	 160.1	 -86.1	 1.0	 100.0	 1	 258.4	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 258.4; % NG
	8523	 217.6	 46.55	 201.5	 -108.4	 1.0	 100.0	 1	 325.2	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 325.2; % NG
	8523	 111.25	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % NG
	8523	 111.25	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % NG
	8523	 111.25	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % NG
	8523	 111.25	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % NG
	8524	 63.75	 15.4	 66.6	 -35.8	 1.0	 100.0	 1	 107.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 107.5; % COW
	8524	 63.75	 15.4	 66.6	 -35.8	 1.0	 100.0	 1	 107.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 107.5; % NG
	8524	 65.35	 15.85	 68.6	 -36.9	 1.0	 100.0	 1	 110.7	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.7; % NG
	8524	 73.25	 18.1	 78.4	 -42.2	 1.0	 100.0	 1	 126.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 126.5; % NG
	8524	 110.1	 8.7	 55.8	 -38.4	 1.0	 100.0	 1	 115.2	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.2; % COW
	8525	 110.9	 9.95	 63.8	 -43.9	 1.0	 100.0	 1	 131.8	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 131.8; % COW
	8525	 70.7	 7.5	 48.1	 -33.1	 1.0	 100.0	 1	 99.4	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.4; % NG
	8526	 151.25	 30.45	 131.7	 -70.8	 1.0	 100.0	 1	 212.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.5; % NG
	8526	 71.4	 7.2	 46.1	 -31.7	 1.0	 100.0	 1	 95.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.2; % NG
	8526	 71.4	 7.2	 46.1	 -31.7	 1.0	 100.0	 1	 95.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.2; % NG
	8526	 71.4	 7.2	 46.1	 -31.7	 1.0	 100.0	 1	 95.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.2; % NG
	8526	 71.4	 7.2	 46.1	 -31.7	 1.0	 100.0	 1	 95.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.2; % NG
	8526	 71.4	 7.2	 46.1	 -31.7	 1.0	 100.0	 1	 95.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.2; % NG
	8526	 60.1	 7.2	 46.1	 -31.7	 1.0	 100.0	 1	 95.2	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.2; % NG
	8526	 60.1	 7.2	 46.1	 -31.7	 1.0	 100.0	 1	 95.2	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.2; % NG
	8526	 60.1	 7.2	 46.1	 -31.7	 1.0	 100.0	 1	 95.2	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.2; % NG
	8528	 25.0	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	8528	 76.0	 12.9	 55.8	 -30.0	 1.0	 100.0	 1	 90.0	 62.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	8528	 76.0	 12.9	 55.8	 -30.0	 1.0	 100.0	 1	 90.0	 62.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	8529	 80.35	 16.9	 60.8	 -27.0	 1.0	 100.0	 1	 81.0	 79.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.0; % NG
	8529	 70.0	 16.2	 58.4	 -26.0	 1.0	 100.0	 1	 77.9	 62.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.9; % NG
	8529	 70.0	 16.2	 58.4	 -26.0	 1.0	 100.0	 1	 77.9	 62.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.9; % COW
	8530	 55.8	 11.7	 50.6	 -27.2	 1.0	 100.0	 1	 81.6	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % NG
	8530	 51.75	 15.3	 55.1	 -24.5	 1.0	 100.0	 1	 73.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 73.5; % NG
	8531	 51.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	8531	 36.63	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 31.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8531	 36.355	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 30.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8531	 36.165	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 30.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8531	 51.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	8531	 51.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	8531	 51.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	8531	 40.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 39.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8531	 40.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 39.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8531	 40.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 39.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8531	 40.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 39.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8531	 36.63	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 31.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % PEL
	8532	 45.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	8532	 45.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	8532	 45.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % PEL
	8532	 45.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	8532	 111.845	 18.85	 86.4	 -48.7	 1.0	 100.0	 1	 146.2	 77.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 146.2; % NG
	8532	 111.845	 18.85	 86.4	 -48.7	 1.0	 100.0	 1	 146.2	 77.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 146.2; % NG
	8533	 50.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % NG
	8533	 17.71	 3.45	 14.9	 -8.0	 1.0	 100.0	 1	 24.0	 11.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % NG
	8535	 23.0	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 24.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % PEL
	8535	 86.0	 10.2	 65.4	 -45.0	 1.0	 100.0	 1	 135.0	 37.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % PEL
	8535	 23.0	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 24.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % NG
	8535	 23.0	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 24.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % NG
	8535	 22.0	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 24.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % PEL
	8535	 48.0	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	8535	 48.0	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	8535	 48.0	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	8535	 48.0	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	8535	 155.5	 12.15	 78.0	 -53.7	 1.0	 100.0	 1	 161.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 161.0; % NG
	8536	 49.5	 7.55	 32.8	 -17.7	 1.0	 100.0	 1	 53.0	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0; % NG
	8536	 49.5	 7.55	 32.8	 -17.7	 1.0	 100.0	 1	 53.0	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0; % COW
	8536	 49.5	 7.55	 32.8	 -17.7	 1.0	 100.0	 1	 53.0	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0; % NG
	8536	 49.5	 7.55	 32.8	 -17.7	 1.0	 100.0	 1	 53.0	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0; % NG
	8537	 51.5	 7.55	 32.8	 -17.7	 1.0	 100.0	 1	 53.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0; % NG
	8537	 51.5	 7.55	 32.8	 -17.7	 1.0	 100.0	 1	 53.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0; % COW
	8537	 51.5	 7.55	 32.8	 -17.7	 1.0	 100.0	 1	 53.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0; % NG
	8537	 51.5	 7.55	 32.8	 -17.7	 1.0	 100.0	 1	 53.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0; % NG
	8538	 13.3	 1.65	 10.5	 -7.2	 1.0	 100.0	 1	 21.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6; % PEL
	8538	 13.3	 1.65	 10.5	 -7.2	 1.0	 100.0	 1	 21.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6; % PEL
	8538	 37.95	 6.55	 28.4	 -15.3	 1.0	 100.0	 1	 45.9	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.9; % NG
	8538	 37.95	 6.55	 28.4	 -15.3	 1.0	 100.0	 1	 45.9	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.9; % NG
	8540	 40.59	 7.9	 34.1	 -18.3	 1.0	 100.0	 1	 55.0	 26.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0; % NG
	8540	 30.995	 6.0	 26.0	 -14.0	 1.0	 100.0	 1	 42.0	 19.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0; % NG
	8540	 30.87	 6.0	 26.0	 -14.0	 1.0	 100.0	 1	 42.0	 19.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0; % NG
	8542	 41.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8542	 41.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % PEL
	8542	 41.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8542	 30.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8542	 41.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8542	 41.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8542	 41.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8542	 41.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8542	 41.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8542	 41.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8542	 41.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8542	 41.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8543	 39.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8543	 39.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8543	 39.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % PEL
	8543	 39.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8543	 86.8	 7.05	 45.3	 -31.2	 1.0	 100.0	 1	 93.6	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.6; % NG
	8543	 39.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8543	 39.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8543	 39.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8543	 39.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % PEL
	8543	 39.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8543	 39.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8543	 39.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8543	 39.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	8544	 34.7	 5.5	 23.8	 -12.8	 1.0	 100.0	 1	 38.4	 31.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.4; % NG
	8544	 31.7	 5.5	 23.8	 -12.8	 1.0	 100.0	 1	 38.4	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.4; % NG
	8545	 10.75	 1.325	 8.5	 -5.85	 1.0	 100.0	 1	 17.5	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % PEL
	8545	 10.75	 1.325	 8.5	 -5.85	 1.0	 100.0	 1	 17.5	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % NG
	8546	 19.95	 2.65	 16.9	 -11.6	 1.0	 100.0	 1	 34.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.9; % PEL
	8546	 19.95	 2.65	 16.9	 -11.6	 1.0	 100.0	 1	 34.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.9; % PEL
	8549	 17.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	8552	 19.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	8552	 19.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	8552	 19.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % COW
	8552	 19.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	8552	 19.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	8552	 19.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	8552	 19.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	8553	 734.0	 0.0	 383.6	 -383.6	 1.0	 100.0	 1	 1298.0	 170.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	8553	 734.0	 0.0	 383.6	 -383.6	 1.0	 100.0	 1	 1298.0	 170.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	8554	 599.25	 85.95	 551.4	 -379.5	 1.0	 100.0	 1	 1138.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	8554	 599.25	 85.95	 551.4	 -379.5	 1.0	 100.0	 1	 1138.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	8555	 552.9	 0.0	 339.5	 -339.5	 1.0	 100.0	 1	 980.8	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	8556	 630.5	 70.65	 453.3	 -312.0	 1.0	 100.0	 1	 936.0	 325.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 936.0; % COW
	8556	 630.5	 70.65	 453.3	 -312.0	 1.0	 100.0	 1	 936.0	 325.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 936.0; % COW
	8557	 643.0	 70.65	 453.3	 -312.0	 1.0	 100.0	 1	 936.0	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 936.0; % NUC
	8557	 0.0	 0.0	 453.3	 -312.0	 1.0	 100.0	 0	 936.0	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 936.0; % COW
	8558	 508.7	 0.0	 290.2	 -290.2	 1.0	 100.0	 1	 923.4	 94.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	8558	 0.0	 0.0	 290.2	 -290.2	 1.0	 100.0	 0	 923.4	 93.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	8559	 731.85	 130.85	 566.3	 -304.6	 1.0	 100.0	 1	 913.7	 550.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 913.7; % COW
	8559	 0.0	 0.0	 566.3	 -304.6	 1.0	 100.0	 0	 913.7	 550.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 913.7; % COW
	8559	 0.0	 0.0	 566.3	 -304.6	 1.0	 100.0	 0	 913.7	 550.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 913.7; % COW
	8560	 496.0	 0.0	 227.4	 -227.4	 1.0	 100.0	 1	 692.0	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 692.0; % COW
	8560	 485.0	 49.85	 319.7	 -220.0	 1.0	 100.0	 1	 660.0	 310.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 660.0; % COW
	8560	 485.0	 49.85	 319.7	 -220.0	 1.0	 100.0	 1	 660.0	 310.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 660.0; % COW
	8561	 431.0	 0.0	 290.2	 -290.2	 1.0	 100.0	 1	 637.0	 225.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 637.0; % COW
	8562	 392.5	 44.15	 283.3	 -195.0	 1.0	 100.0	 1	 585.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 585.0; % COW
	8563	 406.08	 46.75	 285.5	 -192.0	 1.0	 100.0	 1	 576.0	 236.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 576.0; % COW
	8563	 406.08	 46.75	 285.5	 -192.0	 1.0	 100.0	 1	 576.0	 236.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 576.0; % COW
	8563	 406.08	 46.75	 285.5	 -192.0	 1.0	 100.0	 1	 576.0	 236.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 576.0; % COW
	8564	 207.945	 36.55	 172.8	 -99.7	 1.0	 100.0	 1	 299.2	 116.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 299.2; % NG
	8564	 50.795	 10.7	 46.3	 -24.9	 1.0	 100.0	 1	 74.7	 26.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.7; % PEL
	8565	 217.1	 19.55	 125.5	 -86.4	 1.0	 100.0	 1	 259.2	 175.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 259.2; % NG
	8565	 217.1	 19.55	 125.5	 -86.4	 1.0	 100.0	 1	 259.2	 175.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 259.2; % NG
	8565	 217.1	 19.55	 125.5	 -86.4	 1.0	 100.0	 1	 259.2	 175.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 259.2; % NG
	8566	 18.5	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	8566	 123.0	 22.35	 96.7	 -52.0	 1.0	 100.0	 1	 156.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.0; % NG
	8566	 158.5	 36.5	 158.0	 -85.0	 1.0	 100.0	 1	 255.0	 62.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 255.0; % NG
	8566	 118.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0; % NG
	8567	 172.5	 35.8	 154.9	 -83.3	 1.0	 100.0	 1	 250.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 250.0; % COW
	8567	 172.5	 35.8	 154.9	 -83.3	 1.0	 100.0	 1	 250.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 250.0; % NG
	8567	 161.5	 32.65	 141.3	 -76.0	 1.0	 100.0	 1	 228.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 228.0; % COW
	8568	 13.1	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % NG
	8568	 37.845	 9.025	 37.45	 -19.4	 1.0	 100.0	 1	 58.22	 17.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.225; % NG
	8568	 37.845	 9.025	 37.45	 -19.4	 1.0	 100.0	 1	 58.22	 17.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.225; % NG
	8568	 37.845	 9.025	 37.45	 -19.4	 1.0	 100.0	 1	 58.22	 17.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.225; % PEL
	8568	 37.845	 9.025	 37.45	 -19.4	 1.0	 100.0	 1	 58.22	 17.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.225; % NG
	8568	 129.47	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 68.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4; % NG
	8569	 156.4	 32.9	 142.5	 -76.7	 1.0	 100.0	 1	 230.0	 82.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.0; % NG
	8570	 191.8	 17.25	 110.7	 -76.2	 1.0	 100.0	 1	 228.6	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 228.6; % NG
	8570	 173.25	 15.95	 102.4	 -70.5	 1.0	 100.0	 1	 211.5	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 211.5; % NG
	8570	 173.25	 15.95	 102.4	 -70.5	 1.0	 100.0	 1	 211.5	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 211.5; % NG
	8571	 163.1	 38.85	 168.1	 -90.4	 1.0	 100.0	 1	 271.2	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.2; % COW
	8571	 163.1	 38.85	 168.1	 -90.4	 1.0	 100.0	 1	 271.2	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.2; % NG
	8571	 151.95	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	8571	 151.95	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	8571	 151.95	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % COW
	8571	 151.95	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	8572	 227.75	 38.9	 168.3	 -90.5	 1.0	 100.0	 1	 271.5	 184.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.5; % COW
	8572	 144.1	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	8572	 144.1	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	8572	 144.1	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	8574	 156.0	 13.9	 89.1	 -61.3	 1.0	 100.0	 1	 184.0	 128.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.0; % NG
	8574	 156.0	 13.9	 89.1	 -61.3	 1.0	 100.0	 1	 184.0	 128.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.0; % NG
	8574	 157.5	 14.2	 91.1	 -62.7	 1.0	 100.0	 1	 188.0	 127.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.0; % NG
	8575	 144.5	 25.6	 110.9	 -59.7	 1.0	 100.0	 1	 179.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.0; % COW
	8575	 144.5	 25.6	 110.9	 -59.7	 1.0	 100.0	 1	 179.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.0; % NG
	8575	 144.5	 25.6	 110.9	 -59.7	 1.0	 100.0	 1	 179.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.0; % COW
	8575	 250.5	 51.7	 223.7	 -120.3	 1.0	 100.0	 1	 361.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 361.0; % COW
	8576	 136.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0; % NG
	8576	 136.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0; % NG
	8576	 136.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0; % NG
	8576	 136.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0; % NG
	8577	 114.25	 23.4	 101.3	 -54.5	 1.0	 100.0	 1	 163.5	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.5; % COW
	8577	 114.25	 23.4	 101.3	 -54.5	 1.0	 100.0	 1	 163.5	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.5; % NG
	8577	 213.55	 45.4	 196.5	 -105.7	 1.0	 100.0	 1	 317.1	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 317.1; % NG
	8578	 113.425	 30.6	 115.6	 -54.4	 1.0	 100.0	 1	 163.2	 63.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2; % NG
	8578	 113.425	 30.6	 115.6	 -54.4	 1.0	 100.0	 1	 163.2	 63.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2; % NG
	8579	 36.3	 8.25	 35.7	 -19.2	 1.0	 100.0	 1	 57.6	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.6; % PEL
	8579	 97.5	 19.35	 83.7	 -45.0	 1.0	 100.0	 1	 135.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % NG
	8580	 99.55	 19.2	 83.1	 -44.7	 1.0	 100.0	 1	 134.1	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.1; % NG
	8581	 92.0	 10.1	 64.9	 -44.7	 1.0	 100.0	 1	 134.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.0; % NG
	8581	 92.0	 10.1	 64.9	 -44.7	 1.0	 100.0	 1	 134.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.0; % NG
	8581	 92.0	 10.1	 64.9	 -44.7	 1.0	 100.0	 1	 134.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.0; % COW
	8581	 92.0	 10.1	 64.9	 -44.7	 1.0	 100.0	 1	 134.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.0; % NG
	8581	 92.0	 10.1	 64.9	 -44.7	 1.0	 100.0	 1	 134.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.0; % COW
	8581	 92.0	 10.1	 64.9	 -44.7	 1.0	 100.0	 1	 134.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.0; % NG
	8581	 92.0	 10.1	 64.9	 -44.7	 1.0	 100.0	 1	 134.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.0; % NG
	8581	 92.0	 10.1	 64.9	 -44.7	 1.0	 100.0	 1	 134.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.0; % NG
	8582	 117.75	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % NG
	8582	 117.75	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % NG
	8582	 101.0	 18.2	 78.7	 -42.3	 1.0	 100.0	 1	 127.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 127.0; % NG
	8582	 101.0	 18.2	 78.7	 -42.3	 1.0	 100.0	 1	 127.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 127.0; % NG
	8582	 101.0	 18.2	 78.7	 -42.3	 1.0	 100.0	 1	 127.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 127.0; % NG
	8582	 101.0	 18.2	 78.7	 -42.3	 1.0	 100.0	 1	 127.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 127.0; % NG
	8582	 101.0	 18.2	 78.7	 -42.3	 1.0	 100.0	 1	 127.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 127.0; % NG
	8582	 101.0	 18.2	 78.7	 -42.3	 1.0	 100.0	 1	 127.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 127.0; % NG
	8583	 145.0	 26.9	 116.5	 -62.7	 1.0	 100.0	 1	 188.0	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.0; % NG
	8583	 145.0	 26.9	 116.5	 -62.7	 1.0	 100.0	 1	 188.0	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.0; % NG
	8583	 87.5	 26.05	 93.8	 -41.7	 1.0	 100.0	 1	 125.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	8583	 87.5	 26.05	 93.8	 -41.7	 1.0	 100.0	 1	 125.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	8584	 97.5	 0.0	 16.8	 -16.8	 1.0	 100.0	 1	 118.0	 77.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 118.0; % NG
	8586	 51.0	 0.0	 45.0	 -45.0	 1.0	 100.0	 1	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	8587	 50.25	 0.0	 44.3	 -44.3	 1.0	 100.0	 1	 100.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	8588	 86.875	 17.9	 77.5	 -41.7	 1.0	 100.0	 1	 125.0	 48.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	8588	 128.575	 26.5	 114.7	 -61.7	 1.0	 100.0	 1	 185.0	 72.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	8588	 67.5	 14.35	 62.0	 -33.3	 1.0	 100.0	 1	 100.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0; % NG
	8588	 67.5	 20.85	 75.0	 -33.3	 1.0	 100.0	 1	 100.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0; % COW
	8589	 59.0	 20.4	 73.5	 -32.7	 1.0	 100.0	 1	 98.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.0; % NG
	8590	 72.35	 13.55	 58.7	 -31.6	 1.0	 100.0	 1	 94.7	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.7; % NG
	8592	 55.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 90.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	8594	 40.0	 0.0	 31.6	 -31.6	 1.0	 100.0	 1	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	8595	 12.45	 2.855	 12.33	 -6.62	 1.0	 100.0	 1	 19.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.9; % NG
	8595	 12.45	 2.855	 12.33	 -6.62	 1.0	 100.0	 1	 19.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.9; % NG
	8595	 12.45	 2.855	 12.33	 -6.62	 1.0	 100.0	 1	 19.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.9; % PEL
	8595	 12.45	 2.855	 12.33	 -6.62	 1.0	 100.0	 1	 19.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.9; % NG
	8595	 13.1	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % PEL
	8595	 13.1	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % NG
	8595	 220.5	 56.0	 242.3	 -130.3	 1.0	 100.0	 1	 391.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 391.0; % NG
	8595	 220.5	 56.0	 242.3	 -130.3	 1.0	 100.0	 1	 391.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 391.0; % COW
	8596	 12.125	 2.75	 11.92	 -6.42	 1.0	 100.0	 1	 19.25	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.25; % NG
	8596	 12.125	 2.75	 11.92	 -6.42	 1.0	 100.0	 1	 19.25	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.25; % COW
	8596	 12.125	 2.75	 11.92	 -6.42	 1.0	 100.0	 1	 19.25	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.25; % NG
	8596	 12.125	 2.75	 11.92	 -6.42	 1.0	 100.0	 1	 19.25	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.25; % NG
	8596	 13.1	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % NG
	8597	 11.8	 2.66	 11.52	 -6.2	 1.0	 100.0	 1	 18.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.6; % PEL
	8597	 11.8	 2.66	 11.52	 -6.2	 1.0	 100.0	 1	 18.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.6; % PEL
	8597	 11.8	 2.66	 11.52	 -6.2	 1.0	 100.0	 1	 18.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.6; % NG
	8597	 11.8	 2.66	 11.52	 -6.2	 1.0	 100.0	 1	 18.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.6; % NG
	8598	 34.05	 9.55	 34.4	 -15.3	 1.0	 100.0	 1	 45.9	 22.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.9; % NG
	8598	 10.13	 2.93	 10.56	 -4.7	 1.0	 100.0	 1	 14.08	 6.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.08; % PEL
	8598	 10.13	 2.93	 10.56	 -4.7	 1.0	 100.0	 1	 14.08	 6.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.08; % PEL
	8598	 10.13	 2.93	 10.56	 -4.7	 1.0	 100.0	 1	 14.08	 6.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.08; % PEL
	8598	 10.13	 2.93	 10.56	 -4.7	 1.0	 100.0	 1	 14.08	 6.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.08; % NG
	8598	 10.13	 2.93	 10.56	 -4.7	 1.0	 100.0	 1	 14.08	 6.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.08; % NG
	8598	 23.65	 8.15	 29.3	 -13.0	 1.0	 100.0	 1	 39.1	 8.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.1; % COW
	8599	 35.05	 0.0	 27.7	 -27.7	 1.0	 100.0	 1	 70.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	8600	 39.15	 5.15	 33.1	 -22.8	 1.0	 100.0	 1	 68.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.3; % PEL
	8600	 39.15	 5.15	 33.1	 -22.8	 1.0	 100.0	 1	 68.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.3; % PEL
	8600	 39.15	 5.15	 33.1	 -22.8	 1.0	 100.0	 1	 68.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.3; % PEL
	8600	 39.15	 5.15	 33.1	 -22.8	 1.0	 100.0	 1	 68.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.3; % NG
	8600	 39.15	 5.15	 33.1	 -22.8	 1.0	 100.0	 1	 68.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.3; % PEL
	8600	 39.15	 5.15	 33.1	 -22.8	 1.0	 100.0	 1	 68.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.3; % NG
	8600	 39.15	 5.15	 33.1	 -22.8	 1.0	 100.0	 1	 68.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.3; % NG
	8600	 39.15	 5.15	 33.1	 -22.8	 1.0	 100.0	 1	 68.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.3; % PEL
	8601	 35.0	 9.6	 41.5	 -22.3	 1.0	 100.0	 1	 67.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0; % NG
	8602	 88.0	 10.85	 69.7	 -48.0	 1.0	 100.0	 1	 144.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 144.0; % NG
	8602	 20.25	 3.65	 15.8	 -8.5	 1.0	 100.0	 1	 25.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5; % NG
	8602	 20.25	 3.65	 15.8	 -8.5	 1.0	 100.0	 1	 25.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5; % NG
	8602	 20.25	 3.65	 15.8	 -8.5	 1.0	 100.0	 1	 25.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5; % PEL
	8602	 47.65	 4.9	 31.6	 -21.8	 1.0	 100.0	 1	 65.3	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.3; % PEL
	8602	 47.65	 4.9	 31.6	 -21.8	 1.0	 100.0	 1	 65.3	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.3; % NG
	8602	 47.65	 4.9	 31.6	 -21.8	 1.0	 100.0	 1	 65.3	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.3; % PEL
	8603	 15.0	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	8603	 15.0	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	8603	 15.0	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % PEL
	8603	 15.0	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	8605	 31.25	 0.0	 24.7	 -24.7	 1.0	 100.0	 1	 62.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	8607	 40.45	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % NG
	8607	 40.45	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % NG
	8607	 40.45	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % NG
	8607	 39.45	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % PEL
	8607	 37.95	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % COW
	8608	 42.3	 4.35	 27.9	 -19.2	 1.0	 100.0	 1	 57.6	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.6; % PEL
	8609	 11.8	 2.665	 11.53	 -6.2	 1.0	 100.0	 1	 18.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.6; % NG
	8609	 11.8	 2.665	 11.53	 -6.2	 1.0	 100.0	 1	 18.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.6; % PEL
	8609	 11.8	 2.665	 11.53	 -6.2	 1.0	 100.0	 1	 18.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.6; % NG
	8610	 33.0	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % PEL
	8611	 41.8	 11.15	 40.2	 -17.9	 1.0	 100.0	 1	 53.6	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.6; % NG
	8612	 26.65	 7.6	 33.0	 -17.8	 1.0	 100.0	 1	 53.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.3; % NG
	8613	 29.05	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1; % NG
	8614	 9.535	 2.63	 11.13	 -5.87	 1.0	 100.0	 1	 17.57	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5667; % PEL
	8614	 9.535	 2.63	 11.13	 -5.87	 1.0	 100.0	 1	 17.57	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5667; % NG
	8614	 9.535	 2.63	 11.13	 -5.87	 1.0	 100.0	 1	 17.57	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5667; % NG
	8614	 105.6	 22.35	 96.8	 -52.1	 1.0	 100.0	 1	 156.2	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.2; % NG
	8614	 62.05	 6.75	 43.2	 -29.7	 1.0	 100.0	 1	 89.1	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.1; % NG
	8614	 62.05	 6.75	 43.2	 -29.7	 1.0	 100.0	 1	 89.1	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.1; % NG
	8614	 74.25	 14.8	 64.1	 -34.5	 1.0	 100.0	 1	 103.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5; % NG
	8615	 26.25	 0.0	 20.7	 -20.7	 1.0	 100.0	 1	 52.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	8616	 17.65	 4.825	 18.35	 -8.7	 1.0	 100.0	 1	 26.1	 9.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.1; % PEL
	8616	 17.65	 4.825	 18.35	 -8.7	 1.0	 100.0	 1	 26.1	 9.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.1; % COW
	8617	 7.9	 0.96	 6.2	 -4.28	 1.0	 100.0	 1	 12.8	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8; % NG
	8617	 7.9	 0.96	 6.2	 -4.28	 1.0	 100.0	 1	 12.8	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8; % COW
	8617	 7.9	 0.96	 6.2	 -4.28	 1.0	 100.0	 1	 12.8	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8; % PEL
	8617	 7.9	 0.96	 6.2	 -4.28	 1.0	 100.0	 1	 12.8	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8; % NG
	8618	 42.75	 10.55	 37.9	 -16.8	 1.0	 100.0	 1	 50.5	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.5; % NG
	8619	 26.95	 7.15	 30.9	 -16.6	 1.0	 100.0	 1	 49.9	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9; % NG
	8623	 23.9	 3.3	 21.2	 -14.6	 1.0	 100.0	 1	 43.8	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.8; % NG
	8623	 23.9	 3.3	 21.2	 -14.6	 1.0	 100.0	 1	 43.8	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.8; % PEL
	8624	 23.9	 3.3	 21.2	 -14.6	 1.0	 100.0	 1	 43.8	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.8; % NG
	8624	 23.9	 3.3	 21.2	 -14.6	 1.0	 100.0	 1	 43.8	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.8; % PEL
	8625	 23.9	 3.3	 21.2	 -14.6	 1.0	 100.0	 1	 43.8	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.8; % NG
	8625	 23.9	 3.3	 21.2	 -14.6	 1.0	 100.0	 1	 43.8	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.8; % NG
	8629	 24.1	 5.2	 22.6	 -12.2	 1.0	 100.0	 1	 36.5	 11.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.5; % PEL
	8630	 15.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	8630	 15.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	8630	 49.5	 10.25	 45.5	 -25.0	 1.0	 100.0	 1	 75.0	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % COW
	8630	 49.5	 10.25	 45.5	 -25.0	 1.0	 100.0	 1	 75.0	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % COW
	8630	 49.5	 10.25	 45.5	 -25.0	 1.0	 100.0	 1	 75.0	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % COW
	8632	 22.5	 7.3	 26.3	 -11.7	 1.0	 100.0	 1	 35.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % PEL
	8632	 72.0	 23.75	 85.5	 -38.0	 1.0	 100.0	 1	 114.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0; % NG
	8633	 17.25	 0.0	 13.6	 -13.6	 1.0	 100.0	 1	 34.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	8635	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 33.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0; % NG
	8636	 23.65	 2.4	 15.6	 -10.8	 1.0	 100.0	 1	 32.3	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.3; % NG
	8636	 29.2	 5.5	 23.8	 -12.8	 1.0	 100.0	 1	 38.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.4; % NG
	8637	 23.05	 2.4	 15.5	 -10.7	 1.0	 100.0	 1	 32.1	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.1; % PEL
	8640	 14.7	 2.275	 9.9	 -5.35	 1.0	 100.0	 1	 16.0	 13.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	8640	 14.7	 2.275	 9.9	 -5.35	 1.0	 100.0	 1	 16.0	 13.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	8641	 16.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % NG
	8641	 18.75	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 37.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % NG
	8641	 18.75	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 37.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % NG
	8641	 18.75	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 37.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % NG
	8641	 16.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % PEL
	8641	 16.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % PEL
	8641	 16.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % PEL
	8641	 16.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % PEL
	8641	 16.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0; % NG
	8641	 16.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0; % PEL
	8641	 18.75	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 37.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % PEL
	8641	 18.75	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 37.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % PEL
	8642	 6.835	 2.085	 7.5	 -3.33	 1.0	 100.0	 1	 10.0	 3.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % NG
	8642	 6.835	 2.085	 7.5	 -3.33	 1.0	 100.0	 1	 10.0	 3.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % NG
	8642	 6.835	 2.085	 7.5	 -3.33	 1.0	 100.0	 1	 10.0	 3.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % PEL
	8643	 6.5	 2.085	 7.5	 -3.33	 1.0	 100.0	 1	 10.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % NG
	8643	 6.5	 2.085	 7.5	 -3.33	 1.0	 100.0	 1	 10.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % NG
	8643	 6.5	 2.085	 7.5	 -3.33	 1.0	 100.0	 1	 10.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % NG
	8644	 15.75	 0.0	 11.9	 -11.9	 1.0	 100.0	 1	 30.0	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	8646	 28.53	 4.15	 18.0	 -9.7	 1.0	 100.0	 1	 29.0	 28.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.0; % NG
	8646	 149.0	 31.5	 136.3	 -73.3	 1.0	 100.0	 1	 220.0	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 220.0; % NG
	8646	 149.0	 31.5	 136.3	 -73.3	 1.0	 100.0	 1	 220.0	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 220.0; % NG
	8647	 22.5	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % PEL
	8647	 22.5	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % PEL
	8648	 22.5	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % COW
	8649	 22.5	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % PEL
	8649	 22.5	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % NG
	8650	 13.0	 0.0	 10.3	 -10.3	 1.0	 100.0	 1	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	8651	 13.75	 5.25	 18.8	 -8.3	 1.0	 100.0	 1	 25.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	8651	 13.75	 5.25	 18.8	 -8.3	 1.0	 100.0	 1	 25.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	8652	 3.3	 0.46	 2.95	 -2.03	 1.0	 100.0	 1	 6.1	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1; % PEL
	8652	 3.3	 0.46	 2.95	 -2.03	 1.0	 100.0	 1	 6.1	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1; % NG
	8652	 3.3	 0.46	 2.95	 -2.03	 1.0	 100.0	 1	 6.1	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1; % PEL
	8652	 3.3	 0.46	 2.95	 -2.03	 1.0	 100.0	 1	 6.1	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1; % NG
	8653	 15.55	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 24.1	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.1; % PEL
	8654	 3.5	 1.25	 4.5	 -2.0	 1.0	 100.0	 1	 6.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0; % NG
	8654	 3.5	 1.25	 4.5	 -2.0	 1.0	 100.0	 1	 6.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0; % NG
	8654	 3.5	 1.25	 4.5	 -2.0	 1.0	 100.0	 1	 6.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0; % NG
	8654	 3.5	 1.25	 4.5	 -2.0	 1.0	 100.0	 1	 6.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0; % PEL
	8657	 20.15	 3.2	 13.8	 -7.4	 1.0	 100.0	 1	 22.3	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.3; % PEL
	8657	 20.15	 3.2	 13.8	 -7.4	 1.0	 100.0	 1	 22.3	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.3; % NG
	8657	 20.15	 3.2	 13.8	 -7.4	 1.0	 100.0	 1	 22.3	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.3; % PEL
	8657	 20.15	 3.2	 13.8	 -7.4	 1.0	 100.0	 1	 22.3	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.3; % NG
	8657	 550.25	 64.2	 411.9	 -283.5	 1.0	 100.0	 1	 850.5	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 850.5; % COW
	8657	 550.25	 64.2	 411.9	 -283.5	 1.0	 100.0	 1	 850.5	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 850.5; % COW
	8661	 11.5	 3.0	 13.0	 -7.0	 1.0	 100.0	 1	 21.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0; % COW
	8662	 19.0	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	8662	 19.0	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	8662	 18.5	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	13881	 33.035	 7.215	 31.23	 -16.8	 1.0	 100.0	 1	 50.4	 15.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.4; % NG
	13881	 33.035	 7.215	 31.23	 -16.8	 1.0	 100.0	 1	 50.4	 15.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.4; % NG
	13881	 33.035	 7.215	 31.23	 -16.8	 1.0	 100.0	 1	 50.4	 15.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.4; % NG
	13882	 112.0	 20.6	 89.2	 -48.0	 1.0	 100.0	 1	 144.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 144.0; % NG
	13882	 112.0	 20.6	 89.2	 -48.0	 1.0	 100.0	 1	 144.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 144.0; % COW
	13882	 112.0	 20.6	 89.2	 -48.0	 1.0	 100.0	 1	 144.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 144.0; % COW
	13882	 140.0	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	13882	 120.0	 27.95	 120.9	 -65.0	 1.0	 100.0	 1	 195.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.0; % NG
	13882	 101.0	 9.2	 59.1	 -40.7	 1.0	 100.0	 1	 122.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % NG
	13882	 101.0	 9.2	 59.1	 -40.7	 1.0	 100.0	 1	 122.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % NG
	13882	 101.0	 9.2	 59.1	 -40.7	 1.0	 100.0	 1	 122.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % NG
	13883	 21.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 27.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % PEL
	13883	 21.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 27.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % PEL
	13883	 46.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 75.0	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	13883	 68.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 92.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 92.0; % NG
	13883	 68.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 92.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 92.0; % NG
	13884	 113.4	 25.35	 109.6	 -58.9	 1.0	 100.0	 1	 176.8	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.8; % NG
	13884	 55.08	 11.15	 49.5	 -27.2	 1.0	 100.0	 1	 81.6	 28.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % PEL
	13884	 55.08	 11.15	 49.5	 -27.2	 1.0	 100.0	 1	 81.6	 28.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % NG
	13884	 317.75	 33.65	 215.8	 -148.5	 1.0	 100.0	 1	 445.5	 190.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 445.5; % COW
	13885	 113.4	 25.35	 109.6	 -58.9	 1.0	 100.0	 1	 176.8	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.8; % NG
	13885	 255.5	 33.65	 216.0	 -148.7	 1.0	 100.0	 1	 446.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 446.0; % COW
	13885	 50.0	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	13886	 51.5	 8.55	 39.8	 -22.7	 1.0	 100.0	 1	 68.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % PEL
	13886	 40.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	13886	 40.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	13888	 23.5	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	13889	 23.0	 5.4	 19.5	 -8.7	 1.0	 100.0	 1	 26.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.0; % NG
	13889	 23.0	 5.4	 19.5	 -8.7	 1.0	 100.0	 1	 26.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.0; % NG
	13890	 6.425	 1.425	 6.2	 -3.35	 1.0	 100.0	 1	 10.0	 2.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % NG
	13890	 6.425	 1.425	 6.2	 -3.35	 1.0	 100.0	 1	 10.0	 2.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % PEL
	13891	 17.5	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	13892	 484.0	 69.3	 444.6	 -306.0	 1.0	 100.0	 1	 918.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	13892	 475.35	 68.75	 441.1	 -303.6	 1.0	 100.0	 1	 910.7	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	13893	 452.5	 51.75	 331.8	 -228.3	 1.0	 100.0	 1	 685.0	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 685.0; % COW
	13893	 452.5	 51.75	 331.8	 -228.3	 1.0	 100.0	 1	 685.0	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 685.0; % COW
	13894	 95.0	 9.4	 60.5	 -41.7	 1.0	 100.0	 1	 125.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % PEL
	13894	 267.0	 52.15	 225.6	 -121.3	 1.0	 100.0	 1	 364.0	 170.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 364.0; % NG
	13894	 95.0	 9.4	 60.5	 -41.7	 1.0	 100.0	 1	 125.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	13894	 62.0	 7.1	 45.5	 -31.3	 1.0	 100.0	 1	 94.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0; % NG
	13894	 20.0	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % PEL
	13894	 68.0	 14.75	 63.8	 -34.3	 1.0	 100.0	 1	 103.0	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.0; % COW
	13894	 68.0	 14.75	 63.8	 -34.3	 1.0	 100.0	 1	 103.0	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.0; % NG
	13894	 620.5	 49.75	 319.2	 -219.7	 1.0	 100.0	 1	 659.0	 582.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 659.0; % COW
	13894	 620.5	 49.75	 319.2	 -219.7	 1.0	 100.0	 1	 659.0	 582.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 659.0; % COW
	13894	 272.0	 52.15	 225.6	 -121.3	 1.0	 100.0	 1	 364.0	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 364.0; % NG
	13895	 32.5	 4.56	 25.57	 -16.45	 1.0	 100.0	 1	 49.33	 15.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.3333; % NG
	13895	 32.5	 4.56	 25.57	 -16.45	 1.0	 100.0	 1	 49.33	 15.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.3333; % NG
	13895	 32.5	 4.56	 25.57	 -16.45	 1.0	 100.0	 1	 49.33	 15.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.3333; % NG
	13895	 32.5	 4.56	 25.57	 -16.45	 1.0	 100.0	 1	 49.33	 15.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.3333; % NG
	13895	 32.5	 4.56	 25.57	 -16.45	 1.0	 100.0	 1	 49.33	 15.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.3333; % NG
	13895	 32.5	 4.56	 25.57	 -16.45	 1.0	 100.0	 1	 49.33	 15.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.3333; % NG
	13895	 414.5	 47.25	 303.2	 -208.7	 1.0	 100.0	 1	 626.0	 203.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 626.0; % COW
	13895	 411.5	 47.25	 303.2	 -208.7	 1.0	 100.0	 1	 626.0	 197.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 626.0; % COW
	13897	 128.0	 28.1	 121.5	 -65.3	 1.0	 100.0	 1	 196.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.0; % NG
	13897	 128.0	 28.1	 121.5	 -65.3	 1.0	 100.0	 1	 196.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.0; % NG
	13897	 128.0	 28.1	 121.5	 -65.3	 1.0	 100.0	 1	 196.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.0; % NG
	13897	 101.5	 12.3	 78.9	 -54.3	 1.0	 100.0	 1	 163.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.0; % NG
	13897	 101.5	 12.3	 78.9	 -54.3	 1.0	 100.0	 1	 163.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.0; % NG
	13898	 29.05	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1; % NG
	13898	 29.05	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1; % NG
	13898	 29.05	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1; % NG
	13898	 29.05	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1; % NG
	13898	 101.0	 14.5	 93.0	 -64.0	 1.0	 100.0	 1	 192.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.0; % COW
	13899	 140.2	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4; % NG
	13899	 134.7	 30.0	 129.8	 -69.8	 1.0	 100.0	 1	 209.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 209.4; % NG
	13900	 137.95	 25.2	 109.0	 -58.6	 1.0	 100.0	 1	 175.9	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.9; % COW
	13900	 149.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	13900	 149.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	13900	 149.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	13901	 108.5	 12.25	 78.5	 -54.0	 1.0	 100.0	 1	 162.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 162.0; % NG
	13902	 10.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	13902	 10.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	13902	 10.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	13902	 10.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	13902	 10.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	13902	 10.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	13902	 10.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % COW
	13902	 10.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	13903	 83.0	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % NG
	13903	 237.35	 31.3	 200.8	 -138.2	 1.0	 100.0	 1	 414.7	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 414.7; % COW
	13903	 244.5	 27.1	 173.9	 -119.7	 1.0	 100.0	 1	 359.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 359.0; % NG
	13904	 15.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	13904	 15.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	13904	 46.1	 10.3	 44.7	 -24.1	 1.0	 100.0	 1	 72.2	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.2; % PEL
	13904	 77.5	 10.2	 65.4	 -45.0	 1.0	 100.0	 1	 135.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % NG
	13905	 70.75	 9.15	 58.8	 -40.5	 1.0	 100.0	 1	 121.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.5; % NG
	13908	 12.45	 3.4	 14.8	 -8.0	 1.0	 100.0	 1	 23.9	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % PEL
	13908	 12.45	 3.4	 14.8	 -8.0	 1.0	 100.0	 1	 23.9	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % PEL
	13908	 8.135	 2.5	 10.08	 -5.08	 1.0	 100.0	 1	 15.27	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.2667; % NG
	13908	 8.135	 2.5	 10.08	 -5.08	 1.0	 100.0	 1	 15.27	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.2667; % PEL
	13908	 8.135	 2.5	 10.08	 -5.08	 1.0	 100.0	 1	 15.27	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.2667; % PEL
	13908	 8.135	 2.5	 10.08	 -5.08	 1.0	 100.0	 1	 15.27	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.2667; % COW
	13908	 8.135	 2.5	 10.08	 -5.08	 1.0	 100.0	 1	 15.27	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.2667; % NG
	13908	 8.135	 2.5	 10.08	 -5.08	 1.0	 100.0	 1	 15.27	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.2667; % PEL
	13912	 2.425	 1.015	 3.64	 -1.61	 1.0	 100.0	 1	 4.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.85; % PEL
	13912	 2.425	 1.015	 3.64	 -1.61	 1.0	 100.0	 1	 4.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.85; % NG
	13912	 2.425	 1.015	 3.64	 -1.61	 1.0	 100.0	 1	 4.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.85; % NG
	13912	 2.425	 1.015	 3.64	 -1.61	 1.0	 100.0	 1	 4.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.85; % NG
	13912	 2.425	 1.015	 3.64	 -1.61	 1.0	 100.0	 1	 4.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.85; % NG
	13912	 2.425	 1.015	 3.64	 -1.61	 1.0	 100.0	 1	 4.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.85; % NG
	13912	 2.425	 1.015	 3.64	 -1.61	 1.0	 100.0	 1	 4.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.85; % PEL
	13912	 2.425	 1.015	 3.64	 -1.61	 1.0	 100.0	 1	 4.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.85; % NG
	13917	 20.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	13920	 945.8	 94.05	 603.3	 -415.2	 1.0	 100.0	 1	 1245.6	 646.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1245.6; % COW
	13920	 0.0	 0.0	 603.3	 -415.2	 1.0	 100.0	 0	 1245.6	 600.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1245.6; % COW
	13921	 1188.95	 142.4	 691.6	 -406.8	 1.0	 100.0	 1	 1220.3	 1157.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	13921	 1179.4	 206.6	 820.0	 -406.8	 1.0	 100.0	 1	 1220.3	 1138.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NUC
	13922	 969.8	 0.0	 276.3	 -276.3	 1.0	 100.0	 1	 1001.6	 938.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	13922	 966.8	 0.0	 276.3	 -276.3	 1.0	 100.0	 1	 1001.6	 932.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	13923	 939.45	 0.0	 312.5	 -312.5	 1.0	 100.0	 1	 950.9	 928.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NUC
	13924	 456.6	 57.6	 369.6	 -254.4	 1.0	 100.0	 1	 763.2	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 763.2; % COW
	13925	 497.6	 56.25	 360.9	 -248.4	 1.0	 100.0	 1	 745.2	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 745.2; % COW
	13925	 403.5	 49.6	 318.2	 -219.0	 1.0	 100.0	 1	 657.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 657.0; % COW
	13925	 422.6	 56.25	 360.9	 -248.4	 1.0	 100.0	 1	 745.2	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 745.2; % COW
	13925	 255.4	 31.05	 199.0	 -136.9	 1.0	 100.0	 1	 410.8	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 410.8; % COW
	13926	 149.7	 28.55	 123.6	 -66.5	 1.0	 100.0	 1	 199.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.4; % NG
	13926	 149.7	 28.55	 123.6	 -66.5	 1.0	 100.0	 1	 199.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.4; % NG
	13926	 149.7	 28.55	 123.6	 -66.5	 1.0	 100.0	 1	 199.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.4; % NG
	13926	 149.7	 28.55	 123.6	 -66.5	 1.0	 100.0	 1	 199.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.4; % NG
	13926	 149.7	 28.55	 123.6	 -66.5	 1.0	 100.0	 1	 199.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.4; % NG
	13926	 141.74	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 87.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % NG
	13926	 144.565	 28.55	 123.6	 -66.5	 1.0	 100.0	 1	 199.4	 89.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.4; % NG
	13926	 144.565	 28.55	 123.6	 -66.5	 1.0	 100.0	 1	 199.4	 89.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.4; % COW
	13927	 187.2	 28.55	 123.6	 -66.5	 1.0	 100.0	 1	 199.4	 175.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.4; % NG
	13927	 147.2	 28.55	 123.6	 -66.5	 1.0	 100.0	 1	 199.4	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.4; % NG
	13927	 147.2	 28.55	 123.6	 -66.5	 1.0	 100.0	 1	 199.4	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.4; % NG
	13927	 147.2	 28.55	 123.6	 -66.5	 1.0	 100.0	 1	 199.4	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.4; % NG
	13927	 141.375	 27.95	 120.9	 -65.0	 1.0	 100.0	 1	 195.0	 87.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.0; % NG
	13927	 144.565	 28.55	 123.6	 -66.5	 1.0	 100.0	 1	 199.4	 89.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.4; % COW
	13928	 180.25	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % NG
	13928	 180.25	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % NG
	13928	 180.25	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % NG
	13928	 180.25	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % NG
	13928	 180.25	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % NG
	13929	 147.6	 27.95	 121.0	 -65.1	 1.0	 100.0	 1	 195.2	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.2; % COW
	13929	 147.6	 27.95	 121.0	 -65.1	 1.0	 100.0	 1	 195.2	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.2; % NG
	13929	 149.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	13929	 132.6	 27.95	 121.0	 -65.1	 1.0	 100.0	 1	 195.2	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.2; % NG
	13929	 132.6	 27.95	 121.0	 -65.1	 1.0	 100.0	 1	 195.2	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.2; % NG
	13930	 112.1	 23.35	 101.1	 -54.4	 1.0	 100.0	 1	 163.2	 61.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2; % COW
	13930	 112.1	 23.35	 101.1	 -54.4	 1.0	 100.0	 1	 163.2	 61.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2; % NG
	13930	 199.0	 38.95	 168.6	 -90.7	 1.0	 100.0	 1	 272.0	 126.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 272.0; % NG
	13930	 194.0	 38.95	 168.6	 -90.7	 1.0	 100.0	 1	 272.0	 116.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 272.0; % NG
	13930	 196.5	 39.8	 172.3	 -92.7	 1.0	 100.0	 1	 278.0	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 278.0; % NG
	13931	 75.94	 16.1	 69.7	 -37.5	 1.0	 100.0	 1	 112.5	 39.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % NG
	13931	 75.94	 16.1	 69.7	 -37.5	 1.0	 100.0	 1	 112.5	 39.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % COW
	13931	 21.75	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.5	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % PEL
	13931	 21.75	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.5	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % NG
	13931	 312.62	 33.7	 216.3	 -148.9	 1.0	 100.0	 1	 446.6	 178.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 446.6; % COW
	13932	 36.72	 7.3	 31.6	 -17.0	 1.0	 100.0	 1	 51.0	 22.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0; % NG
	13932	 36.72	 7.3	 31.6	 -17.0	 1.0	 100.0	 1	 51.0	 22.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0; % PEL
	13932	 130.59	 26.9	 116.4	 -62.6	 1.0	 100.0	 1	 187.9	 73.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.9; % COW
	13932	 97.715	 29.3	 105.5	 -46.9	 1.0	 100.0	 1	 140.6	 54.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.6; % NG
	13933	 92.435	 27.75	 99.8	 -44.3	 1.0	 100.0	 1	 133.0	 51.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.0; % NG
	13933	 92.435	 27.75	 99.8	 -44.3	 1.0	 100.0	 1	 133.0	 51.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.0; % NG
	13933	 24.165	 3.8	 18.9	 -11.3	 1.0	 100.0	 1	 33.8	 14.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.8; % PEL
	13933	 24.165	 3.8	 18.9	 -11.3	 1.0	 100.0	 1	 33.8	 14.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.8; % NG
	13933	 24.165	 3.8	 18.9	 -11.3	 1.0	 100.0	 1	 33.8	 14.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.8; % PEL
	13933	 24.165	 3.8	 18.9	 -11.3	 1.0	 100.0	 1	 33.8	 14.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.8; % PEL
	13933	 67.5	 20.85	 75.0	 -33.3	 1.0	 100.0	 1	 100.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0; % COW
	13933	 67.5	 20.85	 75.0	 -33.3	 1.0	 100.0	 1	 100.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0; % PEL
	13934	 84.4	 0.0	 28.8	 -28.8	 1.0	 100.0	 1	 87.5	 81.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.5; % NG
	13934	 84.4	 0.0	 28.8	 -28.8	 1.0	 100.0	 1	 87.5	 81.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.5; % NG
	13934	 84.4	 0.0	 28.8	 -28.8	 1.0	 100.0	 1	 87.5	 81.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.5; % NG
	13934	 84.4	 0.0	 28.8	 -28.8	 1.0	 100.0	 1	 87.5	 81.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.5; % NG
	13936	 50.625	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 26.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % COW
	13936	 50.625	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 26.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	13936	 21.155	 4.25	 18.5	 -10.0	 1.0	 100.0	 1	 29.9	 12.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.9; % NG
	13936	 21.155	 4.25	 18.5	 -10.0	 1.0	 100.0	 1	 29.9	 12.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.9; % NG
	13936	 21.155	 4.25	 18.5	 -10.0	 1.0	 100.0	 1	 29.9	 12.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.9; % PEL
	13936	 175.42	 19.05	 122.2	 -84.1	 1.0	 100.0	 1	 252.4	 98.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 252.4; % COW
	13937	 51.95	 5.35	 34.2	 -23.5	 1.0	 100.0	 1	 70.6	 33.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.6; % PEL
	13937	 75.85	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 56.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0; % NG
	13938	 60.5	 5.1	 32.7	 -22.5	 1.0	 100.0	 1	 67.5	 53.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5; % PEL
	13938	 60.5	 5.1	 32.7	 -22.5	 1.0	 100.0	 1	 67.5	 53.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5; % NG
	13940	 14.75	 3.125	 11.25	 -5.0	 1.0	 100.0	 1	 15.0	 14.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % COW
	13940	 14.75	 3.125	 11.25	 -5.0	 1.0	 100.0	 1	 15.0	 14.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % COW
	13940	 14.75	 3.125	 11.25	 -5.0	 1.0	 100.0	 1	 15.0	 14.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % NG
	13940	 14.75	 3.125	 11.25	 -5.0	 1.0	 100.0	 1	 15.0	 14.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % COW
	13941	 34.9	 4.35	 28.0	 -19.3	 1.0	 100.0	 1	 57.8	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.8; % NG
	13942	 28.7	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % NG
	13942	 28.7	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % PEL
	13943	 42.65	 8.2	 35.5	 -19.1	 1.0	 100.0	 1	 57.3	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.3; % NG
	13943	 42.65	 8.2	 35.5	 -19.1	 1.0	 100.0	 1	 57.3	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.3; % NG
	13943	 42.65	 8.2	 35.5	 -19.1	 1.0	 100.0	 1	 57.3	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.3; % NG
	13943	 42.65	 8.2	 35.5	 -19.1	 1.0	 100.0	 1	 57.3	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.3; % NG
	13943	 42.65	 8.2	 35.5	 -19.1	 1.0	 100.0	 1	 57.3	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.3; % NG
	13943	 42.65	 8.2	 35.5	 -19.1	 1.0	 100.0	 1	 57.3	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.3; % NG
	13945	 29.5	 0.0	 13.5	 -13.5	 1.0	 100.0	 1	 54.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	13946	 5.775	 1.825	 6.57	 -2.92	 1.0	 100.0	 1	 8.75	 2.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.75; % NG
	13946	 5.775	 1.825	 6.57	 -2.92	 1.0	 100.0	 1	 8.75	 2.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.75; % NG
	13946	 5.775	 1.825	 6.57	 -2.92	 1.0	 100.0	 1	 8.75	 2.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.75; % NG
	13946	 5.775	 1.825	 6.57	 -2.92	 1.0	 100.0	 1	 8.75	 2.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.75; % NG
	13946	 5.775	 1.825	 6.57	 -2.92	 1.0	 100.0	 1	 8.75	 2.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.75; % NG
	13946	 5.775	 1.825	 6.57	 -2.92	 1.0	 100.0	 1	 8.75	 2.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.75; % NG
	13948	 37.5	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % COW
	13949	 31.05	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 16.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % NG
	13949	 31.05	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 16.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % NG
	13949	 49.615	 15.3	 55.1	 -24.5	 1.0	 100.0	 1	 73.5	 25.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 73.5; % NG
	13950	 22.2	 9.25	 33.3	 -14.8	 1.0	 100.0	 1	 44.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.4; % NG
	13950	 22.2	 9.25	 33.3	 -14.8	 1.0	 100.0	 1	 44.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.4; % NG
	13950	 22.2	 9.25	 33.3	 -14.8	 1.0	 100.0	 1	 44.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.4; % NG
	13950	 22.2	 9.25	 33.3	 -14.8	 1.0	 100.0	 1	 44.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.4; % NG
	13951	 23.55	 6.3	 27.3	 -14.7	 1.0	 100.0	 1	 44.1	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.1; % COW
	13953	 43.2	 9.0	 32.4	 -14.4	 1.0	 100.0	 1	 43.2	 43.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.2; % NG
	13954	 9.5	 1.05	 6.77	 -4.67	 1.0	 100.0	 1	 14.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0; % NG
	13954	 9.5	 1.05	 6.77	 -4.67	 1.0	 100.0	 1	 14.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0; % PEL
	13954	 9.5	 1.05	 6.77	 -4.67	 1.0	 100.0	 1	 14.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0; % NG
	13955	 86.875	 26.05	 93.8	 -41.7	 1.0	 100.0	 1	 125.0	 48.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	13955	 86.875	 26.05	 93.8	 -41.7	 1.0	 100.0	 1	 125.0	 48.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	13955	 24.88	 3.9	 19.4	 -11.6	 1.0	 100.0	 1	 34.8	 14.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.8; % PEL
	13955	 24.88	 3.9	 19.4	 -11.6	 1.0	 100.0	 1	 34.8	 14.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.8; % NG
	13955	 24.88	 3.9	 19.4	 -11.6	 1.0	 100.0	 1	 34.8	 14.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.8; % PEL
	13955	 27.0	 5.5	 24.3	 -13.3	 1.0	 100.0	 1	 40.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	13955	 54.0	 10.9	 48.5	 -26.7	 1.0	 100.0	 1	 80.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % NG
	13956	 27.0	 5.5	 24.3	 -13.3	 1.0	 100.0	 1	 40.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	13956	 27.0	 5.5	 24.3	 -13.3	 1.0	 100.0	 1	 40.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % PEL
	13956	 43.875	 8.85	 39.4	 -21.7	 1.0	 100.0	 1	 65.0	 22.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.0; % NG
	13956	 43.875	 8.85	 39.4	 -21.7	 1.0	 100.0	 1	 65.0	 22.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.0; % PEL
	13956	 373.0	 46.9	 300.8	 -207.0	 1.0	 100.0	 1	 621.0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 621.0; % COW
	13957	 49.0	 7.75	 33.5	 -18.0	 1.0	 100.0	 1	 54.0	 44.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	13957	 32.0	 5.75	 24.8	 -13.3	 1.0	 100.0	 1	 40.0	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % COW
	13957	 69.0	 12.3	 53.3	 -28.7	 1.0	 100.0	 1	 86.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0; % NG
	13958	 18.0	 3.75	 13.5	 -6.0	 1.0	 100.0	 1	 18.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	13958	 18.0	 3.75	 13.5	 -6.0	 1.0	 100.0	 1	 18.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	13959	 36.0	 7.5	 27.0	 -12.0	 1.0	 100.0	 1	 36.0	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0; % NG
	13959	 36.0	 7.5	 27.0	 -12.0	 1.0	 100.0	 1	 36.0	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0; % NG
	13959	 36.0	 7.5	 27.0	 -12.0	 1.0	 100.0	 1	 36.0	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0; % NG
	13960	 18.85	 4.95	 21.5	 -11.6	 1.0	 100.0	 1	 34.7	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.7; % NG
	13961	 19.85	 4.95	 21.5	 -11.6	 1.0	 100.0	 1	 34.7	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.7; % COW
	13962	 8.0	 0.0	 4.23	 -4.23	 1.0	 100.0	 1	 11.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0; % PEL
	13962	 8.0	 0.0	 4.23	 -4.23	 1.0	 100.0	 1	 11.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0; % PEL
	13962	 8.0	 0.0	 4.23	 -4.23	 1.0	 100.0	 1	 11.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0; % NG
	13963	 7.735	 1.2	 5.9	 -3.5	 1.0	 100.0	 1	 10.47	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.4667; % PEL
	13963	 7.735	 1.2	 5.9	 -3.5	 1.0	 100.0	 1	 10.47	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.4667; % PEL
	13963	 7.735	 1.2	 5.9	 -3.5	 1.0	 100.0	 1	 10.47	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.4667; % NG
	13964	 8.0	 0.0	 4.95	 -4.95	 1.0	 100.0	 1	 15.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % NG
	13964	 8.0	 0.0	 4.95	 -4.95	 1.0	 100.0	 1	 15.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % NG
	13965	 24.85	 4.25	 18.4	 -9.9	 1.0	 100.0	 1	 29.7	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.7; % NG
	13966	 14.9	 2.15	 13.9	 -9.6	 1.0	 100.0	 1	 28.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % PEL
	13966	 14.9	 2.15	 13.9	 -9.6	 1.0	 100.0	 1	 28.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % NG
	13966	 14.9	 2.15	 13.9	 -9.6	 1.0	 100.0	 1	 28.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % NG
	13966	 14.9	 2.15	 13.9	 -9.6	 1.0	 100.0	 1	 28.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % PEL
	13966	 14.9	 2.15	 13.9	 -9.6	 1.0	 100.0	 1	 28.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % NG
	13966	 14.9	 2.15	 13.9	 -9.6	 1.0	 100.0	 1	 28.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % NG
	13966	 14.9	 2.15	 13.9	 -9.6	 1.0	 100.0	 1	 28.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % NG
	13966	 14.9	 2.15	 13.9	 -9.6	 1.0	 100.0	 1	 28.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % PEL
	13966	 44.0	 5.55	 35.4	 -24.3	 1.0	 100.0	 1	 73.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 73.0; % PEL
	13968	 15.15	 2.15	 13.7	 -9.4	 1.0	 100.0	 1	 28.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.3; % NG
	13969	 17.5	 4.05	 17.4	 -9.3	 1.0	 100.0	 1	 28.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0; % NG
	13970	 19.59	 3.1	 15.3	 -9.1	 1.0	 100.0	 1	 27.4	 11.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.4; % PEL
	13970	 25.17	 4.0	 19.7	 -11.7	 1.0	 100.0	 1	 35.2	 15.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.2; % PEL
	13970	 25.17	 4.0	 19.7	 -11.7	 1.0	 100.0	 1	 35.2	 15.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.2; % NG
	13971	 13.0	 0.975	 6.3	 -4.35	 1.0	 100.0	 1	 13.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0; % PEL
	13971	 13.0	 0.975	 6.3	 -4.35	 1.0	 100.0	 1	 13.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0; % NG
	13972	 8.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 8.6	 8.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.6; % PEL
	13972	 8.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 8.6	 8.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.6; % NG
	13972	 8.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 8.6	 8.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.6; % NG
	13973	 8.5	 0.0	 2.8	 -2.8	 1.0	 100.0	 1	 8.5	 8.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.5; % NG
	13973	 8.5	 0.0	 2.8	 -2.8	 1.0	 100.0	 1	 8.5	 8.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.5; % NG
	13973	 8.5	 0.0	 2.8	 -2.8	 1.0	 100.0	 1	 8.5	 8.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.5; % NG
	13974	 17.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	13974	 17.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % COW
	13974	 17.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	13974	 17.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	13975	 3.8	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 3.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1; % NG
	13975	 14.75	 2.515	 10.85	 -5.82	 1.0	 100.0	 1	 17.5	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % PEL
	13975	 3.8	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 3.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1; % PEL
	13975	 3.8	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 3.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1; % PEL
	13975	 3.8	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 3.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1; % NG
	13975	 3.8	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 3.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1; % PEL
	13975	 3.8	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 3.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1; % NG
	13975	 14.75	 2.515	 10.85	 -5.82	 1.0	 100.0	 1	 17.5	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % NG
	13975	 14.75	 2.515	 10.85	 -5.82	 1.0	 100.0	 1	 17.5	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % COW
	13975	 14.75	 2.515	 10.85	 -5.82	 1.0	 100.0	 1	 17.5	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % NG
	13976	 16.84	 2.45	 12.8	 -7.9	 1.0	 100.0	 1	 23.8	 9.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % NG
	13976	 16.84	 2.45	 12.8	 -7.9	 1.0	 100.0	 1	 23.8	 9.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % PEL
	13977	 22.0	 4.6	 16.5	 -7.3	 1.0	 100.0	 1	 22.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	13977	 21.5	 4.6	 16.5	 -7.3	 1.0	 100.0	 1	 22.0	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	13977	 20.0	 4.6	 16.5	 -7.3	 1.0	 100.0	 1	 22.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	13978	 20.65	 4.5	 16.2	 -7.2	 1.0	 100.0	 1	 21.6	 19.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6; % PEL
	13979	 13.6	 0.0	 8.8	 -8.8	 1.0	 100.0	 1	 20.0	 7.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	13979	 13.6	 0.0	 8.8	 -8.8	 1.0	 100.0	 1	 20.0	 7.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	13979	 13.6	 0.0	 8.8	 -8.8	 1.0	 100.0	 1	 20.0	 7.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	13979	 13.6	 0.0	 8.8	 -8.8	 1.0	 100.0	 1	 20.0	 7.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	13979	 22.5	 6.25	 22.5	 -10.0	 1.0	 100.0	 1	 30.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0; % PEL
	13980	 582.35	 73.95	 474.5	 -326.6	 1.0	 100.0	 1	 979.7	 185.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NUC
	13980	 582.35	 73.95	 474.5	 -326.6	 1.0	 100.0	 1	 979.7	 185.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	13981	 76.8	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % NG
	13981	 503.5	 66.6	 427.2	 -294.0	 1.0	 100.0	 1	 882.0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 882.0; % COW
	13981	 149.65	 34.25	 148.3	 -79.8	 1.0	 100.0	 1	 239.3	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 239.3; % NG
	13981	 80.07	 11.515	 69.6	 -46.57	 1.0	 100.0	 1	 139.71	 20.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 139.7143; % NG
	13981	 80.07	 11.515	 69.6	 -46.57	 1.0	 100.0	 1	 139.71	 20.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 139.7143; % COW
	13981	 80.07	 11.515	 69.6	 -46.57	 1.0	 100.0	 1	 139.71	 20.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 139.7143; % COW
	13981	 80.07	 11.515	 69.6	 -46.57	 1.0	 100.0	 1	 139.71	 20.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 139.7143; % NG
	13981	 80.07	 11.515	 69.6	 -46.57	 1.0	 100.0	 1	 139.71	 20.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 139.7143; % NG
	13981	 80.07	 11.515	 69.6	 -46.57	 1.0	 100.0	 1	 139.71	 20.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 139.7143; % NG
	13981	 80.07	 11.515	 69.6	 -46.57	 1.0	 100.0	 1	 139.71	 20.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 139.7143; % NG
	13982	 518.25	 64.0	 410.5	 -282.5	 1.0	 100.0	 1	 847.5	 189.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	13982	 518.25	 64.0	 410.5	 -282.5	 1.0	 100.0	 1	 847.5	 189.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	13983	 342.0	 36.0	 231.0	 -159.0	 1.0	 100.0	 1	 477.0	 207.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 477.0; % PEL
	13983	 342.0	 36.0	 231.0	 -159.0	 1.0	 100.0	 1	 477.0	 207.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 477.0; % COW
	13983	 342.0	 36.0	 231.0	 -159.0	 1.0	 100.0	 1	 477.0	 207.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 477.0; % NG
	13983	 342.0	 36.0	 231.0	 -159.0	 1.0	 100.0	 1	 477.0	 207.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 477.0; % PEL
	13983	 342.0	 36.0	 231.0	 -159.0	 1.0	 100.0	 1	 477.0	 207.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 477.0; % COW
	13983	 342.0	 36.0	 231.0	 -159.0	 1.0	 100.0	 1	 477.0	 207.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 477.0; % COW
	13984	 277.0	 32.05	 205.4	 -141.3	 1.0	 100.0	 1	 424.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 424.0; % COW
	13984	 277.0	 32.05	 205.4	 -141.3	 1.0	 100.0	 1	 424.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 424.0; % NG
	13985	 164.15	 19.5	 125.1	 -86.1	 1.0	 100.0	 1	 258.3	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 258.3; % NG
	13986	 148.75	 49.45	 178.1	 -79.2	 1.0	 100.0	 1	 237.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.5; % NG
	13986	 148.75	 49.45	 178.1	 -79.2	 1.0	 100.0	 1	 237.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.5; % NG
	13986	 148.75	 49.45	 178.1	 -79.2	 1.0	 100.0	 1	 237.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.5; % NG
	13987	 136.25	 14.15	 90.8	 -62.5	 1.0	 100.0	 1	 187.5	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.5; % NG
	13987	 136.25	 26.85	 116.2	 -62.5	 1.0	 100.0	 1	 187.5	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.5; % NG
	13987	 536.0	 66.6	 427.2	 -294.0	 1.0	 100.0	 1	 882.0	 190.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 882.0; % COW
	13988	 141.65	 26.25	 113.6	 -61.1	 1.0	 100.0	 1	 183.3	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.3; % NG
	13988	 141.65	 26.25	 113.6	 -61.1	 1.0	 100.0	 1	 183.3	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.3; % NG
	13988	 141.65	 26.25	 113.6	 -61.1	 1.0	 100.0	 1	 183.3	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.3; % NG
	13988	 223.1	 29.9	 191.9	 -132.1	 1.0	 100.0	 1	 396.2	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 396.2; % COW
	13989	 134.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	13989	 134.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	13989	 134.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	13989	 134.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	13989	 134.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	13990	 134.05	 24.5	 106.0	 -57.0	 1.0	 100.0	 1	 171.1	 97.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 171.1; % NG
	13990	 133.55	 24.5	 106.0	 -57.0	 1.0	 100.0	 1	 171.1	 96.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 171.1; % NG
	13990	 133.55	 24.5	 106.0	 -57.0	 1.0	 100.0	 1	 171.1	 96.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 171.1; % NG
	13991	 130.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	13991	 134.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	13991	 134.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	13991	 134.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	13992	 14.635	 2.915	 12.6	 -6.77	 1.0	 100.0	 1	 20.33	 8.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.325; % NG
	13992	 86.75	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 61.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % NG
	13992	 86.75	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 61.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % NG
	13992	 16.84	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 9.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % PEL
	13992	 16.84	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 9.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % PEL
	13992	 16.84	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 9.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % PEL
	13992	 16.84	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 9.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % PEL
	13992	 202.15	 34.25	 148.3	 -79.8	 1.0	 100.0	 1	 239.3	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 239.3; % NG
	13992	 14.635	 2.915	 12.6	 -6.77	 1.0	 100.0	 1	 20.33	 8.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.325; % NG
	13992	 14.635	 2.915	 12.6	 -6.77	 1.0	 100.0	 1	 20.33	 8.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.325; % PEL
	13992	 14.635	 2.915	 12.6	 -6.77	 1.0	 100.0	 1	 20.33	 8.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.325; % NG
	13992	 14.635	 2.915	 12.6	 -6.77	 1.0	 100.0	 1	 20.33	 8.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.325; % PEL
	13992	 14.635	 2.915	 12.6	 -6.77	 1.0	 100.0	 1	 20.33	 8.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.325; % PEL
	13992	 14.635	 2.915	 12.6	 -6.77	 1.0	 100.0	 1	 20.33	 8.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.325; % NG
	13992	 14.635	 2.915	 12.6	 -6.77	 1.0	 100.0	 1	 20.33	 8.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.325; % NG
	13992	 139.6	 26.55	 114.8	 -61.7	 1.0	 100.0	 1	 185.2	 94.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.2; % NG
	13993	 65.5	 0.0	 21.7	 -21.7	 1.0	 100.0	 1	 66.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.0; % PEL
	13993	 65.5	 0.0	 21.7	 -21.7	 1.0	 100.0	 1	 66.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.0; % PEL
	13993	 144.06	 0.0	 49.3	 -49.3	 1.0	 100.0	 1	 150.1	 138.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.1; % NG
	13993	 144.06	 0.0	 49.3	 -49.3	 1.0	 100.0	 1	 150.1	 138.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.1; % NG
	13993	 110.15	 0.0	 37.9	 -37.9	 1.0	 100.0	 1	 115.3	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.3; % COW
	13994	 103.8	 9.8	 62.8	 -43.2	 1.0	 100.0	 1	 129.6	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.6; % COW
	13994	 103.8	 9.8	 62.8	 -43.2	 1.0	 100.0	 1	 129.6	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.6; % PEL
	13994	 103.8	 9.8	 62.8	 -43.2	 1.0	 100.0	 1	 129.6	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.6; % COW
	13995	 130.75	 14.15	 90.6	 -62.3	 1.0	 100.0	 1	 187.0	 74.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.0; % NG
	13995	 80.35	 9.95	 63.9	 -44.0	 1.0	 100.0	 1	 132.0	 28.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.0; % COW
	13995	 80.35	 9.95	 63.9	 -44.0	 1.0	 100.0	 1	 132.0	 28.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.0; % COW
	13995	 97.65	 17.45	 75.6	 -40.7	 1.0	 100.0	 1	 122.0	 73.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % NG
	13995	 97.65	 17.45	 75.6	 -40.7	 1.0	 100.0	 1	 122.0	 73.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % NG
	13995	 97.65	 17.45	 75.6	 -40.7	 1.0	 100.0	 1	 122.0	 73.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % NG
	13995	 97.65	 17.45	 75.6	 -40.7	 1.0	 100.0	 1	 122.0	 73.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % NG
	13996	 138.75	 26.85	 116.2	 -62.5	 1.0	 100.0	 1	 187.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.5; % NG
	13996	 106.5	 10.95	 70.2	 -48.3	 1.0	 100.0	 1	 145.0	 68.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 145.0; % COW
	13996	 105.5	 11.2	 71.7	 -49.3	 1.0	 100.0	 1	 148.0	 63.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 148.0; % NG
	13996	 73.75	 16.1	 69.7	 -37.5	 1.0	 100.0	 1	 112.5	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % NG
	13996	 546.95	 52.4	 336.1	 -231.3	 1.0	 100.0	 1	 693.9	 400.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 693.9; % COW
	13996	 272.5	 51.4	 222.5	 -119.7	 1.0	 100.0	 1	 359.0	 186.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 359.0; % COW
	13996	 58.1	 6.0	 38.4	 -26.4	 1.0	 100.0	 1	 79.2	 37.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 79.2; % NG
	13996	 53.2	 5.6	 36.0	 -24.8	 1.0	 100.0	 1	 74.4	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.4; % PEL
	13998	 16.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	13998	 28.0	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % PEL
	13998	 13.08	 3.09	 12.92	 -6.74	 1.0	 100.0	 1	 20.2	 5.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.2; % NG
	13998	 13.08	 3.09	 12.92	 -6.74	 1.0	 100.0	 1	 20.2	 5.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.2; % PEL
	13998	 13.08	 3.09	 12.92	 -6.74	 1.0	 100.0	 1	 20.2	 5.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.2; % PEL
	13998	 13.08	 3.09	 12.92	 -6.74	 1.0	 100.0	 1	 20.2	 5.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.2; % PEL
	13998	 13.08	 3.09	 12.92	 -6.74	 1.0	 100.0	 1	 20.2	 5.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.2; % COW
	13999	 75.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 96.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.0; % NG
	13999	 78.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 101.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.0; % NG
	13999	 78.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 101.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.0; % NG
	13999	 78.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 101.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.0; % NG
	14000	 62.5	 7.55	 48.4	 -33.3	 1.0	 100.0	 1	 100.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0; % NG
	14000	 156.25	 49.45	 178.1	 -79.2	 1.0	 100.0	 1	 237.5	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.5; % COW
	14001	 17.325	 3.1	 15.4	 -9.2	 1.0	 100.0	 1	 27.5	 7.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % NG
	14001	 20.55	 5.2	 22.4	 -12.0	 1.0	 100.0	 1	 36.1	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.1; % PEL
	14001	 8.105	 1.63	 8.0	 -4.74	 1.0	 100.0	 1	 14.24	 1.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2429; % NG
	14001	 8.105	 1.63	 8.0	 -4.74	 1.0	 100.0	 1	 14.24	 1.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2429; % COW
	14001	 8.105	 1.63	 8.0	 -4.74	 1.0	 100.0	 1	 14.24	 1.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2429; % NG
	14001	 8.105	 1.63	 8.0	 -4.74	 1.0	 100.0	 1	 14.24	 1.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2429; % PEL
	14001	 8.105	 1.63	 8.0	 -4.74	 1.0	 100.0	 1	 14.24	 1.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2429; % NG
	14001	 8.105	 1.63	 8.0	 -4.74	 1.0	 100.0	 1	 14.24	 1.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2429; % COW
	14001	 8.105	 1.63	 8.0	 -4.74	 1.0	 100.0	 1	 14.24	 1.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2429; % NG
	14003	 66.05	 6.95	 44.6	 -30.7	 1.0	 100.0	 1	 92.1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 92.1; % NG
	14003	 66.05	 6.95	 44.6	 -30.7	 1.0	 100.0	 1	 92.1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 92.1; % NG
	14003	 66.05	 6.95	 44.6	 -30.7	 1.0	 100.0	 1	 92.1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 92.1; % COW
	14003	 66.05	 6.95	 44.6	 -30.7	 1.0	 100.0	 1	 92.1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 92.1; % COW
	14005	 65.25	 12.1	 52.4	 -28.2	 1.0	 100.0	 1	 84.5	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % PEL
	14005	 65.25	 12.1	 52.4	 -28.2	 1.0	 100.0	 1	 84.5	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % COW
	14005	 65.25	 12.1	 52.4	 -28.2	 1.0	 100.0	 1	 84.5	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	14005	 65.25	 12.1	 52.4	 -28.2	 1.0	 100.0	 1	 84.5	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % PEL
	14005	 133.05	 24.5	 106.0	 -57.0	 1.0	 100.0	 1	 171.1	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 171.1; % NG
	14006	 16.35	 1.415	 9.05	 -6.22	 1.0	 100.0	 1	 18.7	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.7; % PEL
	14006	 16.35	 1.415	 9.05	 -6.22	 1.0	 100.0	 1	 18.7	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.7; % NG
	14006	 16.35	 1.415	 9.05	 -6.22	 1.0	 100.0	 1	 18.7	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.7; % PEL
	14006	 16.35	 1.415	 9.05	 -6.22	 1.0	 100.0	 1	 18.7	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.7; % PEL
	14007	 45.55	 10.2	 44.1	 -23.7	 1.0	 100.0	 1	 71.1	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.1; % NG
	14008	 45.55	 10.2	 44.1	 -23.7	 1.0	 100.0	 1	 71.1	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.1; % PEL
	14009	 45.55	 10.2	 44.1	 -23.7	 1.0	 100.0	 1	 71.1	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.1; % PEL
	14010	 42.95	 5.3	 33.9	 -23.3	 1.0	 100.0	 1	 69.9	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.9; % NG
	14010	 42.95	 5.3	 33.9	 -23.3	 1.0	 100.0	 1	 69.9	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.9; % NG
	14011	 125.1	 16.6	 94.9	 -61.7	 1.0	 100.0	 1	 185.2	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.2; % NG
	14011	 52.0	 6.15	 35.3	 -23.0	 1.0	 100.0	 1	 69.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % NG
	14012	 8.905	 2.24	 9.93	 -5.45	 1.0	 100.0	 1	 16.37	 1.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.375; % NG
	14012	 8.905	 2.24	 9.93	 -5.45	 1.0	 100.0	 1	 16.37	 1.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.375; % PEL
	14012	 8.905	 2.24	 9.93	 -5.45	 1.0	 100.0	 1	 16.37	 1.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.375; % NG
	14012	 8.905	 2.24	 9.93	 -5.45	 1.0	 100.0	 1	 16.37	 1.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.375; % NG
	14012	 18.5	 4.9	 21.1	 -11.3	 1.0	 100.0	 1	 34.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.0; % PEL
	14012	 18.5	 4.9	 21.1	 -11.3	 1.0	 100.0	 1	 34.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.0; % PEL
	14013	 36.0	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	14013	 36.0	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	14014	 46.25	 8.2	 35.6	 -19.2	 1.0	 100.0	 1	 57.5	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.5; % PEL
	14014	 46.25	 8.2	 35.6	 -19.2	 1.0	 100.0	 1	 57.5	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.5; % PEL
	14014	 46.25	 8.2	 35.6	 -19.2	 1.0	 100.0	 1	 57.5	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.5; % PEL
	14014	 46.25	 8.2	 35.6	 -19.2	 1.0	 100.0	 1	 57.5	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.5; % NG
	14014	 46.25	 8.2	 35.6	 -19.2	 1.0	 100.0	 1	 57.5	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.5; % PEL
	14014	 46.25	 8.2	 35.6	 -19.2	 1.0	 100.0	 1	 57.5	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.5; % NG
	14014	 46.25	 8.2	 35.6	 -19.2	 1.0	 100.0	 1	 57.5	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.5; % NG
	14015	 41.2	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % NG
	14015	 41.2	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % PEL
	14016	 28.7	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % NG
	14016	 28.7	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % NG
	14017	 31.2	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % PEL
	14017	 31.2	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % NG
	14017	 31.2	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % NG
	14017	 31.2	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % PEL
	14018	 41.0	 8.15	 35.3	 -19.0	 1.0	 100.0	 1	 57.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % NG
	14018	 41.0	 8.15	 35.3	 -19.0	 1.0	 100.0	 1	 57.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % NG
	14018	 41.0	 8.15	 35.3	 -19.0	 1.0	 100.0	 1	 57.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % NG
	14018	 41.0	 8.15	 35.3	 -19.0	 1.0	 100.0	 1	 57.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % PEL
	14018	 41.0	 8.15	 35.3	 -19.0	 1.0	 100.0	 1	 57.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % PEL
	14020	 39.4	 3.55	 22.7	 -15.6	 1.0	 100.0	 1	 46.8	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.8; % NG
	14020	 39.4	 3.55	 22.7	 -15.6	 1.0	 100.0	 1	 46.8	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.8; % NG
	14020	 39.4	 3.55	 22.7	 -15.6	 1.0	 100.0	 1	 46.8	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.8; % NG
	14020	 39.4	 3.55	 22.7	 -15.6	 1.0	 100.0	 1	 46.8	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.8; % PEL
	14020	 39.4	 3.55	 22.7	 -15.6	 1.0	 100.0	 1	 46.8	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.8; % NG
	14020	 39.4	 3.55	 22.7	 -15.6	 1.0	 100.0	 1	 46.8	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.8; % COW
	14021	 37.5	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	14021	 37.5	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % PEL
	14022	 24.0	 3.3	 21.3	 -14.7	 1.0	 100.0	 1	 44.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0; % NG
	14022	 24.0	 3.3	 21.3	 -14.7	 1.0	 100.0	 1	 44.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0; % PEL
	14023	 8.0	 1.075	 7.0	 -4.85	 1.0	 100.0	 1	 14.5	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.5; % COW
	14023	 8.0	 1.075	 7.0	 -4.85	 1.0	 100.0	 1	 14.5	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.5; % PEL
	14024	 4.4	 1.7	 5.67	 -2.27	 1.0	 100.0	 1	 6.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8; % NG
	14024	 4.4	 1.7	 5.67	 -2.27	 1.0	 100.0	 1	 6.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8; % NG
	14024	 4.4	 1.7	 5.67	 -2.27	 1.0	 100.0	 1	 6.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8; % NG
	14024	 4.4	 1.7	 5.67	 -2.27	 1.0	 100.0	 1	 6.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8; % NG
	14025	 16.0	 5.65	 20.3	 -9.0	 1.0	 100.0	 1	 27.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % NG
	14027	 2.25	 0.835	 3.0	 -1.33	 1.0	 100.0	 1	 4.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.0; % NG
	14027	 2.25	 0.835	 3.0	 -1.33	 1.0	 100.0	 1	 4.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.0; % PEL
	14027	 2.25	 0.835	 3.0	 -1.33	 1.0	 100.0	 1	 4.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.0; % NG
	14027	 2.25	 0.835	 3.0	 -1.33	 1.0	 100.0	 1	 4.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.0; % PEL
	14027	 2.25	 0.835	 3.0	 -1.33	 1.0	 100.0	 1	 4.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.0; % NG
	14027	 2.25	 0.835	 3.0	 -1.33	 1.0	 100.0	 1	 4.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.0; % PEL
	14028	 3.2	 0.41	 2.62	 -1.8	 1.0	 100.0	 1	 5.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.4; % NG
	14028	 3.2	 0.41	 2.62	 -1.8	 1.0	 100.0	 1	 5.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.4; % PEL
	14028	 3.2	 0.41	 2.62	 -1.8	 1.0	 100.0	 1	 5.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.4; % PEL
	14028	 3.2	 0.41	 2.62	 -1.8	 1.0	 100.0	 1	 5.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.4; % NG
	14030	 3.665	 1.43	 5.13	 -2.27	 1.0	 100.0	 1	 6.83	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8333; % NG
	14030	 3.665	 1.43	 5.13	 -2.27	 1.0	 100.0	 1	 6.83	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8333; % NG
	14030	 3.665	 1.43	 5.13	 -2.27	 1.0	 100.0	 1	 6.83	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8333; % NG
	14031	 19.2	 4.15	 15.0	 -6.7	 1.0	 100.0	 1	 20.0	 18.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	14031	 19.2	 4.15	 15.0	 -6.7	 1.0	 100.0	 1	 20.0	 18.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	14032	 11.0	 4.15	 15.0	 -6.7	 1.0	 100.0	 1	 20.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	14032	 11.0	 4.15	 15.0	 -6.7	 1.0	 100.0	 1	 20.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	14032	 11.0	 4.15	 15.0	 -6.7	 1.0	 100.0	 1	 20.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	14033	 900.0	 98.15	 629.6	 -433.3	 1.0	 100.0	 1	 1300.0	 500.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1300.0; % COW
	14034	 950.0	 98.15	 629.6	 -433.3	 1.0	 100.0	 1	 1300.0	 600.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1300.0; % COW
	14034	 558.15	 61.65	 395.4	 -272.1	 1.0	 100.0	 1	 816.3	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 816.3; % NUC
	14034	 558.15	 61.65	 395.4	 -272.1	 1.0	 100.0	 1	 816.3	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 816.3; % COW
	14035	 613.15	 61.65	 395.4	 -272.1	 1.0	 100.0	 1	 816.3	 410.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 816.3; % COW
	14035	 593.15	 61.65	 395.4	 -272.1	 1.0	 100.0	 1	 816.3	 370.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 816.3; % COW
	14036	 529.5	 0.0	 291.4	 -291.4	 1.0	 100.0	 1	 684.0	 375.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 684.0; % COW
	14036	 529.5	 0.0	 291.4	 -291.4	 1.0	 100.0	 1	 684.0	 375.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 684.0; % COW
	14036	 529.5	 0.0	 291.4	 -291.4	 1.0	 100.0	 1	 684.0	 375.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 684.0; % COW
	14037	 529.5	 51.65	 331.3	 -228.0	 1.0	 100.0	 1	 684.0	 375.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 684.0; % COW
	14037	 529.5	 51.65	 331.3	 -228.0	 1.0	 100.0	 1	 684.0	 375.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 684.0; % COW
	14038	 398.0	 43.5	 279.0	 -192.0	 1.0	 100.0	 1	 576.0	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 576.0; % COW
	14038	 398.0	 43.5	 279.0	 -192.0	 1.0	 100.0	 1	 576.0	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 576.0; % COW
	14039	 411.0	 39.4	 252.8	 -174.0	 1.0	 100.0	 1	 522.0	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 522.0; % NG
	14039	 417.6	 43.05	 276.2	 -190.1	 1.0	 100.0	 1	 570.2	 265.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 570.2; % NG
	14039	 417.6	 43.05	 276.2	 -190.1	 1.0	 100.0	 1	 570.2	 265.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 570.2; % COW
	14040	 168.75	 49.45	 178.1	 -79.2	 1.0	 100.0	 1	 237.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.5; % NG
	14040	 168.75	 49.45	 178.1	 -79.2	 1.0	 100.0	 1	 237.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.5; % NG
	14040	 168.75	 49.45	 178.1	 -79.2	 1.0	 100.0	 1	 237.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.5; % NG
	14042	 151.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0; % NG
	14042	 151.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0; % NG
	14043	 101.25	 31.8	 114.4	 -50.8	 1.0	 100.0	 1	 152.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 152.5; % NG
	14043	 101.25	 31.8	 114.4	 -50.8	 1.0	 100.0	 1	 152.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 152.5; % NG
	14043	 101.25	 31.8	 114.4	 -50.8	 1.0	 100.0	 1	 152.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 152.5; % NG
	14043	 101.25	 31.8	 114.4	 -50.8	 1.0	 100.0	 1	 152.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 152.5; % NG
	14043	 382.75	 70.95	 307.1	 -165.2	 1.0	 100.0	 1	 495.5	 270.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 495.5; % NG
	14044	 50.25	 0.0	 44.3	 -44.3	 1.0	 100.0	 1	 100.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	14045	 54.3	 0.0	 44.1	 -44.1	 1.0	 100.0	 1	 100.0	 8.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	14045	 86.3	 0.0	 72.3	 -72.3	 1.0	 100.0	 1	 164.0	 8.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	14047	 75.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	14047	 75.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % PEL
	14047	 75.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	14047	 75.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % COW
	14047	 75.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	14047	 75.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	14049	 97.44	 26.3	 99.3	 -46.7	 1.0	 100.0	 1	 140.2	 54.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.2; % COW
	14049	 46.575	 9.45	 41.9	 -23.0	 1.0	 100.0	 1	 69.0	 24.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % PEL
	14049	 46.575	 9.45	 41.9	 -23.0	 1.0	 100.0	 1	 69.0	 24.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % NG
	14050	 44.45	 9.85	 42.7	 -23.0	 1.0	 100.0	 1	 68.9	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.9; % PEL
	14051	 34.65	 0.0	 26.1	 -26.1	 1.0	 100.0	 1	 66.0	 3.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	14052	 41.95	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % PEL
	14052	 41.95	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % COW
	14052	 41.95	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % PEL
	14052	 41.95	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % PEL
	14052	 41.95	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % PEL
	14052	 41.95	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % NG
	14053	 113.425	 30.6	 115.6	 -54.4	 1.0	 100.0	 1	 163.2	 63.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2; % COW
	14053	 33.75	 6.8	 30.3	 -16.7	 1.0	 100.0	 1	 50.0	 17.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	14058	 13.75	 1.95	 12.4	 -8.5	 1.0	 100.0	 1	 25.5	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5; % NG
	14058	 13.75	 1.95	 12.4	 -8.5	 1.0	 100.0	 1	 25.5	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5; % NG
	14058	 13.75	 1.95	 12.4	 -8.5	 1.0	 100.0	 1	 25.5	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5; % NG
	14058	 13.75	 1.95	 12.4	 -8.5	 1.0	 100.0	 1	 25.5	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5; % PEL
	14060	 12.0	 1.6	 10.2	 -7.0	 1.0	 100.0	 1	 21.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0; % NG
	14060	 12.0	 1.6	 10.2	 -7.0	 1.0	 100.0	 1	 21.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0; % PEL
	20401	 900.0	 98.15	 629.6	 -433.3	 1.0	 100.0	 1	 1300.0	 500.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1300.0; % COW
	20401	 0.0	 0.0	 629.6	 -433.3	 1.0	 100.0	 0	 1300.0	 500.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1300.0; % COW
	20402	 458.95	 50.45	 323.5	 -222.6	 1.0	 100.0	 1	 667.9	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 667.9; % COW
	20402	 458.95	 50.45	 323.5	 -222.6	 1.0	 100.0	 1	 667.9	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 667.9; % COW
	20402	 458.95	 50.45	 323.5	 -222.6	 1.0	 100.0	 1	 667.9	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 667.9; % NG
	20402	 448.95	 50.45	 323.5	 -222.6	 1.0	 100.0	 1	 667.9	 230.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 667.9; % COW
	20402	 448.95	 50.45	 323.5	 -222.6	 1.0	 100.0	 1	 667.9	 230.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 667.9; % COW
	20403	 44.975	 8.45	 40.2	 -23.3	 1.0	 100.0	 1	 70.0	 19.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0; % NG
	20403	 44.975	 8.45	 40.2	 -23.3	 1.0	 100.0	 1	 70.0	 19.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0; % NG
	20403	 425.0	 40.75	 261.5	 -180.0	 1.0	 100.0	 1	 540.0	 310.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 540.0; % NG
	20404	 400.0	 40.75	 261.5	 -180.0	 1.0	 100.0	 1	 540.0	 260.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 540.0; % COW
	20404	 400.0	 40.75	 261.5	 -180.0	 1.0	 100.0	 1	 540.0	 260.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 540.0; % COW
	20405	 83.75	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % NG
	20405	 415.5	 40.1	 257.2	 -177.0	 1.0	 100.0	 1	 531.0	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 531.0; % PEL
	20405	 380.5	 40.1	 257.2	 -177.0	 1.0	 100.0	 1	 531.0	 230.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 531.0; % COW
	20406	 447.95	 96.1	 415.8	 -223.6	 1.0	 100.0	 1	 670.9	 225.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 670.9; % COW
	20406	 445.45	 96.1	 415.8	 -223.6	 1.0	 100.0	 1	 670.9	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 670.9; % PEL
	20406	 205.8	 40.3	 174.5	 -93.9	 1.0	 100.0	 1	 281.6	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 281.6; % NG
	20406	 374.15	 74.95	 324.3	 -174.4	 1.0	 100.0	 1	 523.3	 225.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 523.3; % COW
	20407	 49.1	 12.65	 54.7	 -29.4	 1.0	 100.0	 1	 88.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2; % NG
	20407	 49.1	 12.65	 54.7	 -29.4	 1.0	 100.0	 1	 88.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2; % COW
	20407	 192.6	 20.0	 128.4	 -88.4	 1.0	 100.0	 1	 265.2	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 265.2; % NG
	20407	 192.6	 20.0	 128.4	 -88.4	 1.0	 100.0	 1	 265.2	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 265.2; % NG
	20408	 190.15	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 163.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3; % NG
	20408	 190.15	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 163.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3; % COW
	20408	 190.15	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 163.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3; % NG
	20408	 190.15	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 163.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3; % NG
	20408	 190.15	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 163.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3; % NG
	20408	 190.15	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 163.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3; % NG
	20409	 156.6	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.2	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.2; % NG
	20409	 156.6	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.2	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.2; % NG
	20409	 161.5	 30.5	 132.0	 -71.0	 1.0	 100.0	 1	 213.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.0; % COW
	20410	 100.65	 15.05	 96.7	 -66.6	 1.0	 100.0	 1	 199.7	 1.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	20411	 145.2	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4; % NG
	20411	 28.75	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % NG
	20411	 281.55	 59.15	 256.0	 -137.7	 1.0	 100.0	 1	 413.1	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 413.1; % COW
	20412	 136.95	 26.05	 112.7	 -60.6	 1.0	 100.0	 1	 181.9	 92.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.9; % NG
	20412	 136.95	 26.05	 112.7	 -60.6	 1.0	 100.0	 1	 181.9	 92.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.9; % NG
	20412	 119.0	 16.1	 103.2	 -71.0	 1.0	 100.0	 1	 213.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.0; % NG
	20413	 122.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0; % NG
	20413	 122.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0; % NG
	20413	 122.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0; % NG
	20413	 122.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0; % NG
	20413	 169.0	 38.4	 166.1	 -89.3	 1.0	 100.0	 1	 268.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 268.0; % NG
	20413	 169.0	 38.4	 166.1	 -89.3	 1.0	 100.0	 1	 268.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 268.0; % NG
	20414	 77.0	 14.35	 62.0	 -33.3	 1.0	 100.0	 1	 100.0	 54.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0; % NG
	20414	 16.95	 4.15	 17.65	 -9.35	 1.0	 100.0	 1	 28.05	 5.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.05; % NG
	20414	 16.95	 4.15	 17.65	 -9.35	 1.0	 100.0	 1	 28.05	 5.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.05; % PEL
	20414	 341.5	 66.3	 286.9	 -154.3	 1.0	 100.0	 1	 463.0	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 463.0; % COW
	20414	 77.0	 14.35	 62.0	 -33.3	 1.0	 100.0	 1	 100.0	 54.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0; % NG
	20414	 64.0	 17.3	 62.3	 -27.7	 1.0	 100.0	 1	 83.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.0; % NG
	20414	 64.0	 17.3	 62.3	 -27.7	 1.0	 100.0	 1	 83.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.0; % NG
	20414	 125.5	 23.05	 99.8	 -53.7	 1.0	 100.0	 1	 161.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 161.0; % COW
	20414	 16.95	 4.15	 17.65	 -9.35	 1.0	 100.0	 1	 28.05	 5.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.05; % NG
	20414	 16.95	 4.15	 17.65	 -9.35	 1.0	 100.0	 1	 28.05	 5.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.05; % NG
	20414	 16.95	 4.15	 17.65	 -9.35	 1.0	 100.0	 1	 28.05	 5.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.05; % NG
	20414	 16.95	 4.15	 17.65	 -9.35	 1.0	 100.0	 1	 28.05	 5.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.05; % PEL
	20415	 103.3	 23.85	 103.2	 -55.5	 1.0	 100.0	 1	 166.6	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 166.6; % NG
	20415	 103.3	 23.85	 103.2	 -55.5	 1.0	 100.0	 1	 166.6	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 166.6; % NG
	20415	 103.3	 23.85	 103.2	 -55.5	 1.0	 100.0	 1	 166.6	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 166.6; % NG
	20415	 201.5	 46.25	 200.2	 -107.7	 1.0	 100.0	 1	 323.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 323.0; % COW
	20416	 105.5	 12.15	 78.0	 -53.7	 1.0	 100.0	 1	 161.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 161.0; % NG
	20417	 101.25	 31.8	 114.4	 -50.8	 1.0	 100.0	 1	 152.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 152.5; % NG
	20417	 101.25	 31.8	 114.4	 -50.8	 1.0	 100.0	 1	 152.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 152.5; % NG
	20417	 140.2	 44.9	 161.6	 -71.8	 1.0	 100.0	 1	 215.4	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 215.4; % NG
	20417	 439.85	 83.05	 359.3	 -193.2	 1.0	 100.0	 1	 579.7	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 579.7; % COW
	20418	 28.5	 0.0	 18.1	 -18.1	 1.0	 100.0	 1	 55.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0; % NG
	20418	 16.4	 3.22	 16.58	 -10.14	 1.0	 100.0	 1	 30.4	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4; % NG
	20418	 16.4	 3.22	 16.58	 -10.14	 1.0	 100.0	 1	 30.4	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4; % NG
	20418	 16.4	 3.22	 16.58	 -10.14	 1.0	 100.0	 1	 30.4	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4; % PEL
	20418	 16.4	 3.22	 16.58	 -10.14	 1.0	 100.0	 1	 30.4	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4; % NG
	20418	 16.4	 3.22	 16.58	 -10.14	 1.0	 100.0	 1	 30.4	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4; % NG
	20418	 22.0	 5.75	 24.8	 -13.3	 1.0	 100.0	 1	 40.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	20418	 17.0	 4.55	 19.8	 -10.7	 1.0	 100.0	 1	 32.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % PEL
	20419	 107.5	 21.5	 93.0	 -50.0	 1.0	 100.0	 1	 150.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0; % NG
	20419	 107.5	 21.5	 93.0	 -50.0	 1.0	 100.0	 1	 150.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0; % COW
	20419	 104.25	 21.5	 93.0	 -50.0	 1.0	 100.0	 1	 150.0	 58.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0; % COW
	20419	 104.25	 21.5	 93.0	 -50.0	 1.0	 100.0	 1	 150.0	 58.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0; % NG
	20421	 99.5	 9.75	 62.5	 -43.0	 1.0	 100.0	 1	 129.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.0; % NG
	20421	 99.5	 9.75	 62.5	 -43.0	 1.0	 100.0	 1	 129.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.0; % NG
	20422	 86.315	 16.15	 78.3	 -46.0	 1.0	 100.0	 1	 138.1	 34.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 138.1; % PEL
	20422	 88.61	 23.9	 90.3	 -42.5	 1.0	 100.0	 1	 127.5	 49.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 127.5; % NG
	20422	 88.96	 24.0	 90.7	 -42.7	 1.0	 100.0	 1	 128.0	 49.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 128.0; % NG
	20422	 88.96	 24.0	 90.7	 -42.7	 1.0	 100.0	 1	 128.0	 49.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 128.0; % NG
	20423	 85.05	 9.45	 60.6	 -41.7	 1.0	 100.0	 1	 125.1	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.1; % COW
	20423	 85.05	 9.45	 60.6	 -41.7	 1.0	 100.0	 1	 125.1	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.1; % COW
	20423	 85.05	 9.45	 60.6	 -41.7	 1.0	 100.0	 1	 125.1	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.1; % NG
	20423	 85.05	 9.45	 60.6	 -41.7	 1.0	 100.0	 1	 125.1	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.1; % COW
	20425	 91.0	 17.9	 77.5	 -41.7	 1.0	 100.0	 1	 125.0	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	20425	 86.6	 17.65	 76.4	 -41.1	 1.0	 100.0	 1	 123.2	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 123.2; % COW
	20425	 81.25	 16.1	 69.7	 -37.5	 1.0	 100.0	 1	 112.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % NG
	20425	 81.25	 16.1	 69.7	 -37.5	 1.0	 100.0	 1	 112.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % PEL
	20425	 83.75	 23.45	 84.4	 -37.5	 1.0	 100.0	 1	 112.5	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % NG
	20425	 146.0	 40.0	 144.0	 -64.0	 1.0	 100.0	 1	 192.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.0; % NG
	20425	 258.5	 55.4	 239.8	 -129.0	 1.0	 100.0	 1	 387.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 387.0; % NG
	20428	 74.35	 14.85	 64.3	 -34.6	 1.0	 100.0	 1	 103.7	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.7; % NG
	20428	 200.1	 0.0	 87.2	 -87.2	 1.0	 100.0	 1	 265.2	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 265.2; % COW
	20429	 52.45	 0.0	 45.6	 -45.6	 1.0	 100.0	 1	 103.5	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	20430	 101.8	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	20430	 100.95	 15.2	 97.5	 -67.1	 1.0	 100.0	 1	 201.3	 0.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	20430	 60.0	 0.0	 44.1	 -44.1	 1.0	 100.0	 1	 100.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	20430	 49.65	 0.0	 43.7	 -43.7	 1.0	 100.0	 1	 99.0	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	20431	 50.25	 0.0	 43.7	 -43.7	 1.0	 100.0	 1	 99.0	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	20432	 49.7	 0.0	 43.5	 -43.5	 1.0	 100.0	 1	 98.7	 0.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	20433	 52.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 94.6	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.6; % NG
	20434	 49.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 90.0	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	20435	 17.5	 0.0	 9.9	 -9.9	 1.0	 100.0	 1	 30.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0; % NG
	20435	 8.635	 1.3	 7.53	 -4.93	 1.0	 100.0	 1	 14.8	 2.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8; % NG
	20435	 8.635	 1.3	 7.53	 -4.93	 1.0	 100.0	 1	 14.8	 2.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8; % NG
	20435	 8.635	 1.3	 7.53	 -4.93	 1.0	 100.0	 1	 14.8	 2.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8; % COW
	20435	 8.635	 1.3	 7.53	 -4.93	 1.0	 100.0	 1	 14.8	 2.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8; % PEL
	20435	 8.635	 1.3	 7.53	 -4.93	 1.0	 100.0	 1	 14.8	 2.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8; % NG
	20435	 8.635	 1.3	 7.53	 -4.93	 1.0	 100.0	 1	 14.8	 2.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8; % NG
	20436	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	20436	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	20436	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	20436	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	20436	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	20436	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	20436	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % PEL
	20436	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	20437	 65.0	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % COW
	20437	 65.0	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	20437	 65.0	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	20437	 65.0	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	20438	 43.5	 9.6	 41.5	 -22.3	 1.0	 100.0	 1	 67.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0; % PEL
	20438	 43.5	 9.6	 41.5	 -22.3	 1.0	 100.0	 1	 67.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0; % NG
	20438	 43.5	 9.6	 41.5	 -22.3	 1.0	 100.0	 1	 67.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0; % NG
	20438	 43.5	 9.6	 41.5	 -22.3	 1.0	 100.0	 1	 67.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0; % PEL
	20438	 43.5	 9.6	 41.5	 -22.3	 1.0	 100.0	 1	 67.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0; % PEL
	20438	 43.5	 9.6	 41.5	 -22.3	 1.0	 100.0	 1	 67.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0; % PEL
	20439	 44.0	 10.0	 40.3	 -20.3	 1.0	 100.0	 1	 61.0	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0; % COW
	20440	 36.9	 10.4	 37.5	 -16.7	 1.0	 100.0	 1	 50.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	20440	 36.9	 10.4	 37.5	 -16.7	 1.0	 100.0	 1	 50.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	20440	 45.02	 12.75	 45.8	 -20.3	 1.0	 100.0	 1	 61.0	 29.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0; % NG
	20440	 45.02	 12.75	 45.8	 -20.3	 1.0	 100.0	 1	 61.0	 29.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0; % NG
	20440	 45.02	 12.75	 45.8	 -20.3	 1.0	 100.0	 1	 61.0	 29.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0; % NG
	20442	 34.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % NG
	20442	 34.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % NG
	20442	 34.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % NG
	20442	 34.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % NG
	20444	 30.5	 0.0	 16.8	 -16.8	 1.0	 100.0	 1	 51.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0; % NG
	20444	 36.6	 0.0	 20.8	 -20.8	 1.0	 100.0	 1	 63.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.2; % NG
	20444	 32.0	 0.0	 20.4	 -20.4	 1.0	 100.0	 1	 62.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	20445	 42.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 34.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	20445	 83.8	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 54.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % PEL
	20445	 50.5	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % NG
	20445	 50.5	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % NG
	20445	 31.28	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 16.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % NG
	20445	 31.28	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 16.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % PEL
	20446	 21.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	20446	 21.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	20448	 29.2	 5.95	 25.7	 -13.8	 1.0	 100.0	 1	 41.4	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4; % NG
	20448	 29.2	 5.95	 25.7	 -13.8	 1.0	 100.0	 1	 41.4	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4; % COW
	20448	 60.95	 12.3	 53.2	 -28.6	 1.0	 100.0	 1	 85.9	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.9; % COW
	20449	 27.135	 8.4	 30.2	 -13.4	 1.0	 100.0	 1	 40.2	 14.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.2; % PEL
	20449	 46.575	 14.4	 51.8	 -23.0	 1.0	 100.0	 1	 69.0	 24.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % PEL
	20449	 23.8	 7.3	 26.3	 -11.7	 1.0	 100.0	 1	 35.0	 12.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % PEL
	20450	 44.45	 8.7	 37.7	 -20.3	 1.0	 100.0	 1	 60.9	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.9; % NG
	20450	 23.0	 4.75	 20.5	 -11.0	 1.0	 100.0	 1	 33.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0; % PEL
	20451	 17.9	 6.4	 23.1	 -10.3	 1.0	 100.0	 1	 30.8	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.8; % NG
	20452	 17.25	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 9.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	20453	 6.775	 1.725	 7.45	 -4.0	 1.0	 100.0	 1	 12.05	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.05; % PEL
	20453	 6.775	 1.725	 7.45	 -4.0	 1.0	 100.0	 1	 12.05	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.05; % PEL
	20454	 3.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 5.85	 0.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.85; % NG
	20454	 3.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 5.85	 0.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.85; % NG
	20454	 3.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 5.85	 0.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.85; % NG
	20454	 3.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 5.85	 0.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.85; % NG
	20455	 6.55	 1.6	 6.9	 -3.7	 1.0	 100.0	 1	 11.1	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.1; % NG
	20455	 6.55	 1.6	 6.9	 -3.7	 1.0	 100.0	 1	 11.1	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.1; % NG
	20457	 11.3	 4.5	 16.2	 -7.2	 1.0	 100.0	 1	 21.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6; % PEL
	20457	 11.3	 4.5	 16.2	 -7.2	 1.0	 100.0	 1	 21.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6; % NG
	20457	 11.3	 4.5	 16.2	 -7.2	 1.0	 100.0	 1	 21.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6; % NG
	20458	 459.1	 79.515	 364.43	 -205.4	 1.0	 100.0	 1	 616.2	 302.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 616.2; % COW
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1; % NG
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1; % NG
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1; % NG
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1; % NG
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1; % NG
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1; % NG
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1; % NG
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1; % NG
	20458	 459.1	 79.515	 364.43	 -205.4	 1.0	 100.0	 1	 616.2	 302.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 616.2; % COW
	20458	 459.1	 79.515	 364.43	 -205.4	 1.0	 100.0	 1	 616.2	 302.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 616.2; % COW
	20458	 217.5	 30.95	 198.6	 -136.7	 1.0	 100.0	 1	 410.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 410.0; % NG
	20458	 210.0	 54.4	 235.5	 -126.7	 1.0	 100.0	 1	 380.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 380.0; % NG
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1; % NG
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1; % COW
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1; % NG
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1; % NG
	20459	 1093.15	 85.55	 548.9	 -377.8	 1.0	 100.0	 1	 1133.3	 1053.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	20459	 1079.0	 86.95	 557.9	 -384.0	 1.0	 100.0	 1	 1152.0	 1006.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	20460	 405.9	 169.15	 608.9	 -270.6	 1.0	 100.0	 1	 811.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	20461	 426.25	 52.65	 337.8	 -232.5	 1.0	 100.0	 1	 697.5	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 697.5; % COW
	20461	 426.25	 52.65	 337.8	 -232.5	 1.0	 100.0	 1	 697.5	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 697.5; % COW
	20461	 48.65	 12.25	 52.9	 -28.4	 1.0	 100.0	 1	 85.3	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.3; % NG
	20461	 48.65	 12.25	 52.9	 -28.4	 1.0	 100.0	 1	 85.3	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.3; % PEL
	20461	 48.65	 12.25	 52.9	 -28.4	 1.0	 100.0	 1	 85.3	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.3; % NG
	20462	 284.9	 47.25	 204.4	 -109.9	 1.0	 100.0	 1	 329.8	 240.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.8; % NG
	20462	 284.9	 47.25	 204.4	 -109.9	 1.0	 100.0	 1	 329.8	 240.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.8; % NG
	20462	 284.9	 47.25	 204.4	 -109.9	 1.0	 100.0	 1	 329.8	 240.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.8; % NG
	20462	 284.9	 47.25	 204.4	 -109.9	 1.0	 100.0	 1	 329.8	 240.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.8; % COW
	20462	 284.9	 47.25	 204.4	 -109.9	 1.0	 100.0	 1	 329.8	 240.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.8; % NG
	20462	 284.9	 47.25	 204.4	 -109.9	 1.0	 100.0	 1	 329.8	 240.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.8; % NG
	20463	 176.25	 60.95	 219.4	 -97.5	 1.0	 100.0	 1	 292.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 292.5; % NG
	20463	 141.3	 58.9	 212.0	 -94.2	 1.0	 100.0	 1	 282.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 282.6; % NG
	20463	 246.55	 74.6	 268.6	 -119.4	 1.0	 100.0	 1	 358.1	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 358.1; % NG
	20464	 633.4	 119.2	 544.0	 -305.6	 1.0	 100.0	 1	 916.8	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 916.8; % COW
	20464	 182.6	 38.0	 164.4	 -88.4	 1.0	 100.0	 1	 265.2	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 265.2; % NG
	20464	 239.4	 93.8	 313.9	 -126.3	 1.0	 100.0	 1	 378.8	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 378.8; % NG
	20465	 118.5	 21.05	 91.1	 -49.0	 1.0	 100.0	 1	 147.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 147.0; % NG
	20465	 118.5	 21.05	 91.1	 -49.0	 1.0	 100.0	 1	 147.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 147.0; % COW
	20465	 118.5	 21.05	 91.1	 -49.0	 1.0	 100.0	 1	 147.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 147.0; % NG
	20465	 207.5	 35.05	 151.8	 -81.7	 1.0	 100.0	 1	 245.0	 170.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 245.0; % NG
	20465	 207.5	 35.05	 151.8	 -81.7	 1.0	 100.0	 1	 245.0	 170.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 245.0; % NG
	20465	 207.5	 35.05	 151.8	 -81.7	 1.0	 100.0	 1	 245.0	 170.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 245.0; % NG
	20466	 19.3	 4.8	 20.8	 -11.2	 1.0	 100.0	 1	 33.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.6; % PEL
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111; % NG
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111; % PEL
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111; % COW
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111; % PEL
	20466	 19.3	 4.8	 20.8	 -11.2	 1.0	 100.0	 1	 33.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.6; % NG
	20466	 19.3	 4.8	 20.8	 -11.2	 1.0	 100.0	 1	 33.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.6; % NG
	20466	 19.3	 4.8	 20.8	 -11.2	 1.0	 100.0	 1	 33.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.6; % PEL
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111; % PEL
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111; % PEL
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111; % NG
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111; % NG
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111; % NG
	20467	 151.85	 27.0	 116.9	 -62.9	 1.0	 100.0	 1	 188.7	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.7; % NG
	20467	 151.85	 27.0	 116.9	 -62.9	 1.0	 100.0	 1	 188.7	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.7; % NG
	20467	 166.7	 30.6	 132.3	 -71.1	 1.0	 100.0	 1	 213.4	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.4; % NG
	20467	 139.35	 27.0	 116.9	 -62.9	 1.0	 100.0	 1	 188.7	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.7; % NG
	20467	 139.35	 27.0	 116.9	 -62.9	 1.0	 100.0	 1	 188.7	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.7; % NG
	20468	 131.5	 35.8	 154.9	 -83.3	 1.0	 100.0	 1	 250.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 250.0; % NG
	20468	 132.5	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	20468	 132.5	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	20468	 132.5	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	20469	 143.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 116.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	20469	 143.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 116.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	20469	 143.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 116.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	20469	 143.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 116.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	20470	 22.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	20470	 22.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	20470	 15.015	 2.9	 14.7	 -8.9	 1.0	 100.0	 1	 26.7	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7; % PEL
	20470	 15.015	 2.9	 14.7	 -8.9	 1.0	 100.0	 1	 26.7	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7; % NG
	20470	 15.015	 2.9	 14.7	 -8.9	 1.0	 100.0	 1	 26.7	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7; % COW
	20470	 15.015	 2.9	 14.7	 -8.9	 1.0	 100.0	 1	 26.7	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7; % NG
	20470	 15.015	 2.9	 14.7	 -8.9	 1.0	 100.0	 1	 26.7	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7; % NG
	20470	 15.015	 2.9	 14.7	 -8.9	 1.0	 100.0	 1	 26.7	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7; % NG
	20471	 113.15	 22.4	 96.9	 -52.1	 1.0	 100.0	 1	 156.3	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.3; % NG
	20471	 113.15	 22.4	 96.9	 -52.1	 1.0	 100.0	 1	 156.3	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.3; % NG
	20472	 127.35	 22.15	 95.9	 -51.6	 1.0	 100.0	 1	 154.7	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 154.7; % NG
	20473	 103.0	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % COW
	20473	 103.0	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % COW
	20473	 100.5	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % PEL
	20473	 100.5	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % COW
	20473	 376.25	 99.2	 429.2	 -230.8	 1.0	 100.0	 1	 692.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 692.5; % COW
	20473	 384.9	 101.65	 439.9	 -236.6	 1.0	 100.0	 1	 709.8	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 709.8; % COW
	20475	 84.095	 22.7	 85.7	 -40.3	 1.0	 100.0	 1	 121.0	 47.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0; % NG
	20476	 73.0	 9.05	 58.1	 -40.0	 1.0	 100.0	 1	 120.0	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0; % NG
	20476	 68.5	 25.0	 90.0	 -40.0	 1.0	 100.0	 1	 120.0	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0; % COW
	20476	 346.75	 40.45	 259.4	 -178.5	 1.0	 100.0	 1	 535.5	 158.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 535.5; % NG
	20477	 103.9	 19.0	 82.3	 -44.3	 1.0	 100.0	 1	 132.8	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.8; % COW
	20477	 83.15	 15.25	 65.9	 -35.4	 1.0	 100.0	 1	 106.3	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.3; % NG
	20477	 83.15	 15.25	 65.9	 -35.4	 1.0	 100.0	 1	 106.3	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.3; % NG
	20479	 69.7	 12.8	 55.4	 -29.8	 1.0	 100.0	 1	 89.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % NG
	20479	 69.7	 12.8	 55.4	 -29.8	 1.0	 100.0	 1	 89.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % NG
	20479	 69.7	 12.8	 55.4	 -29.8	 1.0	 100.0	 1	 89.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % NG
	20479	 69.7	 12.8	 55.4	 -29.8	 1.0	 100.0	 1	 89.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % PEL
	20480	 485.2	 61.55	 394.9	 -271.8	 1.0	 100.0	 1	 815.4	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 815.4; % COW
	20480	 48.65	 12.25	 52.9	 -28.4	 1.0	 100.0	 1	 85.3	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.3; % NG
	20480	 48.65	 12.25	 52.9	 -28.4	 1.0	 100.0	 1	 85.3	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.3; % COW
	20480	 48.65	 12.25	 52.9	 -28.4	 1.0	 100.0	 1	 85.3	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.3; % NG
	20481	 65.0	 14.4	 57.1	 -28.3	 1.0	 100.0	 1	 85.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % COW
	20481	 65.0	 14.4	 57.1	 -28.3	 1.0	 100.0	 1	 85.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	20481	 65.0	 14.4	 57.1	 -28.3	 1.0	 100.0	 1	 85.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % COW
	20481	 65.0	 14.4	 57.1	 -28.3	 1.0	 100.0	 1	 85.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % PEL
	20483	 12.0	 1.86	 9.06	 -5.34	 1.0	 100.0	 1	 16.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	20483	 12.0	 1.86	 9.06	 -5.34	 1.0	 100.0	 1	 16.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % PEL
	20483	 12.0	 1.86	 9.06	 -5.34	 1.0	 100.0	 1	 16.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	20483	 12.0	 1.86	 9.06	 -5.34	 1.0	 100.0	 1	 16.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % COW
	20483	 12.0	 1.86	 9.06	 -5.34	 1.0	 100.0	 1	 16.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	20485	 50.625	 10.25	 45.5	 -25.0	 1.0	 100.0	 1	 75.0	 26.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	20485	 50.625	 10.25	 45.5	 -25.0	 1.0	 100.0	 1	 75.0	 26.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % COW
	20487	 34.95	 0.0	 27.3	 -27.3	 1.0	 100.0	 1	 69.0	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	20489	 10.0	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % COW
	20489	 10.0	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % PEL
	20489	 10.0	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	20489	 10.0	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % PEL
	20490	 11.31	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 6.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	20490	 11.31	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 6.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	20490	 11.31	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 6.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	20490	 11.31	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 6.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	20490	 14.6	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % NG
	20490	 14.6	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % PEL
	20490	 15.7	 3.35	 14.5	 -7.8	 1.0	 100.0	 1	 23.4	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4; % PEL
	20493	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	20494	 36.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % NG
	20494	 36.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % PEL
	20494	 36.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % NG
	20494	 36.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % PEL
	20494	 36.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % PEL
	20494	 36.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % NG
	20494	 62.0	 6.0	 38.3	 -26.3	 1.0	 100.0	 1	 79.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 79.0; % PEL
	20494	 58.5	 15.05	 65.1	 -35.0	 1.0	 100.0	 1	 105.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0; % NG
	20494	 58.5	 15.05	 65.1	 -35.0	 1.0	 100.0	 1	 105.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0; % NG
	20496	 40.0	 4.15	 26.6	 -18.3	 1.0	 100.0	 1	 55.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0; % NG
	20497	 26.85	 0.0	 20.9	 -20.9	 1.0	 100.0	 1	 52.8	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	20498	 6.07	 1.68	 6.5	 -3.14	 1.0	 100.0	 1	 9.44	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.44; % NG
	20498	 6.07	 1.68	 6.5	 -3.14	 1.0	 100.0	 1	 9.44	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.44; % PEL
	20498	 6.07	 1.68	 6.5	 -3.14	 1.0	 100.0	 1	 9.44	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.44; % NG
	20498	 6.07	 1.68	 6.5	 -3.14	 1.0	 100.0	 1	 9.44	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.44; % NG
	20498	 6.07	 1.68	 6.5	 -3.14	 1.0	 100.0	 1	 9.44	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.44; % NG
	20500	 60.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % NG
	20500	 60.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % NG
	20500	 60.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % NG
	20500	 32.0	 6.3	 27.3	 -14.7	 1.0	 100.0	 1	 44.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0; % NG
	20500	 32.0	 6.3	 27.3	 -14.7	 1.0	 100.0	 1	 44.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0; % NG
	20500	 33.5	 6.7	 29.1	 -15.7	 1.0	 100.0	 1	 47.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % NG
	20502	 35.4	 6.1	 26.3	 -14.1	 1.0	 100.0	 1	 42.4	 28.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.4; % NG
	20502	 34.6	 6.1	 26.3	 -14.1	 1.0	 100.0	 1	 42.4	 26.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.4; % NG
	20502	 34.05	 6.15	 26.6	 -14.3	 1.0	 100.0	 1	 42.9	 25.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.9; % NG
	20502	 33.4	 6.1	 26.3	 -14.1	 1.0	 100.0	 1	 42.4	 24.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.4; % NG
	20504	 24.75	 5.65	 24.5	 -13.2	 1.0	 100.0	 1	 39.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.5; % NG
	20505	 27.05	 5.6	 24.2	 -13.0	 1.0	 100.0	 1	 39.1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.1; % COW
	20505	 27.05	 5.6	 24.2	 -13.0	 1.0	 100.0	 1	 39.1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.1; % NG
	20505	 66.75	 11.95	 51.7	 -27.8	 1.0	 100.0	 1	 83.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.5; % NG
	20506	 24.0	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0; % PEL
	20507	 12.87	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 7.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	20507	 12.87	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 7.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	20509	 5.25	 2.185	 7.87	 -3.5	 1.0	 100.0	 1	 10.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5; % NG
	20509	 5.25	 2.185	 7.87	 -3.5	 1.0	 100.0	 1	 10.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5; % NG
	20509	 5.25	 2.185	 7.87	 -3.5	 1.0	 100.0	 1	 10.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5; % NG
	20510	 22.25	 0.0	 6.2	 -6.2	 1.0	 100.0	 1	 30.3	 14.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.3; % NG
	20512	 16.5	 5.85	 21.0	 -9.3	 1.0	 100.0	 1	 28.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0; % NG
	20513	 4.255	 0.915	 3.93	 -2.1	 1.0	 100.0	 1	 6.3	 2.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.3; % NG
	20513	 4.255	 0.915	 3.93	 -2.1	 1.0	 100.0	 1	 6.3	 2.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.3; % NG
	20513	 4.255	 0.915	 3.93	 -2.1	 1.0	 100.0	 1	 6.3	 2.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.3; % COW
	20513	 4.255	 0.915	 3.93	 -2.1	 1.0	 100.0	 1	 6.3	 2.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.3; % COW
	20513	 13.15	 3.05	 13.2	 -7.1	 1.0	 100.0	 1	 21.3	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.3; % PEL
	20514	 22.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	20514	 22.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	20515	 14.5	 0.0	 7.9	 -7.9	 1.0	 100.0	 1	 24.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % NG
	20516	 17.0	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 24.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % NG
	20517	 4.685	 1.25	 5.17	 -2.67	 1.0	 100.0	 1	 7.97	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.9667; % NG
	20517	 4.685	 1.25	 5.17	 -2.67	 1.0	 100.0	 1	 7.97	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.9667; % PEL
	20517	 4.685	 1.25	 5.17	 -2.67	 1.0	 100.0	 1	 7.97	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.9667; % COW
	20518	 4.34	 0.42	 2.42	 -1.58	 1.0	 100.0	 1	 4.74	 3.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.74; % NG
	20518	 4.34	 0.42	 2.42	 -1.58	 1.0	 100.0	 1	 4.74	 3.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.74; % NG
	20518	 4.34	 0.42	 2.42	 -1.58	 1.0	 100.0	 1	 4.74	 3.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.74; % NG
	20518	 4.34	 0.42	 2.42	 -1.58	 1.0	 100.0	 1	 4.74	 3.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.74; % PEL
	20518	 4.34	 0.42	 2.42	 -1.58	 1.0	 100.0	 1	 4.74	 3.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.74; % PEL
	20520	 7.75	 1.65	 7.15	 -3.85	 1.0	 100.0	 1	 11.5	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5; % NG
	20520	 7.75	 1.65	 7.15	 -3.85	 1.0	 100.0	 1	 11.5	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5; % NG
	20522	 13.8	 1.7	 10.9	 -7.5	 1.0	 100.0	 1	 22.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.6; % PEL
	20523	 2.4	 0.665	 2.39	 -1.06	 1.0	 100.0	 1	 3.19	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1857; % NG
	20523	 2.4	 0.665	 2.39	 -1.06	 1.0	 100.0	 1	 3.19	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1857; % NG
	20523	 2.4	 0.665	 2.39	 -1.06	 1.0	 100.0	 1	 3.19	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1857; % PEL
	20523	 2.4	 0.665	 2.39	 -1.06	 1.0	 100.0	 1	 3.19	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1857; % PEL
	20523	 2.4	 0.665	 2.39	 -1.06	 1.0	 100.0	 1	 3.19	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1857; % COW
	20523	 2.4	 0.665	 2.39	 -1.06	 1.0	 100.0	 1	 3.19	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1857; % PEL
	20523	 2.4	 0.665	 2.39	 -1.06	 1.0	 100.0	 1	 3.19	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1857; % PEL
	20524	 18.5	 3.15	 13.6	 -7.3	 1.0	 100.0	 1	 22.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	20524	 23.65	 4.2	 18.2	 -9.8	 1.0	 100.0	 1	 29.3	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.3; % NG
	20527	 3.35	 0.0	 2.2	 -2.2	 1.0	 100.0	 1	 6.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.7; % PEL
	20527	 3.35	 0.0	 2.2	 -2.2	 1.0	 100.0	 1	 6.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.7; % PEL
	20527	 3.35	 0.0	 2.2	 -2.2	 1.0	 100.0	 1	 6.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.7; % NG
	20528	 12.5	 4.15	 15.0	 -6.7	 1.0	 100.0	 1	 20.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % COW
	20529	 13.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	20529	 13.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	20529	 13.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	20530	 14.0	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	20531	 0.0	 0.0	 468.6	 -468.6	 1.0	 100.0	 0	 1425.6	 302.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1425.6; % COW
	20532	 722.3	 0.0	 558.7	 -558.7	 1.0	 100.0	 1	 1311.6	 133.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	20533	 1000.0	 98.15	 629.6	 -433.3	 1.0	 100.0	 1	 1300.0	 700.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1300.0; % NUC
	20533	 0.0	 0.0	 629.6	 -433.3	 1.0	 100.0	 0	 1300.0	 650.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1300.0; % COW
	20534	 517.6	 69.85	 448.1	 -308.4	 1.0	 100.0	 1	 925.2	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	20535	 23.35	 5.95	 21.5	 -9.6	 1.0	 100.0	 1	 28.7	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.7; % NG
	20535	 395.3	 49.85	 319.9	 -220.2	 1.0	 100.0	 1	 660.6	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 660.6; % COW
	20536	 537.5	 49.05	 314.8	 -216.7	 1.0	 100.0	 1	 650.0	 425.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 650.0; % NG
	20536	 520.1	 88.1	 381.3	 -205.1	 1.0	 100.0	 1	 615.2	 425.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 615.2; % NG
	20536	 520.1	 88.1	 381.3	 -205.1	 1.0	 100.0	 1	 615.2	 425.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 615.2; % COW
	20537	 455.1	 46.05	 295.5	 -203.4	 1.0	 100.0	 1	 610.2	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 610.2; % COW
	20537	 455.1	 46.05	 295.5	 -203.4	 1.0	 100.0	 1	 610.2	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 610.2; % COW
	20537	 455.1	 46.05	 295.5	 -203.4	 1.0	 100.0	 1	 610.2	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 610.2; % COW
	20537	 455.1	 46.05	 295.5	 -203.4	 1.0	 100.0	 1	 610.2	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 610.2; % COW
	20538	 87.5	 19.35	 83.7	 -45.0	 1.0	 100.0	 1	 135.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % COW
	20538	 87.5	 19.35	 83.7	 -45.0	 1.0	 100.0	 1	 135.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % NG
	20538	 87.5	 19.35	 83.7	 -45.0	 1.0	 100.0	 1	 135.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % NG
	20538	 56.1	 12.46	 53.92	 -29.0	 1.0	 100.0	 1	 87.0	 25.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.0; % NG
	20538	 56.1	 12.46	 53.92	 -29.0	 1.0	 100.0	 1	 87.0	 25.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.0; % NG
	20538	 56.1	 12.46	 53.92	 -29.0	 1.0	 100.0	 1	 87.0	 25.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.0; % NG
	20538	 56.1	 12.46	 53.92	 -29.0	 1.0	 100.0	 1	 87.0	 25.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.0; % NG
	20538	 56.1	 12.46	 53.92	 -29.0	 1.0	 100.0	 1	 87.0	 25.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.0; % COW
	20540	 163.0	 53.35	 192.0	 -85.3	 1.0	 100.0	 1	 256.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 256.0; % NG
	20541	 139.8	 45.75	 164.7	 -73.2	 1.0	 100.0	 1	 219.6	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 219.6; % NG
	20541	 139.8	 45.75	 164.7	 -73.2	 1.0	 100.0	 1	 219.6	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 219.6; % NG
	20541	 148.75	 49.45	 178.1	 -79.2	 1.0	 100.0	 1	 237.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.5; % NG
	20541	 148.75	 49.45	 178.1	 -79.2	 1.0	 100.0	 1	 237.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.5; % NG
	20541	 482.6	 88.1	 381.3	 -205.1	 1.0	 100.0	 1	 615.2	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 615.2; % NG
	20542	 198.65	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3; % NG
	20542	 198.65	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3; % COW
	20542	 198.65	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3; % NG
	20542	 198.65	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3; % NG
	20542	 198.65	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3; % COW
	20543	 218.55	 45.4	 196.5	 -105.7	 1.0	 100.0	 1	 317.1	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 317.1; % NG
	20543	 144.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	20543	 144.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	20544	 149.0	 28.35	 122.7	 -66.0	 1.0	 100.0	 1	 198.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.0; % COW
	20544	 149.0	 28.35	 122.7	 -66.0	 1.0	 100.0	 1	 198.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.0; % NG
	20544	 149.0	 28.35	 122.7	 -66.0	 1.0	 100.0	 1	 198.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.0; % NG
	20545	 155.5	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 115.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % NG
	20545	 155.5	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 115.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % NG
	20545	 155.5	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 115.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % NG
	20545	 155.5	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 115.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % COW
	20545	 155.5	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 115.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % NG
	20546	 122.7	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4; % NG
	20546	 122.7	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4; % NG
	20546	 122.7	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4; % NG
	20546	 122.7	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4; % NG
	20546	 545.0	 97.35	 421.4	 -226.7	 1.0	 100.0	 1	 680.0	 410.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 680.0; % NUC
	20546	 545.0	 97.35	 421.4	 -226.7	 1.0	 100.0	 1	 680.0	 410.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 680.0; % COW
	20546	 234.5	 47.85	 207.0	 -111.3	 1.0	 100.0	 1	 334.0	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 334.0; % COW
	20547	 134.1	 24.95	 108.0	 -58.1	 1.0	 100.0	 1	 174.2	 94.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.2; % NG
	20547	 134.1	 24.95	 108.0	 -58.1	 1.0	 100.0	 1	 174.2	 94.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.2; % NG
	20547	 134.1	 24.95	 108.0	 -58.1	 1.0	 100.0	 1	 174.2	 94.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.2; % NG
	20547	 246.5	 57.15	 247.3	 -133.0	 1.0	 100.0	 1	 399.0	 94.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 399.0; % NG
	20548	 159.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 146.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0; % NG
	20548	 159.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 146.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0; % NG
	20548	 159.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 146.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0; % NG
	20548	 159.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 146.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0; % NG
	20549	 131.75	 23.4	 101.3	 -54.5	 1.0	 100.0	 1	 163.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.5; % COW
	20549	 131.75	 23.4	 101.3	 -54.5	 1.0	 100.0	 1	 163.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.5; % COW
	20549	 131.75	 23.4	 101.3	 -54.5	 1.0	 100.0	 1	 163.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.5; % PEL
	20549	 131.75	 23.4	 101.3	 -54.5	 1.0	 100.0	 1	 163.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.5; % COW
	20549	 298.55	 45.4	 196.5	 -105.7	 1.0	 100.0	 1	 317.1	 280.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 317.1; % NG
	20549	 298.55	 45.4	 196.5	 -105.7	 1.0	 100.0	 1	 317.1	 280.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 317.1; % NG
	20550	 80.75	 30.3	 114.4	 -53.8	 1.0	 100.0	 1	 161.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 161.5; % COW
	20550	 578.25	 63.55	 407.6	 -280.5	 1.0	 100.0	 1	 841.5	 315.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 841.5; % COW
	20550	 286.95	 33.5	 215.0	 -148.0	 1.0	 100.0	 1	 443.9	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 443.9; % COW
	20550	 286.95	 33.5	 215.0	 -148.0	 1.0	 100.0	 1	 443.9	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 443.9; % COW
	20551	 97.715	 14.5	 75.9	 -46.9	 1.0	 100.0	 1	 140.6	 54.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.6; % NG
	20551	 97.715	 14.5	 75.9	 -46.9	 1.0	 100.0	 1	 140.6	 54.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.6; % NG
	20551	 151.23	 22.45	 117.4	 -72.5	 1.0	 100.0	 1	 217.6	 84.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.6; % NG
	20552	 92.295	 19.0	 82.3	 -44.3	 1.0	 100.0	 1	 132.8	 51.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.8; % NG
	20552	 92.295	 19.0	 82.3	 -44.3	 1.0	 100.0	 1	 132.8	 51.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.8; % PEL
	20552	 16.0	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % NG
	20553	 16.0	 2.57	 11.11	 -5.97	 1.0	 100.0	 1	 17.93	 14.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.9286; % PEL
	20553	 16.0	 2.57	 11.11	 -5.97	 1.0	 100.0	 1	 17.93	 14.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.9286; % PEL
	20553	 16.0	 2.57	 11.11	 -5.97	 1.0	 100.0	 1	 17.93	 14.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.9286; % NG
	20553	 16.0	 2.57	 11.11	 -5.97	 1.0	 100.0	 1	 17.93	 14.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.9286; % NG
	20553	 16.0	 2.57	 11.11	 -5.97	 1.0	 100.0	 1	 17.93	 14.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.9286; % PEL
	20553	 16.0	 2.57	 11.11	 -5.97	 1.0	 100.0	 1	 17.93	 14.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.9286; % PEL
	20553	 16.0	 2.57	 11.11	 -5.97	 1.0	 100.0	 1	 17.93	 14.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.9286; % PEL
	20554	 86.5	 17.6	 76.2	 -41.0	 1.0	 100.0	 1	 123.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 123.0; % NG
	20554	 86.5	 17.6	 76.2	 -41.0	 1.0	 100.0	 1	 123.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 123.0; % NG
	20554	 144.56	 39.0	 147.3	 -69.3	 1.0	 100.0	 1	 208.0	 81.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 208.0; % NG
	20554	 86.5	 25.65	 92.3	 -41.0	 1.0	 100.0	 1	 123.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 123.0; % NG
	20554	 20.0	 4.55	 19.8	 -10.7	 1.0	 100.0	 1	 32.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % NG
	20554	 483.82	 55.15	 337.0	 -226.7	 1.0	 100.0	 1	 680.0	 287.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 680.0; % COW
	20555	 112.1	 12.3	 79.0	 -54.4	 1.0	 100.0	 1	 163.2	 61.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2; % NG
	20555	 260.9	 34.8	 223.2	 -153.6	 1.0	 100.0	 1	 460.8	 61.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 460.8; % NG
	20555	 86.875	 9.4	 60.5	 -41.7	 1.0	 100.0	 1	 125.0	 48.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	20555	 75.94	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 39.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % COW
	20555	 77.625	 8.7	 55.7	 -38.3	 1.0	 100.0	 1	 115.0	 40.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.0; % NG
	20555	 31.45	 4.0	 25.6	 -17.6	 1.0	 100.0	 1	 52.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.9; % NG
	20555	 31.45	 4.0	 25.6	 -17.6	 1.0	 100.0	 1	 52.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.9; % NG
	20555	 31.45	 4.0	 25.6	 -17.6	 1.0	 100.0	 1	 52.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.9; % NG
	20555	 31.45	 4.0	 25.6	 -17.6	 1.0	 100.0	 1	 52.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.9; % NG
	20555	 160.9	 35.05	 151.7	 -81.6	 1.0	 100.0	 1	 244.8	 77.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 244.8; % COW
	20556	 59.6	 15.2	 65.8	 -35.4	 1.0	 100.0	 1	 106.2	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.2; % NG
	20557	 108.56	 29.3	 110.7	 -52.1	 1.0	 100.0	 1	 156.2	 60.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.2; % NG
	20557	 108.56	 29.3	 110.7	 -52.1	 1.0	 100.0	 1	 156.2	 60.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.2; % NG
	20557	 69.795	 14.1	 62.7	 -34.5	 1.0	 100.0	 1	 103.4	 36.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.4; % NG
	20559	 67.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0; % NG
	20559	 67.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0; % NG
	20559	 67.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0; % COW
	20559	 67.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0; % NG
	20559	 67.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0; % NG
	20559	 67.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0; % NG
	20560	 83.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0; % NG
	20560	 83.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0; % NG
	20560	 83.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0; % NG
	20560	 83.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0; % NG
	20561	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	20561	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % COW
	20561	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % COW
	20561	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % COW
	20561	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % COW
	20561	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	20561	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % PEL
	20561	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % COW
	20562	 57.0	 12.3	 53.3	 -28.7	 1.0	 100.0	 1	 86.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0; % NG
	20562	 28.5	 4.15	 18.0	 -9.7	 1.0	 100.0	 1	 29.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.0; % PEL
	20562	 505.0	 97.35	 421.4	 -226.7	 1.0	 100.0	 1	 680.0	 330.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 680.0; % COW
	20563	 42.65	 9.35	 40.5	 -21.8	 1.0	 100.0	 1	 65.3	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.3; % NG
	20563	 42.65	 9.35	 40.5	 -21.8	 1.0	 100.0	 1	 65.3	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.3; % NG
	20563	 57.5	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	20563	 57.5	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	20563	 57.5	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % COW
	20563	 57.5	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	20563	 57.5	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	20564	 62.6	 12.05	 52.2	 -28.1	 1.0	 100.0	 1	 84.2	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.2; % NG
	20564	 72.25	 14.8	 64.1	 -34.5	 1.0	 100.0	 1	 103.5	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5; % NG
	20564	 73.55	 15.2	 65.8	 -35.4	 1.0	 100.0	 1	 106.1	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.1; % NG
	20565	 28.8	 4.65	 20.2	 -10.9	 1.0	 100.0	 1	 32.6	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.6; % PEL
	20565	 49.5	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % PEL
	20565	 49.5	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % PEL
	20565	 49.5	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % NG
	20565	 49.5	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % NG
	20565	 47.0	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % PEL
	20565	 47.0	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % PEL
	20566	 8.3	 1.02	 6.58	 -4.54	 1.0	 100.0	 1	 13.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6; % NG
	20566	 8.3	 1.02	 6.58	 -4.54	 1.0	 100.0	 1	 13.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6; % NG
	20566	 8.3	 1.02	 6.58	 -4.54	 1.0	 100.0	 1	 13.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6; % PEL
	20566	 8.3	 1.02	 6.58	 -4.54	 1.0	 100.0	 1	 13.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6; % NG
	20566	 8.3	 1.02	 6.58	 -4.54	 1.0	 100.0	 1	 13.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6; % NG
	20566	 13.0	 1.7	 11.1	 -7.7	 1.0	 100.0	 1	 23.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % NG
	20567	 38.5	 0.0	 22.0	 -22.0	 1.0	 100.0	 1	 67.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0; % PEL
	20568	 9.75	 2.365	 10.23	 -5.5	 1.0	 100.0	 1	 16.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.5; % PEL
	20568	 9.75	 2.365	 10.23	 -5.5	 1.0	 100.0	 1	 16.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.5; % PEL
	20568	 9.75	 2.365	 10.23	 -5.5	 1.0	 100.0	 1	 16.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.5; % NG
	20568	 9.75	 2.365	 10.23	 -5.5	 1.0	 100.0	 1	 16.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.5; % NG
	20568	 120.6	 23.35	 101.1	 -54.4	 1.0	 100.0	 1	 163.2	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2; % NG
	20568	 355.55	 79.8	 345.3	 -185.7	 1.0	 100.0	 1	 557.1	 154.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 557.1; % NG
	20568	 355.85	 79.85	 345.6	 -185.9	 1.0	 100.0	 1	 557.7	 154.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 557.7; % COW
	20569	 44.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % NG
	20569	 44.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % COW
	20569	 44.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % PEL
	20569	 44.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % PEL
	20570	 14.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	20570	 8.755	 1.065	 6.58	 -4.45	 1.0	 100.0	 1	 13.38	 4.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.375; % COW
	20570	 8.755	 1.065	 6.58	 -4.45	 1.0	 100.0	 1	 13.38	 4.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.375; % NG
	20570	 8.755	 1.065	 6.58	 -4.45	 1.0	 100.0	 1	 13.38	 4.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.375; % NG
	20570	 8.755	 1.065	 6.58	 -4.45	 1.0	 100.0	 1	 13.38	 4.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.375; % PEL
	20571	 32.15	 8.05	 31.2	 -15.1	 1.0	 100.0	 1	 45.3	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.3; % NG
	20572	 7.585	 1.435	 5.95	 -3.08	 1.0	 100.0	 1	 9.25	 5.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.25; % NG
	20572	 7.585	 1.435	 5.95	 -3.08	 1.0	 100.0	 1	 9.25	 5.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.25; % NG
	20572	 7.585	 1.435	 5.95	 -3.08	 1.0	 100.0	 1	 9.25	 5.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.25; % PEL
	20572	 7.585	 1.435	 5.95	 -3.08	 1.0	 100.0	 1	 9.25	 5.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.25; % NG
	20573	 7.3	 1.865	 7.83	 -4.1	 1.0	 100.0	 1	 12.27	 2.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.2667; % NG
	20573	 7.3	 1.865	 7.83	 -4.1	 1.0	 100.0	 1	 12.27	 2.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.2667; % NG
	20573	 7.3	 1.865	 7.83	 -4.1	 1.0	 100.0	 1	 12.27	 2.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.2667; % COW
	20575	 29.5	 4.75	 20.5	 -11.0	 1.0	 100.0	 1	 33.0	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0; % PEL
	20577	 10.5	 2.275	 9.9	 -5.35	 1.0	 100.0	 1	 16.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	20577	 10.5	 2.275	 9.9	 -5.35	 1.0	 100.0	 1	 16.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % PEL
	20578	 30.5	 4.55	 19.8	 -10.7	 1.0	 100.0	 1	 32.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % NG
	20579	 30.5	 4.55	 19.8	 -10.7	 1.0	 100.0	 1	 32.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % PEL
	20580	 20.0	 4.55	 19.8	 -10.7	 1.0	 100.0	 1	 32.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % COW
	20581	 3.075	 0.77	 3.27	 -1.73	 1.0	 100.0	 1	 5.22	 0.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2167; % PEL
	20581	 3.075	 0.77	 3.27	 -1.73	 1.0	 100.0	 1	 5.22	 0.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2167; % NG
	20581	 3.075	 0.77	 3.27	 -1.73	 1.0	 100.0	 1	 5.22	 0.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2167; % NG
	20581	 3.075	 0.77	 3.27	 -1.73	 1.0	 100.0	 1	 5.22	 0.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2167; % NG
	20581	 3.075	 0.77	 3.27	 -1.73	 1.0	 100.0	 1	 5.22	 0.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2167; % NG
	20581	 3.075	 0.77	 3.27	 -1.73	 1.0	 100.0	 1	 5.22	 0.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2167; % NG
	20584	 500.0	 0.0	 9900.0	 -9900.0	 1.0	 100.0	 1	 1000.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % NUC
	20584	 37.3	 7.25	 31.4	 -16.9	 1.0	 100.0	 1	 50.6	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.6; % NG
	20584	 16.5	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	20585	 18.6	 3.9	 16.9	 -9.1	 1.0	 100.0	 1	 27.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.2; % PEL
	20585	 16.0	 3.45	 14.9	 -8.0	 1.0	 100.0	 1	 24.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % NG
	20585	 20.5	 4.45	 19.2	 -10.3	 1.0	 100.0	 1	 31.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.0; % PEL
	20587	 8.775	 2.725	 9.8	 -4.35	 1.0	 100.0	 1	 13.05	 4.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.05; % NG
	20587	 8.775	 2.725	 9.8	 -4.35	 1.0	 100.0	 1	 13.05	 4.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.05; % COW
	20588	 12.35	 0.0	 7.8	 -7.8	 1.0	 100.0	 1	 23.7	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.7; % NG
	20588	 12.35	 0.0	 7.8	 -7.8	 1.0	 100.0	 1	 23.7	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.7; % NG
	20589	 12.2	 0.0	 4.8	 -4.8	 1.0	 100.0	 1	 23.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4; % PEL
	20589	 12.2	 0.0	 4.8	 -4.8	 1.0	 100.0	 1	 23.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4; % PEL
	20589	 12.2	 0.0	 4.8	 -4.8	 1.0	 100.0	 1	 23.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4; % COW
	20590	 14.5	 3.15	 13.6	 -7.3	 1.0	 100.0	 1	 22.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % COW
	20590	 16.0	 5.25	 18.8	 -8.3	 1.0	 100.0	 1	 25.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	20590	 16.0	 5.25	 18.8	 -8.3	 1.0	 100.0	 1	 25.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	20591	 3.915	 1.43	 5.13	 -2.27	 1.0	 100.0	 1	 6.83	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8333; % NG
	20591	 3.915	 1.43	 5.13	 -2.27	 1.0	 100.0	 1	 6.83	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8333; % PEL
	20591	 3.915	 1.43	 5.13	 -2.27	 1.0	 100.0	 1	 6.83	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8333; % NG
	20592	 17.0	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	27810	 1033.5	 81.55	 523.1	 -360.0	 1.0	 100.0	 1	 1080.0	 987.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	27810	 1030.5	 81.55	 523.1	 -360.0	 1.0	 100.0	 1	 1080.0	 981.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	27811	 542.95	 55.55	 356.4	 -245.3	 1.0	 100.0	 1	 735.9	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 735.9; % COW
	27811	 542.95	 55.55	 356.4	 -245.3	 1.0	 100.0	 1	 735.9	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 735.9; % NG
	27812	 439.5	 51.3	 328.9	 -226.3	 1.0	 100.0	 1	 679.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 679.0; % COW
	27812	 439.5	 51.3	 328.9	 -226.3	 1.0	 100.0	 1	 679.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 679.0; % NG
	27813	 323.1	 42.0	 269.4	 -185.4	 1.0	 100.0	 1	 556.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 556.2; % COW
	27813	 318.1	 42.0	 269.4	 -185.4	 1.0	 100.0	 1	 556.2	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 556.2; % NG
	27814	 179.1	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.2	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.2; % COW
	27814	 279.75	 35.1	 225.0	 -154.8	 1.0	 100.0	 1	 464.5	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 464.5; % PEL
	27814	 277.25	 35.1	 225.0	 -154.8	 1.0	 100.0	 1	 464.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 464.5; % COW
	27814	 99.295	 18.55	 80.4	 -43.3	 1.0	 100.0	 1	 129.8	 68.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.8; % PEL
	27815	 38.0	 8.85	 38.4	 -20.7	 1.0	 100.0	 1	 62.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	27815	 317.75	 33.65	 215.8	 -148.5	 1.0	 100.0	 1	 445.5	 190.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 445.5; % COW
	27815	 315.25	 33.65	 215.8	 -148.5	 1.0	 100.0	 1	 445.5	 185.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 445.5; % NG
	27815	 315.25	 33.65	 215.8	 -148.5	 1.0	 100.0	 1	 445.5	 185.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 445.5; % NG
	27815	 321.5	 36.7	 235.4	 -162.0	 1.0	 100.0	 1	 486.0	 157.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 486.0; % PEL
	27816	 482.1	 55.8	 358.0	 -246.4	 1.0	 100.0	 1	 739.2	 225.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 739.2; % COW
	27816	 482.1	 55.8	 358.0	 -246.4	 1.0	 100.0	 1	 739.2	 225.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 739.2; % COW
	27816	 601.02	 67.2	 431.2	 -296.8	 1.0	 100.0	 1	 890.4	 311.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	27816	 270.25	 33.25	 213.3	 -146.8	 1.0	 100.0	 1	 440.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 440.5; % NG
	27816	 321.9	 39.55	 253.7	 -174.6	 1.0	 100.0	 1	 523.8	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 523.8; % NG
	27817	 241.2	 0.0	 182.0	 -182.0	 1.0	 100.0	 1	 402.0	 80.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 402.0; % COW
	27817	 241.2	 0.0	 182.0	 -182.0	 1.0	 100.0	 1	 402.0	 80.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 402.0; % NG
	27819	 78.0	 9.5	 61.0	 -42.0	 1.0	 100.0	 1	 126.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 126.0; % COW
	27819	 14.8	 2.0	 12.9	 -8.9	 1.0	 100.0	 1	 26.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.6; % PEL
	27819	 64.25	 7.8	 50.1	 -34.5	 1.0	 100.0	 1	 103.5	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5; % NG
	27819	 194.5	 18.8	 120.6	 -83.0	 1.0	 100.0	 1	 249.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 249.0; % NG
	27819	 271.9	 27.45	 176.2	 -121.3	 1.0	 100.0	 1	 363.8	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 363.8; % NG
	27819	 120.0	 9.05	 58.1	 -40.0	 1.0	 100.0	 1	 120.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0; % NG
	27820	 186.24	 0.0	 140.5	 -140.5	 1.0	 100.0	 1	 310.4	 62.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 310.4; % NG
	27820	 186.24	 0.0	 140.5	 -140.5	 1.0	 100.0	 1	 310.4	 62.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 310.4; % NG
	27821	 438.5	 75.45	 326.6	 -175.7	 1.0	 100.0	 1	 527.0	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 527.0; % COW
	27821	 438.5	 75.45	 326.6	 -175.7	 1.0	 100.0	 1	 527.0	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 527.0; % COW
	27821	 265.0	 42.7	 184.7	 -99.3	 1.0	 100.0	 1	 298.0	 232.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 298.0; % COW
	27821	 265.0	 42.7	 184.7	 -99.3	 1.0	 100.0	 1	 298.0	 232.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 298.0; % COW
	27821	 265.0	 42.7	 184.7	 -99.3	 1.0	 100.0	 1	 298.0	 232.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 298.0; % NG
	27821	 265.0	 42.7	 184.7	 -99.3	 1.0	 100.0	 1	 298.0	 232.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 298.0; % COW
	27821	 265.0	 42.7	 184.7	 -99.3	 1.0	 100.0	 1	 298.0	 232.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 298.0; % COW
	27821	 265.0	 42.7	 184.7	 -99.3	 1.0	 100.0	 1	 298.0	 232.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 298.0; % COW
	27822	 38.55	 4.7	 30.1	 -20.7	 1.0	 100.0	 1	 62.1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.1; % NG
	27822	 38.55	 4.7	 30.1	 -20.7	 1.0	 100.0	 1	 62.1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.1; % NG
	27822	 38.55	 4.7	 30.1	 -20.7	 1.0	 100.0	 1	 62.1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.1; % COW
	27822	 38.55	 4.7	 30.1	 -20.7	 1.0	 100.0	 1	 62.1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.1; % NG
	27822	 306.85	 42.55	 273.0	 -187.9	 1.0	 100.0	 1	 563.7	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 563.7; % NG
	27822	 238.75	 42.6	 184.4	 -99.2	 1.0	 100.0	 1	 297.5	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 297.5; % NG
	27822	 238.75	 42.6	 184.4	 -99.2	 1.0	 100.0	 1	 297.5	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 297.5; % NG
	27823	 190.8	 41.75	 180.7	 -97.2	 1.0	 100.0	 1	 291.6	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 291.6; % NG
	27824	 13.8	 3.5	 15.2	 -8.2	 1.0	 100.0	 1	 24.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.6; % NG
	27824	 13.8	 3.5	 15.2	 -8.2	 1.0	 100.0	 1	 24.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.6; % PEL
	27824	 48.0	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	27824	 73.05	 13.8	 59.6	 -32.0	 1.0	 100.0	 1	 96.1	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.1; % NG
	27824	 157.85	 35.9	 155.4	 -83.6	 1.0	 100.0	 1	 250.7	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 250.7; % NG
	27825	 149.8	 31.45	 136.1	 -73.2	 1.0	 100.0	 1	 219.6	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 219.6; % NG
	27825	 128.4	 27.5	 118.9	 -63.9	 1.0	 100.0	 1	 191.8	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 191.8; % NG
	27826	 37.7	 4.15	 26.8	 -18.5	 1.0	 100.0	 1	 55.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.4; % NG
	27826	 37.7	 4.15	 26.8	 -18.5	 1.0	 100.0	 1	 55.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.4; % NG
	27826	 37.7	 4.15	 26.8	 -18.5	 1.0	 100.0	 1	 55.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.4; % NG
	27826	 37.7	 4.15	 26.8	 -18.5	 1.0	 100.0	 1	 55.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.4; % NG
	27826	 286.415	 31.8	 204.0	 -140.4	 1.0	 100.0	 1	 421.2	 151.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 421.2; % NG
	27826	 150.945	 29.8	 129.0	 -69.4	 1.0	 100.0	 1	 208.2	 93.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 208.2; % NG
	27826	 150.945	 29.8	 129.0	 -69.4	 1.0	 100.0	 1	 208.2	 93.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 208.2; % NG
	27826	 150.945	 29.8	 129.0	 -69.4	 1.0	 100.0	 1	 208.2	 93.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 208.2; % NG
	27826	 150.945	 29.8	 129.0	 -69.4	 1.0	 100.0	 1	 208.2	 93.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 208.2; % NG
	27827	 150.0	 28.6	 123.9	 -66.7	 1.0	 100.0	 1	 200.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	27827	 150.0	 28.6	 123.9	 -66.7	 1.0	 100.0	 1	 200.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	27827	 150.0	 28.6	 123.9	 -66.7	 1.0	 100.0	 1	 200.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	27828	 147.5	 28.6	 123.9	 -66.7	 1.0	 100.0	 1	 200.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	27828	 62.25	 10.7	 46.2	 -24.8	 1.0	 100.0	 1	 74.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.5; % NG
	27829	 149.7	 28.55	 123.6	 -66.5	 1.0	 100.0	 1	 199.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.4; % NG
	27829	 149.7	 28.55	 123.6	 -66.5	 1.0	 100.0	 1	 199.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.4; % NG
	27830	 139.5	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 199.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.0; % NG
	27830	 139.5	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 199.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.0; % COW
	27830	 117.0	 27.05	 117.1	 -63.0	 1.0	 100.0	 1	 189.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.0; % NG
	27831	 36.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % NG
	27831	 36.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % PEL
	27831	 15.0	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % NG
	27831	 52.5	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	27831	 189.6	 37.1	 160.6	 -86.4	 1.0	 100.0	 1	 259.2	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 259.2; % COW
	27831	 134.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	27832	 150.4	 28.45	 123.2	 -66.3	 1.0	 100.0	 1	 198.8	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.8; % COW
	27832	 150.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	27832	 150.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	27832	 150.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	27832	 150.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	27833	 163.1	 27.95	 121.0	 -65.1	 1.0	 100.0	 1	 195.2	 131.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.2; % COW
	27833	 76.95	 11.9	 51.4	 -27.6	 1.0	 100.0	 1	 82.9	 71.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.9; % NG
	27834	 132.4	 13.25	 85.1	 -58.6	 1.0	 100.0	 1	 175.8	 89.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.8; % NG
	27834	 132.4	 13.25	 85.1	 -58.6	 1.0	 100.0	 1	 175.8	 89.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.8; % COW
	27834	 140.95	 25.1	 114.5	 -64.3	 1.0	 100.0	 1	 192.9	 89.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.9; % NG
	27834	 132.4	 25.2	 109.0	 -58.6	 1.0	 100.0	 1	 175.8	 89.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.8; % NG
	27834	 132.4	 25.2	 109.0	 -58.6	 1.0	 100.0	 1	 175.8	 89.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.8; % NG
	27834	 83.2	 19.1	 82.7	 -44.5	 1.0	 100.0	 1	 133.4	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.4; % NG
	27835	 160.0	 37.2	 161.1	 -86.7	 1.0	 100.0	 1	 260.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 260.0; % NG
	27835	 146.05	 27.55	 119.1	 -64.0	 1.0	 100.0	 1	 192.1	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.1; % NG
	27835	 146.05	 27.55	 119.1	 -64.0	 1.0	 100.0	 1	 192.1	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.1; % NG
	27836	 41.95	 10.0	 43.3	 -23.3	 1.0	 100.0	 1	 69.9	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.9; % PEL
	27836	 133.95	 14.35	 92.0	 -63.3	 1.0	 100.0	 1	 189.9	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.9; % NG
	27836	 133.95	 14.35	 92.0	 -63.3	 1.0	 100.0	 1	 189.9	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.9; % NG
	27836	 133.95	 14.35	 92.0	 -63.3	 1.0	 100.0	 1	 189.9	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.9; % NG
	27836	 143.2	 34.3	 148.4	 -79.8	 1.0	 100.0	 1	 239.4	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 239.4; % NG
	27836	 41.95	 10.0	 43.3	 -23.3	 1.0	 100.0	 1	 69.9	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.9; % NG
	27836	 41.95	 10.0	 43.3	 -23.3	 1.0	 100.0	 1	 69.9	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.9; % COW
	27836	 41.95	 10.0	 43.3	 -23.3	 1.0	 100.0	 1	 69.9	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.9; % COW
	27836	 248.85	 33.65	 215.9	 -148.6	 1.0	 100.0	 1	 445.7	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 445.7; % NG
	27836	 133.95	 14.35	 92.0	 -63.3	 1.0	 100.0	 1	 189.9	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.9; % NG
	27836	 133.95	 14.35	 92.0	 -63.3	 1.0	 100.0	 1	 189.9	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.9; % NG
	27836	 133.95	 14.35	 92.0	 -63.3	 1.0	 100.0	 1	 189.9	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.9; % NG
	27836	 133.95	 14.35	 92.0	 -63.3	 1.0	 100.0	 1	 189.9	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.9; % NG
	27837	 104.83	 22.35	 96.8	 -52.1	 1.0	 100.0	 1	 156.2	 53.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.2; % NG
	27837	 33.5	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	27837	 33.5	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	27837	 33.5	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	27837	 33.5	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	27837	 170.0	 25.95	 112.2	 -60.3	 1.0	 100.0	 1	 181.0	 159.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.0; % NG
	27837	 100.0	 25.95	 112.2	 -60.3	 1.0	 100.0	 1	 181.0	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.0; % NG
	27837	 296.55	 62.45	 270.3	 -145.4	 1.0	 100.0	 1	 436.1	 157.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 436.1; % COW
	27837	 139.1	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27837	 139.1	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27837	 139.1	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27837	 33.5	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	27837	 139.1	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27837	 139.1	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27837	 139.1	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % COW
	27837	 33.5	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	27837	 33.5	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	27837	 33.5	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	27837	 33.5	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	27837	 33.5	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	27837	 33.5	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	27837	 33.5	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	27838	 365.55	 39.0	 223.4	 -145.4	 1.0	 100.0	 1	 436.1	 295.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 436.1; % NG
	27838	 136.445	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 84.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27838	 106.215	 22.35	 96.8	 -52.1	 1.0	 100.0	 1	 156.2	 56.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.2; % NG
	27838	 365.55	 39.0	 223.4	 -145.4	 1.0	 100.0	 1	 436.1	 295.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 436.1; % NG
	27838	 136.445	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 84.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27838	 136.445	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 84.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27838	 136.445	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 84.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27838	 136.445	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 84.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27838	 136.445	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 84.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27838	 136.445	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 84.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27838	 136.445	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 84.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27839	 526.65	 77.25	 442.3	 -287.8	 1.0	 100.0	 1	 863.3	 190.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 863.3; % COW
	27839	 526.65	 77.25	 442.3	 -287.8	 1.0	 100.0	 1	 863.3	 190.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 863.3; % COW
	27839	 390.9	 67.55	 292.4	 -157.3	 1.0	 100.0	 1	 471.8	 310.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 471.8; % NG
	27839	 136.445	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 84.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27839	 136.445	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 84.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % COW
	27839	 136.445	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 84.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27839	 136.445	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 84.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27840	 562.25	 83.65	 478.8	 -311.5	 1.0	 100.0	 1	 934.5	 190.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 934.5; % COW
	27840	 173.5	 42.5	 153.0	 -68.0	 1.0	 100.0	 1	 204.0	 143.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0; % NG
	27840	 173.5	 42.5	 153.0	 -68.0	 1.0	 100.0	 1	 204.0	 143.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0; % NG
	27840	 173.5	 42.5	 153.0	 -68.0	 1.0	 100.0	 1	 204.0	 143.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0; % NG
	27840	 173.5	 42.5	 153.0	 -68.0	 1.0	 100.0	 1	 204.0	 143.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0; % NG
	27840	 562.25	 83.65	 478.8	 -311.5	 1.0	 100.0	 1	 934.5	 190.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 934.5; % COW
	27840	 395.85	 67.55	 292.3	 -157.2	 1.0	 100.0	 1	 471.7	 320.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 471.7; % COW
	27840	 136.445	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 84.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27840	 136.445	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 84.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % COW
	27840	 136.445	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 84.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % COW
	27840	 136.445	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 84.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	27840	 173.5	 42.5	 153.0	 -68.0	 1.0	 100.0	 1	 204.0	 143.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0; % NG
	27840	 173.5	 42.5	 153.0	 -68.0	 1.0	 100.0	 1	 204.0	 143.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0; % NG
	27841	 592.0	 57.4	 368.1	 -253.3	 1.0	 100.0	 1	 760.0	 424.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	27841	 648.6	 66.2	 424.8	 -292.4	 1.0	 100.0	 1	 877.2	 420.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	27841	 391.0	 67.6	 292.5	 -157.3	 1.0	 100.0	 1	 472.0	 310.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 472.0; % COW
	27841	 246.0	 57.55	 249.1	 -134.0	 1.0	 100.0	 1	 402.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 402.0; % NG
	27841	 246.0	 57.55	 249.1	 -134.0	 1.0	 100.0	 1	 402.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 402.0; % COW
	27841	 136.3	 26.9	 116.5	 -62.7	 1.0	 100.0	 1	 188.0	 84.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.0; % NG
	27841	 136.3	 26.9	 116.5	 -62.7	 1.0	 100.0	 1	 188.0	 84.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.0; % NG
	27841	 136.3	 26.9	 116.5	 -62.7	 1.0	 100.0	 1	 188.0	 84.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.0; % NG
	27841	 136.3	 26.9	 116.5	 -62.7	 1.0	 100.0	 1	 188.0	 84.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.0; % NG
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % COW
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % COW
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % COW
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % PEL
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % PEL
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % PEL
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % PEL
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % PEL
	27842	 19.6	 7.15	 25.7	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27842	 99.76	 21.65	 93.7	 -50.4	 1.0	 100.0	 1	 151.2	 48.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 151.2; % NG
	27842	 99.76	 21.65	 93.7	 -50.4	 1.0	 100.0	 1	 151.2	 48.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 151.2; % NG
	27842	 170.0	 38.55	 138.8	 -61.7	 1.0	 100.0	 1	 185.0	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	27842	 170.0	 38.55	 138.8	 -61.7	 1.0	 100.0	 1	 185.0	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	27842	 170.0	 38.55	 138.8	 -61.7	 1.0	 100.0	 1	 185.0	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % PEL
	27842	 170.0	 38.55	 138.8	 -61.7	 1.0	 100.0	 1	 185.0	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27842	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27843	 125.0	 13.95	 89.6	 -61.7	 1.0	 100.0	 1	 185.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	27843	 125.0	 26.5	 114.7	 -61.7	 1.0	 100.0	 1	 185.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	27844	 135.0	 13.95	 89.6	 -61.7	 1.0	 100.0	 1	 185.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	27844	 135.0	 13.95	 89.6	 -61.7	 1.0	 100.0	 1	 185.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	27844	 135.0	 13.95	 89.6	 -61.7	 1.0	 100.0	 1	 185.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	27844	 146.55	 32.7	 141.4	 -76.0	 1.0	 100.0	 1	 228.1	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 228.1; % NG
	27845	 146.0	 26.05	 112.8	 -60.7	 1.0	 100.0	 1	 182.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 182.0; % NG
	27845	 146.0	 26.05	 112.8	 -60.7	 1.0	 100.0	 1	 182.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 182.0; % NG
	27845	 146.0	 26.05	 112.8	 -60.7	 1.0	 100.0	 1	 182.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 182.0; % NG
	27845	 146.0	 26.05	 112.8	 -60.7	 1.0	 100.0	 1	 182.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 182.0; % NG
	27846	 33.85	 4.08	 23.23	 -15.07	 1.0	 100.0	 1	 45.2	 22.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.2; % COW
	27846	 33.85	 4.08	 23.23	 -15.07	 1.0	 100.0	 1	 45.2	 22.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.2; % NG
	27846	 33.85	 4.08	 23.23	 -15.07	 1.0	 100.0	 1	 45.2	 22.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.2; % NG
	27846	 33.85	 4.08	 23.23	 -15.07	 1.0	 100.0	 1	 45.2	 22.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.2; % NG
	27847	 145.2	 25.85	 111.8	 -60.1	 1.0	 100.0	 1	 180.4	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.4; % NG
	27847	 145.2	 25.85	 111.8	 -60.1	 1.0	 100.0	 1	 180.4	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.4; % NG
	27847	 145.2	 25.85	 111.8	 -60.1	 1.0	 100.0	 1	 180.4	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.4; % NG
	27848	 138.16	 25.85	 111.9	 -60.2	 1.0	 100.0	 1	 180.6	 95.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.6; % NG
	27848	 139.925	 27.65	 119.6	 -64.3	 1.0	 100.0	 1	 193.0	 86.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 193.0; % NG
	27848	 144.275	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 199.0	 89.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.0; % NG
	27848	 144.275	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 199.0	 89.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.0; % NG
	27848	 128.29	 24.0	 103.9	 -55.9	 1.0	 100.0	 1	 167.7	 88.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.7; % COW
	27848	 128.29	 24.0	 103.9	 -55.9	 1.0	 100.0	 1	 167.7	 88.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.7; % COW
	27848	 132.65	 24.85	 107.5	 -57.8	 1.0	 100.0	 1	 173.4	 91.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.4; % NG
	27848	 132.65	 24.85	 107.5	 -57.8	 1.0	 100.0	 1	 173.4	 91.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.4; % NG
	27848	 144.78	 28.6	 123.8	 -66.6	 1.0	 100.0	 1	 199.7	 89.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.7; % NG
	27848	 147.9	 29.2	 126.4	 -68.0	 1.0	 100.0	 1	 204.0	 91.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0; % NG
	27848	 154.065	 30.45	 131.7	 -70.8	 1.0	 100.0	 1	 212.5	 95.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.5; % NG
	27848	 139.925	 27.65	 119.6	 -64.3	 1.0	 100.0	 1	 193.0	 86.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 193.0; % NG
	27849	 112.3	 21.4	 92.7	 -49.9	 1.0	 100.0	 1	 149.6	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 149.6; % COW
	27849	 132.7	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4; % NG
	27849	 36.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	27849	 178.955	 30.55	 132.2	 -71.1	 1.0	 100.0	 1	 213.3	 144.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.3; % COW
	27849	 147.32	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.2	 91.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.2; % NG
	27849	 147.32	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.2	 91.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.2; % NG
	27850	 110.05	 18.6	 80.6	 -43.4	 1.0	 100.0	 1	 130.1	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.1; % COW
	27851	 75.0	 26.05	 93.8	 -41.7	 1.0	 100.0	 1	 125.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % COW
	27852	 13.085	 2.7	 12.28	 -6.88	 1.0	 100.0	 1	 20.67	 5.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.6667; % COW
	27852	 13.085	 2.7	 12.28	 -6.88	 1.0	 100.0	 1	 20.67	 5.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.6667; % NG
	27852	 13.085	 2.7	 12.28	 -6.88	 1.0	 100.0	 1	 20.67	 5.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.6667; % NG
	27852	 13.085	 2.7	 12.28	 -6.88	 1.0	 100.0	 1	 20.67	 5.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.6667; % NG
	27852	 13.085	 2.7	 12.28	 -6.88	 1.0	 100.0	 1	 20.67	 5.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.6667; % NG
	27852	 13.085	 2.7	 12.28	 -6.88	 1.0	 100.0	 1	 20.67	 5.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.6667; % PEL
	27852	 14.2	 1.75	 11.3	 -7.8	 1.0	 100.0	 1	 23.4	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4; % PEL
	27852	 26.0	 6.0	 26.0	 -14.0	 1.0	 100.0	 1	 42.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0; % NG
	27853	 108.7	 17.55	 75.9	 -40.8	 1.0	 100.0	 1	 122.4	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.4; % NG
	27854	 33.5	 3.95	 25.2	 -17.3	 1.0	 100.0	 1	 52.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.0; % NG
	27854	 95.75	 9.15	 58.8	 -40.5	 1.0	 100.0	 1	 121.5	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.5; % NG
	27855	 43.4	 5.05	 32.4	 -22.3	 1.0	 100.0	 1	 66.8	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.8; % PEL
	27855	 72.65	 16.45	 68.0	 -35.1	 1.0	 100.0	 1	 105.3	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.3; % NG
	27855	 43.4	 5.05	 32.4	 -22.3	 1.0	 100.0	 1	 66.8	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.8; % PEL
	27855	 43.4	 5.05	 32.4	 -22.3	 1.0	 100.0	 1	 66.8	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.8; % NG
	27855	 43.4	 5.05	 32.4	 -22.3	 1.0	 100.0	 1	 66.8	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.8; % PEL
	27855	 43.4	 5.05	 32.4	 -22.3	 1.0	 100.0	 1	 66.8	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.8; % PEL
	27855	 43.4	 5.05	 32.4	 -22.3	 1.0	 100.0	 1	 66.8	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.8; % NG
	27855	 72.65	 15.1	 65.3	 -35.1	 1.0	 100.0	 1	 105.3	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.3; % COW
	27855	 72.65	 15.1	 65.3	 -35.1	 1.0	 100.0	 1	 105.3	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.3; % COW
	27855	 72.65	 15.1	 65.3	 -35.1	 1.0	 100.0	 1	 105.3	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.3; % NG
	27856	 43.35	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % PEL
	27856	 76.75	 14.8	 64.1	 -34.5	 1.0	 100.0	 1	 103.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5; % NG
	27856	 71.75	 14.8	 64.1	 -34.5	 1.0	 100.0	 1	 103.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5; % NG
	27856	 71.75	 14.8	 64.1	 -34.5	 1.0	 100.0	 1	 103.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5; % NG
	27856	 71.75	 14.8	 64.1	 -34.5	 1.0	 100.0	 1	 103.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5; % COW
	27856	 71.75	 14.8	 64.1	 -34.5	 1.0	 100.0	 1	 103.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5; % NG
	27856	 43.35	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	27856	 43.35	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % PEL
	27856	 43.35	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % PEL
	27856	 43.35	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % PEL
	27856	 43.35	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	27856	 81.75	 7.8	 50.1	 -34.5	 1.0	 100.0	 1	 103.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5; % NG
	27856	 76.75	 14.8	 64.1	 -34.5	 1.0	 100.0	 1	 103.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5; % NG
	27856	 76.75	 14.8	 64.1	 -34.5	 1.0	 100.0	 1	 103.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5; % NG
	27857	 69.35	 13.45	 58.1	 -31.2	 1.0	 100.0	 1	 93.7	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.7; % NG
	27857	 69.35	 13.45	 58.1	 -31.2	 1.0	 100.0	 1	 93.7	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.7; % NG
	27857	 294.85	 52.95	 229.1	 -123.2	 1.0	 100.0	 1	 369.7	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 369.7; % NG
	27857	 429.0	 82.75	 358.2	 -192.7	 1.0	 100.0	 1	 578.0	 280.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 578.0; % NG
	27860	 67.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % COW
	27860	 67.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	27860	 67.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	27860	 67.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % COW
	27860	 85.0	 9.05	 58.1	 -40.0	 1.0	 100.0	 1	 120.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0; % NG
	27860	 85.0	 9.05	 58.1	 -40.0	 1.0	 100.0	 1	 120.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0; % NG
	27861	 31.65	 3.3	 21.0	 -14.4	 1.0	 100.0	 1	 43.3	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.3; % NG
	27861	 61.0	 6.2	 39.7	 -27.3	 1.0	 100.0	 1	 82.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.0; % NG
	27863	 133.125	 30.5	 132.0	 -71.0	 1.0	 100.0	 1	 213.0	 53.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.0; % NG
	27863	 50.76	 11.35	 49.0	 -26.3	 1.0	 100.0	 1	 79.0	 22.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 79.0; % PEL
	27863	 185.445	 23.9	 153.5	 -105.7	 1.0	 100.0	 1	 317.0	 53.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 317.0; % NG
	27864	 101.25	 18.9	 91.8	 -54.0	 1.0	 100.0	 1	 162.0	 40.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 162.0; % NG
	27864	 47.865	 9.0	 42.8	 -24.8	 1.0	 100.0	 1	 74.5	 21.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.5; % PEL
	27866	 36.5	 14.6	 52.5	 -23.3	 1.0	 100.0	 1	 70.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0; % PEL
	27866	 31.75	 12.8	 46.1	 -20.5	 1.0	 100.0	 1	 61.5	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.5; % PEL
	27868	 38.0	 9.45	 40.9	 -22.0	 1.0	 100.0	 1	 66.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.0; % PEL
	27869	 31.15	 8.9	 38.6	 -20.8	 1.0	 100.0	 1	 62.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.3; % NG
	27870	 45.6	 4.6	 29.6	 -20.4	 1.0	 100.0	 1	 61.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.2; % NG
	27870	 45.6	 4.6	 29.6	 -20.4	 1.0	 100.0	 1	 61.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.2; % NG
	27870	 45.6	 4.6	 29.6	 -20.4	 1.0	 100.0	 1	 61.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.2; % PEL
	27870	 27.25	 4.95	 21.4	 -11.5	 1.0	 100.0	 1	 34.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.5; % PEL
	27870	 28.75	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % NG
	27870	 57.5	 14.05	 53.1	 -25.0	 1.0	 100.0	 1	 75.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	27871	 2.785	 0.69	 2.59	 -1.21	 1.0	 100.0	 1	 3.64	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6437; % PEL
	27871	 2.785	 0.69	 2.59	 -1.21	 1.0	 100.0	 1	 3.64	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6437; % NG
	27871	 2.785	 0.69	 2.59	 -1.21	 1.0	 100.0	 1	 3.64	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6437; % NG
	27871	 2.785	 0.69	 2.59	 -1.21	 1.0	 100.0	 1	 3.64	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6437; % NG
	27871	 2.785	 0.69	 2.59	 -1.21	 1.0	 100.0	 1	 3.64	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6437; % NG
	27871	 2.785	 0.69	 2.59	 -1.21	 1.0	 100.0	 1	 3.64	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6437; % PEL
	27871	 2.785	 0.69	 2.59	 -1.21	 1.0	 100.0	 1	 3.64	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6437; % PEL
	27871	 2.785	 0.69	 2.59	 -1.21	 1.0	 100.0	 1	 3.64	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6437; % PEL
	27871	 2.785	 0.69	 2.59	 -1.21	 1.0	 100.0	 1	 3.64	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6437; % PEL
	27871	 2.785	 0.69	 2.59	 -1.21	 1.0	 100.0	 1	 3.64	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6437; % PEL
	27871	 2.785	 0.69	 2.59	 -1.21	 1.0	 100.0	 1	 3.64	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6437; % NG
	27871	 2.785	 0.69	 2.59	 -1.21	 1.0	 100.0	 1	 3.64	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6437; % PEL
	27871	 2.785	 0.69	 2.59	 -1.21	 1.0	 100.0	 1	 3.64	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6437; % NG
	27871	 2.785	 0.69	 2.59	 -1.21	 1.0	 100.0	 1	 3.64	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6437; % NG
	27871	 2.785	 0.69	 2.59	 -1.21	 1.0	 100.0	 1	 3.64	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6437; % NG
	27871	 2.785	 0.69	 2.59	 -1.21	 1.0	 100.0	 1	 3.64	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6437; % NG
	27872	 21.5	 0.0	 6.7	 -6.7	 1.0	 100.0	 1	 33.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0; % PEL
	27872	 35.5	 0.0	 11.2	 -11.2	 1.0	 100.0	 1	 55.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0; % NG
	27872	 44.95	 0.0	 11.8	 -11.8	 1.0	 100.0	 1	 57.9	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.9; % NG
	27873	 15.75	 5.55	 19.9	 -8.8	 1.0	 100.0	 1	 26.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.5; % NG
	27873	 33.7	 12.0	 43.1	 -19.1	 1.0	 100.0	 1	 57.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % PEL
	27873	 33.7	 12.0	 43.1	 -19.1	 1.0	 100.0	 1	 57.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % PEL
	27874	 43.35	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	27874	 43.35	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % PEL
	27874	 43.35	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	27874	 43.35	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	27877	 29.5	 7.75	 33.5	 -18.0	 1.0	 100.0	 1	 54.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % PEL
	27877	 39.95	 10.7	 46.4	 -25.0	 1.0	 100.0	 1	 74.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.9; % NG
	27879	 34.5	 7.05	 30.4	 -16.3	 1.0	 100.0	 1	 49.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0; % NG
	27879	 34.5	 7.05	 30.4	 -16.3	 1.0	 100.0	 1	 49.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0; % NG
	27882	 28.4	 6.7	 29.0	 -15.6	 1.0	 100.0	 1	 46.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.8; % NG
	27883	 25.25	 6.5	 28.2	 -15.2	 1.0	 100.0	 1	 45.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.5; % NG
	27884	 7.05	 0.985	 5.67	 -3.7	 1.0	 100.0	 1	 11.1	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.1; % NG
	27884	 7.05	 0.985	 5.67	 -3.7	 1.0	 100.0	 1	 11.1	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.1; % NG
	27884	 7.05	 0.985	 5.67	 -3.7	 1.0	 100.0	 1	 11.1	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.1; % NG
	27884	 7.05	 0.985	 5.67	 -3.7	 1.0	 100.0	 1	 11.1	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.1; % NG
	27885	 23.25	 6.3	 27.3	 -14.7	 1.0	 100.0	 1	 44.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0; % NG
	27885	 38.45	 10.65	 46.1	 -24.8	 1.0	 100.0	 1	 74.4	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.4; % PEL
	27886	 9.75	 0.0	 4.77	 -4.77	 1.0	 100.0	 1	 14.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.5; % COW
	27886	 9.75	 0.0	 4.77	 -4.77	 1.0	 100.0	 1	 14.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.5; % NG
	27886	 9.75	 0.0	 4.77	 -4.77	 1.0	 100.0	 1	 14.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.5; % NG
	27887	 42.545	 3.25	 20.8	 -14.3	 1.0	 100.0	 1	 43.0	 42.09	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.0; % NG
	27888	 31.7	 5.95	 25.7	 -13.8	 1.0	 100.0	 1	 41.4	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4; % NG
	27888	 31.7	 5.95	 25.7	 -13.8	 1.0	 100.0	 1	 41.4	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4; % NG
	27888	 85.0	 18.65	 80.6	 -43.3	 1.0	 100.0	 1	 130.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0; % NG
	27888	 85.0	 18.65	 80.6	 -43.3	 1.0	 100.0	 1	 130.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0; % NG
	27890	 36.6	 3.25	 20.9	 -14.4	 1.0	 100.0	 1	 43.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.2; % NG
	27890	 30.8	 3.0	 19.2	 -13.2	 1.0	 100.0	 1	 39.6	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.6; % NG
	27891	 21.75	 5.55	 23.9	 -12.8	 1.0	 100.0	 1	 38.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.5; % NG
	27891	 21.75	 5.55	 23.9	 -12.8	 1.0	 100.0	 1	 38.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.5; % COW
	27892	 12.6	 2.75	 11.9	 -6.4	 1.0	 100.0	 1	 19.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.2; % PEL
	27892	 12.6	 2.75	 11.9	 -6.4	 1.0	 100.0	 1	 19.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.2; % NG
	27893	 20.0	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0; % NG
	27895	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27895	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27895	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27895	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % PEL
	27895	 241.2	 0.0	 182.0	 -182.0	 1.0	 100.0	 1	 402.0	 80.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 402.0; % NG
	27895	 241.2	 0.0	 182.0	 -182.0	 1.0	 100.0	 1	 402.0	 80.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 402.0; % NG
	27895	 168.64	 35.5	 153.7	 -82.7	 1.0	 100.0	 1	 248.0	 89.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 248.0; % NG
	27895	 168.64	 35.5	 153.7	 -82.7	 1.0	 100.0	 1	 248.0	 89.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 248.0; % NG
	27895	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27895	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % PEL
	27895	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27895	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % PEL
	27895	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27895	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % PEL
	27895	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27895	 19.6	 4.9	 21.2	 -11.4	 1.0	 100.0	 1	 34.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % NG
	27897	 22.85	 4.85	 20.9	 -11.2	 1.0	 100.0	 1	 33.7	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.7; % PEL
	27897	 22.85	 4.85	 20.9	 -11.2	 1.0	 100.0	 1	 33.7	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.7; % NG
	27897	 27.45	 6.15	 26.6	 -14.3	 1.0	 100.0	 1	 42.9	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.9; % NG
	27897	 27.45	 6.15	 26.6	 -14.3	 1.0	 100.0	 1	 42.9	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.9; % PEL
	27899	 26.4	 0.0	 6.8	 -6.8	 1.0	 100.0	 1	 47.8	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.8; % NG
	27899	 17.5	 4.55	 19.8	 -10.7	 1.0	 100.0	 1	 32.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % NG
	27900	 4.75	 0.975	 4.22	 -2.27	 1.0	 100.0	 1	 6.8	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8; % NG
	27900	 4.75	 0.975	 4.22	 -2.27	 1.0	 100.0	 1	 6.8	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8; % PEL
	27900	 4.75	 0.975	 4.22	 -2.27	 1.0	 100.0	 1	 6.8	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8; % PEL
	27900	 4.75	 0.975	 4.22	 -2.27	 1.0	 100.0	 1	 6.8	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8; % PEL
	27900	 4.75	 0.975	 4.22	 -2.27	 1.0	 100.0	 1	 6.8	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8; % NG
	27900	 4.75	 0.975	 4.22	 -2.27	 1.0	 100.0	 1	 6.8	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8; % NG
	27900	 17.25	 3.8	 16.4	 -8.8	 1.0	 100.0	 1	 26.5	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.5; % NG
	27900	 26.2	 3.05	 16.6	 -10.5	 1.0	 100.0	 1	 31.4	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.4; % NG
	27901	 18.1	 0.0	 10.3	 -10.3	 1.0	 100.0	 1	 31.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.2; % PEL
	27902	 9.0	 2.15	 9.3	 -5.0	 1.0	 100.0	 1	 15.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % NG
	27902	 9.0	 2.15	 9.3	 -5.0	 1.0	 100.0	 1	 15.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % NG
	27902	 140.0	 22.95	 99.2	 -53.3	 1.0	 100.0	 1	 160.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 160.0; % NG
	27902	 35.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	27902	 68.5	 12.45	 53.9	 -29.0	 1.0	 100.0	 1	 87.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.0; % NG
	27903	 17.0	 4.3	 18.6	 -10.0	 1.0	 100.0	 1	 30.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0; % COW
	27904	 17.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 29.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.0; % NG
	27905	 15.65	 3.9	 16.9	 -9.1	 1.0	 100.0	 1	 27.3	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.3; % NG
	27906	 15.0	 3.7	 16.1	 -8.7	 1.0	 100.0	 1	 26.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.0; % NG
	27906	 28.75	 7.25	 31.3	 -16.8	 1.0	 100.0	 1	 50.5	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.5; % NG
	27907	 12.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	27908	 18.0	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 24.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % COW
	27908	 18.0	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 24.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % PEL
	27910	 15.55	 1.65	 10.7	 -7.4	 1.0	 100.0	 1	 22.1	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.1; % PEL
	27911	 2.75	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.75	 2.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.75; % PEL
	27911	 2.75	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.75	 2.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.75; % PEL
	27911	 2.75	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.75	 2.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.75; % PEL
	27911	 2.75	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.75	 2.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.75; % PEL
	27911	 2.75	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.75	 2.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.75; % PEL
	27911	 2.75	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.75	 2.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.75; % PEL
	27911	 2.75	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.75	 2.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.75; % PEL
	27911	 2.75	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.75	 2.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.75; % NG
	27912	 12.5	 3.0	 13.0	 -7.0	 1.0	 100.0	 1	 21.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0; % NG
	27913	 11.5	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	27914	 15.0	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	27914	 29.0	 5.6	 24.2	 -13.0	 1.0	 100.0	 1	 39.0	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.0; % COW
	27915	 705.0	 87.55	 561.8	 -386.7	 1.0	 100.0	 1	 1160.0	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NUC
	27915	 705.0	 87.55	 561.8	 -386.7	 1.0	 100.0	 1	 1160.0	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	27916	 691.0	 136.35	 590.0	 -317.3	 1.0	 100.0	 1	 952.0	 430.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 952.0; % COW
	27916	 691.0	 136.35	 590.0	 -317.3	 1.0	 100.0	 1	 952.0	 430.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 952.0; % COW
	27916	 28.9	 4.0	 25.6	 -17.6	 1.0	 100.0	 1	 52.8	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.8; % NG
	27917	 620.5	 67.25	 431.5	 -297.0	 1.0	 100.0	 1	 891.0	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 891.0; % NUC
	27917	 0.0	 0.0	 431.5	 -297.0	 1.0	 100.0	 0	 891.0	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 891.0; % COW
	27917	 620.5	 67.25	 431.5	 -297.0	 1.0	 100.0	 1	 891.0	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 891.0; % COW
	27917	 0.0	 0.0	 431.5	 -297.0	 1.0	 100.0	 0	 891.0	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 891.0; % COW
	27918	 553.55	 88.45	 462.6	 -285.7	 1.0	 100.0	 1	 857.1	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	27918	 557.35	 89.25	 466.7	 -288.2	 1.0	 100.0	 1	 864.7	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NUC
	27919	 0.0	 0.0	 590.0	 -317.3	 1.0	 100.0	 0	 952.0	 550.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 952.0; % COW
	27919	 751.0	 136.35	 590.0	 -317.3	 1.0	 100.0	 1	 952.0	 550.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 952.0; % COW
	27919	 29.575	 4.25	 22.4	 -13.9	 1.0	 100.0	 1	 41.8	 17.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	27919	 0.0	 0.0	 488.9	 -262.9	 1.0	 100.0	 0	 788.8	 450.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 788.8; % COW
	27919	 0.0	 0.0	 499.4	 -268.6	 1.0	 100.0	 0	 805.8	 450.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 805.8; % COW
	27920	 28.76	 4.91	 27.72	 -17.9	 1.0	 100.0	 1	 53.69	 3.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.6917; % NG
	27920	 28.76	 4.91	 27.72	 -17.9	 1.0	 100.0	 1	 53.69	 3.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.6917; % NG
	27920	 28.76	 4.91	 27.72	 -17.9	 1.0	 100.0	 1	 53.69	 3.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.6917; % NG
	27920	 28.76	 4.91	 27.72	 -17.9	 1.0	 100.0	 1	 53.69	 3.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.6917; % NG
	27920	 28.76	 4.91	 27.72	 -17.9	 1.0	 100.0	 1	 53.69	 3.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.6917; % NG
	27920	 28.76	 4.91	 27.72	 -17.9	 1.0	 100.0	 1	 53.69	 3.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.6917; % NG
	27920	 28.76	 4.91	 27.72	 -17.9	 1.0	 100.0	 1	 53.69	 3.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.6917; % NG
	27920	 28.76	 4.91	 27.72	 -17.9	 1.0	 100.0	 1	 53.69	 3.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.6917; % NG
	27920	 28.76	 4.91	 27.72	 -17.9	 1.0	 100.0	 1	 53.69	 3.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.6917; % NG
	27920	 28.76	 4.91	 27.72	 -17.9	 1.0	 100.0	 1	 53.69	 3.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.6917; % NG
	27920	 28.76	 4.91	 27.72	 -17.9	 1.0	 100.0	 1	 53.69	 3.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.6917; % NG
	27920	 28.76	 4.91	 27.72	 -17.9	 1.0	 100.0	 1	 53.69	 3.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.6917; % PEL
	27921	 28.55	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1; % NG
	27921	 24.84	 6.595	 28.49	 -15.3	 1.0	 100.0	 1	 45.89	 3.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.8857; % NG
	27921	 24.84	 6.595	 28.49	 -15.3	 1.0	 100.0	 1	 45.89	 3.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.8857; % NG
	27921	 24.84	 6.595	 28.49	 -15.3	 1.0	 100.0	 1	 45.89	 3.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.8857; % PEL
	27921	 24.84	 6.595	 28.49	 -15.3	 1.0	 100.0	 1	 45.89	 3.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.8857; % NG
	27921	 28.55	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1; % NG
	27921	 28.55	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1; % NG
	27921	 28.55	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1; % NG
	27921	 28.55	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1; % PEL
	27921	 28.55	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1; % NG
	27921	 24.84	 6.595	 28.49	 -15.3	 1.0	 100.0	 1	 45.89	 3.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.8857; % NG
	27921	 24.84	 6.595	 28.49	 -15.3	 1.0	 100.0	 1	 45.89	 3.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.8857; % NG
	27921	 24.84	 6.595	 28.49	 -15.3	 1.0	 100.0	 1	 45.89	 3.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.8857; % NG
	27922	 199.6	 42.85	 185.4	 -99.7	 1.0	 100.0	 1	 299.2	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 299.2; % NG
	27922	 251.3	 49.05	 217.8	 -119.7	 1.0	 100.0	 1	 359.0	 143.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 359.0; % NG
	27922	 397.0	 77.9	 337.1	 -181.3	 1.0	 100.0	 1	 544.0	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 544.0; % COW
	27922	 397.0	 77.9	 337.1	 -181.3	 1.0	 100.0	 1	 544.0	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 544.0; % COW
	27923	 36.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	27923	 36.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	27923	 207.945	 36.55	 172.8	 -99.7	 1.0	 100.0	 1	 299.2	 116.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 299.2; % NG
	27923	 207.945	 36.55	 172.8	 -99.7	 1.0	 100.0	 1	 299.2	 116.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 299.2; % NG
	27924	 191.3	 21.35	 136.9	 -94.2	 1.0	 100.0	 1	 282.6	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 282.6; % NG
	27924	 191.3	 21.35	 136.9	 -94.2	 1.0	 100.0	 1	 282.6	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 282.6; % NG
	27924	 191.3	 21.35	 136.9	 -94.2	 1.0	 100.0	 1	 282.6	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 282.6; % NG
	27925	 223.24	 21.25	 136.5	 -94.0	 1.0	 100.0	 1	 281.9	 164.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 281.9; % NG
	27925	 223.21	 21.25	 136.5	 -94.0	 1.0	 100.0	 1	 281.9	 164.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 281.9; % NG
	27925	 147.32	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.2	 91.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.2; % NG
	27925	 147.32	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.2	 91.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.2; % NG
	27925	 147.32	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.2	 91.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.2; % NG
	27925	 147.32	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.2	 91.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.2; % COW
	27926	 162.025	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.1	 120.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.1; % NG
	27926	 161.75	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.1	 120.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.1; % COW
	27926	 154.645	 30.55	 132.2	 -71.1	 1.0	 100.0	 1	 213.3	 95.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.3; % NG
	27926	 154.645	 30.55	 132.2	 -71.1	 1.0	 100.0	 1	 213.3	 95.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.3; % NG
	27926	 147.25	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.1	 91.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.1; % NG
	27926	 147.25	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.1	 91.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.1; % NG
	27927	 131.9	 25.75	 117.4	 -65.9	 1.0	 100.0	 1	 197.8	 66.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.8; % NG
	27927	 149.7	 28.55	 123.6	 -66.5	 1.0	 100.0	 1	 199.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.4; % NG
	27927	 149.7	 28.55	 123.6	 -66.5	 1.0	 100.0	 1	 199.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.4; % NG
	27928	 149.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	27928	 149.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	27928	 149.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	27928	 149.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	27929	 147.7	 14.0	 89.8	 -61.8	 1.0	 100.0	 1	 185.4	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.4; % NG
	27929	 155.35	 15.15	 97.2	 -66.9	 1.0	 100.0	 1	 200.7	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.7; % NG
	27930	 136.6	 13.8	 88.7	 -61.1	 1.0	 100.0	 1	 183.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.2; % NG
	27930	 136.6	 13.8	 88.7	 -61.1	 1.0	 100.0	 1	 183.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.2; % NG
	27930	 136.6	 13.8	 88.7	 -61.1	 1.0	 100.0	 1	 183.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.2; % NG
	27930	 136.6	 13.8	 88.7	 -61.1	 1.0	 100.0	 1	 183.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.2; % NG
	27930	 136.6	 13.8	 88.7	 -61.1	 1.0	 100.0	 1	 183.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.2; % NG
	27930	 136.6	 13.8	 88.7	 -61.1	 1.0	 100.0	 1	 183.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.2; % NG
	27931	 127.5	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	27931	 127.5	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	27932	 121.3	 13.4	 86.0	 -59.2	 1.0	 100.0	 1	 177.6	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 177.6; % NG
	27932	 79.15	 14.5	 62.8	 -33.8	 1.0	 100.0	 1	 101.3	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.3; % NG
	27932	 79.15	 14.5	 62.8	 -33.8	 1.0	 100.0	 1	 101.3	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.3; % NG
	27932	 79.15	 14.5	 62.8	 -33.8	 1.0	 100.0	 1	 101.3	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.3; % COW
	27932	 79.15	 14.5	 62.8	 -33.8	 1.0	 100.0	 1	 101.3	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.3; % COW
	27932	 79.15	 14.5	 62.8	 -33.8	 1.0	 100.0	 1	 101.3	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.3; % NG
	27932	 79.15	 14.5	 62.8	 -33.8	 1.0	 100.0	 1	 101.3	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.3; % COW
	27932	 79.15	 14.5	 62.8	 -33.8	 1.0	 100.0	 1	 101.3	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.3; % COW
	27932	 79.15	 14.5	 62.8	 -33.8	 1.0	 100.0	 1	 101.3	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.3; % NG
	27933	 153.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	27933	 120.5	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	27933	 158.85	 26.85	 116.3	 -62.6	 1.0	 100.0	 1	 187.7	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.7; % NG
	27934	 137.65	 25.1	 108.6	 -58.4	 1.0	 100.0	 1	 175.3	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.3; % COW
	27934	 137.65	 25.1	 108.6	 -58.4	 1.0	 100.0	 1	 175.3	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.3; % NG
	27934	 137.65	 25.1	 108.6	 -58.4	 1.0	 100.0	 1	 175.3	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.3; % NG
	27934	 137.65	 25.1	 108.6	 -58.4	 1.0	 100.0	 1	 175.3	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.3; % NG
	27935	 140.5	 24.5	 106.0	 -57.0	 1.0	 100.0	 1	 171.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 171.0; % NG
	27935	 140.5	 24.5	 106.0	 -57.0	 1.0	 100.0	 1	 171.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 171.0; % NG
	27935	 145.5	 32.4	 140.1	 -75.3	 1.0	 100.0	 1	 226.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 226.0; % COW
	27936	 136.0	 23.65	 102.3	 -55.0	 1.0	 100.0	 1	 165.0	 107.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0; % NG
	27936	 136.0	 23.65	 102.3	 -55.0	 1.0	 100.0	 1	 165.0	 107.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0; % NG
	27936	 135.5	 23.65	 102.3	 -55.0	 1.0	 100.0	 1	 165.0	 106.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0; % NG
	27937	 132.35	 12.45	 79.8	 -54.9	 1.0	 100.0	 1	 164.7	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 164.7; % NG
	27937	 132.35	 12.45	 79.8	 -54.9	 1.0	 100.0	 1	 164.7	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 164.7; % NG
	27937	 132.35	 12.45	 79.8	 -54.9	 1.0	 100.0	 1	 164.7	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 164.7; % NG
	27938	 114.1	 23.35	 101.1	 -54.4	 1.0	 100.0	 1	 163.2	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2; % NG
	27938	 36.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 31.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	27938	 36.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 31.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	27938	 29.575	 4.25	 22.4	 -13.9	 1.0	 100.0	 1	 41.8	 17.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	27939	 118.5	 21.05	 91.1	 -49.0	 1.0	 100.0	 1	 147.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 147.0; % NG
	27939	 118.5	 21.05	 91.1	 -49.0	 1.0	 100.0	 1	 147.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 147.0; % COW
	27939	 118.5	 21.05	 91.1	 -49.0	 1.0	 100.0	 1	 147.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 147.0; % COW
	27939	 118.5	 21.05	 91.1	 -49.0	 1.0	 100.0	 1	 147.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 147.0; % COW
	27939	 196.0	 43.25	 187.2	 -100.7	 1.0	 100.0	 1	 302.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 302.0; % NG
	27939	 196.0	 43.25	 187.2	 -100.7	 1.0	 100.0	 1	 302.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 302.0; % NG
	27940	 87.5	 9.4	 60.5	 -41.7	 1.0	 100.0	 1	 125.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	27940	 87.5	 9.4	 60.5	 -41.7	 1.0	 100.0	 1	 125.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	27940	 87.5	 9.4	 60.5	 -41.7	 1.0	 100.0	 1	 125.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % COW
	27940	 401.5	 82.75	 358.2	 -192.7	 1.0	 100.0	 1	 578.0	 225.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 578.0; % COW
	27941	 122.5	 0.0	 41.1	 -41.1	 1.0	 100.0	 1	 125.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	27941	 122.5	 0.0	 41.1	 -41.1	 1.0	 100.0	 1	 125.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % COW
	27941	 122.5	 0.0	 41.1	 -41.1	 1.0	 100.0	 1	 125.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % COW
	27941	 122.5	 0.0	 41.1	 -41.1	 1.0	 100.0	 1	 125.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	27942	 83.75	 9.25	 59.3	 -40.8	 1.0	 100.0	 1	 122.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.5; % NG
	27942	 83.75	 9.25	 59.3	 -40.8	 1.0	 100.0	 1	 122.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.5; % NG
	27942	 83.75	 9.25	 59.3	 -40.8	 1.0	 100.0	 1	 122.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.5; % NG
	27942	 105.6	 22.35	 96.8	 -52.1	 1.0	 100.0	 1	 156.2	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.2; % COW
	27942	 105.6	 22.35	 96.8	 -52.1	 1.0	 100.0	 1	 156.2	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.2; % NG
	27942	 251.85	 57.8	 250.2	 -134.6	 1.0	 100.0	 1	 403.7	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 403.7; % NG
	27942	 251.85	 57.8	 250.2	 -134.6	 1.0	 100.0	 1	 403.7	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 403.7; % COW
	27943	 93.0	 17.35	 75.0	 -40.3	 1.0	 100.0	 1	 121.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0; % NG
	27943	 93.0	 17.35	 75.0	 -40.3	 1.0	 100.0	 1	 121.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0; % NG
	27943	 116.5	 23.45	 101.6	 -54.7	 1.0	 100.0	 1	 164.0	 69.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 164.0; % NG
	27943	 116.5	 23.45	 101.6	 -54.7	 1.0	 100.0	 1	 164.0	 69.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 164.0; % COW
	27944	 93.0	 17.35	 75.0	 -40.3	 1.0	 100.0	 1	 121.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0; % NG
	27944	 93.0	 17.35	 75.0	 -40.3	 1.0	 100.0	 1	 121.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0; % COW
	27945	 95.5	 17.35	 75.0	 -40.3	 1.0	 100.0	 1	 121.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0; % NG
	27945	 95.5	 17.35	 75.0	 -40.3	 1.0	 100.0	 1	 121.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0; % NG
	27945	 95.5	 17.35	 75.0	 -40.3	 1.0	 100.0	 1	 121.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0; % NG
	27945	 95.5	 17.35	 75.0	 -40.3	 1.0	 100.0	 1	 121.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0; % NG
	27945	 95.5	 17.35	 75.0	 -40.3	 1.0	 100.0	 1	 121.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0; % NG
	27945	 95.5	 17.35	 75.0	 -40.3	 1.0	 100.0	 1	 121.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0; % NG
	27946	 93.25	 8.05	 51.6	 -35.5	 1.0	 100.0	 1	 106.5	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.5; % NG
	27946	 93.25	 8.05	 51.6	 -35.5	 1.0	 100.0	 1	 106.5	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.5; % NG
	27946	 95.0	 8.3	 53.3	 -36.7	 1.0	 100.0	 1	 110.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.0; % COW
	27947	 73.45	 13.2	 57.0	 -30.6	 1.0	 100.0	 1	 91.9	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.9; % NG
	27947	 73.45	 13.2	 57.0	 -30.6	 1.0	 100.0	 1	 91.9	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.9; % NG
	27948	 80.95	 13.2	 57.0	 -30.6	 1.0	 100.0	 1	 91.9	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.9; % NG
	27948	 80.95	 13.2	 57.0	 -30.6	 1.0	 100.0	 1	 91.9	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.9; % NG
	27948	 80.95	 13.2	 57.0	 -30.6	 1.0	 100.0	 1	 91.9	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.9; % NG
	27948	 80.95	 13.2	 57.0	 -30.6	 1.0	 100.0	 1	 91.9	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.9; % NG
	27948	 80.95	 13.2	 57.0	 -30.6	 1.0	 100.0	 1	 91.9	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.9; % NG
	27948	 80.95	 13.2	 57.0	 -30.6	 1.0	 100.0	 1	 91.9	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.9; % NG
	27948	 80.95	 13.2	 57.0	 -30.6	 1.0	 100.0	 1	 91.9	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.9; % COW
	27948	 80.95	 13.2	 57.0	 -30.6	 1.0	 100.0	 1	 91.9	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.9; % NG
	27948	 80.95	 13.2	 57.0	 -30.6	 1.0	 100.0	 1	 91.9	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.9; % NG
	27948	 80.95	 13.2	 57.0	 -30.6	 1.0	 100.0	 1	 91.9	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.9; % NG
	27949	 73.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	27949	 73.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	27949	 73.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	27949	 73.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	27949	 73.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % PEL
	27949	 73.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	27949	 73.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	27949	 73.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	27950	 80.0	 0.0	 26.3	 -26.3	 1.0	 100.0	 1	 80.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % NG
	27950	 85.0	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % PEL
	27950	 85.0	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	27950	 85.0	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % COW
	27950	 85.0	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	27951	 17.5	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % PEL
	27951	 19.0	 4.3	 18.6	 -10.0	 1.0	 100.0	 1	 30.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0; % NG
	27951	 10.15	 2.46	 10.06	 -5.14	 1.0	 100.0	 1	 15.4	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.4; % NG
	27951	 10.15	 2.46	 10.06	 -5.14	 1.0	 100.0	 1	 15.4	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.4; % NG
	27951	 10.15	 2.46	 10.06	 -5.14	 1.0	 100.0	 1	 15.4	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.4; % NG
	27951	 10.15	 2.46	 10.06	 -5.14	 1.0	 100.0	 1	 15.4	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.4; % NG
	27951	 10.15	 2.46	 10.06	 -5.14	 1.0	 100.0	 1	 15.4	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.4; % NG
	27952	 75.0	 0.0	 24.7	 -24.7	 1.0	 100.0	 1	 75.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	27952	 75.0	 0.0	 24.7	 -24.7	 1.0	 100.0	 1	 75.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	27952	 75.0	 0.0	 24.7	 -24.7	 1.0	 100.0	 1	 75.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	27952	 75.0	 0.0	 24.7	 -24.7	 1.0	 100.0	 1	 75.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	27952	 82.0	 0.0	 27.0	 -27.0	 1.0	 100.0	 1	 82.0	 82.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.0; % NG
	27952	 82.0	 0.0	 27.0	 -27.0	 1.0	 100.0	 1	 82.0	 82.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.0; % COW
	27952	 82.0	 0.0	 27.0	 -27.0	 1.0	 100.0	 1	 82.0	 82.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.0; % NG
	27952	 82.0	 0.0	 27.0	 -27.0	 1.0	 100.0	 1	 82.0	 82.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.0; % NG
	27953	 25.05	 0.0	 10.2	 -10.2	 1.0	 100.0	 1	 50.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	27953	 12.085	 0.0	 7.1	 -7.1	 1.0	 100.0	 1	 24.07	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0667; % NG
	27953	 12.085	 0.0	 7.1	 -7.1	 1.0	 100.0	 1	 24.07	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0667; % NG
	27953	 12.085	 0.0	 7.1	 -7.1	 1.0	 100.0	 1	 24.07	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0667; % PEL
	27954	 12.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 12.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % PEL
	27954	 12.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 12.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % PEL
	27954	 12.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 12.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % PEL
	27954	 12.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 12.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % PEL
	27954	 12.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 12.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % NG
	27954	 12.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 12.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % NG
	27955	 46.4	 11.85	 51.3	 -27.6	 1.0	 100.0	 1	 82.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.8; % NG
	27955	 45.6	 10.2	 44.1	 -23.7	 1.0	 100.0	 1	 71.2	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2; % NG
	27956	 57.0	 9.2	 39.7	 -21.3	 1.0	 100.0	 1	 64.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.0; % NG
	27956	 60.9	 5.45	 34.8	 -23.9	 1.0	 100.0	 1	 71.8	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.8; % NG
	27956	 60.9	 5.45	 34.8	 -23.9	 1.0	 100.0	 1	 71.8	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.8; % COW
	27956	 75.35	 14.4	 62.4	 -33.6	 1.0	 100.0	 1	 100.7	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.7; % NG
	27956	 75.35	 14.4	 62.4	 -33.6	 1.0	 100.0	 1	 100.7	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.7; % COW
	27957	 48.5	 0.0	 20.4	 -20.4	 1.0	 100.0	 1	 62.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	27957	 48.5	 0.0	 20.4	 -20.4	 1.0	 100.0	 1	 62.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % PEL
	27958	 14.775	 3.125	 11.25	 -5.0	 1.0	 100.0	 1	 15.0	 14.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % NG
	27958	 14.775	 3.125	 11.25	 -5.0	 1.0	 100.0	 1	 15.0	 14.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % NG
	27958	 14.775	 3.125	 11.25	 -5.0	 1.0	 100.0	 1	 15.0	 14.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % COW
	27958	 14.775	 3.125	 11.25	 -5.0	 1.0	 100.0	 1	 15.0	 14.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % NG
	27959	 55.4	 4.25	 27.2	 -18.7	 1.0	 100.0	 1	 56.2	 54.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.2; % PEL
	27959	 55.4	 4.25	 27.2	 -18.7	 1.0	 100.0	 1	 56.2	 54.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.2; % PEL
	27959	 51.45	 3.95	 25.3	 -17.4	 1.0	 100.0	 1	 52.2	 50.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.2; % NG
	27959	 51.45	 3.95	 25.3	 -17.4	 1.0	 100.0	 1	 52.2	 50.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.2; % NG
	27959	 51.45	 3.95	 25.3	 -17.4	 1.0	 100.0	 1	 52.2	 50.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.2; % NG
	27959	 51.45	 3.95	 25.3	 -17.4	 1.0	 100.0	 1	 52.2	 50.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.2; % NG
	27960	 78.0	 9.5	 61.0	 -42.0	 1.0	 100.0	 1	 126.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 126.0; % NG
	27960	 76.75	 7.8	 50.1	 -34.5	 1.0	 100.0	 1	 103.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5; % COW
	27960	 41.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	27960	 43.2	 7.8	 33.7	 -18.1	 1.0	 100.0	 1	 54.4	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.4; % NG
	27961	 27.5	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	27961	 28.1	 7.3	 31.7	 -17.1	 1.0	 100.0	 1	 51.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.2; % NG
	27962	 43.4	 7.15	 30.9	 -16.6	 1.0	 100.0	 1	 49.8	 37.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8; % NG
	27962	 43.4	 7.15	 30.9	 -16.6	 1.0	 100.0	 1	 49.8	 37.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8; % NG
	27963	 11.155	 1.75	 8.7	 -5.2	 1.0	 100.0	 1	 15.6	 6.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.6; % NG
	27963	 11.155	 1.75	 8.7	 -5.2	 1.0	 100.0	 1	 15.6	 6.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.6; % COW
	27963	 11.155	 1.75	 8.7	 -5.2	 1.0	 100.0	 1	 15.6	 6.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.6; % NG
	27964	 25.8	 3.55	 22.6	 -15.5	 1.0	 100.0	 1	 46.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.6; % NG
	27965	 11.2	 0.845	 5.42	 -3.73	 1.0	 100.0	 1	 11.2	 11.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % NG
	27965	 11.2	 0.845	 5.42	 -3.73	 1.0	 100.0	 1	 11.2	 11.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % NG
	27965	 11.2	 0.845	 5.42	 -3.73	 1.0	 100.0	 1	 11.2	 11.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % NG
	27965	 11.2	 0.845	 5.42	 -3.73	 1.0	 100.0	 1	 11.2	 11.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % NG
	27966	 31.15	 0.0	 13.9	 -13.9	 1.0	 100.0	 1	 42.3	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.3; % NG
	27966	 31.15	 0.0	 13.9	 -13.9	 1.0	 100.0	 1	 42.3	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.3; % NG
	27967	 41.0	 0.0	 13.8	 -13.8	 1.0	 100.0	 1	 42.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0; % NG
	27967	 41.0	 0.0	 13.8	 -13.8	 1.0	 100.0	 1	 42.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0; % NG
	27967	 41.0	 0.0	 13.8	 -13.8	 1.0	 100.0	 1	 42.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0; % NG
	27967	 41.0	 0.0	 13.8	 -13.8	 1.0	 100.0	 1	 42.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0; % NG
	27968	 20.05	 0.0	 13.5	 -13.5	 1.0	 100.0	 1	 37.1	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.1; % NG
	27968	 24.0	 0.0	 16.3	 -16.3	 1.0	 100.0	 1	 45.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	27969	 35.0	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % COW
	27969	 35.0	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % PEL
	27970	 6.36	 0.0	 2.75	 -2.75	 1.0	 100.0	 1	 8.35	 4.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.35; % PEL
	27970	 6.36	 0.0	 2.75	 -2.75	 1.0	 100.0	 1	 8.35	 4.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.35; % NG
	27970	 6.36	 0.0	 2.75	 -2.75	 1.0	 100.0	 1	 8.35	 4.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.35; % COW
	27970	 6.36	 0.0	 2.75	 -2.75	 1.0	 100.0	 1	 8.35	 4.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.35; % COW
	27971	 2.5	 0.525	 1.88	 -0.83	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	27971	 2.5	 0.525	 1.88	 -0.83	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	27971	 2.5	 0.525	 1.88	 -0.83	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	27971	 2.5	 0.525	 1.88	 -0.83	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % NG
	27971	 2.5	 0.525	 1.88	 -0.83	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	27971	 2.5	 0.525	 1.88	 -0.83	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	27971	 2.5	 0.525	 1.88	 -0.83	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	27971	 2.5	 0.525	 1.88	 -0.83	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	27971	 2.5	 0.525	 1.88	 -0.83	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	27971	 2.5	 0.525	 1.88	 -0.83	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	27971	 2.5	 0.525	 1.88	 -0.83	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	27971	 2.5	 0.525	 1.88	 -0.83	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	27974	 13.6	 5.25	 18.9	 -8.4	 1.0	 100.0	 1	 25.2	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.2; % NG
	27974	 13.6	 5.25	 18.9	 -8.4	 1.0	 100.0	 1	 25.2	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.2; % NG
	27974	 23.5	 9.4	 33.8	 -15.0	 1.0	 100.0	 1	 45.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % PEL
	27974	 23.5	 9.4	 33.8	 -15.0	 1.0	 100.0	 1	 45.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	27975	 7.5	 0.565	 3.63	 -2.5	 1.0	 100.0	 1	 7.5	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5; % COW
	27975	 7.5	 0.565	 3.63	 -2.5	 1.0	 100.0	 1	 7.5	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5; % NG
	27975	 7.5	 0.565	 3.63	 -2.5	 1.0	 100.0	 1	 7.5	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5; % NG
	27976	 22.2	 4.7	 16.9	 -7.5	 1.0	 100.0	 1	 22.5	 21.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5; % PEL
	27976	 22.2	 4.7	 16.9	 -7.5	 1.0	 100.0	 1	 22.5	 21.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5; % NG
	27977	 14.6	 4.6	 16.5	 -7.3	 1.0	 100.0	 1	 22.0	 7.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	27978	 21.0	 3.15	 13.6	 -7.3	 1.0	 100.0	 1	 22.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	27978	 34.2	 5.5	 23.8	 -12.8	 1.0	 100.0	 1	 38.4	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.4; % NG
	27979	 10.75	 4.15	 15.0	 -6.7	 1.0	 100.0	 1	 20.0	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	27980	 1177.6	 91.0	 583.7	 -401.7	 1.0	 100.0	 1	 1205.1	 1150.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	27980	 1172.6	 91.0	 583.7	 -401.7	 1.0	 100.0	 1	 1205.1	 1140.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NUC
	27981	 589.8	 0.0	 484.0	 -484.0	 1.0	 100.0	 1	 1029.6	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	27982	 876.15	 67.4	 432.6	 -297.8	 1.0	 100.0	 1	 893.3	 859.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	27982	 867.35	 66.9	 429.4	 -295.6	 1.0	 100.0	 1	 886.7	 848.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	27982	 0.0	 0.0	 429.4	 -295.6	 1.0	 100.0	 0	 886.7	 847.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	27983	 15.95	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 26.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.9; % NG
	27983	 15.95	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 26.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.9; % NG
	27983	 566.35	 47.75	 306.4	 -210.9	 1.0	 100.0	 1	 632.7	 500.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 632.7; % NG
	27984	 403.1	 42.0	 269.4	 -185.4	 1.0	 100.0	 1	 556.2	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 556.2; % NG
	27984	 425.45	 44.6	 286.2	 -197.0	 1.0	 100.0	 1	 590.9	 260.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 590.9; % NG
	27984	 420.5	 44.6	 286.2	 -197.0	 1.0	 100.0	 1	 591.0	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 591.0; % NG
	27984	 451.0	 49.25	 315.8	 -217.3	 1.0	 100.0	 1	 652.0	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 652.0; % COW
	27985	 363.65	 59.75	 258.6	 -139.1	 1.0	 100.0	 1	 417.3	 310.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 417.3; % NG
	27986	 302.95	 55.3	 239.2	 -128.6	 1.0	 100.0	 1	 385.9	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 385.9; % COW
	27986	 302.95	 55.3	 239.2	 -128.6	 1.0	 100.0	 1	 385.9	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 385.9; % NG
	27987	 212.5	 23.8	 152.6	 -105.0	 1.0	 100.0	 1	 315.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 315.0; % NG
	27987	 207.5	 23.8	 152.6	 -105.0	 1.0	 100.0	 1	 315.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 315.0; % NG
	27987	 207.5	 23.8	 152.6	 -105.0	 1.0	 100.0	 1	 315.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 315.0; % COW
	27987	 207.5	 23.8	 152.6	 -105.0	 1.0	 100.0	 1	 315.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 315.0; % NG
	27988	 143.585	 29.55	 128.0	 -68.9	 1.0	 100.0	 1	 206.6	 80.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.6; % NG
	27988	 754.8	 0.0	 315.7	 -315.7	 1.0	 100.0	 1	 768.6	 741.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	27989	 230.0	 30.6	 196.2	 -135.0	 1.0	 100.0	 1	 405.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 405.0; % NG
	27989	 141.95	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	27989	 141.95	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	27989	 141.95	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	27990	 16.23	 2.55	 12.7	 -7.6	 1.0	 100.0	 1	 22.7	 9.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.7; % PEL
	27990	 15.115	 2.54	 11.67	 -6.59	 1.0	 100.0	 1	 19.76	 10.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.76; % PEL
	27990	 15.115	 2.54	 11.67	 -6.59	 1.0	 100.0	 1	 19.76	 10.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.76; % NG
	27990	 15.115	 2.54	 11.67	 -6.59	 1.0	 100.0	 1	 19.76	 10.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.76; % PEL
	27990	 15.115	 2.54	 11.67	 -6.59	 1.0	 100.0	 1	 19.76	 10.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.76; % NG
	27990	 15.115	 2.54	 11.67	 -6.59	 1.0	 100.0	 1	 19.76	 10.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.76; % NG
	27990	 16.23	 2.55	 12.7	 -7.6	 1.0	 100.0	 1	 22.7	 9.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.7; % PEL
	27990	 16.23	 2.55	 12.7	 -7.6	 1.0	 100.0	 1	 22.7	 9.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.7; % PEL
	27990	 16.23	 2.55	 12.7	 -7.6	 1.0	 100.0	 1	 22.7	 9.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.7; % PEL
	27990	 15.115	 2.54	 11.67	 -6.59	 1.0	 100.0	 1	 19.76	 10.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.76; % NG
	27990	 15.115	 2.54	 11.67	 -6.59	 1.0	 100.0	 1	 19.76	 10.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.76; % COW
	27990	 15.115	 2.54	 11.67	 -6.59	 1.0	 100.0	 1	 19.76	 10.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.76; % NG
	27990	 15.115	 2.54	 11.67	 -6.59	 1.0	 100.0	 1	 19.76	 10.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.76; % NG
	27990	 15.115	 2.54	 11.67	 -6.59	 1.0	 100.0	 1	 19.76	 10.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.76; % NG
	27991	 148.5	 28.2	 122.1	 -65.7	 1.0	 100.0	 1	 197.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0; % NG
	27991	 148.5	 28.2	 122.1	 -65.7	 1.0	 100.0	 1	 197.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0; % COW
	27991	 148.5	 28.2	 122.1	 -65.7	 1.0	 100.0	 1	 197.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0; % NG
	27991	 148.5	 28.2	 122.1	 -65.7	 1.0	 100.0	 1	 197.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0; % NG
	27991	 148.5	 28.2	 122.1	 -65.7	 1.0	 100.0	 1	 197.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0; % NG
	27992	 147.25	 20.7	 132.9	 -91.5	 1.0	 100.0	 1	 274.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 274.5; % NG
	27992	 148.5	 28.2	 122.1	 -65.7	 1.0	 100.0	 1	 197.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0; % NG
	27992	 148.5	 28.2	 122.1	 -65.7	 1.0	 100.0	 1	 197.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0; % NG
	27993	 174.25	 14.6	 93.7	 -64.5	 1.0	 100.0	 1	 193.5	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 193.5; % NG
	27993	 174.25	 14.6	 93.7	 -64.5	 1.0	 100.0	 1	 193.5	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 193.5; % NG
	27993	 174.25	 14.6	 93.7	 -64.5	 1.0	 100.0	 1	 193.5	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 193.5; % NG
	27993	 174.25	 14.6	 93.7	 -64.5	 1.0	 100.0	 1	 193.5	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 193.5; % NG
	27994	 142.5	 23.65	 102.3	 -55.0	 1.0	 100.0	 1	 165.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0; % NG
	27994	 142.5	 23.65	 102.3	 -55.0	 1.0	 100.0	 1	 165.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0; % COW
	27994	 92.5	 23.65	 102.3	 -55.0	 1.0	 100.0	 1	 165.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0; % NG
	27994	 92.5	 23.65	 102.3	 -55.0	 1.0	 100.0	 1	 165.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0; % NG
	27994	 47.0	 12.05	 52.1	 -28.0	 1.0	 100.0	 1	 84.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.0; % COW
	27994	 47.0	 12.05	 52.1	 -28.0	 1.0	 100.0	 1	 84.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.0; % NG
	27994	 47.0	 12.05	 52.1	 -28.0	 1.0	 100.0	 1	 84.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.0; % NG
	27994	 155.0	 27.25	 117.8	 -63.3	 1.0	 100.0	 1	 190.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.0; % NG
	27995	 100.9	 21.05	 91.0	 -48.9	 1.0	 100.0	 1	 146.8	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 146.8; % NG
	27995	 100.9	 21.05	 91.0	 -48.9	 1.0	 100.0	 1	 146.8	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 146.8; % NG
	27996	 90.5	 25.5	 96.3	 -45.3	 1.0	 100.0	 1	 136.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % NG
	27996	 131.3	 40.8	 154.1	 -72.5	 1.0	 100.0	 1	 217.6	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.6; % NG
	27996	 94.52	 25.5	 96.3	 -45.3	 1.0	 100.0	 1	 136.0	 53.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % NG
	27997	 13.55	 2.0	 11.44	 -7.44	 1.0	 100.0	 1	 22.3	 4.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.3; % PEL
	27997	 13.55	 2.0	 11.44	 -7.44	 1.0	 100.0	 1	 22.3	 4.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.3; % PEL
	27997	 13.55	 2.0	 11.44	 -7.44	 1.0	 100.0	 1	 22.3	 4.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.3; % NG
	27997	 13.55	 2.0	 11.44	 -7.44	 1.0	 100.0	 1	 22.3	 4.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.3; % PEL
	27997	 13.55	 2.0	 11.44	 -7.44	 1.0	 100.0	 1	 22.3	 4.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.3; % COW
	27997	 22.65	 2.65	 17.1	 -11.8	 1.0	 100.0	 1	 35.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.3; % PEL
	27997	 15.3	 2.0	 12.9	 -8.9	 1.0	 100.0	 1	 26.6	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.6; % NG
	27997	 15.3	 2.0	 12.9	 -8.9	 1.0	 100.0	 1	 26.6	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.6; % PEL
	27998	 36.95	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % NG
	27998	 62.5	 15.65	 56.3	 -25.0	 1.0	 100.0	 1	 75.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	27998	 80.0	 20.85	 75.0	 -33.3	 1.0	 100.0	 1	 100.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0; % NG
	27998	 17.635	 3.99	 17.23	 -9.25	 1.0	 100.0	 1	 27.77	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.775; % NG
	27998	 17.635	 3.99	 17.23	 -9.25	 1.0	 100.0	 1	 27.77	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.775; % PEL
	27998	 17.635	 3.99	 17.23	 -9.25	 1.0	 100.0	 1	 27.77	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.775; % NG
	27998	 17.635	 3.99	 17.23	 -9.25	 1.0	 100.0	 1	 27.77	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.775; % COW
	27998	 136.95	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	27998	 136.95	 41.45	 149.2	 -66.3	 1.0	 100.0	 1	 198.9	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	27998	 62.5	 15.65	 56.3	 -25.0	 1.0	 100.0	 1	 75.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	27999	 42.05	 9.2	 44.8	 -26.4	 1.0	 100.0	 1	 79.1	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 79.1; % COW
	27999	 20.6	 4.43	 20.83	 -11.97	 1.0	 100.0	 1	 35.87	 5.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.8667; % NG
	27999	 20.6	 4.43	 20.83	 -11.97	 1.0	 100.0	 1	 35.87	 5.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.8667; % NG
	27999	 20.6	 4.43	 20.83	 -11.97	 1.0	 100.0	 1	 35.87	 5.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.8667; % PEL
	28000	 87.15	 14.3	 61.9	 -33.3	 1.0	 100.0	 1	 99.9	 74.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.9; % NG
	28000	 87.15	 14.3	 61.9	 -33.3	 1.0	 100.0	 1	 99.9	 74.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.9; % NG
	28000	 87.15	 14.3	 61.9	 -33.3	 1.0	 100.0	 1	 99.9	 74.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.9; % NG
	28000	 87.15	 14.3	 61.9	 -33.3	 1.0	 100.0	 1	 99.9	 74.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.9; % NG
	28000	 87.15	 14.3	 61.9	 -33.3	 1.0	 100.0	 1	 99.9	 74.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.9; % NG
	28000	 87.15	 14.3	 61.9	 -33.3	 1.0	 100.0	 1	 99.9	 74.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.9; % NG
	28000	 87.15	 14.3	 61.9	 -33.3	 1.0	 100.0	 1	 99.9	 74.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.9; % NG
	28000	 87.15	 14.3	 61.9	 -33.3	 1.0	 100.0	 1	 99.9	 74.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.9; % NG
	28001	 62.1	 14.2	 61.5	 -33.1	 1.0	 100.0	 1	 99.2	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.2; % NG
	28002	 47.5	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	28002	 47.5	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	28002	 70.0	 12.9	 55.8	 -30.0	 1.0	 100.0	 1	 90.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	28002	 69.5	 12.9	 55.8	 -30.0	 1.0	 100.0	 1	 90.0	 49.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	28003	 55.08	 11.15	 49.5	 -27.2	 1.0	 100.0	 1	 81.6	 28.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % NG
	28003	 55.08	 11.15	 49.5	 -27.2	 1.0	 100.0	 1	 81.6	 28.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % NG
	28004	 77.4	 5.95	 38.2	 -26.3	 1.0	 100.0	 1	 78.8	 76.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.8; % PEL
	28004	 77.4	 5.95	 38.2	 -26.3	 1.0	 100.0	 1	 78.8	 76.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.8; % PEL
	28005	 9.75	 2.65	 11.47	 -6.17	 1.0	 100.0	 1	 18.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.5; % NG
	28005	 9.75	 2.65	 11.47	 -6.17	 1.0	 100.0	 1	 18.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.5; % NG
	28005	 9.75	 2.65	 11.47	 -6.17	 1.0	 100.0	 1	 18.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.5; % PEL
	28005	 9.75	 2.65	 11.47	 -6.17	 1.0	 100.0	 1	 18.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.5; % NG
	28006	 38.4	 5.05	 32.4	 -22.3	 1.0	 100.0	 1	 66.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.8; % NG
	28006	 37.9	 5.0	 31.9	 -21.9	 1.0	 100.0	 1	 65.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.8; % NG
	28006	 37.9	 5.0	 31.9	 -21.9	 1.0	 100.0	 1	 65.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.8; % NG
	28006	 99.0	 11.9	 76.5	 -52.7	 1.0	 100.0	 1	 158.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 158.0; % NG
	28006	 99.0	 11.9	 76.5	 -52.7	 1.0	 100.0	 1	 158.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 158.0; % NG
	28006	 38.4	 5.05	 32.4	 -22.3	 1.0	 100.0	 1	 66.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.8; % NG
	28006	 38.4	 5.05	 32.4	 -22.3	 1.0	 100.0	 1	 66.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.8; % PEL
	28006	 38.4	 5.05	 32.4	 -22.3	 1.0	 100.0	 1	 66.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.8; % NG
	28006	 38.4	 5.05	 32.4	 -22.3	 1.0	 100.0	 1	 66.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.8; % PEL
	28006	 38.4	 5.05	 32.4	 -22.3	 1.0	 100.0	 1	 66.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.8; % PEL
	28006	 37.9	 5.0	 31.9	 -21.9	 1.0	 100.0	 1	 65.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.8; % NG
	28006	 37.9	 5.0	 31.9	 -21.9	 1.0	 100.0	 1	 65.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.8; % COW
	28006	 37.9	 5.0	 31.9	 -21.9	 1.0	 100.0	 1	 65.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.8; % NG
	28007	 56.95	 4.8	 30.9	 -21.3	 1.0	 100.0	 1	 63.9	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.9; % NG
	28007	 56.95	 4.8	 30.9	 -21.3	 1.0	 100.0	 1	 63.9	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.9; % NG
	28007	 56.95	 4.8	 30.9	 -21.3	 1.0	 100.0	 1	 63.9	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.9; % NG
	28007	 56.95	 4.8	 30.9	 -21.3	 1.0	 100.0	 1	 63.9	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.9; % NG
	28007	 56.95	 4.8	 30.9	 -21.3	 1.0	 100.0	 1	 63.9	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.9; % NG
	28007	 56.95	 4.8	 30.9	 -21.3	 1.0	 100.0	 1	 63.9	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.9; % NG
	28007	 56.95	 4.8	 30.9	 -21.3	 1.0	 100.0	 1	 63.9	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.9; % NG
	28007	 56.95	 4.8	 30.9	 -21.3	 1.0	 100.0	 1	 63.9	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.9; % NG
	28008	 15.0	 1.14	 7.28	 -5.0	 1.0	 100.0	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % NG
	28008	 15.0	 1.14	 7.28	 -5.0	 1.0	 100.0	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % PEL
	28008	 15.0	 1.14	 7.28	 -5.0	 1.0	 100.0	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % NG
	28008	 15.0	 1.14	 7.28	 -5.0	 1.0	 100.0	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % NG
	28009	 55.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % COW
	28009	 29.1	 5.9	 25.5	 -13.7	 1.0	 100.0	 1	 41.2	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.2; % COW
	28010	 11.2	 0.0	 3.68	 -3.68	 1.0	 100.0	 1	 11.2	 11.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % NG
	28010	 11.2	 0.0	 3.68	 -3.68	 1.0	 100.0	 1	 11.2	 11.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % NG
	28010	 11.2	 0.0	 3.68	 -3.68	 1.0	 100.0	 1	 11.2	 11.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % NG
	28010	 11.2	 0.0	 3.68	 -3.68	 1.0	 100.0	 1	 11.2	 11.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % NG
	28010	 11.2	 0.0	 3.68	 -3.68	 1.0	 100.0	 1	 11.2	 11.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % COW
	28011	 49.85	 3.9	 25.0	 -17.2	 1.0	 100.0	 1	 51.7	 48.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7; % NG
	28011	 49.85	 3.9	 25.0	 -17.2	 1.0	 100.0	 1	 51.7	 48.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7; % NG
	28011	 49.85	 3.9	 25.0	 -17.2	 1.0	 100.0	 1	 51.7	 48.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7; % NG
	28011	 49.85	 3.9	 25.0	 -17.2	 1.0	 100.0	 1	 51.7	 48.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7; % PEL
	28011	 49.85	 3.9	 25.0	 -17.2	 1.0	 100.0	 1	 51.7	 48.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7; % NG
	28011	 49.85	 3.9	 25.0	 -17.2	 1.0	 100.0	 1	 51.7	 48.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7; % NG
	28011	 49.85	 3.9	 25.0	 -17.2	 1.0	 100.0	 1	 51.7	 48.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7; % NG
	28012	 33.2	 7.4	 31.9	 -17.1	 1.0	 100.0	 1	 51.4	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.4; % NG
	28013	 39.2	 6.95	 30.0	 -16.1	 1.0	 100.0	 1	 48.4	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.4; % NG
	28013	 45.6	 8.75	 37.9	 -20.4	 1.0	 100.0	 1	 61.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.2; % NG
	28014	 15.0	 1.815	 8.63	 -5.0	 1.0	 100.0	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % COW
	28014	 15.0	 1.815	 8.63	 -5.0	 1.0	 100.0	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % NG
	28014	 15.0	 1.815	 8.63	 -5.0	 1.0	 100.0	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % COW
	28015	 14.5	 3.135	 11.27	 -5.0	 1.0	 100.0	 1	 15.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % PEL
	28015	 14.5	 3.135	 11.27	 -5.0	 1.0	 100.0	 1	 15.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % NG
	28015	 14.5	 3.135	 11.27	 -5.0	 1.0	 100.0	 1	 15.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % PEL
	28016	 8.46	 0.64	 4.1	 -2.82	 1.0	 100.0	 1	 8.46	 8.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.46; % NG
	28016	 8.46	 0.64	 4.1	 -2.82	 1.0	 100.0	 1	 8.46	 8.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.46; % NG
	28016	 8.46	 0.64	 4.1	 -2.82	 1.0	 100.0	 1	 8.46	 8.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.46; % NG
	28016	 8.46	 0.64	 4.1	 -2.82	 1.0	 100.0	 1	 8.46	 8.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.46; % NG
	28016	 8.46	 0.64	 4.1	 -2.82	 1.0	 100.0	 1	 8.46	 8.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.46; % NG
	28018	 17.25	 4.55	 19.8	 -10.7	 1.0	 100.0	 1	 32.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % NG
	28018	 17.25	 4.55	 19.8	 -10.7	 1.0	 100.0	 1	 32.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % NG
	28018	 66.0	 17.45	 75.6	 -40.7	 1.0	 100.0	 1	 122.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % NG
	28019	 24.3	 2.3	 14.8	 -10.2	 1.0	 100.0	 1	 30.6	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.6; % NG
	28019	 24.3	 2.3	 14.8	 -10.2	 1.0	 100.0	 1	 30.6	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.6; % COW
	28019	 21.8	 2.3	 14.8	 -10.2	 1.0	 100.0	 1	 30.6	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.6; % PEL
	28019	 21.8	 2.3	 14.8	 -10.2	 1.0	 100.0	 1	 30.6	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.6; % NG
	28019	 32.5	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	28019	 32.5	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	28020	 5.585	 2.085	 7.5	 -3.33	 1.0	 100.0	 1	 10.0	 1.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % NG
	28020	 5.585	 2.085	 7.5	 -3.33	 1.0	 100.0	 1	 10.0	 1.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % NG
	28020	 5.585	 2.085	 7.5	 -3.33	 1.0	 100.0	 1	 10.0	 1.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % PEL
	28021	 3.44	 0.73	 2.62	 -1.16	 1.0	 100.0	 1	 3.5	 3.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.5; % PEL
	28021	 3.44	 0.73	 2.62	 -1.16	 1.0	 100.0	 1	 3.5	 3.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.5; % NG
	28021	 3.44	 0.73	 2.62	 -1.16	 1.0	 100.0	 1	 3.5	 3.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.5; % PEL
	28021	 3.44	 0.73	 2.62	 -1.16	 1.0	 100.0	 1	 3.5	 3.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.5; % NG
	28021	 3.44	 0.73	 2.62	 -1.16	 1.0	 100.0	 1	 3.5	 3.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.5; % NG
	28021	 3.44	 0.73	 2.62	 -1.16	 1.0	 100.0	 1	 3.5	 3.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.5; % NG
	28021	 3.44	 0.73	 2.62	 -1.16	 1.0	 100.0	 1	 3.5	 3.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.5; % NG
	28021	 3.44	 0.73	 2.62	 -1.16	 1.0	 100.0	 1	 3.5	 3.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.5; % NG
	28023	 15.0	 4.05	 17.4	 -9.3	 1.0	 100.0	 1	 28.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0; % PEL
	28024	 35.85	 4.85	 31.3	 -21.6	 1.0	 100.0	 1	 64.7	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.7; % NG
	28024	 14.3	 2.0	 12.9	 -8.9	 1.0	 100.0	 1	 26.6	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.6; % PEL
	28024	 14.3	 2.0	 12.9	 -8.9	 1.0	 100.0	 1	 26.6	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.6; % COW
	28025	 3.0	 0.625	 2.25	 -1.0	 1.0	 100.0	 1	 3.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.0; % PEL
	28025	 3.0	 0.625	 2.25	 -1.0	 1.0	 100.0	 1	 3.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.0; % PEL
	28025	 3.0	 0.625	 2.25	 -1.0	 1.0	 100.0	 1	 3.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.0; % PEL
	28025	 3.0	 0.625	 2.25	 -1.0	 1.0	 100.0	 1	 3.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.0; % NG
	28025	 3.0	 0.625	 2.25	 -1.0	 1.0	 100.0	 1	 3.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.0; % NG
	28025	 3.0	 0.625	 2.25	 -1.0	 1.0	 100.0	 1	 3.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.0; % PEL
	28025	 3.0	 0.625	 2.25	 -1.0	 1.0	 100.0	 1	 3.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.0; % NG
	28025	 3.0	 0.625	 2.25	 -1.0	 1.0	 100.0	 1	 3.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.0; % PEL
	35250	 1126.4	 0.0	 378.6	 -378.6	 1.0	 100.0	 1	 1152.0	 1100.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	35250	 1127.5	 0.0	 455.3	 -455.3	 1.0	 100.0	 1	 1152.0	 1103.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	35250	 1147.45	 0.0	 470.3	 -470.3	 1.0	 100.0	 1	 1190.0	 1104.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	35251	 569.1	 127.2	 550.5	 -296.1	 1.0	 100.0	 1	 888.2	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	35251	 0.0	 0.0	 550.5	 -296.1	 1.0	 100.0	 0	 888.2	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	35252	 502.75	 101.0	 437.2	 -235.2	 1.0	 100.0	 1	 705.5	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 705.5; % COW
	35252	 502.75	 101.0	 437.2	 -235.2	 1.0	 100.0	 1	 705.5	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 705.5; % COW
	35252	 502.75	 101.0	 437.2	 -235.2	 1.0	 100.0	 1	 705.5	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 705.5; % COW
	35252	 502.75	 101.0	 437.2	 -235.2	 1.0	 100.0	 1	 705.5	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 705.5; % COW
	35253	 113.75	 20.735	 95.97	 -54.5	 1.0	 100.0	 1	 163.5	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.5; % COW
	35253	 113.75	 20.735	 95.97	 -54.5	 1.0	 100.0	 1	 163.5	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.5; % COW
	35253	 113.75	 20.735	 95.97	 -54.5	 1.0	 100.0	 1	 163.5	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.5; % PEL
	35253	 113.75	 20.735	 95.97	 -54.5	 1.0	 100.0	 1	 163.5	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.5; % NG
	35254	 104.05	 21.95	 94.9	 -51.0	 1.0	 100.0	 1	 153.1	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 153.1; % NG
	35254	 163.1	 27.95	 121.0	 -65.1	 1.0	 100.0	 1	 195.2	 131.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.2; % NG
	35254	 0.0	 0.0	 250.2	 -134.6	 1.0	 100.0	 0	 403.7	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 403.7; % COW
	35254	 104.05	 21.95	 94.9	 -51.0	 1.0	 100.0	 1	 153.1	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 153.1; % NG
	35254	 137.05	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.1	 104.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.1; % NG
	35254	 137.05	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.1	 104.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.1; % NG
	35254	 128.55	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.1	 87.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.1; % NG
	35254	 124.55	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.1	 79.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.1; % NG
	35254	 0.0	 0.0	 488.9	 -262.9	 1.0	 100.0	 0	 788.8	 465.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 788.8; % COW
	35254	 0.0	 0.0	 168.6	 -90.7	 1.0	 100.0	 0	 272.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 272.0; % NG
	35254	 0.0	 0.0	 121.0	 -65.1	 1.0	 100.0	 0	 195.2	 141.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.2; % NG
	35255	 157.4	 35.05	 151.7	 -81.6	 1.0	 100.0	 1	 244.8	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 244.8; % NG
	35255	 826.0	 136.35	 590.0	 -317.3	 1.0	 100.0	 1	 952.0	 700.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 952.0; % COW
	35255	 18.6	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % NG
	35255	 171.0	 38.95	 168.6	 -90.7	 1.0	 100.0	 1	 272.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 272.0; % NG
	35255	 171.0	 38.95	 168.6	 -90.7	 1.0	 100.0	 1	 272.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 272.0; % NG
	35255	 171.0	 38.95	 168.6	 -90.7	 1.0	 100.0	 1	 272.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 272.0; % COW
	35256	 73.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 66.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % NG
	35256	 189.6	 38.55	 166.8	 -89.7	 1.0	 100.0	 1	 269.2	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 269.2; % NG
	35256	 204.6	 42.85	 185.4	 -99.7	 1.0	 100.0	 1	 299.2	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 299.2; % NG
	35256	 73.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 66.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % NG
	35256	 73.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 66.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % NG
	35256	 73.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 66.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % NG
	35256	 73.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 66.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % COW
	35256	 73.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 66.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % NG
	35256	 73.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 66.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % NG
	35256	 73.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 66.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % PEL
	35256	 73.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 66.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % NG
	35257	 216.7	 37.0	 160.1	 -86.1	 1.0	 100.0	 1	 258.4	 175.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 258.4; % NG
	35257	 216.7	 37.0	 160.1	 -86.1	 1.0	 100.0	 1	 258.4	 175.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 258.4; % COW
	35257	 200.5	 43.8	 189.6	 -102.0	 1.0	 100.0	 1	 306.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 306.0; % NG
	35258	 194.5	 32.8	 141.9	 -76.3	 1.0	 100.0	 1	 229.0	 160.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 229.0; % NG
	35258	 76.55	 12.65	 54.8	 -29.5	 1.0	 100.0	 1	 88.4	 64.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.4; % NG
	35259	 150.0	 20.4	 130.8	 -90.0	 1.0	 100.0	 1	 270.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 270.0; % COW
	35259	 138.4	 30.15	 130.6	 -70.3	 1.0	 100.0	 1	 210.8	 66.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 210.8; % NG
	35259	 138.4	 30.15	 130.6	 -70.3	 1.0	 100.0	 1	 210.8	 66.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 210.8; % NG
	35259	 138.4	 30.15	 130.6	 -70.3	 1.0	 100.0	 1	 210.8	 66.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 210.8; % NG
	35260	 150.0	 56.25	 202.5	 -90.0	 1.0	 100.0	 1	 270.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 270.0; % NG
	35260	 137.0	 43.75	 157.5	 -70.0	 1.0	 100.0	 1	 210.0	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 210.0; % NG
	35260	 137.0	 43.75	 157.5	 -70.0	 1.0	 100.0	 1	 210.0	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 210.0; % COW
	35260	 137.0	 43.75	 157.5	 -70.0	 1.0	 100.0	 1	 210.0	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 210.0; % NG
	35261	 197.33	 40.35	 174.7	 -94.0	 1.0	 100.0	 1	 281.9	 112.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 281.9; % NG
	35261	 197.33	 40.35	 174.7	 -94.0	 1.0	 100.0	 1	 281.9	 112.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 281.9; % NG
	35261	 162.84	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.1	 122.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.1; % NG
	35261	 161.575	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.1	 120.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.1; % NG
	35261	 153.035	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.1	 102.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.1; % NG
	35261	 154.645	 30.55	 132.2	 -71.1	 1.0	 100.0	 1	 213.3	 95.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.3; % NG
	35261	 147.25	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.1	 91.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.1; % NG
	35261	 147.25	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.1	 91.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.1; % NG
	35261	 147.25	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.1	 91.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.1; % NG
	35262	 128.0	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	35262	 34.75	 4.5	 28.8	 -19.8	 1.0	 100.0	 1	 59.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.5; % PEL
	35262	 34.75	 4.5	 28.8	 -19.8	 1.0	 100.0	 1	 59.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.5; % NG
	35262	 34.75	 4.5	 28.8	 -19.8	 1.0	 100.0	 1	 59.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.5; % NG
	35262	 438.5	 41.55	 266.4	 -183.3	 1.0	 100.0	 1	 550.0	 327.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 550.0; % NG
	35262	 128.0	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	35262	 128.0	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	35262	 128.0	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	35262	 34.75	 4.5	 28.8	 -19.8	 1.0	 100.0	 1	 59.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.5; % COW
	35262	 34.75	 4.5	 28.8	 -19.8	 1.0	 100.0	 1	 59.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.5; % PEL
	35262	 34.75	 4.5	 28.8	 -19.8	 1.0	 100.0	 1	 59.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.5; % NG
	35262	 34.75	 4.5	 28.8	 -19.8	 1.0	 100.0	 1	 59.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.5; % NG
	35262	 34.75	 4.5	 28.8	 -19.8	 1.0	 100.0	 1	 59.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.5; % NG
	35263	 136.0	 26.8	 115.9	 -62.3	 1.0	 100.0	 1	 187.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.0; % NG
	35263	 136.0	 26.8	 115.9	 -62.3	 1.0	 100.0	 1	 187.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.0; % NG
	35263	 136.0	 26.8	 115.9	 -62.3	 1.0	 100.0	 1	 187.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.0; % NG
	35263	 136.0	 26.8	 115.9	 -62.3	 1.0	 100.0	 1	 187.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.0; % NG
	35264	 146.86	 26.5	 114.7	 -61.7	 1.0	 100.0	 1	 185.0	 108.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	35264	 146.785	 26.5	 114.7	 -61.7	 1.0	 100.0	 1	 185.0	 108.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	35264	 141.525	 26.5	 114.7	 -61.7	 1.0	 100.0	 1	 185.0	 98.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	35264	 141.525	 26.5	 114.7	 -61.7	 1.0	 100.0	 1	 185.0	 98.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	35264	 197.4	 21.3	 136.6	 -94.0	 1.0	 100.0	 1	 282.0	 112.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 282.0; % NG
	35264	 197.4	 21.3	 136.6	 -94.0	 1.0	 100.0	 1	 282.0	 112.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 282.0; % NG
	35265	 136.55	 13.85	 88.7	 -61.0	 1.0	 100.0	 1	 183.1	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.1; % NG
	35265	 136.55	 13.85	 88.7	 -61.0	 1.0	 100.0	 1	 183.1	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.1; % NG
	35265	 136.55	 13.85	 88.7	 -61.0	 1.0	 100.0	 1	 183.1	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.1; % NG
	35265	 212.55	 29.45	 188.9	 -130.0	 1.0	 100.0	 1	 390.1	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 390.1; % COW
	35266	 134.5	 13.5	 86.7	 -59.7	 1.0	 100.0	 1	 179.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.0; % NG
	35266	 134.5	 13.5	 86.7	 -59.7	 1.0	 100.0	 1	 179.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.0; % COW
	35266	 134.5	 13.5	 86.7	 -59.7	 1.0	 100.0	 1	 179.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.0; % NG
	35266	 225.05	 29.45	 188.9	 -130.0	 1.0	 100.0	 1	 390.1	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 390.1; % COW
	35268	 97.715	 10.6	 68.1	 -46.9	 1.0	 100.0	 1	 140.6	 54.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.6; % NG
	35268	 97.715	 10.6	 68.1	 -46.9	 1.0	 100.0	 1	 140.6	 54.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.6; % NG
	35268	 97.715	 10.6	 68.1	 -46.9	 1.0	 100.0	 1	 140.6	 54.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.6; % NG
	35268	 97.715	 10.6	 68.1	 -46.9	 1.0	 100.0	 1	 140.6	 54.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.6; % NG
	35268	 97.715	 29.3	 105.5	 -46.9	 1.0	 100.0	 1	 140.6	 54.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.6; % NG
	35268	 97.715	 29.3	 105.5	 -46.9	 1.0	 100.0	 1	 140.6	 54.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.6; % NG
	35268	 401.0	 41.55	 266.4	 -183.3	 1.0	 100.0	 1	 550.0	 252.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 550.0; % COW
	35268	 413.5	 43.4	 278.5	 -191.7	 1.0	 100.0	 1	 575.0	 252.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 575.0; % COW
	35269	 138.75	 26.85	 116.2	 -62.5	 1.0	 100.0	 1	 187.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.5; % NG
	35269	 140.2	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4; % COW
	35269	 87.5	 17.9	 77.5	 -41.7	 1.0	 100.0	 1	 125.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	35269	 87.5	 17.9	 77.5	 -41.7	 1.0	 100.0	 1	 125.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % COW
	35269	 694.4	 113.0	 488.9	 -262.9	 1.0	 100.0	 1	 788.8	 600.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 788.8; % COW
	35270	 89.0	 16.15	 70.0	 -37.7	 1.0	 100.0	 1	 113.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.0; % COW
	35270	 89.0	 16.15	 70.0	 -37.7	 1.0	 100.0	 1	 113.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.0; % NG
	35270	 140.5	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 111.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	35270	 140.5	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 111.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % PEL
	35271	 81.1	 11.75	 50.9	 -27.4	 1.0	 100.0	 1	 82.2	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.2; % NG
	35271	 94.5	 13.9	 60.1	 -32.3	 1.0	 100.0	 1	 97.0	 92.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.0; % NG
	35272	 86.75	 6.8	 43.8	 -30.2	 1.0	 100.0	 1	 90.5	 83.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.5; % NG
	35272	 86.75	 6.8	 43.8	 -30.2	 1.0	 100.0	 1	 90.5	 83.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.5; % NG
	35274	 14.565	 3.75	 16.2	 -8.7	 1.0	 100.0	 1	 26.13	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.1333; % PEL
	35274	 14.565	 3.75	 16.2	 -8.7	 1.0	 100.0	 1	 26.13	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.1333; % PEL
	35274	 14.565	 3.75	 16.2	 -8.7	 1.0	 100.0	 1	 26.13	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.1333; % NG
	35276	 48.5	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % PEL
	35276	 48.5	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % NG
	35277	 64.5	 5.1	 32.7	 -22.5	 1.0	 100.0	 1	 67.5	 61.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5; % PEL
	35277	 64.5	 5.1	 32.7	 -22.5	 1.0	 100.0	 1	 67.5	 61.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5; % NG
	35278	 53.0	 5.0	 32.0	 -22.0	 1.0	 100.0	 1	 66.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.0; % PEL
	35278	 188.0	 17.8	 114.3	 -78.7	 1.0	 100.0	 1	 236.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 236.0; % COW
	35278	 188.0	 17.8	 114.3	 -78.7	 1.0	 100.0	 1	 236.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 236.0; % COW
	35279	 37.1	 4.45	 27.3	 -18.4	 1.0	 100.0	 1	 55.2	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.2; % NG
	35279	 27.6	 5.5	 23.7	 -12.7	 1.0	 100.0	 1	 38.2	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.2; % NG
	35280	 52.95	 0.0	 23.0	 -23.0	 1.0	 100.0	 1	 53.9	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.9; % NG
	35281	 50.75	 3.85	 24.9	 -17.2	 1.0	 100.0	 1	 51.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.5; % NG
	35281	 50.75	 3.85	 24.9	 -17.2	 1.0	 100.0	 1	 51.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.5; % NG
	35282	 45.5	 0.0	 16.5	 -16.5	 1.0	 100.0	 1	 50.2	 40.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.2; % COW
	35282	 45.5	 0.0	 16.5	 -16.5	 1.0	 100.0	 1	 50.2	 40.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.2; % COW
	35282	 45.5	 0.0	 16.5	 -16.5	 1.0	 100.0	 1	 50.2	 40.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.2; % NG
	35282	 50.4	 0.0	 19.7	 -19.7	 1.0	 100.0	 1	 60.0	 40.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % PEL
	35283	 29.65	 10.3	 37.0	 -16.4	 1.0	 100.0	 1	 49.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.3; % NG
	35283	 29.65	 10.3	 37.0	 -16.4	 1.0	 100.0	 1	 49.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.3; % NG
	35284	 26.5	 3.6	 23.2	 -16.0	 1.0	 100.0	 1	 48.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.0; % NG
	35284	 37.0	 5.2	 33.4	 -23.0	 1.0	 100.0	 1	 69.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % NG
	35286	 42.25	 3.25	 20.7	 -14.2	 1.0	 100.0	 1	 42.7	 41.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.7; % NG
	35286	 42.15	 3.25	 20.7	 -14.2	 1.0	 100.0	 1	 42.7	 41.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.7; % NG
	35286	 42.15	 3.25	 20.7	 -14.2	 1.0	 100.0	 1	 42.7	 41.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.7; % NG
	35287	 9.15	 2.5	 9.53	 -4.53	 1.0	 100.0	 1	 13.63	 4.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6333; % NG
	35287	 9.15	 2.5	 9.53	 -4.53	 1.0	 100.0	 1	 13.63	 4.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6333; % NG
	35287	 9.15	 2.5	 9.53	 -4.53	 1.0	 100.0	 1	 13.63	 4.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6333; % COW
	35288	 37.25	 0.0	 13.3	 -13.3	 1.0	 100.0	 1	 40.5	 34.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.5; % PEL
	35288	 37.25	 0.0	 13.3	 -13.3	 1.0	 100.0	 1	 40.5	 34.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.5; % PEL
	35289	 24.25	 3.05	 19.6	 -13.5	 1.0	 100.0	 1	 40.5	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.5; % NG
	35289	 29.65	 7.1	 30.6	 -16.4	 1.0	 100.0	 1	 49.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.3; % NG
	35290	 6.29	 0.985	 4.12	 -2.15	 1.0	 100.0	 1	 6.43	 6.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.4333; % NG
	35290	 6.29	 0.985	 4.12	 -2.15	 1.0	 100.0	 1	 6.43	 6.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.4333; % NG
	35290	 6.29	 0.985	 4.12	 -2.15	 1.0	 100.0	 1	 6.43	 6.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.4333; % PEL
	35290	 6.29	 0.985	 4.12	 -2.15	 1.0	 100.0	 1	 6.43	 6.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.4333; % NG
	35290	 6.29	 0.985	 4.12	 -2.15	 1.0	 100.0	 1	 6.43	 6.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.4333; % NG
	35290	 6.29	 0.985	 4.12	 -2.15	 1.0	 100.0	 1	 6.43	 6.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.4333; % NG
	35291	 23.7	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.4; % NG
	35291	 25.0	 5.75	 24.8	 -13.3	 1.0	 100.0	 1	 40.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	35292	 26.85	 5.1	 22.1	 -11.9	 1.0	 100.0	 1	 35.7	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.7; % PEL
	35292	 40.5	 8.75	 37.8	 -20.3	 1.0	 100.0	 1	 61.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0; % NG
	35293	 31.35	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.1	 27.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.1; % NG
	35293	 35.8	 3.3	 21.1	 -14.5	 1.0	 100.0	 1	 43.6	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.6; % NG
	35293	 35.75	 3.3	 21.1	 -14.5	 1.0	 100.0	 1	 43.6	 27.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.6; % NG
	35293	 31.6	 2.7	 17.4	 -12.0	 1.0	 100.0	 1	 36.0	 27.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0; % PEL
	35293	 30.25	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.1	 25.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.1; % NG
	35293	 30.05	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.1	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.1; % PEL
	35293	 29.3	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.1	 23.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.1; % PEL
	35293	 29.25	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.1	 23.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.1; % NG
	35293	 29.25	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.1	 23.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.1; % NG
	35293	 29.2	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.1	 23.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.1; % NG
	35293	 29.05	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.1	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.1; % PEL
	35294	 28.85	 0.0	 11.1	 -11.1	 1.0	 100.0	 1	 33.7	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.7; % PEL
	35294	 28.85	 0.0	 11.1	 -11.1	 1.0	 100.0	 1	 33.7	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.7; % PEL
	35294	 28.85	 0.0	 11.1	 -11.1	 1.0	 100.0	 1	 33.7	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.7; % PEL
	35295	 9.925	 1.8	 8.85	 -5.25	 1.0	 100.0	 1	 15.75	 4.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.75; % COW
	35295	 9.925	 1.8	 8.85	 -5.25	 1.0	 100.0	 1	 15.75	 4.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.75; % NG
	35296	 29.25	 2.25	 14.3	 -9.8	 1.0	 100.0	 1	 29.5	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.5; % PEL
	35296	 29.25	 2.25	 14.3	 -9.8	 1.0	 100.0	 1	 29.5	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.5; % PEL
	35296	 29.25	 2.25	 14.3	 -9.8	 1.0	 100.0	 1	 29.5	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.5; % COW
	35296	 29.25	 2.25	 14.3	 -9.8	 1.0	 100.0	 1	 29.5	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.5; % COW
	35296	 29.25	 2.25	 14.3	 -9.8	 1.0	 100.0	 1	 29.5	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.5; % PEL
	35296	 29.25	 2.25	 14.3	 -9.8	 1.0	 100.0	 1	 29.5	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.5; % COW
	35297	 25.75	 2.2	 14.1	 -9.7	 1.0	 100.0	 1	 29.2	 22.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.2; % PEL
	35297	 25.75	 2.2	 14.1	 -9.7	 1.0	 100.0	 1	 29.2	 22.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.2; % PEL
	35297	 25.75	 2.2	 14.1	 -9.7	 1.0	 100.0	 1	 29.2	 22.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.2; % NG
	35298	 21.7	 2.15	 13.9	 -9.6	 1.0	 100.0	 1	 28.8	 14.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % PEL
	35298	 20.85	 2.15	 13.9	 -9.6	 1.0	 100.0	 1	 28.8	 12.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % NG
	35298	 19.25	 2.15	 13.9	 -9.6	 1.0	 100.0	 1	 28.8	 9.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % NG
	35298	 19.25	 2.15	 13.9	 -9.6	 1.0	 100.0	 1	 28.8	 9.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % NG
	35299	 7.75	 2.625	 9.4	 -4.15	 1.0	 100.0	 1	 12.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5; % NG
	35299	 7.75	 2.625	 9.4	 -4.15	 1.0	 100.0	 1	 12.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5; % NG
	35300	 25.0	 3.2	 14.7	 -8.3	 1.0	 100.0	 1	 25.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	35300	 25.0	 3.2	 14.7	 -8.3	 1.0	 100.0	 1	 25.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	35300	 25.0	 3.2	 14.7	 -8.3	 1.0	 100.0	 1	 25.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	35300	 25.0	 3.2	 14.7	 -8.3	 1.0	 100.0	 1	 25.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	35301	 24.25	 0.0	 12.0	 -12.0	 1.0	 100.0	 1	 25.0	 23.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	35301	 24.5	 0.0	 12.3	 -12.3	 1.0	 100.0	 1	 25.5	 23.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5; % COW
	35302	 19.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	35302	 26.0	 4.55	 19.8	 -10.7	 1.0	 100.0	 1	 32.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % PEL
	35302	 37.75	 7.95	 34.4	 -18.5	 1.0	 100.0	 1	 55.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.5; % PEL
	35303	 23.35	 1.85	 11.8	 -8.1	 1.0	 100.0	 1	 24.3	 22.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.3; % PEL
	35303	 23.3	 1.85	 11.8	 -8.1	 1.0	 100.0	 1	 24.3	 22.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.3; % PEL
	35303	 23.3	 1.85	 11.8	 -8.1	 1.0	 100.0	 1	 24.3	 22.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.3; % PEL
	35304	 52.6	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 51.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	35304	 23.6	 2.2	 14.1	 -9.7	 1.0	 100.0	 1	 29.2	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.2; % NG
	35304	 23.6	 2.2	 14.1	 -9.7	 1.0	 100.0	 1	 29.2	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.2; % NG
	35304	 23.6	 2.2	 14.1	 -9.7	 1.0	 100.0	 1	 29.2	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.2; % PEL
	35304	 23.6	 2.2	 14.1	 -9.7	 1.0	 100.0	 1	 29.2	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.2; % NG
	35304	 23.6	 2.2	 14.1	 -9.7	 1.0	 100.0	 1	 29.2	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.2; % NG
	35304	 23.6	 2.2	 14.1	 -9.7	 1.0	 100.0	 1	 29.2	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.2; % PEL
	35304	 23.6	 2.2	 14.1	 -9.7	 1.0	 100.0	 1	 29.2	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.2; % PEL
	35304	 28.0	 2.7	 17.4	 -12.0	 1.0	 100.0	 1	 36.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0; % NG
	35304	 22.0	 4.8	 17.3	 -7.7	 1.0	 100.0	 1	 23.0	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % COW
	35304	 22.0	 4.8	 17.3	 -7.7	 1.0	 100.0	 1	 23.0	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % PEL
	35304	 52.0	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	35304	 22.0	 4.8	 17.3	 -7.7	 1.0	 100.0	 1	 23.0	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % PEL
	35304	 22.0	 4.8	 17.3	 -7.7	 1.0	 100.0	 1	 23.0	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % PEL
	35304	 52.0	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	35304	 23.6	 1.9	 12.2	 -8.4	 1.0	 100.0	 1	 25.2	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.2; % PEL
	35304	 25.6	 2.2	 14.1	 -9.7	 1.0	 100.0	 1	 29.2	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.2; % PEL
	35304	 21.6	 1.9	 12.2	 -8.4	 1.0	 100.0	 1	 25.2	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.2; % PEL
	35304	 25.45	 2.35	 15.0	 -10.3	 1.0	 100.0	 1	 30.9	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.9; % PEL
	35304	 25.45	 2.35	 15.0	 -10.3	 1.0	 100.0	 1	 30.9	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.9; % NG
	35304	 25.45	 2.35	 15.0	 -10.3	 1.0	 100.0	 1	 30.9	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.9; % NG
	35305	 17.75	 0.0	 6.7	 -6.7	 1.0	 100.0	 1	 20.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.5; % PEL
	35305	 17.75	 0.0	 6.7	 -6.7	 1.0	 100.0	 1	 20.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.5; % COW
	35305	 17.75	 0.0	 6.7	 -6.7	 1.0	 100.0	 1	 20.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.5; % NG
	35305	 17.75	 0.0	 6.7	 -6.7	 1.0	 100.0	 1	 20.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.5; % NG
	35306	 49.4	 10.4	 37.5	 -16.7	 1.0	 100.0	 1	 50.0	 48.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	35306	 49.4	 10.4	 37.5	 -16.7	 1.0	 100.0	 1	 50.0	 48.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	35306	 49.4	 10.4	 37.5	 -16.7	 1.0	 100.0	 1	 50.0	 48.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	35306	 19.75	 4.15	 15.0	 -6.7	 1.0	 100.0	 1	 20.0	 19.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	35307	 12.5	 0.0	 8.5	 -8.5	 1.0	 100.0	 1	 20.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	35307	 12.5	 0.0	 8.5	 -8.5	 1.0	 100.0	 1	 20.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	35307	 12.5	 0.0	 8.5	 -8.5	 1.0	 100.0	 1	 20.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	35307	 13.5	 0.0	 9.4	 -9.4	 1.0	 100.0	 1	 22.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	35308	 606.0	 58.3	 373.9	 -257.3	 1.0	 100.0	 1	 772.0	 440.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 772.0; % COW
	35309	 943.1	 86.85	 557.1	 -383.4	 1.0	 100.0	 1	 1150.2	 736.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1150.2; % NG
	35309	 554.0	 53.15	 341.0	 -234.7	 1.0	 100.0	 1	 704.0	 404.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 704.0; % COW
	35309	 552.5	 53.15	 341.0	 -234.7	 1.0	 100.0	 1	 704.0	 401.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 704.0; % COW
	35310	 139.5	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 199.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.0; % NG
	35310	 139.5	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 199.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.0; % NG
	35310	 139.5	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 199.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.0; % NG
	35310	 139.5	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 199.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.0; % NG
	35310	 139.5	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 199.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.0; % NG
	35310	 139.5	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 199.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.0; % NG
	35310	 353.55	 42.75	 274.2	 -188.7	 1.0	 100.0	 1	 566.1	 141.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 566.1; % COW
	35311	 356.95	 42.05	 269.7	 -185.6	 1.0	 100.0	 1	 556.9	 157.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 556.9; % COW
	35311	 355.65	 42.0	 269.4	 -185.4	 1.0	 100.0	 1	 556.3	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 556.3; % NG
	35311	 354.6	 42.0	 269.4	 -185.4	 1.0	 100.0	 1	 556.2	 153.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 556.2; % COW
	35311	 353.25	 42.0	 269.5	 -185.5	 1.0	 100.0	 1	 556.5	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 556.5; % NG
	35312	 404.7	 38.45	 246.7	 -169.8	 1.0	 100.0	 1	 509.4	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 509.4; % NG
	35313	 316.3	 34.9	 224.0	 -154.2	 1.0	 100.0	 1	 462.6	 170.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 462.6; % NG
	35313	 235.25	 26.85	 172.2	 -118.5	 1.0	 100.0	 1	 355.5	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 355.5; % NG
	35313	 235.25	 26.85	 172.2	 -118.5	 1.0	 100.0	 1	 355.5	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 355.5; % NG
	35313	 359.3	 41.05	 263.3	 -181.2	 1.0	 100.0	 1	 543.6	 175.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 543.6; % NG
	35314	 254.7	 47.15	 204.1	 -109.8	 1.0	 100.0	 1	 329.4	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.4; % NG
	35314	 254.7	 47.15	 204.1	 -109.8	 1.0	 100.0	 1	 329.4	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.4; % COW
	35314	 251.3	 0.0	 104.3	 -104.3	 1.0	 100.0	 1	 357.6	 145.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 357.6; % NG
	35314	 436.05	 0.0	 172.7	 -172.7	 1.0	 100.0	 1	 592.1	 280.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 592.1; % COW
	35315	 227.0	 22.1	 141.9	 -97.7	 1.0	 100.0	 1	 293.0	 161.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 293.0; % NG
	35315	 199.0	 22.1	 141.9	 -97.7	 1.0	 100.0	 1	 293.0	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 293.0; % COW
	35316	 558.15	 61.65	 395.4	 -272.1	 1.0	 100.0	 1	 816.3	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 816.3; % COW
	35316	 190.25	 40.15	 173.8	 -93.5	 1.0	 100.0	 1	 280.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 280.5; % NG
	35317	 175.0	 32.9	 142.5	 -76.7	 1.0	 100.0	 1	 230.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.0; % COW
	35317	 175.0	 32.9	 142.5	 -76.7	 1.0	 100.0	 1	 230.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.0; % NG
	35317	 175.0	 32.9	 142.5	 -76.7	 1.0	 100.0	 1	 230.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.0; % NG
	35317	 175.0	 32.9	 142.5	 -76.7	 1.0	 100.0	 1	 230.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.0; % NG
	35317	 175.0	 32.9	 142.5	 -76.7	 1.0	 100.0	 1	 230.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.0; % NG
	35318	 162.5	 29.8	 128.9	 -69.3	 1.0	 100.0	 1	 208.0	 117.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 208.0; % NG
	35318	 162.5	 29.8	 128.9	 -69.3	 1.0	 100.0	 1	 208.0	 117.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 208.0; % NG
	35318	 162.5	 29.8	 128.9	 -69.3	 1.0	 100.0	 1	 208.0	 117.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 208.0; % NG
	35319	 162.5	 15.5	 99.3	 -68.3	 1.0	 100.0	 1	 205.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 205.0; % NG
	35319	 147.5	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	35320	 130.0	 14.5	 93.0	 -64.0	 1.0	 100.0	 1	 192.0	 68.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.0; % NG
	35320	 135.0	 29.35	 127.0	 -68.3	 1.0	 100.0	 1	 205.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 205.0; % NG
	35320	 127.5	 29.35	 127.0	 -68.3	 1.0	 100.0	 1	 205.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 205.0; % NG
	35321	 113.0	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 51.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % COW
	35321	 121.625	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 68.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	35321	 113.0	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 51.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	35321	 113.0	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 51.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	35321	 113.0	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 51.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	35321	 113.0	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 51.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	35321	 113.0	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 51.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	35321	 113.0	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 51.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	35321	 113.0	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 51.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	35321	 113.0	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 51.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	35322	 114.1	 23.35	 101.1	 -54.4	 1.0	 100.0	 1	 163.2	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2; % NG
	35322	 137.2	 30.0	 129.8	 -69.8	 1.0	 100.0	 1	 209.4	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 209.4; % NG
	35322	 176.0	 38.95	 168.6	 -90.7	 1.0	 100.0	 1	 272.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 272.0; % NG
	35323	 126.6	 23.35	 101.1	 -54.4	 1.0	 100.0	 1	 163.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2; % COW
	35323	 216.05	 21.3	 136.6	 -94.0	 1.0	 100.0	 1	 282.1	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 282.1; % NG
	35324	 121.75	 25.7	 111.2	 -59.8	 1.0	 100.0	 1	 179.5	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.5; % COW
	35324	 309.5	 35.0	 224.7	 -154.7	 1.0	 100.0	 1	 464.0	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 464.0; % COW
	35324	 74.8	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % COW
	35324	 86.5	 17.6	 76.2	 -41.0	 1.0	 100.0	 1	 123.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 123.0; % NG
	35324	 88.0	 18.05	 78.1	 -42.0	 1.0	 100.0	 1	 126.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 126.0; % COW
	35324	 88.0	 18.05	 78.1	 -42.0	 1.0	 100.0	 1	 126.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 126.0; % NG
	35324	 88.0	 18.05	 78.1	 -42.0	 1.0	 100.0	 1	 126.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 126.0; % COW
	35324	 88.0	 18.05	 78.1	 -42.0	 1.0	 100.0	 1	 126.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 126.0; % NG
	35324	 140.9	 25.35	 109.6	 -58.9	 1.0	 100.0	 1	 176.8	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.8; % COW
	35324	 133.4	 25.35	 109.6	 -58.9	 1.0	 100.0	 1	 176.8	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.8; % NG
	35325	 0.0	 0.0	 45.6	 -45.6	 1.0	 100.0	 0	 113.6	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % NG
	35325	 0.0	 0.0	 85.1	 -85.1	 1.0	 100.0	 0	 230.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.4; % NG
	35327	 76.5	 7.4	 47.5	 -32.7	 1.0	 100.0	 1	 98.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.0; % NG
	35327	 76.5	 7.4	 47.5	 -32.7	 1.0	 100.0	 1	 98.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.0; % NG
	35327	 81.5	 8.15	 52.3	 -36.0	 1.0	 100.0	 1	 108.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.0; % NG
	35327	 81.5	 8.15	 52.3	 -36.0	 1.0	 100.0	 1	 108.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.0; % NG
	35327	 64.0	 14.0	 60.7	 -32.7	 1.0	 100.0	 1	 98.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.0; % NG
	35327	 49.0	 14.0	 60.7	 -32.7	 1.0	 100.0	 1	 98.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.0; % COW
	35327	 76.0	 11.25	 72.2	 -49.7	 1.0	 100.0	 1	 149.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 149.0; % NG
	35327	 76.0	 11.25	 72.2	 -49.7	 1.0	 100.0	 1	 149.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 149.0; % COW
	35327	 76.0	 11.25	 72.2	 -49.7	 1.0	 100.0	 1	 149.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 149.0; % NG
	35328	 51.5	 6.65	 42.6	 -29.3	 1.0	 100.0	 1	 88.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.0; % COW
	35329	 65.5	 6.5	 41.7	 -28.7	 1.0	 100.0	 1	 86.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0; % NG
	35329	 65.5	 6.5	 41.7	 -28.7	 1.0	 100.0	 1	 86.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0; % NG
	35329	 65.5	 6.5	 41.7	 -28.7	 1.0	 100.0	 1	 86.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0; % NG
	35329	 65.5	 6.5	 41.7	 -28.7	 1.0	 100.0	 1	 86.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0; % COW
	35329	 65.5	 6.5	 41.7	 -28.7	 1.0	 100.0	 1	 86.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0; % NG
	35329	 65.5	 6.5	 41.7	 -28.7	 1.0	 100.0	 1	 86.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0; % NG
	35329	 65.5	 6.5	 41.7	 -28.7	 1.0	 100.0	 1	 86.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0; % COW
	35329	 65.5	 6.5	 41.7	 -28.7	 1.0	 100.0	 1	 86.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0; % NG
	35330	 6.325	 0.815	 5.18	 -3.55	 1.0	 100.0	 1	 10.65	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.65; % NG
	35330	 6.325	 0.815	 5.18	 -3.55	 1.0	 100.0	 1	 10.65	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.65; % NG
	35330	 6.325	 0.815	 5.18	 -3.55	 1.0	 100.0	 1	 10.65	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.65; % NG
	35330	 6.325	 0.815	 5.18	 -3.55	 1.0	 100.0	 1	 10.65	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.65; % NG
	35330	 6.325	 0.815	 5.18	 -3.55	 1.0	 100.0	 1	 10.65	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.65; % NG
	35330	 6.325	 0.815	 5.18	 -3.55	 1.0	 100.0	 1	 10.65	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.65; % NG
	35330	 6.325	 0.815	 5.18	 -3.55	 1.0	 100.0	 1	 10.65	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.65; % NG
	35330	 6.325	 0.815	 5.18	 -3.55	 1.0	 100.0	 1	 10.65	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.65; % NG
	35332	 50.625	 10.25	 45.5	 -25.0	 1.0	 100.0	 1	 75.0	 26.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	35333	 65.5	 5.3	 33.9	 -23.3	 1.0	 100.0	 1	 70.0	 61.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0; % PEL
	35334	 37.5	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % PEL
	35334	 37.5	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % PEL
	35335	 45.0	 3.4	 21.8	 -15.0	 1.0	 100.0	 1	 45.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % COW
	35335	 45.0	 3.4	 21.8	 -15.0	 1.0	 100.0	 1	 45.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	35335	 45.0	 3.4	 21.8	 -15.0	 1.0	 100.0	 1	 45.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	35335	 45.0	 3.4	 21.8	 -15.0	 1.0	 100.0	 1	 45.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	35335	 45.0	 3.4	 21.8	 -15.0	 1.0	 100.0	 1	 45.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	35335	 45.0	 3.4	 21.8	 -15.0	 1.0	 100.0	 1	 45.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	35337	 27.8	 4.65	 20.2	 -10.9	 1.0	 100.0	 1	 32.6	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.6; % COW
	35337	 129.5	 25.5	 110.3	 -59.3	 1.0	 100.0	 1	 178.0	 81.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.0; % NG
	35339	 5.7	 1.97	 7.07	 -3.13	 1.0	 100.0	 1	 9.4	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.4; % NG
	35339	 5.7	 1.97	 7.07	 -3.13	 1.0	 100.0	 1	 9.4	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.4; % NG
	35339	 5.7	 1.97	 7.07	 -3.13	 1.0	 100.0	 1	 9.4	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.4; % NG
	35340	 52.5	 11.6	 50.2	 -27.0	 1.0	 100.0	 1	 81.0	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.0; % NG
	35340	 52.5	 11.6	 50.2	 -27.0	 1.0	 100.0	 1	 81.0	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.0; % NG
	35340	 17.0	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % NG
	35340	 17.0	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % NG
	35341	 14.85	 2.0	 12.9	 -8.9	 1.0	 100.0	 1	 26.7	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7; % PEL
	35342	 11.35	 2.95	 12.8	 -6.9	 1.0	 100.0	 1	 20.7	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7; % PEL
	35342	 11.35	 2.95	 12.8	 -6.9	 1.0	 100.0	 1	 20.7	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7; % NG
	35342	 11.35	 2.95	 12.8	 -6.9	 1.0	 100.0	 1	 20.7	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7; % NG
	35343	 0.0	 0.0	 697.4	 -480.0	 1.0	 100.0	 0	 1440.0	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	35344	 493.2	 58.95	 378.4	 -260.5	 1.0	 100.0	 1	 781.4	 205.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 781.4; % COW
	35345	 147.75	 26.6	 115.0	 -61.8	 1.0	 100.0	 1	 185.5	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.5; % NG
	35345	 147.75	 26.6	 115.0	 -61.8	 1.0	 100.0	 1	 185.5	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.5; % NG
	35345	 147.75	 26.6	 115.0	 -61.8	 1.0	 100.0	 1	 185.5	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.5; % NG
	35345	 147.75	 26.6	 115.0	 -61.8	 1.0	 100.0	 1	 185.5	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.5; % NG
	35345	 170.1	 27.95	 121.0	 -65.1	 1.0	 100.0	 1	 195.2	 145.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.2; % NG
	35345	 170.1	 27.95	 121.0	 -65.1	 1.0	 100.0	 1	 195.2	 145.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.2; % NG
	35345	 356.65	 78.5	 339.8	 -182.8	 1.0	 100.0	 1	 548.3	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 548.3; % NG
	35345	 356.65	 78.5	 339.8	 -182.8	 1.0	 100.0	 1	 548.3	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 548.3; % NG
	35346	 367.3	 78.0	 337.5	 -181.5	 1.0	 100.0	 1	 544.6	 190.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 544.6; % COW
	35346	 486.5	 59.1	 379.2	 -261.0	 1.0	 100.0	 1	 783.0	 190.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 783.0; % COW
	35347	 431.85	 38.8	 248.8	 -171.2	 1.0	 100.0	 1	 513.7	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 513.7; % NG
	35348	 135.45	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 270.0	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 270.0; % NG
	35348	 135.45	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 270.0	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 270.0; % NG
	35348	 155.7	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 310.5	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 310.5; % NG
	35349	 127.5	 28.6	 123.9	 -66.7	 1.0	 100.0	 1	 200.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	35349	 127.5	 28.6	 123.9	 -66.7	 1.0	 100.0	 1	 200.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	35350	 149.75	 13.95	 89.4	 -61.5	 1.0	 100.0	 1	 184.5	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.5; % NG
	35350	 149.75	 13.95	 89.4	 -61.5	 1.0	 100.0	 1	 184.5	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.5; % NG
	35350	 149.75	 13.95	 89.4	 -61.5	 1.0	 100.0	 1	 184.5	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.5; % NG
	35350	 76.25	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % COW
	35350	 76.25	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % NG
	35350	 76.25	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % COW
	35351	 154.2	 13.5	 86.8	 -59.8	 1.0	 100.0	 1	 179.3	 129.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.3; % COW
	35351	 154.2	 13.5	 86.8	 -59.8	 1.0	 100.0	 1	 179.3	 129.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.3; % NG
	35351	 154.2	 13.5	 86.8	 -59.8	 1.0	 100.0	 1	 179.3	 129.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.3; % COW
	35351	 98.95	 9.2	 59.1	 -40.7	 1.0	 100.0	 1	 122.0	 75.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % COW
	35351	 98.95	 9.2	 59.1	 -40.7	 1.0	 100.0	 1	 122.0	 75.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % COW
	35351	 98.95	 9.2	 59.1	 -40.7	 1.0	 100.0	 1	 122.0	 75.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % COW
	35352	 144.5	 25.6	 110.9	 -59.7	 1.0	 100.0	 1	 179.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.0; % NG
	35352	 144.5	 25.6	 110.9	 -59.7	 1.0	 100.0	 1	 179.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.0; % NG
	35352	 144.5	 25.6	 110.9	 -59.7	 1.0	 100.0	 1	 179.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.0; % NG
	35352	 251.0	 51.8	 224.3	 -120.7	 1.0	 100.0	 1	 362.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 362.0; % NG
	35353	 130.45	 13.5	 86.5	 -59.5	 1.0	 100.0	 1	 178.5	 82.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	35353	 130.45	 13.5	 86.5	 -59.5	 1.0	 100.0	 1	 178.5	 82.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	35353	 130.45	 13.5	 86.5	 -59.5	 1.0	 100.0	 1	 178.5	 82.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	35353	 111.8	 11.8	 75.6	 -52.0	 1.0	 100.0	 1	 156.0	 67.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.0; % COW
	35353	 111.8	 11.8	 75.6	 -52.0	 1.0	 100.0	 1	 156.0	 67.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.0; % NG
	35353	 111.8	 11.8	 75.6	 -52.0	 1.0	 100.0	 1	 156.0	 67.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.0; % COW
	35354	 133.3	 25.25	 109.4	 -58.9	 1.0	 100.0	 1	 176.6	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.6; % NG
	35354	 133.3	 25.25	 109.4	 -58.9	 1.0	 100.0	 1	 176.6	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.6; % COW
	35354	 159.05	 28.4	 122.8	 -66.0	 1.0	 100.0	 1	 198.1	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.1; % COW
	35355	 135.8	 25.25	 109.4	 -58.9	 1.0	 100.0	 1	 176.6	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.6; % NG
	35355	 135.8	 25.25	 109.4	 -58.9	 1.0	 100.0	 1	 176.6	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.6; % COW
	35355	 129.05	 28.4	 122.8	 -66.0	 1.0	 100.0	 1	 198.1	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.1; % COW
	35356	 85.65	 14.5	 62.8	 -33.8	 1.0	 100.0	 1	 101.3	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.3; % NG
	35356	 27.25	 4.89	 21.14	 -11.36	 1.0	 100.0	 1	 34.1	 20.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.1; % PEL
	35356	 27.25	 4.89	 21.14	 -11.36	 1.0	 100.0	 1	 34.1	 20.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.1; % PEL
	35356	 27.25	 4.89	 21.14	 -11.36	 1.0	 100.0	 1	 34.1	 20.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.1; % NG
	35356	 27.25	 4.89	 21.14	 -11.36	 1.0	 100.0	 1	 34.1	 20.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.1; % NG
	35356	 27.25	 4.89	 21.14	 -11.36	 1.0	 100.0	 1	 34.1	 20.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.1; % PEL
	35357	 146.15	 12.15	 78.0	 -53.7	 1.0	 100.0	 1	 161.0	 131.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 161.0; % NG
	35357	 146.15	 12.15	 78.0	 -53.7	 1.0	 100.0	 1	 161.0	 131.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 161.0; % NG
	35357	 146.15	 12.15	 78.0	 -53.7	 1.0	 100.0	 1	 161.0	 131.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 161.0; % NG
	35357	 89.85	 8.0	 51.3	 -35.3	 1.0	 100.0	 1	 106.0	 73.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.0; % COW
	35357	 89.85	 8.0	 51.3	 -35.3	 1.0	 100.0	 1	 106.0	 73.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.0; % NG
	35357	 89.85	 8.0	 51.3	 -35.3	 1.0	 100.0	 1	 106.0	 73.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.0; % NG
	35359	 76.5	 7.0	 45.0	 -31.0	 1.0	 100.0	 1	 93.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.0; % NG
	35359	 76.5	 7.0	 45.0	 -31.0	 1.0	 100.0	 1	 93.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.0; % NG
	35359	 76.5	 7.0	 45.0	 -31.0	 1.0	 100.0	 1	 93.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.0; % NG
	35359	 76.5	 7.0	 45.0	 -31.0	 1.0	 100.0	 1	 93.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.0; % NG
	35360	 68.25	 11.95	 51.7	 -27.8	 1.0	 100.0	 1	 83.5	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.5; % PEL
	35360	 68.25	 11.95	 51.7	 -27.8	 1.0	 100.0	 1	 83.5	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.5; % NG
	35360	 68.25	 11.95	 51.7	 -27.8	 1.0	 100.0	 1	 83.5	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.5; % NG
	35361	 63.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 76.6	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 76.6; % NG
	35361	 63.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 76.6	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 76.6; % COW
	35361	 63.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 76.6	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 76.6; % NG
	35361	 63.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 76.6	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 76.6; % NG
	35362	 50.6	 5.4	 34.5	 -23.7	 1.0	 100.0	 1	 71.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2; % PEL
	35362	 50.6	 5.4	 34.5	 -23.7	 1.0	 100.0	 1	 71.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2; % NG
	35362	 50.6	 5.4	 34.5	 -23.7	 1.0	 100.0	 1	 71.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2; % COW
	35362	 50.6	 5.4	 34.5	 -23.7	 1.0	 100.0	 1	 71.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2; % NG
	35362	 50.6	 5.4	 34.5	 -23.7	 1.0	 100.0	 1	 71.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2; % PEL
	35362	 50.6	 5.4	 34.5	 -23.7	 1.0	 100.0	 1	 71.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2; % COW
	35363	 42.405	 7.95	 37.9	 -22.0	 1.0	 100.0	 1	 66.0	 18.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.0; % PEL
	35364	 47.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % PEL
	35364	 47.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % PEL
	35364	 47.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % NG
	35364	 68.0	 11.85	 51.4	 -27.7	 1.0	 100.0	 1	 83.0	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.0; % NG
	35364	 68.25	 11.95	 51.7	 -27.8	 1.0	 100.0	 1	 83.5	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.5; % NG
	35365	 27.0	 0.0	 15.8	 -15.8	 1.0	 100.0	 1	 48.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.0; % NG
	35366	 35.5	 6.7	 29.1	 -15.7	 1.0	 100.0	 1	 47.0	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % NG
	35366	 35.5	 6.7	 29.1	 -15.7	 1.0	 100.0	 1	 47.0	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % PEL
	35366	 35.5	 6.7	 29.1	 -15.7	 1.0	 100.0	 1	 47.0	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % NG
	35367	 33.0	 4.85	 31.0	 -21.3	 1.0	 100.0	 1	 64.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.0; % NG
	35367	 25.5	 9.6	 34.5	 -15.3	 1.0	 100.0	 1	 46.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % NG
	35368	 31.45	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % NG
	35368	 31.5	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % NG
	35368	 33.0	 7.05	 30.4	 -16.3	 1.0	 100.0	 1	 49.0	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0; % NG
	35369	 69.4	 15.55	 67.4	 -36.3	 1.0	 100.0	 1	 108.8	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.8; % NG
	35369	 31.45	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % NG
	35369	 367.15	 82.75	 358.2	 -192.7	 1.0	 100.0	 1	 578.0	 156.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 578.0; % COW
	35369	 56.9	 13.4	 58.1	 -31.3	 1.0	 100.0	 1	 93.8	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.8; % NG
	35369	 56.9	 13.4	 58.1	 -31.3	 1.0	 100.0	 1	 93.8	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.8; % NG
	35369	 183.35	 42.85	 185.4	 -99.7	 1.0	 100.0	 1	 299.2	 67.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 299.2; % NG
	35370	 10.775	 2.6	 10.9	 -5.7	 1.0	 100.0	 1	 17.05	 4.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.05; % NG
	35370	 10.775	 2.6	 10.9	 -5.7	 1.0	 100.0	 1	 17.05	 4.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.05; % NG
	35371	 18.6	 2.9	 16.5	 -10.7	 1.0	 100.0	 1	 32.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.2; % COW
	35371	 18.8	 4.65	 20.2	 -10.9	 1.0	 100.0	 1	 32.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.6; % NG
	35372	 16.64	 3.15	 14.9	 -8.6	 1.0	 100.0	 1	 25.9	 7.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.9; % PEL
	35372	 16.64	 3.15	 14.9	 -8.6	 1.0	 100.0	 1	 25.9	 7.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.9; % NG
	35372	 16.64	 3.15	 14.9	 -8.6	 1.0	 100.0	 1	 25.9	 7.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.9; % PEL
	35373	 14.6	 5.25	 18.9	 -8.4	 1.0	 100.0	 1	 25.2	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.2; % PEL
	35373	 14.6	 5.25	 18.9	 -8.4	 1.0	 100.0	 1	 25.2	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.2; % NG
	35374	 16.1	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.2; % PEL
	35374	 18.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 25.5	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5; % NG
	35375	 13.0	 0.0	 6.6	 -6.6	 1.0	 100.0	 1	 20.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	35376	 18.0	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	35377	 975.0	 98.15	 629.6	 -433.3	 1.0	 100.0	 1	 1300.0	 650.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1300.0; % COW
	35377	 0.0	 0.0	 629.6	 -433.3	 1.0	 100.0	 0	 1300.0	 650.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1300.0; % COW
	35378	 1196.45	 95.85	 615.0	 -423.3	 1.0	 100.0	 1	 1269.9	 1123.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	35379	 1186.25	 92.15	 591.1	 -406.8	 1.0	 100.0	 1	 1220.5	 1152.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	35379	 1173.1	 92.15	 591.1	 -406.8	 1.0	 100.0	 1	 1220.5	 1125.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	35380	 761.0	 0.0	 344.8	 -344.8	 1.0	 100.0	 1	 950.0	 572.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 950.0; % COW
	35381	 364.2	 32.35	 207.5	 -142.8	 1.0	 100.0	 1	 428.4	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 428.4; % COW
	35381	 364.2	 32.35	 207.5	 -142.8	 1.0	 100.0	 1	 428.4	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 428.4; % NG
	35381	 364.2	 32.35	 207.5	 -142.8	 1.0	 100.0	 1	 428.4	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 428.4; % COW
	35381	 234.2	 32.35	 207.5	 -142.8	 1.0	 100.0	 1	 428.4	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 428.4; % NG
	35382	 14.45	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 23.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % NG
	35382	 14.45	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 23.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % PEL
	35382	 14.45	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 23.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % NG
	35382	 14.45	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 23.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % PEL
	35382	 14.45	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 23.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % PEL
	35382	 14.45	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 23.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % NG
	35382	 14.45	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 23.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % PEL
	35382	 14.45	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 23.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % PEL
	35382	 34.8	 4.5	 28.9	 -19.9	 1.0	 100.0	 1	 59.6	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.6; % PEL
	35382	 34.8	 4.5	 28.9	 -19.9	 1.0	 100.0	 1	 59.6	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.6; % NG
	35382	 34.8	 4.5	 28.9	 -19.9	 1.0	 100.0	 1	 59.6	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.6; % NG
	35382	 14.45	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 23.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % NG
	35382	 34.8	 4.5	 28.9	 -19.9	 1.0	 100.0	 1	 59.6	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.6; % PEL
	35382	 249.0	 24.9	 159.8	 -110.0	 1.0	 100.0	 1	 330.0	 168.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 330.0; % NG
	35382	 249.0	 42.9	 195.8	 -110.0	 1.0	 100.0	 1	 330.0	 168.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 330.0; % NG
	35382	 249.0	 42.9	 195.8	 -110.0	 1.0	 100.0	 1	 330.0	 168.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 330.0; % COW
	35382	 14.45	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 23.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % PEL
	35382	 14.45	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 23.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % PEL
	35382	 14.45	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 23.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % PEL
	35382	 14.45	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 23.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % PEL
	35382	 14.45	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 23.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % PEL
	35382	 14.45	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 23.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % NG
	35382	 14.45	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 23.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9; % NG
	35383	 139.0	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	35383	 139.0	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % COW
	35383	 139.0	 37.5	 141.7	 -66.7	 1.0	 100.0	 1	 200.0	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	35383	 139.0	 37.5	 141.7	 -66.7	 1.0	 100.0	 1	 200.0	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	35385	 127.7	 14.0	 89.8	 -61.8	 1.0	 100.0	 1	 185.4	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.4; % NG
	35385	 130.6	 14.45	 92.6	 -63.7	 1.0	 100.0	 1	 191.2	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 191.2; % NG
	35385	 130.6	 14.45	 92.6	 -63.7	 1.0	 100.0	 1	 191.2	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 191.2; % NG
	35386	 136.5	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 73.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	35386	 136.5	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 73.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	35386	 136.5	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 73.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	35386	 136.5	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 73.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	35386	 136.5	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 73.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	35386	 115.0	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	35386	 115.0	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	35386	 115.0	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	35386	 115.0	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	35387	 125.8	 13.1	 84.0	 -57.8	 1.0	 100.0	 1	 173.4	 78.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.4; % NG
	35387	 72.25	 6.35	 40.9	 -28.2	 1.0	 100.0	 1	 84.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	35387	 73.1	 6.5	 41.7	 -28.7	 1.0	 100.0	 1	 86.2	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.2; % NG
	35387	 73.1	 6.5	 41.7	 -28.7	 1.0	 100.0	 1	 86.2	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.2; % COW
	35387	 73.1	 6.5	 41.7	 -28.7	 1.0	 100.0	 1	 86.2	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.2; % NG
	35387	 73.1	 6.5	 41.7	 -28.7	 1.0	 100.0	 1	 86.2	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.2; % NG
	35387	 177.2	 19.45	 124.8	 -85.9	 1.0	 100.0	 1	 257.6	 96.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 257.6; % NG
	35387	 125.8	 13.1	 84.0	 -57.8	 1.0	 100.0	 1	 173.4	 78.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.4; % NG
	35387	 72.25	 6.35	 40.9	 -28.2	 1.0	 100.0	 1	 84.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	35387	 72.25	 6.35	 40.9	 -28.2	 1.0	 100.0	 1	 84.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	35387	 72.25	 6.35	 40.9	 -28.2	 1.0	 100.0	 1	 84.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	35387	 72.25	 6.35	 40.9	 -28.2	 1.0	 100.0	 1	 84.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	35387	 72.25	 6.35	 40.9	 -28.2	 1.0	 100.0	 1	 84.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	35387	 72.25	 6.35	 40.9	 -28.2	 1.0	 100.0	 1	 84.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	35387	 72.25	 6.35	 40.9	 -28.2	 1.0	 100.0	 1	 84.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	35388	 92.5	 9.4	 60.5	 -41.7	 1.0	 100.0	 1	 125.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % COW
	35388	 120.095	 13.05	 83.7	 -57.6	 1.0	 100.0	 1	 172.8	 67.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.8; % NG
	35388	 70.25	 6.35	 40.9	 -28.2	 1.0	 100.0	 1	 84.5	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	35388	 70.25	 6.35	 40.9	 -28.2	 1.0	 100.0	 1	 84.5	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	35388	 70.25	 6.35	 40.9	 -28.2	 1.0	 100.0	 1	 84.5	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	35388	 70.25	 6.35	 40.9	 -28.2	 1.0	 100.0	 1	 84.5	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	35388	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % PEL
	35388	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % PEL
	35388	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % NG
	35388	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % PEL
	35388	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % PEL
	35388	 92.5	 9.4	 60.5	 -41.7	 1.0	 100.0	 1	 125.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	35388	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % NG
	35388	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % PEL
	35388	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % NG
	35388	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % NG
	35388	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % NG
	35388	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % NG
	35388	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % PEL
	35388	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % NG
	35388	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % PEL
	35388	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % PEL
	35388	 92.5	 9.4	 60.5	 -41.7	 1.0	 100.0	 1	 125.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % COW
	35388	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % NG
	35388	 92.5	 9.4	 60.5	 -41.7	 1.0	 100.0	 1	 125.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	35388	 102.5	 11.1	 71.2	 -49.0	 1.0	 100.0	 1	 147.0	 58.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 147.0; % NG
	35388	 102.5	 11.1	 71.2	 -49.0	 1.0	 100.0	 1	 147.0	 58.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 147.0; % NG
	35388	 116.4	 13.05	 83.7	 -57.6	 1.0	 100.0	 1	 172.8	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.8; % NG
	35388	 116.4	 13.05	 83.7	 -57.6	 1.0	 100.0	 1	 172.8	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.8; % NG
	35388	 120.095	 13.05	 83.7	 -57.6	 1.0	 100.0	 1	 172.8	 67.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.8; % NG
	35389	 101.0	 8.95	 57.2	 -39.3	 1.0	 100.0	 1	 118.0	 84.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 118.0; % NG
	35389	 101.0	 8.95	 57.2	 -39.3	 1.0	 100.0	 1	 118.0	 84.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 118.0; % PEL
	35389	 93.5	 8.45	 54.2	 -37.3	 1.0	 100.0	 1	 112.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.0; % NG
	35389	 93.5	 8.45	 54.2	 -37.3	 1.0	 100.0	 1	 112.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.0; % NG
	35390	 70.75	 6.35	 40.9	 -28.2	 1.0	 100.0	 1	 84.5	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	35390	 70.75	 6.35	 40.9	 -28.2	 1.0	 100.0	 1	 84.5	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	35390	 70.75	 6.35	 40.9	 -28.2	 1.0	 100.0	 1	 84.5	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	35390	 70.75	 6.35	 40.9	 -28.2	 1.0	 100.0	 1	 84.5	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	35390	 45.65	 6.15	 39.4	 -27.1	 1.0	 100.0	 1	 81.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.3; % NG
	35390	 45.65	 6.15	 39.4	 -27.1	 1.0	 100.0	 1	 81.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.3; % NG
	35390	 45.65	 6.15	 39.4	 -27.1	 1.0	 100.0	 1	 81.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.3; % COW
	35390	 45.65	 6.15	 39.4	 -27.1	 1.0	 100.0	 1	 81.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.3; % NG
	35391	 11.535	 0.0	 6.93	 -6.93	 1.0	 100.0	 1	 21.07	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0667; % NG
	35391	 11.535	 0.0	 6.93	 -6.93	 1.0	 100.0	 1	 21.07	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0667; % PEL
	35391	 11.535	 0.0	 6.93	 -6.93	 1.0	 100.0	 1	 21.07	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0667; % PEL
	35391	 13.5	 0.0	 8.2	 -8.2	 1.0	 100.0	 1	 25.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	35393	 18.0	 1.365	 8.73	 -6.0	 1.0	 100.0	 1	 18.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	35393	 18.0	 1.365	 8.73	 -6.0	 1.0	 100.0	 1	 18.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	35393	 18.0	 1.365	 8.73	 -6.0	 1.0	 100.0	 1	 18.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	35395	 34.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	35396	 12.3	 3.47	 12.47	 -5.53	 1.0	 100.0	 1	 16.6	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.6; % PEL
	35396	 12.3	 3.47	 12.47	 -5.53	 1.0	 100.0	 1	 16.6	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.6; % NG
	35396	 12.3	 3.47	 12.47	 -5.53	 1.0	 100.0	 1	 16.6	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.6; % PEL
	35398	 45.0	 3.4	 21.8	 -15.0	 1.0	 100.0	 1	 45.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	35398	 45.0	 3.4	 21.8	 -15.0	 1.0	 100.0	 1	 45.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % PEL
	35398	 45.0	 3.4	 21.8	 -15.0	 1.0	 100.0	 1	 45.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	35399	 27.25	 3.15	 20.1	 -13.8	 1.0	 100.0	 1	 41.4	 13.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4; % PEL
	35399	 32.65	 3.95	 25.3	 -17.4	 1.0	 100.0	 1	 52.2	 13.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.2; % NG
	35400	 36.35	 0.0	 18.2	 -18.2	 1.0	 100.0	 1	 40.0	 32.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % COW
	35400	 36.35	 0.0	 18.2	 -18.2	 1.0	 100.0	 1	 40.0	 32.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	35400	 36.35	 0.0	 18.2	 -18.2	 1.0	 100.0	 1	 40.0	 32.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	35400	 36.35	 0.0	 18.2	 -18.2	 1.0	 100.0	 1	 40.0	 32.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % PEL
	35400	 35.4	 0.0	 18.2	 -18.2	 1.0	 100.0	 1	 40.0	 30.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	35400	 35.4	 0.0	 18.2	 -18.2	 1.0	 100.0	 1	 40.0	 30.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % PEL
	35401	 25.6	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 39.9	 11.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.9; % NG
	35401	 25.6	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 39.9	 11.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.9; % NG
	35401	 25.6	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 39.9	 11.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.9; % NG
	35401	 25.6	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 39.9	 11.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.9; % NG
	35402	 26.55	 2.9	 18.6	 -12.8	 1.0	 100.0	 1	 38.5	 14.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.5; % NG
	35403	 12.0	 0.9	 5.8	 -4.0	 1.0	 100.0	 1	 12.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % NG
	35403	 12.0	 0.9	 5.8	 -4.0	 1.0	 100.0	 1	 12.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % NG
	35403	 12.0	 0.9	 5.8	 -4.0	 1.0	 100.0	 1	 12.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % COW
	35404	 22.65	 2.7	 17.4	 -12.0	 1.0	 100.0	 1	 36.0	 9.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0; % NG
	35404	 22.65	 2.7	 17.4	 -12.0	 1.0	 100.0	 1	 36.0	 9.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0; % PEL
	35405	 32.35	 0.0	 13.3	 -13.3	 1.0	 100.0	 1	 40.6	 24.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.6; % COW
	35405	 33.55	 0.0	 14.1	 -14.1	 1.0	 100.0	 1	 43.0	 24.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.0; % NG
	35405	 22.4	 2.6	 16.6	 -11.4	 1.0	 100.0	 1	 34.2	 10.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2; % PEL
	35405	 23.05	 2.7	 17.2	 -11.8	 1.0	 100.0	 1	 35.5	 10.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.5; % NG
	35406	 12.925	 1.925	 9.45	 -5.6	 1.0	 100.0	 1	 16.85	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.85; % PEL
	35406	 12.925	 1.925	 9.45	 -5.6	 1.0	 100.0	 1	 16.85	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.85; % NG
	35408	 33.3	 2.5	 16.1	 -11.1	 1.0	 100.0	 1	 33.3	 33.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.3; % NG
	35408	 33.3	 2.5	 16.1	 -11.1	 1.0	 100.0	 1	 33.3	 33.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.3; % PEL
	35408	 33.3	 2.5	 16.1	 -11.1	 1.0	 100.0	 1	 33.3	 33.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.3; % NG
	35409	 23.45	 2.45	 15.7	 -10.8	 1.0	 100.0	 1	 32.4	 14.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.4; % NG
	35409	 23.95	 2.55	 16.2	 -11.1	 1.0	 100.0	 1	 33.4	 14.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.4; % PEL
	35409	 24.55	 2.65	 16.8	 -11.5	 1.0	 100.0	 1	 34.6	 14.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.6; % NG
	35409	 24.55	 2.65	 16.8	 -11.5	 1.0	 100.0	 1	 34.6	 14.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.6; % NG
	35410	 22.85	 2.4	 15.3	 -10.5	 1.0	 100.0	 1	 31.5	 14.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.5; % NG
	35410	 25.35	 2.75	 17.7	 -12.2	 1.0	 100.0	 1	 36.5	 14.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.5; % PEL
	35410	 27.2	 3.15	 20.1	 -13.8	 1.0	 100.0	 1	 41.4	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4; % NG
	35410	 27.2	 3.15	 20.1	 -13.8	 1.0	 100.0	 1	 41.4	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4; % PEL
	35412	 24.65	 0.0	 9.7	 -9.7	 1.0	 100.0	 1	 29.6	 19.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.6; % NG
	35412	 28.85	 0.0	 12.5	 -12.5	 1.0	 100.0	 1	 38.0	 19.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0; % NG
	35412	 29.0	 0.0	 12.6	 -12.6	 1.0	 100.0	 1	 38.3	 19.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.3; % PEL
	35413	 19.8	 2.15	 13.9	 -9.6	 1.0	 100.0	 1	 28.8	 10.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % NG
	35414	 24.7	 2.15	 13.9	 -9.6	 1.0	 100.0	 1	 28.8	 20.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % PEL
	35414	 22.25	 2.15	 13.9	 -9.6	 1.0	 100.0	 1	 28.8	 15.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % PEL
	35415	 28.0	 2.15	 13.6	 -9.3	 1.0	 100.0	 1	 28.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0; % PEL
	35416	 13.5	 0.0	 10.7	 -10.7	 1.0	 100.0	 1	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	35417	 25.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % COW
	35417	 25.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	35417	 25.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	35417	 26.85	 4.1	 17.8	 -9.6	 1.0	 100.0	 1	 28.7	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.7; % PEL
	35418	 13.0	 0.0	 8.2	 -8.2	 1.0	 100.0	 1	 25.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	35421	 26.0	 0.0	 16.4	 -16.4	 1.0	 100.0	 1	 50.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	35421	 12.25	 1.7	 10.9	 -7.5	 1.0	 100.0	 1	 22.5	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5; % NG
	35422	 1.2	 0.155	 0.97	 -0.66	 1.0	 100.0	 1	 2.0	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35422	 1.2	 0.155	 0.97	 -0.66	 1.0	 100.0	 1	 2.0	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35422	 1.2	 0.155	 0.97	 -0.66	 1.0	 100.0	 1	 2.0	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % NG
	35422	 1.2	 0.155	 0.97	 -0.66	 1.0	 100.0	 1	 2.0	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35422	 1.2	 0.155	 0.97	 -0.66	 1.0	 100.0	 1	 2.0	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35422	 1.2	 0.155	 0.97	 -0.66	 1.0	 100.0	 1	 2.0	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35422	 1.2	 0.155	 0.97	 -0.66	 1.0	 100.0	 1	 2.0	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35422	 1.2	 0.155	 0.97	 -0.66	 1.0	 100.0	 1	 2.0	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35422	 1.2	 0.155	 0.97	 -0.66	 1.0	 100.0	 1	 2.0	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35422	 1.2	 0.155	 0.97	 -0.66	 1.0	 100.0	 1	 2.0	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35422	 1.2	 0.155	 0.97	 -0.66	 1.0	 100.0	 1	 2.0	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35423	 1.25	 0.0	 0.65	 -0.65	 1.0	 100.0	 1	 2.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % NG
	35423	 1.25	 0.0	 0.65	 -0.65	 1.0	 100.0	 1	 2.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35423	 1.25	 0.0	 0.65	 -0.65	 1.0	 100.0	 1	 2.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % NG
	35423	 1.25	 0.0	 0.65	 -0.65	 1.0	 100.0	 1	 2.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35423	 1.25	 0.0	 0.65	 -0.65	 1.0	 100.0	 1	 2.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35423	 1.25	 0.0	 0.65	 -0.65	 1.0	 100.0	 1	 2.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35423	 1.25	 0.0	 0.65	 -0.65	 1.0	 100.0	 1	 2.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35423	 1.25	 0.0	 0.65	 -0.65	 1.0	 100.0	 1	 2.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35423	 1.25	 0.0	 0.65	 -0.65	 1.0	 100.0	 1	 2.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35423	 1.25	 0.0	 0.65	 -0.65	 1.0	 100.0	 1	 2.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	35423	 1.25	 0.0	 0.65	 -0.65	 1.0	 100.0	 1	 2.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39875	 543.45	 61.3	 393.2	 -270.6	 1.0	 100.0	 1	 811.9	 275.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 811.9; % COW
	39876	 472.95	 52.5	 337.0	 -232.0	 1.0	 100.0	 1	 695.9	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 695.9; % COW
	39877	 369.75	 0.0	 223.3	 -223.3	 1.0	 100.0	 1	 679.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39878	 151.2	 22.65	 145.3	 -100.0	 1.0	 100.0	 1	 300.0	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39880	 105.0	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39882	 155.2	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4; % NG
	39882	 155.2	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4; % NG
	39882	 125.25	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % NG
	39883	 87.45	 13.2	 84.7	 -58.3	 1.0	 100.0	 1	 174.8	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39884	 134.2	 24.85	 107.5	 -57.8	 1.0	 100.0	 1	 173.4	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.4; % NG
	39884	 134.2	 24.85	 107.5	 -57.8	 1.0	 100.0	 1	 173.4	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.4; % NG
	39884	 159.5	 36.7	 158.7	 -85.3	 1.0	 100.0	 1	 256.0	 63.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 256.0; % NG
	39885	 76.55	 0.0	 67.5	 -67.5	 1.0	 100.0	 1	 153.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39886	 75.05	 0.0	 66.1	 -66.1	 1.0	 100.0	 1	 150.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39888	 78.75	 0.0	 66.1	 -66.1	 1.0	 100.0	 1	 150.0	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39889	 78.75	 0.0	 66.1	 -66.1	 1.0	 100.0	 1	 150.0	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39890	 106.0	 21.05	 91.1	 -49.0	 1.0	 100.0	 1	 147.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 147.0; % NG
	39890	 219.6	 26.35	 169.1	 -116.4	 1.0	 100.0	 1	 349.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 349.2; % COW
	39890	 0.0	 0.0	 282.9	 -194.7	 1.0	 100.0	 0	 584.1	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 584.1; % NG
	39891	 83.0	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % COW
	39892	 9.25	 2.285	 9.91	 -5.34	 1.0	 100.0	 1	 16.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % PEL
	39892	 9.25	 2.285	 9.91	 -5.34	 1.0	 100.0	 1	 16.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % PEL
	39892	 9.25	 2.285	 9.91	 -5.34	 1.0	 100.0	 1	 16.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	39892	 9.25	 2.285	 9.91	 -5.34	 1.0	 100.0	 1	 16.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	39892	 9.25	 2.285	 9.91	 -5.34	 1.0	 100.0	 1	 16.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % COW
	39892	 9.25	 2.285	 9.91	 -5.34	 1.0	 100.0	 1	 16.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % PEL
	39892	 9.25	 2.285	 9.91	 -5.34	 1.0	 100.0	 1	 16.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % COW
	39892	 9.25	 2.285	 9.91	 -5.34	 1.0	 100.0	 1	 16.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	39894	 56.75	 0.0	 49.6	 -49.6	 1.0	 100.0	 1	 112.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39895	 26.25	 0.0	 19.8	 -19.8	 1.0	 100.0	 1	 50.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39895	 52.5	 0.0	 44.1	 -44.1	 1.0	 100.0	 1	 100.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39896	 50.5	 0.0	 44.1	 -44.1	 1.0	 100.0	 1	 100.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39897	 49.55	 0.0	 43.7	 -43.7	 1.0	 100.0	 1	 99.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39898	 49.5	 7.45	 47.9	 -33.0	 1.0	 100.0	 1	 99.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39899	 51.45	 0.0	 43.2	 -43.2	 1.0	 100.0	 1	 98.0	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39900	 18.72	 3.77	 16.97	 -9.43	 1.0	 100.0	 1	 28.27	 9.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.2667; % PEL
	39900	 18.72	 3.77	 16.97	 -9.43	 1.0	 100.0	 1	 28.27	 9.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.2667; % NG
	39900	 18.72	 3.77	 16.97	 -9.43	 1.0	 100.0	 1	 28.27	 9.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.2667; % NG
	39902	 24.75	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.5	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % NG
	39902	 63.3	 11.7	 50.6	 -27.2	 1.0	 100.0	 1	 81.6	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % NG
	39903	 40.6	 0.0	 31.7	 -31.7	 1.0	 100.0	 1	 80.2	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39904	 40.5	 0.0	 31.6	 -31.6	 1.0	 100.0	 1	 80.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39905	 40.0	 0.0	 31.6	 -31.6	 1.0	 100.0	 1	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39906	 146.0	 16.0	 102.7	 -70.7	 1.0	 100.0	 1	 212.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.0; % NG
	39906	 12.35	 1.485	 9.55	 -6.58	 1.0	 100.0	 1	 19.7	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.7; % NG
	39906	 12.35	 1.485	 9.55	 -6.58	 1.0	 100.0	 1	 19.7	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.7; % NG
	39906	 12.35	 1.485	 9.55	 -6.58	 1.0	 100.0	 1	 19.7	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.7; % PEL
	39906	 12.35	 1.485	 9.55	 -6.58	 1.0	 100.0	 1	 19.7	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.7; % PEL
	39908	 42.4	 5.95	 38.2	 -26.3	 1.0	 100.0	 1	 78.8	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.8; % NG
	39908	 42.4	 5.95	 38.2	 -26.3	 1.0	 100.0	 1	 78.8	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.8; % NG
	39909	 62.5	 15.05	 65.1	 -35.0	 1.0	 100.0	 1	 105.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0; % NG
	39909	 37.5	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	39910	 37.55	 0.0	 29.6	 -29.6	 1.0	 100.0	 1	 75.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39911	 10.25	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	39911	 10.25	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	39911	 10.25	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	39911	 10.25	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	39912	 38.6	 5.4	 34.5	 -23.7	 1.0	 100.0	 1	 71.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2; % PEL
	39912	 47.5	 6.7	 43.1	 -29.7	 1.0	 100.0	 1	 89.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.0; % NG
	39912	 54.95	 7.85	 50.3	 -34.6	 1.0	 100.0	 1	 103.9	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.9; % NG
	39913	 34.65	 0.0	 26.1	 -26.1	 1.0	 100.0	 1	 66.0	 3.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39914	 46.5	 4.75	 30.5	 -21.0	 1.0	 100.0	 1	 63.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0; % NG
	39914	 46.5	 4.75	 30.5	 -21.0	 1.0	 100.0	 1	 63.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0; % NG
	39914	 46.5	 4.75	 30.5	 -21.0	 1.0	 100.0	 1	 63.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0; % NG
	39915	 45.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	39915	 45.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	39915	 45.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	39917	 29.3	 0.0	 23.1	 -23.1	 1.0	 100.0	 1	 58.5	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	39917	 37.55	 0.0	 29.6	 -29.6	 1.0	 100.0	 1	 75.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39917	 61.55	 0.0	 54.2	 -54.2	 1.0	 100.0	 1	 123.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39919	 19.7	 4.9	 21.3	 -11.5	 1.0	 100.0	 1	 34.4	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.4; % PEL
	39919	 27.5	 5.75	 24.8	 -13.3	 1.0	 100.0	 1	 40.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	39919	 34.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	39920	 37.0	 7.05	 30.4	 -16.3	 1.0	 100.0	 1	 49.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0; % NG
	39920	 60.8	 11.7	 50.6	 -27.2	 1.0	 100.0	 1	 81.6	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % NG
	39920	 643.75	 69.65	 446.8	 -307.5	 1.0	 100.0	 1	 922.5	 365.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 922.5; % COW
	39920	 537.9	 54.8	 351.5	 -241.9	 1.0	 100.0	 1	 725.8	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 725.8; % COW
	39923	 21.75	 0.0	 17.2	 -17.2	 1.0	 100.0	 1	 43.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39924	 22.05	 0.0	 16.6	 -16.6	 1.0	 100.0	 1	 42.0	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39926	 25.31	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.5	 13.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % NG
	39926	 185.7	 20.7	 132.9	 -91.5	 1.0	 100.0	 1	 274.5	 96.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 274.5; % NG
	39927	 25.31	 5.1	 22.7	 -12.5	 1.0	 100.0	 1	 37.5	 13.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % PEL
	39927	 24.75	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.5	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % NG
	39927	 52.8	 11.7	 50.6	 -27.2	 1.0	 100.0	 1	 81.6	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % NG
	39930	 20.5	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % PEL
	39931	 17.55	 0.0	 13.8	 -13.8	 1.0	 100.0	 1	 35.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39931	 92.55	 13.95	 89.6	 -61.7	 1.0	 100.0	 1	 185.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39932	 14.85	 0.0	 11.7	 -11.7	 1.0	 100.0	 1	 29.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39933	 22.75	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.5	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % COW
	39933	 18.35	 5.95	 21.5	 -9.6	 1.0	 100.0	 1	 28.7	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.7; % PEL
	39934	 1.5	 0.0	 0.41	 -0.41	 1.0	 100.0	 1	 2.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39934	 1.5	 0.0	 0.41	 -0.41	 1.0	 100.0	 1	 2.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39934	 1.5	 0.0	 0.41	 -0.41	 1.0	 100.0	 1	 2.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39934	 1.5	 0.0	 0.41	 -0.41	 1.0	 100.0	 1	 2.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39934	 1.5	 0.0	 0.41	 -0.41	 1.0	 100.0	 1	 2.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39934	 1.5	 0.0	 0.41	 -0.41	 1.0	 100.0	 1	 2.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39934	 1.5	 0.0	 0.41	 -0.41	 1.0	 100.0	 1	 2.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39934	 1.5	 0.0	 0.41	 -0.41	 1.0	 100.0	 1	 2.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39934	 1.5	 0.0	 0.41	 -0.41	 1.0	 100.0	 1	 2.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39934	 1.5	 0.0	 0.41	 -0.41	 1.0	 100.0	 1	 2.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39934	 1.5	 0.0	 0.41	 -0.41	 1.0	 100.0	 1	 2.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39934	 1.5	 0.0	 0.41	 -0.41	 1.0	 100.0	 1	 2.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39934	 1.5	 0.0	 0.41	 -0.41	 1.0	 100.0	 1	 2.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39934	 1.5	 0.0	 0.41	 -0.41	 1.0	 100.0	 1	 2.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39935	 14.0	 0.0	 11.1	 -11.1	 1.0	 100.0	 1	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39935	 66.0	 0.0	 58.2	 -58.2	 1.0	 100.0	 1	 132.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39938	 18.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	39938	 25.75	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.5	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % NG
	39939	 1.05	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39939	 1.05	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39939	 1.05	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39939	 1.05	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39939	 1.05	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39939	 1.05	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39939	 1.05	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39939	 1.05	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39939	 1.05	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39939	 1.05	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39939	 1.05	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39939	 1.05	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	39940	 16.9	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % COW
	39941	 16.9	 5.0	 17.9	 -7.9	 1.0	 100.0	 1	 23.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % NG
	39942	 16.9	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % NG
	39942	 16.9	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % PEL
	39943	 96.9	 21.3	 92.2	 -49.6	 1.0	 100.0	 1	 148.8	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 148.8; % NG
	39943	 15.525	 3.15	 14.0	 -7.7	 1.0	 100.0	 1	 23.0	 8.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % PEL
	39943	 29.6	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 9.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	39944	 18.2	 3.2	 13.9	 -7.5	 1.0	 100.0	 1	 22.5	 13.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5; % PEL
	39945	 11.3	 0.0	 8.9	 -8.9	 1.0	 100.0	 1	 22.5	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39945	 80.3	 0.0	 70.8	 -70.8	 1.0	 100.0	 1	 160.5	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39946	 2.75	 0.0	 0.75	 -0.75	 1.0	 100.0	 1	 3.67	 1.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6667; % NG
	39946	 2.75	 0.0	 0.75	 -0.75	 1.0	 100.0	 1	 3.67	 1.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6667; % PEL
	39946	 2.75	 0.0	 0.75	 -0.75	 1.0	 100.0	 1	 3.67	 1.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6667; % PEL
	39946	 2.75	 0.0	 0.75	 -0.75	 1.0	 100.0	 1	 3.67	 1.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6667; % NG
	39946	 2.75	 0.0	 0.75	 -0.75	 1.0	 100.0	 1	 3.67	 1.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6667; % NG
	39946	 2.75	 0.0	 0.75	 -0.75	 1.0	 100.0	 1	 3.67	 1.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6667; % NG
	39947	 13.15	 3.05	 13.2	 -7.1	 1.0	 100.0	 1	 21.3	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.3; % NG
	39948	 4.085	 1.47	 5.27	 -2.33	 1.0	 100.0	 1	 7.0	 1.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.0; % PEL
	39948	 4.085	 1.47	 5.27	 -2.33	 1.0	 100.0	 1	 7.0	 1.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.0; % NG
	39948	 4.085	 1.47	 5.27	 -2.33	 1.0	 100.0	 1	 7.0	 1.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.0; % NG
	39949	 11.0	 0.0	 8.3	 -8.3	 1.0	 100.0	 1	 21.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39951	 12.5	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	39951	 12.5	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	39952	 10.0	 0.0	 7.9	 -7.9	 1.0	 100.0	 1	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39953	 941.5	 92.45	 593.2	 -408.3	 1.0	 100.0	 1	 1224.9	 658.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39953	 0.0	 0.0	 593.2	 -408.3	 1.0	 100.0	 0	 1224.9	 657.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39954	 941.7	 92.45	 593.2	 -408.3	 1.0	 100.0	 1	 1224.9	 658.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39954	 936.5	 92.45	 593.2	 -408.3	 1.0	 100.0	 1	 1224.9	 648.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39955	 652.5	 88.35	 566.7	 -390.0	 1.0	 100.0	 1	 1170.0	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39955	 652.0	 88.35	 566.7	 -390.0	 1.0	 100.0	 1	 1170.0	 134.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39956	 718.2	 85.95	 551.3	 -379.4	 1.0	 100.0	 1	 1138.3	 298.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39957	 579.65	 0.0	 349.3	 -349.3	 1.0	 100.0	 1	 1009.3	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39957	 0.0	 0.0	 349.3	 -349.3	 1.0	 100.0	 0	 1009.3	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39958	 570.65	 0.0	 349.3	 -349.3	 1.0	 100.0	 1	 1009.3	 132.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39958	 570.65	 0.0	 349.3	 -349.3	 1.0	 100.0	 1	 1009.3	 132.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NUC
	39959	 608.9	 67.4	 432.4	 -297.6	 1.0	 100.0	 1	 892.8	 325.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 892.8; % COW
	39959	 0.0	 0.0	 432.4	 -297.6	 1.0	 100.0	 0	 892.8	 325.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 892.8; % COW
	39960	 390.0	 49.85	 319.7	 -220.0	 1.0	 100.0	 1	 660.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 660.0; % COW
	39960	 0.0	 0.0	 319.7	 -220.0	 1.0	 100.0	 0	 660.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 660.0; % COW
	39961	 449.75	 49.8	 319.4	 -219.8	 1.0	 100.0	 1	 659.5	 240.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 659.5; % COW
	39961	 449.75	 49.8	 319.4	 -219.8	 1.0	 100.0	 1	 659.5	 240.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 659.5; % COW
	39962	 442.25	 47.9	 307.3	 -211.5	 1.0	 100.0	 1	 634.5	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 634.5; % COW
	39962	 442.25	 47.9	 307.3	 -211.5	 1.0	 100.0	 1	 634.5	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 634.5; % COW
	39962	 437.55	 89.5	 387.4	 -208.4	 1.0	 100.0	 1	 625.1	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 625.1; % NG
	39963	 458.7	 46.6	 299.0	 -205.8	 1.0	 100.0	 1	 617.4	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 617.4; % COW
	39963	 408.7	 46.6	 299.0	 -205.8	 1.0	 100.0	 1	 617.4	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 617.4; % COW
	39964	 291.5	 36.8	 236.3	 -162.7	 1.0	 100.0	 1	 488.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 488.0; % COW
	39964	 31.28	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 16.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % NG
	39964	 31.28	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 16.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % NG
	39964	 31.28	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 16.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % NG
	39964	 31.28	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 16.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % PEL
	39964	 31.28	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 16.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % NG
	39965	 343.0	 63.15	 273.3	 -147.0	 1.0	 100.0	 1	 441.0	 245.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 441.0; % NG
	39966	 294.45	 55.7	 241.0	 -129.6	 1.0	 100.0	 1	 388.9	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 388.9; % COW
	39966	 463.25	 46.55	 298.6	 -205.5	 1.0	 100.0	 1	 616.5	 310.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 616.5; % NG
	39967	 16.4	 3.25	 14.1	 -7.6	 1.0	 100.0	 1	 22.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.8; % NG
	39967	 24.0	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0; % NG
	39967	 24.0	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0; % NG
	39967	 24.0	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0; % NG
	39967	 24.0	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0; % NG
	39967	 24.0	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0; % NG
	39967	 24.0	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0; % NG
	39967	 24.0	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0; % NG
	39967	 261.8	 51.1	 226.9	 -124.7	 1.0	 100.0	 1	 374.0	 149.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 374.0; % NG
	39969	 0.0	 0.0	 17.4	 -9.3	 1.0	 100.0	 0	 28.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0; % NG
	39969	 0.0	 0.0	 17.4	 -9.3	 1.0	 100.0	 0	 28.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0; % NG
	39969	 0.0	 0.0	 17.4	 -9.3	 1.0	 100.0	 0	 28.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0; % NG
	39969	 0.0	 0.0	 17.4	 -9.3	 1.0	 100.0	 0	 28.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0; % NG
	39969	 0.0	 0.0	 202.3	 -108.8	 1.0	 100.0	 0	 326.4	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 326.4; % NG
	39969	 0.0	 0.0	 220.2	 -118.4	 1.0	 100.0	 0	 355.3	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 355.3; % NG
	39970	 150.0	 22.65	 145.3	 -100.0	 1.0	 100.0	 1	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39971	 166.315	 29.2	 138.2	 -79.8	 1.0	 100.0	 1	 239.3	 93.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 239.3; % NG
	39971	 250.67	 48.9	 217.2	 -119.4	 1.0	 100.0	 1	 358.1	 143.24	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 358.1; % NG
	39972	 170.6	 16.85	 108.1	 -74.4	 1.0	 100.0	 1	 223.2	 118.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 223.2; % NG
	39972	 166.6	 16.85	 108.1	 -74.4	 1.0	 100.0	 1	 223.2	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 223.2; % NG
	39972	 61.45	 9.4	 45.8	 -27.0	 1.0	 100.0	 1	 80.9	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.9; % NG
	39972	 85.8	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 58.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % NG
	39974	 162.6	 27.4	 118.5	 -63.7	 1.0	 100.0	 1	 191.2	 134.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 191.2; % NG
	39974	 178.5	 30.05	 130.1	 -70.0	 1.0	 100.0	 1	 210.0	 147.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 210.0; % NG
	39974	 178.5	 30.05	 130.1	 -70.0	 1.0	 100.0	 1	 210.0	 147.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 210.0; % NG
	39975	 199.0	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 198.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39976	 0.0	 0.0	 123.3	 -66.3	 1.0	 100.0	 0	 198.9	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % COW
	39976	 0.0	 0.0	 123.3	 -66.3	 1.0	 100.0	 0	 198.9	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	39976	 0.0	 0.0	 123.3	 -66.3	 1.0	 100.0	 0	 198.9	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	39977	 99.75	 14.95	 95.9	 -66.0	 1.0	 100.0	 1	 198.0	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39977	 99.75	 14.95	 95.9	 -66.0	 1.0	 100.0	 1	 198.0	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	39978	 146.0	 27.5	 119.0	 -64.0	 1.0	 100.0	 1	 192.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.0; % COW
	39978	 146.0	 27.5	 119.0	 -64.0	 1.0	 100.0	 1	 192.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.0; % NG
	39978	 146.0	 27.5	 119.0	 -64.0	 1.0	 100.0	 1	 192.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.0; % NG
	39978	 0.0	 0.0	 119.0	 -64.0	 1.0	 100.0	 0	 192.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.0; % NG
	39978	 0.0	 0.0	 119.0	 -64.0	 1.0	 100.0	 0	 192.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.0; % NG
	39978	 0.0	 0.0	 119.0	 -64.0	 1.0	 100.0	 0	 192.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.0; % NG
	39978	 0.0	 0.0	 119.0	 -64.0	 1.0	 100.0	 0	 192.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.0; % NG
	39978	 0.0	 0.0	 119.0	 -64.0	 1.0	 100.0	 0	 192.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.0; % NG
	39978	 0.0	 0.0	 119.0	 -64.0	 1.0	 100.0	 0	 192.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.0; % NG
	39979	 127.67	 34.45	 130.1	 -61.2	 1.0	 100.0	 1	 183.7	 71.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.7; % NG
	39979	 130.31	 35.15	 132.8	 -62.5	 1.0	 100.0	 1	 187.5	 73.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.5; % NG
	39979	 197.1	 42.85	 185.4	 -99.7	 1.0	 100.0	 1	 299.2	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 299.2; % NG
	39979	 389.2	 85.7	 370.9	 -199.5	 1.0	 100.0	 1	 598.4	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 598.4; % COW
	39980	 115.15	 26.25	 113.6	 -61.1	 1.0	 100.0	 1	 183.3	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.3; % NG
	39980	 115.15	 26.25	 113.6	 -61.1	 1.0	 100.0	 1	 183.3	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.3; % NG
	39980	 115.15	 26.25	 113.6	 -61.1	 1.0	 100.0	 1	 183.3	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.3; % NG
	39980	 115.15	 26.25	 113.6	 -61.1	 1.0	 100.0	 1	 183.3	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.3; % NG
	39980	 115.15	 26.25	 113.6	 -61.1	 1.0	 100.0	 1	 183.3	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.3; % NG
	39980	 115.15	 26.25	 113.6	 -61.1	 1.0	 100.0	 1	 183.3	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.3; % NG
	39981	 135.0	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	39981	 135.0	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	39981	 135.0	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	39981	 135.0	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	39981	 99.5	 19.15	 83.0	 -44.7	 1.0	 100.0	 1	 134.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.0; % NG
	39981	 99.5	 19.15	 83.0	 -44.7	 1.0	 100.0	 1	 134.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.0; % NG
	39981	 99.5	 19.15	 83.0	 -44.7	 1.0	 100.0	 1	 134.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.0; % COW
	39981	 99.5	 19.15	 83.0	 -44.7	 1.0	 100.0	 1	 134.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.0; % NG
	39982	 139.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	39982	 139.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	39982	 197.55	 49.45	 213.9	 -115.0	 1.0	 100.0	 1	 345.1	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 345.1; % NG
	39983	 0.0	 0.0	 104.1	 -56.0	 1.0	 100.0	 0	 168.0	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 168.0; % NG
	39984	 0.0	 0.0	 97.9	 -52.7	 1.0	 100.0	 0	 158.0	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 158.0; % NG
	39984	 0.0	 0.0	 97.9	 -52.7	 1.0	 100.0	 0	 158.0	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 158.0; % NG
	39985	 140.7	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 156.4	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.4; % NG
	39985	 140.7	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 156.4	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.4; % NG
	39986	 150.0	 0.0	 66.1	 -66.1	 1.0	 100.0	 1	 150.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39987	 106.8	 10.45	 67.1	 -46.2	 1.0	 100.0	 1	 138.6	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 138.6; % NG
	39988	 103.0	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % NG
	39988	 210.25	 40.15	 173.8	 -93.5	 1.0	 100.0	 1	 280.5	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 280.5; % NG
	39988	 269.4	 52.1	 225.5	 -121.3	 1.0	 100.0	 1	 363.8	 175.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 363.8; % NG
	39989	 112.0	 10.2	 65.4	 -45.0	 1.0	 100.0	 1	 135.0	 89.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % NG
	39989	 112.0	 10.2	 65.4	 -45.0	 1.0	 100.0	 1	 135.0	 89.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % NG
	39990	 100.5	 10.2	 65.4	 -45.0	 1.0	 100.0	 1	 135.0	 66.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % NG
	39990	 100.5	 10.2	 65.4	 -45.0	 1.0	 100.0	 1	 135.0	 66.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % NG
	39991	 0.0	 0.0	 65.4	 -45.0	 1.0	 100.0	 0	 135.0	 104.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % NG
	39991	 0.0	 0.0	 65.4	 -45.0	 1.0	 100.0	 0	 135.0	 104.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % NG
	39991	 0.0	 0.0	 65.4	 -45.0	 1.0	 100.0	 0	 135.0	 104.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % PEL
	39991	 0.0	 0.0	 65.4	 -45.0	 1.0	 100.0	 0	 135.0	 104.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % COW
	39992	 82.0	 16.35	 70.7	 -38.0	 1.0	 100.0	 1	 114.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0; % NG
	39992	 76.5	 16.35	 70.7	 -38.0	 1.0	 100.0	 1	 114.0	 39.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0; % NG
	39992	 76.5	 16.35	 70.7	 -38.0	 1.0	 100.0	 1	 114.0	 39.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0; % COW
	39992	 76.5	 16.35	 70.7	 -38.0	 1.0	 100.0	 1	 114.0	 39.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0; % NG
	39993	 80.5	 16.35	 70.7	 -38.0	 1.0	 100.0	 1	 114.0	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0; % NG
	39993	 80.5	 16.35	 70.7	 -38.0	 1.0	 100.0	 1	 114.0	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0; % NG
	39993	 80.5	 16.35	 70.7	 -38.0	 1.0	 100.0	 1	 114.0	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0; % NG
	39993	 80.5	 16.35	 70.7	 -38.0	 1.0	 100.0	 1	 114.0	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0; % NG
	39993	 80.5	 16.35	 70.7	 -38.0	 1.0	 100.0	 1	 114.0	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0; % COW
	39993	 80.5	 16.35	 70.7	 -38.0	 1.0	 100.0	 1	 114.0	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0; % NG
	39994	 73.75	 16.1	 69.7	 -37.5	 1.0	 100.0	 1	 112.5	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % NG
	39994	 32.125	 6.0	 28.7	 -16.7	 1.0	 100.0	 1	 50.0	 14.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	39994	 32.125	 6.0	 28.7	 -16.7	 1.0	 100.0	 1	 50.0	 14.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	39994	 32.125	 6.0	 28.7	 -16.7	 1.0	 100.0	 1	 50.0	 14.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % PEL
	39994	 251.3	 55.5	 240.2	 -129.2	 1.0	 100.0	 1	 387.6	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 387.6; % NG
	39995	 102.0	 0.0	 45.0	 -45.0	 1.0	 100.0	 1	 102.0	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39996	 73.4	 14.6	 63.1	 -33.9	 1.0	 100.0	 1	 101.8	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.8; % NG
	39996	 73.4	 14.6	 63.1	 -33.9	 1.0	 100.0	 1	 101.8	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.8; % NG
	39996	 73.4	 14.6	 63.1	 -33.9	 1.0	 100.0	 1	 101.8	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.8; % NG
	39996	 73.4	 14.6	 63.1	 -33.9	 1.0	 100.0	 1	 101.8	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.8; % COW
	39996	 73.4	 14.6	 63.1	 -33.9	 1.0	 100.0	 1	 101.8	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.8; % NG
	39996	 73.4	 14.6	 63.1	 -33.9	 1.0	 100.0	 1	 101.8	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.8; % NG
	39996	 73.4	 14.6	 63.1	 -33.9	 1.0	 100.0	 1	 101.8	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.8; % COW
	39996	 73.4	 14.6	 63.1	 -33.9	 1.0	 100.0	 1	 101.8	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.8; % COW
	39997	 50.25	 0.0	 44.3	 -44.3	 1.0	 100.0	 1	 100.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39998	 51.0	 0.0	 44.3	 -44.3	 1.0	 100.0	 1	 100.5	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	39999	 148.65	 15.65	 100.4	 -69.1	 1.0	 100.0	 1	 207.3	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 207.3; % NG
	39999	 69.1	 0.0	 29.6	 -29.6	 1.0	 100.0	 1	 90.2	 48.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.2; % NG
	39999	 69.1	 6.8	 43.7	 -30.1	 1.0	 100.0	 1	 90.2	 48.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.2; % COW
	39999	 152.55	 32.95	 142.6	 -76.7	 1.0	 100.0	 1	 230.1	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.1; % NG
	40000	 67.0	 12.75	 55.2	 -29.7	 1.0	 100.0	 1	 89.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.0; % NG
	40000	 67.0	 12.75	 55.2	 -29.7	 1.0	 100.0	 1	 89.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.0; % NG
	40000	 67.0	 12.75	 55.2	 -29.7	 1.0	 100.0	 1	 89.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.0; % NG
	40000	 67.0	 12.75	 55.2	 -29.7	 1.0	 100.0	 1	 89.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.0; % COW
	40001	 65.75	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	40001	 65.75	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	40001	 65.75	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % COW
	40001	 65.75	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	40001	 65.75	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	40001	 65.75	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	40001	 65.75	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	40001	 65.75	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % PEL
	40002	 40.0	 0.0	 31.6	 -31.6	 1.0	 100.0	 1	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40003	 40.0	 0.0	 25.6	 -25.6	 1.0	 100.0	 1	 78.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0; % PEL
	40004	 50.0	 15.65	 56.3	 -25.0	 1.0	 100.0	 1	 75.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	40004	 155.65	 33.1	 143.3	 -77.1	 1.0	 100.0	 1	 231.3	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 231.3; % NG
	40005	 49.615	 10.05	 44.6	 -24.5	 1.0	 100.0	 1	 73.5	 25.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 73.5; % PEL
	40005	 73.44	 14.85	 66.0	 -36.3	 1.0	 100.0	 1	 108.8	 38.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.8; % COW
	40006	 10.25	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	40006	 10.25	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	40006	 10.25	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	40006	 10.25	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	40007	 36.0	 0.0	 28.5	 -28.5	 1.0	 100.0	 1	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	40008	 45.5	 5.35	 34.4	 -23.7	 1.0	 100.0	 1	 71.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.0; % NG
	40009	 0.0	 0.0	 44.0	 -23.7	 1.0	 100.0	 0	 71.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.0; % NG
	40009	 0.0	 0.0	 132.0	 -71.0	 1.0	 100.0	 0	 213.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.0; % NG
	40009	 0.0	 0.0	 44.0	 -23.7	 1.0	 100.0	 0	 71.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.0; % NG
	40009	 0.0	 0.0	 44.0	 -23.7	 1.0	 100.0	 0	 71.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.0; % NG
	40009	 0.0	 0.0	 44.0	 -23.7	 1.0	 100.0	 0	 71.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.0; % NG
	40009	 0.0	 0.0	 44.0	 -23.7	 1.0	 100.0	 0	 71.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.0; % PEL
	40009	 0.0	 0.0	 44.0	 -23.7	 1.0	 100.0	 0	 71.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.0; % NG
	40009	 0.0	 0.0	 130.1	 -70.0	 1.0	 100.0	 0	 210.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 210.0; % NG
	40009	 0.0	 0.0	 132.0	 -71.0	 1.0	 100.0	 0	 213.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.0; % NG
	40009	 0.0	 0.0	 132.0	 -71.0	 1.0	 100.0	 0	 213.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.0; % NG
	40010	 13.125	 2.055	 9.93	 -5.82	 1.0	 100.0	 1	 17.5	 8.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % PEL
	40010	 13.125	 2.055	 9.93	 -5.82	 1.0	 100.0	 1	 17.5	 8.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % NG
	40010	 13.125	 2.055	 9.93	 -5.82	 1.0	 100.0	 1	 17.5	 8.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % NG
	40010	 13.125	 2.055	 9.93	 -5.82	 1.0	 100.0	 1	 17.5	 8.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % PEL
	40012	 33.0	 8.75	 37.8	 -20.3	 1.0	 100.0	 1	 61.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0; % NG
	40012	 26.53	 3.8	 20.1	 -12.5	 1.0	 100.0	 1	 37.5	 15.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % NG
	40012	 96.0	 9.4	 60.5	 -41.7	 1.0	 100.0	 1	 125.0	 67.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % COW
	40012	 159.5	 28.6	 123.9	 -66.7	 1.0	 100.0	 1	 200.0	 119.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	40012	 159.5	 28.6	 123.9	 -66.7	 1.0	 100.0	 1	 200.0	 119.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	40013	 46.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % PEL
	40013	 46.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % PEL
	40013	 46.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	40013	 46.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	40013	 46.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	40013	 46.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	40013	 46.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	40013	 46.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	40014	 35.7	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 12.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % PEL
	40014	 35.7	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 12.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % COW
	40014	 35.7	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 12.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % NG
	40014	 35.7	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 12.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % NG
	40014	 35.7	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 12.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % PEL
	40014	 35.7	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 12.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % PEL
	40016	 26.5	 0.0	 20.9	 -20.9	 1.0	 100.0	 1	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40017	 35.45	 7.25	 31.5	 -17.0	 1.0	 100.0	 1	 50.9	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.9; % NG
	40017	 35.45	 7.25	 31.5	 -17.0	 1.0	 100.0	 1	 50.9	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.9; % NG
	40017	 35.45	 7.25	 31.5	 -17.0	 1.0	 100.0	 1	 50.9	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.9; % NG
	40017	 35.45	 7.25	 31.5	 -17.0	 1.0	 100.0	 1	 50.9	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.9; % NG
	40017	 35.45	 7.25	 31.5	 -17.0	 1.0	 100.0	 1	 50.9	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.9; % NG
	40017	 35.45	 7.25	 31.5	 -17.0	 1.0	 100.0	 1	 50.9	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.9; % NG
	40017	 35.45	 7.25	 31.5	 -17.0	 1.0	 100.0	 1	 50.9	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.9; % NG
	40017	 35.45	 7.25	 31.5	 -17.0	 1.0	 100.0	 1	 50.9	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.9; % NG
	40018	 25.2	 0.0	 19.9	 -19.9	 1.0	 100.0	 1	 50.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40021	 32.5	 6.7	 29.1	 -15.7	 1.0	 100.0	 1	 47.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % NG
	40021	 32.5	 6.7	 29.1	 -15.7	 1.0	 100.0	 1	 47.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % PEL
	40021	 32.5	 6.7	 29.1	 -15.7	 1.0	 100.0	 1	 47.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % PEL
	40021	 32.5	 6.7	 29.1	 -15.7	 1.0	 100.0	 1	 47.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % NG
	40022	 37.0	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	40022	 37.0	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % COW
	40022	 37.0	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	40022	 37.0	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	40022	 40.0	 10.4	 37.5	 -16.7	 1.0	 100.0	 1	 50.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	40022	 40.0	 10.4	 37.5	 -16.7	 1.0	 100.0	 1	 50.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	40022	 40.0	 10.4	 37.5	 -16.7	 1.0	 100.0	 1	 50.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	40022	 40.0	 10.4	 37.5	 -16.7	 1.0	 100.0	 1	 50.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	40023	 0.0	 0.0	 20.1	 -13.8	 1.0	 100.0	 0	 41.5	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.5; % NG
	40023	 0.0	 0.0	 78.0	 -41.9	 1.0	 100.0	 0	 125.8	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.8; % NG
	40023	 0.0	 0.0	 75.9	 -40.8	 1.0	 100.0	 0	 122.4	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.4; % NG
	40023	 0.0	 0.0	 78.0	 -41.9	 1.0	 100.0	 0	 125.8	 62.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.8; % COW
	40026	 2.84	 0.985	 3.55	 -1.58	 1.0	 100.0	 1	 4.74	 0.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.7375; % NG
	40026	 2.84	 0.985	 3.55	 -1.58	 1.0	 100.0	 1	 4.74	 0.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.7375; % NG
	40026	 2.84	 0.985	 3.55	 -1.58	 1.0	 100.0	 1	 4.74	 0.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.7375; % NG
	40026	 2.84	 0.985	 3.55	 -1.58	 1.0	 100.0	 1	 4.74	 0.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.7375; % PEL
	40026	 2.84	 0.985	 3.55	 -1.58	 1.0	 100.0	 1	 4.74	 0.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.7375; % PEL
	40026	 2.84	 0.985	 3.55	 -1.58	 1.0	 100.0	 1	 4.74	 0.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.7375; % PEL
	40026	 2.84	 0.985	 3.55	 -1.58	 1.0	 100.0	 1	 4.74	 0.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.7375; % NG
	40026	 2.84	 0.985	 3.55	 -1.58	 1.0	 100.0	 1	 4.74	 0.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.7375; % PEL
	40028	 68.5	 15.05	 65.1	 -35.0	 1.0	 100.0	 1	 105.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0; % NG
	40028	 37.5	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	40028	 15.5	 6.5	 23.3	 -10.3	 1.0	 100.0	 1	 31.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.0; % PEL
	40028	 15.5	 6.5	 23.3	 -10.3	 1.0	 100.0	 1	 31.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.0; % NG
	40028	 15.5	 6.5	 23.3	 -10.3	 1.0	 100.0	 1	 31.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.0; % PEL
	40028	 15.5	 6.5	 23.3	 -10.3	 1.0	 100.0	 1	 31.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.0; % COW
	40028	 15.5	 6.5	 23.3	 -10.3	 1.0	 100.0	 1	 31.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.0; % COW
	40029	 1.11	 0.29	 1.25	 -0.67	 1.0	 100.0	 1	 1.99	 0.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.9933; % PEL
	40029	 1.11	 0.29	 1.25	 -0.67	 1.0	 100.0	 1	 1.99	 0.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.9933; % PEL
	40029	 1.11	 0.29	 1.25	 -0.67	 1.0	 100.0	 1	 1.99	 0.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.9933; % PEL
	40029	 1.11	 0.29	 1.25	 -0.67	 1.0	 100.0	 1	 1.99	 0.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.9933; % PEL
	40029	 1.11	 0.29	 1.25	 -0.67	 1.0	 100.0	 1	 1.99	 0.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.9933; % PEL
	40029	 1.11	 0.29	 1.25	 -0.67	 1.0	 100.0	 1	 1.99	 0.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.9933; % PEL
	40029	 1.11	 0.29	 1.25	 -0.67	 1.0	 100.0	 1	 1.99	 0.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.9933; % PEL
	40029	 1.11	 0.29	 1.25	 -0.67	 1.0	 100.0	 1	 1.99	 0.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.9933; % NG
	40029	 1.11	 0.29	 1.25	 -0.67	 1.0	 100.0	 1	 1.99	 0.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.9933; % PEL
	40029	 1.11	 0.29	 1.25	 -0.67	 1.0	 100.0	 1	 1.99	 0.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.9933; % PEL
	40029	 1.11	 0.29	 1.25	 -0.67	 1.0	 100.0	 1	 1.99	 0.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.9933; % PEL
	40029	 1.11	 0.29	 1.25	 -0.67	 1.0	 100.0	 1	 1.99	 0.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.9933; % PEL
	40029	 1.11	 0.29	 1.25	 -0.67	 1.0	 100.0	 1	 1.99	 0.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.9933; % PEL
	40029	 1.11	 0.29	 1.25	 -0.67	 1.0	 100.0	 1	 1.99	 0.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.9933; % PEL
	40029	 1.11	 0.29	 1.25	 -0.67	 1.0	 100.0	 1	 1.99	 0.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.9933; % PEL
	40030	 2.215	 0.475	 2.04	 -1.09	 1.0	 100.0	 1	 3.28	 1.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2778; % PEL
	40030	 2.215	 0.475	 2.04	 -1.09	 1.0	 100.0	 1	 3.28	 1.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2778; % PEL
	40030	 2.215	 0.475	 2.04	 -1.09	 1.0	 100.0	 1	 3.28	 1.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2778; % NG
	40030	 2.215	 0.475	 2.04	 -1.09	 1.0	 100.0	 1	 3.28	 1.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2778; % PEL
	40030	 2.215	 0.475	 2.04	 -1.09	 1.0	 100.0	 1	 3.28	 1.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2778; % NG
	40030	 2.215	 0.475	 2.04	 -1.09	 1.0	 100.0	 1	 3.28	 1.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2778; % NG
	40030	 2.215	 0.475	 2.04	 -1.09	 1.0	 100.0	 1	 3.28	 1.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2778; % COW
	40030	 2.215	 0.475	 2.04	 -1.09	 1.0	 100.0	 1	 3.28	 1.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2778; % NG
	40030	 2.215	 0.475	 2.04	 -1.09	 1.0	 100.0	 1	 3.28	 1.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2778; % PEL
	40031	 0.0	 0.0	 4.42	 -1.96	 1.0	 100.0	 0	 5.9	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.9; % PEL
	40031	 0.0	 0.0	 4.42	 -1.96	 1.0	 100.0	 0	 5.9	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.9; % PEL
	40031	 0.0	 0.0	 4.42	 -1.96	 1.0	 100.0	 0	 5.9	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.9; % NG
	40031	 0.0	 0.0	 4.42	 -1.96	 1.0	 100.0	 0	 5.9	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.9; % PEL
	40031	 0.0	 0.0	 4.42	 -1.96	 1.0	 100.0	 0	 5.9	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.9; % PEL
	40032	 5.95	 1.97	 7.07	 -3.13	 1.0	 100.0	 1	 9.4	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.4; % NG
	40032	 5.95	 1.97	 7.07	 -3.13	 1.0	 100.0	 1	 9.4	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.4; % NG
	40032	 5.95	 1.97	 7.07	 -3.13	 1.0	 100.0	 1	 9.4	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.4; % NG
	40034	 10.0	 1.85	 8.05	 -4.35	 1.0	 100.0	 1	 13.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0; % NG
	40034	 4.085	 1.135	 4.46	 -2.19	 1.0	 100.0	 1	 6.56	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5556; % PEL
	40034	 4.085	 1.135	 4.46	 -2.19	 1.0	 100.0	 1	 6.56	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5556; % NG
	40034	 10.0	 1.85	 8.05	 -4.35	 1.0	 100.0	 1	 13.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0; % NG
	40034	 4.085	 1.135	 4.46	 -2.19	 1.0	 100.0	 1	 6.56	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5556; % NG
	40034	 4.085	 1.135	 4.46	 -2.19	 1.0	 100.0	 1	 6.56	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5556; % PEL
	40034	 4.085	 1.135	 4.46	 -2.19	 1.0	 100.0	 1	 6.56	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5556; % PEL
	40034	 4.085	 1.135	 4.46	 -2.19	 1.0	 100.0	 1	 6.56	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5556; % PEL
	40034	 4.085	 1.135	 4.46	 -2.19	 1.0	 100.0	 1	 6.56	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5556; % NG
	40034	 4.085	 1.135	 4.46	 -2.19	 1.0	 100.0	 1	 6.56	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5556; % PEL
	40034	 4.085	 1.135	 4.46	 -2.19	 1.0	 100.0	 1	 6.56	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5556; % NG
	40035	 2.455	 0.735	 2.64	 -1.17	 1.0	 100.0	 1	 3.51	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.5143; % NG
	40035	 2.455	 0.735	 2.64	 -1.17	 1.0	 100.0	 1	 3.51	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.5143; % PEL
	40035	 2.455	 0.735	 2.64	 -1.17	 1.0	 100.0	 1	 3.51	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.5143; % NG
	40035	 2.455	 0.735	 2.64	 -1.17	 1.0	 100.0	 1	 3.51	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.5143; % NG
	40035	 2.455	 0.735	 2.64	 -1.17	 1.0	 100.0	 1	 3.51	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.5143; % NG
	40035	 2.455	 0.735	 2.64	 -1.17	 1.0	 100.0	 1	 3.51	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.5143; % NG
	40035	 2.455	 0.735	 2.64	 -1.17	 1.0	 100.0	 1	 3.51	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.5143; % NG
	40036	 17.015	 2.7	 13.3	 -7.9	 1.0	 100.0	 1	 23.8	 10.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % PEL
	40036	 17.015	 2.7	 13.3	 -7.9	 1.0	 100.0	 1	 23.8	 10.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % NG
	40036	 17.015	 2.7	 13.3	 -7.9	 1.0	 100.0	 1	 23.8	 10.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % PEL
	40036	 17.015	 2.7	 13.3	 -7.9	 1.0	 100.0	 1	 23.8	 10.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % PEL
	40038	 14.85	 3.0	 13.3	 -7.3	 1.0	 100.0	 1	 22.0	 7.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % COW
	40038	 13.0	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 24.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % COW
	40040	 16.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	40040	 16.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	40040	 18.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	40040	 18.0	 2.25	 14.5	 -10.0	 1.0	 100.0	 1	 30.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0; % NG
	40040	 18.0	 2.25	 14.5	 -10.0	 1.0	 100.0	 1	 30.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0; % NG
	40041	 669.35	 70.85	 454.6	 -312.9	 1.0	 100.0	 1	 938.7	 400.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 938.7; % COW
	40041	 512.65	 0.0	 348.7	 -348.7	 1.0	 100.0	 1	 765.3	 260.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 765.3; % COW
	40041	 512.65	 0.0	 348.7	 -348.7	 1.0	 100.0	 1	 765.3	 260.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 765.3; % COW
	40042	 474.2	 85.7	 370.9	 -199.5	 1.0	 100.0	 1	 598.4	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 598.4; % NG
	40043	 546.55	 44.8	 287.3	 -197.7	 1.0	 100.0	 1	 593.1	 500.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40043	 0.0	 0.0	 287.3	 -197.7	 1.0	 100.0	 0	 593.1	 500.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	40044	 161.25	 30.45	 131.7	 -70.8	 1.0	 100.0	 1	 212.5	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.5; % COW
	40044	 96.0	 17.45	 75.6	 -40.7	 1.0	 100.0	 1	 122.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % COW
	40045	 208.0	 24.15	 155.0	 -106.7	 1.0	 100.0	 1	 320.0	 96.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 320.0; % NG
	40045	 165.0	 30.05	 130.1	 -70.0	 1.0	 100.0	 1	 210.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 210.0; % NG
	40046	 102.75	 15.5	 99.5	 -68.5	 1.0	 100.0	 1	 205.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40047	 147.0	 29.2	 126.4	 -68.0	 1.0	 100.0	 1	 204.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0; % NG
	40047	 147.0	 29.2	 126.4	 -68.0	 1.0	 100.0	 1	 204.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0; % NG
	40048	 101.0	 15.15	 97.3	 -67.0	 1.0	 100.0	 1	 201.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40049	 206.0	 35.8	 154.9	 -83.3	 1.0	 100.0	 1	 250.0	 162.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 250.0; % NG
	40049	 142.5	 28.2	 122.1	 -65.7	 1.0	 100.0	 1	 197.0	 88.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0; % NG
	40049	 142.5	 28.2	 122.1	 -65.7	 1.0	 100.0	 1	 197.0	 88.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0; % NG
	40050	 97.95	 14.15	 73.9	 -45.6	 1.0	 100.0	 1	 136.9	 59.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.9; % COW
	40050	 144.45	 26.9	 116.4	 -62.6	 1.0	 100.0	 1	 187.9	 101.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.9; % NG
	40052	 74.4	 0.0	 65.6	 -65.6	 1.0	 100.0	 1	 148.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	40053	 98.9	 10.0	 64.3	 -44.3	 1.0	 100.0	 1	 132.8	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.8; % COW
	40053	 103.75	 24.0	 103.8	 -55.8	 1.0	 100.0	 1	 167.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.5; % PEL
	40053	 103.75	 24.0	 103.8	 -55.8	 1.0	 100.0	 1	 167.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.5; % COW
	40055	 20.375	 2.95	 15.5	 -9.6	 1.0	 100.0	 1	 28.8	 11.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % NG
	40055	 22.56	 4.2	 20.03	 -11.63	 1.0	 100.0	 1	 34.87	 10.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.8667; % NG
	40055	 22.56	 4.2	 20.03	 -11.63	 1.0	 100.0	 1	 34.87	 10.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.8667; % PEL
	40055	 22.56	 4.2	 20.03	 -11.63	 1.0	 100.0	 1	 34.87	 10.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.8667; % NG
	40055	 52.8	 11.7	 50.6	 -27.2	 1.0	 100.0	 1	 81.6	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % COW
	40056	 54.35	 0.0	 45.6	 -45.6	 1.0	 100.0	 1	 103.5	 5.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40057	 50.25	 0.0	 44.3	 -44.3	 1.0	 100.0	 1	 100.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40059	 50.75	 13.05	 59.6	 -33.5	 1.0	 100.0	 1	 100.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	40060	 16.125	 0.0	 8.12	 -8.12	 1.0	 100.0	 1	 24.75	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.75; % PEL
	40060	 16.125	 0.0	 8.12	 -8.12	 1.0	 100.0	 1	 24.75	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.75; % PEL
	40060	 16.125	 0.0	 8.12	 -8.12	 1.0	 100.0	 1	 24.75	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.75; % COW
	40060	 16.125	 0.0	 8.12	 -8.12	 1.0	 100.0	 1	 24.75	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.75; % PEL
	40060	 34.5	 0.0	 17.7	 -17.7	 1.0	 100.0	 1	 54.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	40060	 15.0	 0.0	 8.2	 -8.2	 1.0	 100.0	 1	 25.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	40061	 49.5	 0.0	 43.7	 -43.7	 1.0	 100.0	 1	 99.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40062	 51.9	 0.0	 43.6	 -43.6	 1.0	 100.0	 1	 98.9	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40063	 67.15	 12.75	 55.3	 -29.8	 1.0	 100.0	 1	 89.3	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.3; % NG
	40063	 67.15	 12.75	 55.3	 -29.8	 1.0	 100.0	 1	 89.3	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.3; % PEL
	40063	 67.15	 12.75	 55.3	 -29.8	 1.0	 100.0	 1	 89.3	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.3; % NG
	40063	 67.15	 12.75	 55.3	 -29.8	 1.0	 100.0	 1	 89.3	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.3; % NG
	40063	 67.15	 12.75	 55.3	 -29.8	 1.0	 100.0	 1	 89.3	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.3; % NG
	40063	 67.15	 12.75	 55.3	 -29.8	 1.0	 100.0	 1	 89.3	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.3; % NG
	40065	 59.5	 6.35	 40.7	 -28.0	 1.0	 100.0	 1	 84.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.0; % NG
	40065	 58.0	 6.35	 40.7	 -28.0	 1.0	 100.0	 1	 84.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.0; % NG
	40065	 58.0	 6.35	 40.7	 -28.0	 1.0	 100.0	 1	 84.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.0; % NG
	40066	 52.5	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	40066	 52.5	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	40066	 282.25	 27.5	 176.5	 -121.5	 1.0	 100.0	 1	 364.5	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 364.5; % NG
	40066	 424.0	 42.15	 270.3	 -186.0	 1.0	 100.0	 1	 558.0	 290.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 558.0; % NG
	40067	 6.3	 2.525	 9.08	 -4.03	 1.0	 100.0	 1	 12.1	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.1; % PEL
	40067	 6.3	 2.525	 9.08	 -4.03	 1.0	 100.0	 1	 12.1	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.1; % COW
	40067	 6.3	 2.525	 9.08	 -4.03	 1.0	 100.0	 1	 12.1	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.1; % COW
	40067	 6.3	 2.525	 9.08	 -4.03	 1.0	 100.0	 1	 12.1	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.1; % NG
	40067	 6.3	 2.525	 9.08	 -4.03	 1.0	 100.0	 1	 12.1	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.1; % NG
	40067	 6.3	 2.525	 9.08	 -4.03	 1.0	 100.0	 1	 12.1	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.1; % PEL
	40068	 10.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	40068	 10.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	40068	 10.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	40068	 10.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	40070	 15.0	 5.25	 18.8	 -8.3	 1.0	 100.0	 1	 25.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	40070	 39.0	 13.65	 49.1	 -21.8	 1.0	 100.0	 1	 65.5	 12.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.5; % PEL
	40070	 32.0	 11.25	 40.5	 -18.0	 1.0	 100.0	 1	 54.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	40071	 33.75	 8.95	 38.7	 -20.8	 1.0	 100.0	 1	 62.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.5; % NG
	40072	 35.6	 4.6	 29.6	 -20.4	 1.0	 100.0	 1	 61.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.2; % NG
	40074	 44.35	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	40074	 37.85	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % PEL
	40074	 37.85	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % PEL
	40074	 37.85	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % PEL
	40075	 43.2	 7.8	 33.7	 -18.1	 1.0	 100.0	 1	 54.4	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.4; % NG
	40075	 59.0	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 43.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	40076	 25.5	 0.0	 20.2	 -20.2	 1.0	 100.0	 1	 51.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40077	 32.5	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	40079	 25.5	 0.0	 19.8	 -19.8	 1.0	 100.0	 1	 50.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	40080	 24.75	 0.0	 19.6	 -19.6	 1.0	 100.0	 1	 49.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40081	 25.0	 10.25	 36.8	 -16.3	 1.0	 100.0	 1	 49.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0; % NG
	40082	 11.335	 2.285	 9.9	 -5.33	 1.0	 100.0	 1	 16.0	 6.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	40082	 11.335	 2.285	 9.9	 -5.33	 1.0	 100.0	 1	 16.0	 6.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	40082	 11.335	 2.285	 9.9	 -5.33	 1.0	 100.0	 1	 16.0	 6.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % COW
	40082	 17.5	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	40082	 150.65	 27.4	 118.6	 -63.8	 1.0	 100.0	 1	 191.3	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 191.3; % NG
	40083	 3.225	 0.945	 3.4	 -1.51	 1.0	 100.0	 1	 4.53	 1.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.5333; % NG
	40083	 3.225	 0.945	 3.4	 -1.51	 1.0	 100.0	 1	 4.53	 1.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.5333; % PEL
	40083	 3.225	 0.945	 3.4	 -1.51	 1.0	 100.0	 1	 4.53	 1.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.5333; % NG
	40083	 3.225	 0.945	 3.4	 -1.51	 1.0	 100.0	 1	 4.53	 1.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.5333; % NG
	40083	 3.225	 0.945	 3.4	 -1.51	 1.0	 100.0	 1	 4.53	 1.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.5333; % NG
	40083	 3.225	 0.945	 3.4	 -1.51	 1.0	 100.0	 1	 4.53	 1.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.5333; % PEL
	40083	 3.225	 0.945	 3.4	 -1.51	 1.0	 100.0	 1	 4.53	 1.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.5333; % PEL
	40083	 3.225	 0.945	 3.4	 -1.51	 1.0	 100.0	 1	 4.53	 1.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.5333; % PEL
	40083	 3.225	 0.945	 3.4	 -1.51	 1.0	 100.0	 1	 4.53	 1.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.5333; % PEL
	40084	 24.5	 2.8	 17.9	 -12.3	 1.0	 100.0	 1	 37.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.0; % NG
	40086	 19.15	 5.05	 21.9	 -11.8	 1.0	 100.0	 1	 35.3	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.3; % PEL
	40086	 19.25	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % COW
	40089	 19.45	 2.4	 15.4	 -10.6	 1.0	 100.0	 1	 31.9	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.9; % NG
	40090	 3.42	 1.22	 4.38	 -1.94	 1.0	 100.0	 1	 5.84	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.84; % NG
	40090	 3.42	 1.22	 4.38	 -1.94	 1.0	 100.0	 1	 5.84	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.84; % NG
	40090	 3.42	 1.22	 4.38	 -1.94	 1.0	 100.0	 1	 5.84	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.84; % NG
	40090	 3.42	 1.22	 4.38	 -1.94	 1.0	 100.0	 1	 5.84	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.84; % PEL
	40090	 3.42	 1.22	 4.38	 -1.94	 1.0	 100.0	 1	 5.84	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.84; % PEL
	40091	 20.375	 2.95	 15.5	 -9.6	 1.0	 100.0	 1	 28.8	 11.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % PEL
	40092	 15.8	 3.95	 17.1	 -9.2	 1.0	 100.0	 1	 27.6	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.6; % NG
	40092	 23.75	 5.95	 25.7	 -13.8	 1.0	 100.0	 1	 41.5	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.5; % NG
	40093	 4.42	 0.825	 3.95	 -2.3	 1.0	 100.0	 1	 6.88	 1.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.875; % NG
	40093	 4.42	 0.825	 3.95	 -2.3	 1.0	 100.0	 1	 6.88	 1.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.875; % NG
	40093	 4.42	 0.825	 3.95	 -2.3	 1.0	 100.0	 1	 6.88	 1.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.875; % NG
	40093	 4.42	 0.825	 3.95	 -2.3	 1.0	 100.0	 1	 6.88	 1.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.875; % NG
	40095	 9.125	 2.325	 9.05	 -4.4	 1.0	 100.0	 1	 13.25	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.25; % NG
	40095	 9.125	 2.325	 9.05	 -4.4	 1.0	 100.0	 1	 13.25	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.25; % PEL
	40097	 6.75	 2.625	 9.4	 -4.15	 1.0	 100.0	 1	 12.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5; % NG
	40097	 6.75	 2.625	 9.4	 -4.15	 1.0	 100.0	 1	 12.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5; % NG
	40098	 20.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	40099	 20.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	40100	 12.65	 0.0	 9.9	 -9.9	 1.0	 100.0	 1	 25.0	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40101	 6.05	 0.0	 4.75	 -4.75	 1.0	 100.0	 1	 12.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	40101	 6.05	 0.0	 4.75	 -4.75	 1.0	 100.0	 1	 12.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40103	 8.75	 1.65	 7.15	 -3.85	 1.0	 100.0	 1	 11.5	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5; % NG
	40103	 8.75	 1.65	 7.15	 -3.85	 1.0	 100.0	 1	 11.5	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5; % NG
	40104	 11.6	 0.0	 8.7	 -8.7	 1.0	 100.0	 1	 21.9	 1.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	40105	 2.375	 0.76	 2.72	 -1.2	 1.0	 100.0	 1	 3.62	 1.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6167; % NG
	40105	 2.375	 0.76	 2.72	 -1.2	 1.0	 100.0	 1	 3.62	 1.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6167; % NG
	40105	 2.375	 0.76	 2.72	 -1.2	 1.0	 100.0	 1	 3.62	 1.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6167; % PEL
	40105	 2.375	 0.76	 2.72	 -1.2	 1.0	 100.0	 1	 3.62	 1.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6167; % NG
	40105	 2.375	 0.76	 2.72	 -1.2	 1.0	 100.0	 1	 3.62	 1.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6167; % NG
	40105	 2.375	 0.76	 2.72	 -1.2	 1.0	 100.0	 1	 3.62	 1.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6167; % PEL
	40106	 12.85	 2.4	 11.5	 -6.7	 1.0	 100.0	 1	 20.0	 5.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	40107	 10.5	 0.0	 7.9	 -7.9	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40109	 506.65	 100.4	 434.6	 -233.8	 1.0	 100.0	 1	 701.3	 312.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 701.3; % COW
	40110	 14.5	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	40110	 396.5	 0.0	 233.4	 -233.4	 1.0	 100.0	 1	 643.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	40110	 396.5	 0.0	 233.4	 -233.4	 1.0	 100.0	 1	 643.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	40111	 458.3	 88.3	 382.1	 -205.5	 1.0	 100.0	 1	 616.6	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 616.6; % COW
	40111	 0.0	 0.0	 382.1	 -205.5	 1.0	 100.0	 0	 616.6	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 616.6; % COW
	40112	 256.0	 29.2	 187.4	 -129.0	 1.0	 100.0	 1	 387.0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 387.0; % COW
	40113	 247.8	 26.1	 167.4	 -115.2	 1.0	 100.0	 1	 345.6	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 345.6; % NG
	40114	 0.0	 0.0	 153.8	 -105.9	 1.0	 100.0	 0	 317.6	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 317.6; % COW
	40114	 0.0	 0.0	 156.9	 -108.0	 1.0	 100.0	 0	 324.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 324.0; % NG
	40114	 0.0	 0.0	 185.4	 -99.7	 1.0	 100.0	 0	 299.2	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 299.2; % NG
	40114	 0.0	 0.0	 185.4	 -99.7	 1.0	 100.0	 0	 299.2	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 299.2; % COW
	40115	 171.05	 39.65	 171.7	 -92.4	 1.0	 100.0	 1	 277.1	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 277.1; % NG
	40115	 149.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	40115	 149.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	40116	 174.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	40116	 174.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	40116	 185.5	 31.65	 137.0	 -73.7	 1.0	 100.0	 1	 221.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 221.0; % NG
	40117	 126.15	 27.55	 119.2	 -64.1	 1.0	 100.0	 1	 192.3	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.3; % NG
	40118	 144.5	 26.8	 115.9	 -62.3	 1.0	 100.0	 1	 187.0	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.0; % NG
	40118	 144.5	 26.8	 115.9	 -62.3	 1.0	 100.0	 1	 187.0	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.0; % NG
	40118	 144.5	 26.8	 115.9	 -62.3	 1.0	 100.0	 1	 187.0	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.0; % NG
	40119	 142.75	 26.6	 115.0	 -61.8	 1.0	 100.0	 1	 185.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.5; % NG
	40119	 142.75	 26.6	 115.0	 -61.8	 1.0	 100.0	 1	 185.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.5; % NG
	40120	 24.4	 5.78	 23.62	 -12.06	 1.0	 100.0	 1	 36.2	 12.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.2; % NG
	40120	 24.4	 5.78	 23.62	 -12.06	 1.0	 100.0	 1	 36.2	 12.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.2; % NG
	40120	 24.4	 5.78	 23.62	 -12.06	 1.0	 100.0	 1	 36.2	 12.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.2; % NG
	40120	 24.4	 5.78	 23.62	 -12.06	 1.0	 100.0	 1	 36.2	 12.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.2; % NG
	40120	 24.4	 5.78	 23.62	 -12.06	 1.0	 100.0	 1	 36.2	 12.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.2; % PEL
	40120	 37.2	 7.8	 33.7	 -18.1	 1.0	 100.0	 1	 54.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.4; % NG
	40120	 53.3	 11.7	 50.6	 -27.2	 1.0	 100.0	 1	 81.6	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % NG
	40121	 146.15	 0.0	 25.3	 -25.3	 1.0	 100.0	 1	 177.3	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 177.3; % COW
	40121	 83.1	 0.0	 15.1	 -15.1	 1.0	 100.0	 1	 106.2	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.2; % NG
	40122	 136.7	 24.85	 107.5	 -57.8	 1.0	 100.0	 1	 173.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.4; % NG
	40122	 136.7	 24.85	 107.5	 -57.8	 1.0	 100.0	 1	 173.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.4; % NG
	40123	 0.0	 0.0	 104.1	 -56.0	 1.0	 100.0	 0	 167.9	 77.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.9; % NG
	40123	 0.0	 0.0	 104.1	 -56.0	 1.0	 100.0	 0	 167.9	 77.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.9; % NG
	40123	 0.0	 0.0	 104.1	 -56.0	 1.0	 100.0	 0	 167.9	 77.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.9; % NG
	40123	 0.0	 0.0	 104.1	 -56.0	 1.0	 100.0	 0	 167.9	 77.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.9; % NG
	40123	 0.0	 0.0	 166.5	 -89.5	 1.0	 100.0	 0	 268.6	 124.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 268.6; % NG
	40123	 196.4	 38.5	 166.5	 -89.5	 1.0	 100.0	 1	 268.6	 124.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 268.6; % NG
	40124	 72.6	 0.0	 64.0	 -64.0	 1.0	 100.0	 1	 145.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	40125	 0.0	 0.0	 84.3	 -45.3	 1.0	 100.0	 0	 136.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % NG
	40125	 0.0	 0.0	 84.3	 -45.3	 1.0	 100.0	 0	 136.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % COW
	40127	 70.8	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % NG
	40127	 70.8	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % NG
	40128	 72.7	 19.9	 71.6	 -31.8	 1.0	 100.0	 1	 95.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.4; % NG
	40128	 72.7	 19.9	 71.6	 -31.8	 1.0	 100.0	 1	 95.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.4; % NG
	40128	 72.7	 19.9	 71.6	 -31.8	 1.0	 100.0	 1	 95.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.4; % NG
	40128	 72.7	 19.9	 71.6	 -31.8	 1.0	 100.0	 1	 95.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.4; % NG
	40129	 57.7	 19.9	 71.6	 -31.8	 1.0	 100.0	 1	 95.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.4; % NG
	40129	 57.7	 19.9	 71.6	 -31.8	 1.0	 100.0	 1	 95.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.4; % NG
	40129	 57.7	 19.9	 71.6	 -31.8	 1.0	 100.0	 1	 95.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.4; % NG
	40129	 57.7	 19.9	 71.6	 -31.8	 1.0	 100.0	 1	 95.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.4; % NG
	40130	 0.0	 0.0	 71.6	 -31.8	 1.0	 100.0	 0	 95.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.4; % NG
	40130	 0.0	 0.0	 71.6	 -31.8	 1.0	 100.0	 0	 95.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.4; % NG
	40130	 0.0	 0.0	 71.6	 -31.8	 1.0	 100.0	 0	 95.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.4; % NG
	40130	 0.0	 0.0	 71.6	 -31.8	 1.0	 100.0	 0	 95.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.4; % NG
	40131	 45.6	 4.6	 29.6	 -20.4	 1.0	 100.0	 1	 61.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.2; % NG
	40131	 45.6	 4.6	 29.6	 -20.4	 1.0	 100.0	 1	 61.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.2; % NG
	40131	 45.6	 4.6	 29.6	 -20.4	 1.0	 100.0	 1	 61.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.2; % NG
	40131	 45.6	 4.6	 29.6	 -20.4	 1.0	 100.0	 1	 61.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.2; % NG
	40131	 0.0	 0.0	 56.3	 -30.3	 1.0	 100.0	 0	 90.9	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.9; % NG
	40132	 66.5	 11.85	 51.4	 -27.7	 1.0	 100.0	 1	 83.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.0; % COW
	40133	 44.5	 5.2	 33.4	 -23.0	 1.0	 100.0	 1	 69.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % NG
	40133	 243.5	 26.5	 170.0	 -117.0	 1.0	 100.0	 1	 351.0	 136.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 351.0; % NG
	40133	 254.35	 31.25	 200.4	 -137.9	 1.0	 100.0	 1	 413.7	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 413.7; % NG
	40134	 34.7	 5.1	 32.8	 -22.6	 1.0	 100.0	 1	 67.7	 1.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	40137	 14.61	 2.665	 10.45	 -5.12	 1.0	 100.0	 1	 15.4	 13.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.4; % NG
	40137	 14.61	 2.665	 10.45	 -5.12	 1.0	 100.0	 1	 15.4	 13.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.4; % NG
	40137	 14.61	 2.665	 10.45	 -5.12	 1.0	 100.0	 1	 15.4	 13.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.4; % COW
	40137	 14.61	 2.665	 10.45	 -5.12	 1.0	 100.0	 1	 15.4	 13.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.4; % NG
	40137	 20.75	 4.45	 16.1	 -7.2	 1.0	 100.0	 1	 21.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.5; % PEL
	40139	 52.8	 11.7	 50.6	 -27.2	 1.0	 100.0	 1	 81.6	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % NG
	40139	 35.5	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % COW
	40139	 242.75	 26.5	 169.8	 -116.8	 1.0	 100.0	 1	 350.5	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 350.5; % NG
	40139	 429.0	 85.2	 368.7	 -198.3	 1.0	 100.0	 1	 595.0	 263.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 595.0; % COW
	40140	 27.0	 11.25	 40.5	 -18.0	 1.0	 100.0	 1	 54.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	40141	 28.3	 0.0	 21.3	 -21.3	 1.0	 100.0	 1	 54.0	 2.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40142	 39.05	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1; % NG
	40142	 39.05	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1; % NG
	40143	 89.8	 21.4	 92.7	 -49.9	 1.0	 100.0	 1	 149.6	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 149.6; % NG
	40143	 48.3	 11.7	 50.6	 -27.2	 1.0	 100.0	 1	 81.6	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % NG
	40143	 30.5	 10.4	 37.5	 -16.7	 1.0	 100.0	 1	 50.0	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	40143	 39.5	 14.4	 51.8	 -23.0	 1.0	 100.0	 1	 69.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % PEL
	40143	 73.0	 13.05	 56.4	 -30.3	 1.0	 100.0	 1	 91.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.0; % NG
	40144	 28.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	40144	 28.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	40144	 79.25	 7.8	 50.1	 -34.5	 1.0	 100.0	 1	 103.5	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5; % NG
	40145	 25.85	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.7	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.7; % PEL
	40147	 43.35	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % PEL
	40147	 42.35	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	40147	 22.25	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.5	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % COW
	40147	 48.19	 9.05	 43.1	 -25.0	 1.0	 100.0	 1	 75.0	 21.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	40147	 48.19	 9.05	 43.1	 -25.0	 1.0	 100.0	 1	 75.0	 21.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	40148	 28.3	 7.4	 26.6	 -11.8	 1.0	 100.0	 1	 35.5	 21.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.5; % PEL
	40148	 28.1	 7.4	 26.6	 -11.8	 1.0	 100.0	 1	 35.5	 20.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.5; % NG
	40149	 5.525	 0.685	 4.32	 -2.95	 1.0	 100.0	 1	 8.82	 2.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.825; % NG
	40149	 5.525	 0.685	 4.32	 -2.95	 1.0	 100.0	 1	 8.82	 2.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.825; % COW
	40149	 5.525	 0.685	 4.32	 -2.95	 1.0	 100.0	 1	 8.82	 2.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.825; % NG
	40149	 5.525	 0.685	 4.32	 -2.95	 1.0	 100.0	 1	 8.82	 2.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.825; % NG
	40151	 18.5	 5.0	 21.7	 -11.7	 1.0	 100.0	 1	 35.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % NG
	40152	 7.05	 0.85	 5.47	 -3.77	 1.0	 100.0	 1	 11.3	 2.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.3; % PEL
	40152	 7.05	 0.85	 5.47	 -3.77	 1.0	 100.0	 1	 11.3	 2.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.3; % COW
	40152	 7.05	 0.85	 5.47	 -3.77	 1.0	 100.0	 1	 11.3	 2.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.3; % NG
	40153	 6.1	 1.485	 6.6	 -3.63	 1.0	 100.0	 1	 10.87	 1.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8667; % PEL
	40153	 6.1	 1.485	 6.6	 -3.63	 1.0	 100.0	 1	 10.87	 1.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8667; % NG
	40153	 6.1	 1.485	 6.6	 -3.63	 1.0	 100.0	 1	 10.87	 1.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8667; % NG
	40155	 2.365	 0.82	 2.95	 -1.31	 1.0	 100.0	 1	 3.93	 0.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.925; % NG
	40155	 2.365	 0.82	 2.95	 -1.31	 1.0	 100.0	 1	 3.93	 0.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.925; % NG
	40155	 2.365	 0.82	 2.95	 -1.31	 1.0	 100.0	 1	 3.93	 0.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.925; % NG
	40155	 2.365	 0.82	 2.95	 -1.31	 1.0	 100.0	 1	 3.93	 0.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.925; % NG
	40155	 2.365	 0.82	 2.95	 -1.31	 1.0	 100.0	 1	 3.93	 0.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.925; % NG
	40155	 2.365	 0.82	 2.95	 -1.31	 1.0	 100.0	 1	 3.93	 0.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.925; % NG
	40155	 2.365	 0.82	 2.95	 -1.31	 1.0	 100.0	 1	 3.93	 0.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.925; % NG
	40155	 2.365	 0.82	 2.95	 -1.31	 1.0	 100.0	 1	 3.93	 0.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.925; % NG
	40156	 10.6	 1.775	 8.6	 -5.05	 1.0	 100.0	 1	 15.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.2; % NG
	40156	 10.6	 1.775	 8.6	 -5.05	 1.0	 100.0	 1	 15.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.2; % COW
	40157	 15.0	 0.0	 11.9	 -11.9	 1.0	 100.0	 1	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40158	 15.0	 0.0	 11.9	 -11.9	 1.0	 100.0	 1	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	40158	 49.5	 0.0	 43.7	 -43.7	 1.0	 100.0	 1	 99.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	40160	 15.5	 2.3	 11.3	 -6.7	 1.0	 100.0	 1	 20.0	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	40160	 15.0	 2.3	 11.3	 -6.7	 1.0	 100.0	 1	 20.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	40160	 21.1	 3.9	 16.9	 -9.1	 1.0	 100.0	 1	 27.2	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.2; % NG
	40162	 17.15	 5.1	 18.4	 -8.2	 1.0	 100.0	 1	 24.5	 9.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.5; % PEL
	40163	 13.3	 3.35	 14.6	 -7.9	 1.0	 100.0	 1	 23.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.6; % NG
	40164	 1.81	 0.0	 1.0	 -1.0	 1.0	 100.0	 1	 2.9	 0.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9; % NG
	40164	 1.81	 0.0	 1.0	 -1.0	 1.0	 100.0	 1	 2.9	 0.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9; % NG
	40164	 1.81	 0.0	 1.0	 -1.0	 1.0	 100.0	 1	 2.9	 0.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9; % NG
	40164	 1.81	 0.0	 1.0	 -1.0	 1.0	 100.0	 1	 2.9	 0.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9; % PEL
	40164	 1.81	 0.0	 1.0	 -1.0	 1.0	 100.0	 1	 2.9	 0.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9; % NG
	40164	 1.81	 0.0	 1.0	 -1.0	 1.0	 100.0	 1	 2.9	 0.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9; % PEL
	40164	 1.81	 0.0	 1.0	 -1.0	 1.0	 100.0	 1	 2.9	 0.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9; % NG
	40164	 1.81	 0.0	 1.0	 -1.0	 1.0	 100.0	 1	 2.9	 0.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9; % NG
	40165	 3.915	 1.535	 5.5	 -2.43	 1.0	 100.0	 1	 7.33	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.3333; % PEL
	40165	 3.915	 1.535	 5.5	 -2.43	 1.0	 100.0	 1	 7.33	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.3333; % NG
	40165	 3.915	 1.535	 5.5	 -2.43	 1.0	 100.0	 1	 7.33	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.3333; % PEL
	40166	 6.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0; % NG
	40166	 6.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0; % NG
	40167	 2.25	 0.75	 2.7	 -1.2	 1.0	 100.0	 1	 3.6	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6; % NG
	40167	 2.25	 0.75	 2.7	 -1.2	 1.0	 100.0	 1	 3.6	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6; % NG
	40167	 2.25	 0.75	 2.7	 -1.2	 1.0	 100.0	 1	 3.6	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6; % PEL
	40167	 2.25	 0.75	 2.7	 -1.2	 1.0	 100.0	 1	 3.6	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6; % NG
	40167	 2.25	 0.75	 2.7	 -1.2	 1.0	 100.0	 1	 3.6	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6; % NG
	40167	 2.25	 0.75	 2.7	 -1.2	 1.0	 100.0	 1	 3.6	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6; % NG
	40168	 6.93	 1.45	 5.2	 -2.3	 1.0	 100.0	 1	 6.93	 6.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.9333; % NG
	40168	 6.93	 1.45	 5.2	 -2.3	 1.0	 100.0	 1	 6.93	 6.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.9333; % NG
	40168	 6.93	 1.45	 5.2	 -2.3	 1.0	 100.0	 1	 6.93	 6.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.9333; % PEL
	40169	 2.5	 1.035	 3.75	 -1.68	 1.0	 100.0	 1	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.0; % NG
	40169	 2.5	 1.035	 3.75	 -1.68	 1.0	 100.0	 1	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.0; % NG
	40169	 2.5	 1.035	 3.75	 -1.68	 1.0	 100.0	 1	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.0; % PEL
	40169	 2.5	 1.035	 3.75	 -1.68	 1.0	 100.0	 1	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.0; % NG
	40170	 6.0	 2.075	 7.5	 -3.35	 1.0	 100.0	 1	 10.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % NG
	40170	 6.0	 2.075	 7.5	 -3.35	 1.0	 100.0	 1	 10.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % NG
	40171	 13.5	 2.7	 12.1	 -6.7	 1.0	 100.0	 1	 20.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	40171	 23.29	 4.7	 20.9	 -11.5	 1.0	 100.0	 1	 34.5	 12.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.5; % NG
	40171	 14.0	 3.15	 14.0	 -7.7	 1.0	 100.0	 1	 23.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % PEL
	40171	 27.5	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	40171	 27.5	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	46843	 596.25	 0.0	 309.8	 -309.8	 1.0	 100.0	 1	 942.5	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	46843	 0.0	 0.0	 437.1	 -300.8	 1.0	 100.0	 0	 902.5	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NUC
	46844	 550.0	 67.95	 435.9	 -300.0	 1.0	 100.0	 1	 900.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 900.0; % COW
	46844	 0.0	 0.0	 435.9	 -300.0	 1.0	 100.0	 0	 900.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 900.0; % NG
	46845	 560.0	 67.95	 435.9	 -300.0	 1.0	 100.0	 1	 900.0	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 900.0; % COW
	46845	 560.0	 67.95	 435.9	 -300.0	 1.0	 100.0	 1	 900.0	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 900.0; % NG
	46846	 510.0	 54.35	 348.7	 -240.0	 1.0	 100.0	 1	 720.0	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 720.0; % NG
	46847	 369.0	 42.15	 270.3	 -186.0	 1.0	 100.0	 1	 558.0	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 558.0; % NG
	46848	 337.65	 41.15	 263.8	 -181.5	 1.0	 100.0	 1	 544.6	 130.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 544.6; % COW
	46848	 210.015	 33.6	 186.9	 -119.7	 1.0	 100.0	 1	 359.0	 61.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 359.0; % NG
	46849	 192.0	 18.25	 117.2	 -80.7	 1.0	 100.0	 1	 242.0	 142.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 242.0; % NG
	46849	 192.0	 18.25	 117.2	 -80.7	 1.0	 100.0	 1	 242.0	 142.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 242.0; % COW
	46849	 172.5	 19.8	 126.9	 -87.3	 1.0	 100.0	 1	 262.0	 83.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 262.0; % NG
	46850	 171.25	 40.15	 173.8	 -93.5	 1.0	 100.0	 1	 280.5	 62.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 280.5; % NG
	46850	 149.65	 28.55	 123.5	 -66.4	 1.0	 100.0	 1	 199.3	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.3; % NG
	46850	 149.65	 28.55	 123.5	 -66.4	 1.0	 100.0	 1	 199.3	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.3; % NG
	46851	 176.0	 23.9	 153.5	 -105.7	 1.0	 100.0	 1	 317.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 317.0; % NG
	46851	 139.45	 15.0	 96.3	 -66.3	 1.0	 100.0	 1	 198.9	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	46851	 139.45	 15.0	 96.3	 -66.3	 1.0	 100.0	 1	 198.9	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	46853	 133.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	46853	 197.5	 36.5	 158.0	 -85.0	 1.0	 100.0	 1	 255.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 255.0; % NG
	46853	 197.5	 36.5	 158.0	 -85.0	 1.0	 100.0	 1	 255.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 255.0; % COW
	46853	 197.5	 36.5	 158.0	 -85.0	 1.0	 100.0	 1	 255.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 255.0; % COW
	46853	 133.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	46853	 133.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	46853	 133.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	46853	 133.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	46853	 133.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	46853	 133.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % COW
	46853	 133.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	46853	 197.5	 36.5	 158.0	 -85.0	 1.0	 100.0	 1	 255.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 255.0; % NG
	46854	 139.9	 11.7	 75.0	 -51.6	 1.0	 100.0	 1	 154.8	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 154.8; % COW
	46855	 85.5	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % NG
	46857	 72.5	 17.2	 74.4	 -40.0	 1.0	 100.0	 1	 120.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0; % NG
	46858	 63.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	46858	 63.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	46858	 64.0	 12.6	 54.5	 -29.3	 1.0	 100.0	 1	 88.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.0; % NG
	46858	 64.0	 12.6	 54.5	 -29.3	 1.0	 100.0	 1	 88.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.0; % PEL
	46860	 97.625	 18.2	 88.5	 -52.1	 1.0	 100.0	 1	 156.2	 39.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.2; % NG
	46860	 44.33	 8.35	 39.7	 -23.0	 1.0	 100.0	 1	 69.0	 19.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % PEL
	46861	 44.33	 8.35	 39.7	 -23.0	 1.0	 100.0	 1	 69.0	 19.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % NG
	46861	 44.33	 8.35	 39.7	 -23.0	 1.0	 100.0	 1	 69.0	 19.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % NG
	46862	 38.0	 0.0	 18.4	 -18.4	 1.0	 100.0	 1	 56.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.0; % PEL
	46862	 38.0	 0.0	 18.4	 -18.4	 1.0	 100.0	 1	 56.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.0; % PEL
	46863	 39.0	 7.3	 31.6	 -17.0	 1.0	 100.0	 1	 51.0	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0; % NG
	46863	 39.0	 7.3	 31.6	 -17.0	 1.0	 100.0	 1	 51.0	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0; % NG
	46863	 39.0	 7.3	 31.6	 -17.0	 1.0	 100.0	 1	 51.0	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0; % NG
	46863	 39.0	 7.3	 31.6	 -17.0	 1.0	 100.0	 1	 51.0	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0; % NG
	46863	 39.0	 7.3	 31.6	 -17.0	 1.0	 100.0	 1	 51.0	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0; % NG
	46863	 39.0	 7.3	 31.6	 -17.0	 1.0	 100.0	 1	 51.0	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0; % NG
	46863	 68.5	 7.95	 50.9	 -35.0	 1.0	 100.0	 1	 105.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0; % NG
	46863	 68.5	 7.95	 50.9	 -35.0	 1.0	 100.0	 1	 105.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0; % NG
	46863	 58.75	 11.95	 51.7	 -27.8	 1.0	 100.0	 1	 83.5	 34.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.5; % NG
	46864	 31.5	 0.0	 15.8	 -15.8	 1.0	 100.0	 1	 48.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.0; % NG
	46864	 31.5	 0.0	 15.8	 -15.8	 1.0	 100.0	 1	 48.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.0; % NG
	46866	 25.1	 3.05	 19.5	 -13.4	 1.0	 100.0	 1	 40.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.2; % NG
	46866	 25.1	 3.05	 19.5	 -13.4	 1.0	 100.0	 1	 40.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.2; % NG
	46868	 74.69	 13.95	 67.7	 -39.8	 1.0	 100.0	 1	 119.5	 29.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.5; % NG
	46868	 298.75	 79.1	 342.4	 -184.2	 1.0	 100.0	 1	 552.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 552.5; % COW
	46868	 25.7	 4.85	 23.0	 -13.3	 1.0	 100.0	 1	 40.0	 11.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % COW
	46868	 25.7	 4.85	 23.0	 -13.3	 1.0	 100.0	 1	 40.0	 11.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	46869	 21.5	 0.0	 9.2	 -9.2	 1.0	 100.0	 1	 28.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0; % NG
	46869	 27.5	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 40.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	46870	 25.0	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 40.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % PEL
	46870	 25.0	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 40.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % COW
	46870	 25.0	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 40.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % PEL
	46870	 25.0	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 40.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	46870	 27.5	 0.0	 14.8	 -14.8	 1.0	 100.0	 1	 45.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	46870	 27.5	 0.0	 14.8	 -14.8	 1.0	 100.0	 1	 45.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % PEL
	46870	 27.5	 0.0	 14.8	 -14.8	 1.0	 100.0	 1	 45.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	46870	 27.5	 0.0	 14.8	 -14.8	 1.0	 100.0	 1	 45.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	46871	 28.75	 2.85	 18.2	 -12.5	 1.0	 100.0	 1	 37.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % COW
	46871	 28.75	 2.85	 18.2	 -12.5	 1.0	 100.0	 1	 37.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % NG
	46872	 5.9	 0.0	 3.53	 -3.53	 1.0	 100.0	 1	 10.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8; % NG
	46872	 5.9	 0.0	 3.53	 -3.53	 1.0	 100.0	 1	 10.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8; % NG
	46872	 5.9	 0.0	 3.53	 -3.53	 1.0	 100.0	 1	 10.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8; % PEL
	46873	 5.9	 0.0	 3.53	 -3.53	 1.0	 100.0	 1	 10.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8; % PEL
	46873	 5.9	 0.0	 3.53	 -3.53	 1.0	 100.0	 1	 10.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8; % NG
	46873	 5.9	 0.0	 3.53	 -3.53	 1.0	 100.0	 1	 10.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8; % PEL
	46874	 21.5	 2.15	 13.6	 -9.3	 1.0	 100.0	 1	 28.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0; % NG
	46874	 21.5	 2.15	 13.6	 -9.3	 1.0	 100.0	 1	 28.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0; % NG
	46875	 97.625	 18.2	 88.5	 -52.1	 1.0	 100.0	 1	 156.2	 39.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.2; % NG
	46875	 17.025	 3.2	 15.2	 -8.8	 1.0	 100.0	 1	 26.5	 7.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.5; % NG
	46878	 13.35	 1.7	 11.0	 -7.6	 1.0	 100.0	 1	 22.7	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.7; % NG
	46878	 13.35	 1.7	 11.0	 -7.6	 1.0	 100.0	 1	 22.7	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.7; % NG
	46883	 11.5	 0.0	 6.6	 -6.6	 1.0	 100.0	 1	 20.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	46884	 699.9	 90.6	 581.1	 -399.9	 1.0	 100.0	 1	 1199.8	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	46885	 569.75	 78.2	 501.7	 -345.3	 1.0	 100.0	 1	 1035.9	 103.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NUC
	46886	 482.35	 0.0	 284.8	 -284.8	 1.0	 100.0	 1	 720.7	 244.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 720.7; % COW
	46887	 363.0	 47.25	 303.2	 -208.7	 1.0	 100.0	 1	 626.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 626.0; % NG
	46888	 94.1	 23.35	 101.1	 -54.4	 1.0	 100.0	 1	 163.2	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2; % NG
	46888	 96.8	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % COW
	46888	 96.8	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % NG
	46888	 377.4	 69.05	 335.4	 -197.3	 1.0	 100.0	 1	 591.8	 163.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 591.8; % COW
	46888	 382.3	 71.7	 348.3	 -204.9	 1.0	 100.0	 1	 614.6	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 614.6; % COW
	46889	 250.25	 33.65	 215.8	 -148.5	 1.0	 100.0	 1	 445.5	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 445.5; % NG
	46889	 551.9	 100.8	 436.2	 -234.6	 1.0	 100.0	 1	 703.8	 400.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 703.8; % COW
	46889	 369.0	 42.15	 270.3	 -186.0	 1.0	 100.0	 1	 558.0	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 558.0; % COW
	46890	 36.45	 0.0	 13.5	 -13.5	 1.0	 100.0	 1	 41.0	 31.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.0; % COW
	46890	 285.25	 33.65	 215.8	 -148.5	 1.0	 100.0	 1	 445.5	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 445.5; % COW
	46890	 285.25	 33.65	 215.8	 -148.5	 1.0	 100.0	 1	 445.5	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 445.5; % COW
	46891	 143.85	 35.45	 153.5	 -82.6	 1.0	 100.0	 1	 247.7	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 247.7; % COW
	46891	 366.1	 83.35	 360.8	 -194.1	 1.0	 100.0	 1	 582.2	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 582.2; % COW
	46891	 222.35	 60.25	 260.7	 -140.2	 1.0	 100.0	 1	 420.7	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 420.7; % NG
	46892	 168.2	 37.9	 163.9	 -88.1	 1.0	 100.0	 1	 264.4	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 264.4; % NG
	46892	 168.2	 37.9	 163.9	 -88.1	 1.0	 100.0	 1	 264.4	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 264.4; % NG
	46892	 160.15	 30.8	 133.3	 -71.7	 1.0	 100.0	 1	 215.1	 105.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 215.1; % NG
	46892	 160.15	 30.8	 133.3	 -71.7	 1.0	 100.0	 1	 215.1	 105.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 215.1; % NG
	46892	 160.15	 30.8	 133.3	 -71.7	 1.0	 100.0	 1	 215.1	 105.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 215.1; % NG
	46892	 160.15	 30.8	 133.3	 -71.7	 1.0	 100.0	 1	 215.1	 105.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 215.1; % NG
	46893	 16.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	46893	 15.085	 3.6	 14.92	 -7.72	 1.0	 100.0	 1	 23.17	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1667; % PEL
	46893	 15.085	 3.6	 14.92	 -7.72	 1.0	 100.0	 1	 23.17	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1667; % NG
	46893	 15.085	 3.6	 14.92	 -7.72	 1.0	 100.0	 1	 23.17	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1667; % NG
	46893	 15.085	 3.6	 14.92	 -7.72	 1.0	 100.0	 1	 23.17	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1667; % NG
	46893	 15.085	 3.6	 14.92	 -7.72	 1.0	 100.0	 1	 23.17	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1667; % PEL
	46893	 15.085	 3.6	 14.92	 -7.72	 1.0	 100.0	 1	 23.17	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1667; % PEL
	46893	 15.085	 3.6	 14.92	 -7.72	 1.0	 100.0	 1	 23.17	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1667; % NG
	46893	 16.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	46893	 16.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	46893	 16.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	46893	 16.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	46893	 17.85	 4.1	 17.8	 -9.6	 1.0	 100.0	 1	 28.7	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.7; % PEL
	46893	 14.4	 4.55	 16.4	 -7.3	 1.0	 100.0	 1	 21.8	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.8; % PEL
	46893	 15.085	 3.6	 14.92	 -7.72	 1.0	 100.0	 1	 23.17	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1667; % PEL
	46893	 15.085	 3.6	 14.92	 -7.72	 1.0	 100.0	 1	 23.17	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1667; % PEL
	46894	 138.1	 26.65	 115.4	 -62.1	 1.0	 100.0	 1	 186.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 186.2; % NG
	46894	 190.05	 0.0	 78.9	 -78.9	 1.0	 100.0	 1	 240.1	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.1; % NG
	46894	 144.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	46894	 144.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	46895	 102.5	 27.95	 120.9	 -65.0	 1.0	 100.0	 1	 195.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.0; % NG
	46895	 104.0	 28.35	 122.7	 -66.0	 1.0	 100.0	 1	 198.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.0; % NG
	46895	 104.0	 28.35	 122.7	 -66.0	 1.0	 100.0	 1	 198.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.0; % NG
	46895	 104.0	 28.35	 122.7	 -66.0	 1.0	 100.0	 1	 198.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.0; % NG
	46895	 104.0	 28.35	 122.7	 -66.0	 1.0	 100.0	 1	 198.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.0; % COW
	46896	 147.5	 27.95	 120.9	 -65.0	 1.0	 100.0	 1	 195.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.0; % NG
	46896	 147.5	 27.95	 120.9	 -65.0	 1.0	 100.0	 1	 195.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.0; % NG
	46896	 61.5	 14.75	 63.8	 -34.3	 1.0	 100.0	 1	 103.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.0; % NG
	46897	 146.55	 34.85	 150.7	 -81.0	 1.0	 100.0	 1	 243.1	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 243.1; % NG
	46897	 154.35	 27.0	 116.9	 -62.9	 1.0	 100.0	 1	 188.7	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.7; % NG
	46897	 154.35	 27.0	 116.9	 -62.9	 1.0	 100.0	 1	 188.7	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.7; % NG
	46897	 154.35	 27.0	 116.9	 -62.9	 1.0	 100.0	 1	 188.7	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.7; % NG
	46897	 81.8	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % NG
	46898	 148.5	 26.8	 115.9	 -62.3	 1.0	 100.0	 1	 187.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.0; % NG
	46898	 148.5	 26.8	 115.9	 -62.3	 1.0	 100.0	 1	 187.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.0; % NG
	46898	 103.0	 28.1	 121.5	 -65.3	 1.0	 100.0	 1	 196.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.0; % NG
	46899	 143.5	 26.35	 114.0	 -61.3	 1.0	 100.0	 1	 184.0	 103.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.0; % NG
	46899	 143.5	 26.35	 114.0	 -61.3	 1.0	 100.0	 1	 184.0	 103.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.0; % NG
	46899	 157.0	 36.7	 158.7	 -85.3	 1.0	 100.0	 1	 256.0	 58.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 256.0; % NG
	46900	 136.65	 25.65	 111.1	 -59.8	 1.0	 100.0	 1	 179.3	 94.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.3; % NG
	46900	 136.65	 25.65	 111.1	 -59.8	 1.0	 100.0	 1	 179.3	 94.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.3; % NG
	46900	 136.65	 25.65	 111.1	 -59.8	 1.0	 100.0	 1	 179.3	 94.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.3; % NG
	46900	 96.5	 17.45	 75.6	 -40.7	 1.0	 100.0	 1	 122.0	 71.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % NG
	46900	 96.5	 17.45	 75.6	 -40.7	 1.0	 100.0	 1	 122.0	 71.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % COW
	46900	 96.5	 17.45	 75.6	 -40.7	 1.0	 100.0	 1	 122.0	 71.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % COW
	46901	 119.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	46901	 119.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	46901	 119.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % COW
	46901	 216.85	 51.35	 222.3	 -119.6	 1.0	 100.0	 1	 358.7	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 358.7; % NG
	46903	 108.6	 23.35	 101.1	 -54.4	 1.0	 100.0	 1	 163.2	 54.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2; % PEL
	46903	 137.2	 34.3	 148.4	 -79.8	 1.0	 100.0	 1	 239.4	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 239.4; % NG
	46903	 408.4	 69.05	 335.4	 -197.3	 1.0	 100.0	 1	 591.8	 225.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 591.8; % NG
	46903	 408.4	 69.05	 335.4	 -197.3	 1.0	 100.0	 1	 591.8	 225.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 591.8; % COW
	46903	 375.9	 69.05	 335.4	 -197.3	 1.0	 100.0	 1	 591.8	 160.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 591.8; % COW
	46904	 74.3	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % COW
	46904	 74.3	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % NG
	46904	 101.4	 10.0	 64.3	 -44.3	 1.0	 100.0	 1	 132.8	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.8; % PEL
	46904	 101.4	 10.0	 64.3	 -44.3	 1.0	 100.0	 1	 132.8	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.8; % NG
	46905	 79.55	 9.75	 62.5	 -43.0	 1.0	 100.0	 1	 129.1	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.1; % NG
	46905	 94.65	 24.8	 107.4	 -57.8	 1.0	 100.0	 1	 173.3	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.3; % NG
	46905	 41.25	 8.95	 38.7	 -20.8	 1.0	 100.0	 1	 62.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.5; % NG
	46905	 41.5	 9.0	 39.0	 -21.0	 1.0	 100.0	 1	 63.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0; % NG
	46905	 12.5	 3.3	 14.3	 -7.7	 1.0	 100.0	 1	 23.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % NG
	46905	 42.5	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	46905	 27.5	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	46905	 27.5	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	46908	 72.0	 13.45	 65.3	 -38.4	 1.0	 100.0	 1	 115.2	 28.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.2; % NG
	46908	 381.1	 83.35	 360.8	 -194.1	 1.0	 100.0	 1	 582.2	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 582.2; % NG
	46908	 150.9	 37.45	 162.2	 -87.3	 1.0	 100.0	 1	 261.8	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 261.8; % COW
	46911	 79.15	 6.45	 41.3	 -28.4	 1.0	 100.0	 1	 85.3	 73.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.3; % NG
	46912	 55.45	 12.0	 52.0	 -28.0	 1.0	 100.0	 1	 83.9	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.9; % NG
	46914	 32.5	 8.15	 35.3	 -19.0	 1.0	 100.0	 1	 57.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % PEL
	46914	 60.75	 5.8	 37.1	 -25.5	 1.0	 100.0	 1	 76.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 76.5; % NG
	46914	 60.75	 5.8	 37.1	 -25.5	 1.0	 100.0	 1	 76.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 76.5; % PEL
	46914	 39.75	 5.8	 37.1	 -25.5	 1.0	 100.0	 1	 76.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 76.5; % NG
	46914	 95.625	 12.55	 66.8	 -41.7	 1.0	 100.0	 1	 125.0	 66.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % COW
	46914	 100.0	 17.9	 77.5	 -41.7	 1.0	 100.0	 1	 125.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % COW
	46914	 55.0	 12.6	 54.5	 -29.3	 1.0	 100.0	 1	 88.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.0; % NG
	46914	 51.5	 12.9	 55.8	 -30.0	 1.0	 100.0	 1	 90.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	46915	 12.15	 1.75	 11.3	 -7.8	 1.0	 100.0	 1	 23.3	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.3; % NG
	46915	 14.25	 2.05	 13.3	 -9.2	 1.0	 100.0	 1	 27.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % NG
	46915	 9.425	 1.54	 9.03	 -5.95	 1.0	 100.0	 1	 17.85	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.85; % NG
	46915	 9.425	 1.54	 9.03	 -5.95	 1.0	 100.0	 1	 17.85	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.85; % NG
	46915	 9.425	 1.54	 9.03	 -5.95	 1.0	 100.0	 1	 17.85	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.85; % NG
	46915	 9.425	 1.54	 9.03	 -5.95	 1.0	 100.0	 1	 17.85	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.85; % NG
	46916	 70.315	 13.15	 63.8	 -37.5	 1.0	 100.0	 1	 112.5	 28.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % NG
	46916	 96.4	 24.3	 105.2	 -56.6	 1.0	 100.0	 1	 169.8	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 169.8; % COW
	46916	 44.33	 8.35	 39.7	 -23.0	 1.0	 100.0	 1	 69.0	 19.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % NG
	46916	 542.55	 67.55	 433.5	 -298.4	 1.0	 100.0	 1	 895.1	 190.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 895.1; % COW
	46916	 542.55	 67.55	 433.5	 -298.4	 1.0	 100.0	 1	 895.1	 190.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 895.1; % COW
	46917	 32.0	 0.0	 25.6	 -25.6	 1.0	 100.0	 1	 60.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % NG
	46917	 35.85	 0.0	 28.8	 -28.8	 1.0	 100.0	 1	 67.7	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.7; % NG
	46918	 154.81	 28.9	 140.4	 -82.6	 1.0	 100.0	 1	 247.7	 61.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 247.7; % NG
	46918	 32.15	 4.45	 28.7	 -19.8	 1.0	 100.0	 1	 59.3	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.3; % COW
	46918	 35.5	 5.0	 32.0	 -22.0	 1.0	 100.0	 1	 66.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.0; % PEL
	46918	 55.5	 7.6	 48.9	 -33.7	 1.0	 100.0	 1	 101.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.0; % NG
	46920	 40.0	 4.15	 26.6	 -18.3	 1.0	 100.0	 1	 55.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0; % NG
	46920	 55.0	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	46921	 128.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 187.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.0; % NG
	46921	 40.45	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 53.9	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.9; % NG
	46921	 70.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 100.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0; % NG
	46922	 21.5	 5.0	 21.7	 -11.7	 1.0	 100.0	 1	 35.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % PEL
	46922	 41.05	 8.2	 35.4	 -19.0	 1.0	 100.0	 1	 57.1	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.1; % NG
	46922	 61.55	 10.45	 45.3	 -24.4	 1.0	 100.0	 1	 73.1	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 73.1; % NG
	46922	 61.55	 10.45	 45.3	 -24.4	 1.0	 100.0	 1	 73.1	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 73.1; % NG
	46922	 57.6	 11.05	 47.8	 -25.7	 1.0	 100.0	 1	 77.2	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.2; % NG
	46922	 57.6	 11.05	 47.8	 -25.7	 1.0	 100.0	 1	 77.2	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.2; % COW
	46922	 26.5	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	46922	 45.0	 11.75	 50.8	 -27.3	 1.0	 100.0	 1	 82.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.0; % PEL
	46922	 5.75	 1.5	 6.5	 -3.5	 1.0	 100.0	 1	 10.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5; % NG
	46922	 5.75	 1.5	 6.5	 -3.5	 1.0	 100.0	 1	 10.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5; % NG
	46922	 5.75	 1.5	 6.5	 -3.5	 1.0	 100.0	 1	 10.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5; % NG
	46922	 5.75	 1.5	 6.5	 -3.5	 1.0	 100.0	 1	 10.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5; % NG
	46922	 5.75	 1.5	 6.5	 -3.5	 1.0	 100.0	 1	 10.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5; % NG
	46922	 10.5	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	46923	 33.215	 6.25	 29.7	 -17.2	 1.0	 100.0	 1	 51.7	 14.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7; % NG
	46923	 52.17	 9.8	 46.7	 -27.1	 1.0	 100.0	 1	 81.2	 23.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.2; % NG
	46924	 32.7	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 50.4	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.4; % NG
	46924	 32.7	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 50.4	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.4; % NG
	46926	 36.5	 5.75	 24.8	 -13.3	 1.0	 100.0	 1	 40.0	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % PEL
	46926	 36.5	 5.75	 24.8	 -13.3	 1.0	 100.0	 1	 40.0	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	46927	 26.85	 0.0	 7.2	 -7.2	 1.0	 100.0	 1	 35.7	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.7; % COW
	46927	 30.6	 0.0	 8.4	 -8.4	 1.0	 100.0	 1	 41.2	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.2; % NG
	46928	 7.5	 0.0	 2.55	 -2.55	 1.0	 100.0	 1	 12.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5; % NG
	46928	 7.5	 0.0	 2.55	 -2.55	 1.0	 100.0	 1	 12.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5; % NG
	46929	 6.95	 1.15	 6.45	 -4.15	 1.0	 100.0	 1	 12.5	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5; % PEL
	46929	 6.95	 1.15	 6.45	 -4.15	 1.0	 100.0	 1	 12.5	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5; % COW
	46931	 14.25	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 3.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	46931	 14.25	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 3.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	46931	 14.25	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 3.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	46934	 27.315	 4.3	 21.3	 -12.7	 1.0	 100.0	 1	 38.2	 16.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.2; % NG
	46934	 33.4	 5.55	 24.0	 -12.9	 1.0	 100.0	 1	 38.8	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.8; % NG
	46934	 33.0	 7.9	 28.5	 -12.7	 1.0	 100.0	 1	 38.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0; % NG
	46934	 7.0	 1.725	 7.45	 -4.0	 1.0	 100.0	 1	 12.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % NG
	46934	 7.0	 1.725	 7.45	 -4.0	 1.0	 100.0	 1	 12.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % NG
	46936	 2.8	 0.74	 3.04	 -1.56	 1.0	 100.0	 1	 4.7	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.7; % NG
	46936	 2.8	 0.74	 3.04	 -1.56	 1.0	 100.0	 1	 4.7	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.7; % NG
	46936	 2.8	 0.74	 3.04	 -1.56	 1.0	 100.0	 1	 4.7	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.7; % NG
	46936	 2.8	 0.74	 3.04	 -1.56	 1.0	 100.0	 1	 4.7	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.7; % PEL
	46936	 2.8	 0.74	 3.04	 -1.56	 1.0	 100.0	 1	 4.7	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.7; % PEL
	46937	 34.95	 6.6	 31.3	 -18.1	 1.0	 100.0	 1	 54.4	 15.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.4; % NG
	46937	 15.5	 3.3	 14.3	 -7.7	 1.0	 100.0	 1	 23.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % PEL
	46937	 206.75	 49.9	 216.0	 -116.2	 1.0	 100.0	 1	 348.5	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 348.5; % COW
	46939	 6.6	 1.525	 6.7	 -3.65	 1.0	 100.0	 1	 11.0	 2.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0; % PEL
	46939	 6.6	 1.525	 6.7	 -3.65	 1.0	 100.0	 1	 11.0	 2.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0; % COW
	46940	 14.4	 1.6	 10.1	 -6.9	 1.0	 100.0	 1	 20.8	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.8; % NG
	46940	 22.75	 2.85	 18.2	 -12.5	 1.0	 100.0	 1	 37.5	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % NG
	46941	 16.3	 2.95	 12.8	 -6.9	 1.0	 100.0	 1	 20.7	 11.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7; % PEL
	46942	 2.225	 0.55	 2.07	 -0.97	 1.0	 100.0	 1	 2.91	 1.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9143; % PEL
	46942	 2.225	 0.55	 2.07	 -0.97	 1.0	 100.0	 1	 2.91	 1.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9143; % NG
	46942	 2.225	 0.55	 2.07	 -0.97	 1.0	 100.0	 1	 2.91	 1.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9143; % NG
	46942	 2.225	 0.55	 2.07	 -0.97	 1.0	 100.0	 1	 2.91	 1.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9143; % PEL
	46942	 2.225	 0.55	 2.07	 -0.97	 1.0	 100.0	 1	 2.91	 1.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9143; % PEL
	46942	 2.225	 0.55	 2.07	 -0.97	 1.0	 100.0	 1	 2.91	 1.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9143; % NG
	46942	 2.225	 0.55	 2.07	 -0.97	 1.0	 100.0	 1	 2.91	 1.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9143; % PEL
	46943	 13.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	46943	 15.5	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 24.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % PEL
	46944	 11.5	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	46944	 14.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % COW
	46945	 1017.9	 93.3	 598.5	 -411.9	 1.0	 100.0	 1	 1235.8	 800.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	46946	 632.0	 69.0	 442.7	 -304.7	 1.0	 100.0	 1	 914.0	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 914.0; % COW
	46946	 538.0	 54.8	 351.6	 -242.0	 1.0	 100.0	 1	 726.0	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 726.0; % COW
	46947	 487.5	 49.05	 314.8	 -216.7	 1.0	 100.0	 1	 650.0	 325.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 650.0; % COW
	46947	 487.5	 49.05	 314.8	 -216.7	 1.0	 100.0	 1	 650.0	 325.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 650.0; % COW
	46948	 450.5	 46.9	 300.8	 -207.0	 1.0	 100.0	 1	 621.0	 280.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 621.0; % COW
	46948	 448.0	 46.9	 300.8	 -207.0	 1.0	 100.0	 1	 621.0	 275.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 621.0; % NG
	46949	 123.0	 0.0	 62.2	 -62.2	 1.0	 100.0	 1	 146.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 146.0; % NG
	46949	 118.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	46949	 442.15	 44.85	 287.8	 -198.1	 1.0	 100.0	 1	 594.3	 290.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 594.3; % COW
	46950	 454.0	 46.9	 300.8	 -207.0	 1.0	 100.0	 1	 621.0	 287.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 621.0; % COW
	46950	 450.5	 46.9	 300.8	 -207.0	 1.0	 100.0	 1	 621.0	 280.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 621.0; % COW
	46950	 431.85	 82.15	 355.5	 -191.2	 1.0	 100.0	 1	 573.7	 290.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 573.7; % COW
	46950	 431.35	 82.15	 355.5	 -191.2	 1.0	 100.0	 1	 573.7	 289.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 573.7; % COW
	46951	 401.35	 78.75	 340.7	 -183.2	 1.0	 100.0	 1	 549.7	 253.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 549.7; % COW
	46951	 400.85	 78.75	 340.7	 -183.2	 1.0	 100.0	 1	 549.7	 252.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 549.7; % COW
	46952	 27.5	 3.75	 24.2	 -16.7	 1.0	 100.0	 1	 50.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	46952	 29.28	 4.08	 26.16	 -18.0	 1.0	 100.0	 1	 54.0	 4.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % PEL
	46952	 29.28	 4.08	 26.16	 -18.0	 1.0	 100.0	 1	 54.0	 4.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	46952	 29.28	 4.08	 26.16	 -18.0	 1.0	 100.0	 1	 54.0	 4.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % PEL
	46952	 29.28	 4.08	 26.16	 -18.0	 1.0	 100.0	 1	 54.0	 4.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	46952	 29.28	 4.08	 26.16	 -18.0	 1.0	 100.0	 1	 54.0	 4.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	46952	 29.28	 4.08	 26.16	 -18.0	 1.0	 100.0	 1	 54.0	 4.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	46952	 29.28	 4.08	 26.16	 -18.0	 1.0	 100.0	 1	 54.0	 4.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % COW
	46952	 29.28	 4.08	 26.16	 -18.0	 1.0	 100.0	 1	 54.0	 4.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	46952	 27.5	 3.75	 24.2	 -16.7	 1.0	 100.0	 1	 50.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	46952	 34.5	 4.85	 31.0	 -21.3	 1.0	 100.0	 1	 64.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.0; % NG
	46952	 34.5	 4.85	 31.0	 -21.3	 1.0	 100.0	 1	 64.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.0; % NG
	46952	 34.5	 4.85	 31.0	 -21.3	 1.0	 100.0	 1	 64.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.0; % NG
	46952	 34.5	 4.85	 31.0	 -21.3	 1.0	 100.0	 1	 64.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.0; % NG
	46952	 34.5	 4.85	 31.0	 -21.3	 1.0	 100.0	 1	 64.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.0; % NG
	46952	 34.5	 4.85	 31.0	 -21.3	 1.0	 100.0	 1	 64.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.0; % NG
	46952	 29.28	 4.08	 26.16	 -18.0	 1.0	 100.0	 1	 54.0	 4.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	46956	 184.5	 15.4	 98.8	 -68.0	 1.0	 100.0	 1	 204.0	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0; % NG
	46956	 184.5	 15.4	 98.8	 -68.0	 1.0	 100.0	 1	 204.0	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0; % COW
	46957	 139.0	 14.65	 94.0	 -64.7	 1.0	 100.0	 1	 194.0	 84.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 194.0; % NG
	46957	 41.0	 3.95	 25.2	 -17.3	 1.0	 100.0	 1	 52.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.0; % PEL
	46957	 43.5	 4.3	 27.6	 -19.0	 1.0	 100.0	 1	 57.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.0; % NG
	46958	 124.0	 14.2	 91.1	 -62.7	 1.0	 100.0	 1	 188.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.0; % NG
	46958	 119.0	 26.9	 116.5	 -62.7	 1.0	 100.0	 1	 188.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.0; % NG
	46958	 119.0	 26.9	 116.5	 -62.7	 1.0	 100.0	 1	 188.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.0; % NG
	46959	 127.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 180.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	46959	 128.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 181.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.0; % COW
	46959	 96.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 123.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 123.0; % COW
	46959	 128.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 206.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.5; % NG
	46960	 144.0	 13.6	 87.2	 -60.0	 1.0	 100.0	 1	 180.0	 108.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	46960	 144.0	 13.6	 87.2	 -60.0	 1.0	 100.0	 1	 180.0	 108.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % COW
	46960	 175.0	 20.4	 130.8	 -90.0	 1.0	 100.0	 1	 270.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 270.0; % NG
	46961	 148.35	 24.6	 106.4	 -57.2	 1.0	 100.0	 1	 171.7	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 171.7; % NG
	46961	 604.0	 55.7	 357.4	 -246.0	 1.0	 100.0	 1	 738.0	 470.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 738.0; % NUC
	46961	 256.0	 38.95	 168.6	 -90.7	 1.0	 100.0	 1	 272.0	 240.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 272.0; % COW
	46962	 120.4	 22.6	 97.8	 -52.6	 1.0	 100.0	 1	 157.8	 83.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 157.8; % NG
	46962	 120.4	 22.6	 97.8	 -52.6	 1.0	 100.0	 1	 157.8	 83.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 157.8; % NG
	46963	 150.0	 0.0	 66.1	 -66.1	 1.0	 100.0	 1	 150.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	46964	 73.0	 0.0	 64.4	 -64.4	 1.0	 100.0	 1	 146.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	46965	 95.25	 19.7	 85.2	 -45.8	 1.0	 100.0	 1	 137.5	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 137.5; % NG
	46965	 91.75	 19.7	 85.2	 -45.8	 1.0	 100.0	 1	 137.5	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 137.5; % PEL
	46965	 35.5	 4.2	 27.1	 -18.7	 1.0	 100.0	 1	 56.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.0; % PEL
	46965	 34.0	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	46965	 207.0	 41.4	 179.1	 -96.3	 1.0	 100.0	 1	 289.0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 289.0; % NG
	46965	 262.0	 51.4	 222.5	 -119.7	 1.0	 100.0	 1	 359.0	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 359.0; % COW
	46966	 96.1	 17.35	 75.1	 -40.4	 1.0	 100.0	 1	 121.2	 71.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.2; % NG
	46967	 98.5	 16.75	 72.5	 -39.0	 1.0	 100.0	 1	 117.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.0; % NG
	46967	 98.5	 16.75	 72.5	 -39.0	 1.0	 100.0	 1	 117.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.0; % NG
	46967	 98.5	 16.75	 72.5	 -39.0	 1.0	 100.0	 1	 117.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.0; % NG
	46968	 78.9	 14.6	 63.1	 -33.9	 1.0	 100.0	 1	 101.8	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.8; % NG
	46968	 78.9	 14.6	 63.1	 -33.9	 1.0	 100.0	 1	 101.8	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.8; % NG
	46968	 78.9	 14.6	 63.1	 -33.9	 1.0	 100.0	 1	 101.8	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.8; % COW
	46968	 78.9	 14.6	 63.1	 -33.9	 1.0	 100.0	 1	 101.8	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.8; % NG
	46968	 78.9	 14.6	 63.1	 -33.9	 1.0	 100.0	 1	 101.8	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.8; % NG
	46968	 78.9	 14.6	 63.1	 -33.9	 1.0	 100.0	 1	 101.8	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.8; % NG
	46968	 78.9	 14.6	 63.1	 -33.9	 1.0	 100.0	 1	 101.8	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.8; % NG
	46968	 78.9	 14.6	 63.1	 -33.9	 1.0	 100.0	 1	 101.8	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.8; % COW
	46969	 55.0	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	46969	 14.0	 3.3	 14.3	 -7.7	 1.0	 100.0	 1	 23.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % PEL
	46969	 15.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	46969	 47.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % PEL
	46970	 39.5	 5.55	 35.8	 -24.7	 1.0	 100.0	 1	 74.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.0; % NG
	46972	 33.0	 4.6	 29.5	 -20.3	 1.0	 100.0	 1	 61.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0; % NG
	46972	 33.0	 4.6	 29.5	 -20.3	 1.0	 100.0	 1	 61.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0; % NG
	46972	 33.0	 4.6	 29.5	 -20.3	 1.0	 100.0	 1	 61.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0; % NG
	46972	 33.0	 4.6	 29.5	 -20.3	 1.0	 100.0	 1	 61.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0; % PEL
	46973	 33.4	 4.55	 29.4	 -20.3	 1.0	 100.0	 1	 60.8	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.8; % NG
	46974	 33.35	 4.6	 29.4	 -20.2	 1.0	 100.0	 1	 60.7	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.7; % NG
	46975	 33.3	 4.55	 29.3	 -20.2	 1.0	 100.0	 1	 60.6	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.6; % NG
	46976	 42.25	 4.55	 29.3	 -20.2	 1.0	 100.0	 1	 60.5	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	46976	 42.25	 4.55	 29.3	 -20.2	 1.0	 100.0	 1	 60.5	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	46976	 79.5	 9.75	 62.5	 -43.0	 1.0	 100.0	 1	 129.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.0; % COW
	46976	 79.5	 9.75	 62.5	 -43.0	 1.0	 100.0	 1	 129.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.0; % COW
	46977	 49.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % PEL
	46977	 49.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % PEL
	46977	 49.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % PEL
	46977	 49.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % PEL
	46978	 44.45	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % PEL
	46978	 44.45	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % NG
	46979	 28.55	 0.0	 22.4	 -22.4	 1.0	 100.0	 1	 56.7	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	46981	 35.36	 0.0	 17.1	 -17.1	 1.0	 100.0	 1	 52.0	 18.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.0; % NG
	46983	 25.35	 0.0	 19.9	 -19.9	 1.0	 100.0	 1	 50.4	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	46984	 42.5	 7.15	 32.6	 -18.3	 1.0	 100.0	 1	 55.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0; % NG
	46984	 40.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	46984	 339.5	 31.6	 202.9	 -139.7	 1.0	 100.0	 1	 419.0	 260.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 419.0; % NG
	46987	 35.0	 6.3	 27.3	 -14.7	 1.0	 100.0	 1	 44.0	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0; % NG
	46990	 33.35	 8.45	 30.5	 -13.6	 1.0	 100.0	 1	 40.7	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.7; % NG
	46990	 33.35	 8.45	 30.5	 -13.6	 1.0	 100.0	 1	 40.7	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.7; % NG
	46990	 33.35	 8.45	 30.5	 -13.6	 1.0	 100.0	 1	 40.7	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.7; % NG
	46990	 33.35	 8.45	 30.5	 -13.6	 1.0	 100.0	 1	 40.7	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.7; % NG
	46993	 10.5	 2.725	 11.8	 -6.35	 1.0	 100.0	 1	 19.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0; % PEL
	46993	 10.5	 2.725	 11.8	 -6.35	 1.0	 100.0	 1	 19.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0; % NG
	46994	 10.0	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	46994	 10.0	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	46995	 11.5	 1.35	 8.7	 -6.0	 1.0	 100.0	 1	 18.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % COW
	46995	 11.5	 1.35	 8.7	 -6.0	 1.0	 100.0	 1	 18.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	46996	 4.91	 1.42	 5.12	 -2.28	 1.0	 100.0	 1	 6.82	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.82; % PEL
	46996	 4.91	 1.42	 5.12	 -2.28	 1.0	 100.0	 1	 6.82	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.82; % COW
	46996	 4.91	 1.42	 5.12	 -2.28	 1.0	 100.0	 1	 6.82	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.82; % NG
	46996	 4.91	 1.42	 5.12	 -2.28	 1.0	 100.0	 1	 6.82	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.82; % PEL
	46996	 4.91	 1.42	 5.12	 -2.28	 1.0	 100.0	 1	 6.82	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.82; % NG
	46997	 21.88	 3.45	 17.1	 -10.2	 1.0	 100.0	 1	 30.6	 13.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.6; % NG
	46998	 27.0	 0.0	 8.9	 -8.9	 1.0	 100.0	 1	 27.0	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % COW
	46998	 31.0	 0.0	 10.2	 -10.2	 1.0	 100.0	 1	 31.0	 31.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.0; % NG
	46999	 24.3	 2.0	 12.9	 -8.9	 1.0	 100.0	 1	 26.6	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.6; % PEL
	46999	 24.3	 2.0	 12.9	 -8.9	 1.0	 100.0	 1	 26.6	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.6; % PEL
	47000	 1.725	 0.545	 1.97	 -0.88	 1.0	 100.0	 1	 2.63	 0.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.63; % PEL
	47000	 1.725	 0.545	 1.97	 -0.88	 1.0	 100.0	 1	 2.63	 0.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.63; % PEL
	47000	 1.725	 0.545	 1.97	 -0.88	 1.0	 100.0	 1	 2.63	 0.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.63; % PEL
	47000	 1.725	 0.545	 1.97	 -0.88	 1.0	 100.0	 1	 2.63	 0.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.63; % PEL
	47000	 1.725	 0.545	 1.97	 -0.88	 1.0	 100.0	 1	 2.63	 0.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.63; % PEL
	47000	 1.725	 0.545	 1.97	 -0.88	 1.0	 100.0	 1	 2.63	 0.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.63; % PEL
	47000	 1.725	 0.545	 1.97	 -0.88	 1.0	 100.0	 1	 2.63	 0.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.63; % PEL
	47000	 1.725	 0.545	 1.97	 -0.88	 1.0	 100.0	 1	 2.63	 0.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.63; % PEL
	47000	 1.725	 0.545	 1.97	 -0.88	 1.0	 100.0	 1	 2.63	 0.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.63; % PEL
	47000	 1.725	 0.545	 1.97	 -0.88	 1.0	 100.0	 1	 2.63	 0.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.63; % PEL
	47001	 5.1	 0.0	 1.77	 -1.77	 1.0	 100.0	 1	 8.7	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.7; % NG
	47001	 5.1	 0.0	 1.77	 -1.77	 1.0	 100.0	 1	 8.7	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.7; % NG
	47001	 5.1	 0.0	 1.77	 -1.77	 1.0	 100.0	 1	 8.7	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.7; % NG
	47004	 7.5	 1.8	 7.35	 -3.75	 1.0	 100.0	 1	 11.25	 3.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.25; % NG
	47004	 7.5	 1.8	 7.35	 -3.75	 1.0	 100.0	 1	 11.25	 3.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.25; % PEL
	47005	 13.5	 1.7	 10.7	 -7.3	 1.0	 100.0	 1	 22.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	47009	 10.75	 1.6	 10.4	 -7.2	 1.0	 100.0	 1	 21.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.5; % NG
	47009	 10.75	 1.6	 10.4	 -7.2	 1.0	 100.0	 1	 21.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.5; % NG
	47009	 13.75	 2.05	 13.3	 -9.2	 1.0	 100.0	 1	 27.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % COW
	47009	 13.75	 2.05	 13.3	 -9.2	 1.0	 100.0	 1	 27.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % NG
	47009	 13.75	 2.05	 13.3	 -9.2	 1.0	 100.0	 1	 27.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % NG
	47009	 13.75	 2.05	 13.3	 -9.2	 1.0	 100.0	 1	 27.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % NG
	47009	 13.75	 2.05	 13.3	 -9.2	 1.0	 100.0	 1	 27.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % NG
	47009	 13.75	 2.05	 13.3	 -9.2	 1.0	 100.0	 1	 27.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % NG
	47010	 12.1	 1.6	 10.3	 -7.1	 1.0	 100.0	 1	 21.2	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % PEL
	50134	 658.85	 95.7	 614.0	 -422.6	 1.0	 100.0	 1	 1267.7	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NUC
	50135	 472.5	 54.35	 348.7	 -240.0	 1.0	 100.0	 1	 720.0	 225.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 720.0; % COW
	50135	 469.8	 54.35	 348.7	 -240.0	 1.0	 100.0	 1	 720.0	 219.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 720.0; % COW
	50135	 469.8	 54.35	 348.7	 -240.0	 1.0	 100.0	 1	 720.0	 219.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 720.0; % NUC
	50136	 696.5	 67.4	 432.5	 -297.7	 1.0	 100.0	 1	 893.0	 500.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 893.0; % COW
	50136	 555.0	 51.75	 331.8	 -228.3	 1.0	 100.0	 1	 685.0	 425.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 685.0; % COW
	50137	 221.85	 26.35	 168.9	 -116.2	 1.0	 100.0	 1	 348.7	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 348.7; % NG
	50138	 37.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 50.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	50138	 27.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 37.5	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % NG
	50138	 108.35	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 140.7	 76.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.7; % COW
	50138	 108.35	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 140.7	 76.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.7; % NG
	50139	 69.5	 0.0	 23.6	 -23.6	 1.0	 100.0	 1	 94.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0; % NG
	50139	 208.5	 0.0	 65.4	 -65.4	 1.0	 100.0	 1	 261.0	 156.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 261.0; % NG
	50140	 75.0	 0.0	 66.1	 -66.1	 1.0	 100.0	 1	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50141	 89.5	 21.3	 92.3	 -49.7	 1.0	 100.0	 1	 149.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 149.0; % COW
	50142	 74.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 148.5	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50143	 58.8	 0.0	 49.4	 -49.4	 1.0	 100.0	 1	 112.0	 5.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50144	 50.45	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 100.8	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50145	 49.5	 0.0	 43.7	 -43.7	 1.0	 100.0	 1	 99.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50146	 85.5	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % NG
	50146	 81.65	 14.05	 60.9	 -32.8	 1.0	 100.0	 1	 98.3	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.3; % NG
	50146	 81.65	 14.05	 60.9	 -32.8	 1.0	 100.0	 1	 98.3	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.3; % NG
	50146	 145.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 112.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	50146	 237.5	 29.45	 188.9	 -130.0	 1.0	 100.0	 1	 390.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 390.0; % COW
	50147	 53.0	 0.0	 42.3	 -42.3	 1.0	 100.0	 1	 96.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50147	 57.5	 0.0	 46.3	 -46.3	 1.0	 100.0	 1	 105.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50148	 60.65	 13.1	 56.6	 -30.4	 1.0	 100.0	 1	 91.3	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.3; % NG
	50148	 60.65	 13.1	 56.6	 -30.4	 1.0	 100.0	 1	 91.3	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.3; % NG
	50148	 60.65	 13.1	 56.6	 -30.4	 1.0	 100.0	 1	 91.3	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.3; % NG
	50148	 60.65	 13.1	 56.6	 -30.4	 1.0	 100.0	 1	 91.3	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.3; % NG
	50149	 70.0	 12.9	 55.8	 -30.0	 1.0	 100.0	 1	 90.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	50150	 101.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0; % NG
	50150	 29.935	 3.525	 21.85	 -14.8	 1.0	 100.0	 1	 44.35	 15.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.35; % NG
	50150	 29.935	 3.525	 21.85	 -14.8	 1.0	 100.0	 1	 44.35	 15.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.35; % NG
	50150	 53.0	 6.5	 41.7	 -28.7	 1.0	 100.0	 1	 86.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0; % PEL
	50151	 47.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	50152	 100.0	 21.5	 93.0	 -50.0	 1.0	 100.0	 1	 150.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0; % NG
	50152	 57.0	 11.75	 50.8	 -27.3	 1.0	 100.0	 1	 82.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.0; % NG
	50152	 20.52	 2.95	 15.6	 -9.7	 1.0	 100.0	 1	 29.0	 12.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.0; % PEL
	50152	 20.52	 2.95	 15.6	 -9.7	 1.0	 100.0	 1	 29.0	 12.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.0; % NG
	50153	 52.3	 11.7	 50.6	 -27.2	 1.0	 100.0	 1	 81.6	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % COW
	50154	 106.25	 0.0	 39.5	 -39.5	 1.0	 100.0	 1	 157.5	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 157.5; % PEL
	50154	 41.85	 0.0	 16.5	 -16.5	 1.0	 100.0	 1	 65.7	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.7; % PEL
	50154	 41.85	 0.0	 16.5	 -16.5	 1.0	 100.0	 1	 65.7	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.7; % PEL
	50154	 58.3	 0.0	 20.5	 -20.5	 1.0	 100.0	 1	 81.6	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % COW
	50155	 57.75	 8.95	 43.6	 -25.7	 1.0	 100.0	 1	 77.0	 38.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.0; % NG
	50156	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50156	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50156	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % COW
	50156	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % PEL
	50156	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50156	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % PEL
	50156	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50156	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50156	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50157	 46.6	 5.4	 34.5	 -23.7	 1.0	 100.0	 1	 71.2	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2; % NG
	50157	 46.6	 5.4	 34.5	 -23.7	 1.0	 100.0	 1	 71.2	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2; % PEL
	50157	 47.2	 5.5	 35.1	 -24.1	 1.0	 100.0	 1	 72.4	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.4; % COW
	50159	 44.33	 8.35	 39.7	 -23.0	 1.0	 100.0	 1	 69.0	 19.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0; % NG
	50160	 33.5	 7.75	 33.5	 -18.0	 1.0	 100.0	 1	 54.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	50160	 33.5	 7.75	 33.5	 -18.0	 1.0	 100.0	 1	 54.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	50160	 33.5	 7.75	 33.5	 -18.0	 1.0	 100.0	 1	 54.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	50160	 33.5	 7.75	 33.5	 -18.0	 1.0	 100.0	 1	 54.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	50160	 140.7	 24.55	 106.2	 -57.1	 1.0	 100.0	 1	 171.4	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 171.4; % NG
	50160	 140.7	 24.55	 106.2	 -57.1	 1.0	 100.0	 1	 171.4	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 171.4; % NG
	50160	 140.7	 24.55	 106.2	 -57.1	 1.0	 100.0	 1	 171.4	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 171.4; % NG
	50161	 40.05	 0.0	 12.6	 -12.6	 1.0	 100.0	 1	 50.1	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.1; % NG
	50161	 40.05	 0.0	 12.6	 -12.6	 1.0	 100.0	 1	 50.1	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.1; % NG
	50161	 47.75	 0.0	 16.4	 -16.4	 1.0	 100.0	 1	 65.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.5; % COW
	50162	 36.5	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	50163	 25.0	 0.0	 19.8	 -19.8	 1.0	 100.0	 1	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50164	 30.0	 0.0	 19.8	 -19.8	 1.0	 100.0	 1	 50.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50165	 78.0	 16.35	 70.7	 -38.0	 1.0	 100.0	 1	 114.0	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0; % COW
	50165	 39.5	 10.25	 36.8	 -16.3	 1.0	 100.0	 1	 49.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0; % NG
	50165	 269.0	 30.45	 195.2	 -134.3	 1.0	 100.0	 1	 403.0	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 403.0; % NG
	50166	 24.0	 0.0	 19.0	 -19.0	 1.0	 100.0	 1	 48.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50166	 50.25	 0.0	 44.3	 -44.3	 1.0	 100.0	 1	 100.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50167	 69.0	 16.35	 70.7	 -38.0	 1.0	 100.0	 1	 114.0	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0; % NG
	50167	 69.0	 16.35	 70.7	 -38.0	 1.0	 100.0	 1	 114.0	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0; % NG
	50167	 34.0	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % PEL
	50167	 48.5	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % COW
	50168	 28.35	 9.1	 32.8	 -14.6	 1.0	 100.0	 1	 43.7	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.7; % PEL
	50169	 24.5	 3.05	 19.4	 -13.3	 1.0	 100.0	 1	 40.0	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	50170	 12.3	 0.0	 6.45	 -6.45	 1.0	 100.0	 1	 19.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6; % NG
	50170	 12.3	 0.0	 6.45	 -6.45	 1.0	 100.0	 1	 19.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6; % NG
	50171	 30.45	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 38.9	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.9; % PEL
	50172	 15.75	 3.8	 16.4	 -8.8	 1.0	 100.0	 1	 26.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.5; % NG
	50173	 5.8	 1.585	 5.7	 -2.53	 1.0	 100.0	 1	 7.6	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.6; % NG
	50173	 5.8	 1.585	 5.7	 -2.53	 1.0	 100.0	 1	 7.6	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.6; % PEL
	50173	 5.8	 1.585	 5.7	 -2.53	 1.0	 100.0	 1	 7.6	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.6; % NG
	50174	 2.075	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 3.65	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.65; % NG
	50174	 2.075	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 3.65	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.65; % PEL
	50174	 2.075	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 3.65	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.65; % NG
	50174	 2.075	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 3.65	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.65; % NG
	50174	 2.075	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 3.65	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.65; % NG
	50174	 2.075	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 3.65	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.65; % NG
	50175	 4.965	 1.08	 3.88	 -1.72	 1.0	 100.0	 1	 5.18	 4.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.175; % NG
	50175	 4.965	 1.08	 3.88	 -1.72	 1.0	 100.0	 1	 5.18	 4.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.175; % NG
	50175	 4.965	 1.08	 3.88	 -1.72	 1.0	 100.0	 1	 5.18	 4.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.175; % PEL
	50175	 4.965	 1.08	 3.88	 -1.72	 1.0	 100.0	 1	 5.18	 4.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.175; % PEL
	50176	 2.0	 0.52	 1.88	 -0.84	 1.0	 100.0	 1	 2.5	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	50176	 2.0	 0.52	 1.88	 -0.84	 1.0	 100.0	 1	 2.5	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	50176	 2.0	 0.52	 1.88	 -0.84	 1.0	 100.0	 1	 2.5	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	50176	 2.0	 0.52	 1.88	 -0.84	 1.0	 100.0	 1	 2.5	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	50176	 2.0	 0.52	 1.88	 -0.84	 1.0	 100.0	 1	 2.5	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % COW
	50176	 2.0	 0.52	 1.88	 -0.84	 1.0	 100.0	 1	 2.5	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	50176	 2.0	 0.52	 1.88	 -0.84	 1.0	 100.0	 1	 2.5	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	50176	 2.0	 0.52	 1.88	 -0.84	 1.0	 100.0	 1	 2.5	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	50177	 1.15	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	50177	 1.15	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	50177	 1.15	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	50177	 1.15	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	50177	 1.15	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	50177	 1.15	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	50177	 1.15	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	50177	 1.15	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	50177	 1.15	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	50177	 1.15	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	50178	 12.0	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	50179	 11.5	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	50180	 549.9	 45.65	 292.9	 -201.6	 1.0	 100.0	 1	 604.8	 495.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 604.8; % COW
	50180	 444.9	 45.65	 292.9	 -201.6	 1.0	 100.0	 1	 604.8	 285.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 604.8; % COW
	50181	 325.0	 33.95	 217.9	 -150.0	 1.0	 100.0	 1	 450.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 450.0; % COW
	50182	 317.45	 32.8	 210.6	 -145.0	 1.0	 100.0	 1	 434.9	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 434.9; % NG
	50182	 317.45	 32.8	 210.6	 -145.0	 1.0	 100.0	 1	 434.9	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 434.9; % COW
	50183	 227.0	 19.4	 124.5	 -85.7	 1.0	 100.0	 1	 257.0	 197.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 257.0; % NG
	50183	 428.5	 36.0	 231.0	 -159.0	 1.0	 100.0	 1	 477.0	 380.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 477.0; % COW
	50184	 163.0	 30.95	 133.9	 -72.0	 1.0	 100.0	 1	 216.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.0; % NG
	50184	 330.0	 33.2	 213.1	 -146.7	 1.0	 100.0	 1	 440.0	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 440.0; % NG
	50185	 140.1	 0.0	 75.2	 -75.2	 1.0	 100.0	 1	 190.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.2; % NG
	50186	 90.0	 13.6	 87.2	 -60.0	 1.0	 100.0	 1	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50187	 82.45	 0.0	 70.1	 -70.1	 1.0	 100.0	 1	 159.0	 5.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50188	 74.5	 0.0	 65.7	 -65.7	 1.0	 100.0	 1	 149.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50189	 77.95	 0.0	 65.5	 -65.5	 1.0	 100.0	 1	 148.5	 7.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50190	 63.0	 0.0	 52.9	 -52.9	 1.0	 100.0	 1	 120.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50191	 57.75	 0.0	 50.9	 -50.9	 1.0	 100.0	 1	 115.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50192	 57.5	 0.0	 37.8	 -37.8	 1.0	 100.0	 1	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.0; % COW
	50192	 57.5	 0.0	 37.8	 -37.8	 1.0	 100.0	 1	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.0; % NG
	50192	 64.0	 0.0	 42.1	 -42.1	 1.0	 100.0	 1	 128.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 128.0; % NG
	50192	 64.0	 0.0	 42.1	 -42.1	 1.0	 100.0	 1	 128.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 128.0; % NG
	50192	 64.0	 0.0	 42.1	 -42.1	 1.0	 100.0	 1	 128.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 128.0; % NG
	50193	 53.75	 0.0	 45.2	 -45.2	 1.0	 100.0	 1	 102.4	 5.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50194	 32.75	 0.0	 24.7	 -24.7	 1.0	 100.0	 1	 62.4	 3.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50195	 32.3	 0.0	 24.3	 -24.3	 1.0	 100.0	 1	 61.5	 3.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50196	 25.2	 0.0	 19.0	 -19.0	 1.0	 100.0	 1	 48.0	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	50196	 26.55	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 50.6	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50197	 24.8	 0.0	 19.6	 -19.6	 1.0	 100.0	 1	 49.5	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	50198	 26.0	 0.0	 19.6	 -19.6	 1.0	 100.0	 1	 49.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50199	 24.05	 0.0	 19.0	 -19.0	 1.0	 100.0	 1	 48.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50200	 21.25	 0.0	 16.0	 -16.0	 1.0	 100.0	 1	 40.5	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50201	 20.3	 0.0	 16.0	 -16.0	 1.0	 100.0	 1	 40.5	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50203	 18.55	 0.0	 14.5	 -14.5	 1.0	 100.0	 1	 36.8	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	50204	 17.0	 0.0	 12.4	 -12.4	 1.0	 100.0	 1	 31.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50205	 16.05	 1.85	 11.7	 -8.0	 1.0	 100.0	 1	 24.1	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.1; % NG
	50205	 16.05	 1.85	 11.7	 -8.0	 1.0	 100.0	 1	 24.1	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.1; % NG
	50206	 0.0	 0.0	 496.4	 -267.0	 1.0	 100.0	 0	 801.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50207	 340.65	 51.45	 330.0	 -227.1	 1.0	 100.0	 1	 681.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 681.3; % NG
	50207	 0.0	 0.0	 330.0	 -227.1	 1.0	 100.0	 0	 681.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 681.3; % COW
	50208	 529.0	 55.7	 357.4	 -246.0	 1.0	 100.0	 1	 738.0	 320.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 738.0; % COW
	50208	 425.8	 49.2	 315.6	 -217.2	 1.0	 100.0	 1	 651.6	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 651.6; % COW
	50209	 488.0	 71.9	 311.1	 -167.3	 1.0	 100.0	 1	 502.0	 474.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50210	 144.75	 24.7	 106.9	 -57.5	 1.0	 100.0	 1	 172.5	 117.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.5; % COW
	50210	 141.75	 24.7	 106.9	 -57.5	 1.0	 100.0	 1	 172.5	 111.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.5; % NG
	50211	 74.9	 8.3	 53.2	 -36.6	 1.0	 100.0	 1	 109.8	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 109.8; % COW
	50212	 41.0	 0.0	 32.0	 -32.0	 1.0	 100.0	 1	 81.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50215	 95.0	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 54.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % NG
	50215	 138.8	 31.2	 134.9	 -72.5	 1.0	 100.0	 1	 217.6	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.6; % NG
	50215	 71.9	 15.55	 67.4	 -36.3	 1.0	 100.0	 1	 108.8	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.8; % NG
	50215	 71.9	 15.55	 67.4	 -36.3	 1.0	 100.0	 1	 108.8	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.8; % NG
	50215	 54.25	 15.3	 55.1	 -24.5	 1.0	 100.0	 1	 73.5	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 73.5; % COW
	50216	 41.2	 5.5	 35.1	 -24.1	 1.0	 100.0	 1	 72.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.4; % PEL
	50216	 72.7	 19.9	 71.6	 -31.8	 1.0	 100.0	 1	 95.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.4; % NG
	50216	 57.7	 19.9	 71.6	 -31.8	 1.0	 100.0	 1	 95.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.4; % NG
	50217	 35.7	 10.2	 44.2	 -23.8	 1.0	 100.0	 1	 71.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.4; % PEL
	50219	 34.2	 9.1	 39.3	 -21.1	 1.0	 100.0	 1	 63.4	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.4; % NG
	50219	 34.2	 9.1	 39.3	 -21.1	 1.0	 100.0	 1	 63.4	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.4; % NG
	50219	 38.2	 7.8	 33.7	 -18.1	 1.0	 100.0	 1	 54.4	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.4; % NG
	50219	 14.95	 3.55	 15.4	 -8.3	 1.0	 100.0	 1	 24.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9; % PEL
	50220	 19.1	 2.15	 13.7	 -9.4	 1.0	 100.0	 1	 28.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.2; % PEL
	50220	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	50220	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	50220	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	50221	 30.0	 0.0	 23.7	 -23.7	 1.0	 100.0	 1	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50223	 59.95	 17.15	 74.3	 -40.0	 1.0	 100.0	 1	 119.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.9; % COW
	50223	 28.35	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	50223	 54.4	 15.55	 67.4	 -36.3	 1.0	 100.0	 1	 108.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.8; % PEL
	50224	 28.35	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % NG
	50225	 38.7	 4.15	 26.8	 -18.5	 1.0	 100.0	 1	 55.4	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.4; % NG
	50225	 38.7	 4.15	 26.8	 -18.5	 1.0	 100.0	 1	 55.4	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.4; % NG
	50225	 44.45	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % COW
	50225	 41.45	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % PEL
	50225	 79.8	 15.1	 65.4	 -35.2	 1.0	 100.0	 1	 105.6	 54.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.6; % NG
	50226	 27.5	 0.0	 16.4	 -16.4	 1.0	 100.0	 1	 50.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	50227	 7.6	 0.0	 5.0	 -5.0	 1.0	 100.0	 1	 15.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.2; % NG
	50227	 7.6	 0.0	 5.0	 -5.0	 1.0	 100.0	 1	 15.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.2; % NG
	50227	 7.6	 0.0	 5.0	 -5.0	 1.0	 100.0	 1	 15.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.2; % PEL
	50228	 6.55	 1.0	 6.35	 -4.35	 1.0	 100.0	 1	 13.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.1; % COW
	50228	 6.55	 1.0	 6.35	 -4.35	 1.0	 100.0	 1	 13.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.1; % NG
	50230	 12.75	 1.7	 10.9	 -7.5	 1.0	 100.0	 1	 22.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5; % NG
	50231	 30.0	 3.05	 19.4	 -13.3	 1.0	 100.0	 1	 40.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	50231	 60.75	 6.9	 44.3	 -30.5	 1.0	 100.0	 1	 91.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.5; % NG
	50231	 14.0	 3.15	 13.6	 -7.3	 1.0	 100.0	 1	 22.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	50232	 13.5	 1.7	 10.7	 -7.3	 1.0	 100.0	 1	 22.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	50233	 14.5	 3.15	 13.6	 -7.3	 1.0	 100.0	 1	 22.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	50234	 1.36	 0.57	 2.05	 -0.91	 1.0	 100.0	 1	 2.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.725; % NG
	50234	 1.36	 0.57	 2.05	 -0.91	 1.0	 100.0	 1	 2.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.725; % PEL
	50234	 1.36	 0.57	 2.05	 -0.91	 1.0	 100.0	 1	 2.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.725; % NG
	50234	 1.36	 0.57	 2.05	 -0.91	 1.0	 100.0	 1	 2.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.725; % PEL
	50234	 1.36	 0.57	 2.05	 -0.91	 1.0	 100.0	 1	 2.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.725; % PEL
	50234	 1.36	 0.57	 2.05	 -0.91	 1.0	 100.0	 1	 2.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.725; % PEL
	50234	 1.36	 0.57	 2.05	 -0.91	 1.0	 100.0	 1	 2.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.725; % PEL
	50234	 1.36	 0.57	 2.05	 -0.91	 1.0	 100.0	 1	 2.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.725; % PEL
	50235	 6.4	 0.825	 5.25	 -3.6	 1.0	 100.0	 1	 10.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8; % NG
	50235	 6.4	 0.825	 5.25	 -3.6	 1.0	 100.0	 1	 10.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8; % NG
	50236	 6.4	 0.825	 5.25	 -3.6	 1.0	 100.0	 1	 10.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8; % NG
	50236	 6.4	 0.825	 5.25	 -3.6	 1.0	 100.0	 1	 10.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8; % PEL
	50237	 2.71	 0.495	 2.12	 -1.13	 1.0	 100.0	 1	 3.42	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.4167; % NG
	50237	 2.71	 0.495	 2.12	 -1.13	 1.0	 100.0	 1	 3.42	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.4167; % PEL
	50237	 2.71	 0.495	 2.12	 -1.13	 1.0	 100.0	 1	 3.42	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.4167; % NG
	50237	 2.71	 0.495	 2.12	 -1.13	 1.0	 100.0	 1	 3.42	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.4167; % NG
	50237	 2.71	 0.495	 2.12	 -1.13	 1.0	 100.0	 1	 3.42	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.4167; % NG
	50237	 2.71	 0.495	 2.12	 -1.13	 1.0	 100.0	 1	 3.42	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.4167; % PEL
	50238	 108.125	 20.15	 98.0	 -57.7	 1.0	 100.0	 1	 173.0	 43.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.0; % NG
	50238	 386.0	 43.15	 277.0	 -190.7	 1.0	 100.0	 1	 572.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 572.0; % COW
	50238	 386.0	 43.15	 277.0	 -190.7	 1.0	 100.0	 1	 572.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 572.0; % COW
	50238	 386.0	 43.15	 277.0	 -190.7	 1.0	 100.0	 1	 572.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 572.0; % COW
	50239	 384.5	 42.95	 275.6	 -189.7	 1.0	 100.0	 1	 569.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 569.0; % COW
	50239	 384.5	 42.95	 275.6	 -189.7	 1.0	 100.0	 1	 569.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 569.0; % COW
	50240	 397.0	 44.85	 287.7	 -198.0	 1.0	 100.0	 1	 594.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 594.0; % COW
	50240	 347.5	 40.75	 261.5	 -180.0	 1.0	 100.0	 1	 540.0	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 540.0; % COW
	50241	 155.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	50241	 136.75	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	50241	 136.75	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	50241	 339.0	 35.7	 229.1	 -157.7	 1.0	 100.0	 1	 473.0	 205.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 473.0; % NG
	50241	 339.0	 35.7	 229.1	 -157.7	 1.0	 100.0	 1	 473.0	 205.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 473.0; % NG
	50241	 316.5	 35.7	 229.1	 -157.7	 1.0	 100.0	 1	 473.0	 160.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 473.0; % COW
	50242	 313.0	 63.85	 276.4	 -148.7	 1.0	 100.0	 1	 446.0	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 446.0; % NG
	50243	 154.75	 22.8	 98.8	 -53.2	 1.0	 100.0	 1	 159.5	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.5; % NG
	50243	 154.75	 22.8	 98.8	 -53.2	 1.0	 100.0	 1	 159.5	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.5; % COW
	50243	 154.75	 22.8	 98.8	 -53.2	 1.0	 100.0	 1	 159.5	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.5; % NG
	50243	 154.75	 22.8	 98.8	 -53.2	 1.0	 100.0	 1	 159.5	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.5; % NG
	50243	 144.2	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 89.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	50243	 144.2	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 89.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	50243	 144.2	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 89.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	50243	 144.2	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 89.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	50244	 126.95	 13.9	 89.1	 -61.3	 1.0	 100.0	 1	 183.9	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.9; % NG
	50244	 126.95	 13.9	 89.1	 -61.3	 1.0	 100.0	 1	 183.9	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.9; % NG
	50244	 126.95	 13.9	 89.1	 -61.3	 1.0	 100.0	 1	 183.9	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.9; % NG
	50244	 126.95	 13.9	 89.1	 -61.3	 1.0	 100.0	 1	 183.9	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.9; % NG
	50244	 193.6	 23.95	 153.6	 -105.7	 1.0	 100.0	 1	 317.2	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 317.2; % COW
	50244	 176.1	 23.95	 153.6	 -105.7	 1.0	 100.0	 1	 317.2	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 317.2; % NG
	50245	 152.15	 25.65	 111.1	 -59.8	 1.0	 100.0	 1	 179.3	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.3; % NG
	50245	 152.15	 25.65	 111.1	 -59.8	 1.0	 100.0	 1	 179.3	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.3; % NG
	50245	 152.15	 25.65	 111.1	 -59.8	 1.0	 100.0	 1	 179.3	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.3; % COW
	50245	 97.0	 17.45	 75.6	 -40.7	 1.0	 100.0	 1	 122.0	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % NG
	50245	 97.0	 17.45	 75.6	 -40.7	 1.0	 100.0	 1	 122.0	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % NG
	50245	 97.0	 17.45	 75.6	 -40.7	 1.0	 100.0	 1	 122.0	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0; % COW
	50246	 135.1	 25.25	 109.4	 -58.9	 1.0	 100.0	 1	 176.6	 93.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.6; % NG
	50246	 135.1	 25.25	 109.4	 -58.9	 1.0	 100.0	 1	 176.6	 93.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.6; % NG
	50246	 143.62	 28.4	 122.8	 -66.0	 1.0	 100.0	 1	 198.1	 89.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.1; % NG
	50247	 138.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	50247	 138.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % COW
	50247	 116.4	 26.2	 113.3	 -60.9	 1.0	 100.0	 1	 182.8	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 182.8; % NG
	50248	 143.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	50248	 143.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	50248	 143.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % COW
	50248	 143.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	50248	 157.5	 36.5	 158.0	 -85.0	 1.0	 100.0	 1	 255.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 255.0; % NG
	50248	 157.5	 36.5	 158.0	 -85.0	 1.0	 100.0	 1	 255.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 255.0; % NG
	50249	 127.5	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	50249	 127.5	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	50250	 76.4	 0.0	 66.9	 -66.9	 1.0	 100.0	 1	 151.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50252	 61.5	 0.0	 54.2	 -54.2	 1.0	 100.0	 1	 123.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50254	 50.65	 0.0	 44.6	 -44.6	 1.0	 100.0	 1	 101.2	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50255	 49.6	 0.0	 43.7	 -43.7	 1.0	 100.0	 1	 99.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50256	 50.0	 0.0	 43.7	 -43.7	 1.0	 100.0	 1	 99.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50257	 52.1	 0.0	 43.7	 -43.7	 1.0	 100.0	 1	 99.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50257	 51.9	 0.0	 43.6	 -43.6	 1.0	 100.0	 1	 98.9	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50258	 94.5	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	50258	 94.5	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	50258	 61.035	 11.45	 54.6	 -31.7	 1.0	 100.0	 1	 95.0	 27.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0; % NG
	50260	 48.5	 0.0	 27.6	 -27.6	 1.0	 100.0	 1	 84.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.0; % NG
	50260	 48.5	 0.0	 27.6	 -27.6	 1.0	 100.0	 1	 84.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.0; % NG
	50260	 68.75	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 51.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	50260	 68.75	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 51.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	50260	 175.0	 23.8	 152.6	 -105.0	 1.0	 100.0	 1	 315.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 315.0; % COW
	50261	 304.5	 35.7	 229.1	 -157.7	 1.0	 100.0	 1	 473.0	 136.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 473.0; % NG
	50261	 274.0	 35.7	 229.1	 -157.7	 1.0	 100.0	 1	 473.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 473.0; % PEL
	50261	 64.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	50261	 64.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	50262	 57.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	50262	 57.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % COW
	50262	 77.0	 9.05	 58.1	 -40.0	 1.0	 100.0	 1	 120.0	 34.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0; % NG
	50264	 30.0	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	50264	 30.0	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	50264	 30.0	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	50264	 18.6	 3.65	 16.7	 -9.4	 1.0	 100.0	 1	 28.2	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.2; % NG
	50264	 18.6	 3.65	 16.7	 -9.4	 1.0	 100.0	 1	 28.2	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.2; % NG
	50264	 18.6	 3.65	 16.7	 -9.4	 1.0	 100.0	 1	 28.2	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.2; % PEL
	50264	 32.5	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	50265	 64.75	 12.1	 52.4	 -28.2	 1.0	 100.0	 1	 84.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % COW
	50265	 64.75	 12.1	 52.4	 -28.2	 1.0	 100.0	 1	 84.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	50265	 64.75	 12.1	 52.4	 -28.2	 1.0	 100.0	 1	 84.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	50265	 64.75	 12.1	 52.4	 -28.2	 1.0	 100.0	 1	 84.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.5; % NG
	50266	 46.75	 4.55	 29.3	 -20.2	 1.0	 100.0	 1	 60.5	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	50266	 26.5	 6.85	 29.7	 -16.0	 1.0	 100.0	 1	 48.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.0; % NG
	50266	 43.5	 7.75	 33.5	 -18.0	 1.0	 100.0	 1	 54.0	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	50266	 54.15	 10.55	 45.7	 -24.6	 1.0	 100.0	 1	 73.8	 34.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 73.8; % NG
	50267	 47.0	 3.8	 24.2	 -16.6	 1.0	 100.0	 1	 49.9	 44.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9; % NG
	50267	 69.9	 5.45	 35.1	 -24.2	 1.0	 100.0	 1	 72.5	 67.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.5; % NG
	50270	 28.05	 0.0	 20.2	 -20.2	 1.0	 100.0	 1	 51.0	 5.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50270	 28.05	 0.0	 20.2	 -20.2	 1.0	 100.0	 1	 51.0	 5.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50271	 34.0	 0.0	 16.4	 -16.4	 1.0	 100.0	 1	 50.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	50271	 34.0	 0.0	 16.4	 -16.4	 1.0	 100.0	 1	 50.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	50272	 77.5	 17.9	 77.5	 -41.7	 1.0	 100.0	 1	 125.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	50272	 82.5	 19.35	 83.7	 -45.0	 1.0	 100.0	 1	 135.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % NG
	50272	 32.5	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	50273	 30.0	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % PEL
	50273	 30.0	 6.45	 27.9	 -15.0	 1.0	 100.0	 1	 45.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	50274	 7.6	 0.0	 3.67	 -3.67	 1.0	 100.0	 1	 11.2	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % NG
	50274	 7.6	 0.0	 3.67	 -3.67	 1.0	 100.0	 1	 11.2	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % COW
	50274	 7.6	 0.0	 3.67	 -3.67	 1.0	 100.0	 1	 11.2	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % PEL
	50274	 7.6	 0.0	 3.67	 -3.67	 1.0	 100.0	 1	 11.2	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % PEL
	50275	 34.1	 3.25	 20.9	 -14.4	 1.0	 100.0	 1	 43.2	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.2; % NG
	50275	 34.1	 3.25	 20.9	 -14.4	 1.0	 100.0	 1	 43.2	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.2; % NG
	50275	 34.1	 3.25	 20.9	 -14.4	 1.0	 100.0	 1	 43.2	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.2; % NG
	50275	 34.1	 3.25	 20.9	 -14.4	 1.0	 100.0	 1	 43.2	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.2; % NG
	50275	 34.1	 3.25	 20.9	 -14.4	 1.0	 100.0	 1	 43.2	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.2; % NG
	50275	 34.1	 3.25	 20.9	 -14.4	 1.0	 100.0	 1	 43.2	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.2; % NG
	50276	 86.5	 10.05	 64.4	 -44.3	 1.0	 100.0	 1	 133.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.0; % COW
	50276	 156.5	 19.1	 122.5	 -84.3	 1.0	 100.0	 1	 253.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 253.0; % NG
	50276	 36.5	 3.1	 19.9	 -13.7	 1.0	 100.0	 1	 41.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.0; % NG
	50276	 33.5	 3.1	 19.9	 -13.7	 1.0	 100.0	 1	 41.0	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.0; % NG
	50276	 41.5	 4.75	 30.5	 -21.0	 1.0	 100.0	 1	 63.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0; % NG
	50276	 51.0	 6.2	 39.7	 -27.3	 1.0	 100.0	 1	 82.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.0; % NG
	50277	 23.95	 0.0	 16.0	 -16.0	 1.0	 100.0	 1	 40.5	 7.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50277	 56.95	 0.0	 47.0	 -47.0	 1.0	 100.0	 1	 106.5	 7.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50278	 13.75	 0.0	 6.4	 -6.4	 1.0	 100.0	 1	 19.5	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.5; % NG
	50278	 13.75	 0.0	 6.4	 -6.4	 1.0	 100.0	 1	 19.5	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.5; % NG
	50280	 30.0	 0.0	 11.5	 -11.5	 1.0	 100.0	 1	 35.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % COW
	50280	 30.0	 0.0	 11.5	 -11.5	 1.0	 100.0	 1	 35.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % PEL
	50281	 25.05	 0.0	 12.7	 -12.7	 1.0	 100.0	 1	 32.1	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.1; % NG
	50281	 25.05	 0.0	 12.7	 -12.7	 1.0	 100.0	 1	 32.1	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.1; % PEL
	50281	 25.05	 0.0	 12.7	 -12.7	 1.0	 100.0	 1	 32.1	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.1; % PEL
	50281	 25.05	 2.4	 15.5	 -10.7	 1.0	 100.0	 1	 32.1	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.1; % COW
	50282	 20.0	 0.0	 9.9	 -9.9	 1.0	 100.0	 1	 30.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0; % NG
	50282	 20.0	 0.0	 9.9	 -9.9	 1.0	 100.0	 1	 30.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0; % PEL
	50282	 20.0	 0.0	 9.9	 -9.9	 1.0	 100.0	 1	 30.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0; % NG
	50283	 18.75	 0.0	 9.0	 -9.0	 1.0	 100.0	 1	 27.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % NG
	50283	 18.75	 0.0	 9.0	 -9.0	 1.0	 100.0	 1	 27.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % NG
	50283	 18.75	 0.0	 9.0	 -9.0	 1.0	 100.0	 1	 27.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % NG
	50283	 18.75	 0.0	 9.0	 -9.0	 1.0	 100.0	 1	 27.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % NG
	50284	 111.5	 12.3	 78.9	 -54.3	 1.0	 100.0	 1	 163.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.0; % COW
	50284	 147.5	 16.65	 106.6	 -73.3	 1.0	 100.0	 1	 220.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 220.0; % NG
	50284	 52.25	 4.55	 29.3	 -20.2	 1.0	 100.0	 1	 60.5	 44.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	50284	 52.25	 4.55	 29.3	 -20.2	 1.0	 100.0	 1	 60.5	 44.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	50284	 17.15	 2.05	 13.1	 -9.0	 1.0	 100.0	 1	 27.0	 7.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % NG
	50284	 261.5	 33.45	 214.6	 -147.7	 1.0	 100.0	 1	 443.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 443.0; % NG
	50285	 14.0	 5.25	 18.8	 -8.3	 1.0	 100.0	 1	 25.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	50285	 24.75	 9.3	 33.4	 -14.8	 1.0	 100.0	 1	 44.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.5; % NG
	50285	 24.75	 9.3	 33.4	 -14.8	 1.0	 100.0	 1	 44.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.5; % NG
	50286	 1.81	 0.465	 1.68	 -0.75	 1.0	 100.0	 1	 2.24	 1.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2364; % PEL
	50286	 1.81	 0.465	 1.68	 -0.75	 1.0	 100.0	 1	 2.24	 1.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2364; % PEL
	50286	 1.81	 0.465	 1.68	 -0.75	 1.0	 100.0	 1	 2.24	 1.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2364; % PEL
	50286	 1.81	 0.465	 1.68	 -0.75	 1.0	 100.0	 1	 2.24	 1.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2364; % PEL
	50286	 1.81	 0.465	 1.68	 -0.75	 1.0	 100.0	 1	 2.24	 1.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2364; % PEL
	50286	 1.81	 0.465	 1.68	 -0.75	 1.0	 100.0	 1	 2.24	 1.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2364; % PEL
	50286	 1.81	 0.465	 1.68	 -0.75	 1.0	 100.0	 1	 2.24	 1.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2364; % PEL
	50286	 1.81	 0.465	 1.68	 -0.75	 1.0	 100.0	 1	 2.24	 1.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2364; % PEL
	50286	 1.81	 0.465	 1.68	 -0.75	 1.0	 100.0	 1	 2.24	 1.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2364; % PEL
	50286	 1.81	 0.465	 1.68	 -0.75	 1.0	 100.0	 1	 2.24	 1.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2364; % PEL
	50286	 1.81	 0.465	 1.68	 -0.75	 1.0	 100.0	 1	 2.24	 1.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.2364; % PEL
	50287	 11.5	 1.7	 11.1	 -7.7	 1.0	 100.0	 1	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % PEL
	50287	 318.5	 42.8	 274.6	 -189.0	 1.0	 100.0	 1	 567.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 567.0; % COW
	50287	 318.5	 42.8	 274.6	 -189.0	 1.0	 100.0	 1	 567.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 567.0; % COW
	50287	 318.5	 42.8	 274.6	 -189.0	 1.0	 100.0	 1	 567.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 567.0; % COW
	50288	 8.3	 1.95	 7.7	 -3.8	 1.0	 100.0	 1	 11.35	 5.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.35; % PEL
	50288	 8.3	 1.95	 7.7	 -3.8	 1.0	 100.0	 1	 11.35	 5.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.35; % NG
	50290	 13.5	 0.0	 6.6	 -6.6	 1.0	 100.0	 1	 20.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	50290	 13.5	 0.0	 6.6	 -6.6	 1.0	 100.0	 1	 20.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	50290	 16.3	 0.0	 8.4	 -8.4	 1.0	 100.0	 1	 25.6	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.6; % NG
	50291	 303.0	 34.45	 220.9	 -152.0	 1.0	 100.0	 1	 456.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 456.0; % NG
	50292	 105.0	 15.85	 101.7	 -70.0	 1.0	 100.0	 1	 210.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50293	 82.35	 9.05	 58.0	 -39.9	 1.0	 100.0	 1	 119.7	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.7; % NG
	50293	 82.35	 9.05	 58.0	 -39.9	 1.0	 100.0	 1	 119.7	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.7; % COW
	50293	 128.15	 23.85	 103.1	 -55.4	 1.0	 100.0	 1	 166.3	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 166.3; % NG
	50294	 56.0	 0.0	 36.8	 -36.8	 1.0	 100.0	 1	 112.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.0; % NG
	50294	 56.0	 0.0	 36.8	 -36.8	 1.0	 100.0	 1	 112.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.0; % NG
	50294	 56.0	 0.0	 36.8	 -36.8	 1.0	 100.0	 1	 112.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.0; % COW
	50294	 56.0	 0.0	 36.8	 -36.8	 1.0	 100.0	 1	 112.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.0; % COW
	50294	 56.0	 0.0	 36.8	 -36.8	 1.0	 100.0	 1	 112.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.0; % NG
	50294	 56.0	 0.0	 36.8	 -36.8	 1.0	 100.0	 1	 112.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.0; % NG
	50294	 56.0	 0.0	 36.8	 -36.8	 1.0	 100.0	 1	 112.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.0; % NG
	50295	 52.0	 0.0	 43.7	 -43.7	 1.0	 100.0	 1	 99.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50296	 69.8	 7.05	 45.3	 -31.2	 1.0	 100.0	 1	 93.5	 46.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.5; % NG
	50296	 70.55	 7.15	 46.0	 -31.7	 1.0	 100.0	 1	 95.0	 46.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0; % COW
	50297	 38.75	 5.1	 32.7	 -22.5	 1.0	 100.0	 1	 67.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5; % PEL
	50297	 38.75	 5.1	 32.7	 -22.5	 1.0	 100.0	 1	 67.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5; % PEL
	50298	 43.75	 5.1	 32.7	 -22.5	 1.0	 100.0	 1	 67.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5; % NG
	50299	 29.25	 0.0	 19.2	 -19.2	 1.0	 100.0	 1	 58.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.5; % PEL
	50299	 29.25	 0.0	 19.2	 -19.2	 1.0	 100.0	 1	 58.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.5; % NG
	50299	 29.25	 0.0	 19.2	 -19.2	 1.0	 100.0	 1	 58.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.5; % PEL
	50299	 29.25	 0.0	 19.2	 -19.2	 1.0	 100.0	 1	 58.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.5; % NG
	50299	 29.25	 0.0	 19.2	 -19.2	 1.0	 100.0	 1	 58.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.5; % COW
	50299	 33.6	 0.0	 22.1	 -22.1	 1.0	 100.0	 1	 67.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.2; % NG
	50299	 33.6	 0.0	 22.1	 -22.1	 1.0	 100.0	 1	 67.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.2; % PEL
	50299	 33.6	 0.0	 22.1	 -22.1	 1.0	 100.0	 1	 67.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.2; % PEL
	50300	 26.8	 0.0	 20.2	 -20.2	 1.0	 100.0	 1	 51.0	 2.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	50301	 25.2	 0.0	 19.9	 -19.9	 1.0	 100.0	 1	 50.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50302	 28.95	 6.15	 26.6	 -14.3	 1.0	 100.0	 1	 42.9	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.9; % NG
	50303	 21.25	 0.0	 16.0	 -16.0	 1.0	 100.0	 1	 40.5	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50304	 20.0	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	50304	 20.0	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % PEL
	50304	 20.0	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % PEL
	50304	 20.0	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % COW
	50304	 20.0	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	50304	 20.0	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	50304	 20.0	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % COW
	50304	 20.0	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	50306	 15.25	 2.15	 13.9	 -9.6	 1.0	 100.0	 1	 28.8	 1.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % COW
	50308	 15.0	 0.0	 9.9	 -9.9	 1.0	 100.0	 1	 25.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50309	 16.05	 1.85	 11.7	 -8.0	 1.0	 100.0	 1	 24.1	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.1; % NG
	50310	 1317.15	 102.25	 655.9	 -451.4	 1.0	 100.0	 1	 1354.3	 1280.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50310	 1317.15	 102.25	 655.9	 -451.4	 1.0	 100.0	 1	 1354.3	 1280.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50311	 1163.5	 91.75	 588.5	 -405.0	 1.0	 100.0	 1	 1215.0	 1112.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NUC
	50311	 1159.0	 91.75	 588.5	 -405.0	 1.0	 100.0	 1	 1215.0	 1103.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NUC
	50312	 632.4	 0.0	 267.4	 -267.4	 1.0	 100.0	 1	 916.8	 348.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 916.8; % NUC
	50313	 646.5	 0.0	 324.1	 -324.1	 1.0	 100.0	 1	 893.0	 400.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 893.0; % COW
	50313	 678.4	 0.0	 407.6	 -407.6	 1.0	 100.0	 1	 956.8	 400.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 956.8; % COW
	50314	 765.6	 0.0	 260.7	 -260.7	 1.0	 100.0	 1	 793.2	 738.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 793.2; % COW
	50314	 0.0	 0.0	 260.7	 -260.7	 1.0	 100.0	 0	 793.2	 738.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 793.2; % COW
	50314	 0.0	 0.0	 260.7	 -260.7	 1.0	 100.0	 0	 793.2	 734.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 793.2; % COW
	50315	 415.0	 57.75	 370.5	 -255.0	 1.0	 100.0	 1	 765.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 765.0; % COW
	50315	 415.0	 57.75	 370.5	 -255.0	 1.0	 100.0	 1	 765.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 765.0; % COW
	50316	 560.5	 54.45	 349.2	 -240.3	 1.0	 100.0	 1	 721.0	 400.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 721.0; % COW
	50317	 467.5	 54.35	 348.7	 -240.0	 1.0	 100.0	 1	 720.0	 215.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 720.0; % COW
	50318	 570.75	 49.95	 320.4	 -220.5	 1.0	 100.0	 1	 661.5	 480.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 661.5; % COW
	50319	 486.2	 46.95	 301.4	 -207.5	 1.0	 100.0	 1	 622.4	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 622.4; % COW
	50320	 108.9	 26.9	 116.4	 -62.6	 1.0	 100.0	 1	 187.8	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.8; % NG
	50320	 108.9	 26.9	 116.4	 -62.6	 1.0	 100.0	 1	 187.8	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.8; % NG
	50320	 320.25	 43.8	 281.1	 -193.5	 1.0	 100.0	 1	 580.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 580.5; % COW
	50320	 454.55	 55.4	 355.5	 -244.7	 1.0	 100.0	 1	 734.1	 175.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 734.1; % COW
	50320	 454.55	 55.4	 355.5	 -244.7	 1.0	 100.0	 1	 734.1	 175.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 734.1; % COW
	50320	 179.6	 42.85	 185.4	 -99.7	 1.0	 100.0	 1	 299.2	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 299.2; % NG
	50320	 394.8	 71.7	 348.3	 -204.9	 1.0	 100.0	 1	 614.6	 175.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 614.6; % COW
	50320	 414.5	 76.3	 370.6	 -218.0	 1.0	 100.0	 1	 654.0	 175.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 654.0; % COW
	50321	 228.4	 38.875	 177.95	 -100.2	 1.0	 100.0	 1	 300.55	 156.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.55; % NG
	50321	 228.4	 38.875	 177.95	 -100.2	 1.0	 100.0	 1	 300.55	 156.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.55; % NG
	50322	 431.7	 44.8	 287.4	 -197.8	 1.0	 100.0	 1	 593.4	 270.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 593.4; % COW
	50322	 431.7	 44.8	 287.4	 -197.8	 1.0	 100.0	 1	 593.4	 270.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 593.4; % COW
	50323	 754.6	 0.0	 260.7	 -260.7	 1.0	 100.0	 1	 793.2	 716.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 793.2; % PEL
	50323	 557.7	 0.0	 252.8	 -252.8	 1.0	 100.0	 1	 593.4	 522.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 593.4; % NG
	50323	 557.7	 0.0	 252.8	 -252.8	 1.0	 100.0	 1	 593.4	 522.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 593.4; % COW
	50324	 565.3	 0.0	 214.4	 -214.4	 1.0	 100.0	 1	 590.6	 540.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 590.6; % COW
	50325	 376.45	 42.85	 275.0	 -189.3	 1.0	 100.0	 1	 567.9	 185.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 567.9; % COW
	50325	 376.45	 42.85	 275.0	 -189.3	 1.0	 100.0	 1	 567.9	 185.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 567.9; % COW
	50326	 584.0	 66.25	 425.2	 -292.7	 1.0	 100.0	 1	 878.0	 290.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 878.0; % COW
	50326	 344.0	 42.7	 274.1	 -188.7	 1.0	 100.0	 1	 566.0	 122.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 566.0; % COW
	50327	 354.0	 42.15	 270.3	 -186.0	 1.0	 100.0	 1	 558.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 558.0; % COW
	50327	 354.0	 42.15	 270.3	 -186.0	 1.0	 100.0	 1	 558.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 558.0; % COW
	50327	 354.0	 42.15	 270.3	 -186.0	 1.0	 100.0	 1	 558.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 558.0; % COW
	50328	 320.0	 34.75	 222.8	 -153.3	 1.0	 100.0	 1	 460.0	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 460.0; % NG
	50328	 387.5	 46.45	 297.9	 -205.0	 1.0	 100.0	 1	 615.0	 160.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 615.0; % COW
	50328	 387.5	 46.45	 297.9	 -205.0	 1.0	 100.0	 1	 615.0	 160.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 615.0; % NG
	50329	 301.75	 34.2	 219.6	 -151.2	 1.0	 100.0	 1	 453.5	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 453.5; % NG
	50330	 27.95	 7.45	 32.2	 -17.3	 1.0	 100.0	 1	 51.9	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.9; % NG
	50330	 176.0	 18.925	 113.4	 -75.55	 1.0	 100.0	 1	 226.6	 125.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 226.6; % COW
	50330	 176.0	 18.925	 113.4	 -75.55	 1.0	 100.0	 1	 226.6	 125.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 226.6; % NG
	50330	 105.0	 9.75	 62.5	 -43.0	 1.0	 100.0	 1	 129.0	 81.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.0; % NG
	50330	 105.0	 9.75	 62.5	 -43.0	 1.0	 100.0	 1	 129.0	 81.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.0; % NG
	50330	 105.0	 9.75	 62.5	 -43.0	 1.0	 100.0	 1	 129.0	 81.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.0; % NG
	50331	 258.0	 33.65	 216.0	 -148.7	 1.0	 100.0	 1	 446.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 446.0; % COW
	50331	 258.0	 33.65	 216.0	 -148.7	 1.0	 100.0	 1	 446.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 446.0; % NG
	50332	 270.5	 33.65	 216.0	 -148.7	 1.0	 100.0	 1	 446.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 446.0; % NG
	50333	 285.5	 33.65	 216.0	 -148.7	 1.0	 100.0	 1	 446.0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 446.0; % COW
	50333	 305.5	 36.7	 235.4	 -162.0	 1.0	 100.0	 1	 486.0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 486.0; % NG
	50334	 330.0	 30.95	 198.6	 -136.7	 1.0	 100.0	 1	 410.0	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 410.0; % NG
	50335	 287.5	 0.0	 207.3	 -207.3	 1.0	 100.0	 1	 455.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 455.0; % COW
	50335	 287.5	 0.0	 207.3	 -207.3	 1.0	 100.0	 1	 455.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 455.0; % COW
	50335	 227.4	 84.35	 303.6	 -134.9	 1.0	 100.0	 1	 404.8	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 404.8; % NG
	50336	 497.5	 40.1	 257.2	 -177.0	 1.0	 100.0	 1	 531.0	 464.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 531.0; % COW
	50336	 374.75	 29.9	 192.0	 -132.2	 1.0	 100.0	 1	 396.5	 353.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 396.5; % NG
	50337	 261.5	 27.2	 174.4	 -120.0	 1.0	 100.0	 1	 360.0	 163.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 360.0; % NG
	50337	 261.5	 27.2	 174.4	 -120.0	 1.0	 100.0	 1	 360.0	 163.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 360.0; % COW
	50337	 261.5	 27.2	 174.4	 -120.0	 1.0	 100.0	 1	 360.0	 163.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 360.0; % NG
	50338	 237.5	 21.5	 138.0	 -95.0	 1.0	 100.0	 1	 285.0	 190.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 285.0; % NG
	50338	 106.5	 10.05	 64.4	 -44.3	 1.0	 100.0	 1	 133.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.0; % NG
	50339	 283.2	 21.4	 137.2	 -94.4	 1.0	 100.0	 1	 283.2	 283.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50340	 146.05	 20.95	 134.6	 -92.7	 1.0	 100.0	 1	 278.0	 14.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50341	 160.7	 31.65	 153.8	 -90.5	 1.0	 100.0	 1	 271.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.4; % NG
	50341	 160.7	 31.65	 153.8	 -90.5	 1.0	 100.0	 1	 271.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.4; % COW
	50342	 218.5	 38.25	 165.5	 -89.0	 1.0	 100.0	 1	 267.0	 170.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 267.0; % NG
	50342	 201.0	 38.25	 165.5	 -89.0	 1.0	 100.0	 1	 267.0	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 267.0; % COW
	50342	 201.0	 38.25	 165.5	 -89.0	 1.0	 100.0	 1	 267.0	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 267.0; % COW
	50343	 124.5	 18.8	 120.6	 -83.0	 1.0	 100.0	 1	 249.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50344	 225.35	 35.45	 153.5	 -82.6	 1.0	 100.0	 1	 247.7	 203.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 247.7; % NG
	50344	 369.0	 29.2	 187.4	 -129.0	 1.0	 100.0	 1	 387.0	 351.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 387.0; % NG
	50345	 151.75	 18.7	 119.9	 -82.5	 1.0	 100.0	 1	 247.5	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 247.5; % NG
	50345	 151.75	 18.7	 119.9	 -82.5	 1.0	 100.0	 1	 247.5	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 247.5; % NG
	50346	 163.95	 18.4	 118.1	 -81.3	 1.0	 100.0	 1	 243.9	 84.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 243.9; % NG
	50346	 163.95	 18.4	 118.1	 -81.3	 1.0	 100.0	 1	 243.9	 84.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 243.9; % NG
	50346	 192.3	 22.7	 145.6	 -100.2	 1.0	 100.0	 1	 300.6	 84.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.6; % NG
	50347	 196.0	 19.8	 126.9	 -87.3	 1.0	 100.0	 1	 262.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 262.0; % NG
	50347	 163.5	 18.25	 117.2	 -80.7	 1.0	 100.0	 1	 242.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 242.0; % NG
	50347	 163.5	 18.25	 117.2	 -80.7	 1.0	 100.0	 1	 242.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 242.0; % COW
	50348	 195.85	 34.6	 149.8	 -80.6	 1.0	 100.0	 1	 241.7	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 241.7; % NG
	50348	 195.85	 34.6	 149.8	 -80.6	 1.0	 100.0	 1	 241.7	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 241.7; % NG
	50348	 201.4	 36.2	 156.7	 -84.3	 1.0	 100.0	 1	 252.8	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 252.8; % COW
	50348	 201.4	 36.2	 156.7	 -84.3	 1.0	 100.0	 1	 252.8	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 252.8; % NG
	50349	 120.5	 18.2	 116.7	 -80.3	 1.0	 100.0	 1	 241.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50350	 144.7	 34.3	 148.4	 -79.8	 1.0	 100.0	 1	 239.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 239.4; % NG
	50350	 144.7	 34.3	 148.4	 -79.8	 1.0	 100.0	 1	 239.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 239.4; % NG
	50350	 388.3	 69.05	 335.3	 -197.2	 1.0	 100.0	 1	 591.6	 185.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 591.6; % NG
	50350	 264.2	 55.25	 268.3	 -157.8	 1.0	 100.0	 1	 473.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 473.4; % NG
	50350	 281.2	 59.25	 287.6	 -169.1	 1.0	 100.0	 1	 507.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 507.4; % NG
	50351	 221.15	 34.25	 148.3	 -79.8	 1.0	 100.0	 1	 239.3	 203.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 239.3; % NG
	50353	 182.5	 40.8	 176.6	 -95.0	 1.0	 100.0	 1	 285.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 285.0; % NG
	50353	 167.5	 16.2	 104.1	 -71.7	 1.0	 100.0	 1	 215.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 215.0; % NG
	50353	 167.5	 16.2	 104.1	 -71.7	 1.0	 100.0	 1	 215.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 215.0; % NG
	50354	 106.55	 16.1	 103.2	 -71.0	 1.0	 100.0	 1	 213.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50354	 111.8	 16.85	 108.2	 -74.5	 1.0	 100.0	 1	 223.5	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50354	 149.55	 22.55	 144.8	 -99.7	 1.0	 100.0	 1	 299.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50355	 150.0	 20.75	 133.2	 -91.7	 1.0	 100.0	 1	 275.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 275.0; % NG
	50355	 107.0	 30.05	 130.1	 -70.0	 1.0	 100.0	 1	 210.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 210.0; % NG
	50355	 109.4	 30.75	 133.1	 -71.6	 1.0	 100.0	 1	 214.8	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 214.8; % NG
	50355	 109.4	 30.75	 133.1	 -71.6	 1.0	 100.0	 1	 214.8	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 214.8; % NG
	50356	 104.5	 15.75	 101.2	 -69.7	 1.0	 100.0	 1	 209.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % COW
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % COW
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % PEL
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % COW
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % COW
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % COW
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50357	 6.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50358	 100.8	 15.2	 97.6	 -67.2	 1.0	 100.0	 1	 201.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50360	 100.05	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50361	 212.8	 57.4	 206.7	 -91.9	 1.0	 100.0	 1	 275.6	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 275.6; % NG
	50361	 145.0	 41.65	 150.0	 -66.7	 1.0	 100.0	 1	 200.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	50361	 145.0	 41.65	 150.0	 -66.7	 1.0	 100.0	 1	 200.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	50362	 125.0	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50363	 125.0	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50364	 99.75	 15.05	 96.6	 -66.5	 1.0	 100.0	 1	 199.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50365	 104.95	 15.0	 96.3	 -66.3	 1.0	 100.0	 1	 198.9	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	50365	 325.25	 43.8	 281.1	 -193.5	 1.0	 100.0	 1	 580.5	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 580.5; % COW
	50365	 207.5	 29.9	 191.8	 -132.0	 1.0	 100.0	 1	 396.0	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 396.0; % NG
	50366	 146.95	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	50366	 146.95	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	50366	 105.25	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % COW
	50367	 117.25	 22.8	 98.8	 -53.2	 1.0	 100.0	 1	 159.5	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.5; % NG
	50367	 117.25	 22.8	 98.8	 -53.2	 1.0	 100.0	 1	 159.5	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.5; % NG
	50367	 117.25	 22.8	 98.8	 -53.2	 1.0	 100.0	 1	 159.5	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.5; % NG
	50367	 117.25	 22.8	 98.8	 -53.2	 1.0	 100.0	 1	 159.5	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.5; % NG
	50367	 136.95	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % COW
	50367	 136.95	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	50367	 136.95	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	50367	 136.95	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9; % NG
	50368	 33.2	 3.9	 24.9	 -17.1	 1.0	 100.0	 1	 51.4	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.4; % NG
	50368	 31.7	 3.9	 24.9	 -17.1	 1.0	 100.0	 1	 51.4	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.4; % NG
	50368	 31.7	 7.4	 31.9	 -17.1	 1.0	 100.0	 1	 51.4	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.4; % NG
	50368	 31.7	 7.4	 31.9	 -17.1	 1.0	 100.0	 1	 51.4	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.4; % COW
	50368	 31.7	 7.4	 31.9	 -17.1	 1.0	 100.0	 1	 51.4	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.4; % PEL
	50368	 31.7	 7.4	 31.9	 -17.1	 1.0	 100.0	 1	 51.4	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.4; % NG
	50368	 145.0	 28.35	 122.7	 -66.0	 1.0	 100.0	 1	 198.0	 92.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.0; % NG
	50368	 122.5	 27.25	 117.8	 -63.3	 1.0	 100.0	 1	 190.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.0; % NG
	50369	 98.5	 14.85	 95.4	 -65.7	 1.0	 100.0	 1	 197.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50370	 145.0	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	50370	 158.45	 14.9	 95.4	 -65.6	 1.0	 100.0	 1	 196.9	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.9; % NG
	50371	 148.75	 14.75	 94.7	 -65.2	 1.0	 100.0	 1	 195.5	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % COW
	50371	 148.75	 14.75	 94.7	 -65.2	 1.0	 100.0	 1	 195.5	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5; % NG
	50371	 132.0	 29.2	 126.4	 -68.0	 1.0	 100.0	 1	 204.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0; % NG
	50372	 114.95	 21.45	 92.9	 -50.0	 1.0	 100.0	 1	 149.9	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 149.9; % NG
	50372	 156.05	 27.55	 119.1	 -64.0	 1.0	 100.0	 1	 192.1	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.1; % NG
	50372	 156.05	 27.55	 119.1	 -64.0	 1.0	 100.0	 1	 192.1	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.1; % NG
	50372	 156.05	 27.55	 119.1	 -64.0	 1.0	 100.0	 1	 192.1	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.1; % NG
	50372	 156.05	 27.55	 119.1	 -64.0	 1.0	 100.0	 1	 192.1	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.1; % NG
	50373	 225.0	 26.5	 170.0	 -117.0	 1.0	 100.0	 1	 351.0	 99.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 351.0; % NG
	50373	 124.8	 27.15	 117.5	 -63.2	 1.0	 100.0	 1	 189.6	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.6; % NG
	50373	 124.8	 27.15	 117.5	 -63.2	 1.0	 100.0	 1	 189.6	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.6; % NG
	50374	 225.0	 26.5	 170.0	 -117.0	 1.0	 100.0	 1	 351.0	 99.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 351.0; % NG
	50374	 203.5	 26.6	 170.5	 -117.3	 1.0	 100.0	 1	 352.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 352.0; % NG
	50374	 124.8	 27.15	 117.5	 -63.2	 1.0	 100.0	 1	 189.6	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.6; % COW
	50374	 124.8	 27.15	 117.5	 -63.2	 1.0	 100.0	 1	 189.6	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.6; % NG
	50375	 211.6	 53.45	 231.3	 -124.4	 1.0	 100.0	 1	 373.2	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 373.2; % COW
	50375	 134.5	 27.05	 117.1	 -63.0	 1.0	 100.0	 1	 189.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.0; % NG
	50375	 134.5	 27.05	 117.1	 -63.0	 1.0	 100.0	 1	 189.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.0; % NG
	50375	 134.5	 27.05	 117.1	 -63.0	 1.0	 100.0	 1	 189.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.0; % NG
	50376	 201.15	 34.7	 150.2	 -80.8	 1.0	 100.0	 1	 242.3	 160.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 242.3; % NG
	50376	 133.1	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	50376	 133.1	 26.95	 116.6	 -62.7	 1.0	 100.0	 1	 188.2	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.2; % NG
	50377	 108.9	 26.9	 116.4	 -62.6	 1.0	 100.0	 1	 187.8	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.8; % NG
	50377	 108.9	 26.9	 116.4	 -62.6	 1.0	 100.0	 1	 187.8	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.8; % NG
	50377	 127.65	 32.25	 139.6	 -75.1	 1.0	 100.0	 1	 225.3	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 225.3; % COW
	50377	 127.65	 32.25	 139.6	 -75.1	 1.0	 100.0	 1	 225.3	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 225.3; % NG
	50378	 136.6	 13.8	 88.7	 -61.1	 1.0	 100.0	 1	 183.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.2; % NG
	50378	 136.6	 13.8	 88.7	 -61.1	 1.0	 100.0	 1	 183.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.2; % NG
	50378	 136.6	 13.8	 88.7	 -61.1	 1.0	 100.0	 1	 183.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.2; % NG
	50378	 225.05	 29.45	 188.9	 -130.0	 1.0	 100.0	 1	 390.1	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 390.1; % COW
	50379	 136.6	 13.8	 88.7	 -61.1	 1.0	 100.0	 1	 183.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.2; % NG
	50379	 136.6	 13.8	 88.7	 -61.1	 1.0	 100.0	 1	 183.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.2; % NG
	50379	 136.6	 13.8	 88.7	 -61.1	 1.0	 100.0	 1	 183.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.2; % NG
	50379	 290.0	 29.45	 188.9	 -130.0	 1.0	 100.0	 1	 390.0	 190.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 390.0; % NG
	50380	 105.0	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % COW
	50380	 195.5	 26.5	 170.0	 -117.0	 1.0	 100.0	 1	 351.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 351.0; % NG
	50380	 195.5	 26.5	 170.0	 -117.0	 1.0	 100.0	 1	 351.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 351.0; % NG
	50381	 141.0	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	50381	 141.0	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % COW
	50381	 141.0	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	50381	 141.0	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	50381	 158.0	 20.85	 133.7	 -92.0	 1.0	 100.0	 1	 276.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 276.0; % COW
	50382	 145.0	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	50382	 42.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % NG
	50384	 90.0	 13.6	 87.2	 -60.0	 1.0	 100.0	 1	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50385	 154.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % COW
	50385	 154.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	50385	 124.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5; % NG
	50386	 139.1	 13.45	 86.3	 -59.4	 1.0	 100.0	 1	 178.2	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.2; % NG
	50386	 102.2	 7.9	 50.6	 -34.8	 1.0	 100.0	 1	 104.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.4; % COW
	50387	 163.4	 36.85	 132.6	 -58.9	 1.0	 100.0	 1	 176.8	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.8; % NG
	50387	 489.3	 39.75	 255.0	 -175.5	 1.0	 100.0	 1	 526.6	 452.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 526.6; % COW
	50388	 123.3	 25.25	 109.4	 -58.9	 1.0	 100.0	 1	 176.6	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.6; % COW
	50388	 123.3	 25.25	 109.4	 -58.9	 1.0	 100.0	 1	 176.6	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.6; % NG
	50388	 124.05	 28.4	 122.8	 -66.0	 1.0	 100.0	 1	 198.1	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.1; % NG
	50389	 143.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	50389	 137.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 98.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % COW
	50389	 133.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	50389	 133.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % COW
	50389	 140.2	 32.15	 139.1	 -74.8	 1.0	 100.0	 1	 224.4	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 224.4; % NG
	50389	 140.2	 32.15	 139.1	 -74.8	 1.0	 100.0	 1	 224.4	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 224.4; % COW
	50390	 132.5	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	50390	 132.5	 13.25	 84.8	 -58.3	 1.0	 100.0	 1	 175.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	50390	 130.0	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	50391	 132.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 185.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % PEL
	50391	 132.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 185.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	50391	 132.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 185.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	50391	 120.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 175.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0; % NG
	50391	 72.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 85.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	50392	 134.8	 13.2	 84.6	 -58.2	 1.0	 100.0	 1	 174.6	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.6; % NG
	50392	 134.8	 13.2	 84.6	 -58.2	 1.0	 100.0	 1	 174.6	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.6; % NG
	50393	 143.8	 13.05	 83.6	 -57.5	 1.0	 100.0	 1	 172.6	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.6; % NG
	50393	 132.1	 13.15	 84.4	 -58.1	 1.0	 100.0	 1	 174.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.2; % NG
	50393	 132.1	 13.15	 84.4	 -58.1	 1.0	 100.0	 1	 174.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.2; % NG
	50394	 142.5	 26.5	 114.7	 -61.7	 1.0	 100.0	 1	 185.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0; % NG
	50394	 121.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0; % NG
	50394	 121.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0; % NG
	50395	 135.85	 24.6	 106.4	 -57.2	 1.0	 100.0	 1	 171.7	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 171.7; % NG
	50395	 138.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	50395	 138.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	50395	 138.0	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0; % NG
	50395	 134.65	 29.25	 126.6	 -68.1	 1.0	 100.0	 1	 204.3	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.3; % NG
	50395	 134.65	 29.25	 126.6	 -68.1	 1.0	 100.0	 1	 204.3	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.3; % NG
	50396	 135.55	 24.5	 106.0	 -57.0	 1.0	 100.0	 1	 171.1	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 171.1; % NG
	50396	 135.55	 24.5	 106.0	 -57.0	 1.0	 100.0	 1	 171.1	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 171.1; % NG
	50396	 135.55	 24.5	 106.0	 -57.0	 1.0	 100.0	 1	 171.1	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 171.1; % NG
	50396	 135.55	 24.5	 106.0	 -57.0	 1.0	 100.0	 1	 171.1	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 171.1; % NG
	50396	 170.35	 28.9	 125.1	 -67.3	 1.0	 100.0	 1	 201.9	 138.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 201.9; % COW
	50396	 170.2	 28.9	 125.1	 -67.3	 1.0	 100.0	 1	 201.9	 138.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 201.9; % NG
	50397	 85.1	 12.85	 82.4	 -56.7	 1.0	 100.0	 1	 170.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50398	 135.25	 25.35	 109.6	 -58.9	 1.0	 100.0	 1	 176.8	 93.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.8; % COW
	50398	 130.125	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.1	 90.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.1; % NG
	50398	 130.125	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.1	 90.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.1; % NG
	50399	 135.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	50399	 135.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	50399	 72.85	 18.25	 79.1	 -42.6	 1.0	 100.0	 1	 127.7	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 127.7; % PEL
	50400	 167.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 164.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	50400	 167.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 164.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	50400	 180.0	 42.95	 185.9	 -100.0	 1.0	 100.0	 1	 300.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.0; % NG
	50401	 135.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	50401	 135.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	50401	 140.0	 32.9	 142.5	 -76.7	 1.0	 100.0	 1	 230.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.0; % NG
	50402	 130.0	 12.8	 82.3	 -56.7	 1.0	 100.0	 1	 170.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	50402	 130.0	 12.8	 82.3	 -56.7	 1.0	 100.0	 1	 170.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0; % NG
	50403	 124.9	 24.3	 105.2	 -56.6	 1.0	 100.0	 1	 169.8	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 169.8; % NG
	50403	 124.9	 24.3	 105.2	 -56.6	 1.0	 100.0	 1	 169.8	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 169.8; % PEL
	50403	 124.9	 24.3	 105.2	 -56.6	 1.0	 100.0	 1	 169.8	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 169.8; % PEL
	50403	 124.9	 24.3	 105.2	 -56.6	 1.0	 100.0	 1	 169.8	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 169.8; % NG
	50403	 124.9	 24.3	 105.2	 -56.6	 1.0	 100.0	 1	 169.8	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 169.8; % NG
	50403	 124.9	 24.3	 105.2	 -56.6	 1.0	 100.0	 1	 169.8	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 169.8; % NG
	50403	 245.5	 59.55	 257.8	 -138.7	 1.0	 100.0	 1	 416.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 416.0; % NG
	50403	 245.5	 59.55	 257.8	 -138.7	 1.0	 100.0	 1	 416.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 416.0; % NG
	50404	 84.75	 12.8	 82.1	 -56.5	 1.0	 100.0	 1	 169.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50406	 138.5	 23.9	 103.5	 -55.7	 1.0	 100.0	 1	 167.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.0; % NG
	50406	 138.5	 23.9	 103.5	 -55.7	 1.0	 100.0	 1	 167.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.0; % NG
	50406	 138.5	 23.9	 103.5	 -55.7	 1.0	 100.0	 1	 167.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.0; % NG
	50406	 137.5	 35.8	 154.9	 -83.3	 1.0	 100.0	 1	 250.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 250.0; % NG
	50406	 64.5	 15.75	 68.2	 -36.7	 1.0	 100.0	 1	 110.0	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.0; % NG
	50407	 118.35	 23.85	 103.3	 -55.6	 1.0	 100.0	 1	 166.7	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 166.7; % NG
	50407	 118.35	 23.85	 103.3	 -55.6	 1.0	 100.0	 1	 166.7	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 166.7; % NG
	50407	 118.35	 23.85	 103.3	 -55.6	 1.0	 100.0	 1	 166.7	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 166.7; % NG
	50407	 118.35	 23.85	 103.3	 -55.6	 1.0	 100.0	 1	 166.7	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 166.7; % NG
	50407	 117.3	 26.45	 114.4	 -61.5	 1.0	 100.0	 1	 184.6	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.6; % NG
	50407	 117.3	 26.45	 114.4	 -61.5	 1.0	 100.0	 1	 184.6	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.6; % NG
	50408	 140.5	 12.55	 80.4	 -55.3	 1.0	 100.0	 1	 166.0	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 166.0; % NG
	50408	 140.5	 12.55	 80.4	 -55.3	 1.0	 100.0	 1	 166.0	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 166.0; % COW
	50408	 65.0	 7.55	 48.4	 -33.3	 1.0	 100.0	 1	 100.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0; % NG
	50409	 82.8	 0.0	 73.0	 -73.0	 1.0	 100.0	 1	 165.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50410	 102.0	 19.05	 92.5	 -54.4	 1.0	 100.0	 1	 163.2	 40.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2; % COW
	50411	 81.0	 0.0	 71.0	 -71.0	 1.0	 100.0	 1	 161.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50412	 85.2	 0.0	 70.5	 -70.5	 1.0	 100.0	 1	 160.0	 10.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50413	 127.0	 22.05	 95.4	 -51.3	 1.0	 100.0	 1	 154.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 154.0; % NG
	50413	 127.0	 22.05	 95.4	 -51.3	 1.0	 100.0	 1	 154.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 154.0; % NG
	50413	 127.0	 22.05	 95.4	 -51.3	 1.0	 100.0	 1	 154.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 154.0; % NG
	50413	 157.5	 35.8	 154.9	 -83.3	 1.0	 100.0	 1	 250.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 250.0; % NG
	50413	 80.0	 7.15	 46.0	 -31.7	 1.0	 100.0	 1	 95.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0; % NG
	50414	 27.995	 7.95	 28.6	 -12.7	 1.0	 100.0	 1	 38.12	 17.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.125; % NG
	50414	 27.995	 7.95	 28.6	 -12.7	 1.0	 100.0	 1	 38.12	 17.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.125; % NG
	50414	 27.995	 7.95	 28.6	 -12.7	 1.0	 100.0	 1	 38.12	 17.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.125; % COW
	50414	 27.995	 7.95	 28.6	 -12.7	 1.0	 100.0	 1	 38.12	 17.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.125; % NG
	50414	 27.7	 7.15	 25.8	 -11.5	 1.0	 100.0	 1	 34.4	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.4; % NG
	50414	 35.75	 10.1	 36.4	 -16.2	 1.0	 100.0	 1	 48.5	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.5; % NG
	50414	 20.65	 6.0	 21.6	 -9.6	 1.0	 100.0	 1	 28.8	 12.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % PEL
	50414	 19.1	 5.65	 20.4	 -9.1	 1.0	 100.0	 1	 27.2	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.2; % NG
	50418	 75.0	 0.0	 66.1	 -66.1	 1.0	 100.0	 1	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50419	 75.5	 0.0	 66.1	 -66.1	 1.0	 100.0	 1	 150.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50420	 116.5	 20.45	 88.6	 -47.7	 1.0	 100.0	 1	 143.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 143.0; % COW
	50420	 116.5	 20.45	 88.6	 -47.7	 1.0	 100.0	 1	 143.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 143.0; % NG
	50420	 116.5	 20.45	 88.6	 -47.7	 1.0	 100.0	 1	 143.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 143.0; % NG
	50420	 116.5	 20.45	 88.6	 -47.7	 1.0	 100.0	 1	 143.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 143.0; % COW
	50421	 71.25	 0.0	 62.8	 -62.8	 1.0	 100.0	 1	 142.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50422	 79.0	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % NG
	50422	 79.0	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % NG
	50422	 205.5	 26.5	 170.0	 -117.0	 1.0	 100.0	 1	 351.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 351.0; % COW
	50423	 75.35	 19.45	 84.1	 -45.2	 1.0	 100.0	 1	 135.7	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.7; % NG
	50423	 75.5	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0; % NG
	50423	 340.25	 43.8	 281.1	 -193.5	 1.0	 100.0	 1	 580.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 580.5; % NG
	50424	 67.5	 0.0	 59.5	 -59.5	 1.0	 100.0	 1	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	50425	 83.4	 18.9	 81.7	 -43.9	 1.0	 100.0	 1	 131.8	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 131.8; % COW
	50425	 83.4	 18.9	 81.7	 -43.9	 1.0	 100.0	 1	 131.8	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 131.8; % NG
	50426	 65.25	 0.0	 57.5	 -57.5	 1.0	 100.0	 1	 130.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50427	 63.25	 0.0	 55.8	 -55.8	 1.0	 100.0	 1	 126.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50428	 62.1	 0.0	 54.8	 -54.8	 1.0	 100.0	 1	 124.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50429	 76.565	 14.3	 69.4	 -40.8	 1.0	 100.0	 1	 122.5	 30.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.5; % NG
	50429	 117.19	 21.9	 106.3	 -62.5	 1.0	 100.0	 1	 187.5	 46.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.5; % NG
	50429	 231.72	 37.1	 206.2	 -132.0	 1.0	 100.0	 1	 396.1	 67.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 396.1; % NG
	50430	 61.45	 0.0	 53.7	 -53.7	 1.0	 100.0	 1	 121.9	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50431	 60.3	 0.0	 53.2	 -53.2	 1.0	 100.0	 1	 120.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50433	 60.0	 0.0	 52.9	 -52.9	 1.0	 100.0	 1	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50434	 60.0	 0.0	 52.9	 -52.9	 1.0	 100.0	 1	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	50435	 98.5	 0.0	 7.4	 -7.4	 1.0	 100.0	 1	 117.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.0; % COW
	50435	 103.45	 9.6	 61.5	 -42.3	 1.0	 100.0	 1	 126.9	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 126.9; % NG
	50436	 57.75	 0.0	 50.9	 -50.9	 1.0	 100.0	 1	 115.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50437	 59.85	 0.0	 50.3	 -50.3	 1.0	 100.0	 1	 114.0	 5.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50438	 59.85	 0.0	 50.3	 -50.3	 1.0	 100.0	 1	 114.0	 5.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50439	 136.25	 18.7	 119.9	 -82.5	 1.0	 100.0	 1	 247.5	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 247.5; % NG
	50439	 69.3	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % NG
	50439	 65.8	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % NG
	50440	 15.72	 2.35	 11.8	 -7.1	 1.0	 100.0	 1	 21.3	 10.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.3; % NG
	50440	 21.75	 5.8	 25.1	 -13.5	 1.0	 100.0	 1	 40.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.5; % NG
	50440	 14.25	 5.3	 19.1	 -8.5	 1.0	 100.0	 1	 25.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5; % NG
	50440	 15.77	 2.835	 15.07	 -9.4	 1.0	 100.0	 1	 28.22	 3.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.225; % NG
	50440	 15.77	 2.835	 15.07	 -9.4	 1.0	 100.0	 1	 28.22	 3.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.225; % PEL
	50440	 15.77	 2.835	 15.07	 -9.4	 1.0	 100.0	 1	 28.22	 3.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.225; % PEL
	50440	 15.77	 2.835	 15.07	 -9.4	 1.0	 100.0	 1	 28.22	 3.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.225; % PEL
	50441	 100.45	 14.05	 90.1	 -62.0	 1.0	 100.0	 1	 186.0	 14.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50441	 111.0	 16.2	 103.9	 -71.5	 1.0	 100.0	 1	 214.5	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50441	 85.5	 0.0	 65.9	 -65.9	 1.0	 100.0	 1	 149.5	 21.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50441	 59.05	 0.0	 49.6	 -49.6	 1.0	 100.0	 1	 112.5	 5.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50442	 73.0	 0.0	 46.3	 -46.3	 1.0	 100.0	 1	 141.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 141.0; % COW
	50442	 84.0	 0.0	 33.9	 -33.9	 1.0	 100.0	 1	 103.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.0; % NG
	50442	 84.0	 0.0	 33.9	 -33.9	 1.0	 100.0	 1	 103.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.0; % NG
	50442	 84.0	 0.0	 33.9	 -33.9	 1.0	 100.0	 1	 103.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.0; % NG
	50443	 61.2	 14.7	 63.5	 -34.1	 1.0	 100.0	 1	 102.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 102.4; % NG
	50444	 80.95	 21.2	 76.4	 -34.0	 1.0	 100.0	 1	 101.9	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.9; % COW
	50447	 33.21	 5.0	 25.0	 -15.0	 1.0	 100.0	 1	 45.0	 21.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	50447	 75.735	 9.95	 52.9	 -33.0	 1.0	 100.0	 1	 99.0	 52.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.0; % NG
	50447	 75.735	 9.95	 52.9	 -33.0	 1.0	 100.0	 1	 99.0	 52.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.0; % NG
	50448	 125.45	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 200.9	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.9; % NG
	50448	 84.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 99.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.0; % COW
	50448	 84.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 99.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.0; % NG
	50448	 74.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 99.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.0; % NG
	50449	 36.9	 4.9	 31.4	 -21.6	 1.0	 100.0	 1	 64.8	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.8; % NG
	50449	 72.25	 9.5	 50.5	 -31.5	 1.0	 100.0	 1	 94.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.5; % NG
	50449	 69.75	 13.55	 58.6	 -31.5	 1.0	 100.0	 1	 94.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.5; % NG
	50449	 69.75	 13.55	 58.6	 -31.5	 1.0	 100.0	 1	 94.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.5; % NG
	50449	 84.5	 17.0	 73.7	 -39.7	 1.0	 100.0	 1	 119.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.0; % NG
	50449	 84.5	 17.0	 73.7	 -39.7	 1.0	 100.0	 1	 119.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.0; % PEL
	50449	 70.65	 15.95	 69.0	 -37.1	 1.0	 100.0	 1	 111.3	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 111.3; % NG
	50450	 45.75	 0.0	 40.3	 -40.3	 1.0	 100.0	 1	 91.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	50451	 45.0	 0.0	 39.7	 -39.7	 1.0	 100.0	 1	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50452	 106.5	 19.9	 96.6	 -56.8	 1.0	 100.0	 1	 170.4	 42.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.4; % NG
	50452	 320.85	 39.05	 250.6	 -172.5	 1.0	 100.0	 1	 517.5	 124.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 517.5; % COW
	50452	 74.7	 6.75	 43.3	 -29.8	 1.0	 100.0	 1	 89.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % COW
	50452	 74.7	 6.75	 43.3	 -29.8	 1.0	 100.0	 1	 89.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % NG
	50452	 74.7	 6.75	 43.3	 -29.8	 1.0	 100.0	 1	 89.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % NG
	50452	 74.7	 6.75	 43.3	 -29.8	 1.0	 100.0	 1	 89.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % NG
	50452	 74.7	 6.75	 43.3	 -29.8	 1.0	 100.0	 1	 89.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % NG
	50452	 74.7	 6.75	 43.3	 -29.8	 1.0	 100.0	 1	 89.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % NG
	50453	 108.95	 16.45	 71.2	 -38.3	 1.0	 100.0	 1	 114.9	 103.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.9; % NG
	50453	 506.25	 40.45	 259.4	 -178.5	 1.0	 100.0	 1	 535.5	 477.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 535.5; % COW
	50453	 74.7	 6.75	 43.3	 -29.8	 1.0	 100.0	 1	 89.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % NG
	50453	 74.7	 6.75	 43.3	 -29.8	 1.0	 100.0	 1	 89.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % NG
	50453	 74.7	 6.75	 43.3	 -29.8	 1.0	 100.0	 1	 89.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % NG
	50453	 74.7	 6.75	 43.3	 -29.8	 1.0	 100.0	 1	 89.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % NG
	50453	 74.7	 6.75	 43.3	 -29.8	 1.0	 100.0	 1	 89.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % NG
	50454	 495.505	 61.45	 389.3	 -266.4	 1.0	 100.0	 1	 799.2	 191.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 799.2; % COW
	50454	 74.7	 6.75	 43.3	 -29.8	 1.0	 100.0	 1	 89.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % NG
	50454	 74.7	 6.75	 43.3	 -29.8	 1.0	 100.0	 1	 89.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % COW
	50454	 74.7	 6.75	 43.3	 -29.8	 1.0	 100.0	 1	 89.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % NG
	50454	 74.7	 6.75	 43.3	 -29.8	 1.0	 100.0	 1	 89.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4; % NG
	50455	 69.1	 12.65	 54.7	 -29.4	 1.0	 100.0	 1	 88.2	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2; % NG
	50455	 69.1	 12.65	 54.7	 -29.4	 1.0	 100.0	 1	 88.2	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2; % PEL
	50456	 63.9	 12.55	 54.4	 -29.3	 1.0	 100.0	 1	 87.8	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.8; % COW
	50456	 63.9	 12.55	 54.4	 -29.3	 1.0	 100.0	 1	 87.8	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.8; % NG
	50456	 55.0	 12.9	 55.8	 -30.0	 1.0	 100.0	 1	 90.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	50457	 64.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	50457	 64.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	50458	 75.9	 17.45	 75.5	 -40.6	 1.0	 100.0	 1	 121.8	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.8; % COW
	50458	 54.8	 11.7	 50.6	 -27.2	 1.0	 100.0	 1	 81.6	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % NG
	50458	 54.8	 11.7	 50.6	 -27.2	 1.0	 100.0	 1	 81.6	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % NG
	50458	 57.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	50458	 57.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	50458	 72.5	 9.05	 58.1	 -40.0	 1.0	 100.0	 1	 120.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0; % NG
	50458	 65.75	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	50458	 65.75	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	50459	 63.5	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % PEL
	50459	 63.5	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	50460	 69.95	 6.4	 41.1	 -28.3	 1.0	 100.0	 1	 84.9	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.9; % NG
	50460	 78.1	 7.9	 50.5	 -34.7	 1.0	 100.0	 1	 104.2	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.2; % NG
	50460	 78.1	 7.9	 50.5	 -34.7	 1.0	 100.0	 1	 104.2	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.2; % NG
	50460	 56.2	 12.55	 54.2	 -29.1	 1.0	 100.0	 1	 87.4	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.4; % NG
	50461	 64.35	 12.15	 52.6	 -28.3	 1.0	 100.0	 1	 84.9	 43.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.9; % NG
	50461	 64.3	 12.15	 52.6	 -28.3	 1.0	 100.0	 1	 84.9	 43.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.9; % NG
	50461	 64.05	 12.15	 52.6	 -28.3	 1.0	 100.0	 1	 84.9	 43.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.9; % NG
	50461	 63.95	 12.15	 52.6	 -28.3	 1.0	 100.0	 1	 84.9	 43.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.9; % PEL
	50461	 63.95	 12.15	 52.6	 -28.3	 1.0	 100.0	 1	 84.9	 43.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.9; % COW
	50461	 66.8	 12.85	 55.7	 -30.0	 1.0	 100.0	 1	 89.9	 43.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.9; % NG
	50461	 81.6	 18.5	 80.1	 -43.1	 1.0	 100.0	 1	 129.2	 34.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.2; % NG
	50462	 44.1	 0.0	 37.0	 -37.0	 1.0	 100.0	 1	 84.0	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50463	 90.8	 11.8	 75.8	 -52.2	 1.0	 100.0	 1	 156.6	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.6; % NG
	50463	 66.7	 16.25	 70.3	 -37.8	 1.0	 100.0	 1	 113.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.4; % NG
	50463	 42.5	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	50463	 68.85	 11.85	 51.3	 -27.6	 1.0	 100.0	 1	 82.7	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.7; % NG
	50464	 43.3	 0.0	 36.4	 -36.4	 1.0	 100.0	 1	 82.5	 4.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50467	 40.25	 0.0	 31.8	 -31.8	 1.0	 100.0	 1	 80.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50469	 40.15	 0.0	 31.5	 -31.5	 1.0	 100.0	 1	 79.8	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50470	 118.0	 33.8	 146.3	 -78.7	 1.0	 100.0	 1	 236.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 236.0; % NG
	50470	 51.145	 16.6	 59.7	 -26.5	 1.0	 100.0	 1	 79.6	 22.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 79.6; % NG
	50471	 41.75	 0.0	 31.4	 -31.4	 1.0	 100.0	 1	 79.5	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50472	 34.35	 4.95	 21.5	 -11.6	 1.0	 100.0	 1	 34.7	 34.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.7; % NG
	50472	 64.1	 11.2	 48.5	 -26.1	 1.0	 100.0	 1	 78.2	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.2; % COW
	50472	 64.1	 11.2	 48.5	 -26.1	 1.0	 100.0	 1	 78.2	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.2; % PEL
	50473	 43.0	 0.0	 30.8	 -30.8	 1.0	 100.0	 1	 78.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	50473	 45.0	 0.0	 36.2	 -36.2	 1.0	 100.0	 1	 82.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50474	 61.25	 11.1	 48.0	 -25.8	 1.0	 100.0	 1	 77.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.5; % NG
	50474	 61.25	 11.1	 48.0	 -25.8	 1.0	 100.0	 1	 77.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.5; % PEL
	50474	 57.5	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	50475	 60.0	 15.65	 56.3	 -25.0	 1.0	 100.0	 1	 75.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	50475	 60.0	 15.65	 56.3	 -25.0	 1.0	 100.0	 1	 75.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	50475	 60.0	 15.65	 56.3	 -25.0	 1.0	 100.0	 1	 75.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	50475	 60.0	 15.65	 56.3	 -25.0	 1.0	 100.0	 1	 75.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	50476	 39.35	 0.0	 29.6	 -29.6	 1.0	 100.0	 1	 75.0	 3.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	50477	 65.0	 5.65	 36.3	 -25.0	 1.0	 100.0	 1	 75.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % COW
	50477	 65.0	 5.65	 36.3	 -25.0	 1.0	 100.0	 1	 75.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	50477	 91.5	 9.4	 60.5	 -41.7	 1.0	 100.0	 1	 125.0	 58.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	50477	 91.5	 9.4	 60.5	 -41.7	 1.0	 100.0	 1	 125.0	 58.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % COW
	50477	 70.75	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	50477	 70.75	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5; % NG
	50478	 37.5	 0.0	 29.6	 -29.6	 1.0	 100.0	 1	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	50478	 37.5	 0.0	 29.6	 -29.6	 1.0	 100.0	 1	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50479	 243.2	 33.7	 216.2	 -148.8	 1.0	 100.0	 1	 446.4	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 446.4; % NG
	50479	 51.0	 5.45	 34.9	 -24.0	 1.0	 100.0	 1	 72.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0; % COW
	50479	 51.0	 5.45	 34.9	 -24.0	 1.0	 100.0	 1	 72.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0; % COW
	50479	 51.0	 5.45	 34.9	 -24.0	 1.0	 100.0	 1	 72.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0; % COW
	50479	 51.0	 5.45	 34.9	 -24.0	 1.0	 100.0	 1	 72.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0; % PEL
	50479	 51.0	 5.45	 34.9	 -24.0	 1.0	 100.0	 1	 72.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0; % PEL
	50479	 51.0	 5.45	 34.9	 -24.0	 1.0	 100.0	 1	 72.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0; % COW
	50481	 120.0	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0; % NG
	50481	 69.0	 14.35	 62.0	 -33.3	 1.0	 100.0	 1	 100.0	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0; % NG
	50481	 43.0	 9.45	 40.9	 -22.0	 1.0	 100.0	 1	 66.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.0; % PEL
	50483	 31.55	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 63.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50485	 142.5	 32.2	 139.4	 -75.0	 1.0	 100.0	 1	 225.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 225.0; % NG
	50485	 156.0	 36.1	 156.2	 -84.0	 1.0	 100.0	 1	 252.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 252.0; % NG
	50485	 40.5	 8.75	 37.8	 -20.3	 1.0	 100.0	 1	 61.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0; % NG
	50485	 40.5	 8.75	 37.8	 -20.3	 1.0	 100.0	 1	 61.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0; % NG
	50485	 40.5	 8.75	 37.8	 -20.3	 1.0	 100.0	 1	 61.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0; % NG
	50485	 40.5	 8.75	 37.8	 -20.3	 1.0	 100.0	 1	 61.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0; % NG
	50485	 243.5	 59.7	 258.4	 -139.0	 1.0	 100.0	 1	 417.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 417.0; % NG
	50486	 36.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	50486	 36.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	50486	 18.45	 4.7	 20.4	 -11.0	 1.0	 100.0	 1	 32.9	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.9; % NG
	50488	 36.0	 0.0	 23.7	 -23.7	 1.0	 100.0	 1	 60.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	50489	 30.05	 0.0	 23.7	 -23.7	 1.0	 100.0	 1	 60.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	50489	 46.3	 0.0	 40.8	 -40.8	 1.0	 100.0	 1	 92.5	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50492	 29.45	 0.0	 23.2	 -23.2	 1.0	 100.0	 1	 58.8	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	50493	 14.8	 0.0	 6.33	 -6.33	 1.0	 100.0	 1	 19.23	 10.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.2333; % NG
	50493	 14.8	 0.0	 6.33	 -6.33	 1.0	 100.0	 1	 19.23	 10.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.2333; % PEL
	50493	 14.8	 0.0	 6.33	 -6.33	 1.0	 100.0	 1	 19.23	 10.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.2333; % NG
	50493	 24.45	 0.0	 10.7	 -10.7	 1.0	 100.0	 1	 32.6	 16.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.6; % COW
	50494	 71.06	 13.25	 64.4	 -37.9	 1.0	 100.0	 1	 113.7	 28.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.7; % NG
	50494	 38.7	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % PEL
	50494	 38.7	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % NG
	50494	 38.7	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % PEL
	50494	 38.7	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % NG
	50494	 48.19	 9.05	 43.1	 -25.0	 1.0	 100.0	 1	 75.0	 21.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	50495	 34.0	 5.75	 24.8	 -13.3	 1.0	 100.0	 1	 40.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % PEL
	50495	 33.0	 4.2	 27.1	 -18.7	 1.0	 100.0	 1	 56.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.0; % NG
	50496	 14.65	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 18.3	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3; % NG
	50496	 14.65	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 18.3	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3; % PEL
	50496	 14.65	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 18.3	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3; % PEL
	50497	 53.5	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	50497	 63.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	50497	 63.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	50497	 62.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	50497	 61.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	50497	 61.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % COW
	50497	 70.05	 16.2	 70.1	 -37.7	 1.0	 100.0	 1	 113.1	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.1; % NG
	50497	 70.05	 16.2	 70.1	 -37.7	 1.0	 100.0	 1	 113.1	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.1; % COW
	50497	 53.5	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	50497	 53.5	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	50497	 53.5	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	50497	 53.5	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	50497	 54.85	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % PEL
	50497	 54.85	 4.3	 27.5	 -18.9	 1.0	 100.0	 1	 56.7	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.7; % PEL
	50497	 53.5	 7.75	 33.5	 -18.0	 1.0	 100.0	 1	 54.0	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	50497	 66.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 48.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0; % NG
	50499	 50.25	 3.85	 24.9	 -17.2	 1.0	 100.0	 1	 51.5	 49.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.5; % NG
	50499	 50.25	 3.85	 24.9	 -17.2	 1.0	 100.0	 1	 51.5	 49.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.5; % NG
	50499	 50.25	 3.85	 24.9	 -17.2	 1.0	 100.0	 1	 51.5	 49.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.5; % NG
	50499	 50.25	 3.85	 24.9	 -17.2	 1.0	 100.0	 1	 51.5	 49.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.5; % NG
	50499	 227.5	 30.6	 196.2	 -135.0	 1.0	 100.0	 1	 405.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 405.0; % NG
	50499	 185.5	 45.95	 198.9	 -107.0	 1.0	 100.0	 1	 321.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 321.0; % NG
	50500	 57.5	 15.65	 56.3	 -25.0	 1.0	 100.0	 1	 75.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	50500	 57.5	 15.65	 56.3	 -25.0	 1.0	 100.0	 1	 75.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	50500	 30.5	 10.65	 38.3	 -17.0	 1.0	 100.0	 1	 51.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0; % NG
	50500	 30.5	 10.65	 38.3	 -17.0	 1.0	 100.0	 1	 51.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0; % NG
	50501	 38.0	 8.75	 37.8	 -20.3	 1.0	 100.0	 1	 61.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0; % NG
	50501	 16.5	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 24.0	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % NG
	50501	 41.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	50501	 20.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	50503	 30.55	 7.0	 30.4	 -16.4	 1.0	 100.0	 1	 49.1	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.1; % NG
	50503	 30.55	 7.0	 30.4	 -16.4	 1.0	 100.0	 1	 49.1	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.1; % NG
	50503	 58.5	 7.95	 50.9	 -35.0	 1.0	 100.0	 1	 105.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0; % COW
	50504	 31.485	 10.25	 36.8	 -16.3	 1.0	 100.0	 1	 49.0	 13.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0; % NG
	50505	 122.7	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4; % NG
	50505	 34.5	 10.0	 36.0	 -16.0	 1.0	 100.0	 1	 48.0	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.0; % NG
	50505	 66.5	 20.4	 73.5	 -32.7	 1.0	 100.0	 1	 98.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.0; % NG
	50505	 59.5	 20.4	 73.5	 -32.7	 1.0	 100.0	 1	 98.0	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.0; % NG
	50506	 35.0	 6.85	 29.7	 -16.0	 1.0	 100.0	 1	 48.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.0; % NG
	50510	 28.27	 5.3	 25.3	 -14.7	 1.0	 100.0	 1	 44.0	 12.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0; % PEL
	50511	 34.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 41.6	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.6; % NG
	50511	 34.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 41.6	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.6; % NG
	50512	 31.6	 5.85	 25.4	 -13.7	 1.0	 100.0	 1	 41.0	 22.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.0; % NG
	50513	 36.25	 0.0	 13.3	 -13.3	 1.0	 100.0	 1	 40.5	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.5; % NG
	50513	 36.25	 0.0	 13.3	 -13.3	 1.0	 100.0	 1	 40.5	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.5; % NG
	50515	 32.35	 5.7	 24.6	 -13.2	 1.0	 100.0	 1	 39.7	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.7; % NG
	50515	 32.35	 5.7	 24.6	 -13.2	 1.0	 100.0	 1	 39.7	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.7; % NG
	50515	 32.35	 5.7	 24.6	 -13.2	 1.0	 100.0	 1	 39.7	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.7; % PEL
	50515	 74.45	 14.15	 61.3	 -33.0	 1.0	 100.0	 1	 98.9	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.9; % NG
	50515	 121.9	 23.45	 101.5	 -54.6	 1.0	 100.0	 1	 163.8	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.8; % NG
	50516	 14.4	 1.5	 9.6	 -6.6	 1.0	 100.0	 1	 19.8	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.8; % NG
	50516	 14.4	 1.5	 9.6	 -6.6	 1.0	 100.0	 1	 19.8	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.8; % COW
	50517	 28.3	 0.0	 15.3	 -15.3	 1.0	 100.0	 1	 38.6	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.6; % NG
	50517	 126.5	 0.0	 40.9	 -40.9	 1.0	 100.0	 1	 163.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.0; % NG
	50517	 126.5	 0.0	 40.9	 -40.9	 1.0	 100.0	 1	 163.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.0; % NG
	50517	 126.5	 0.0	 47.5	 -47.5	 1.0	 100.0	 1	 163.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.0; % NG
	50518	 24.3	 8.05	 29.0	 -12.9	 1.0	 100.0	 1	 38.6	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.6; % NG
	50518	 24.3	 8.05	 29.0	 -12.9	 1.0	 100.0	 1	 38.6	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.6; % NG
	50519	 29.2	 2.9	 18.6	 -12.8	 1.0	 100.0	 1	 38.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.4; % COW
	50520	 24.0	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0; % NG
	50520	 24.0	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0; % NG
	50520	 47.0	 15.4	 55.5	 -24.7	 1.0	 100.0	 1	 74.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.0; % NG
	50520	 193.0	 26.5	 170.0	 -117.0	 1.0	 100.0	 1	 351.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 351.0; % NG
	50522	 20.0	 0.0	 17.1	 -17.1	 1.0	 100.0	 1	 37.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % NG
	50523	 18.75	 0.0	 14.8	 -14.8	 1.0	 100.0	 1	 37.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	50524	 32.2	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.4	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.4; % PEL
	50524	 32.2	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.4	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.4; % PEL
	50524	 19.35	 4.5	 19.6	 -10.6	 1.0	 100.0	 1	 31.7	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.7; % NG
	50525	 22.2	 5.1	 22.5	 -12.3	 1.0	 100.0	 1	 37.0	 7.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.0; % COW
	50526	 21.5	 7.3	 26.3	 -11.7	 1.0	 100.0	 1	 35.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % NG
	50527	 17.15	 0.0	 13.6	 -13.6	 1.0	 100.0	 1	 34.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	50530	 6.75	 0.8	 5.1	 -3.5	 1.0	 100.0	 1	 10.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5; % NG
	50530	 6.75	 0.8	 5.1	 -3.5	 1.0	 100.0	 1	 10.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5; % COW
	50530	 6.75	 0.8	 5.1	 -3.5	 1.0	 100.0	 1	 10.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5; % NG
	50531	 20.45	 3.25	 16.0	 -9.5	 1.0	 100.0	 1	 28.6	 12.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.6; % NG
	50532	 16.8	 6.0	 21.5	 -9.5	 1.0	 100.0	 1	 28.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.6; % NG
	50532	 16.8	 6.0	 21.5	 -9.5	 1.0	 100.0	 1	 28.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.6; % COW
	50533	 18.0	 0.0	 8.5	 -8.5	 1.0	 100.0	 1	 26.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.0; % NG
	50533	 18.0	 0.0	 8.5	 -8.5	 1.0	 100.0	 1	 26.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.0; % NG
	50534	 2.93	 0.665	 2.41	 -1.08	 1.0	 100.0	 1	 3.21	 2.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2125; % NG
	50534	 2.93	 0.665	 2.41	 -1.08	 1.0	 100.0	 1	 3.21	 2.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2125; % PEL
	50534	 2.93	 0.665	 2.41	 -1.08	 1.0	 100.0	 1	 3.21	 2.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2125; % NG
	50534	 2.93	 0.665	 2.41	 -1.08	 1.0	 100.0	 1	 3.21	 2.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2125; % COW
	50534	 2.93	 0.665	 2.41	 -1.08	 1.0	 100.0	 1	 3.21	 2.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2125; % PEL
	50534	 2.93	 0.665	 2.41	 -1.08	 1.0	 100.0	 1	 3.21	 2.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2125; % PEL
	50534	 2.93	 0.665	 2.41	 -1.08	 1.0	 100.0	 1	 3.21	 2.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2125; % NG
	50534	 2.93	 0.665	 2.41	 -1.08	 1.0	 100.0	 1	 3.21	 2.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2125; % COW
	50535	 7.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50535	 7.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50535	 7.2	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4; % NG
	50535	 28.1	 3.25	 20.9	 -14.4	 1.0	 100.0	 1	 43.2	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.2; % NG
	50535	 17.5	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	50536	 15.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	50536	 22.5	 5.75	 24.8	 -13.3	 1.0	 100.0	 1	 40.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	50537	 27.25	 5.2	 22.6	 -12.2	 1.0	 100.0	 1	 36.5	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.5; % NG
	50537	 27.25	 5.2	 22.6	 -12.2	 1.0	 100.0	 1	 36.5	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.5; % NG
	50537	 20.1	 5.05	 18.2	 -8.1	 1.0	 100.0	 1	 24.2	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.2; % COW
	50537	 20.1	 5.05	 18.2	 -8.1	 1.0	 100.0	 1	 24.2	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.2; % COW
	50537	 20.1	 5.05	 18.2	 -8.1	 1.0	 100.0	 1	 24.2	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.2; % NG
	50537	 20.1	 5.05	 18.2	 -8.1	 1.0	 100.0	 1	 24.2	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.2; % PEL
	50539	 12.9	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % PEL
	50540	 3.62	 1.225	 4.4	 -1.95	 1.0	 100.0	 1	 5.87	 1.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.875; % NG
	50540	 3.62	 1.225	 4.4	 -1.95	 1.0	 100.0	 1	 5.87	 1.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.875; % COW
	50540	 3.62	 1.225	 4.4	 -1.95	 1.0	 100.0	 1	 5.87	 1.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.875; % NG
	50540	 3.62	 1.225	 4.4	 -1.95	 1.0	 100.0	 1	 5.87	 1.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.875; % NG
	50541	 16.7	 3.35	 14.5	 -7.8	 1.0	 100.0	 1	 23.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4; % COW
	50542	 5.75	 1.65	 7.15	 -3.85	 1.0	 100.0	 1	 11.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5; % PEL
	50542	 5.75	 1.65	 7.15	 -3.85	 1.0	 100.0	 1	 11.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5; % NG
	50542	 35.0	 3.05	 19.4	 -13.3	 1.0	 100.0	 1	 40.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	50542	 16.0	 1.7	 10.7	 -7.3	 1.0	 100.0	 1	 22.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	50542	 16.0	 1.7	 10.7	 -7.3	 1.0	 100.0	 1	 22.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	50543	 7.6	 1.6	 6.95	 -3.75	 1.0	 100.0	 1	 11.2	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % PEL
	50543	 7.6	 1.6	 6.95	 -3.75	 1.0	 100.0	 1	 11.2	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % NG
	50543	 16.06	 3.05	 14.4	 -8.3	 1.0	 100.0	 1	 25.0	 7.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	50543	 24.5	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 42.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0; % NG
	50543	 28.6	 7.05	 30.5	 -16.4	 1.0	 100.0	 1	 49.2	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.2; % NG
	50543	 28.6	 7.05	 30.5	 -16.4	 1.0	 100.0	 1	 49.2	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.2; % NG
	50543	 28.6	 7.05	 30.5	 -16.4	 1.0	 100.0	 1	 49.2	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.2; % NG
	50544	 13.5	 1.7	 10.7	 -7.3	 1.0	 100.0	 1	 22.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	50544	 33.0	 7.75	 33.5	 -18.0	 1.0	 100.0	 1	 54.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	50544	 14.5	 3.45	 14.9	 -8.0	 1.0	 100.0	 1	 24.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % PEL
	50544	 15.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	50547	 12.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	50549	 11.0	 4.15	 15.0	 -6.7	 1.0	 100.0	 1	 20.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	50549	 11.0	 4.15	 15.0	 -6.7	 1.0	 100.0	 1	 20.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	50549	 11.0	 4.15	 15.0	 -6.7	 1.0	 100.0	 1	 20.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % COW
	50549	 11.0	 4.15	 15.0	 -6.7	 1.0	 100.0	 1	 20.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	75451	 39.75	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	75451	 39.75	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	75451	 39.75	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	75451	 39.75	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	75461	 4.05	 0.0	 3.55	 -3.55	 1.0	 100.0	 1	 7.5	 0.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5; % NG
	75461	 4.05	 0.0	 3.55	 -3.55	 1.0	 100.0	 1	 7.5	 0.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5; % PEL
	75461	 4.05	 0.0	 3.55	 -3.55	 1.0	 100.0	 1	 7.5	 0.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5; % NG
	75461	 4.05	 0.0	 3.55	 -3.55	 1.0	 100.0	 1	 7.5	 0.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5; % COW
	75462	 17.75	 0.0	 5.2	 -5.2	 1.0	 100.0	 1	 25.7	 9.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.7; % NG
	75493	 40.55	 7.0	 30.4	 -16.4	 1.0	 100.0	 1	 49.1	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.1; % NG
	75493	 108.45	 18.45	 79.9	 -43.0	 1.0	 100.0	 1	 128.9	 88.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 128.9; % COW
	75496	 70.45	 11.55	 50.1	 -27.0	 1.0	 100.0	 1	 80.9	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.9; % COW
	75496	 77.0	 12.9	 55.8	 -30.0	 1.0	 100.0	 1	 90.0	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	75496	 77.0	 12.9	 55.8	 -30.0	 1.0	 100.0	 1	 90.0	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	75497	 43.0	 8.3	 35.9	 -19.3	 1.0	 100.0	 1	 58.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.0; % NG
	75497	 43.0	 8.3	 35.9	 -19.3	 1.0	 100.0	 1	 58.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.0; % NG
	75497	 16.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	75497	 56.5	 5.75	 36.8	 -25.3	 1.0	 100.0	 1	 76.0	 37.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 76.0; % NG
	75503	 25.05	 3.5	 22.3	 -15.3	 1.0	 100.0	 1	 46.0	 4.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0; % NG
	75508	 17.6	 1.6	 10.3	 -7.1	 1.0	 100.0	 1	 21.2	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % COW
	75509	 17.7	 2.9	 12.6	 -6.8	 1.0	 100.0	 1	 20.4	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.4; % NG
	75510	 6.425	 1.2	 5.75	 -3.35	 1.0	 100.0	 1	 10.0	 2.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % NG
	75510	 6.425	 1.2	 5.75	 -3.35	 1.0	 100.0	 1	 10.0	 2.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % NG
	75511	 41.0	 10.3	 44.6	 -24.0	 1.0	 100.0	 1	 72.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0; % PEL
	75511	 148.4	 26.75	 115.8	 -62.3	 1.0	 100.0	 1	 186.8	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 186.8; % NG
	75514	 132.2	 25.7	 111.2	 -59.8	 1.0	 100.0	 1	 179.4	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.4; % NG
	75514	 70.05	 13.6	 58.9	 -31.7	 1.0	 100.0	 1	 95.1	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.1; % NG
	75517	 14.005	 3.35	 13.88	 -7.18	 1.0	 100.0	 1	 21.55	 6.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.55; % PEL
	75517	 14.005	 3.35	 13.88	 -7.18	 1.0	 100.0	 1	 21.55	 6.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.55; % NG
	75517	 14.005	 3.35	 13.88	 -7.18	 1.0	 100.0	 1	 21.55	 6.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.55; % PEL
	75517	 14.005	 3.35	 13.88	 -7.18	 1.0	 100.0	 1	 21.55	 6.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.55; % PEL
	75517	 15.98	 3.4	 14.6	 -7.8	 1.0	 100.0	 1	 23.5	 8.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.5; % NG
	75517	 21.42	 4.5	 19.5	 -10.5	 1.0	 100.0	 1	 31.5	 11.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.5; % PEL
	75518	 15.35	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 30.2	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.2; % NG
	75518	 10.405	 2.335	 11.5	 -6.83	 1.0	 100.0	 1	 20.47	 0.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.4667; % PEL
	75518	 10.405	 2.335	 11.5	 -6.83	 1.0	 100.0	 1	 20.47	 0.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.4667; % PEL
	75518	 10.405	 2.335	 11.5	 -6.83	 1.0	 100.0	 1	 20.47	 0.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.4667; % NG
	75527	 9.75	 2.5	 10.85	 -5.85	 1.0	 100.0	 1	 17.5	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % PEL
	75527	 9.75	 2.5	 10.85	 -5.85	 1.0	 100.0	 1	 17.5	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % PEL
	75530	 16.75	 3.9	 17.0	 -9.2	 1.0	 100.0	 1	 27.5	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % COW
	75534	 15.0	 4.8	 17.3	 -7.7	 1.0	 100.0	 1	 23.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % PEL
	75534	 16.9	 5.6	 20.1	 -8.9	 1.0	 100.0	 1	 26.8	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.8; % NG
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % NG
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % NG
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % NG
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % NG
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % NG
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % PEL
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % PEL
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % NG
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % PEL
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % NG
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % PEL
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % PEL
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % PEL
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % PEL
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % PEL
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % PEL
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % PEL
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % PEL
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % PEL
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % NG
	75546	 0.77	 0.11	 0.7	 -0.48	 1.0	 100.0	 1	 1.44	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4429; % PEL
	75553	 33.4	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8; % NG
	75553	 16.5	 2.05	 13.1	 -9.0	 1.0	 100.0	 1	 27.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % NG
	75554	 1.33	 0.33	 1.24	 -0.58	 1.0	 100.0	 1	 1.74	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.74; % PEL
	75554	 1.33	 0.33	 1.24	 -0.58	 1.0	 100.0	 1	 1.74	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.74; % PEL
	75554	 1.33	 0.33	 1.24	 -0.58	 1.0	 100.0	 1	 1.74	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.74; % PEL
	75554	 1.33	 0.33	 1.24	 -0.58	 1.0	 100.0	 1	 1.74	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.74; % PEL
	75554	 1.33	 0.33	 1.24	 -0.58	 1.0	 100.0	 1	 1.74	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.74; % PEL
	75554	 1.33	 0.33	 1.24	 -0.58	 1.0	 100.0	 1	 1.74	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.74; % PEL
	75554	 1.33	 0.33	 1.24	 -0.58	 1.0	 100.0	 1	 1.74	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.74; % PEL
	75554	 1.33	 0.33	 1.24	 -0.58	 1.0	 100.0	 1	 1.74	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.74; % PEL
	75554	 1.33	 0.33	 1.24	 -0.58	 1.0	 100.0	 1	 1.74	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.74; % PEL
	75554	 1.33	 0.33	 1.24	 -0.58	 1.0	 100.0	 1	 1.74	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.74; % PEL
	75554	 1.33	 0.33	 1.24	 -0.58	 1.0	 100.0	 1	 1.74	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.74; % PEL
	75554	 1.33	 0.33	 1.24	 -0.58	 1.0	 100.0	 1	 1.74	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.74; % PEL
	75554	 1.33	 0.33	 1.24	 -0.58	 1.0	 100.0	 1	 1.74	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.74; % PEL
	75554	 1.33	 0.33	 1.24	 -0.58	 1.0	 100.0	 1	 1.74	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.74; % PEL
	75554	 1.33	 0.33	 1.24	 -0.58	 1.0	 100.0	 1	 1.74	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.74; % PEL
	75555	 37.25	 4.5	 28.8	 -19.8	 1.0	 100.0	 1	 59.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.5; % PEL
	75557	 3.095	 0.265	 1.69	 -1.16	 1.0	 100.0	 1	 3.49	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.49; % COW
	75557	 3.095	 0.265	 1.69	 -1.16	 1.0	 100.0	 1	 3.49	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.49; % NG
	75557	 3.095	 0.265	 1.69	 -1.16	 1.0	 100.0	 1	 3.49	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.49; % NG
	75557	 3.095	 0.265	 1.69	 -1.16	 1.0	 100.0	 1	 3.49	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.49; % PEL
	75557	 3.095	 0.265	 1.69	 -1.16	 1.0	 100.0	 1	 3.49	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.49; % PEL
	75557	 3.095	 0.265	 1.69	 -1.16	 1.0	 100.0	 1	 3.49	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.49; % PEL
	75557	 3.095	 0.265	 1.69	 -1.16	 1.0	 100.0	 1	 3.49	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.49; % PEL
	75557	 3.095	 0.265	 1.69	 -1.16	 1.0	 100.0	 1	 3.49	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.49; % PEL
	75557	 3.095	 0.265	 1.69	 -1.16	 1.0	 100.0	 1	 3.49	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.49; % PEL
	75557	 3.095	 0.265	 1.69	 -1.16	 1.0	 100.0	 1	 3.49	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.49; % NG
	76506	 64.25	 12.1	 57.5	 -33.3	 1.0	 100.0	 1	 100.0	 28.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0; % NG
	76516	 51.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 78.6	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.6; % NG
	76524	 42.75	 0.0	 19.9	 -19.9	 1.0	 100.0	 1	 60.5	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	76530	 34.45	 2.85	 18.5	 -12.8	 1.0	 100.0	 1	 38.3	 30.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.3; % COW
	76530	 47.95	 4.2	 26.8	 -18.4	 1.0	 100.0	 1	 55.3	 40.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.3; % NG
	76532	 37.6	 6.15	 26.6	 -14.3	 1.0	 100.0	 1	 43.0	 32.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.0; % NG
	76532	 46.4	 7.9	 34.1	 -18.3	 1.0	 100.0	 1	 55.0	 37.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0; % NG
	76535	 45.0	 4.0	 25.7	 -17.7	 1.0	 100.0	 1	 53.0	 37.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0; % NG
	76535	 45.0	 4.0	 25.7	 -17.7	 1.0	 100.0	 1	 53.0	 37.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0; % NG
	76537	 44.95	 3.75	 24.2	 -16.7	 1.0	 100.0	 1	 50.0	 39.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	76537	 44.95	 3.75	 24.2	 -16.7	 1.0	 100.0	 1	 50.0	 39.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	76538	 44.95	 3.75	 24.2	 -16.7	 1.0	 100.0	 1	 50.0	 39.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	76538	 44.95	 3.75	 24.2	 -16.7	 1.0	 100.0	 1	 50.0	 39.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	76539	 45.0	 10.4	 37.5	 -16.7	 1.0	 100.0	 1	 50.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % PEL
	76539	 18.5	 6.65	 24.0	 -10.7	 1.0	 100.0	 1	 32.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % PEL
	76540	 47.1	 7.05	 30.5	 -16.4	 1.0	 100.0	 1	 49.2	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.2; % PEL
	76540	 27.0	 5.6	 24.2	 -13.0	 1.0	 100.0	 1	 39.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.0; % NG
	76543	 39.35	 7.0	 30.2	 -16.2	 1.0	 100.0	 1	 48.7	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.7; % NG
	76543	 39.35	 7.0	 30.2	 -16.2	 1.0	 100.0	 1	 48.7	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.7; % NG
	76543	 39.35	 7.0	 30.2	 -16.2	 1.0	 100.0	 1	 48.7	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.7; % PEL
	76543	 44.6	 0.0	 15.3	 -15.3	 1.0	 100.0	 1	 75.2	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.2; % PEL
	76545	 28.15	 3.55	 22.9	 -15.8	 1.0	 100.0	 1	 47.3	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.3; % NG
	76545	 14.75	 1.85	 11.9	 -8.2	 1.0	 100.0	 1	 24.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.5; % NG
	76545	 14.75	 1.85	 11.9	 -8.2	 1.0	 100.0	 1	 24.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.5; % NG
	76550	 25.75	 3.5	 22.5	 -15.5	 1.0	 100.0	 1	 46.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.5; % COW
	76553	 23.45	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % PEL
	76558	 3.64	 0.95	 3.53	 -1.63	 1.0	 100.0	 1	 4.9	 2.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.9; % NG
	76558	 3.64	 0.95	 3.53	 -1.63	 1.0	 100.0	 1	 4.9	 2.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.9; % NG
	76558	 3.64	 0.95	 3.53	 -1.63	 1.0	 100.0	 1	 4.9	 2.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.9; % PEL
	76558	 3.64	 0.95	 3.53	 -1.63	 1.0	 100.0	 1	 4.9	 2.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.9; % NG
	76558	 3.64	 0.95	 3.53	 -1.63	 1.0	 100.0	 1	 4.9	 2.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.9; % PEL
	76558	 3.64	 0.95	 3.53	 -1.63	 1.0	 100.0	 1	 4.9	 2.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.9; % PEL
	76561	 13.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 25.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	76564	 11.8	 2.8	 12.8	 -7.2	 1.0	 100.0	 1	 21.6	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6; % PEL
	77631	 114.7	 10.85	 69.5	 -47.8	 1.0	 100.0	 1	 143.4	 86.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 143.4; % NG
	77631	 114.7	 10.85	 69.5	 -47.8	 1.0	 100.0	 1	 143.4	 86.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 143.4; % NG
	77631	 84.7	 10.85	 69.5	 -47.8	 1.0	 100.0	 1	 143.4	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 143.4; % COW
	77642	 31.29	 6.1	 26.3	 -14.1	 1.0	 100.0	 1	 42.4	 20.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.4; % NG
	77642	 87.27	 6.95	 44.6	 -30.7	 1.0	 100.0	 1	 92.1	 82.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 92.1; % NG
	77648	 10.8	 2.665	 11.53	 -6.2	 1.0	 100.0	 1	 18.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.6; % NG
	77648	 10.8	 2.665	 11.53	 -6.2	 1.0	 100.0	 1	 18.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.6; % PEL
	77648	 10.8	 2.665	 11.53	 -6.2	 1.0	 100.0	 1	 18.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.6; % NG
	77655	 31.5	 3.4	 21.8	 -15.0	 1.0	 100.0	 1	 45.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	77656	 23.95	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % NG
	77656	 23.95	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9; % NG
	77660	 14.5	 5.65	 20.3	 -9.0	 1.0	 100.0	 1	 27.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % PEL
	77660	 8.5	 2.65	 10.3	 -5.0	 1.0	 100.0	 1	 15.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % NG
	77660	 8.5	 2.65	 10.3	 -5.0	 1.0	 100.0	 1	 15.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % COW
	77661	 20.0	 4.6	 16.5	 -7.3	 1.0	 100.0	 1	 22.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	77661	 24.15	 6.0	 21.6	 -9.6	 1.0	 100.0	 1	 28.8	 19.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % NG
	77662	 15.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.5	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5; % PEL
	77663	 13.6	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % NG
	77663	 13.6	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % NG
	77663	 21.6	 5.35	 23.1	 -12.4	 1.0	 100.0	 1	 37.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.2; % NG
	77702	 171.0	 34.65	 150.0	 -80.7	 1.0	 100.0	 1	 242.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 242.0; % NG
	77702	 133.0	 26.65	 115.3	 -62.0	 1.0	 100.0	 1	 186.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 186.0; % NG
	77702	 133.0	 26.65	 115.3	 -62.0	 1.0	 100.0	 1	 186.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 186.0; % NG
	77720	 8.075	 2.345	 8.44	 -3.75	 1.0	 100.0	 1	 11.25	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.25; % NG
	77720	 8.075	 2.345	 8.44	 -3.75	 1.0	 100.0	 1	 11.25	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.25; % NG
	77720	 8.075	 2.345	 8.44	 -3.75	 1.0	 100.0	 1	 11.25	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.25; % NG
	77720	 8.075	 2.345	 8.44	 -3.75	 1.0	 100.0	 1	 11.25	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.25; % NG
	77720	 8.075	 2.345	 8.44	 -3.75	 1.0	 100.0	 1	 11.25	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.25; % PEL
	77720	 8.075	 2.345	 8.44	 -3.75	 1.0	 100.0	 1	 11.25	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.25; % COW
	77720	 8.075	 2.345	 8.44	 -3.75	 1.0	 100.0	 1	 11.25	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.25; % NG
	77720	 8.075	 2.345	 8.44	 -3.75	 1.0	 100.0	 1	 11.25	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.25; % NG
	77720	 8.075	 2.345	 8.44	 -3.75	 1.0	 100.0	 1	 11.25	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.25; % PEL
	77720	 8.075	 2.345	 8.44	 -3.75	 1.0	 100.0	 1	 11.25	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.25; % PEL
	77724	 74.5	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0; % NG
	77725	 69.2	 12.65	 54.8	 -29.5	 1.0	 100.0	 1	 88.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.4; % NG
	77732	 15.0	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	77732	 15.0	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	77732	 15.0	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % PEL
	77732	 15.0	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % PEL
	77733	 44.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % NG
	77741	 36.5	 6.85	 29.7	 -16.0	 1.0	 100.0	 1	 48.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.0; % PEL
	77742	 37.65	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 47.3	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.3; % NG
	77743	 24.0	 3.3	 21.3	 -14.7	 1.0	 100.0	 1	 44.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0; % NG
	77747	 19.4	 0.0	 14.9	 -14.9	 1.0	 100.0	 1	 37.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	77748	 16.25	 2.65	 11.45	 -6.15	 1.0	 100.0	 1	 18.5	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.5; % PEL
	77748	 16.25	 2.65	 11.45	 -6.15	 1.0	 100.0	 1	 18.5	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.5; % PEL
	77749	 16.25	 2.65	 11.45	 -6.15	 1.0	 100.0	 1	 18.5	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.5; % NG
	77749	 16.25	 2.65	 11.45	 -6.15	 1.0	 100.0	 1	 18.5	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.5; % NG
	77751	 18.35	 2.7	 17.3	 -11.9	 1.0	 100.0	 1	 35.7	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.7; % NG
	77753	 22.5	 6.9	 24.8	 -11.0	 1.0	 100.0	 1	 33.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0; % NG
	77753	 22.5	 6.9	 24.8	 -11.0	 1.0	 100.0	 1	 33.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0; % PEL
	77753	 22.5	 6.9	 24.8	 -11.0	 1.0	 100.0	 1	 33.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0; % NG
	77753	 42.25	 15.1	 54.4	 -24.2	 1.0	 100.0	 1	 72.5	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.5; % NG
	77755	 14.6	 2.275	 9.9	 -5.35	 1.0	 100.0	 1	 16.0	 13.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % PEL
	77755	 14.6	 2.275	 9.9	 -5.35	 1.0	 100.0	 1	 16.0	 13.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	77756	 14.9	 2.275	 9.9	 -5.35	 1.0	 100.0	 1	 16.0	 13.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	77756	 14.9	 2.275	 9.9	 -5.35	 1.0	 100.0	 1	 16.0	 13.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	77761	 15.2	 0.0	 11.6	 -11.6	 1.0	 100.0	 1	 29.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	77765	 12.0	 0.0	 9.5	 -9.5	 1.0	 100.0	 1	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	77766	 42.75	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 60.5	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	77766	 16.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 23.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.2; % PEL
	77770	 7.525	 0.825	 5.25	 -3.6	 1.0	 100.0	 1	 10.85	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.85; % COW
	77770	 7.525	 0.825	 5.25	 -3.6	 1.0	 100.0	 1	 10.85	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.85; % NG
	77771	 13.1	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % PEL
	77771	 13.1	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % PEL
	77771	 13.1	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % PEL
	77772	 13.1	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % NG
	77772	 13.1	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % PEL
	77772	 13.1	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2; % NG
	79474	 22.8	 6.5	 28.0	 -15.0	 1.0	 100.0	 1	 45.1	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.1; % NG
	79486	 150.5	 17.3	 110.9	 -76.3	 1.0	 100.0	 1	 229.0	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 229.0; % COW
	79500	 69.25	 14.8	 64.1	 -34.5	 1.0	 100.0	 1	 103.5	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5; % COW
	79501	 84.2	 13.05	 56.6	 -30.5	 1.0	 100.0	 1	 91.4	 77.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.4; % NG
	79501	 74.85	 14.15	 61.2	 -32.9	 1.0	 100.0	 1	 98.7	 51.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.7; % NG
	79501	 74.85	 14.15	 61.2	 -32.9	 1.0	 100.0	 1	 98.7	 51.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.7; % NG
	79503	 35.25	 0.0	 27.7	 -27.7	 1.0	 100.0	 1	 70.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	79504	 34.4	 0.0	 17.0	 -17.0	 1.0	 100.0	 1	 67.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.8; % PEL
	79505	 35.1	 4.55	 29.2	 -20.1	 1.0	 100.0	 1	 60.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.2; % NG
	79506	 23.29	 4.7	 20.9	 -11.5	 1.0	 100.0	 1	 34.5	 12.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.5; % PEL
	79506	 50.625	 10.25	 45.5	 -25.0	 1.0	 100.0	 1	 75.0	 26.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % COW
	79508	 1.68	 0.7	 2.52	 -1.12	 1.0	 100.0	 1	 3.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.36; % PEL
	79508	 1.68	 0.7	 2.52	 -1.12	 1.0	 100.0	 1	 3.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.36; % COW
	79508	 1.68	 0.7	 2.52	 -1.12	 1.0	 100.0	 1	 3.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.36; % PEL
	79508	 1.68	 0.7	 2.52	 -1.12	 1.0	 100.0	 1	 3.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.36; % NG
	79508	 1.68	 0.7	 2.52	 -1.12	 1.0	 100.0	 1	 3.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.36; % PEL
	79508	 1.68	 0.7	 2.52	 -1.12	 1.0	 100.0	 1	 3.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.36; % NG
	79508	 1.68	 0.7	 2.52	 -1.12	 1.0	 100.0	 1	 3.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.36; % PEL
	79508	 1.68	 0.7	 2.52	 -1.12	 1.0	 100.0	 1	 3.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.36; % PEL
	79508	 1.68	 0.7	 2.52	 -1.12	 1.0	 100.0	 1	 3.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.36; % NG
	79508	 1.68	 0.7	 2.52	 -1.12	 1.0	 100.0	 1	 3.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.36; % NG
	79509	 27.0	 0.0	 11.9	 -11.9	 1.0	 100.0	 1	 30.0	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0; % NG
	79509	 30.5	 0.0	 15.9	 -15.9	 1.0	 100.0	 1	 35.0	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % PEL
	79510	 8.5	 0.85	 5.35	 -3.65	 1.0	 100.0	 1	 11.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0; % NG
	79510	 8.5	 0.85	 5.35	 -3.65	 1.0	 100.0	 1	 11.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0; % NG
	79511	 11.85	 2.95	 12.8	 -6.9	 1.0	 100.0	 1	 20.7	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7; % PEL
	79511	 11.85	 2.95	 12.8	 -6.9	 1.0	 100.0	 1	 20.7	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7; % PEL
	79511	 11.85	 2.95	 12.8	 -6.9	 1.0	 100.0	 1	 20.7	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7; % PEL
	79511	 11.85	 2.95	 12.8	 -6.9	 1.0	 100.0	 1	 20.7	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7; % PEL
	79513	 7.5	 2.075	 7.5	 -3.35	 1.0	 100.0	 1	 10.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % PEL
	79513	 7.5	 2.075	 7.5	 -3.35	 1.0	 100.0	 1	 10.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0; % NG
	79540	 68.5	 0.0	 26.6	 -26.6	 1.0	 100.0	 1	 81.0	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.0; % COW
	79540	 68.5	 0.0	 26.6	 -26.6	 1.0	 100.0	 1	 81.0	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.0; % COW
	79540	 74.35	 0.0	 30.5	 -30.5	 1.0	 100.0	 1	 92.7	 56.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 92.7; % NG
	79546	 35.25	 10.55	 43.6	 -22.5	 1.0	 100.0	 1	 67.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5; % PEL
	79550	 42.65	 8.2	 35.5	 -19.1	 1.0	 100.0	 1	 57.3	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.3; % NG
	79550	 42.65	 8.2	 35.5	 -19.1	 1.0	 100.0	 1	 57.3	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.3; % PEL
	79550	 42.65	 8.2	 35.5	 -19.1	 1.0	 100.0	 1	 57.3	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.3; % PEL
	79550	 42.65	 8.2	 35.5	 -19.1	 1.0	 100.0	 1	 57.3	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.3; % NG
	79550	 42.65	 8.2	 35.5	 -19.1	 1.0	 100.0	 1	 57.3	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.3; % NG
	79554	 11.25	 2.5	 10.83	 -5.83	 1.0	 100.0	 1	 17.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % PEL
	79554	 11.25	 2.5	 10.83	 -5.83	 1.0	 100.0	 1	 17.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % PEL
	79554	 11.25	 2.5	 10.83	 -5.83	 1.0	 100.0	 1	 17.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % NG
	79558	 30.65	 9.15	 33.0	 -14.7	 1.0	 100.0	 1	 44.0	 17.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0; % NG
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % NG
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % PEL
	79571	 0.75	 0.315	 1.13	 -0.5	 1.0	 100.0	 1	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5; % NG
	79610	 71.0	 15.75	 68.2	 -36.7	 1.0	 100.0	 1	 110.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.0; % NG
	79610	 71.0	 15.75	 68.2	 -36.7	 1.0	 100.0	 1	 110.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.0; % NG
	79610	 67.5	 15.75	 68.2	 -36.7	 1.0	 100.0	 1	 110.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.0; % NG
	79617	 43.0	 4.0	 25.7	 -17.7	 1.0	 100.0	 1	 53.0	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0; % NG
	79617	 43.0	 4.0	 25.7	 -17.7	 1.0	 100.0	 1	 53.0	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0; % NG
	79617	 78.6	 7.35	 47.1	 -32.4	 1.0	 100.0	 1	 97.2	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.2; % NG
	79617	 78.6	 7.35	 47.1	 -32.4	 1.0	 100.0	 1	 97.2	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.2; % NG
	79619	 11.9	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8; % PEL
	79619	 65.95	 6.95	 44.5	 -30.6	 1.0	 100.0	 1	 91.9	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.9; % NG
	79619	 65.95	 6.95	 44.5	 -30.6	 1.0	 100.0	 1	 91.9	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.9; % NG
	79619	 65.95	 6.95	 44.5	 -30.6	 1.0	 100.0	 1	 91.9	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.9; % NG
	79619	 65.95	 6.95	 44.5	 -30.6	 1.0	 100.0	 1	 91.9	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.9; % NG
	79632	 27.8	 6.8	 29.5	 -15.9	 1.0	 100.0	 1	 47.6	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.6; % NG
	79637	 4.0	 0.865	 3.73	 -2.0	 1.0	 100.0	 1	 6.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0; % NG
	79637	 4.0	 0.865	 3.73	 -2.0	 1.0	 100.0	 1	 6.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0; % PEL
	79637	 4.0	 0.865	 3.73	 -2.0	 1.0	 100.0	 1	 6.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0; % NG
	79637	 4.0	 0.865	 3.73	 -2.0	 1.0	 100.0	 1	 6.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0; % PEL
	79638	 11.85	 2.95	 12.8	 -6.9	 1.0	 100.0	 1	 20.7	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7; % PEL
	79638	 11.85	 2.95	 12.8	 -6.9	 1.0	 100.0	 1	 20.7	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7; % NG
	79638	 11.85	 2.95	 12.8	 -6.9	 1.0	 100.0	 1	 20.7	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7; % PEL
	79638	 11.85	 2.95	 12.8	 -6.9	 1.0	 100.0	 1	 20.7	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7; % PEL
	79654	 134.8	 45.75	 164.7	 -73.2	 1.0	 100.0	 1	 219.6	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 219.6; % NG
	79654	 134.8	 45.75	 164.7	 -73.2	 1.0	 100.0	 1	 219.6	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 219.6; % NG
	79662	 63.85	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 95.7	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.7; % NG
	79666	 54.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % NG
	79671	 20.05	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	79671	 20.05	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	79672	 9.85	 0.0	 6.15	 -6.15	 1.0	 100.0	 1	 18.7	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.7; % PEL
	79672	 9.85	 0.0	 6.15	 -6.15	 1.0	 100.0	 1	 18.7	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.7; % NG
	79673	 23.625	 4.75	 21.2	 -11.7	 1.0	 100.0	 1	 35.0	 12.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % NG
	79673	 50.42	 10.2	 45.3	 -24.9	 1.0	 100.0	 1	 74.7	 26.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.7; % PEL
	79674	 15.5	 1.95	 12.6	 -8.7	 1.0	 100.0	 1	 26.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.0; % PEL
	79674	 46.0	 6.2	 39.7	 -27.3	 1.0	 100.0	 1	 82.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.0; % NG
	79675	 4.585	 1.7	 6.13	 -2.73	 1.0	 100.0	 1	 8.17	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.1667; % COW
	79675	 4.585	 1.7	 6.13	 -2.73	 1.0	 100.0	 1	 8.17	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.1667; % PEL
	79675	 4.585	 1.7	 6.13	 -2.73	 1.0	 100.0	 1	 8.17	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.1667; % NG
	81895	 130.5	 0.0	 57.5	 -57.5	 1.0	 100.0	 1	 130.5	 130.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	81900	 90.8	 13.3	 65.5	 -38.9	 1.0	 100.0	 1	 116.6	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 116.6; % NG
	81900	 85.8	 13.3	 65.5	 -38.9	 1.0	 100.0	 1	 116.6	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 116.6; % COW
	81904	 53.0	 0.0	 46.7	 -46.7	 1.0	 100.0	 1	 106.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	81905	 10.215	 2.49	 10.8	 -5.82	 1.0	 100.0	 1	 17.43	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.4333; % NG
	81905	 10.215	 2.49	 10.8	 -5.82	 1.0	 100.0	 1	 17.43	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.4333; % PEL
	81905	 10.215	 2.49	 10.8	 -5.82	 1.0	 100.0	 1	 17.43	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.4333; % NG
	81905	 10.215	 2.49	 10.8	 -5.82	 1.0	 100.0	 1	 17.43	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.4333; % PEL
	81905	 10.215	 2.49	 10.8	 -5.82	 1.0	 100.0	 1	 17.43	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.4333; % PEL
	81905	 10.215	 2.49	 10.8	 -5.82	 1.0	 100.0	 1	 17.43	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.4333; % PEL
	81917	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	81917	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	81917	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	81917	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	81921	 31.55	 4.0	 25.7	 -17.7	 1.0	 100.0	 1	 53.1	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1; % NG
	81921	 49.4	 6.7	 43.0	 -29.6	 1.0	 100.0	 1	 88.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.8; % NG
	81925	 29.2	 5.95	 25.7	 -13.8	 1.0	 100.0	 1	 41.4	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4; % COW
	81925	 29.2	 5.95	 25.7	 -13.8	 1.0	 100.0	 1	 41.4	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4; % NG
	81927	 13.5	 3.15	 13.6	 -7.3	 1.0	 100.0	 1	 22.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	81952	 84.375	 15.75	 76.5	 -45.0	 1.0	 100.0	 1	 135.0	 33.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % NG
	81952	 84.375	 15.75	 76.5	 -45.0	 1.0	 100.0	 1	 135.0	 33.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0; % NG
	81959	 73.5	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.0	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	81959	 73.5	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.0	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	81959	 73.5	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.0	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	81959	 60.0	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	81959	 60.0	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	81967	 39.0	 8.3	 35.9	 -19.3	 1.0	 100.0	 1	 58.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.0; % NG
	81967	 65.05	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.1	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.1; % PEL
	81970	 50.0	 6.0	 38.7	 -26.7	 1.0	 100.0	 1	 80.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % NG
	81972	 54.05	 5.5	 35.4	 -24.4	 1.0	 100.0	 1	 73.1	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 73.1; % NG
	81975	 38.7	 0.0	 5.3	 -5.3	 1.0	 100.0	 1	 68.4	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.4; % PEL
	81978	 10.5	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % COW
	81978	 10.5	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % COW
	81978	 10.5	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	81978	 10.5	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	81979	 13.0	 3.0	 13.0	 -7.0	 1.0	 100.0	 1	 21.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0; % PEL
	81979	 14.5	 3.45	 14.9	 -8.0	 1.0	 100.0	 1	 24.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % PEL
	81979	 9.565	 2.7	 10.72	 -5.32	 1.0	 100.0	 1	 16.0	 3.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % COW
	81979	 9.565	 2.7	 10.72	 -5.32	 1.0	 100.0	 1	 16.0	 3.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	81979	 9.565	 2.7	 10.72	 -5.32	 1.0	 100.0	 1	 16.0	 3.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	81979	 9.565	 2.7	 10.72	 -5.32	 1.0	 100.0	 1	 16.0	 3.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0; % NG
	81981	 30.0	 0.0	 23.7	 -23.7	 1.0	 100.0	 1	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	81982	 8.83	 3.1	 11.13	 -4.93	 1.0	 100.0	 1	 14.83	 2.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8333; % NG
	81982	 8.83	 3.1	 11.13	 -4.93	 1.0	 100.0	 1	 14.83	 2.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8333; % NG
	81982	 8.83	 3.1	 11.13	 -4.93	 1.0	 100.0	 1	 14.83	 2.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8333; % NG
	81985	 27.0	 3.3	 21.3	 -14.7	 1.0	 100.0	 1	 44.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0; % NG
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % NG
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % NG
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % COW
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % NG
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % NG
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % NG
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % NG
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % NG
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % NG
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % NG
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % NG
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726; % PEL
	81988	 18.5	 1.7	 11.1	 -7.7	 1.0	 100.0	 1	 23.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % PEL
	81988	 25.05	 2.5	 16.0	 -11.0	 1.0	 100.0	 1	 33.1	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.1; % NG
	81990	 32.9	 0.0	 5.5	 -5.5	 1.0	 100.0	 1	 38.6	 27.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.6; % COW
	81990	 25.95	 0.0	 8.7	 -8.7	 1.0	 100.0	 1	 29.8	 22.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.8; % NG
	81990	 49.5	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	81991	 17.55	 4.9	 17.6	 -7.8	 1.0	 100.0	 1	 23.4	 11.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4; % NG
	81991	 17.55	 4.9	 17.6	 -7.8	 1.0	 100.0	 1	 23.4	 11.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4; % NG
	81991	 17.55	 4.9	 17.6	 -7.8	 1.0	 100.0	 1	 23.4	 11.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4; % NG
	81992	 21.1	 5.15	 18.6	 -8.3	 1.0	 100.0	 1	 24.8	 17.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.8; % PEL
	81992	 19.0	 2.95	 13.6	 -7.7	 1.0	 100.0	 1	 23.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % NG
	81993	 0.0	 0.0	 5.7	 -3.55	 1.0	 100.0	 0	 10.6	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.6; % NG
	81993	 0.0	 0.0	 5.7	 -3.55	 1.0	 100.0	 0	 10.6	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.6; % PEL
	81994	 30.0	 6.3	 27.3	 -14.7	 1.0	 100.0	 1	 44.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0; % NG
	81994	 13.0	 3.0	 13.0	 -7.0	 1.0	 100.0	 1	 21.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0; % PEL
	82010	 163.0	 53.35	 192.0	 -85.3	 1.0	 100.0	 1	 256.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 256.0; % NG
	82037	 52.5	 7.55	 48.4	 -33.3	 1.0	 100.0	 1	 100.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0; % NG
	82052	 29.5	 4.75	 20.5	 -11.0	 1.0	 100.0	 1	 33.0	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0; % NG
	82053	 29.5	 4.75	 20.5	 -11.0	 1.0	 100.0	 1	 33.0	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0; % NG
	82056	 20.375	 2.95	 15.5	 -9.6	 1.0	 100.0	 1	 28.8	 11.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % PEL
	82056	 20.375	 2.95	 15.5	 -9.6	 1.0	 100.0	 1	 28.8	 11.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % COW
	82057	 9.625	 1.225	 7.05	 -4.6	 1.0	 100.0	 1	 13.75	 5.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.75; % NG
	82057	 9.625	 1.225	 7.05	 -4.6	 1.0	 100.0	 1	 13.75	 5.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.75; % NG
	82058	 8.985	 7.7	 7.7	 7.7	 1.0	 100.0	 1	 13.75	 4.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.75; % COW
	82058	 8.985	 7.7	 7.7	 7.7	 1.0	 100.0	 1	 13.75	 4.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.75; % PEL
	82058	 16.5	 15.5	 15.5	 15.5	 1.0	 100.0	 1	 25.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	82060	 19.1	 2.75	 14.5	 -9.0	 1.0	 100.0	 1	 27.0	 11.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % PEL
	82060	 19.1	 2.75	 14.5	 -9.0	 1.0	 100.0	 1	 27.0	 11.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % NG
	84656	 247.7	 66.95	 265.7	 -131.8	 1.0	 100.0	 1	 395.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 395.4; % NG
	84718	 58.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 86.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0; % NG
	84719	 72.5	 12.9	 55.8	 -30.0	 1.0	 100.0	 1	 90.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0; % NG
	84719	 52.0	 12.05	 52.1	 -28.0	 1.0	 100.0	 1	 84.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.0; % NG
	84719	 55.5	 12.3	 53.3	 -28.7	 1.0	 100.0	 1	 86.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0; % NG
	84719	 53.0	 12.3	 53.3	 -28.7	 1.0	 100.0	 1	 86.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0; % NG
	84719	 53.0	 12.3	 53.3	 -28.7	 1.0	 100.0	 1	 86.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0; % NG
	84724	 26.0	 8.75	 31.5	 -14.0	 1.0	 100.0	 1	 42.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0; % NG
	84724	 128.75	 24.0	 103.8	 -55.8	 1.0	 100.0	 1	 167.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.5; % NG
	84724	 25.0	 8.35	 30.0	 -13.3	 1.0	 100.0	 1	 40.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	84724	 46.25	 11.8	 51.1	 -27.5	 1.0	 100.0	 1	 82.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.5; % PEL
	84724	 62.5	 16.65	 60.0	 -26.7	 1.0	 100.0	 1	 80.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0; % PEL
	84731	 11.635	 1.515	 8.9	 -5.87	 1.0	 100.0	 1	 17.65	 5.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.65; % NG
	84731	 11.635	 1.515	 8.9	 -5.87	 1.0	 100.0	 1	 17.65	 5.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.65; % NG
	84731	 11.635	 1.515	 8.9	 -5.87	 1.0	 100.0	 1	 17.65	 5.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.65; % COW
	84731	 11.635	 1.515	 8.9	 -5.87	 1.0	 100.0	 1	 17.65	 5.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.65; % PEL
	84731	 13.3	 1.65	 10.5	 -7.2	 1.0	 100.0	 1	 21.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6; % NG
	84731	 13.75	 4.15	 15.0	 -6.7	 1.0	 100.0	 1	 20.0	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	84732	 38.8	 9.7	 41.9	 -22.5	 1.0	 100.0	 1	 67.6	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.6; % NG
	84739	 20.295	 3.075	 15.3	 -9.15	 1.0	 100.0	 1	 27.5	 13.09	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % NG
	84739	 20.295	 3.075	 15.3	 -9.15	 1.0	 100.0	 1	 27.5	 13.09	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % NG
	84740	 32.0	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % PEL
	84740	 32.0	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	84740	 16.8	 4.1	 17.7	 -9.5	 1.0	 100.0	 1	 28.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.6; % NG
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % NG
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % NG
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % NG
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % NG
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	84742	 2.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 2.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.5; % PEL
	84743	 11.655	 2.335	 10.1	 -5.43	 1.0	 100.0	 1	 16.3	 7.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.3; % PEL
	84743	 11.655	 2.335	 10.1	 -5.43	 1.0	 100.0	 1	 16.3	 7.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.3; % NG
	84743	 11.655	 2.335	 10.1	 -5.43	 1.0	 100.0	 1	 16.3	 7.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.3; % PEL
	84743	 16.06	 3.05	 14.4	 -8.3	 1.0	 100.0	 1	 25.0	 7.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	84743	 40.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	84743	 73.05	 13.8	 59.6	 -32.0	 1.0	 100.0	 1	 96.1	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.1; % NG
	84745	 29.4	 6.95	 30.2	 -16.3	 1.0	 100.0	 1	 48.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.8; % NG
	84745	 15.75	 3.8	 16.4	 -8.8	 1.0	 100.0	 1	 26.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.5; % PEL
	84745	 34.45	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9; % NG
	84746	 24.25	 5.8	 25.1	 -13.5	 1.0	 100.0	 1	 40.5	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.5; % NG
	84748	 18.7	 7.4	 26.6	 -11.8	 1.0	 100.0	 1	 35.4	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.4; % PEL
	84748	 22.25	 8.85	 31.9	 -14.2	 1.0	 100.0	 1	 42.5	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.5; % NG
	84751	 19.35	 4.85	 20.9	 -11.2	 1.0	 100.0	 1	 33.7	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.7; % NG
	84751	 19.35	 4.85	 20.9	 -11.2	 1.0	 100.0	 1	 33.7	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.7; % PEL
	84752	 30.25	 8.4	 36.3	 -19.5	 1.0	 100.0	 1	 58.5	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.5; % PEL
	84752	 17.0	 6.65	 24.0	 -10.7	 1.0	 100.0	 1	 32.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % PEL
	84755	 8.6	 1.6	 6.95	 -3.75	 1.0	 100.0	 1	 11.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % NG
	84755	 8.6	 1.6	 6.95	 -3.75	 1.0	 100.0	 1	 11.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2; % COW
	84755	 25.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	84755	 80.6	 6.5	 41.7	 -28.7	 1.0	 100.0	 1	 86.2	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.2; % PEL
	84823	 7.295	 1.54	 5.55	 -2.47	 1.0	 100.0	 1	 7.4	 7.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.4; % COW
	84823	 7.295	 1.54	 5.55	 -2.47	 1.0	 100.0	 1	 7.4	 7.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.4; % NG
	84823	 7.295	 1.54	 5.55	 -2.47	 1.0	 100.0	 1	 7.4	 7.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.4; % COW
	84823	 7.295	 1.54	 5.55	 -2.47	 1.0	 100.0	 1	 7.4	 7.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.4; % NG
	84824	 18.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 27.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0; % NG
	84824	 24.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 39.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.0; % NG
	84872	 10.3	 2.8	 12.15	 -6.55	 1.0	 100.0	 1	 19.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6; % PEL
	84872	 10.3	 2.8	 12.15	 -6.55	 1.0	 100.0	 1	 19.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6; % NG
	84874	 28.0	 2.15	 13.6	 -9.3	 1.0	 100.0	 1	 28.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0; % PEL
	84874	 28.0	 2.15	 13.6	 -9.3	 1.0	 100.0	 1	 28.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0; % PEL
	84874	 28.0	 2.15	 13.6	 -9.3	 1.0	 100.0	 1	 28.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0; % NG
	87110	 28.76	 3.115	 15.85	 -9.62	 1.0	 100.0	 1	 28.83	 28.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8333; % PEL
	87110	 28.76	 3.115	 15.85	 -9.62	 1.0	 100.0	 1	 28.83	 28.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8333; % NG
	87110	 28.76	 3.115	 15.85	 -9.62	 1.0	 100.0	 1	 28.83	 28.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8333; % NG
	87110	 0.0	 0.0	 15.85	 -9.62	 1.0	 100.0	 0	 28.83	 28.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8333; % PEL
	87110	 0.0	 0.0	 15.85	 -9.62	 1.0	 100.0	 0	 28.83	 28.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8333; % PEL
	87110	 0.0	 0.0	 15.85	 -9.62	 1.0	 100.0	 0	 28.83	 28.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8333; % COW
	87120	 32.45	 5.7	 24.7	 -13.3	 1.0	 100.0	 1	 39.9	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.9; % NG
	87120	 78.8	 11.85	 51.2	 -27.5	 1.0	 100.0	 1	 82.6	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.6; % NG
	87121	 75.0	 10.05	 45.1	 -25.0	 1.0	 100.0	 1	 75.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	87121	 75.0	 10.05	 45.1	 -25.0	 1.0	 100.0	 1	 75.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	87121	 75.0	 10.05	 45.1	 -25.0	 1.0	 100.0	 1	 75.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	87127	 45.95	 4.2	 24.0	 -15.6	 1.0	 100.0	 1	 46.9	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.9; % NG
	87168	 59.4	 7.5	 47.9	 -32.9	 1.0	 100.0	 1	 98.8	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.8; % NG
	87168	 68.0	 13.75	 59.5	 -32.0	 1.0	 100.0	 1	 96.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.0; % NG
	87171	 56.0	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 37.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	87171	 75.3	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 37.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6; % COW
	87174	 30.65	 0.0	 18.1	 -18.1	 1.0	 100.0	 1	 42.4	 18.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.4; % PEL
	87174	 30.65	 0.0	 18.1	 -18.1	 1.0	 100.0	 1	 42.4	 18.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.4; % NG
	87174	 31.75	 0.0	 19.0	 -19.0	 1.0	 100.0	 1	 44.6	 18.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.6; % NG
	87174	 31.75	 0.0	 19.0	 -19.0	 1.0	 100.0	 1	 44.6	 18.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.6; % NG
	87174	 31.75	 0.0	 19.0	 -19.0	 1.0	 100.0	 1	 44.6	 18.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.6; % NG
	87176	 32.5	 2.45	 15.7	 -10.8	 1.0	 100.0	 1	 32.5	 32.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.5; % NG
	87176	 32.5	 2.45	 15.7	 -10.8	 1.0	 100.0	 1	 32.5	 32.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.5; % PEL
	87176	 32.5	 2.45	 15.7	 -10.8	 1.0	 100.0	 1	 32.5	 32.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.5; % NG
	87176	 32.5	 2.45	 15.7	 -10.8	 1.0	 100.0	 1	 32.5	 32.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.5; % PEL
	87199	 70.315	 13.15	 63.8	 -37.5	 1.0	 100.0	 1	 112.5	 28.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % NG
	87199	 70.315	 13.15	 63.8	 -37.5	 1.0	 100.0	 1	 112.5	 28.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5; % NG
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % COW
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % NG
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % COW
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % NG
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % NG
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % NG
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % NG
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % COW
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % NG
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % NG
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % PEL
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % NG
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % NG
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % NG
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % NG
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % NG
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % NG
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % PEL
	87224	 6.025	 2.105	 7.62	 -3.41	 1.0	 100.0	 1	 10.23	 1.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2263; % NG
	87239	 40.5	 8.2	 36.4	 -20.0	 1.0	 100.0	 1	 60.0	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % PEL
	87239	 40.5	 8.2	 36.4	 -20.0	 1.0	 100.0	 1	 60.0	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % PEL
	87239	 40.5	 8.2	 36.4	 -20.0	 1.0	 100.0	 1	 60.0	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % NG
	87239	 40.5	 8.2	 36.4	 -20.0	 1.0	 100.0	 1	 60.0	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % NG
	87241	 43.6	 10.9	 39.2	 -17.4	 1.0	 100.0	 1	 52.2	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.2; % NG
	87241	 43.6	 10.9	 39.2	 -17.4	 1.0	 100.0	 1	 52.2	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.2; % NG
	87241	 43.6	 10.9	 39.2	 -17.4	 1.0	 100.0	 1	 52.2	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.2; % NG
	87243	 31.85	 3.4	 21.8	 -15.0	 1.0	 100.0	 1	 45.0	 18.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	87246	 31.7	 0.0	 12.1	 -12.1	 1.0	 100.0	 1	 33.4	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.4; % NG
	87246	 24.7	 0.0	 12.1	 -12.1	 1.0	 100.0	 1	 33.4	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.4; % PEL
	87246	 24.7	 0.0	 12.1	 -12.1	 1.0	 100.0	 1	 33.4	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.4; % PEL
	87246	 24.7	 0.0	 12.1	 -12.1	 1.0	 100.0	 1	 33.4	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.4; % NG
	87246	 28.5	 0.0	 14.9	 -14.9	 1.0	 100.0	 1	 41.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.0; % NG
	87249	 20.75	 2.25	 14.4	 -9.9	 1.0	 100.0	 1	 29.7	 11.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.7; % NG
	87249	 20.75	 2.25	 14.4	 -9.9	 1.0	 100.0	 1	 29.7	 11.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.7; % PEL
	87251	 18.55	 1.85	 11.8	 -8.1	 1.0	 100.0	 1	 24.3	 12.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.3; % NG
	87251	 18.55	 1.85	 11.8	 -8.1	 1.0	 100.0	 1	 24.3	 12.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.3; % PEL
	87251	 20.55	 2.1	 13.3	 -9.1	 1.0	 100.0	 1	 27.4	 13.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.4; % PEL
	87251	 20.8	 2.1	 13.5	 -9.3	 1.0	 100.0	 1	 27.9	 13.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.9; % NG
	87252	 8.75	 2.4	 8.65	 -3.85	 1.0	 100.0	 1	 11.5	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5; % NG
	87252	 8.75	 2.4	 8.65	 -3.85	 1.0	 100.0	 1	 11.5	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5; % NG
	88792	 131.75	 31.3	 135.4	 -72.8	 1.0	 100.0	 1	 218.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.5; % NG
	88793	 100.65	 15.05	 96.7	 -66.6	 1.0	 100.0	 1	 199.7	 1.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	88801	 78.75	 0.0	 66.1	 -66.1	 1.0	 100.0	 1	 150.0	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	88805	 4.16	 1.735	 6.24	 -2.77	 1.0	 100.0	 1	 8.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.32; % NG
	88805	 4.16	 1.735	 6.24	 -2.77	 1.0	 100.0	 1	 8.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.32; % PEL
	88805	 4.16	 1.735	 6.24	 -2.77	 1.0	 100.0	 1	 8.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.32; % COW
	88805	 4.16	 1.735	 6.24	 -2.77	 1.0	 100.0	 1	 8.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.32; % NG
	88805	 4.16	 1.735	 6.24	 -2.77	 1.0	 100.0	 1	 8.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.32; % COW
	88805	 4.16	 1.735	 6.24	 -2.77	 1.0	 100.0	 1	 8.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.32; % COW
	88805	 4.16	 1.735	 6.24	 -2.77	 1.0	 100.0	 1	 8.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.32; % PEL
	88805	 4.16	 1.735	 6.24	 -2.77	 1.0	 100.0	 1	 8.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.32; % NG
	88805	 4.16	 1.735	 6.24	 -2.77	 1.0	 100.0	 1	 8.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.32; % PEL
	88805	 4.16	 1.735	 6.24	 -2.77	 1.0	 100.0	 1	 8.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.32; % PEL
	88805	 4.16	 1.735	 6.24	 -2.77	 1.0	 100.0	 1	 8.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.32; % COW
	88805	 4.16	 1.735	 6.24	 -2.77	 1.0	 100.0	 1	 8.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.32; % NG
	88805	 4.16	 1.735	 6.24	 -2.77	 1.0	 100.0	 1	 8.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.32; % COW
	88805	 4.16	 1.735	 6.24	 -2.77	 1.0	 100.0	 1	 8.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.32; % PEL
	88805	 4.16	 1.735	 6.24	 -2.77	 1.0	 100.0	 1	 8.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.32; % NG
	88810	 9.53	 1.935	 8.57	 -4.7	 1.0	 100.0	 1	 14.12	 4.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.1167; % NG
	88810	 9.53	 1.935	 8.57	 -4.7	 1.0	 100.0	 1	 14.12	 4.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.1167; % NG
	88810	 9.53	 1.935	 8.57	 -4.7	 1.0	 100.0	 1	 14.12	 4.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.1167; % NG
	88810	 9.53	 1.935	 8.57	 -4.7	 1.0	 100.0	 1	 14.12	 4.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.1167; % COW
	88810	 9.53	 1.935	 8.57	 -4.7	 1.0	 100.0	 1	 14.12	 4.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.1167; % COW
	88810	 9.53	 1.935	 8.57	 -4.7	 1.0	 100.0	 1	 14.12	 4.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.1167; % NG
	88813	 14.775	 2.295	 11.17	 -6.58	 1.0	 100.0	 1	 19.7	 9.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.7; % NG
	88813	 14.775	 2.295	 11.17	 -6.58	 1.0	 100.0	 1	 19.7	 9.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.7; % NG
	88813	 14.775	 2.295	 11.17	 -6.58	 1.0	 100.0	 1	 19.7	 9.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.7; % NG
	88813	 14.775	 2.295	 11.17	 -6.58	 1.0	 100.0	 1	 19.7	 9.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.7; % NG
	88816	 8.54	 1.8	 7.6	 -4.0	 1.0	 100.0	 1	 12.0	 5.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % NG
	88816	 8.54	 1.8	 7.6	 -4.0	 1.0	 100.0	 1	 12.0	 5.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % NG
	88816	 8.54	 1.8	 7.6	 -4.0	 1.0	 100.0	 1	 12.0	 5.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % COW
	88816	 8.54	 1.8	 7.6	 -4.0	 1.0	 100.0	 1	 12.0	 5.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % NG
	88816	 8.54	 1.8	 7.6	 -4.0	 1.0	 100.0	 1	 12.0	 5.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0; % NG
	88818	 4.585	 1.12	 4.8	 -2.56	 1.0	 100.0	 1	 7.67	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.6714; % COW
	88818	 4.585	 1.12	 4.8	 -2.56	 1.0	 100.0	 1	 7.67	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.6714; % NG
	88818	 4.585	 1.12	 4.8	 -2.56	 1.0	 100.0	 1	 7.67	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.6714; % NG
	88818	 4.585	 1.12	 4.8	 -2.56	 1.0	 100.0	 1	 7.67	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.6714; % COW
	88818	 4.585	 1.12	 4.8	 -2.56	 1.0	 100.0	 1	 7.67	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.6714; % NG
	88818	 4.585	 1.12	 4.8	 -2.56	 1.0	 100.0	 1	 7.67	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.6714; % NG
	88818	 4.585	 1.12	 4.8	 -2.56	 1.0	 100.0	 1	 7.67	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.6714; % NG
	88821	 6.875	 1.69	 7.2	 -3.82	 1.0	 100.0	 1	 11.5	 2.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5; % NG
	88821	 6.875	 1.69	 7.2	 -3.82	 1.0	 100.0	 1	 11.5	 2.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5; % NG
	88821	 6.875	 1.69	 7.2	 -3.82	 1.0	 100.0	 1	 11.5	 2.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5; % NG
	88821	 6.875	 1.69	 7.2	 -3.82	 1.0	 100.0	 1	 11.5	 2.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5; % NG
	88822	 29.05	 6.5	 28.0	 -15.0	 1.0	 100.0	 1	 45.1	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.1; % NG
	88822	 29.05	 6.5	 28.0	 -15.0	 1.0	 100.0	 1	 45.1	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.1; % NG
	88823	 23.7	 3.15	 20.1	 -13.8	 1.0	 100.0	 1	 41.4	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4; % NG
	88823	 23.7	 3.15	 20.1	 -13.8	 1.0	 100.0	 1	 41.4	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4; % NG
	88823	 51.5	 7.35	 47.0	 -32.3	 1.0	 100.0	 1	 97.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.0; % NG
	88826	 50.65	 5.35	 34.5	 -23.8	 1.0	 100.0	 1	 71.3	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.3; % PEL
	88826	 26.25	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % PEL
	88827	 12.0	 1.35	 8.7	 -6.0	 1.0	 100.0	 1	 18.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	88827	 12.0	 1.35	 8.7	 -6.0	 1.0	 100.0	 1	 18.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	88829	 17.885	 3.65	 16.1	 -8.8	 1.0	 100.0	 1	 26.5	 9.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.5; % NG
	88830	 110.25	 25.15	 108.8	 -58.5	 1.0	 100.0	 1	 175.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.5; % NG
	88830	 47.5	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	88830	 15.5	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	88831	 2.0	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	88831	 2.0	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	88831	 2.0	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	88831	 2.0	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	88831	 2.0	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	88831	 2.0	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	88831	 2.0	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	88831	 2.0	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	88831	 2.0	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	88831	 2.0	 0.415	 1.5	 -0.67	 1.0	 100.0	 1	 2.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0; % PEL
	88860	 227.7	 51.65	 223.4	 -120.1	 1.0	 100.0	 1	 360.4	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 360.4; % NG
	88869	 114.2	 16.4	 105.3	 -72.5	 1.0	 100.0	 1	 217.5	 10.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	88908	 32.5	 12.9	 46.5	 -20.7	 1.0	 100.0	 1	 62.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	88912	 40.25	 4.85	 31.2	 -21.5	 1.0	 100.0	 1	 64.5	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.5; % NG
	88912	 40.25	 4.85	 31.2	 -21.5	 1.0	 100.0	 1	 64.5	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.5; % NG
	88912	 40.25	 4.85	 31.2	 -21.5	 1.0	 100.0	 1	 64.5	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.5; % NG
	88912	 29.0	 11.25	 40.5	 -18.0	 1.0	 100.0	 1	 54.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	88912	 29.0	 11.25	 40.5	 -18.0	 1.0	 100.0	 1	 54.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0; % NG
	88916	 24.75	 0.0	 19.6	 -19.6	 1.0	 100.0	 1	 49.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	88916	 25.5	 0.0	 20.2	 -20.2	 1.0	 100.0	 1	 51.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	88916	 49.5	 0.0	 43.7	 -43.7	 1.0	 100.0	 1	 99.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	88917	 10.435	 1.85	 9.13	 -5.43	 1.0	 100.0	 1	 16.33	 4.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.3333; % NG
	88917	 10.435	 1.85	 9.13	 -5.43	 1.0	 100.0	 1	 16.33	 4.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.3333; % NG
	88917	 10.435	 1.85	 9.13	 -5.43	 1.0	 100.0	 1	 16.33	 4.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.3333; % COW
	88921	 14.0	 4.6	 16.5	 -7.3	 1.0	 100.0	 1	 22.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	88921	 7.95	 2.765	 9.93	 -4.4	 1.0	 100.0	 1	 13.23	 2.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.2333; % COW
	88921	 7.95	 2.765	 9.93	 -4.4	 1.0	 100.0	 1	 13.23	 2.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.2333; % NG
	88921	 7.95	 2.765	 9.93	 -4.4	 1.0	 100.0	 1	 13.23	 2.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.2333; % NG
	88922	 30.5	 5.6	 24.2	 -13.0	 1.0	 100.0	 1	 39.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.0; % PEL
	88922	 30.5	 5.6	 24.2	 -13.0	 1.0	 100.0	 1	 39.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.0; % NG
	88922	 30.5	 5.6	 24.2	 -13.0	 1.0	 100.0	 1	 39.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.0; % NG
	88922	 31.5	 8.85	 38.4	 -20.7	 1.0	 100.0	 1	 62.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0; % NG
	88924	 139.0	 13.05	 83.8	 -57.7	 1.0	 100.0	 1	 173.0	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.0; % NG
	88924	 31.5	 4.75	 20.5	 -11.0	 1.0	 100.0	 1	 33.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0; % PEL
	88924	 31.5	 4.75	 20.5	 -11.0	 1.0	 100.0	 1	 33.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0; % PEL
	88924	 31.5	 4.75	 20.5	 -11.0	 1.0	 100.0	 1	 33.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0; % COW
	88924	 57.5	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	88924	 57.5	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	88928	 13.8	 2.0	 12.9	 -8.9	 1.0	 100.0	 1	 26.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.6; % NG
	88930	 3.39	 0.625	 2.99	 -1.74	 1.0	 100.0	 1	 5.21	 1.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2143; % PEL
	88930	 4.15	 1.015	 4.63	 -2.6	 1.0	 100.0	 1	 7.8	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.8; % COW
	88930	 3.39	 0.625	 2.99	 -1.74	 1.0	 100.0	 1	 5.21	 1.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2143; % NG
	88930	 3.39	 0.625	 2.99	 -1.74	 1.0	 100.0	 1	 5.21	 1.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2143; % NG
	88930	 3.39	 0.625	 2.99	 -1.74	 1.0	 100.0	 1	 5.21	 1.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2143; % PEL
	88930	 3.39	 0.625	 2.99	 -1.74	 1.0	 100.0	 1	 5.21	 1.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2143; % NG
	88930	 3.39	 0.625	 2.99	 -1.74	 1.0	 100.0	 1	 5.21	 1.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2143; % COW
	88930	 3.39	 0.625	 2.99	 -1.74	 1.0	 100.0	 1	 5.21	 1.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2143; % NG
	88930	 4.15	 1.015	 4.63	 -2.6	 1.0	 100.0	 1	 7.8	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.8; % NG
	88930	 4.15	 1.015	 4.63	 -2.6	 1.0	 100.0	 1	 7.8	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.8; % COW
	88931	 17.4	 0.0	 4.1	 -4.1	 1.0	 100.0	 1	 20.0	 14.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	88949	 118.65	 13.4	 85.9	 -59.1	 1.0	 100.0	 1	 177.3	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 177.3; % COW
	88949	 75.6	 8.0	 51.4	 -35.4	 1.0	 100.0	 1	 106.2	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.2; % NG
	88955	 54.1	 0.0	 47.3	 -47.3	 1.0	 100.0	 1	 107.2	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	88958	 50.25	 0.0	 44.3	 -44.3	 1.0	 100.0	 1	 100.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	88964	 42.75	 0.0	 37.7	 -37.7	 1.0	 100.0	 1	 85.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	88969	 10.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	88969	 10.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % NG
	88969	 10.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	88969	 10.5	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0; % PEL
	88972	 37.5	 8.3	 35.9	 -19.3	 1.0	 100.0	 1	 58.0	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.0; % PEL
	88972	 37.5	 8.3	 35.9	 -19.3	 1.0	 100.0	 1	 58.0	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.0; % PEL
	88977	 45.8	 11.7	 50.6	 -27.2	 1.0	 100.0	 1	 81.6	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6; % NG
	88977	 30.0	 10.4	 37.5	 -16.7	 1.0	 100.0	 1	 50.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	88980	 7.65	 1.935	 7.87	 -4.0	 1.0	 100.0	 1	 11.97	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.9667; % NG
	88980	 7.65	 1.935	 7.87	 -4.0	 1.0	 100.0	 1	 11.97	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.9667; % NG
	88980	 7.65	 1.935	 7.87	 -4.0	 1.0	 100.0	 1	 11.97	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.9667; % NG
	88981	 20.0	 0.0	 11.5	 -11.5	 1.0	 100.0	 1	 35.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % PEL
	88981	 27.45	 0.0	 16.4	 -16.4	 1.0	 100.0	 1	 49.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9; % NG
	88982	 16.05	 0.0	 12.6	 -12.6	 1.0	 100.0	 1	 32.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	88984	 13.25	 3.45	 14.9	 -8.0	 1.0	 100.0	 1	 24.0	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % PEL
	88984	 15.0	 3.9	 17.0	 -9.2	 1.0	 100.0	 1	 27.5	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5; % COW
	88984	 5.165	 1.285	 5.57	 -3.0	 1.0	 100.0	 1	 9.0	 1.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0; % NG
	88984	 5.165	 1.285	 5.57	 -3.0	 1.0	 100.0	 1	 9.0	 1.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0; % NG
	88984	 5.165	 1.285	 5.57	 -3.0	 1.0	 100.0	 1	 9.0	 1.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0; % COW
	88985	 8.55	 2.125	 8.6	 -4.35	 1.0	 100.0	 1	 13.1	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.1; % NG
	88985	 8.55	 2.125	 8.6	 -4.35	 1.0	 100.0	 1	 13.1	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.1; % NG
	88986	 15.7	 3.35	 14.5	 -7.8	 1.0	 100.0	 1	 23.4	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4; % PEL
	88987	 10.0	 0.0	 7.9	 -7.9	 1.0	 100.0	 1	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	89012	 14.4	 4.02	 16.64	 -8.6	 1.0	 100.0	 1	 25.8	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.8; % NG
	89012	 14.4	 4.02	 16.64	 -8.6	 1.0	 100.0	 1	 25.8	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.8; % NG
	89012	 14.4	 4.02	 16.64	 -8.6	 1.0	 100.0	 1	 25.8	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.8; % PEL
	89012	 14.4	 4.02	 16.64	 -8.6	 1.0	 100.0	 1	 25.8	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.8; % PEL
	89012	 14.4	 4.02	 16.64	 -8.6	 1.0	 100.0	 1	 25.8	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.8; % PEL
	89012	 15.6	 2.15	 13.7	 -9.4	 1.0	 100.0	 1	 28.2	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.2; % NG
	89012	 15.95	 4.15	 17.9	 -9.6	 1.0	 100.0	 1	 28.9	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.9; % COW
	89012	 23.6	 9.0	 32.4	 -14.4	 1.0	 100.0	 1	 43.2	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.2; % NG
	89021	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	89021	 43.75	 9.9	 42.0	 -22.2	 1.0	 100.0	 1	 66.5	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.5; % NG
	89022	 38.7	 13.25	 47.6	 -21.1	 1.0	 100.0	 1	 63.4	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.4; % NG
	89022	 14.0	 4.6	 16.5	 -7.3	 1.0	 100.0	 1	 22.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	89022	 19.0	 6.65	 24.0	 -10.7	 1.0	 100.0	 1	 32.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % NG
	89023	 38.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	89027	 4.035	 1.2	 4.58	 -2.18	 1.0	 100.0	 1	 6.57	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5667; % PEL
	89027	 4.035	 1.2	 4.58	 -2.18	 1.0	 100.0	 1	 6.57	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5667; % NG
	89027	 4.035	 1.2	 4.58	 -2.18	 1.0	 100.0	 1	 6.57	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5667; % NG
	89027	 4.035	 1.2	 4.58	 -2.18	 1.0	 100.0	 1	 6.57	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5667; % NG
	89027	 4.035	 1.2	 4.58	 -2.18	 1.0	 100.0	 1	 6.57	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5667; % NG
	89027	 4.035	 1.2	 4.58	 -2.18	 1.0	 100.0	 1	 6.57	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5667; % NG
	89031	 0.0	 0.0	 13.15	 -5.85	 1.0	 100.0	 0	 17.5	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % PEL
	89031	 0.0	 0.0	 13.15	 -5.85	 1.0	 100.0	 0	 17.5	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5; % PEL
	89032	 38.9	 5.8	 25.0	 -13.4	 1.0	 100.0	 1	 40.3	 37.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.3; % NG
	89032	 29.6	 4.55	 19.8	 -10.7	 1.0	 100.0	 1	 32.0	 27.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0; % NG
	89033	 15.9	 4.1	 17.8	 -9.6	 1.0	 100.0	 1	 28.8	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % PEL
	89033	 15.9	 4.1	 17.8	 -9.6	 1.0	 100.0	 1	 28.8	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8; % PEL
	89034	 16.06	 3.05	 14.4	 -8.3	 1.0	 100.0	 1	 25.0	 7.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	89034	 16.06	 3.05	 14.4	 -8.3	 1.0	 100.0	 1	 25.0	 7.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	91068	 140.0	 25.8	 111.6	 -60.0	 1.0	 100.0	 1	 180.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0; % NG
	91068	 34.0	 4.2	 27.1	 -18.7	 1.0	 100.0	 1	 56.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.0; % NG
	91076	 42.0	 6.05	 31.8	 -19.7	 1.0	 100.0	 1	 59.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % NG
	91076	 95.5	 9.5	 61.0	 -42.0	 1.0	 100.0	 1	 126.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 126.0; % NG
	91080	 14.625	 2.275	 11.05	 -6.5	 1.0	 100.0	 1	 19.5	 9.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.5; % NG
	91080	 14.625	 2.275	 11.05	 -6.5	 1.0	 100.0	 1	 19.5	 9.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.5; % NG
	91080	 14.625	 2.275	 11.05	 -6.5	 1.0	 100.0	 1	 19.5	 9.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.5; % NG
	91080	 14.625	 2.275	 11.05	 -6.5	 1.0	 100.0	 1	 19.5	 9.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.5; % NG
	91088	 25.0	 3.4	 21.8	 -15.0	 1.0	 100.0	 1	 45.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	91088	 25.0	 3.4	 21.8	 -15.0	 1.0	 100.0	 1	 45.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0; % NG
	91088	 26.0	 3.55	 22.8	 -15.7	 1.0	 100.0	 1	 47.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % NG
	91090	 25.1	 0.0	 13.2	 -13.2	 1.0	 100.0	 1	 40.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.2; % COW
	91090	 25.1	 0.0	 13.2	 -13.2	 1.0	 100.0	 1	 40.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.2; % NG
	91090	 25.1	 0.0	 13.2	 -13.2	 1.0	 100.0	 1	 40.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.2; % NG
	91090	 25.1	 0.0	 13.2	 -13.2	 1.0	 100.0	 1	 40.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.2; % NG
	91101	 6.75	 0.65	 4.13	 -2.83	 1.0	 100.0	 1	 8.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.5; % NG
	91101	 6.75	 0.65	 4.13	 -2.83	 1.0	 100.0	 1	 8.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.5; % NG
	91101	 6.75	 0.65	 4.13	 -2.83	 1.0	 100.0	 1	 8.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.5; % NG
	91102	 19.0	 2.7	 17.4	 -12.0	 1.0	 100.0	 1	 36.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0; % NG
	91102	 13.5	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	91102	 16.3	 4.4	 19.0	 -10.2	 1.0	 100.0	 1	 30.6	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.6; % PEL
	91104	 17.0	 4.6	 16.5	 -7.3	 1.0	 100.0	 1	 22.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	91104	 17.0	 4.6	 16.5	 -7.3	 1.0	 100.0	 1	 22.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % COW
	91105	 15.7	 3.1	 13.3	 -7.1	 1.0	 100.0	 1	 21.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.4; % NG
	91105	 17.25	 3.5	 15.2	 -8.2	 1.0	 100.0	 1	 24.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.5; % PEL
	91105	 36.2	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4; % NG
	91105	 37.75	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	91105	 37.75	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	91108	 13.5	 0.0	 6.6	 -6.6	 1.0	 100.0	 1	 20.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
	91108	 13.5	 0.0	 6.6	 -6.6	 1.0	 100.0	 1	 20.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	91108	 13.5	 0.0	 6.6	 -6.6	 1.0	 100.0	 1	 20.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	91108	 13.5	 0.0	 6.6	 -6.6	 1.0	 100.0	 1	 20.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	91108	 13.5	 0.0	 6.6	 -6.6	 1.0	 100.0	 1	 20.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	91109	 13.5	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	91109	 16.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	91109	 25.0	 5.75	 24.8	 -13.3	 1.0	 100.0	 1	 40.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	91136	 154.75	 26.4	 114.3	 -61.5	 1.0	 100.0	 1	 184.5	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.5; % NG
	91136	 145.15	 24.95	 108.0	 -58.1	 1.0	 100.0	 1	 174.3	 116.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.3; % NG
	91144	 32.5	 0.0	 16.4	 -16.4	 1.0	 100.0	 1	 50.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % PEL
	91144	 13.5	 0.0	 7.2	 -7.2	 1.0	 100.0	 1	 22.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	91144	 92.9	 0.0	 41.3	 -41.3	 1.0	 100.0	 1	 125.8	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.8; % NG
	91144	 92.9	 0.0	 41.3	 -41.3	 1.0	 100.0	 1	 125.8	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.8; % NG
	91145	 69.0	 17.9	 77.5	 -41.7	 1.0	 100.0	 1	 125.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0; % NG
	91148	 77.0	 14.9	 64.5	 -34.7	 1.0	 100.0	 1	 104.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.0; % NG
	91148	 77.0	 14.9	 64.5	 -34.7	 1.0	 100.0	 1	 104.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.0; % NG
	91148	 77.0	 14.9	 64.5	 -34.7	 1.0	 100.0	 1	 104.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.0; % NG
	91148	 77.0	 14.9	 64.5	 -34.7	 1.0	 100.0	 1	 104.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.0; % COW
	91151	 80.0	 14.6	 63.2	 -34.0	 1.0	 100.0	 1	 102.0	 58.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 102.0; % COW
	91151	 80.0	 14.6	 63.2	 -34.0	 1.0	 100.0	 1	 102.0	 58.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 102.0; % NG
	91151	 80.0	 14.6	 63.2	 -34.0	 1.0	 100.0	 1	 102.0	 58.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 102.0; % NG
	91154	 41.9	 11.25	 48.8	 -26.3	 1.0	 100.0	 1	 78.8	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.8; % NG
	91161	 9.95	 0.0	 6.2	 -6.2	 1.0	 100.0	 1	 18.9	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.9; % PEL
	91161	 9.95	 0.0	 6.2	 -6.2	 1.0	 100.0	 1	 18.9	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.9; % NG
	91161	 9.95	 0.0	 6.2	 -6.2	 1.0	 100.0	 1	 18.9	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.9; % NG
	91161	 8.6	 0.0	 4.9	 -4.9	 1.0	 100.0	 1	 14.87	 2.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8667; % NG
	91161	 8.6	 0.0	 4.9	 -4.9	 1.0	 100.0	 1	 14.87	 2.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8667; % PEL
	91161	 8.6	 0.0	 4.9	 -4.9	 1.0	 100.0	 1	 14.87	 2.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8667; % NG
	91168	 32.7	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 50.4	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.4; % NG
	91168	 32.7	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 50.4	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.4; % NG
	91169	 16.06	 3.05	 14.4	 -8.3	 1.0	 100.0	 1	 25.0	 7.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	91169	 24.095	 4.55	 21.6	 -12.5	 1.0	 100.0	 1	 37.5	 10.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % PEL
	91169	 48.19	 9.05	 43.1	 -25.0	 1.0	 100.0	 1	 75.0	 21.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % PEL
	91170	 17.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	91170	 20.0	 2.25	 14.5	 -10.0	 1.0	 100.0	 1	 30.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0; % PEL
	91170	 25.0	 3.05	 19.4	 -13.3	 1.0	 100.0	 1	 40.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	91170	 25.0	 3.05	 19.4	 -13.3	 1.0	 100.0	 1	 40.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	91171	 20.5	 2.8	 17.9	 -12.3	 1.0	 100.0	 1	 37.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.0; % NG
	91171	 20.75	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.5	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5; % NG
	91171	 14.5	 5.25	 18.8	 -8.3	 1.0	 100.0	 1	 25.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	91173	 13.5	 0.0	 7.9	 -7.9	 1.0	 100.0	 1	 24.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % PEL
	91173	 13.5	 0.0	 7.9	 -7.9	 1.0	 100.0	 1	 24.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % COW
	91173	 13.5	 0.0	 7.9	 -7.9	 1.0	 100.0	 1	 24.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % NG
	91173	 13.5	 0.0	 7.9	 -7.9	 1.0	 100.0	 1	 24.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % NG
	91173	 13.5	 0.0	 7.9	 -7.9	 1.0	 100.0	 1	 24.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % PEL
	91173	 13.5	 0.0	 7.9	 -7.9	 1.0	 100.0	 1	 24.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % NG
	91173	 13.5	 0.0	 7.9	 -7.9	 1.0	 100.0	 1	 24.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % NG
	91173	 13.5	 0.0	 7.9	 -7.9	 1.0	 100.0	 1	 24.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0; % PEL
	91175	 13.0	 3.3	 14.3	 -7.7	 1.0	 100.0	 1	 23.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % PEL
	91175	 13.0	 3.3	 14.3	 -7.7	 1.0	 100.0	 1	 23.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % PEL
	91194	 165.5	 19.7	 126.4	 -87.0	 1.0	 100.0	 1	 261.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 261.0; % NG
	91196	 218.15	 36.3	 157.0	 -84.4	 1.0	 100.0	 1	 253.3	 183.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 253.3; % NG
	91196	 218.15	 36.3	 157.0	 -84.4	 1.0	 100.0	 1	 253.3	 183.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 253.3; % NG
	91200	 171.4	 0.0	 69.9	 -69.9	 1.0	 100.0	 1	 212.8	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.8; % NG
	91221	 36.65	 5.15	 33.1	 -22.8	 1.0	 100.0	 1	 68.3	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.3; % PEL
	91225	 9.65	 3.625	 13.0	 -5.75	 1.0	 100.0	 1	 17.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.3; % PEL
	91225	 9.65	 3.625	 13.0	 -5.75	 1.0	 100.0	 1	 17.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.3; % PEL
	91225	 8.0	 2.195	 8.82	 -4.43	 1.0	 100.0	 1	 13.25	 2.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.25; % COW
	91225	 8.0	 2.195	 8.82	 -4.43	 1.0	 100.0	 1	 13.25	 2.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.25; % COW
	91225	 8.0	 2.195	 8.82	 -4.43	 1.0	 100.0	 1	 13.25	 2.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.25; % COW
	91225	 8.0	 2.195	 8.82	 -4.43	 1.0	 100.0	 1	 13.25	 2.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.25; % COW
	91227	 25.35	 0.0	 19.9	 -19.9	 1.0	 100.0	 1	 50.4	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	91230	 32.5	 0.0	 16.4	 -16.4	 1.0	 100.0	 1	 50.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	91230	 32.5	 0.0	 16.4	 -16.4	 1.0	 100.0	 1	 50.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % NG
	91230	 32.5	 0.0	 16.4	 -16.4	 1.0	 100.0	 1	 50.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % COW
	91230	 32.5	 0.0	 16.4	 -16.4	 1.0	 100.0	 1	 50.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0; % COW
	91232	 26.2	 3.6	 23.0	 -15.8	 1.0	 100.0	 1	 47.4	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.4; % NG
	91234	 3.615	 0.975	 3.49	 -1.54	 1.0	 100.0	 1	 4.64	 2.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6444; % NG
	91234	 3.615	 0.975	 3.49	 -1.54	 1.0	 100.0	 1	 4.64	 2.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6444; % NG
	91234	 3.615	 0.975	 3.49	 -1.54	 1.0	 100.0	 1	 4.64	 2.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6444; % NG
	91234	 3.615	 0.975	 3.49	 -1.54	 1.0	 100.0	 1	 4.64	 2.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6444; % NG
	91234	 3.615	 0.975	 3.49	 -1.54	 1.0	 100.0	 1	 4.64	 2.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6444; % NG
	91234	 3.615	 0.975	 3.49	 -1.54	 1.0	 100.0	 1	 4.64	 2.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6444; % PEL
	91234	 3.615	 0.975	 3.49	 -1.54	 1.0	 100.0	 1	 4.64	 2.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6444; % PEL
	91234	 3.615	 0.975	 3.49	 -1.54	 1.0	 100.0	 1	 4.64	 2.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6444; % PEL
	91234	 3.615	 0.975	 3.49	 -1.54	 1.0	 100.0	 1	 4.64	 2.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6444; % NG
	91235	 4.155	 0.965	 3.46	 -1.53	 1.0	 100.0	 1	 4.61	 3.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6111; % NG
	91235	 4.155	 0.965	 3.46	 -1.53	 1.0	 100.0	 1	 4.61	 3.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6111; % PEL
	91235	 4.155	 0.965	 3.46	 -1.53	 1.0	 100.0	 1	 4.61	 3.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6111; % NG
	91235	 4.155	 0.965	 3.46	 -1.53	 1.0	 100.0	 1	 4.61	 3.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6111; % NG
	91235	 4.155	 0.965	 3.46	 -1.53	 1.0	 100.0	 1	 4.61	 3.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6111; % NG
	91235	 4.155	 0.965	 3.46	 -1.53	 1.0	 100.0	 1	 4.61	 3.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6111; % NG
	91235	 4.155	 0.965	 3.46	 -1.53	 1.0	 100.0	 1	 4.61	 3.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6111; % NG
	91235	 4.155	 0.965	 3.46	 -1.53	 1.0	 100.0	 1	 4.61	 3.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6111; % PEL
	91235	 4.155	 0.965	 3.46	 -1.53	 1.0	 100.0	 1	 4.61	 3.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6111; % PEL
	91237	 20.0	 3.05	 19.4	 -13.3	 1.0	 100.0	 1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % COW
	91237	 20.0	 3.05	 19.4	 -13.3	 1.0	 100.0	 1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	91238	 30.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % PEL
	91240	 39.5	 4.9	 31.5	 -21.7	 1.0	 100.0	 1	 65.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.0; % PEL
	91240	 16.5	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	91240	 16.5	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	91241	 14.5	 3.3	 14.3	 -7.7	 1.0	 100.0	 1	 23.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % PEL
	91241	 14.5	 3.3	 14.3	 -7.7	 1.0	 100.0	 1	 23.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0; % NG
	91242	 16.0	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 22.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	91242	 23.5	 5.0	 21.7	 -11.7	 1.0	 100.0	 1	 35.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % NG
	91243	 48.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0; % NG
	91243	 33.0	 6.3	 27.3	 -14.7	 1.0	 100.0	 1	 44.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0; % NG
	91243	 16.0	 3.15	 13.6	 -7.3	 1.0	 100.0	 1	 22.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % PEL
	91243	 16.0	 3.15	 13.6	 -7.3	 1.0	 100.0	 1	 22.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	91243	 75.5	 15.05	 65.1	 -35.0	 1.0	 100.0	 1	 105.0	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0; % NG
	91243	 60.5	 7.25	 46.5	 -32.0	 1.0	 100.0	 1	 96.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.0; % NG
	91243	 63.25	 7.7	 49.2	 -33.8	 1.0	 100.0	 1	 101.5	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.5; % NG
	91246	 13.4	 4.55	 16.4	 -7.3	 1.0	 100.0	 1	 21.8	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.8; % PEL
	91246	 15.3	 5.35	 19.2	 -8.5	 1.0	 100.0	 1	 25.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.6; % PEL
	92475	 38.6	 5.4	 34.5	 -23.7	 1.0	 100.0	 1	 71.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2; % NG
	92475	 38.1	 5.4	 34.5	 -23.7	 1.0	 100.0	 1	 71.2	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2; % PEL
	92500	 23.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.0	 6.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	92500	 52.15	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 29.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0; % NG
	92506	 46.95	 13.45	 58.2	 -31.3	 1.0	 100.0	 1	 93.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.9; % NG
	92506	 38.3	 11.0	 47.5	 -25.5	 1.0	 100.0	 1	 76.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 76.6; % COW
	92506	 38.3	 11.0	 47.5	 -25.5	 1.0	 100.0	 1	 76.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 76.6; % PEL
	92507	 57.15	 5.8	 37.0	 -25.4	 1.0	 100.0	 1	 76.3	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 76.3; % PEL
	92512	 43.5	 4.9	 31.5	 -21.7	 1.0	 100.0	 1	 65.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.0; % PEL
	92512	 43.5	 4.9	 31.5	 -21.7	 1.0	 100.0	 1	 65.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.0; % NG
	92515	 29.7	 0.0	 23.5	 -23.5	 1.0	 100.0	 1	 59.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	92518	 3.465	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 2.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1; % PEL
	92518	 3.465	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 2.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1; % PEL
	92518	 3.465	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 2.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1; % NG
	92518	 3.465	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 2.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1; % NG
	92518	 3.465	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 2.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1; % NG
	92518	 3.465	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 2.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1; % NG
	92538	 79.05	 0.0	 66.6	 -66.6	 1.0	 100.0	 1	 151.0	 7.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	92539	 60.05	 0.0	 52.9	 -52.9	 1.0	 100.0	 1	 120.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	92546	 47.75	 0.0	 41.7	 -41.7	 1.0	 100.0	 1	 94.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	92550	 43.95	 0.0	 37.5	 -37.5	 1.0	 100.0	 1	 85.0	 2.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	92554	 46.5	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0; % PEL
	92555	 10.725	 1.69	 8.38	 -5.0	 1.0	 100.0	 1	 15.0	 6.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % PEL
	92555	 10.725	 1.69	 8.38	 -5.0	 1.0	 100.0	 1	 15.0	 6.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % COW
	92555	 10.725	 1.69	 8.38	 -5.0	 1.0	 100.0	 1	 15.0	 6.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % NG
	92555	 10.725	 1.69	 8.38	 -5.0	 1.0	 100.0	 1	 15.0	 6.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0; % NG
	92560	 19.5	 5.3	 22.9	 -12.3	 1.0	 100.0	 1	 37.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.0; % NG
	92567	 13.3	 1.65	 10.5	 -7.2	 1.0	 100.0	 1	 21.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6; % NG
	92567	 13.3	 1.65	 10.5	 -7.2	 1.0	 100.0	 1	 21.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6; % NG
	92567	 13.3	 1.65	 10.5	 -7.2	 1.0	 100.0	 1	 21.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6; % NG
	92567	 13.3	 1.65	 10.5	 -7.2	 1.0	 100.0	 1	 21.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6; % COW
	92567	 13.3	 1.65	 10.5	 -7.2	 1.0	 100.0	 1	 21.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6; % PEL
	92567	 13.3	 1.65	 10.5	 -7.2	 1.0	 100.0	 1	 21.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6; % NG
	92579	 30.0	 5.75	 24.8	 -13.3	 1.0	 100.0	 1	 40.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	92580	 13.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	92580	 13.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	92580	 13.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	92580	 13.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % NG
	92580	 15.5	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0; % PEL
	92655	 116.25	 17.55	 112.6	 -77.5	 1.0	 100.0	 1	 232.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	92664	 100.5	 15.15	 97.3	 -67.0	 1.0	 100.0	 1	 201.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	92701	 90.5	 13.6	 87.2	 -60.0	 1.0	 100.0	 1	 180.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	92733	 23.8	 5.285	 24.57	 -14.0	 1.0	 100.0	 1	 42.0	 5.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0; % PEL
	92733	 23.8	 5.285	 24.57	 -14.0	 1.0	 100.0	 1	 42.0	 5.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0; % NG
	92733	 23.8	 5.285	 24.57	 -14.0	 1.0	 100.0	 1	 42.0	 5.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0; % NG
	92733	 23.8	 5.285	 24.57	 -14.0	 1.0	 100.0	 1	 42.0	 5.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0; % NG
	92733	 26.0	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.0	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % PEL
	92733	 26.0	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.0	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % NG
	92733	 27.5	 5.0	 21.7	 -11.7	 1.0	 100.0	 1	 35.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0; % NG
	92745	 75.0	 0.0	 66.1	 -66.1	 1.0	 100.0	 1	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	92746	 75.0	 0.0	 66.1	 -66.1	 1.0	 100.0	 1	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	92748	 75.1	 0.0	 66.1	 -66.1	 1.0	 100.0	 1	 150.0	 0.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	92758	 60.0	 0.0	 52.9	 -52.9	 1.0	 100.0	 1	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	92767	 35.3	 2.85	 18.2	 -12.5	 1.0	 100.0	 1	 37.6	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.6; % PEL
	92767	 19.25	 1.55	 9.9	 -6.8	 1.0	 100.0	 1	 20.5	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.5; % PEL
	92767	 74.1	 5.9	 37.9	 -26.1	 1.0	 100.0	 1	 78.2	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.2; % NG
	92767	 47.75	 5.1	 27.15	 -16.95	 1.0	 100.0	 1	 50.85	 44.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.85; % NG
	92767	 47.75	 5.1	 27.15	 -16.95	 1.0	 100.0	 1	 50.85	 44.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.85; % NG
	92768	 51.1	 0.0	 44.6	 -44.6	 1.0	 100.0	 1	 101.2	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	92787	 60.5	 0.0	 16.4	 -16.4	 1.0	 100.0	 1	 81.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.0; % PEL
	92789	 42.25	 6.1	 39.0	 -26.8	 1.0	 100.0	 1	 80.5	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.5; % NG
	92790	 42.6	 0.0	 31.6	 -31.6	 1.0	 100.0	 1	 80.0	 5.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	92800	 35.3	 0.0	 27.5	 -27.5	 1.0	 100.0	 1	 69.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % PEL
	92800	 40.5	 0.0	 31.6	 -31.6	 1.0	 100.0	 1	 80.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	92801	 10.885	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 15.77	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.775; % NG
	92801	 10.885	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 15.77	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.775; % PEL
	92801	 10.885	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 15.77	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.775; % PEL
	92801	 10.885	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 15.77	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.775; % NG
	92802	 35.55	 4.6	 29.6	 -20.4	 1.0	 100.0	 1	 61.1	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.1; % NG
	92802	 37.7	 9.35	 40.5	 -21.8	 1.0	 100.0	 1	 65.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.4; % PEL
	92804	 36.75	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	92804	 36.75	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	92804	 36.75	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % COW
	92804	 36.75	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5; % NG
	92805	 29.9	 0.0	 23.6	 -23.6	 1.0	 100.0	 1	 59.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % COW
	92806	 48.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % NG
	92806	 48.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % PEL
	92806	 48.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % PEL
	92806	 48.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0; % PEL
	92813	 19.0	 1.7	 10.7	 -7.3	 1.0	 100.0	 1	 22.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0; % NG
	92813	 15.26	 1.985	 9.87	 -5.9	 1.0	 100.0	 1	 17.67	 12.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.6667; % NG
	92813	 15.26	 1.985	 9.87	 -5.9	 1.0	 100.0	 1	 17.67	 12.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.6667; % NG
	92813	 15.26	 1.985	 9.87	 -5.9	 1.0	 100.0	 1	 17.67	 12.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.6667; % NG
	92816	 49.5	 0.0	 19.6	 -19.6	 1.0	 100.0	 1	 49.5	 49.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0; % NG
	92819	 26.0	 6.7	 29.1	 -15.7	 1.0	 100.0	 1	 47.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0; % PEL
	92820	 27.05	 9.6	 34.6	 -15.4	 1.0	 100.0	 1	 46.1	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.1; % NG
	92821	 31.1	 3.35	 21.4	 -14.7	 1.0	 100.0	 1	 44.2	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.2; % NG
	92823	 27.5	 5.75	 24.8	 -13.3	 1.0	 100.0	 1	 40.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0; % NG
	92831	 32.5	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0; % COW
	92833	 16.5	 1.25	 8.0	 -5.5	 1.0	 100.0	 1	 16.5	 16.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.5; % NG
	92833	 16.5	 1.25	 8.0	 -5.5	 1.0	 100.0	 1	 16.5	 16.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.5; % PEL
	92834	 31.0	 2.5	 16.0	 -11.0	 1.0	 100.0	 1	 33.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0; % NG
	92834	 30.0	 2.5	 16.0	 -11.0	 1.0	 100.0	 1	 33.0	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0; % PEL
	92839	 4.0	 1.25	 4.5	 -2.0	 1.0	 100.0	 1	 6.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0; % NG
	92839	 4.0	 1.25	 4.5	 -2.0	 1.0	 100.0	 1	 6.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0; % NG
	92839	 4.0	 1.25	 4.5	 -2.0	 1.0	 100.0	 1	 6.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0; % NG
	92839	 4.0	 1.25	 4.5	 -2.0	 1.0	 100.0	 1	 6.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0; % PEL
	92840	 10.95	 1.55	 10.1	 -7.0	 1.0	 100.0	 1	 20.9	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.9; % PEL
	92840	 10.95	 1.55	 10.1	 -7.0	 1.0	 100.0	 1	 20.9	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.9; % NG
	92841	 3.5	 0.375	 2.43	 -1.68	 1.0	 100.0	 1	 5.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.0; % NG
	92841	 3.5	 0.375	 2.43	 -1.68	 1.0	 100.0	 1	 5.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.0; % PEL
	92841	 3.5	 0.375	 2.43	 -1.68	 1.0	 100.0	 1	 5.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.0; % PEL
	92841	 3.5	 0.375	 2.43	 -1.68	 1.0	 100.0	 1	 5.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.0; % PEL
	92842	 14.3	 2.25	 11.2	 -6.7	 1.0	 100.0	 1	 20.0	 8.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % PEL
	92842	 14.3	 2.25	 11.2	 -6.7	 1.0	 100.0	 1	 20.0	 8.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0; % NG
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.000000	   8.112508	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   5.242924	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  63.181185	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.006174	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.436015	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.202087	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.912913	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.755649	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.193144	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.747395	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.895680	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.674596	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.150933	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.252060	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.898101	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.633985	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.365498	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.558376	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.440008	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.859180	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  79.476533	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.729443	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.056584	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.351132	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.130885	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.974537	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.744926	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.595918	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  60.288566	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.854662	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.306911	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.203450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.039868	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.341860	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.657580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.060552	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.854673	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.900297	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.260136	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.654889	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.361886	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.820577	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.008069	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.284994	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 103.319094	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.462150	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.664728	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.294432	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.071165	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.106071	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.741523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.537987	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.217178	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.117382	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 125.030500	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.497485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.311110	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.605665	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.075703	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.561403	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.602656	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.748514	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.178337	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.382500	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.511277	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.479530	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.845104	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.980091	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.205869	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.970079	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.152702	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.952217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.617180	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.726221	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.629709	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.639651	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.755704	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.996531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.668820	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.718225	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.963043	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.385371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.765098	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.992603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.828828	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.684712	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.926910	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.118136	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.944919	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.948732	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.999171	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.216072	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.637511	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.724101	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.457553	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.267492	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.182150	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.040995	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.654209	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.824076	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.630985	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.397195	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.775833	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.199314	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.187835	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.524987	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.248455	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.869835	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.252538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.154468	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.890023	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.813366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.831919	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.025238	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.121777	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.777474	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.029877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.598978	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.438404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.496580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.001479	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.898214	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.901243	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.320360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.447192	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.266602	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.231150	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.810844	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.151973	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.012784	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 116.690016	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 131.824409	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.018645	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.429136	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.947603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.025818	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.113494	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.941667	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.208362	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.369038	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.284054	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.732367	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.957031	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.705740	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.746968	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.733384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.755274	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.925361	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.247064	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 116.886623	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.752574	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.495268	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.171702	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.877517	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.703824	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.969024	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.601555	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.266327	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.018997	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.020199	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.692544	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.738833	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.484918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.637539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.152803	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.038462	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.506172	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.574998	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.995186	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.895753	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.552940	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.433522	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.644855	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.002116	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.941608	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  92.493848	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.859278	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.325914	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.126784	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  93.853956	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 129.681653	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.166322	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.521778	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.971152	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.431466	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.014103	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.046507	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.741864	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.916964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.061173	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.598149	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.484315	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.245541	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.478755	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.024008	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.055578	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.926221	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.184019	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.635291	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.743789	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.803675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.995033	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.964542	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.767773	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.228280	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.761583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.371377	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.566611	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.918508	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.118648	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.208932	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.449359	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.387369	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.288590	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.598687	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.953231	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.665542	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.204644	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.175896	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.563056	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 109.438402	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.202093	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 119.635777	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.809154	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.165300	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.990262	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.895395	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.427026	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.177742	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.490378	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.475982	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.566463	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.506568	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.906464	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.679918	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.527565	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.479430	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.622530	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.265097	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.101876	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  88.550551	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.265475	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.050489	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.765808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.625381	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.289052	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.871565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.613812	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.790799	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.946278	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.593844	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.182189	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.975636	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.030926	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.851028	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.202214	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.319491	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.304292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.518265	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.091695	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.174578	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.623406	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.575713	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.227424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.215264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.600615	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.319116	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.214690	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.369083	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.779799	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.974718	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.300481	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.175847	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  96.557622	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.919023	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.433808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.612587	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.453690	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.187534	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.919337	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.306025	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.170044	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.378417	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.764071	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.704591	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.600797	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.701149	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.251555	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.487696	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.073028	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.288738	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.647907	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.273071	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.673406	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.440326	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.310510	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.580209	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.834824	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  92.438909	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.860674	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.765514	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.519274	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.289324	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.933479	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.143778	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.518769	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  10.122878	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.600053	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  90.534502	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.045396	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.529757	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.349540	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.923352	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.032951	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.554079	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.292196	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.862764	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.936019	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  20.688976	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.755872	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.520433	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.930278	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.318016	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.456909	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.073200	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.830255	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.815889	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.593541	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   4.077418	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.141955	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.880561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.400261	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.539749	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.327466	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.390023	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.438504	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.606598	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.955987	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.555651	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.598049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.917517	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.418439	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.295707	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.483996	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.735299	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.973028	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.698944	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.729653	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.276754	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.824109	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.862103	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.898557	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.443733	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.859326	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.377315	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  94.287805	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.655565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.884160	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.334383	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.439854	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.450073	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.039750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.574564	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.568538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.163423	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.451127	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.964679	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.443877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.155504	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.745649	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.288757	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.764836	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.883759	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.461220	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.989105	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.381832	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.150427	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.768223	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.993161	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.553996	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.741763	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.921953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.189450	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.124515	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.908177	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.794060	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.323919	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.361384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.712822	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.839160	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.096961	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.078718	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.816419	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.198064	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.239903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.989467	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  61.561776	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.272666	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.957255	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.519484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.096674	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.948917	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.933759	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.832331	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.923825	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.484068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.304162	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.457421	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.429676	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.359709	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.930019	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.796687	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.948373	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.873473	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.943334	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.940299	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.008690	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.479059	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.684748	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.038641	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.374910	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.538528	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.748621	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.033582	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.833165	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.342539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.007436	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.127840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.737907	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.310044	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.960694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.627372	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  55.089712	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.187095	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.587559	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.056209	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.192947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.275617	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.621925	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.543328	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.081327	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.797478	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  95.725872	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.650921	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.419958	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.610748	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.822061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.749867	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.585180	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.322055	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.979685	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.759393	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.631975	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.227467	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.157298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.071234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.282260	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.541417	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.506074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.340320	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.820883	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.479279	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.051696	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.198429	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.939602	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.568482	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.881217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.587240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.274891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.357842	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.575157	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.259910	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.355211	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.733620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.746475	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.074476	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.008348	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.575793	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.044697	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.194262	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.097875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.839855	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.054288	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   2.794782	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  55.851164	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.290469	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.973330	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.310669	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.441480	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.429304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.411450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.541568	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.817822	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.324726	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.432411	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.823888	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.607352	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.074456	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.982751	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.740462	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.134564	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.590060	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.422340	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.034353	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.560025	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.025373	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.508960	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.918438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.810248	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 110.085067	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.181656	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 130.523543	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.833340	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.424703	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.567836	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.172739	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.798703	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.962318	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.650867	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.894756	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.775147	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.487837	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.862730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.360137	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.927631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.754779	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.715606	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.819622	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.004497	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.753717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.213714	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.304975	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.685563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.831549	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.178714	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.818429	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.482324	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.294090	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.116823	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.827240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.504875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.656456	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.355281	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.164714	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.099093	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.346514	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.624324	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.659599	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.323588	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.792908	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.827293	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.294363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.447483	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.659399	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   8.263767	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.511283	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.380013	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.790073	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.101678	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   7.011551	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.118583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.356740	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.986078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.269678	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.897025	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.721016	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.575965	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.537924	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.979999	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.673408	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.485240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.451213	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 106.738427	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.136932	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.805338	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 122.130231	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.354030	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 125.818106	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.215620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.100649	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.551787	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.936372	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.698659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.322579	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.172890	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.428511	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.491971	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.753682	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  96.901922	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.839895	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.634499	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.406948	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.422554	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.407563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.894177	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.010412	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.954524	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.730987	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.676620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 131.652613	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.466871	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.911068	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.917818	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.566768	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.555109	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.684853	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.611176	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.169376	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.726551	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.095079	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.702083	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.795759	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.825756	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.593339	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 100.664987	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.646252	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 105.236309	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.412304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.091369	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.616329	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.838901	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.595029	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.746482	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.075045	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  13.717328	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.066884	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.293053	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.882591	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.427943	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  75.835455	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.929580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.974840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.151319	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.063001	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.046993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.929344	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.778361	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.745234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.489685	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.260668	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.754185	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.022897	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.626787	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.534387	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.946531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.532839	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.595110	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.536973	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.933781	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.014575	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.111872	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.060141	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.948763	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.535953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.212559	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.206506	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.794589	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.608996	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.192424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.417229	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.832560	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.123234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.810248	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.198857	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.406162	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.936741	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.877513	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.957361	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.910775	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.205177	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.542433	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.994137	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.940971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.235222	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.625238	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.873769	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.615572	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.681346	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  22.963857	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.141990	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.384807	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.953626	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.230896	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.300569	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.352721	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.840622	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.721754	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.264108	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.329853	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.145079	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.554293	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.514759	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.417569	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.844532	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.499308	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.354958	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.231655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.359875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.256969	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.903775	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.909700	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.898903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.754752	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.420005	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.053455	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.820880	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.484595	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.800550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.057546	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.231006	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.167205	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.496233	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.675662	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.433166	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.366526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.130994	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.937284	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.656725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.792064	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.581686	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.766691	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.573032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.189974	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.850907	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.659434	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.717203	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.713488	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.310242	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.630491	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.173043	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.045196	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.701527	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.265761	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.872074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.599879	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.328275	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.949283	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.995856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.723572	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.310509	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.049853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.838373	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.305840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.659443	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.557842	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.923652	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.253158	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.589417	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.164521	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.289667	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.690088	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.876967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.784154	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.151831	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.333701	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.829175	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.027599	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.254774	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.036473	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.965533	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.544236	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.196773	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.945597	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.776249	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.201608	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.098191	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.457887	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.962677	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.268395	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.956941	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.192771	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.144635	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.027598	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.242468	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.528860	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.485058	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.324875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.372806	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.191744	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.207864	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.673749	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.633000	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.742696	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.867258	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.450246	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.460984	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  57.250651	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.549149	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.426410	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.898720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.069213	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.100968	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.850493	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.709940	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.911853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.142877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.674750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.085904	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.185980	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.843730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.819882	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.381598	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.501984	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.578163	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.542161	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.466973	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.156974	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.744797	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.368899	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.877450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.228864	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.198602	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.407038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.756619	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.372240	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.621755	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.810287	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  58.401205	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.812722	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 127.512812	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.977357	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.020899	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.541003	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.863358	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.541416	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.002255	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.886737	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.413746	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.482644	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.964892	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.783985	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  12.334880	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.011226	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.982346	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.676363	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.348823	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.194352	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.812748	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.655269	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.054938	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.593528	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.632890	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.444785	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.375498	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.403793	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.936377	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  93.517673	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.998056	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.835610	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.381102	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.938941	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.090700	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.714074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.014044	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.113991	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.165179	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.251596	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.797231	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.631420	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.204148	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.589047	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  52.903166	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.210222	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.949078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.963330	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.429607	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.155024	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.052169	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.526272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.746066	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.595405	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.259757	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.874619	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.500416	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.287840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.917120	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.703408	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.678769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.403996	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.406272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.358685	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.910845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.029174	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.748913	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.028273	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.230542	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.600386	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.176025	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.477130	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.282123	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.300701	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.195316	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.667588	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.847976	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.012809	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.440947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.701299	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.054026	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.890545	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.215350	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.797024	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.956495	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.952277	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.548706	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.563843	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.718509	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.527097	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.465317	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.795633	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.504939	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.953645	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.863655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.541579	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.838067	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.553108	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.612824	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.516427	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.326168	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.177820	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.930204	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.098605	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.613550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.146847	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.224391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.019313	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.867886	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.815379	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.242359	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.691387	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.310063	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.008308	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.257705	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.494631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.748705	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.128386	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.009569	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.202812	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.583076	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.619496	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.240969	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  96.617651	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.140705	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.137525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.462062	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.261262	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.160123	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.875510	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 130.923881	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.174681	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   4.486120	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.178348	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 109.277327	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.051305	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.634375	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 127.065106	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.038292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.926702	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.724608	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.928470	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.150123	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.970002	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.744200	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.984009	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.929957	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.853439	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.843846	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.264355	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.593791	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  52.568387	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.838880	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.661355	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.045728	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.912889	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.896963	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.247776	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.666489	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.228543	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.768833	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 120.238210	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.826323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  93.888037	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.297688	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.728734	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.222286	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.446090	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.179123	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.381877	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.682393	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.918643	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.842873	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.566795	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.725003	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.874058	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.082675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.369537	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.426623	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.701058	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.833798	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  98.439954	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.264565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.441766	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.170634	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.505074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.160003	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.434206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.479915	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.772164	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.933326	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.732013	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.241767	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  91.568474	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.582099	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.201186	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.781769	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 106.265894	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.936767	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.197335	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  56.132366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.633875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.306751	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.709009	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.491117	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.929880	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.563198	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.693702	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.723890	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.796366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.579119	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.529556	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.792929	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.754293	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.806694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.434759	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.143554	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 140.621343	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.012428	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.334710	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.166274	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.253237	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.774483	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.440047	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.811495	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.728965	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.857095	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.326829	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.408054	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.444992	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   9.966992	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 106.179475	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.301841	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.575959	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.828817	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.758867	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.402126	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.511962	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.824216	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.683696	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.098306	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.323894	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.680073	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.092724	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.465420	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.017164	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.858186	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.374050	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.392044	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.131823	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.669302	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.583631	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 124.986161	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.082286	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.530798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.891053	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.776253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.420114	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.468659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.647323	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.795880	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.249842	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.917542	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.009971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.898866	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.208510	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.880631	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.371256	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.128523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.611864	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.789579	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.030628	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.247333	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.499443	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.403050	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.849760	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.852993	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.885565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.043367	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.631742	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.601479	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.508107	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.745576	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.532902	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.724858	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.905949	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.472734	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.083831	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.668836	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.126203	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.712158	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 122.221066	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.460301	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.919051	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.030397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.489491	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.909309	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.732958	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.771024	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.525215	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.226351	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.420212	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.689379	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.327707	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.421365	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.504176	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.582041	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.592428	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.442250	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.835292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.656479	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.069936	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.359465	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.311135	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.363919	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.379008	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.827419	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.097400	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.923751	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.402376	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.160723	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.220492	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.133709	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.722005	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.797530	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.071301	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.270221	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  11.154368	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.873579	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.479750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.212055	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.056446	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.411606	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 118.156974	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  53.245223	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.285240	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.459720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.665989	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.395182	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.571755	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.928323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.456270	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.645450	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.382068	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.529130	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.973658	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.041505	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.250238	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.235428	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.768349	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.441174	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  10.711141	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.185525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.171067	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.730306	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.742012	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.386764	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.883871	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.015219	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.323723	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.081161	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.032051	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.472958	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  32.503064	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.677821	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.362349	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  22.284219	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.502300	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.788536	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.142611	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.031182	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.773105	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.677218	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.739275	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.110670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.549681	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.494103	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.205219	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.136802	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.912829	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.518538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.451622	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.393663	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.518040	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.281136	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.660798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.861776	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.966361	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.719784	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.723353	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.229649	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.047019	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.339287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.213514	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.306525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.940973	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.067470	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.507917	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.566797	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.849566	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.751375	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.088244	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.591982	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  62.517832	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.961721	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.551431	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.954823	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.379250	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.117831	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.994141	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.438743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.103497	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.495274	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.260029	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.310547	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.396400	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.582595	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.414825	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.497491	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.761902	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.524017	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.994419	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.540278	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.222315	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.537961	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.355161	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.927455	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 131.019720	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.894139	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.931809	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.461607	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.952769	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.260223	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.190737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.386262	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.271561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.841595	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.171607	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.604741	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.966256	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.830206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.635134	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.275126	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.902424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.301806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.335861	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.144752	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.670379	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.868017	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.213206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.995135	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.511507	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.054560	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.468444	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.541964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.148678	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.636734	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.554456	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.485333	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.872303	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.333732	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.412193	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.894629	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.864812	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.513691	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.244622	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.303202	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.931447	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.597414	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.187238	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.567142	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.076038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.310279	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.497908	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.243309	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.649550	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.203881	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.621340	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.173438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.582419	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.137130	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.190353	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.754409	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.199503	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.237456	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.124890	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 105.905654	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 133.268178	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.119718	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.164773	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.281115	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.654452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.845483	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.664808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.047957	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.812687	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.987765	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.506840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.614121	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.471236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.896083	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.526571	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.931160	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.808335	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.023425	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.312271	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.967851	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.558979	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  54.336566	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.781676	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.668182	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.045308	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.365846	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.847050	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.108944	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.894151	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.728489	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.883477	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.481165	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.071691	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  10.197115	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.619980	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.163527	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.715984	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.708225	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.547968	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.378723	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.602183	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.469901	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.693346	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.935658	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.043903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.472577	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.839335	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.301442	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.357431	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.363754	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.561362	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.380657	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  95.969185	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.994011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.726317	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   7.934164	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  31.362251	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.089465	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.942188	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.400494	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.684073	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.740978	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.406942	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.046953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.128442	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.834912	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.429912	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.809505	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.907943	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.427670	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.481923	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  58.154072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.471330	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.262830	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.018663	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.825108	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.043571	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.958917	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.567545	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.716452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.631496	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.861036	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.590852	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.356585	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.292270	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.500837	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.654930	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.144932	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.076427	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.161596	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.449718	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.065208	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.587569	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.485364	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.317644	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.956886	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.229559	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.703177	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.615389	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.395214	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.078169	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.186416	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.816856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.840922	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.060238	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.420959	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.207913	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.711140	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.025462	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.997498	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.315548	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 127.734250	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.023313	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.237741	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.979420	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.889154	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.645064	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.376061	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.404306	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.088930	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.455210	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.726434	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 126.487743	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.567467	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.939915	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.128429	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.173787	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.377853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.594669	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.691558	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.144217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.005217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.105606	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.910039	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.021837	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.380624	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.363104	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.575880	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 128.303118	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.921444	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.692888	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.366737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.853906	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.666785	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.394564	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.930193	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.542392	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.006716	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.658224	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.070983	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.746662	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.254443	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.364866	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.999735	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.917482	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.423180	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.775565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.240584	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  53.654259	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.401049	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.954140	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.785303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.057196	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.733762	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.136537	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 116.862112	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.069895	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.499000	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.665725	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.016384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 128.363969	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.732889	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.445104	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.445586	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.131703	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.778066	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.111951	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.659895	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.901594	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.928686	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.786734	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.344660	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.939077	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.769846	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.442008	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.682786	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.124015	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.683699	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.153937	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.695530	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.679491	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.450875	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.328231	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.235240	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.420820	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.694591	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.324366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.974534	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   7.431877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.364118	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.224783	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.795604	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.229464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 132.599409	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.125184	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.134139	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.268017	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 127.180785	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.270570	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.107543	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.304499	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.502005	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.086506	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.771451	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.994021	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.082700	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.858935	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.472789	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.869707	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.464420	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 130.607662	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.599267	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.604230	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.662592	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.805705	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.609575	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.645552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.164766	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.074395	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.429683	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.323447	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.849626	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.644591	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.967205	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.427668	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.056995	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.416529	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.948807	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.088665	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.553809	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.525198	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.955616	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.101849	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.850454	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   4.126204	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.126157	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.415489	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  26.566398	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.667601	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.431072	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.883456	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.708480	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.783184	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.420407	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.155251	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.631552	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.802923	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.043240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.138531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.682401	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.339691	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.677950	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.230644	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.970095	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.327951	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.042485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.568905	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.477072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.429369	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.525205	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.763410	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.001665	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.091091	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.776496	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.363110	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.952940	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.604367	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.944480	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.079963	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.355619	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 119.211074	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.869091	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.931834	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 126.874167	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 139.723239	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.756451	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 102.898719	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.132720	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  89.124368	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.992636	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.003086	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.429281	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.093798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.131339	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.051214	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.753621	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.120341	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.809312	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.412180	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.922862	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.010396	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.859546	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.233539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.979082	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.249838	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.508613	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.255904	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.696192	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.880649	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.843740	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.315498	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.178016	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.531056	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.443597	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  97.777246	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.547799	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.722218	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  64.776113	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.068903	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.803876	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.599433	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.567914	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.609701	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.348660	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.602217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.748585	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.823411	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.980834	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.531536	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.017498	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.547210	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.497218	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.848561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.071613	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.373262	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.070447	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.104540	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.145230	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.676139	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.561156	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.919513	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.029244	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.572273	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.006841	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.696358	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.436418	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.367477	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.681331	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.993455	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.180146	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.700158	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.522970	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.578404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.233123	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.849821	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.630217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.104673	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.379725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.371995	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.308043	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.088599	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.274079	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.906134	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.523709	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.669438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.715283	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.284803	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.544883	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.365562	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.595150	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.079989	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.622337	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.098574	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.557216	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.095175	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.134168	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.155893	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.489761	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.716943	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.499549	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.879499	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.222788	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.634019	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.922462	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.959233	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.512022	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.667085	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.103616	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.269640	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.352685	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.021617	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.231226	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.599399	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.348358	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.519955	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.177593	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.463607	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.456008	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.897037	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.323377	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.855065	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.507430	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.662846	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.113912	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.334090	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.236301	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.373994	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.511558	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 130.330480	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  52.324485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.905425	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.943953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.533201	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.605283	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.453114	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.889222	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.070486	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.877775	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.512274	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.981998	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.293054	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.837089	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  65.651484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.940421	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.913410	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.017523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.291437	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.308969	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  99.280823	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.064612	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.602729	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.804280	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.979671	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.170340	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.991029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.062261	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.167817	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.263864	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.827436	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.272358	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.768684	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.658526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.100190	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.198744	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.212717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.738957	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.507068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 124.433716	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.951808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.555875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.132170	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.569851	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.340304	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  90.826705	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.782034	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.547161	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.219862	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.578610	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.168597	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.271999	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.545787	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.983647	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.972093	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.135431	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.629959	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.714458	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.321397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.157612	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.500319	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.673496	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.750620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.767224	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.835940	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.787605	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.669367	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.211394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.708101	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.508072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.259943	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.810406	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.677515	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.808055	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.158883	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.634154	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.715643	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.101581	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.791538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.247330	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.615348	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.690741	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.270675	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.302836	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.569402	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.139779	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.987339	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.780725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.154752	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.427292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.346711	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.330252	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.780366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.451563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.216447	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.203422	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.909720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.682822	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.758006	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.104876	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.897115	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.300502	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.788858	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.775306	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.771450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.556952	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.244352	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.133402	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.177505	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.407753	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 121.852592	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.962441	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.835533	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.146099	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.231746	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.765315	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.647034	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.902704	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.807643	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.100332	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.445812	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.820446	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.355416	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.908815	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.296523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.956668	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.639765	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.693547	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.982436	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.905162	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.163051	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.842687	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.235497	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.491093	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.690223	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.486668	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.922779	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.955299	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.902728	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.019273	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.999918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.738038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.506343	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.445355	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.645656	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 110.547198	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.733881	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.780971	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.866815	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.740799	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.558343	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.728889	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.988859	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.589045	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.415156	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.979208	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.254555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.262835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.907481	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.364896	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.485387	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.858028	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.354258	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.756415	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.928119	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.121148	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.346720	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.114917	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.512871	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.837803	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.141464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.723772	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.731059	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.739664	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.980296	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.236732	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.411167	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  92.488105	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.126798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.628060	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.956402	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.054052	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.628906	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.736182	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.645632	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.552130	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 129.232703	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.571408	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.708271	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.076966	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.085910	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.731717	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.705528	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.087819	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.512872	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.116139	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.643436	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.121604	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.495425	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.870092	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.774758	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.201458	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.494835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.762946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.129066	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.884719	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.524502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.634656	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.706402	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.702366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.805152	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.303124	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.274224	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.274220	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.075098	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.823135	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.271537	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.791358	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.989858	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.013743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.338720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.449654	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.119487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.316384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.598312	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.146068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.152621	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.612674	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.458222	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.861043	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 106.537388	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  57.345678	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.774368	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.454120	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.595610	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.892208	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.709616	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.827895	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.761704	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.583144	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.198932	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.541854	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.536341	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.170205	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.897341	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.443075	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.403413	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.408164	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.434961	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.199798	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.804168	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 110.728860	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.588674	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  96.529245	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.389468	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.402928	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.269522	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.801387	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.037904	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  81.436043	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.332249	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.927491	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.773861	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.745558	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.196988	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.346974	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  28.265915	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.586307	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.278200	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.816936	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.431797	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.703405	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.885341	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.209204	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.220614	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.660342	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.659366	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.774411	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.734470	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.845905	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.297464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.384445	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.594638	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.621746	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.695542	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.816840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.062600	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.430781	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.159077	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.249549	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.870516	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.003721	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.648610	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.787027	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.336808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.788570	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.274868	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.619805	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.407064	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.043032	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.733003	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.326756	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.839188	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.448027	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.789480	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.261493	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.205555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.053894	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.355347	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.443718	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.879832	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.256579	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  18.719983	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.594159	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.352527	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.311826	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.927945	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.938801	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.890952	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.288725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.208269	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.484439	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.245360	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.528579	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 106.685406	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.644897	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   4.184656	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.773723	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.726215	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.970807	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.656012	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.917693	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.755763	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.906902	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.273245	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.184022	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  87.544314	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.603582	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.893405	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 125.566940	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.019435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.437388	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.448156	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.515698	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 124.586381	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.022448	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.909508	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.621085	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.704269	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.427665	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.801542	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.716785	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.918754	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.849607	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.709146	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.002174	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.776216	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.476843	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.390166	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.291099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.794511	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.305343	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.591227	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.851864	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.611182	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.508331	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.427597	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.066628	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.514713	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.308202	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.640702	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.095485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.915533	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.933858	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.568863	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.135928	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.526838	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.463288	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.706824	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.708185	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.754197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.659061	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   8.059509	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.382250	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.749924	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.417127	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.557240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.028187	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.992165	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.695982	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.938088	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.279101	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.858297	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.922240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.914525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   4.364775	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.426058	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  99.845013	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.056698	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.395286	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.414457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.911108	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.467054	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.680468	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.514813	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.296349	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.946118	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.716075	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.333895	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.834312	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 130.134799	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.827057	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.531932	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.712782	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.794347	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.417154	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.758351	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.563311	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.169859	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.845161	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 132.044158	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.856801	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.338771	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.619610	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.899236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 129.440616	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.262523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.586796	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.571087	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  94.834478	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.795427	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.573875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.850450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.552942	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 102.142583	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.881706	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.571155	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.833613	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.759110	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.936292	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.373865	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.423033	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.557053	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.063467	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.738782	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.506810	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.499155	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  44.660025	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.889372	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.403170	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.711214	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  93.733583	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.073725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.496811	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.987617	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.257752	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  85.414248	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.667223	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.616780	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.976029	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 105.874160	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.838112	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.805569	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.540681	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.575665	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.238591	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.574118	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.950349	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.155131	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.710137	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.402072	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.530718	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.082714	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.178438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.616697	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 103.614332	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.250243	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 100.327191	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.015272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.777270	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.173956	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.950033	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.983925	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.914976	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.458353	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.358633	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.388433	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.925980	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.337291	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.750630	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.638587	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.816150	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.989182	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.554327	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.313750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.132664	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.583810	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.218523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.753913	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.459097	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.477747	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.577003	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.864677	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.211076	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.205028	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.110146	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.611328	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.305737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.156627	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.657203	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.934431	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.001151	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.766664	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.337719	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.306974	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 128.403110	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.176388	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.240932	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.732684	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.407757	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.102959	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.087923	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.198385	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.153077	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.227794	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.559561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.296911	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.964402	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.777670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.914306	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.727757	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.008182	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.218230	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.138061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.752457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.875971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.785016	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.390948	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.489157	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.605163	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.935560	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 136.350268	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.258140	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.776533	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.757694	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.613675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.964017	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.272645	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.782001	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.581142	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.796700	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.774054	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.803047	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.202368	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.515385	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.359598	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.091568	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.317865	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.378137	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.757330	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.817254	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.727788	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.575987	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  52.010697	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.745119	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.216302	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.393363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.518245	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.858061	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.410898	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.338424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.336831	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.420502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.090613	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.135630	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.351330	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.392461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.649083	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.868869	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.911564	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.358079	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.612523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.369242	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.242818	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.408598	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.835024	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.792844	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.672294	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.305207	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.180124	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.911100	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.819571	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.328850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.007050	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.054748	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.045583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.350358	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.283062	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  62.657986	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.995344	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.638890	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.704069	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.612357	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.452057	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.011095	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.606879	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.298220	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.026828	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.433472	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.780020	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.567425	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.463552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.748032	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.924571	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.928373	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.514038	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.474324	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.682085	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.017685	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.928371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.317119	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.245323	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.738980	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.205900	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.958773	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.769478	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.945122	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.014018	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.501779	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.898129	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.407199	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.766235	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.012079	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.833452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.006263	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.825214	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.124439	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.769380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.335391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.611509	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.437922	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.649194	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.602531	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.399177	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.397752	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.572126	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.656889	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  88.229710	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.267317	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.800618	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.176028	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.051940	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.006397	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.476073	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.315367	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.854389	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.532360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.562450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.211656	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.474200	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.151753	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.955029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.669232	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.258642	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.882870	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.335610	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.130224	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.130353	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.400051	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.303820	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.603486	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.958155	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.004743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.470407	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.792967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.342316	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.996020	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.304940	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.482168	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.241094	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.663772	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.706449	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.812899	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.390613	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.003947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.209990	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.462513	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.488387	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.899069	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.982446	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.427102	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.213527	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.370143	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.334754	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.941562	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.556187	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.888248	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.164342	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.440915	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.952144	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.098319	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.999927	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.445725	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.382244	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.306824	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.539507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.125998	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.882457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.115038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.947848	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.581382	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.006237	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.076614	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.939106	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.440771	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.124072	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.639762	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.713557	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   9.583018	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.481453	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  95.848221	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.608546	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.084453	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.288197	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.475841	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 128.919961	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   4.063720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.590636	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.035957	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.991866	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.595024	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.676023	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.266774	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 125.300765	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.135136	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.684237	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.168736	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.860627	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.064853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.927322	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.540123	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.213836	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.368451	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.330097	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.720656	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.894662	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.380076	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.195415	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.427939	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.582077	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.783028	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   3.839837	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.208275	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  55.245996	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.046567	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.977497	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.085422	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.940467	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.484214	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.931964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.869717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.757905	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.622485	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.837803	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.161154	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.766837	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.241501	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.517888	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.119286	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.466352	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.225546	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.654007	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.678078	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.693544	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.460153	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.020998	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.724354	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.812104	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.597313	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.460705	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.897068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.471808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.052731	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   5.654474	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.864481	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.048189	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.486623	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.364745	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.866844	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.575101	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.732789	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.743124	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.343154	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.449185	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.062910	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.897089	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.609411	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.467847	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.021816	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.484938	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.929452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.182026	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.594214	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  94.972222	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.634738	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.842742	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.061373	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.330742	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.273380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.363980	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.953454	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.018015	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.757859	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.692285	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.365099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.322412	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 118.358938	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.740239	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.472710	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.893824	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.336542	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.792010	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.586813	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.855000	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.806746	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.998886	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.279242	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.632578	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.211481	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.662725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  92.917935	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.270656	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.302109	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  13.184719	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.426297	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.548398	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.221388	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.325259	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.401450	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.475376	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.051517	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.812685	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.103314	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.210866	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.089453	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.167153	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.239635	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.724241	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.466487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.073988	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.831971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.964293	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.328370	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.836789	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.425211	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.262123	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.434315	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.937670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.657142	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.480900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.138207	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.480001	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 113.950444	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.013439	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.888942	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.887484	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.287344	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.456094	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  96.719314	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.048274	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.918920	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.219223	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.992575	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.312803	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.007650	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.649475	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.068019	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  15.376354	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.659685	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.102230	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.021659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.638478	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  30.686889	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.991168	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.420451	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.694122	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.427659	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  23.877495	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.780827	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.785819	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.490692	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.019656	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.720244	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.497044	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  62.588373	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.593101	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.396032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.468430	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.371227	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.158987	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.575664	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.600061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.097717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.592864	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.063964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.450586	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.439434	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.790534	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.967370	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.387376	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.152266	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.584905	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.011996	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.828383	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.696138	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.637925	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.368956	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.962966	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.085545	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.432787	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.830827	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.054118	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.788226	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.565867	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.182795	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.660459	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.904093	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.276853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.856389	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.004437	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.731147	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.226796	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.505287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.102132	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.002176	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.150047	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.837272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.886087	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.239674	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.800891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.013248	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.547513	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.003641	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.679983	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.539002	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.808293	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.824988	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.175419	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.355416	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.619377	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.241852	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.109438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.428314	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.906261	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.483167	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.348266	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.806191	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.821174	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.071107	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.460508	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.805936	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.080772	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.053184	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.117377	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.812196	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.933958	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.540909	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.266844	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.927091	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.412670	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.888958	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.384195	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.829359	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.880451	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.341509	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.223661	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.167453	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.404243	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.031702	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.389609	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.571126	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.934415	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.320424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.639555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.716721	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.010403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.909669	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.081935	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.483097	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.934533	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.540964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.002023	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.075900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.393099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.050661	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.703552	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.409181	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.040258	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.548395	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.676179	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.221647	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.292125	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.907642	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.720614	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.549443	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.641921	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.327816	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.932389	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.284332	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.896816	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.331225	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.077592	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.834926	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.779669	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.060377	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.397536	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.398022	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.956412	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.251447	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.112602	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.177230	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.451933	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.657081	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.184249	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.762791	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.775927	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.473162	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.790063	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.106161	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.725777	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.898598	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.471307	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.057507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.900946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.658064	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.298500	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.118655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.826875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 127.427902	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.837744	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.404020	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.019475	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.409360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.000698	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  56.214819	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.939719	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.758104	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.438664	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.177891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.999884	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.835873	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.899372	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.000064	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.665041	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.970090	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.728605	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 124.383188	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 127.673730	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.599324	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.178320	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.445047	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.226074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.270420	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.048612	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.712449	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.961792	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.752402	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.370263	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.021538	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.123614	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  52.825609	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.007258	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.476391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.557909	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.096225	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.315790	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.374635	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.765452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.382747	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.765593	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 129.104910	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  10.565873	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.401986	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.422074	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.303141	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.984272	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.664530	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.887375	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.280464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.518483	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.711398	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.899400	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.685405	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.781797	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.222181	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.927245	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.485343	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.100859	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.464205	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.577006	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.175679	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.038346	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.507800	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.758391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.573405	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.122348	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.564375	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.012270	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.830720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.855237	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.618652	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.434236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.579167	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.729321	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.919970	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.595385	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 119.116197	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.822917	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  53.733382	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.826028	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.984506	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 106.738746	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 129.214577	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.873957	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.960929	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.915571	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.657398	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.910118	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.156260	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.869336	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.620615	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.705233	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  92.769897	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.614301	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.552748	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.399814	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.198651	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.336163	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.062963	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.098295	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 127.539655	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.027658	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.543176	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.139466	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.018304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.604941	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.242187	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.865617	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  23.456448	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.967786	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.347792	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.217681	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.869840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.036635	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.367157	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.441271	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.134004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.809432	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.500609	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.123993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.146481	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.023202	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.042450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.224572	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.729014	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.926834	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.077603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.079475	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.263141	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.899659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.188026	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.266138	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.539651	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.114659	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.881317	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.129530	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.380186	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.132391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 129.885780	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.607918	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.868009	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.098986	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.121371	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.027066	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.331742	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.305033	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.876384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.784289	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.093720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.309610	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.945268	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.665075	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.587590	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.233377	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.291793	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.854546	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.379652	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.821115	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.639670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.354204	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  59.502671	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.768073	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.855940	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.139175	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.963464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.670475	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.067602	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.099133	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.121194	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.600949	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.521070	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 130.958213	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.566976	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.603322	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  92.864046	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.455804	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.797167	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.276484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.304214	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.541680	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.289660	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.756630	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.003860	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.516174	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.421150	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.525421	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.550403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.645933	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.543743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.563369	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.573593	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.777388	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 128.793613	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.728717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.086023	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.466584	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.931412	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.364144	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.861799	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.328827	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.944459	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.492930	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.276360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.567557	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.558135	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.468541	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.334811	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.875822	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.147334	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  87.958980	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.903702	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.575961	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 134.972529	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.094544	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.492775	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.005905	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.568359	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.724288	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.592876	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.128700	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.093081	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.722826	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.770505	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.025348	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.371701	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.675359	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.963707	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.946542	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.634675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.988553	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.311166	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.041505	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.477697	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.497291	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.984010	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.953999	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.245793	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.347151	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.057445	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.923615	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.460767	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.398387	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.717764	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.599588	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.787824	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.424546	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.117165	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.605999	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.678218	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.129178	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.020884	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.740727	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.947646	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.882681	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.843238	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.864437	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.295545	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.698670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.065872	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 107.156172	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.529817	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.651691	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.348011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.092846	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.965087	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.699046	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.236632	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.269869	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.752352	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.673138	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.085440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.924065	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 122.124318	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.826957	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.970408	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.328397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.334806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.220898	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.714007	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.391672	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.211325	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.374736	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.946533	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.339390	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.570897	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.322822	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.486864	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.834764	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.452670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.036746	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.151030	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 124.829276	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.884253	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.971402	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.834194	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.826138	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.176554	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.598267	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.220942	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.008898	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.775221	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.833527	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.193334	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.413668	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.352804	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.252851	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.873904	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.860905	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.080678	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.742324	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 106.657083	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.331043	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.074625	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.979308	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.028622	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.839251	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.932221	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.775873	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.321707	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.530816	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.695461	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.599181	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.854124	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.265005	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.255172	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.892404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.968850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.430928	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.137122	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.200833	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.854719	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.611408	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.536392	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.833606	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.336807	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.688468	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.026030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.251825	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.928872	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.269470	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.025296	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.820201	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.872615	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.007106	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.001463	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.994264	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.015673	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.534070	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.170258	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.468396	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.771470	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.932261	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.083800	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.014692	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.729138	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.730518	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.949292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.650268	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.751692	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.832246	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.594073	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.118879	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.467798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.616448	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   2.726085	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.462035	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.214144	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.675296	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.894918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.291581	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.760762	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 117.428652	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.549737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.450739	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.902223	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.503285	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.300006	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.681048	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.822461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   4.780242	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.202076	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.900413	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.857251	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.648126	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.014226	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.303233	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.361185	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.875806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.034826	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.329741	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.055755	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.189436	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.064627	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.454956	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.458748	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.559786	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.745213	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.881762	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.813724	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.233160	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.425713	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.851371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.272684	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.881738	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.380286	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.813076	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.966364	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.229536	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.043904	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.919580	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  58.155990	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.823216	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.527060	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.849214	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.189368	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.678706	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.154622	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.003442	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.742096	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.443740	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.430430	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.020595	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.929196	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.236231	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.091550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.404966	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.339359	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.070214	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.463353	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.513242	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.922556	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.816830	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.760338	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.593300	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.080696	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.458529	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.062120	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.037100	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.470620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.448336	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.102196	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.332874	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.645354	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  98.441040	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.682536	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.205885	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.264514	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.796362	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.755206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.009945	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.610563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.280789	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.024138	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.871991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.612027	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.469916	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.701493	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.625594	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.154750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.301857	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.943670	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.375586	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.364611	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  99.924062	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  12.902769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.655725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.708668	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.415137	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.287740	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  96.859053	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.693263	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.229601	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.358500	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.243553	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.758463	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.975844	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.427464	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 102.794385	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.579535	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  93.428304	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.241477	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.495347	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.005649	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.771146	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.414162	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.563874	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.758104	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.337876	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.334647	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.361181	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.116116	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.873408	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.786390	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.948333	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.396784	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.948219	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.241164	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.739429	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.954188	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.551765	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.328462	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.282521	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.800502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.519920	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.298110	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.587877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.184739	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.217326	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.372979	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.818575	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 102.499470	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.566942	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.127392	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.638028	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.480002	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.846686	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.867500	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.295537	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  96.399894	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.723334	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.580903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.892464	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.720626	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.185444	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.350576	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.514995	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.020262	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.244209	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.841181	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.876747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.041746	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.280474	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.319365	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.239836	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.870722	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.640376	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.650585	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.195136	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.752583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.153641	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.319133	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.295304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.586222	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.272937	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.907000	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.542042	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.481444	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.750255	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.789914	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.307658	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.317292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.814837	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.281026	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.018205	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.877239	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.968424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.412817	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.726802	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.472957	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.202451	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.108237	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.361509	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.649282	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.459705	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.479165	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.455497	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.416068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.703159	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.744866	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.680954	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.351428	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.713173	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.371805	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.236960	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.861130	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.736863	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.367639	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.119197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.621010	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.989597	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.179530	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.370983	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.524281	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.059183	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.321957	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.217200	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.757505	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.387982	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.444441	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.800651	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.074872	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.433691	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.183337	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.011070	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.032765	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.609279	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.229275	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.248012	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.411235	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.953854	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.860675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.107350	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.730235	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.142089	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.964485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.760624	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.397952	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  72.315061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.042221	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.348198	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.583462	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.445972	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.780703	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.046387	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.564988	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.284135	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.137908	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.529934	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.440148	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.773734	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.828094	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.827796	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.213923	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.780525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.806254	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.765915	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.975834	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.769013	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.497578	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.188507	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.707856	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.059343	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.680229	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.956869	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.823291	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.966692	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.851690	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.023504	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.014132	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.879929	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.169579	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.578183	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.783381	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.262106	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.048480	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.145529	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.738709	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.186434	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   4.992181	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.454977	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.717532	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.434330	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.414865	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.515171	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.329034	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.385354	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.384124	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.278029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.764319	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.942754	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.968802	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.140711	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.119141	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.907212	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.702771	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.877390	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.357529	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.023213	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.398240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.764393	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.787676	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.376864	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.328052	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.696471	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.298726	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.197797	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.046055	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.764230	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.400440	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.238271	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.905382	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.166304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.443154	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.417923	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.903380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.509575	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.966450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.819266	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.117880	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.657780	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  58.133471	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.588319	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.573160	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.479921	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.982004	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.661850	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.609019	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.096573	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  90.140782	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.122618	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.600330	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.456659	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.173095	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  64.792927	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.793934	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.991310	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.998587	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.217320	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.561739	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.716039	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.336665	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.524007	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.851096	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.611356	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.961611	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.312333	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.544831	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.155147	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.464240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.455319	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.760538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.361821	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.068674	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 129.185775	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.242464	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 106.574755	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  88.316298	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.654039	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.446750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.864285	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.245411	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.513859	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.448922	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.086294	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.750806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.481953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.814675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.212539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.010534	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.581864	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.143962	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.582863	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.597704	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.648808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.357808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.769760	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.827394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.741581	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.593176	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.492870	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.772954	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.288258	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.752674	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.893975	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.363892	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.404143	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.122801	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.073737	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.006894	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.571622	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.803363	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.603800	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.714686	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.447277	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.414295	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.758793	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.755368	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.215387	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.979235	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.155242	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.232912	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  54.358397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.547725	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.526845	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.505218	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.721061	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.073136	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.527464	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.677092	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.093031	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.757399	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.658321	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.301854	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.857953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.119165	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 135.984349	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.489201	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.809932	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.677921	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.464306	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.027636	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.807441	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.666325	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.011875	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.555568	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.158382	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.015751	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.398532	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.125857	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.575939	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.464004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.690800	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.892341	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.043476	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.756913	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.087379	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.507315	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.020290	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.246576	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.137926	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.501951	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.058748	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.978214	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.919098	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.719829	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.551891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.959687	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.092986	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.182344	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.644696	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.163479	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.996267	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.434054	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.684083	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.224676	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.478776	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.458967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.008284	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.532692	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.879508	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.414870	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.207502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.355547	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.110793	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.707440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.109044	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  89.628497	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.034356	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.459232	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.725008	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.660508	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.140320	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.209261	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.858364	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.952300	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.882296	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.310620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.056502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.568328	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.810101	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.950088	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.320715	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.096734	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.262838	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.201576	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.661600	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.018489	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.085608	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.355852	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.788835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.531307	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.684169	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.343934	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.744047	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.137391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.333553	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.178535	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.534571	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  92.606621	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.572085	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.245207	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.438338	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  53.002244	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.619542	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.591987	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  96.678828	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.333074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  86.301940	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.434661	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.228909	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.263059	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.941454	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.966339	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.304196	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.691222	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.901342	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 130.399803	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.345969	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.616128	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.677672	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.609584	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.078210	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.141815	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.336116	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.815921	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.928922	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.539248	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.625685	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.531836	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.714165	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.593988	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.110311	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.952627	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.447102	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.651651	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.091487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.302338	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.026510	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.312834	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.965765	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.585043	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.337271	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.664306	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.475404	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.335498	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.808452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.369120	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.962638	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  92.164056	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.365661	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.367503	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.733479	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.597084	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.097894	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.114443	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.633035	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.780938	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.621015	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.234080	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.224869	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  95.017491	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   3.279457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.064518	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.546286	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.438559	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.767993	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.264717	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.594945	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.023343	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.122974	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.501277	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.042544	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.835029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.024614	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.253437	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.064305	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.728109	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.388377	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.873448	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 132.864587	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.792608	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.052204	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.663441	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.755520	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.723545	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.292611	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.169210	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.664257	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.943415	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.711974	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.969655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.933262	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.620518	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.715111	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.867432	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.190565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.122680	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.236967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.437343	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.027515	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.361480	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 134.894643	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.763617	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.774834	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.833913	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.780143	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  98.630906	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.983399	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.375823	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.228247	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.023888	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.344407	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.731499	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.303250	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.116296	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.207308	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.691285	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.871066	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.884095	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.821680	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.789653	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.663112	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.504164	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.492751	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.850819	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.865976	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.420626	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.803412	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.610716	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.929632	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.711357	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.589237	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.905348	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.608969	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 102.675601	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.366969	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.252183	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.075762	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.991390	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.138687	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.739261	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.072633	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.928009	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.163285	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.421928	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.008899	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.048969	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.079977	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  91.229850	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  53.877125	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.779287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 138.110758	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.650115	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.651900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.972554	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.537344	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.121354	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.708868	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.465111	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.533380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.247127	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.749620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.283914	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.027705	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.202866	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.498436	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.291743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.527213	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.340950	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.648820	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 132.891156	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.290997	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  99.494238	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 126.843488	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.942616	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.755289	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.091480	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.615852	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.503451	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 126.174981	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.348104	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 133.502237	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.903093	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.052478	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.119756	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.720026	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.620723	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.531730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.476952	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.194431	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.538438	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.648505	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.604284	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.424182	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.084709	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  99.208994	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 126.125982	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.045107	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  95.257544	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.738924	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.931629	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   9.762324	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.367264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.930126	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.233745	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.266134	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 128.230666	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.517124	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.661476	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.669461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.369631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.703660	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.202456	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.077900	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.462355	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.220951	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  66.856736	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.814113	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.441725	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.134603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.125584	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.682004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.046275	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.542680	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.874080	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.454016	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.945013	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.608027	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.879054	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.719014	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.270664	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.637042	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.951454	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.793219	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.933025	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.389295	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  24.789918	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.071608	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.616368	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.822398	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.413527	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.303976	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.954686	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.086485	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.556257	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.517755	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.024470	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.156145	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.708747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.862438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.602822	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.269233	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.352450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.065363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.603077	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.899271	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.383767	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.071595	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.885736	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.800612	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.329177	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.159711	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.890990	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.253008	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.037953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.126453	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.219846	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.353719	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.183853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.706279	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.421000	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.878804	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.278909	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.541380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.821993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.352147	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.111535	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.515412	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.511785	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.569485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.354527	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.374549	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.415257	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.706385	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.658796	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.643663	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.355261	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.925765	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.380040	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.665976	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.404388	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.802795	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.277160	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.133324	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.735729	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.757500	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.413582	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.829419	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.777437	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.858060	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.407321	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.120053	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.335967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.346063	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.726793	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.637802	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.284394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.703032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.368222	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.235440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.114378	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.317215	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.581734	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.470078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.371175	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.228189	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.300997	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.418221	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.724392	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.719528	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.010719	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.949061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.508461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.658889	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.154674	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.578522	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.455886	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.140122	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.249216	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.266535	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.458703	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.555371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.899072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.175077	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.747954	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.048157	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.459180	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.642780	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.207017	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.122917	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.241862	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.484663	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.455238	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.043273	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  58.430186	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.788395	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.604111	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.884648	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.631485	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.100971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.914344	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.532321	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.075861	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.902845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.503184	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.733041	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.436946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.005351	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.115502	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.095410	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.955272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.313682	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.894733	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.565393	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.982131	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.550281	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.289046	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.030871	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.563199	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  57.879364	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.136360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.113538	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.252767	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.712071	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.973111	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.463551	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.937016	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.641685	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.026374	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.285121	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.443565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.067130	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.673493	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.071449	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.551836	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.740200	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.923752	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.293593	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.002253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.488461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.059932	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.890944	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.512086	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.871343	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.887227	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.197716	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.134511	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.889857	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.433537	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.811107	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.550359	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.346677	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.933232	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.798347	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.848155	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.589373	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.226465	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.900650	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.041341	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  99.178601	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.114801	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.635521	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.112676	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.028988	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.204292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.555668	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.081951	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.623110	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.388602	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.085552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.474023	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.747987	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.880080	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.684281	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.970878	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.694931	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.569566	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.443298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.629320	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.979946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.236304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.780996	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.725999	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.777292	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 125.380494	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.649103	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.862011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.323016	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.587948	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.805098	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.671582	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.857151	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.441355	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.993549	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.910579	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.353718	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.731072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.994277	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.664557	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.250500	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.172419	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.923287	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.087380	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.745963	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.278647	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.260773	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.072134	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.220438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.527228	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.662032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.543879	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.730060	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.983453	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 116.054848	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.824374	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.272668	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  96.955784	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.929264	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  88.495174	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.422014	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  54.592714	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.276552	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.168634	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.284644	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.818849	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.766111	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.483606	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.854012	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.264685	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 127.101888	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.083462	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.659898	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.348316	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.208493	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.780296	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.081242	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.902174	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.593532	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.143608	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.187971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.565243	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 139.043179	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.363008	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.894248	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.395671	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.411808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.321453	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.459575	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.731947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.645067	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.336960	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.637001	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.961990	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.273392	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 135.747690	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.847896	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.069616	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.879175	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  10.991370	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.054647	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.786630	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.867507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.616308	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.954498	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.747022	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.648891	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.449467	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.121180	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.259412	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.631526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.411799	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.529570	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.851839	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.688259	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.109329	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.936570	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.011627	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.093298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.796854	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.992266	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.283812	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.936718	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  55.681344	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.871590	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.251453	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.804020	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.709472	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.838729	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.947436	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.458696	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.462069	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.742581	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.815839	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.708613	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.078810	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 126.659401	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.958128	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.189835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.405080	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  96.377234	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.283821	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.869701	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   1.435091	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.624665	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.205243	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 118.235607	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.093886	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  11.678040	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 105.009323	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.658107	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.866042	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.506670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.410503	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.028103	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.803977	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.078178	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.068081	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.300309	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.888749	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.879411	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.725032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.734219	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.855860	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  57.058323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.676332	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.573524	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.586975	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  12.669279	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.833416	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.643159	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.933874	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.219272	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.818227	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.452850	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.552029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.729272	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 132.025897	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.446943	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.799650	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.279672	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.950432	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.307367	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.296642	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.454773	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.669429	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.091077	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.885528	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.284176	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.458754	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.564344	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.753586	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.270021	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.978314	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.263305	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.048170	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.717719	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.363937	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.036695	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  83.903810	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.034806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.565318	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.286005	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.592162	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.298587	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.211222	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.172371	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.867769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.615776	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.388337	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.641143	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.128184	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.817995	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.862354	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.950859	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.983829	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 125.929757	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.283484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.456377	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.677821	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.499024	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.465354	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.140282	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.873311	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.555045	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.166131	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.039967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.928593	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.192202	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.325650	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.942249	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.433303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.750061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.909800	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.642129	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.826075	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.915903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.155817	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.594601	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.504936	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.444862	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.303902	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.043753	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.001043	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 115.175613	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.655595	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.594662	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.289751	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.515577	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.131191	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.293255	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.632820	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  60.186188	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.248153	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.437363	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.779608	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.020490	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.961656	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.528433	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.860014	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.176414	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.557980	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.475691	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.328528	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.155375	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.998296	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.337043	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.533634	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.042756	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.124949	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.946740	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.651583	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.180861	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.543839	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.369942	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.805914	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.547915	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.325334	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.839859	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.976800	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.935323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.349979	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.614326	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.882379	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.912620	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.709074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.096089	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.187667	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.583406	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.989758	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.742784	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.694908	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.922316	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.052748	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.043326	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.163943	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.073509	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.889786	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.210877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.146477	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.926044	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.209466	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.131389	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.355017	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.655659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.337421	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.187175	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.009711	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.547037	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.130811	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.257288	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.227769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.695923	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.910297	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.430958	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.558407	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.052296	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.702063	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.035371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.631991	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.694617	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.189268	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.327662	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.948490	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.633478	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.240139	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.648744	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.242077	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.689850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.139957	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.851209	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.393829	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.263550	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.369657	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.306303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.131349	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 117.826636	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.927755	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.684223	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  54.141989	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.328335	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.588499	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.655470	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.259794	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.187315	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.894715	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.030706	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.772616	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.854478	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.680788	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.321178	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.308360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.140555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.585153	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.917711	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.872197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.393698	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.201323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.343423	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.920913	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.955395	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.550660	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.190804	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.992591	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.076717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.976737	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.351325	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.904520	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.055294	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.771210	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.890065	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.065786	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.714171	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.668739	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.961928	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.501719	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.290016	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 129.472573	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.153798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.637280	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.588794	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.772074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.083981	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.687428	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.348827	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.928936	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.533634	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.669645	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.578667	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.823477	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 130.251572	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.019353	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.835393	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.026362	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.130252	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.021217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.425814	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.953401	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.600841	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.261490	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.532464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.727987	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.301583	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.336545	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  18.236076	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.298885	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.480733	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.198428	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.127341	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.354887	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.300363	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.192741	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.260884	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.836470	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.997684	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.497645	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.204065	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.649190	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.096520	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.489644	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.390287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.030596	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.221478	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.268087	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.805009	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.557963	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.768585	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.473751	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.485944	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.308453	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.745078	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.730186	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.222741	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.590520	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.412593	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.807045	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.091368	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.589863	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.902058	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.573381	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.991824	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.663052	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.140753	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.945570	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.917246	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.216539	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.582921	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.082435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.269732	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.647728	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.136665	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.196891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.429645	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.652620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.758381	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.502034	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.235419	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.631440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.230419	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.191318	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.270118	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.056605	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.182996	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.914484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.453552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  95.474598	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.762246	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 101.476314	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.028000	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.546928	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.502545	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.886248	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.836574	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.331793	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.038413	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.652822	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.132032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.691124	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.215336	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.316925	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  94.996678	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  65.973836	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.021761	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.788383	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.753582	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.436638	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.381518	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.812115	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.244604	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.928037	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  15.619910	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.087000	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.746845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.264206	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.546114	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.139695	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.307663	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.417372	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.632133	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.864428	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.851957	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.292039	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.258426	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.318308	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.253001	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.980524	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.794686	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.279163	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.114893	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.936014	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.579064	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.097400	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.823661	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  91.915896	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.684550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.586326	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.253301	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.918099	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.959394	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.865406	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.373958	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.286504	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.336496	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   4.998677	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.598012	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.879462	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.056465	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.761037	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.686940	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.195806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.839803	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.844408	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.910266	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.857677	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.641156	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.453493	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.195015	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.926254	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.591343	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.473029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.964845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.533180	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.732306	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.869846	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.310275	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.425617	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.791543	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.172490	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.121654	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.142083	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.772431	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  64.071915	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.056648	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.744149	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.244521	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.794445	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.852401	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.954779	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.010681	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.144330	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  56.126734	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.564832	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.755420	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.910053	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.747922	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.652264	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.866093	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.370431	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.564169	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  54.834857	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.176644	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.617513	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.771652	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.529553	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.530828	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.414049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.273394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.541259	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.995554	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.663124	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.916002	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.718054	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.264293	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.170901	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.221149	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.673279	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.708614	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.595831	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.439872	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.229045	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.294551	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.114934	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.445057	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.557279	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.407362	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.748443	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.514687	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.173823	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.072970	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.630694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.097768	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.404008	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.854032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.165312	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.098379	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.183460	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 120.571990	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.458255	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.426591	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.049005	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.754368	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.695629	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.084523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  96.302231	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.544206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.356410	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.852782	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.227344	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.175947	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.034186	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.629182	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.392356	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.420426	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.330332	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.638441	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.848827	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.056583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.933546	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.000435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.382594	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.384413	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.660804	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.799129	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.058174	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.414883	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.412968	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.838925	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.281713	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.473972	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.879790	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.470675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.288540	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.910176	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.430027	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.421903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.023160	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.703028	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.870043	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.683872	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.916747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.544687	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.985758	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.853165	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.119515	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.551185	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 123.254342	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.912574	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.931029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.799076	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.631075	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.333430	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.846841	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.630412	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.938022	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.115024	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.644001	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 134.109899	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.058194	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.768510	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.092603	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.190055	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.522080	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.534065	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.127317	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.668049	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.279424	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.722589	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.845612	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.705753	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.571531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.122532	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.611757	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.324253	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.946933	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.084947	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.808038	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.983955	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.633117	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.775241	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.907150	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.183503	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.922761	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.616722	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.887781	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.259639	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.246440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.178769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.657930	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.545847	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.780749	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.972840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.902228	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.954764	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.900806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.214963	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.410641	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.287200	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  95.419344	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.417774	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.730186	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.245706	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.559164	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.960549	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.973584	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.891346	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.417145	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.928209	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.030074	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.486038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.919099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.745759	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  15.008629	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.407237	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.375884	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.919795	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.580100	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.904372	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.717114	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  99.243943	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.668138	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.112318	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.774551	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.497875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.689984	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.112166	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.967438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.909156	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.250112	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.362541	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.491927	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.841337	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.484543	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.633100	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.638164	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.859495	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 124.579476	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.203909	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.359305	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.892516	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.174393	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.356797	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.120201	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.547150	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.988623	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.641603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.228624	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.077611	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.685379	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.074297	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.856327	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 100.186021	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.072065	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.702998	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.671279	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.749264	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.639594	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.436708	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.906097	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.598734	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.557680	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.544276	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.400243	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.892283	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.589234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.703354	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.814876	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.812946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.994166	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.586686	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.656025	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.205984	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  13.496785	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.941555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 136.491734	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.202112	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.191362	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.141506	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.465615	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.205585	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.741558	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.333487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.173332	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.314928	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 135.977409	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.961428	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  99.195971	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.005000	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.169979	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.081664	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  96.953297	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 124.821455	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.020098	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.827399	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.187520	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.864030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.012613	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.186331	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.548878	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.724887	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  58.788850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.418199	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.010252	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.943171	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.719603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.331478	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.386910	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.181682	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 127.169083	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   7.026398	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  20.638918	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.743386	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.236089	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  12.349505	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.147307	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.176030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.514343	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.407879	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.850258	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.512737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.152610	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.637681	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.648604	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.854572	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.734022	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.011784	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.939863	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.571026	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.457820	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.378299	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.883337	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.349404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.409221	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.390674	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.124163	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.809147	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.048090	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.224348	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.744513	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.844337	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.681008	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.731238	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.771629	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.544753	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.132251	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.455781	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.951768	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  86.205571	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.660480	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.277451	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 115.948330	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.869952	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.176307	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.250097	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.303645	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.032667	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.044862	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.011720	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.029972	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.509112	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.440400	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.310113	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.719172	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.850651	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.387773	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.945692	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  11.409090	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.477015	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.356531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.384500	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.051878	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.426056	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.330798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.346647	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.642856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.376779	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.592210	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.658669	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.567509	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.805314	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.191454	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.450635	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.723832	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.156618	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.979834	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.604502	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.116331	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.921685	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.477936	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  11.008698	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 104.922219	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.413778	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.119316	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.519096	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 124.406062	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  52.842349	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.865915	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.339998	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.010452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.373704	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.170934	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.966487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.941208	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.161162	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.478819	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.607450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.933411	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.654565	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.185418	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.656335	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.908316	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.692168	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.775327	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.754136	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 101.562681	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 133.339266	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.863491	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.230002	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 124.395301	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.539359	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.855745	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.060899	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.902818	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.236226	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.988312	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.313490	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.710239	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.381273	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.146947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.362060	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.524631	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.798221	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.097668	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.346158	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.257717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.228749	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.941002	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.706524	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.881622	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.911050	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.649940	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.729222	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.244132	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.800744	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.252697	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.991851	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.900010	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.348593	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.864180	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.478190	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.928560	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.083065	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.572329	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.038420	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.121427	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.479340	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.864856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.901484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.716739	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.153623	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.516856	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.122818	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.110640	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.325580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.570437	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.243201	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.183392	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.604340	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.995369	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.152262	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.645447	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.054052	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.802643	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.244010	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.953061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.012820	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.029911	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.337422	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.095821	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 106.784818	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.981868	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.258983	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.060560	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.740655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.620886	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.594457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.351929	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.550613	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.062897	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.204118	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.997098	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.452920	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.802314	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.444555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.735983	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.368791	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.508870	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.496943	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.961876	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 117.686679	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.403300	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.817117	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.884003	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.314684	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.348197	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   8.600004	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.158102	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.517389	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.170576	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.312703	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.930385	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.591610	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.245057	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.307739	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.247195	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.510835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.867264	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.785876	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.297233	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.143914	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.582960	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.199714	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.271587	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.608061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.095116	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.903125	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 124.999669	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.887887	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.290657	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.408920	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.254761	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   4.847347	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.059303	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.713033	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.392663	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.254889	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.949403	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.975541	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.940373	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.690190	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.297316	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.067076	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.623863	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.651217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.342608	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.912955	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.761298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.441748	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.946917	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.541570	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.312083	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.861374	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.188437	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.274164	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.112464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.866845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.363277	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.649853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.229626	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.249323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.989283	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.301182	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.421159	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.480782	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.098048	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.147021	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.846337	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.204804	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.788338	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.865095	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.797497	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.294382	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.169739	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.507133	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.120189	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.292185	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.040620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.473156	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.114247	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.702112	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.106714	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.841675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.444743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.001206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.127646	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.847484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.652469	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  62.094087	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.290148	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.368437	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.832886	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.424513	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.847191	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.756460	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.854434	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.060142	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.255021	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.596946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.361001	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.627210	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.628018	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.691358	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.525925	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.224252	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.215583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.076971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.305773	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.193713	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  13.837090	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.640547	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.452612	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.823849	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.626231	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.399498	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.319030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.983526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.627318	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.782645	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.769017	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.416880	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.663727	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.116652	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.441099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.758363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.044908	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.427643	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.855006	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.434659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.474839	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.688247	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.028893	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.268908	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  54.765794	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.443202	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.371140	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.002277	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.688328	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.019919	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.576623	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.052215	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.445985	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.507172	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.511426	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.866434	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.294341	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.019175	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.257960	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.982647	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.749661	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 110.223137	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.800065	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.376437	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.389644	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.156813	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.710075	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 131.533540	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  55.099012	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.375853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.317961	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.952648	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.849580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.562426	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.996780	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.155447	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.093831	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.104395	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.243372	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.651264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.339045	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.893378	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  94.813889	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.275984	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.163037	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.383209	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.624199	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.575331	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.847092	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.234382	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.656292	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.910820	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  96.682113	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 132.531231	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.836528	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.786750	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.205639	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 113.660640	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.564883	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.895867	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 130.728744	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.875955	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.056631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.549207	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.221126	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.927795	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.516629	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.476644	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.048976	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.650328	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.324746	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.254060	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.713412	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.597288	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.981124	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.840699	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.508467	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 100.267454	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.448812	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.884276	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.261030	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.260874	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 129.912416	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.823737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.638423	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.733428	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.224090	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  91.245900	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.924310	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.948578	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.826681	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.472993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.131076	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.553015	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 128.029716	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.080403	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.679527	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.995693	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.414040	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.884279	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.812540	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.953485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.666631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.167382	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.384150	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.039435	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   7.392918	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   6.251542	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  22.961213	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.449084	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.197176	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.853504	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.603540	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.856717	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.581178	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.723992	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.794636	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.447285	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.664066	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.264913	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.523809	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.263122	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.863451	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.255282	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.467197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.338948	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.453745	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.955679	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.301846	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.112589	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.353501	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.780796	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  57.520086	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.498487	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.685492	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.773256	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.650196	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.917999	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.154187	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.026965	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.906179	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.460637	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.962212	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.595857	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.003741	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.782781	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.828600	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.070709	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.528969	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.963783	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.173445	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.301201	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.051451	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.921694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.419189	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.446893	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.586834	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.428113	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.268480	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.224289	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.371051	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.440300	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.181004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.044868	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.937107	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.020426	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.091868	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.338656	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.749313	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.462872	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.550908	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.109085	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.146470	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.076779	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.809906	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.840203	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.264098	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.174660	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.141873	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.747795	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.145449	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.170788	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.572808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.513399	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.907872	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.715629	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.728818	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.000808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.677744	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  60.843030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.192305	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.608404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.835314	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.138714	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.764485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.766624	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.077376	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.649838	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.415828	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.873928	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.032799	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.094120	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.866086	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.259793	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.354683	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.164294	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.826576	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.548534	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.189427	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.379550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.892002	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.245978	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.556392	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.906147	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.931146	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.671372	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.836486	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.164806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.115601	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.219662	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.795951	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.647310	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.391997	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.274261	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.017069	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.870394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.442175	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.749061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.108438	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.642078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.042475	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.214404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.801073	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.762932	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.664729	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.709414	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.386279	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.221172	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.791614	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.723784	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.003840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.528389	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.234620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.228107	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.721525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.244925	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.049646	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.127923	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.778799	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.201853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.035880	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.813704	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.899310	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.945022	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.169743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.689297	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.775234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.551562	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  99.858483	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.566975	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.125192	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.103342	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.576595	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.919573	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.332912	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.531743	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.413235	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.203832	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.985592	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.064406	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.438993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.708621	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.831357	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.022323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.039636	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.780826	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.507241	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.533389	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.853632	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.537730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.535765	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.294293	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.843719	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.049549	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.066233	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.034716	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.910786	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.912615	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.822169	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.191282	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.992713	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.938908	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.730942	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.800196	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.301087	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.266285	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.321901	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.560282	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.977342	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.388217	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.890751	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.819909	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.710457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.039719	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.572663	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.031673	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.544521	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.851107	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.172400	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.509353	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.332777	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  69.417457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.704489	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.957746	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.322723	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.255991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.417910	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.779041	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.639068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.254574	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.474533	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.832687	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.964021	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.163071	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.306879	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.565360	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.523362	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.611881	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.386981	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.935806	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.104609	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.282731	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.195273	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.741202	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.365011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.501527	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.033808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.641536	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.766823	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.261194	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.741891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.297420	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.208436	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.896413	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.713036	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.000095	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.667000	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.734647	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.690704	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.422028	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.476523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.437760	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.032770	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.447349	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.291852	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.191448	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.434455	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.502163	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.332944	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.473317	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.676119	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.365591	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.165077	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.799228	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.447135	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.079836	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.946444	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.815765	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.370376	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.870662	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.953375	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.309709	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.679856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.668130	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.985278	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.990040	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.685533	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.254270	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.379748	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.875350	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.760832	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.017726	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.336970	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.575919	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.820820	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.135926	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.724222	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.514019	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.526205	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   4.261269	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.750861	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.952821	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.519902	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.499958	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.413585	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.687776	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.221557	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.834387	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.383907	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.347791	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.079061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.180688	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.779563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.220793	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.791256	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.213311	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.923410	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.442363	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.408408	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.936595	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.722282	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.418481	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.783571	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.729947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.469044	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.903857	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.641917	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.352970	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.968038	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.004058	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.835214	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.049319	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.669354	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.187282	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.637038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.391817	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.895612	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.072354	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.981757	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.095863	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.894486	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.497380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.717817	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.856453	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 124.265618	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.757594	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.799246	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.695839	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.988136	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.432751	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.926050	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.508908	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.521355	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.695531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.604865	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.037818	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.458487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.984531	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.092243	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.625917	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  62.665460	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.703663	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.191241	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.304485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.525636	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  58.706614	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.945901	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.364600	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.748035	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.207317	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.424510	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.313908	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.389337	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.606002	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.429895	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.923942	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.119445	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.762706	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.702530	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.190944	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.878769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.147890	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 129.675635	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.972280	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.731469	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.810473	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.102052	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.848663	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.538768	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.979724	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.834857	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.594647	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.934411	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.739328	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.063380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.213252	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.253210	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.763899	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.684021	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.236140	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.251577	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.618365	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.032103	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.136382	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.423365	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.477863	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.838565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.319075	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.317272	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.187526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.451533	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.547033	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.478759	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.442438	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.480041	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.316596	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.211717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.812895	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.231129	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.966219	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.437664	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.015613	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.733572	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.715069	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.553459	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.744386	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.311125	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.391210	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.995426	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.169711	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 127.221115	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.333725	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.065745	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.206286	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.955452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.825817	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.701753	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.270379	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.681399	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.001671	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.346632	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.268431	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.562947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.143222	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.446910	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.545590	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.668888	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 107.046728	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 127.166910	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.827476	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.267972	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.795525	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.134242	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.753558	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.597081	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.327022	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.728323	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.907701	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.640094	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.946896	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.817296	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.243016	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.813526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.904236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.461852	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.033848	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.755227	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.307989	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.929718	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.686739	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.842775	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.443715	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.423656	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.028169	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.762644	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.095716	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.161810	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.078631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.056118	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.497520	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.285436	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.264227	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.134482	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.887086	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.326832	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.226159	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.423572	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.032086	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.473072	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.877459	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.714193	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.559424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.886500	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.630848	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.243729	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  59.060601	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.278783	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.463921	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.846926	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.013552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.221751	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.588442	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.681774	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.611503	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.050904	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 124.559482	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.462288	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.054818	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.185998	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.828860	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.417457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.737147	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.119528	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.798894	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.195590	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.719933	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.849056	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.162413	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 127.657920	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  82.081656	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.299485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.616560	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.155651	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.639851	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.988787	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.212383	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.081690	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.900733	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.770652	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.063099	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.751592	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.928189	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.726494	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.287432	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.772547	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.285497	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.241558	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.491196	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.021611	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.749050	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.517959	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.047177	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.376387	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.154246	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.267936	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.588241	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  11.172933	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.762510	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.205323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.041783	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.473526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.170600	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.054561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.395294	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.672197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.643387	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.090876	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.170074	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.052086	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.689963	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.487900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.609811	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.077030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.703143	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.299971	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.149700	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.016485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.435232	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.768748	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.539748	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.753224	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.698873	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.947169	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.729147	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.716645	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.837702	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.682093	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.838495	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.813305	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.597066	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.800295	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.425026	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.153421	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.774805	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.730257	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.231173	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.878124	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.290745	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.163153	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 123.264366	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.502271	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.222268	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.275479	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.130724	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.229941	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.328833	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.111492	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.759304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.739492	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.037868	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.053691	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.356453	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.389591	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.143361	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.327595	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  96.970817	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.339242	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.066437	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.349867	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.558470	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.948587	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.024894	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.609183	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.453393	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.004694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.935305	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.344438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.544953	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.583565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.940747	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.708369	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.103574	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.537039	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.342808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.934516	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.758990	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.216046	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.422908	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.394199	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.893003	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.207455	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.955367	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.612913	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.931046	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.034679	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.942480	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.823194	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.649287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.110634	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.774384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   3.513042	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.948198	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.898567	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.721009	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.048684	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.946916	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.045760	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.405665	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.614333	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.012388	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.183940	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.920768	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.208153	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.634661	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.304943	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.827134	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.657792	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.838197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.779073	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.262930	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.432767	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.225601	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.127110	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.258460	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.449795	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.038178	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.003452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.787702	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 126.222354	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.840909	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.970281	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.793912	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.744944	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 110.270137	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.368589	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.541179	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.196919	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.980520	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.754432	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.614345	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.793858	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.273049	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.381310	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 127.069590	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.346105	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  90.620071	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.133566	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 137.316828	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.880648	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 129.567792	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.850940	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.726902	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 132.796804	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.690339	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.347227	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.081786	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.375116	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.262187	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  95.689769	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.347722	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.183773	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.260578	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.482691	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.977086	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.001023	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.084844	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.681750	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  95.601977	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.077912	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.009342	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.797352	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.014276	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.512639	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.477097	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.365289	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.810573	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.383767	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.842074	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.050961	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.648554	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.278707	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 133.259627	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 125.003165	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.639781	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.828791	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.006991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.595780	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.831777	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.918710	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.185738	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.288687	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.446789	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.855056	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.610051	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.753010	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.072343	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.101087	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.120048	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.261067	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.897592	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.399027	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.768538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.934277	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.393208	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  96.468963	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.227470	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.685126	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.055885	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.602263	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 116.881213	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.234404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.828055	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.615452	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.429750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.662737	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  94.735976	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.568762	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.567084	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.176185	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.963904	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.966651	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.950794	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.557132	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.981175	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  96.814380	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.016932	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.970655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.677867	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.204254	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.285533	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  57.510204	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.985122	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 138.619796	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.733092	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.781712	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.317470	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.073085	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.634038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.358555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.061365	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.932671	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.064645	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.200525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.597928	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.370812	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.830301	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.538488	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.041491	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.844673	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.270664	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.756533	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.352088	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.997713	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.205157	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.331004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  92.851810	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.312307	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.964987	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.374987	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.746612	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.918209	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.810743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.566946	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.136886	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.419944	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.898011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.012469	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.011270	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.359796	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.793771	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.897521	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.721938	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.811131	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.366411	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.740739	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.760029	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.769357	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  52.605912	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.654846	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.701000	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.217592	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.390620	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.991239	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.930298	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.390854	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.127585	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.412076	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.681262	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.837670	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.825868	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.512670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.982043	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.754394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.938707	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 124.942581	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.542672	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.188338	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.997647	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 104.970585	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   6.540902	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 113.541046	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.589486	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.089240	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.072786	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.160009	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.400685	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.858396	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.758617	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.926672	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  95.791130	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.710673	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.628786	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.004796	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.297858	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.726727	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.822010	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.580371	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.606180	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.616718	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.404976	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.786363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.794183	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.591423	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.068502	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.576056	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.579157	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.453570	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.598295	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 133.066582	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.972747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.887943	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.976213	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.108080	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.504382	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.846110	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.100427	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  92.464572	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.246780	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.049794	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.532790	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  96.763561	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.603411	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 127.479237	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.759208	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.908090	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  90.736926	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.316087	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.332159	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.144157	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.289550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.187156	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.452567	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.185119	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.770812	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.746775	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.830361	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.764383	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  95.052963	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.060485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.777703	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.219317	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.368701	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.768537	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.059027	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  96.502637	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.801125	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 124.181331	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.467048	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.434802	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.830498	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.887881	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.484002	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.150687	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.518746	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.122761	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.815841	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.990371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.307091	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.596352	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.846703	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.011149	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.961973	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.461110	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.388828	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 117.390450	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.915104	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.338518	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.382027	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.004430	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.337868	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.746880	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 130.336037	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.072372	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.997557	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  96.967722	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 130.694245	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.661581	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.156850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.434909	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.624769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.020396	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.297991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.809200	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.632382	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.707046	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.136072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.839945	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.974600	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.915683	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.987577	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.355596	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.328183	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.345465	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.480025	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.255786	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.038217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.934513	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.241111	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.000078	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.010598	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.342350	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.676829	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.724220	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.051315	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.574083	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.218363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.915531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.071566	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.844923	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.512265	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.322992	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.424321	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.780089	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.691369	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.221089	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.514336	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.735284	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.834461	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.538503	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 106.718331	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.432195	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.783303	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.646090	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.609441	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.066492	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.039136	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  95.854676	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.027773	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.349372	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.927929	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.273326	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.532028	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.936458	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.588553	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.120010	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.671583	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.611771	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  93.765804	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.525522	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  95.971747	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.760897	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 124.659889	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.129600	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.533229	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.249698	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.204801	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.618278	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.606531	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.377555	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.464775	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.845944	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.854343	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.833382	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.582521	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.231494	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 126.945196	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.268875	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.712394	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.947920	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.696189	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.747566	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.018636	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  86.941324	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.317431	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 124.304459	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.036258	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.270873	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.163442	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.909769	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.174470	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.701383	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 127.885988	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.767407	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.195123	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.073060	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.513732	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 140.065573	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.608054	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 134.286336	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.309363	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.176327	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.179810	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.947302	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.584700	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.849577	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 127.844481	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.844525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.804584	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.738743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.099992	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.768072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.429174	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.102380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.684282	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.866300	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.758731	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.036197	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.056057	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.035095	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.768174	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.117453	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.563869	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.032865	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.412520	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.154840	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.574413	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.039658	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.838315	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 109.113842	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  99.959883	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  91.531226	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.584779	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.664331	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.216681	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.373198	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.714215	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.623561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.187187	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.681613	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.696967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.459120	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.229234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.519977	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.666469	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.897839	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.756428	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.215419	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 116.466548	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.931537	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.656844	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.162666	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.062959	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.613526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.198763	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.080276	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.624925	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  93.088272	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.009695	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.201219	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.064511	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.820780	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.024777	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.934785	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.883712	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.809603	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.127485	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.766499	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.261958	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.592032	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.273520	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.316535	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.352356	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.452610	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  92.288827	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.116363	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.234401	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.774806	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  56.549876	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  87.859068	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.691871	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.768954	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.767754	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.043499	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.055363	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.344069	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.121047	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.709669	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.316914	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.478159	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  93.067504	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.232762	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.017546	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.994352	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.031708	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.540593	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.172573	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  10.887496	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.876646	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.968609	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.950100	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.175360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.558699	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.718992	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.064391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  87.102034	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.492425	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.488597	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.677533	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.091195	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.898397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.660891	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.823779	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.713572	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.001536	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.995597	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  93.873655	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.577675	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.710520	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.551567	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.994680	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.243507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.391888	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.545483	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 122.209372	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.142412	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.418425	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.989089	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.584260	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.248564	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.796445	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.659037	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.150506	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  54.384217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.101442	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.001183	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.587263	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.574506	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.512910	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.476643	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.619730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.938733	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.528749	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.801502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.602993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.406163	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.953418	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.366779	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.499443	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.303397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.234637	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.397607	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.851148	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.274075	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.749587	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  94.698030	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.882371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.303380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.286644	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.348130	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.803866	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.757159	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.483550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.669600	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.316305	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.596249	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.267894	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.321464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.732824	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.603471	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.322808	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.956873	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.055787	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.687998	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.440793	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.359494	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.764234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.449709	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.236460	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.831828	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.471382	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.558503	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.176506	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.008412	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.521502	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.408671	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.904395	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 125.257481	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.523230	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.940923	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.756171	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  93.565433	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.117769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.250210	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.368532	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.631999	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.053237	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.086373	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.440416	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.295688	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.719791	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.691226	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.424524	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.834194	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.144548	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.431487	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.709551	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.735762	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.313042	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.122309	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.392681	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.846468	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.158435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.773146	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.108765	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.403121	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.038311	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.932794	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.351520	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.772623	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.500093	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.099656	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.519150	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.701116	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.930466	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.726486	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.912281	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.077505	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.512378	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.366148	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.117674	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.177130	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.430554	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.374533	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.273043	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.959177	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.556717	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.085841	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.818695	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  82.822100	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.803589	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.517410	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.913632	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.205789	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   4.473654	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.906625	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.442594	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.318511	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.974455	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.659090	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.351903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.307587	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.927926	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.561142	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.751709	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.037700	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.093069	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.358917	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.038717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.973100	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.939026	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.464602	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.046642	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.861164	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.518182	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  83.211628	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.459080	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.474082	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.812100	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  95.840538	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.853553	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.037798	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.649111	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.687875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.060955	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.271571	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.333799	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.330810	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.766345	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.315277	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.755251	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.323364	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.921855	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.319271	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.677583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.292266	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.096750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.271301	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.708534	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.118634	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 124.871958	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 127.329977	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.262009	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.361598	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.489480	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.438103	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.277537	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.890870	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.456503	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.605380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.422232	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.855996	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.248863	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.715739	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.602267	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.464910	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.087132	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.051903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.671716	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.784379	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.390507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.813301	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.209732	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.720936	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  94.049434	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.033736	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.107079	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.315335	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.068031	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.596502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.145700	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 136.810006	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.995829	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.832127	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.848033	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.423965	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.984405	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.267990	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.128933	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.920081	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.878575	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  94.009824	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.746522	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.704100	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.185941	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.552625	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.751274	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.834592	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.959507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.429836	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.307772	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.931927	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.318913	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.697478	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.655313	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.311505	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.739126	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.012600	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.066683	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.241170	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.492236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.622758	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.312125	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.327194	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.305806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.413959	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.550063	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.805965	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.884146	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.595601	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.195356	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.161633	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.304912	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.633169	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.002695	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.776865	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.924165	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.003625	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.535566	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.754398	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.510658	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  82.055783	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.177932	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.049558	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.580090	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.599679	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.973998	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.681421	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.791935	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.238006	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.857286	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.969251	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.859946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.921153	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.888155	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.066467	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.300901	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.211370	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.660149	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.304773	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.300781	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.860993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.186743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.626260	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.655272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.947036	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.641450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.488746	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.204827	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 124.240428	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.026936	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.122105	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.798861	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.336350	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.832149	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.531647	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.981604	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 128.622434	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  13.639482	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.986638	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.392236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.291002	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.418031	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.200845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.883423	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.667853	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  93.625043	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  56.431168	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.079064	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.605672	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.808199	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.263624	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 125.484719	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.187409	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.987782	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.046549	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.437382	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.013547	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.036628	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.229352	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.577382	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.210711	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.822905	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.322341	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.930083	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.559235	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.526883	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.717826	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.105227	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.462020	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.878808	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.937403	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.918131	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.814784	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.565287	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.277142	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.058792	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.761653	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  64.140907	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.558307	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 131.614844	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.653553	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.295333	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.174731	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.973054	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.240931	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.732794	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.269631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 129.663059	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.594402	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.074810	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.897813	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.835058	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.553461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.309911	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.061128	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.652281	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.783538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.214428	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.631220	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.981734	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.871293	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 129.432676	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.999550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.298828	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.101078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.748220	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 119.275623	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.091665	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.143210	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.515298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.657444	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.628195	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.393929	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.449658	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.311324	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.885579	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.057537	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.180793	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.070344	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.992900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.017215	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.141223	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.624138	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.397115	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.265756	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.299093	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.366504	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.460397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.904369	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.003010	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.706340	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.353896	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.211174	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.839139	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.139096	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.707262	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  72.402355	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.996230	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.939514	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.067963	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.513167	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.978428	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.784312	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.483469	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.556519	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.304037	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.045645	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.391509	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.312947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.981038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.085201	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.808618	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.817328	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.909352	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.553678	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.575377	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.293756	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.024361	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.931253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.216506	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.260799	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.018398	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.295224	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.091550	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  55.448408	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.344500	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.479829	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.094899	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.283435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 128.900387	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.171211	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.274502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.028735	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.302234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.625785	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.397842	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.256089	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  95.043035	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.088717	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  12.187121	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.206527	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.402534	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.136955	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.474717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.996023	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.595547	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.834755	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.213668	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.664584	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.056926	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.182799	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.661150	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.452622	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.427536	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.888032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.945415	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 124.621293	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 127.368901	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.393072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  70.301872	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.628332	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.377021	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.813792	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 131.768982	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.335690	   0.000000; % NG
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	1	 750	 0.002206	 0.024586	 0.23216	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1	 874	 0.000137	 0.002324	 0.05049	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1	 75433	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1	 75433	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2	 295	 0.000362	 0.005106	 0.08247	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	2	 689	 2.6e-05	 0.000329	 0.00575	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2	 75436	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2	 75436	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3	 6	 3e-06	 4.9e-05	 0.0008	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 237	 2.3e-05	 0.000249	 0.00372	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 237	 2.3e-05	 0.000249	 0.00372	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 75437	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3	 75437	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75438	 3	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75438	 3	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4	 237	 0.000165	 0.002908	 0.04828	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4	 295	 0.000194	 0.00192	 0.03286	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4	 295	 0.000194	 0.00192	 0.03286	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4	 75439	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4	 75439	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5	 875	 0.00134	 0.02377	 0.24937	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	5	 2698	 0.001462	 0.015475	 0.23161	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5	 2698	 0.001462	 0.015475	 0.23161	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5	 2752	 0.000762	 0.009364	 0.15006	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5	 75441	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5	 75441	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6	 234	 6.9e-05	 0.000715	 0.01123	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6	 234	 6.9e-05	 0.000715	 0.01123	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6	 75442	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6	 75442	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7	 350	 0.001121	 0.012942	 0.11349	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	7	 457	 0.000553	 0.005739	 0.08924	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7	 750	 0.00052	 0.006859	 0.0752	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7	 75444	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7	 75444	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8	 794	 0.001786	 0.010459	 0.00285	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8	 811	 0.000783	 0.003958	 0.0011	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8	 823	 0.000418	 0.001409	 0.00035	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8	 825	 0.002371	 0.008584	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 8	 0.076959	 0.20377	 0.0478	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8	 75446	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8	 75446	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9	 15	 4.2e-05	 0.000166	 4e-05	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9	 726	 0.004367	 0.027133	 0.00766	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9	 752	 0.000651	 0.005234	 0.00147	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 9	 0.05751	 0.14946	 0.03632	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9	 75447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9	 75447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10	 906	 0.000346	 0.003291	 0.00585	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10	 75448	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10	 75448	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75449	 10	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75449	 10	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11	 232	 0.000949	 0.004799	 0.00134	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 75450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11	 75450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11	 75579	 8.4e-05	 0.000482	 0.00014	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12	 295	 0.000174	 0.003055	 0.03269	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12	 311	 0.001252	 0.014191	 0.12925	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12	 75451	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12	 75451	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13	 426	 0.005184	 0.013699	 0.00321	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13	 432	 0.002558	 0.00766	 0.00173	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13	 446	 0.004035	 0.010665	 0.0025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13	 447	 0.002871	 0.008464	 0.00197	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13	 75453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13	 75453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14	 273	 0.000658	 0.008281	 0.00257	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14	 275	 0.000852	 0.002212	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75451	 14	 2.3e-05	 0.00032	 0.00014	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14	 75454	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14	 75454	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15	 730	 0.005198	 0.014494	 0.00304	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15	 731	 0.002849	 0.016974	 0.00447	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15	 755	 0.000823	 0.006613	 0.00186	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15	 790	 0.002184	 0.014655	 0.00354	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15	 75455	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15	 75455	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16	 18	 7.8e-05	 0.000314	 8e-05	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16	 490	 0.000803	 0.003215	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16	 492	 0.002317	 0.010434	 0.00278	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16	 75456	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16	 75456	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17	 509	 0.000655	 0.001732	 0.00041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17	 517	 0.001246	 0.003292	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17	 563	 0.000517	 0.002189	 0.00049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17	 75457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17	 75457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18	 503	 0.000765	 0.003006	 0.00079	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18	 75458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18	 75458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19	 326	 0.012803	 0.021567	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19	 803	 0.050701	 0.039742	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19	 807	 0.011189	 0.049584	 0.00149	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19	 75595	 0.057877	 0.14879	 0.0023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20	 960	 0.000877	 0.002859	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20	 75459	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20	 75459	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21	 290	 0.002512	 0.009872	 0.00258	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21	 799	 0.00416	 0.016653	 0.0042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21	 75460	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21	 75460	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22	 850	 0.000221	 0.003061	 0.00211	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22	 75461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22	 75461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22	 75744	 0.00011	 0.001847	 0.00105	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23	 525	 0.002616	 0.007339	 0.00189	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23	 527	 0.000913	 0.002692	 0.00063	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23	 529	 0.001405	 0.004143	 0.00096	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24	 930	 0.000314	 0.000976	 0.0002	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24	 931	 0.001884	 0.006286	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24	 75462	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24	 75462	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25	 567	 0.004568	 0.025666	 0.00048	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25	 572	 0.00719	 0.018483	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 170	 0.000295	 0.000922	 0.00027	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 75463	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26	 75463	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27	 773	 0.017891	 0.011583	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27	 775	 0.003707	 0.012971	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28	 584	 0.00328	 0.008669	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28	 75464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28	 75464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29	 599	 0.004593	 0.011808	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29	 600	 0.021059	 0.029895	 0.00049	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30	 572	 0.003192	 0.015585	 0.00033	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30	 75670	 0.005209	 0.013391	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31	 139	 0.0023	 0.006078	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31	 162	 0.006178	 0.016328	 0.00382	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31	 75465	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31	 75465	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32	 1351	 0.000268	 0.002844	 0.02967	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32	 1367	 0.00079	 0.008666	 0.08419	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32	 2378	 0.000978	 0.011365	 0.09827	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32	 75466	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32	 75466	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33	 457	 0.002078	 0.024007	 0.21071	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	33	 1771	 0.000113	 0.001235	 0.012	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	33	 2625	 0.001256	 0.019607	 0.33385	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33	 75468	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33	 75468	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34	 1771	 0.001417	 0.025261	 0.26241	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34	 3433	 0.003352	 0.042421	 0.41529	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34	 75471	 0.000529	 0.028567	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34	 75471	 0.000529	 0.028567	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35	 424	 0.014223	 0.051506	 0.01105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 433	 0.004691	 0.015807	 0.00393	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 434	 0.005032	 0.017605	 0.00583	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 1801	 0.001051	 0.00319	 0.0007	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 75474	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35	 75474	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36	 2228	 0.000434	 0.006894	 0.1132	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36	 2744	 0.00013	 0.002069	 0.02173	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36	 75475	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36	 75475	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75476	 36	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75476	 36	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37	 2744	 0.000287	 0.003037	 0.04541	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37	 2744	 0.000287	 0.003037	 0.04541	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37	 2752	 0.000226	 0.004178	 0.04014	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37	 75477	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37	 75477	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38	 2006	 3.1e-05	 0.000328	 0.0049	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38	 2006	 3.1e-05	 0.000328	 0.0049	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38	 2010	 7.2e-05	 0.000787	 0.00765	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38	 2026	 7.7e-05	 0.000877	 0.00798	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38	 2057	 0.000229	 0.002561	 0.02393	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38	 2476	 0.000221	 0.002503	 0.02278	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38	 2606	 0.000202	 0.002219	 0.02156	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38	 75479	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38	 75479	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39	 2253	 4.4e-05	 0.000482	 0.00468	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39	 2264	 5.3e-05	 0.000581	 0.0057	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39	 2336	 0.00119	 0.013254	 0.12503	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39	 2476	 0.000488	 0.005435	 0.05126	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39	 75481	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39	 75481	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40	 2026	 6e-05	 0.000667	 0.00629	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40	 2031	 3.4e-05	 0.000372	 0.00362	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40	 2476	 0.000124	 0.001389	 0.01298	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40	 75483	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40	 75483	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41	 1421	 0.00067	 0.009168	 0.13716	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41	 1477	 0.000353	 0.004378	 0.04057	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41	 3081	 0.000272	 0.003014	 0.0287	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41	 75486	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41	 75486	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42	 1771	 0.001722	 0.0189	 0.18374	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42	 2853	 0.004376	 0.04891	 0.46382	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42	 75488	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42	 75488	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43	 2721	 0.005282	 0.041174	 0.01231	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43	 2767	 0.006856	 0.022872	 0.0058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43	 2768	 0.001544	 0.009196	 0.00242	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43	 2770	 0.001711	 0.006852	 0.00173	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43	 2776	 0.005676	 0.015829	 0.00332	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43	 75490	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43	 75490	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44	 67	 0.003105	 0.010651	 0.00255	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 1428	 0.003797	 0.012793	 0.00318	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 1447	 0.008537	 0.035542	 0.01108	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 1482	 0.005374	 0.022744	 0.00512	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 75491	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44	 75491	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45	 1772	 0.008493	 0.019715	 0.00601	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45	 1838	 0.006655	 0.022828	 0.00547	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45	 1845	 0.002483	 0.014062	 0.00349	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45	 75492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45	 75492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46	 47	 0.000176	 0.001954	 0.0186	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46	 1920	 0.000916	 0.010051	 0.09765	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46	 75493	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46	 75493	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47	 2744	 0.000214	 0.002389	 0.02232	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47	 75495	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47	 75495	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48	 1719	 4.9e-05	 0.000552	 0.00516	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48	 1771	 0.000193	 0.002226	 0.01951	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48	 75496	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48	 75496	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49	 2264	 2.4e-05	 0.000265	 0.00257	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49	 75497	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49	 75497	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50	 2603	 0.000268	 0.00073	 0.00016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50	 75498	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50	 75498	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51	 1705	 0.001836	 0.004852	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51	 1712	 0.001876	 0.004522	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51	 75499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51	 75499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52	 1727	 0.000747	 0.002491	 0.00063	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 1785	 0.000964	 0.003859	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 1805	 0.001367	 0.005474	 0.00138	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 75500	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52	 75500	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53	 1873	 0.000473	 0.001251	 0.00029	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53	 1889	 0.003207	 0.010999	 0.00264	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53	 75501	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53	 75501	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 1560	 0.000711	 0.00357	 0.00093	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54	 1576	 0.0007	 0.002963	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54	 75502	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54	 75502	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55	 3026	 0.004721	 0.016453	 0.00381	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55	 75503	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55	 75503	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55	 75955	 0.001802	 0.005396	 0.00122	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56	 2164	 0.007864	 0.032468	 0.00768	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56	 2209	 0.001373	 0.005497	 0.00138	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56	 2296	 0.001721	 0.011549	 0.00279	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57	 2148	 0.003379	 0.006915	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57	 2149	 0.003934	 0.009133	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57	 2165	 0.060036	 0.046051	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58	 1368	 0.002215	 0.007599	 0.00182	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58	 75504	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58	 75504	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59	 1632	 0.001636	 0.005701	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59	 1651	 0.00155	 0.004023	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60	 2392	 0.0063	 0.016651	 0.0039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60	 2393	 0.006684	 0.02252	 0.0056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60	 2400	 0.00247	 0.011517	 0.00285	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60	 75505	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60	 75505	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61	 1775	 0.001234	 0.002525	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61	 1779	 0.020775	 0.030272	 0.00068	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61	 1833	 0.005579	 0.018412	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62	 1795	 0.018639	 0.047915	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62	 1797	 0.043526	 0.079724	 0.00138	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 1551	 0.002961	 0.017344	 0.00472	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 1574	 0.000395	 0.002165	 0.00057	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 76225	 0.001574	 0.015116	 0.0044	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64	 2592	 0.027735	 0.038653	 0.00066	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64	 2596	 0.003547	 0.015806	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64	 2597	 0.001251	 0.002905	 4e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64	 2604	 0.023531	 0.04659	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65	 2185	 0.000578	 0.002014	 0.00047	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65	 2428	 0.000595	 0.001544	 0.00037	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65	 2495	 0.000276	 0.000728	 0.00017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66	 1499	 0.008946	 0.050856	 0.00092	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66	 1519	 0.017556	 0.019122	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67	 1420	 0.004693	 0.021531	 0.00552	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67	 1425	 0.00416	 0.013877	 0.00352	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67	 1428	 0.00119	 0.003146	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67	 75506	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67	 75506	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68	 1860	 0.019847	 0.015706	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68	 1862	 0.007036	 0.005515	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68	 1864	 0.008878	 0.01626	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68	 2171	 0.005415	 0.004285	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69	 1605	 0.00421	 0.011739	 0.00246	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69	 75507	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69	 75507	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70	 2039	 0.00031	 0.001045	 0.00026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70	 75508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70	 75508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71	 1405	 0.002949	 0.008457	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72	 1381	 0.000385	 0.006276	 0.00374	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72	 75509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72	 75509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73	 1774	 0.000308	 0.000775	 0.0002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73	 75510	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73	 75510	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74	 1177	 0.000933	 0.010565	 0.09621	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74	 1252	 0.00032	 0.003636	 0.03284	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74	 75511	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74	 75511	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75	 1038	 4.6e-05	 0.000705	 0.00155	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75	 1076	 0.000835	 0.005423	 0.0108	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75	 75513	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75	 75513	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76	 1157	 0.000291	 0.003229	 0.03074	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76	 75514	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76	 75514	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77	 1177	 0.000332	 0.003829	 0.03357	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77	 75515	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77	 75515	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78	 1212	 9e-05	 0.00037	 9e-05	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78	 1213	 0.007077	 0.024666	 0.00572	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78	 1223	 0.058536	 0.1728	 0.04026	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79	 1156	 0.01069	 0.037788	 0.00852	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79	 75821	 0.00569	 0.019519	 0.00468	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80	 1005	 0.016838	 0.10709	 0.2256	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80	 75517	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80	 75517	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 1208	 0.028022	 0.078629	 0.02025	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81	 1213	 0.00287	 0.007812	 0.00172	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81	 75518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 75518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82	 1208	 0.038602	 0.10206	 0.0239	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82	 1261	 0.034922	 0.14793	 0.03333	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82	 75519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82	 75519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83	 89	 0.005736	 0.024967	 0.00711	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83	 1087	 0.002869	 0.009665	 0.0024	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83	 1110	 0.026532	 0.13563	 0.03415	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83	 1159	 0.006435	 0.022428	 0.0052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83	 75520	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83	 75520	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84	 967	 0.001356	 0.01566	 0.13735	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84	 1033	 0.000194	 0.002	 0.03143	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84	 1061	 0.000622	 0.008084	 0.13404	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84	 75521	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84	 75521	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85	 1128	 0.009538	 0.023977	 0.00621	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85	 1248	 0.007671	 0.020272	 0.00475	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85	 75523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85	 75523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86	 1155	 0.050825	 0.13656	 0.03098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86	 75524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86	 75524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87	 75525	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87	 75525	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87	 75821	 0.004319	 0.011415	 0.00267	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88	 1002	 0.038566	 0.20551	 0.00361	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88	 1006	 0.028199	 0.071715	 0.00113	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88	 75781	 0.6564	 0.51528	 0.00661	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89	 983	 0.014826	 0.050863	 0.01219	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89	 1106	 0.019609	 0.080981	 0.01917	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89	 75526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89	 75526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90	 994	 0.06056	 0.16907	 0.03553	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90	 995	 0.001379	 0.003708	 0.00104	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90	 1011	 0.065245	 0.17539	 0.03981	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91	 1001	 0.039926	 0.14264	 0.00283	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91	 1002	 0.026801	 0.048359	 0.0007	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91	 1004	 0.10407	 0.14505	 0.00248	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92	 1044	 0.001065	 0.002739	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92	 75527	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 75527	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93	 1245	 0.069602	 0.18422	 0.0432	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93	 75528	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93	 75528	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94	 1249	 0.008825	 0.022871	 0.00692	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94	 75529	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94	 75529	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95	 1185	 0.019186	 0.053144	 0.00088	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95	 1187	 0.020659	 0.028161	 0.00062	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95	 1188	 0.010106	 0.024737	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95	 1190	 0.021811	 0.053387	 0.00091	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	96	 963	 0.000687	 0.002752	 0.00069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	96	 969	 0.00031	 0.001176	 0.00033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	96	 970	 0.000543	 0.002298	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	97	 1261	 0.055775	 0.15568	 0.03271	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	97	 1269	 0.004024	 0.010446	 0.00254	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	97	 75530	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	97	 75530	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	98	 1189	 0.021614	 0.091508	 0.0206	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	98	 1208	 0.015771	 0.046502	 0.01082	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	98	 75531	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	98	 75531	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	99	 998	 0.091281	 0.07224	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	99	 999	 0.035069	 0.063033	 0.00113	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	99	 1000	 0.045439	 0.045895	 0.00061	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	100	 1009	 0.058625	 0.15087	 0.0374	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	100	 75532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	100	 75532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	101	 1176	 0.048281	 0.072385	 0.00131	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	101	 1180	 0.049548	 0.050045	 0.00066	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	101	 1251	 0.095681	 0.12452	 0.00174	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	101	 75827	 0.010073	 0.049153	 0.00085	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	102	 1087	 0.002755	 0.009974	 0.00214	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	102	 75533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	102	 75533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	103	 1265	 0.048022	 0.12476	 0.03031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	103	 75534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	103	 75534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	104	 991	 0.024152	 0.092919	 0.00159	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	105	 1665	 0.001473	 0.01617	 0.15716	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	105	 1680	 0.000994	 0.011473	 0.1006	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	105	 1693	 0.000342	 0.004482	 0.04056	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	105	 3040	 0.000399	 0.006995	 0.07485	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	105	 75535	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	105	 75535	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	106	 108	 5e-05	 0.000581	 0.00509	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	106	 75537	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	106	 75537	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	107	 2882	 9.2e-05	 0.001333	 0.02048	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	107	 2911	 0.000305	 0.003382	 0.0322	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	107	 75539	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	107	 75539	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	108	 1031	 0.001747	 0.03259	 0.30933	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	108	 3040	 0.000155	 0.002457	 0.04033	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	108	 3047	 0.00032	 0.003491	 0.03427	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	108	 75541	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	108	 75541	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	109	 1310	 0.002647	 0.016767	 0.00455	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	109	 3037	 0.000486	 0.002987	 0.00086	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	109	 3039	 0.000926	 0.009817	 0.00291	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75537	 109	 0.000142	 0.001026	 0.00055	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	109	 75542	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	109	 75542	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	110	 2882	 0.000842	 0.009715	 0.08518	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	110	 2974	 0.000219	 0.00281	 0.02642	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	110	 75543	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	110	 75543	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	111	 1157	 0.001414	 0.014965	 0.22396	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	111	 1157	 0.001414	 0.014965	 0.22396	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	111	 2852	 0.003602	 0.037325	 0.58968	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	111	 2852	 0.003602	 0.037325	 0.58968	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	111	 75545	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	111	 75545	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	112	 2800	 0.062103	 0.17813	 0.00274	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	112	 2802	 0.11136	 0.14493	 0.00203	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	112	 2839	 0.08903	 0.27322	 0.0074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	113	 3070	 0.046767	 0.15434	 0.0025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	113	 3071	 0.031646	 0.023283	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	114	 2783	 0.041382	 0.096075	 0.00143	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	114	 2845	 0.023978	 0.060981	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	114	 76296	 0.028317	 0.056065	 0.00082	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	115	 2968	 0.089179	 0.070576	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	115	 3068	 0.056852	 0.074722	 0.00102	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	115	 3069	 0.055714	 0.072507	 0.00101	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	115	 76297	 0.18803	 0.20867	 0.00407	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 122	 0.000462	 0.002709	 0.00074	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 3174	 0.002525	 0.017859	 0.0049	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 3221	 0.002991	 0.010423	 0.00242	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 3223	 0.001007	 0.003648	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 3241	 0.003791	 0.022202	 0.00605	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 3253	 0.003154	 0.011035	 0.00366	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 3254	 0.00229	 0.011584	 0.00322	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 75547	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	116	 75547	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	117	 1453	 0.000875	 0.007283	 0.00221	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	117	 3130	 0.006942	 0.038519	 0.01171	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	117	 3146	 0.002121	 0.006142	 0.00148	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	117	 75548	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	117	 75548	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	118	 3155	 0.000284	 0.002074	 0.00061	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 3157	 0.000889	 0.003097	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 3185	 0.000503	 0.00362	 0.00096	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 3186	 0.000436	 0.003184	 0.00094	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 3254	 0.005445	 0.014389	 0.00337	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 75549	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	118	 75549	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	119	 2752	 0.000214	 0.002466	 0.02162	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	119	 75550	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	119	 75550	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	120	 2759	 0.003391	 0.020202	 0.00531	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	120	 2766	 0.014567	 0.045537	 0.01319	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	120	 3233	 0.001422	 0.012198	 0.00347	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75550	 120	 3.2e-05	 0.000248	 7e-05	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	120	 75552	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	120	 75552	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	121	 3182	 0.000675	 0.00294	 0.00084	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	121	 3267	 0.000829	 0.004097	 0.0012	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	121	 75553	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	121	 75553	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	122	 3219	 0.001343	 0.006355	 0.00153	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	122	 75554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	122	 75554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	123	 3354	 0.000606	 0.00278	 0.00071	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	123	 4232	 0.012066	 0.076444	 0.02076	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	123	 75555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	123	 75555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	124	 3450	 0.032835	 0.14693	 0.00303	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	124	 3451	 0.20157	 0.13052	 0.00248	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	124	 3453	 0.032907	 0.027086	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	124	 3456	 0.012562	 0.02462	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	124	 76437	 0.1809	 0.33147	 0.00572	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	124	 76446	 0.023664	 0.087498	 0.00162	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	125	 3074	 0.019791	 0.066033	 0.01675	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	125	 3500	 0.01012	 0.04052	 0.01021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	125	 75556	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	125	 75556	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	125	 76449	 0.0128	 0.074993	 0.02043	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	126	 3490	 0.019247	 0.049883	 0.00094	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	126	 3491	 0.009244	 0.035962	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	126	 76300	 0.053976	 0.050617	 0.00078	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	126	 76302	 0.047354	 0.047829	 0.00063	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	127	 1700	 0.004676	 0.03137	 0.00757	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	127	 2816	 0.009825	 0.048544	 0.01418	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	127	 2823	 0.004319	 0.011415	 0.00267	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	127	 75557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	127	 75557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	128	 3337	 0.069788	 0.21435	 0.00402	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	128	 3476	 0.020662	 0.099696	 0.00176	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	128	 3477	 0.062473	 0.04944	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	129	 3351	 0.005149	 0.025126	 0.00043	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	129	 3358	 0.003159	 0.012911	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	130	 3388	 0.022042	 0.035183	 0.00081	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	130	 3390	 0.072806	 0.28016	 0.00478	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	130	 3390	 0.072806	 0.28016	 0.00478	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	130	 3392	 0.013059	 0.090976	 0.00214	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	131	 2838	 0.11924	 0.12177	 0.0019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	131	 3348	 0.046831	 0.10711	 0.00261	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	131	 3349	 0.046969	 0.14425	 0.00271	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75465	 132	 0.037064	 0.084074	 0.00168	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	133	 134	 0.070604	 0.051946	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	134	 136	 0.011066	 0.028447	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	135	 141	 0.032398	 0.035634	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	135	 151	 0.017971	 0.026305	 0.00041	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75465	 136	 0.007183	 0.028497	 0.00081	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	137	 138	 0.026339	 0.020844	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	138	 146	 0.028981	 0.022935	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	138	 75558	 0.007553	 0.019417	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	139	 75558	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	139	 75558	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75465	 140	 0.019655	 0.015077	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	141	 142	 0.019261	 0.025066	 0.00035	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75465	 141	 0.004891	 0.01028	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	142	 160	 0.021318	 0.015101	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75463	 143	 0.0256	 0.020067	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75465	 143	 0.022648	 0.024185	 0.00051	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75463	 144	 0.0351	 0.027778	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75465	 144	 0.007796	 0.014066	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75558	 145	 0.021112	 0.015261	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	147	 162	 0.000649	 0.002597	 0.00065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	147	 75559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	147	 75559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	148	 150	 0.06173	 0.039964	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	149	 152	 0.006164	 0.057385	 0.00111	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	149	 8441	 0.006276	 0.047456	 0.00158	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 153	 0.027045	 0.027316	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	151	 159	 0.01433	 0.0252	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	152	 154	 0.003673	 0.011279	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	152	 159	 0.006679	 0.025591	 0.00072	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	153	 75560	 0.006903	 0.015859	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	154	 75560	 0.006742	 0.01733	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	155	 172	 0.002252	 0.007587	 0.00189	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	155	 75560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	155	 75560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	156	 157	 0.018125	 0.014344	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	157	 176	 0.008067	 0.020738	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75560	 157	 0.00624	 0.021834	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	157	 75561	 0.004402	 0.016935	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	158	 75561	 0.014912	 0.013984	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	159	 75561	 0.00337	 0.011242	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	160	 161	 0.003617	 0.007401	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75463	 160	 0.007578	 0.017592	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75559	 161	 0.002095	 0.007484	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	162	 75561	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	162	 75561	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	162	 75579	 0.02978	 0.079972	 0.01813	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	163	 165	 0.006692	 0.014064	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75559	 163	 0.00465	 0.009114	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75561	 164	 0.016604	 0.010749	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	165	 167	 0.005776	 0.01132	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	165	 175	 0.008957	 0.023025	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	166	 167	 0.005599	 0.005979	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	166	 168	 0.007726	 0.013941	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	168	 169	 0.004712	 0.010939	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	168	 171	 0.024798	 0.017926	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75561	 168	 0.006919	 0.023082	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	169	 75562	 0.007552	 0.012055	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	170	 75562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	170	 75562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	172	 187	 0.001537	 0.007273	 0.00175	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	172	 75563	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	172	 75563	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	173	 174	 0.006668	 0.025652	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	173	 75565	 0.004674	 0.028732	 0.00052	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	174	 175	 0.0054	 0.018014	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75563	 176	 0.006429	 0.024733	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75561	 177	 0.038979	 0.095412	 0.00163	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	177	 75564	 0.00311	 0.017501	 0.00038	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	178	 180	 0.050946	 0.036088	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	179	 187	 0.002153	 0.007502	 0.00174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	179	 75564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	179	 75564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75564	 180	 0.038597	 0.050728	 0.0007	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	181	 182	 0.009114	 0.019458	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	181	 206	 0.013719	 0.028075	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	181	 75570	 0.0307	 0.019875	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	182	 184	 0.016652	 0.018315	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	182	 191	 0.026929	 0.019812	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	182	 207	 0.053699	 0.050358	 0.00078	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	182	 75571	 0.030191	 0.055297	 0.00095	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	183	 194	 0.003689	 0.009749	 0.00228	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	183	 208	 0.003957	 0.010273	 0.00249	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	184	 190	 0.01671	 0.013224	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	185	 186	 0.023167	 0.017552	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	186	 190	 0.027538	 0.021586	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 193	 0.002285	 0.009147	 0.0023	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 194	 0.001516	 0.00617	 0.0015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 3532	 0.008739	 0.086739	 0.0236	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 75565	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	187	 75565	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	188	 75567	 0.018583	 0.013163	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	189	 190	 0.014317	 0.01133	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	189	 75567	 0.010737	 0.011695	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	190	 75566	 0.010129	 0.015516	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	191	 75572	 0.018862	 0.014468	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	192	 75566	 0.013347	 0.010562	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	193	 194	 0.00121	 0.003294	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	193	 198	 0.001531	 0.004109	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	193	 75566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	193	 75566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	193	 75575	 0.01346	 0.035575	 0.00833	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	194	 75567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	194	 75567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	194	 75575	 0.014655	 0.038048	 0.00924	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	195	 196	 0.021342	 0.016728	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	196	 197	 0.010502	 0.006799	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75567	 196	 0.011272	 0.017268	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	197	 75568	 0.010264	 0.011289	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	198	 199	 0.001201	 0.003225	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	198	 75568	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	198	 75568	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	199	 211	 0.002197	 0.005522	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	200	 201	 0.004897	 0.009696	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75567	 200	 0.008826	 0.034336	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	201	 202	 0.027023	 0.019535	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	203	 205	 0.036771	 0.0291	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	204	 214	 0.002749	 0.011005	 0.00277	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	204	 338	 0.003433	 0.019687	 0.00654	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	204	 75569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	204	 75569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	205	 206	 0.014397	 0.037008	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75569	 205	 0.012245	 0.031477	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	208	 209	 0.001826	 0.00459	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	208	 75570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	208	 75570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	209	 210	 0.002178	 0.006072	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	210	 75571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	210	 75571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	210	 75575	 0.005917	 0.015638	 0.00366	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	211	 212	 0.001696	 0.004088	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	211	 75572	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	211	 75572	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	212	 213	 0.002868	 0.007372	 0.00183	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	212	 75573	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	212	 75573	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	213	 221	 0.003323	 0.008782	 0.00206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	214	 215	 0.002395	 0.011624	 0.00266	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	215	 219	 0.002895	 0.011592	 0.00292	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	216	 217	 0.007022	 0.018051	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	216	 75588	 0.005254	 0.013505	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 218	 0.020545	 0.022597	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75450	 217	 0.013977	 0.044821	 0.00111	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	218	 291	 0.073693	 0.049502	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	219	 225	 0.003141	 0.013293	 0.00299	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	220	 221	 0.000672	 0.004836	 0.00128	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	220	 75575	 0.000671	 0.004745	 0.0013	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	221	 231	 0.000734	 0.004646	 0.00126	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	221	 75574	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	221	 75574	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	222	 234	 7.8e-05	 0.00122	 0.02687	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	222	 9563	 0.002773	 0.027494	 0.47211	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	222	 9563	 0.002773	 0.027494	 0.47211	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	222	 75575	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	222	 75575	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	223	 229	 0.018926	 0.014978	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	224	 75576	 0.020072	 0.015885	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	225	 228	 0.000866	 0.003525	 0.00086	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	225	 247	 0.001689	 0.00657	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	226	 75586	 0.012624	 0.01375	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	227	 75586	 0.01792	 0.014047	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 75576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	228	 75576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	228	 75582	 0.000943	 0.003895	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	229	 233	 0.017827	 0.013973	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	229	 75577	 0.011384	 0.017438	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	230	 231	 0.000968	 0.006131	 0.00166	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	230	 232	 0.000593	 0.003401	 0.00113	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	232	 75577	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	232	 75577	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75450	 233	 0.00699	 0.011658	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	234	 75578	 6.8e-05	 0.005405	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75579	 234	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75443	 235	 0.007339	 0.010004	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75443	 236	 0.010837	 0.007834	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	237	 75580	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	237	 75580	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	238	 75583	 0.011141	 0.008817	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75442	 239	 0.000198	 0.00202	 0.00641	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75578	 239	 0.000153	 0.000969	 0.00203	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	239	 75582	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	239	 75582	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	239	 76466	 0.004449	 0.049563	 0.19234	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	240	 241	 8.5e-05	 0.001215	 0.00041	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75582	 240	 0.000123	 0.001858	 0.00055	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75580	 241	 0.000188	 0.002882	 0.00081	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	241	 75583	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	241	 75583	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75583	 242	 0.006388	 0.005056	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	243	 246	 0.000278	 0.001763	 0.00048	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75580	 243	 0.000471	 0.003531	 0.00086	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	243	 75584	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	243	 75584	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75584	 244	 0.006159	 0.004452	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	245	 75608	 0.010355	 0.008195	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	246	 248	 0.000444	 0.002809	 0.00076	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	246	 75585	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	246	 75585	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75580	 247	 0.001513	 0.006058	 0.00153	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	247	 75586	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	247	 75586	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	248	 249	 0.000268	 0.001699	 0.00046	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 251	 0.000413	 0.002615	 0.00071	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 252	 0.000973	 0.006264	 0.00164	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75580	 249	 0.001012	 0.008619	 0.00215	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 75587	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	249	 75587	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75587	 250	 0.005	 0.009158	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	250	 75589	 0.007456	 0.011178	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	251	 252	 0.000562	 0.003619	 0.00095	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	252	 282	 0.000813	 0.011372	 0.00386	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	252	 75588	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	252	 75588	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	253	 254	 0.004329	 0.01025	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	253	 283	 0.010658	 0.027398	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	253	 75589	 0.007502	 0.018619	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	254	 75589	 0.003362	 0.008643	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	255	 341	 0.001176	 0.004623	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	255	 75589	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	255	 75589	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	256	 257	 0.00101	 0.007271	 0.00024	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75589	 256	 0.001013	 0.008928	 0.00019	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	257	 277	 0.003134	 0.011195	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	257	 277	 0.003134	 0.011195	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	257	 285	 0.009703	 0.032021	 0.00052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	257	 75590	 0.003777	 0.019641	 0.00043	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	258	 259	 0.001691	 0.005643	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	258	 269	 0.002802	 0.008037	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	259	 75590	 0.001707	 0.005694	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 261	 0.001303	 0.007322	 0.00014	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 75590	 0.003238	 0.0158	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	261	 262	 0.007829	 0.005069	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	261	 75591	 0.001053	 0.007228	 0.00013	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	263	 267	 0.000407	 0.002188	 0.00054	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	263	 75590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	263	 75590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	264	 75591	 0.011387	 0.009012	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75580	 265	 0.001283	 0.003718	 0.0009	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	265	 75591	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	265	 75591	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75581	 266	 0.014912	 0.011801	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75438	 267	 0.000523	 0.00511	 0.00143	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	267	 75592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	267	 75592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	268	 271	 0.000191	 0.003033	 0.00192	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75438	 268	 0.000168	 0.00281	 0.00159	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	269	 270	 0.015107	 0.010148	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	269	 276	 0.00287	 0.010253	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	269	 276	 0.00287	 0.010253	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75590	 269	 0.001738	 0.010521	 0.00033	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 273	 0.000145	 0.002306	 0.00146	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 75593	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	271	 75593	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	272	 273	 0.001723	 0.006006	 0.00139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75451	 273	 0.000592	 0.008547	 0.00271	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	274	 276	 0.003412	 0.015202	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	274	 695	 0.026093	 0.016893	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75454	 274	 0.004165	 0.021068	 0.00037	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	275	 75594	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	275	 75594	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75440	 276	 0.008814	 0.034423	 0.00076	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	277	 278	 0.00335	 0.012888	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	277	 279	 0.011677	 0.033491	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75594	 278	 0.00491	 0.02396	 0.00041	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75440	 279	 0.007677	 0.019734	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	280	 297	 0.002268	 0.007781	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75439	 280	 0.002644	 0.008907	 0.00221	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 282	 0.000627	 0.006128	 0.00172	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 288	 0.002394	 0.011164	 0.00277	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 292	 0.002403	 0.009619	 0.00242	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	282	 287	 0.001625	 0.006387	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75588	 283	 0.004608	 0.018833	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	283	 75595	 0.017106	 0.071402	 0.00206	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	284	 285	 0.031838	 0.03251	 0.00051	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	285	 286	 0.032454	 0.023877	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	287	 298	 0.001886	 0.006597	 0.00219	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	288	 289	 0.002028	 0.009303	 0.00238	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	288	 75595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	288	 75595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	289	 290	 0.002628	 0.010523	 0.00265	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	289	 75596	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	289	 75596	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	292	 333	 0.004152	 0.017141	 0.00406	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	293	 294	 0.000946	 0.004927	 0.00129	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	293	 654	 0.001086	 0.005455	 0.00142	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	294	 653	 0.000506	 0.005359	 0.00159	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	294	 75597	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	294	 75597	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	294	 75598	 0.000438	 0.004726	 0.00253	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	295	 75598	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	295	 75598	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	296	 300	 0.004815	 0.011603	 0.00328	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75598	 296	 0.002446	 0.007325	 0.00165	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	296	 75599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	296	 75599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	297	 298	 0.002053	 0.00807	 0.00211	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75599	 299	 0.062338	 0.045064	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	300	 75600	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	300	 75600	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	301	 75601	 0.01624	 0.024877	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	302	 304	 0.001878	 0.006442	 0.00154	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	302	 75601	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	302	 75601	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	302	 75603	 0.002665	 0.006919	 0.00168	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	303	 328	 0.017897	 0.036624	 0.0009	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	303	 75604	 0.005847	 0.025763	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	304	 333	 0.0036	 0.015237	 0.00343	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	305	 307	 0.065288	 0.049465	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	306	 307	 0.027465	 0.040724	 0.00061	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	306	 566	 0.074882	 0.059262	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	307	 75604	 0.009294	 0.052833	 0.00096	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	308	 314	 0.017673	 0.013986	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	308	 75602	 0.002489	 0.00658	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	309	 75602	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	309	 75602	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	309	 75603	 0.000727	 0.005313	 0.00137	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	310	 320	 0.001125	 0.00516	 0.00132	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	310	 75603	 0.000955	 0.004382	 0.00112	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	311	 75603	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	312	 336	 0.004356	 0.021886	 0.0057	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	312	 75605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	312	 75605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	313	 315	 0.004635	 0.010759	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75602	 313	 0.00345	 0.016559	 0.00049	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	315	 316	 0.033664	 0.0423	 0.00064	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	317	 318	 0.019546	 0.021498	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	318	 323	 0.027852	 0.048621	 0.00075	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	318	 75606	 0.002479	 0.010349	 0.0003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	319	 320	 0.001182	 0.005268	 0.00143	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	319	 569	 0.01214	 0.034055	 0.00877	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	319	 75606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	319	 75606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	321	 322	 0.024282	 0.019033	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75604	 322	 0.01979	 0.0379	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	323	 324	 0.052897	 0.038918	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75606	 325	 0.051525	 0.040776	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	326	 327	 0.011187	 0.02649	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	327	 328	 0.011729	 0.029828	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75595	 329	 0.085477	 0.067647	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	330	 331	 0.03619	 0.036954	 0.00058	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75460	 331	 0.016771	 0.065244	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75569	 332	 0.11061	 0.081385	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	334	 335	 0.02557	 0.018813	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75605	 335	 0.027304	 0.041411	 0.00059	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	336	 338	 0.001532	 0.009125	 0.0024	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	337	 75607	 0.048812	 0.03863	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	338	 8443	 0.000902	 0.008767	 0.00578	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	338	 75607	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	338	 75607	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75605	 339	 0.01587	 0.048684	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75605	 339	 0.01587	 0.048684	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75607	 339	 0.015359	 0.059089	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75607	 339	 0.015359	 0.059089	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	340	 570	 0.066545	 0.04896	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75580	 341	 0.00143	 0.005437	 0.00152	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	341	 75608	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	341	 75608	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	342	 414	 0.095309	 0.068901	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	343	 362	 0.001773	 0.008744	 0.00236	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	343	 75609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	343	 75609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	343	 75716	 0.00243	 0.020839	 0.00593	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 345	 0.002056	 0.010891	 0.00276	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 75716	 0.001673	 0.008892	 0.00206	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	345	 364	 0.001368	 0.00754	 0.00176	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	345	 75610	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	345	 75610	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	346	 355	 0.002722	 0.007195	 0.00168	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	346	 75611	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	346	 75611	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	346	 75612	 0.002136	 0.00755	 0.0017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	347	 348	 0.008247	 0.013773	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	347	 75613	 0.005993	 0.023316	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	349	 383	 0.001579	 0.0041	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	349	 75612	 0.001344	 0.003856	 0.00095	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	350	 397	 0.0004	 0.004618	 0.04048	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	350	 75612	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	351	 352	 0.002472	 0.006213	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75612	 351	 0.001931	 0.006992	 0.0015	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	352	 615	 0.002953	 0.00759	 0.00188	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	352	 75614	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	352	 75614	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75614	 353	 0.028554	 0.022382	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75611	 354	 0.021033	 0.041644	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	355	 356	 0.001402	 0.003911	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	355	 75615	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	355	 75615	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	356	 357	 0.001425	 0.003767	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	357	 75616	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	357	 75616	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	357	 75626	 0.006739	 0.02018	 0.00455	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75611	 358	 0.007241	 0.012198	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75615	 359	 0.070106	 0.055481	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	360	 399	 0.022446	 0.10002	 0.0017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	360	 407	 0.022326	 0.057392	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	361	 377	 0.011769	 0.009225	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	361	 75617	 0.012996	 0.013127	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	362	 371	 0.001845	 0.005439	 0.00127	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	362	 75617	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	362	 75617	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	363	 377	 0.016655	 0.012253	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	363	 75618	 0.005079	 0.010057	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	364	 365	 0.000802	 0.002079	 0.00063	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	364	 467	 0.004332	 0.017885	 0.00423	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	364	 75618	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	364	 75618	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	365	 75619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	365	 75619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	366	 367	 0.004473	 0.008856	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75618	 366	 0.005061	 0.016882	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 368	 0.006755	 0.008086	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	368	 369	 0.003608	 0.008377	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	368	 374	 0.006317	 0.007842	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	368	 375	 0.011017	 0.018559	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	369	 370	 0.00416	 0.006947	 0.00012	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	370	 376	 0.00366	 0.008496	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	370	 75620	 0.003194	 0.008212	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	371	 75620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	371	 75620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75619	 372	 0.02467	 0.019524	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	373	 374	 0.015855	 0.011665	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	373	 385	 0.018455	 0.022092	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75619	 374	 0.009211	 0.022862	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	375	 381	 0.016442	 0.015299	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	376	 379	 0.009242	 0.014017	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	378	 379	 0.001253	 0.005015	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75620	 378	 0.002076	 0.011062	 0.00019	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	379	 380	 0.019975	 0.014696	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	379	 469	 0.008612	 0.022138	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	381	 75625	 0.016084	 0.029021	 0.00042	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	382	 75621	 0.011758	 0.023044	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	383	 384	 0.002257	 0.005965	 0.0014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	384	 396	 0.007761	 0.020511	 0.0048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	384	 75621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	384	 75621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75621	 385	 0.008767	 0.017181	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	386	 395	 0.001851	 0.004459	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	386	 75622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	386	 75622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	387	 388	 0.010084	 0.020637	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75621	 387	 0.017557	 0.045132	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75610	 388	 0.037006	 0.03316	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75622	 388	 0.01842	 0.047352	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75622	 389	 0.00617	 0.015628	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	389	 75712	 0.014555	 0.048553	 0.00077	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	390	 391	 0.001745	 0.005143	 0.0012	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	390	 738	 0.001432	 0.005442	 0.00152	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	390	 787	 0.001651	 0.009907	 0.003	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	391	 789	 0.004848	 0.015811	 0.0042	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	391	 75623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	391	 75623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	392	 393	 0.01525	 0.02569	 0.00037	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75622	 392	 0.020778	 0.033166	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75623	 392	 0.007506	 0.029199	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75613	 394	 0.008842	 0.034019	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	394	 75624	 0.003882	 0.023865	 0.00043	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	395	 75624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	395	 75624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	396	 517	 0.003404	 0.019556	 0.00554	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	396	 75625	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	396	 75625	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	396	 75626	 0.001608	 0.006439	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	397	 750	 0.000355	 0.005399	 0.09676	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	397	 75626	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	398	 400	 0.007994	 0.026667	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75627	 398	 0.005909	 0.028834	 0.0005	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	399	 400	 0.054661	 0.035388	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75616	 399	 0.011414	 0.029341	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75627	 399	 0.007186	 0.038593	 0.00092	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	400	 401	 0.008378	 0.021537	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	401	 402	 0.020125	 0.032123	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	402	 403	 0.035176	 0.027572	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	402	 75628	 0.028459	 0.027957	 0.00047	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75626	 404	 0.003165	 0.020697	 0.00526	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	404	 75628	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	404	 75628	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	405	 486	 0.029894	 0.032561	 0.00044	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75628	 405	 0.03128	 0.031593	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	406	 407	 0.061022	 0.061635	 0.00082	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	406	 411	 0.036818	 0.052267	 0.00086	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	406	 581	 0.1296	 0.10257	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	408	 409	 0.010602	 0.027254	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	408	 412	 0.018052	 0.046405	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75628	 409	 0.009319	 0.04106	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	410	 412	 0.035615	 0.028185	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	410	 415	 0.058059	 0.04551	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	411	 412	 0.019697	 0.038998	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	412	 413	 0.047194	 0.037349	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	412	 75629	 0.11659	 0.092271	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	414	 75629	 0.056868	 0.095801	 0.00136	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	415	 435	 0.098684	 0.090901	 0.00146	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	415	 75629	 0.061019	 0.04623	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	416	 433	 0.008344	 0.021661	 0.00526	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	416	 590	 0.024378	 0.064438	 0.01509	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	416	 75629	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	416	 75629	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	417	 422	 0.025499	 0.018761	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	418	 419	 0.016063	 0.024363	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	418	 421	 0.007162	 0.036231	 0.00063	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	418	 482	 0.01285	 0.033032	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	418	 75653	 0.004634	 0.022614	 0.00039	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	419	 484	 0.013694	 0.035201	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	420	 421	 0.059872	 0.043281	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	421	 75630	 0.024385	 0.040668	 0.00059	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	422	 428	 0.011787	 0.023101	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	423	 427	 0.023788	 0.0154	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	423	 428	 0.012177	 0.020337	 0.00035	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	424	 432	 0.004834	 0.013481	 0.00283	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	424	 75630	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	424	 75630	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75630	 425	 0.04605	 0.036443	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	425	 75632	 0.024504	 0.019392	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	426	 75631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	426	 75631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75631	 427	 0.031901	 0.025246	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	428	 429	 0.00965	 0.020603	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	428	 452	 0.009476	 0.024358	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	428	 75647	 0.012594	 0.048995	 0.00082	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	429	 560	 0.006767	 0.019408	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	430	 431	 0.030532	 0.022072	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75453	 430	 0.001135	 0.003486	 7e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	432	 75632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	432	 75632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	433	 75633	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	433	 75633	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	434	 75634	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	434	 75634	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	435	 1798	 0.063262	 0.063897	 0.00085	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75633	 435	 0.036325	 0.04956	 0.00089	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	436	 437	 0.022672	 0.017942	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	436	 439	 0.036741	 0.034455	 0.00053	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	436	 1808	 0.018364	 0.025033	 0.00056	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	437	 438	 0.026712	 0.020938	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	438	 440	 0.018063	 0.035763	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75474	 438	 0.015278	 0.059437	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75634	 439	 0.035966	 0.036725	 0.00057	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	440	 445	 0.024886	 0.027106	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	441	 443	 0.056352	 0.036483	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	441	 444	 0.029051	 0.029342	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	441	 922	 0.047928	 0.062992	 0.00086	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75634	 441	 0.025417	 0.065338	 0.00101	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	442	 75668	 0.044741	 0.033897	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	444	 445	 0.011447	 0.022665	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	445	 75635	 0.01875	 0.018938	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	446	 75635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	446	 75635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	447	 75636	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	447	 75636	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	448	 449	 0.027855	 0.044461	 0.00102	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75636	 448	 0.030022	 0.042619	 0.0007	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	449	 453	 0.015898	 0.036525	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	450	 451	 0.006031	 0.018501	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	450	 75661	 0.008847	 0.034417	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	451	 914	 0.007442	 0.0224	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	452	 453	 0.011926	 0.025462	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	453	 75661	 0.041956	 0.050225	 0.00084	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	454	 75661	 0.014507	 0.028724	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 75666	 0.038961	 0.039352	 0.00052	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 75667	 0.014519	 0.028747	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	456	 465	 0.001972	 0.005498	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	456	 558	 0.002827	 0.007472	 0.00175	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	456	 634	 0.003102	 0.010349	 0.00262	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	456	 75637	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	456	 75637	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	457	 75638	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	458	 460	 0.00183	 0.004704	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75638	 458	 0.001658	 0.005157	 0.00108	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	458	 75640	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	458	 75640	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75640	 459	 0.008164	 0.021159	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	459	 75651	 0.010259	 0.015713	 0.00027	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	460	 467	 0.002888	 0.00726	 0.00188	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	460	 75641	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	460	 75641	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	461	 462	 0.024104	 0.019076	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75641	 461	 0.016949	 0.010973	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 75667	 0.018377	 0.036385	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75637	 463	 0.023257	 0.038787	 0.00056	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75617	 464	 0.009176	 0.017983	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	464	 75642	 0.024178	 0.022673	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	465	 75642	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	465	 75642	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75620	 466	 0.007095	 0.018239	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	466	 75643	 0.012296	 0.022101	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	467	 503	 0.005455	 0.018712	 0.00448	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	467	 75643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	467	 75643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75643	 468	 0.008777	 0.020377	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	468	 75644	 0.01834	 0.023044	 0.00035	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	469	 471	 0.010733	 0.019292	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75643	 469	 0.027025	 0.029724	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	470	 519	 0.001769	 0.00596	 0.00148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75626	 470	 0.004894	 0.019594	 0.00494	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	470	 75644	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	470	 75644	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	471	 472	 0.017188	 0.02259	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 473	 0.002751	 0.010582	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 474	 0.007071	 0.018176	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 477	 0.006315	 0.012502	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	473	 475	 0.003185	 0.013016	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	474	 485	 0.00486	 0.009622	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75625	 475	 0.004209	 0.019544	 0.00053	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	476	 477	 0.005649	 0.009515	 0.00014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	476	 518	 0.016316	 0.012912	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	478	 480	 0.011539	 0.008342	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	478	 75656	 0.009905	 0.025461	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	479	 481	 0.014388	 0.011278	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	481	 75655	 0.016604	 0.025436	 0.00036	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	482	 75655	 0.009682	 0.034587	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	483	 484	 0.006113	 0.020394	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	483	 485	 0.016467	 0.014755	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	483	 486	 0.009228	 0.023722	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75625	 486	 0.015186	 0.059078	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	487	 488	 0.007053	 0.005582	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	487	 489	 0.016733	 0.013243	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	487	 505	 0.006117	 0.009371	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	487	 75651	 0.003111	 0.015183	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	488	 75645	 0.014794	 0.011348	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	489	 508	 0.002129	 0.006826	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	489	 75650	 0.006533	 0.011741	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	490	 491	 0.000376	 0.001725	 0.00044	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	490	 519	 0.002237	 0.007675	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	490	 75645	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	490	 75645	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	491	 500	 0.000451	 0.001806	 0.00045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	491	 75646	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	491	 75646	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	492	 75647	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	492	 75647	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	493	 495	 0.000657	 0.001937	 0.00045	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	493	 498	 0.000894	 0.00278	 0.00058	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	494	 495	 0.00036	 0.001061	 0.00025	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	494	 497	 0.000648	 0.00191	 0.00044	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	496	 511	 0.006063	 0.004295	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	496	 75649	 0.014271	 0.011294	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	497	 515	 0.000784	 0.002104	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	497	 75648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	497	 75648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	498	 500	 0.001055	 0.003618	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	498	 75649	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	498	 75649	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75649	 499	 0.006948	 0.004667	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 75650	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	500	 75650	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	501	 504	 0.000972	 0.00271	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75638	 501	 0.003779	 0.010945	 0.00264	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	501	 75651	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	501	 75651	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75651	 502	 0.005409	 0.010709	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	502	 75652	 0.016442	 0.016446	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	503	 75652	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	503	 75652	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	504	 519	 0.000852	 0.002375	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75646	 506	 0.020175	 0.015966	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	507	 516	 0.010518	 0.00681	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75457	 507	 0.007732	 0.006364	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	507	 75656	 0.017534	 0.011352	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75457	 508	 0.002455	 0.0057	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	509	 517	 0.000668	 0.001734	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	510	 75669	 0.006593	 0.004268	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	512	 513	 0.020346	 0.02035	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	512	 75654	 0.005072	 0.013037	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	512	 75669	 0.002962	 0.014225	 0.00028	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	514	 515	 0.000743	 0.002073	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	514	 75653	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	514	 75653	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	515	 75654	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	515	 75654	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	517	 75655	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	517	 75655	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	518	 561	 0.014558	 0.011521	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	518	 75656	 0.006402	 0.008414	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	519	 521	 0.000907	 0.002397	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	520	 564	 0.014863	 0.010935	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75651	 520	 0.017552	 0.012913	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	521	 75656	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	521	 75656	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	522	 75657	 0.026355	 0.020857	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75456	 523	 0.020271	 0.018672	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75647	 524	 0.012357	 0.022976	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	524	 75657	 0.004222	 0.014085	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	525	 75657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	525	 75657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	526	 532	 0.0087	 0.01705	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	526	 75658	 0.00774	 0.019897	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	527	 75658	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	527	 75658	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	528	 75659	 0.023464	 0.015761	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75638	 529	 0.002794	 0.008014	 0.00197	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	529	 75659	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	529	 75659	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	530	 531	 0.001245	 0.003341	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	530	 553	 0.002198	 0.005706	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	531	 75660	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	531	 75660	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	532	 533	 0.013448	 0.016394	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75660	 532	 0.013867	 0.018225	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	533	 534	 0.008987	 0.009077	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	534	 535	 0.016753	 0.012111	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75657	 535	 0.017098	 0.027292	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	536	 545	 0.020693	 0.015225	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	536	 916	 0.005792	 0.016022	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	536	 75662	 0.005206	 0.025117	 0.00044	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	537	 547	 0.00459	 0.012131	 0.00284	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75638	 537	 0.008297	 0.031538	 0.00883	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	537	 75661	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	537	 75661	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75661	 538	 0.007853	 0.013229	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	539	 546	 0.002388	 0.006412	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	539	 75662	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	539	 75662	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	540	 543	 0.005519	 0.01583	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75662	 540	 0.004757	 0.009734	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	541	 542	 0.01349	 0.013034	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75661	 541	 0.031889	 0.025237	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	542	 75663	 0.007326	 0.013845	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	543	 544	 0.010431	 0.009347	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	543	 75663	 0.002383	 0.01448	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	544	 549	 0.034254	 0.026275	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	546	 910	 0.004189	 0.010875	 0.00264	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	547	 548	 0.001571	 0.00463	 0.00108	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	547	 75663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	547	 75663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	548	 550	 0.00279	 0.009101	 0.00242	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	548	 75664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	548	 75664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	550	 552	 0.003805	 0.016103	 0.00362	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	551	 75665	 0.085141	 0.06738	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	552	 628	 0.003626	 0.018219	 0.00474	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	552	 75665	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	552	 75665	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	553	 555	 0.002937	 0.00866	 0.00201	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75639	 554	 0.014848	 0.023701	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	555	 556	 0.002818	 0.009821	 0.00228	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75444	 556	 0.004382	 0.027757	 0.00753	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	556	 75666	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	556	 75666	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	557	 908	 0.028333	 0.072834	 0.00113	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	557	 75677	 0.025162	 0.064682	 0.001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	558	 75667	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	558	 75667	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	559	 1805	 0.00805	 0.020863	 0.00631	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	559	 75668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	559	 75668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75647	 560	 0.003074	 0.013465	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75648	 560	 0.007449	 0.016712	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75655	 561	 0.012548	 0.009931	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75655	 562	 0.016125	 0.011422	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	563	 75669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	563	 75669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75644	 564	 0.006411	 0.011523	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75632	 565	 0.014117	 0.032775	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	567	 571	 0.021625	 0.050198	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	568	 572	 0.040389	 0.040795	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	569	 75670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	569	 75670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75670	 570	 0.008914	 0.022669	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	571	 578	 0.039174	 0.1007	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	573	 574	 0.046426	 0.11935	 0.00185	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	573	 602	 0.11056	 0.21671	 0.00325	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	573	 616	 0.1014	 0.074602	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	573	 1393	 0.031831	 0.093605	 0.00192	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	573	 1400	 0.14234	 0.095622	 0.00169	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	574	 575	 0.16033	 0.16196	 0.00215	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	575	 576	 0.13052	 0.084504	 0.00161	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	576	 583	 0.11608	 0.09187	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	577	 578	 0.036716	 0.078389	 0.00177	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	577	 579	 0.041317	 0.10621	 0.00164	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	579	 604	 0.034475	 0.081637	 0.00149	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	580	 803	 0.12487	 0.09027	 0.00137	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	582	 602	 0.091523	 0.072432	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	583	 75672	 0.09018	 0.091087	 0.00121	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	584	 585	 0.004694	 0.013089	 0.00275	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	585	 613	 0.005603	 0.016518	 0.00384	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	586	 587	 0.028087	 0.059965	 0.00135	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	586	 589	 0.03039	 0.070545	 0.00134	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	587	 600	 0.015332	 0.035589	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	588	 605	 0.11356	 0.089873	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	589	 604	 0.022854	 0.058748	 0.00091	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	590	 598	 0.010719	 0.02583	 0.00729	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	590	 75671	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	590	 75671	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	591	 593	 0.004465	 0.017868	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	591	 597	 0.010712	 0.024611	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75464	 592	 0.013318	 0.014222	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75464	 593	 0.000378	 0.00165	 4e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	594	 595	 0.003345	 0.013014	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75464	 594	 0.002251	 0.009621	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	595	 597	 0.00389	 0.014594	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	596	 597	 0.059498	 0.043775	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75671	 597	 0.015283	 0.053509	 0.00148	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	598	 75672	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	598	 75672	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75464	 599	 0.006634	 0.017055	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	600	 601	 0.039868	 0.03125	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	602	 603	 0.075612	 0.059839	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75628	 602	 0.13773	 0.21989	 0.00507	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75672	 603	 0.099728	 0.064567	 0.00123	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	604	 607	 0.030305	 0.069308	 0.00169	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	605	 606	 0.010963	 0.031444	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	605	 75673	 0.010912	 0.053247	 0.00092	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	606	 75674	 0.01408	 0.035807	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	607	 612	 0.0274	 0.084145	 0.00158	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	607	 75673	 0.014296	 0.033191	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	608	 609	 0.001762	 0.004914	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	608	 75673	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	608	 75673	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	609	 829	 0.002047	 0.006035	 0.0014	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	610	 828	 0.014677	 0.028763	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	611	 612	 0.01284	 0.049952	 0.00083	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	611	 75728	 0.008899	 0.039817	 0.00082	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	613	 615	 0.003252	 0.008443	 0.00205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	613	 75674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	613	 75674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	614	 837	 0.062746	 0.063376	 0.00084	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	617	 623	 0.014727	 0.011544	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	618	 619	 0.009607	 0.019661	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	618	 621	 0.014617	 0.019925	 0.00044	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	618	 75678	 0.038335	 0.042164	 0.00056	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	619	 620	 0.011745	 0.029869	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75609	 619	 0.023813	 0.055286	 0.00082	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	620	 75717	 0.014055	 0.054678	 0.00091	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	622	 623	 0.016686	 0.010803	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	623	 75675	 0.006368	 0.012608	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	624	 625	 0.001002	 0.00424	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	624	 632	 0.002231	 0.007887	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	624	 75675	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	624	 75675	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	625	 652	 0.001878	 0.007642	 0.00186	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	625	 742	 0.005634	 0.035685	 0.00969	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	625	 75676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	625	 75676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75676	 626	 0.033808	 0.02444	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	627	 636	 0.013226	 0.033999	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75676	 627	 0.01443	 0.035321	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75444	 628	 0.003083	 0.018368	 0.00483	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	628	 75677	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	628	 75677	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	629	 630	 0.064904	 0.049786	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 75681	 0.063636	 0.080989	 0.00119	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75445	 630	 0.067466	 0.052883	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75445	 631	 0.037114	 0.056291	 0.00081	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	632	 634	 0.004639	 0.013893	 0.00313	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	632	 635	 0.00244	 0.00822	 0.00204	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75444	 632	 0.003401	 0.013367	 0.0035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	632	 75678	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	632	 75678	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	633	 75679	 0.013194	 0.026123	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	634	 635	 0.001671	 0.005733	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	634	 75679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	634	 75679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	636	 746	 0.017214	 0.043777	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	637	 782	 0.033965	 0.087312	 0.00135	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	637	 75686	 0.038253	 0.086772	 0.00173	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	638	 647	 0.010772	 0.041911	 0.0112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	638	 652	 0.006469	 0.021099	 0.0056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	638	 75680	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	638	 75680	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	639	 640	 0.005935	 0.015687	 0.00367	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	639	 895	 0.008904	 0.022384	 0.0058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	640	 75681	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	640	 75681	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	641	 75683	 0.064944	 0.051396	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	642	 645	 0.051496	 0.039015	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	642	 75682	 0.037565	 0.029445	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	643	 650	 0.011278	 0.029806	 0.00698	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	643	 651	 0.003695	 0.012677	 0.00304	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	643	 780	 0.013349	 0.041514	 0.00866	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	643	 75682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	643	 75682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	644	 645	 0.016643	 0.027643	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	644	 75685	 0.050745	 0.047587	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	645	 75720	 0.055714	 0.14323	 0.00222	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	646	 647	 0.004323	 0.011426	 0.00267	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	646	 75683	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	646	 75683	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	647	 651	 0.006292	 0.016334	 0.00396	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	647	 842	 0.008122	 0.021465	 0.00502	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 647	 0.019142	 0.059536	 0.01242	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	648	 785	 0.023878	 0.047276	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75683	 648	 0.1002	 0.11021	 0.00147	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	649	 843	 0.076958	 0.070888	 0.00114	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	649	 75684	 0.022085	 0.037204	 0.00053	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	649	 75685	 0.049872	 0.064904	 0.00091	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 650	 0.017301	 0.047107	 0.01038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	650	 75684	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	650	 75684	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	651	 75685	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	651	 75685	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75444	 652	 0.002463	 0.00986	 0.00248	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	652	 75686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	652	 75686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	653	 655	 0.000414	 0.003952	 0.0013	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	654	 657	 0.000865	 0.004035	 0.001	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	655	 657	 0.001994	 0.007253	 0.00222	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	655	 726	 0.002918	 0.028958	 0.00787	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	655	 75687	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	655	 75687	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75687	 656	 0.024072	 0.01905	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	656	 75688	 0.019783	 0.02319	 0.0004	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	657	 658	 0.000698	 0.003183	 0.00101	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	657	 661	 0.001134	 0.007722	 0.00263	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75598	 657	 0.001156	 0.014982	 0.00593	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	657	 75688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	657	 75688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	658	 660	 0.00117	 0.005678	 0.0013	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 660	 0.001909	 0.00876	 0.00224	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 786	 0.002184	 0.010338	 0.00249	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 75689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	659	 75689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	661	 800	 0.002724	 0.019269	 0.00529	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	661	 75690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	661	 75690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	662	 75736	 0.004773	 0.006652	 0.00011	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	663	 682	 0.000798	 0.002793	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	663	 841	 0.00048	 0.006592	 0.00238	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75436	 663	 0.000298	 0.00421	 0.00139	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	663	 75691	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	663	 75691	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	664	 839	 0.000784	 0.002838	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75436	 664	 0.002928	 0.007972	 0.00176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	664	 75692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	664	 75692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	665	 710	 0.007061	 0.020252	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75691	 665	 0.005706	 0.014666	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75692	 666	 0.003979	 0.010227	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 75738	 0.005841	 0.014498	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75692	 667	 0.010266	 0.008124	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	668	 677	 0.011971	 0.008041	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	668	 75693	 0.006068	 0.012013	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	668	 75736	 0.010673	 0.008446	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	669	 675	 0.002074	 0.006449	 0.00135	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	669	 840	 0.001012	 0.005555	 0.00147	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	669	 841	 0.00065	 0.005118	 0.0015	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	669	 75693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	669	 75693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	670	 671	 0.015347	 0.011772	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75693	 670	 0.007951	 0.012179	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	672	 673	 0.001583	 0.01315	 0.00032	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	672	 715	 0.012764	 0.036609	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	672	 716	 0.005095	 0.028059	 0.00063	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	672	 75702	 0.036348	 0.027881	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	673	 674	 0.00153	 0.009873	 0.00031	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	674	 717	 0.054377	 0.059809	 0.0008	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	674	 725	 0.00405	 0.01351	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	674	 75694	 0.007395	 0.015846	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	675	 75694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	675	 75694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	676	 723	 0.005045	 0.011947	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75694	 676	 0.002601	 0.010119	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	678	 679	 0.014245	 0.011166	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	678	 722	 0.00316	 0.01943	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	678	 75737	 0.002283	 0.014037	 0.00025	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	679	 75695	 0.004372	 0.011239	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 681	 0.000367	 0.001555	 0.00035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 840	 0.000364	 0.001583	 0.00045	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	681	 682	 0.000547	 0.002191	 0.00055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	681	 684	 0.000347	 0.002156	 0.00061	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	683	 684	 0.000531	 0.002911	 0.00077	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75436	 683	 0.000948	 0.005888	 0.00166	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	684	 685	 0.000329	 0.00196	 0.00052	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	684	 75695	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	684	 75695	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	685	 719	 0.001504	 0.007337	 0.00203	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	685	 75696	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	685	 75696	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75696	 686	 0.00998	 0.016813	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	687	 75697	 0.020377	 0.015972	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	688	 766	 0.000836	 0.0058	 0.00166	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	688	 75697	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	688	 75697	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	688	 75698	 0.000436	 0.004442	 0.00114	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	689	 750	 0.000703	 0.012745	 0.12745	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	689	 75698	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	690	 763	 0.019508	 0.015439	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	691	 692	 0.010966	 0.019144	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	691	 699	 0.009236	 0.016601	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75452	 691	 0.00642	 0.037443	 0.00075	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	691	 75700	 0.007904	 0.026085	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	691	 75701	 0.004558	 0.02731	 0.00066	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	693	 694	 0.017575	 0.012705	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75454	 693	 0.009871	 0.019544	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	696	 698	 0.000776	 0.011186	 0.00406	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75439	 696	 0.000157	 0.001704	 0.00053	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75451	 696	 0.000657	 0.004577	 0.00172	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	696	 75700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	696	 75700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75700	 697	 0.050731	 0.039766	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	698	 701	 0.000388	 0.005706	 0.00174	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	698	 75701	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	698	 75701	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	699	 700	 0.027886	 0.020159	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	701	 702	 0.000393	 0.002909	 0.00149	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	702	 707	 0.000533	 0.003952	 0.00202	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	703	 841	 0.001854	 0.00517	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	703	 75702	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	703	 75702	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	704	 706	 0.000293	 0.003005	 0.00095	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	704	 707	 0.000546	 0.006033	 0.00181	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	705	 75738	 0.0191	 0.015115	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	706	 841	 0.00042	 0.004456	 0.00132	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	706	 75703	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	706	 75703	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	707	 841	 0.000685	 0.010466	 0.00337	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75439	 707	 0.001517	 0.024668	 0.007	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	707	 75704	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	707	 75704	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	708	 709	 0.004924	 0.019157	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75704	 708	 0.00223	 0.009935	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	709	 711	 0.015878	 0.012566	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75703	 709	 0.00329	 0.009676	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75703	 710	 0.004851	 0.017328	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	712	 713	 0.003232	 0.024238	 0.00049	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	712	 715	 0.012301	 0.035281	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75704	 712	 0.01164	 0.026742	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75701	 713	 0.002981	 0.024801	 0.00047	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75597	 714	 0.032924	 0.0238	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75687	 716	 0.004405	 0.030238	 0.00055	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	718	 728	 0.043846	 0.057627	 0.00079	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	718	 75726	 0.028624	 0.073583	 0.00114	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	719	 732	 0.002177	 0.008715	 0.0022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	719	 75705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	719	 75705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	720	 722	 0.00447	 0.011817	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75705	 720	 0.004332	 0.012425	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	721	 75706	 0.004945	 0.019235	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	721	 75707	 0.003982	 0.014224	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	722	 723	 0.005152	 0.01196	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	722	 75706	 0.002366	 0.011355	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	724	 726	 0.001901	 0.005605	 0.0013	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	724	 75706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	724	 75706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75706	 725	 0.006481	 0.016797	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	726	 75707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	726	 75707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75707	 727	 0.031959	 0.025292	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	728	 75708	 0.028286	 0.037176	 0.00051	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75707	 729	 0.00844	 0.023056	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	729	 75709	 0.010561	 0.027147	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 75708	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	730	 75708	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	731	 734	 0.002621	 0.012025	 0.00308	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	731	 75709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	731	 75709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	732	 734	 0.001287	 0.005314	 0.00126	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	732	 75710	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	732	 75710	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	733	 777	 0.024052	 0.061829	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75447	 733	 0.019116	 0.03912	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75709	 733	 0.007476	 0.023974	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75710	 733	 0.011044	 0.042963	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	734	 768	 0.002492	 0.007748	 0.00162	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	734	 75711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	734	 75711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	735	 736	 0.009004	 0.007057	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	735	 737	 0.019427	 0.015374	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	735	 744	 0.001929	 0.006434	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	735	 748	 0.008377	 0.006056	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	735	 749	 0.007533	 0.012581	 0.00021	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	738	 75712	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	738	 75712	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	738	 75716	 0.0021	 0.008886	 0.002	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 75713	 0.011557	 0.011353	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	740	 741	 0.000878	 0.002274	 0.00069	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	740	 742	 0.001218	 0.004177	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	740	 75713	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	740	 75713	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	741	 743	 0.000542	 0.001622	 0.00037	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	742	 758	 0.000908	 0.006955	 0.00186	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	742	 75714	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	742	 75714	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	743	 75715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	743	 75715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75715	 744	 0.00248	 0.008473	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	745	 746	 0.016382	 0.022331	 0.0005	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75714	 745	 0.010223	 0.015661	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	746	 75717	 0.014552	 0.050918	 0.00105	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	746	 75718	 0.006144	 0.037751	 0.00086	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	747	 749	 0.024789	 0.019618	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75715	 749	 0.007503	 0.02503	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	749	 75717	 0.003277	 0.014439	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 75716	 0.000123	 0.009866	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75717	 751	 0.02172	 0.028547	 0.00039	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	752	 755	 0.000398	 0.002836	 0.00088	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75447	 753	 0.015949	 0.012622	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	754	 760	 0.030581	 0.019798	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75447	 754	 0.005958	 0.017089	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	755	 757	 0.000651	 0.005129	 0.0015	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	755	 759	 0.002166	 0.007429	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75455	 756	 0.010369	 0.02053	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 758	 0.000724	 0.00578	 0.00142	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	759	 75718	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	759	 75718	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75447	 761	 0.028269	 0.055971	 0.00082	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	762	 763	 0.022931	 0.025221	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	763	 764	 0.015833	 0.01253	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75699	 763	 0.003741	 0.017879	 0.00039	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	765	 770	 0.01099	 0.028252	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75697	 765	 0.003108	 0.015149	 0.00028	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	766	 767	 0.000621	 0.004169	 0.00101	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	767	 768	 0.002154	 0.007613	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	767	 781	 0.003907	 0.025547	 0.0065	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	769	 771	 0.013134	 0.030174	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	769	 772	 0.028216	 0.018267	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	769	 773	 0.003598	 0.021865	 0.0004	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75699	 769	 0.014856	 0.066198	 0.00112	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	770	 771	 0.006737	 0.016491	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	773	 774	 0.004107	 0.025248	 0.00046	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	774	 779	 0.015448	 0.039711	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	774	 75720	 0.055266	 0.049523	 0.00101	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75711	 776	 0.027456	 0.056188	 0.00138	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	776	 75720	 0.023844	 0.046731	 0.0007	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	777	 782	 0.023249	 0.047578	 0.00117	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	778	 779	 0.013235	 0.032849	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	778	 783	 0.0266	 0.068378	 0.00106	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	780	 781	 0.002479	 0.010089	 0.00246	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	780	 75719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	780	 75719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	781	 75720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	781	 75720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	782	 784	 0.034694	 0.067994	 0.00102	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75685	 783	 0.11257	 0.11994	 0.00171	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	784	 785	 0.009266	 0.021191	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75719	 784	 0.017567	 0.045158	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	786	 795	 0.002005	 0.01311	 0.00333	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	786	 799	 0.001961	 0.012419	 0.00337	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	786	 75721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	786	 75721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	787	 788	 0.001103	 0.008266	 0.00202	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	787	 789	 0.003024	 0.010687	 0.00241	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	787	 75722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	787	 75722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	788	 790	 0.001169	 0.008637	 0.00249	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	789	 835	 0.005164	 0.015682	 0.00343	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	789	 75723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	789	 75723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	790	 75724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	790	 75724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	791	 801	 0.014999	 0.030694	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75724	 791	 0.008155	 0.025018	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	792	 75732	 0.020177	 0.026258	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	793	 804	 0.002083	 0.012412	 0.00327	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	793	 824	 0.002432	 0.01339	 0.00483	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	793	 75725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	793	 75725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	794	 795	 0.001025	 0.006878	 0.00166	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	795	 75726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	795	 75726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	796	 802	 0.008951	 0.029859	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75721	 796	 0.01338	 0.051475	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	797	 798	 0.014212	 0.028138	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75726	 797	 0.0132	 0.033932	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	797	 75727	 0.020192	 0.078555	 0.00131	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	799	 800	 0.002255	 0.009028	 0.00227	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	800	 804	 0.002513	 0.01686	 0.00407	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75603	 800	 0.008886	 0.055218	 0.01559	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	800	 75727	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	800	 75727	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	801	 802	 0.009741	 0.027939	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 75728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	804	 75728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75727	 805	 0.048508	 0.053353	 0.00071	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	806	 807	 0.00358	 0.01811	 0.00032	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75728	 806	 0.008134	 0.036244	 0.00062	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	808	 811	 0.000798	 0.00239	 0.00054	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	808	 75729	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	808	 75729	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	809	 810	 0.001912	 0.005068	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	809	 75730	 0.002624	 0.010208	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	810	 817	 0.003022	 0.01008	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	811	 75730	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	811	 75730	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	812	 819	 0.002334	 0.010284	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75446	 812	 0.000749	 0.00697	 0.00013	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75729	 812	 0.002943	 0.011039	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	813	 815	 0.004211	 0.012932	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75730	 813	 0.003179	 0.014079	 0.00032	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	814	 815	 0.003669	 0.007508	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	814	 75734	 0.005662	 0.013408	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	816	 831	 0.021173	 0.023288	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	816	 834	 0.027653	 0.036344	 0.0005	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	817	 818	 0.003504	 0.007171	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	818	 75735	 0.008871	 0.022559	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	819	 820	 0.003864	 0.015033	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	820	 75735	 0.008486	 0.022492	 0.00057	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	821	 75731	 0.009276	 0.007341	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75446	 822	 0.010109	 0.020015	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	823	 824	 0.001791	 0.006144	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	823	 75731	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	823	 75731	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	824	 826	 0.001018	 0.004142	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	825	 75732	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	825	 75732	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	826	 75733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	826	 75733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	827	 828	 0.018062	 0.011693	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	828	 75734	 0.002013	 0.008922	 0.00027	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75716	 829	 0.016556	 0.051756	 0.01499	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	829	 75734	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	829	 75734	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	830	 831	 0.026092	 0.016892	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	831	 837	 0.009818	 0.025238	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75734	 831	 0.006981	 0.020023	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	832	 834	 0.017377	 0.013752	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	833	 834	 0.01758	 0.012934	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	834	 75735	 0.004383	 0.017118	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	835	 75735	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	835	 75735	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	836	 837	 0.024573	 0.041396	 0.00059	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75723	 836	 0.034659	 0.050504	 0.00114	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	837	 838	 0.053836	 0.042199	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	839	 75736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	839	 75736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	840	 75737	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	840	 75737	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	841	 75738	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	841	 75738	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	842	 896	 0.009305	 0.024158	 0.00586	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	843	 844	 0.036749	 0.037524	 0.00058	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	844	 904	 0.034787	 0.045271	 0.00063	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	844	 75753	 0.077923	 0.061081	 0.00078	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 852	 0.001238	 0.004246	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 900	 0.001154	 0.004619	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 8079	 0.028059	 0.18851	 0.0456	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 845	 0.004347	 0.017948	 0.00425	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75448	 845	 0.003028	 0.0198	 0.00503	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 75739	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	845	 75739	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	846	 847	 0.001109	 0.005413	 9e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	846	 848	 0.002392	 0.009573	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75739	 847	 0.002261	 0.01285	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	848	 849	 0.001823	 0.007295	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75461	 849	 0.006446	 0.025079	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	850	 853	 0.000258	 0.004057	 0.00216	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	851	 852	 0.001838	 0.007223	 0.00189	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 851	 0.002379	 0.009349	 0.00245	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 853	 0.000395	 0.005764	 0.00358	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	854	 855	 0.017846	 0.045876	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75449	 854	 0.010638	 0.024694	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75739	 855	 0.014211	 0.054673	 0.00093	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	856	 857	 0.003551	 0.010285	 0.00248	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	856	 902	 0.004264	 0.011448	 0.00259	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	856	 75740	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	856	 75740	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	857	 895	 0.006356	 0.016501	 0.00401	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	858	 860	 0.002075	 0.008306	 0.00209	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	858	 888	 0.002671	 0.009717	 0.00297	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	859	 75741	 0.024361	 0.047744	 0.00072	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	860	 861	 0.001683	 0.007124	 0.0016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	861	 864	 0.002244	 0.010696	 0.0031	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	861	 75741	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	861	 75741	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75741	 862	 0.010115	 0.018527	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	863	 864	 0.001085	 0.004979	 0.00128	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	863	 891	 0.003391	 0.015813	 0.00392	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	864	 901	 0.001453	 0.009359	 0.00245	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	864	 936	 0.016601	 0.06526	 0.01708	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75448	 864	 0.002782	 0.021685	 0.00648	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	864	 75742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	864	 75742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	865	 866	 0.02155	 0.013951	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75742	 866	 0.016161	 0.024757	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	867	 75743	 0.017331	 0.10655	 0.00192	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	867	 76412	 0.07237	 0.2816	 0.0047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	868	 869	 0.001954	 0.014638	 0.00357	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	868	 884	 0.004036	 0.025563	 0.00694	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75448	 869	 0.001098	 0.00827	 0.00229	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 75743	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	869	 75743	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	869	 75755	 0.001211	 0.010565	 0.0029	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	870	 75747	 0.052235	 0.040945	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	871	 75754	 0.030885	 0.024209	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	872	 873	 0.027625	 0.01997	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75461	 873	 0.005952	 0.0095	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	874	 875	 5.4e-05	 0.00075	 0.0127	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	874	 75744	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	874	 75744	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	875	 75745	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	876	 878	 0.001009	 0.006596	 0.00168	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75745	 876	 0.001135	 0.008026	 0.0022	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	876	 75747	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	876	 75747	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75747	 877	 0.040207	 0.031819	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	878	 882	 0.000917	 0.005807	 0.00158	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	879	 3302	 0.005405	 0.026374	 0.00046	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	879	 75748	 0.007017	 0.039889	 0.00072	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	880	 881	 0.002175	 0.012742	 0.00347	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	880	 3301	 0.001021	 0.005663	 0.00172	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	881	 882	 0.001415	 0.009483	 0.00291	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	881	 75748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	881	 75748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	882	 75749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	882	 75749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75748	 883	 0.070743	 0.055452	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	884	 3300	 0.003954	 0.025044	 0.0068	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	885	 886	 0.099781	 0.078967	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	886	 75750	 0.034096	 0.061521	 0.00089	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	887	 888	 0.003325	 0.011404	 0.00273	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	887	 75750	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	887	 75750	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	888	 75751	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	888	 75751	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	888	 75755	 0.007006	 0.055204	 0.01615	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	889	 890	 0.084987	 0.065192	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	889	 943	 0.10981	 0.086906	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75751	 889	 0.024216	 0.057343	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	891	 898	 0.00602	 0.029216	 0.00668	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	892	 893	 0.027561	 0.043993	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	892	 907	 0.092437	 0.068011	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	893	 894	 0.11571	 0.091578	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75680	 893	 0.089247	 0.17672	 0.00259	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	894	 75752	 0.050878	 0.09145	 0.00164	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	895	 75752	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	895	 75752	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75434	 896	 0.006274	 0.022179	 0.005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	896	 75753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	896	 75753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75753	 897	 0.056258	 0.050758	 0.00085	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	898	 937	 0.005433	 0.019009	 0.0063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	899	 75756	 0.031806	 0.032477	 0.00051	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 900	 0.003351	 0.018454	 0.00666	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	900	 75754	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	900	 75754	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	900	 75755	 0.001276	 0.008079	 0.00219	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75448	 901	 0.001905	 0.014279	 0.00348	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75448	 902	 0.001727	 0.00537	 0.00112	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75435	 903	 0.053811	 0.058612	 0.0008	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	904	 905	 0.017519	 0.02856	 0.00044	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75435	 905	 0.011747	 0.027817	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75433	 906	 0.000643	 0.007544	 0.03042	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	906	 75755	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75756	 906	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	908	 928	 0.033375	 0.068301	 0.00168	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	909	 75757	 0.09463	 0.074177	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 927	 0.010905	 0.029691	 0.00654	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	911	 912	 0.023814	 0.015417	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	912	 913	 0.01261	 0.024713	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	912	 915	 0.023897	 0.018912	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	913	 914	 0.00921	 0.023675	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	913	 920	 0.024312	 0.056444	 0.00084	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	914	 916	 0.014922	 0.02237	 0.00041	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	915	 917	 0.030579	 0.028166	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	916	 917	 0.012933	 0.032101	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 926	 0.02354	 0.067517	 0.00104	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	918	 921	 0.019192	 0.049334	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	918	 75759	 0.11682	 0.1285	 0.00172	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	919	 926	 0.077046	 0.060974	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	920	 921	 0.026236	 0.067444	 0.00104	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	920	 923	 0.037193	 0.086337	 0.00164	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	920	 75759	 0.10843	 0.21252	 0.00319	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	921	 935	 0.1376	 0.099474	 0.00151	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	922	 1811	 0.030353	 0.039892	 0.00055	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	923	 924	 0.058772	 0.046512	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75668	 923	 0.013024	 0.045599	 0.00126	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	925	 934	 0.048495	 0.12037	 0.002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75462	 925	 0.035723	 0.088668	 0.00147	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	926	 75759	 0.026161	 0.071469	 0.00121	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	927	 936	 0.007776	 0.019547	 0.00506	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	927	 75757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	927	 75757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	928	 75760	 0.038045	 0.075326	 0.00111	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 930	 0.004221	 0.011155	 0.00261	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 941	 0.003896	 0.015598	 0.00393	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 75758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	929	 75758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	931	 75759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	931	 75759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75758	 932	 0.008499	 0.047823	 0.00103	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	932	 75760	 0.005871	 0.036072	 0.00082	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 935	 0.068969	 0.054582	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	934	 2775	 0.047162	 0.11994	 0.0019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	935	 1812	 0.053964	 0.10685	 0.00157	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	935	 75992	 0.073913	 0.19002	 0.00294	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	936	 937	 0.002831	 0.007893	 0.00166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	936	 75760	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	936	 75760	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	937	 75761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	937	 75761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75760	 938	 0.025747	 0.065478	 0.00104	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75761	 938	 0.015235	 0.043695	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	938	 75766	 0.04788	 0.18628	 0.00311	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	939	 940	 0.013473	 0.010662	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75760	 940	 0.010682	 0.020935	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	941	 949	 0.006576	 0.036084	 0.00954	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	941	 75762	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	941	 75762	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75762	 942	 0.017825	 0.047245	 0.0012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	942	 75763	 0.040039	 0.10142	 0.00201	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	944	 948	 0.04258	 0.066439	 0.00111	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75762	 944	 0.062511	 0.099784	 0.0023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	945	 951	 0.0025	 0.019012	 0.00597	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	945	 2759	 0.003324	 0.028311	 0.00706	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	946	 75764	 0.097686	 0.063244	 0.0012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	947	 75764	 0.060261	 0.11932	 0.00175	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	948	 75763	 0.13651	 0.10701	 0.00137	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75441	 949	 0.004627	 0.016833	 0.00515	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	949	 75763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	949	 75763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 2767	 0.005257	 0.037187	 0.0102	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75441	 950	 0.001647	 0.014026	 0.0035	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	950	 75764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	950	 75764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75441	 951	 0.001312	 0.011626	 0.00309	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	952	 3238	 0.019268	 0.094027	 0.00162	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	952	 75765	 0.008683	 0.04879	 0.0009	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	953	 955	 0.007918	 0.019904	 0.00516	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75441	 953	 0.003097	 0.007786	 0.00202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	953	 75765	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	953	 75765	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	954	 957	 0.019065	 0.073347	 0.00125	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75765	 954	 0.020415	 0.061447	 0.0012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 75766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	955	 75766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	956	 957	 0.021993	 0.073367	 0.00116	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	956	 959	 0.039315	 0.091277	 0.00136	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75751	 956	 0.014932	 0.10132	 0.00189	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75762	 956	 0.038152	 0.1335	 0.00277	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 958	 0.018543	 0.042601	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	958	 959	 0.013745	 0.054533	 0.00156	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75459	 958	 0.008773	 0.039094	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75750	 959	 0.009126	 0.066705	 0.00123	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	960	 75767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	960	 75767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	961	 75768	 0.002112	 0.008218	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	961	 75771	 0.002159	 0.008398	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 982	 0.041542	 0.064821	 0.00108	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 984	 0.088731	 0.23524	 0.00597	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 75770	 0.020748	 0.084796	 0.00172	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	963	 968	 0.000978	 0.003843	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	963	 75768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	963	 75768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75768	 964	 0.004831	 0.016117	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 75770	 0.011641	 0.030853	 0.00078	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	965	 75771	 0.018382	 0.014547	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	966	 75770	 0.018268	 0.060942	 0.00097	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	966	 75801	 0.13908	 0.10902	 0.0014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	967	 1157	 0.001256	 0.02205	 0.2362	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	967	 75769	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75769	 968	 0.00284	 0.013029	 0.00334	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	969	 972	 0.000749	 0.002647	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	969	 75771	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	969	 75771	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	970	 977	 0.003135	 0.01108	 0.0025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	971	 972	 0.000777	 0.003113	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	971	 976	 0.002741	 0.011155	 0.00272	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	971	 75772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	971	 75772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	972	 974	 0.003681	 0.01558	 0.00351	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 75773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	972	 75773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75772	 973	 0.029903	 0.023665	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75773	 973	 0.015685	 0.012413	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	974	 978	 0.003925	 0.013224	 0.00329	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	974	 75774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	974	 75774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75772	 975	 0.009402	 0.016793	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	975	 75775	 0.023372	 0.027396	 0.00048	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75514	 976	 0.018014	 0.12861	 0.03991	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 75775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	976	 75775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	977	 987	 0.005329	 0.019296	 0.00414	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	978	 979	 0.004495	 0.012067	 0.00273	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	978	 980	 0.006409	 0.019194	 0.00432	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	979	 75776	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	979	 75776	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	980	 1054	 0.012264	 0.037242	 0.00816	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	981	 1066	 0.073906	 0.14154	 0.00223	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75770	 981	 0.033856	 0.087031	 0.00135	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	983	 987	 0.007394	 0.029605	 0.00746	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	983	 75777	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	983	 75777	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75526	 984	 0.020045	 0.049064	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	985	 1119	 0.095685	 0.075726	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75526	 985	 0.022271	 0.017625	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	986	 1119	 0.19254	 0.12467	 0.00237	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75777	 986	 0.051367	 0.1017	 0.00149	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	988	 1116	 0.0327	 0.10791	 0.00175	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75775	 988	 0.018709	 0.063911	 0.00139	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 990	 0.36835	 0.29164	 0.00367	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 996	 0.29129	 0.23059	 0.0029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	990	 991	 0.18134	 0.18319	 0.00243	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	991	 992	 0.14542	 0.094156	 0.00179	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 75778	 0.20984	 0.13588	 0.00259	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	993	 995	 0.065956	 0.17146	 0.04168	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	993	 75778	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	993	 75778	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	995	 75779	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	995	 75779	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	996	 998	 0.18368	 0.14538	 0.00183	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75779	 996	 0.15564	 0.30824	 0.00453	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75779	 997	 0.2379	 0.24034	 0.00318	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	997	 75780	 0.12107	 0.13188	 0.0018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	999	 1001	 0.12246	 0.093937	 0.00126	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1000	 1003	 0.045051	 0.07191	 0.00166	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1002	 1004	 0.058503	 0.11583	 0.0017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1003	 75780	 0.045432	 0.11679	 0.00181	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1004	 75780	 0.020645	 0.042248	 0.00104	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1005	 75780	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1005	 75780	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75780	 1006	 0.13731	 0.15104	 0.00202	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1007	 1010	 0.42852	 0.30376	 0.0048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75780	 1007	 0.25528	 0.33565	 0.0046	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1007	 75782	 0.56801	 0.41841	 0.00612	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1008	 1010	 0.23523	 0.18619	 0.00234	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1008	 75781	 0.025757	 0.050479	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1009	 75781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1009	 75781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1010	 1012	 0.39679	 0.40105	 0.00531	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75781	 1010	 0.16668	 0.13192	 0.00166	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1010	 75782	 0.27061	 0.26155	 0.0038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1011	 1213	 0.044595	 0.12926	 0.03121	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1011	 75782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1011	 75782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75532	 1012	 0.35101	 0.25386	 0.00385	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1012	 75834	 0.65552	 0.54086	 0.01096	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1013	 1032	 0.002127	 0.012457	 0.00339	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1013	 75783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1013	 75783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1013	 75786	 0.000843	 0.004936	 0.00134	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75783	 1014	 0.0102	 0.007225	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1015	 1017	 0.002191	 0.007308	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1015	 1021	 0.007549	 0.017526	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1015	 75793	 0.00802	 0.016857	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1016	 1017	 0.003173	 0.008387	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75783	 1016	 0.002694	 0.007646	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1017	 1022	 0.004145	 0.009479	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1018	 1021	 0.009519	 0.007533	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1019	 1020	 0.005876	 0.003804	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1019	 1021	 0.004565	 0.010598	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75527	 1019	 0.008928	 0.010884	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75783	 1021	 0.008758	 0.029217	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 75791	 0.006851	 0.038496	 0.00071	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1022	 1027	 0.011425	 0.029609	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1022	 75784	 0.007129	 0.014983	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1023	 1025	 0.015202	 0.01203	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1024	 75784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1024	 75784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1024	 75786	 0.001733	 0.004581	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 1026	 0.005431	 0.016347	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75784	 1025	 0.006115	 0.015847	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1026	 75788	 0.007029	 0.018581	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 75790	 0.011044	 0.042965	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1028	 1034	 0.025657	 0.050799	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1028	 75785	 0.005818	 0.017847	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1029	 1030	 0.002412	 0.006765	 0.00174	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1029	 75785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1029	 75785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1030	 75786	 0.001395	 0.004786	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1031	 1033	 0.000106	 0.001904	 0.01955	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1031	 75786	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1031	 75786	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1032	 1045	 0.003429	 0.01664	 0.0038	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75521	 1032	 0.002061	 0.023983	 0.00705	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 1037	 0.002553	 0.01239	 0.00283	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 75787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1035	 75787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75787	 1036	 0.013639	 0.022747	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1037	 75788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1037	 75788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1037	 75789	 0.000991	 0.006647	 0.0016	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1038	 75789	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75790	 1038	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75513	 1039	 0.002753	 0.013027	 0.00313	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1039	 75791	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1039	 75791	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1039	 75803	 0.004451	 0.018376	 0.00435	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1040	 1043	 0.000979	 0.003919	 0.00099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75513	 1040	 0.004836	 0.021049	 0.006	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1041	 75793	 0.002957	 0.006635	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1041	 75794	 0.017734	 0.035113	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1042	 1077	 0.013152	 0.037721	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1042	 75792	 0.007132	 0.022967	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1043	 1045	 0.001854	 0.007421	 0.00187	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1043	 75792	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1043	 75792	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1044	 75793	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1044	 75793	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1045	 75794	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1045	 75794	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1046	 1078	 0.037488	 0.086127	 0.00131	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75794	 1046	 0.016967	 0.037552	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1047	 1048	 0.002289	 0.007712	 0.00192	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75513	 1047	 0.002931	 0.0089	 0.00195	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1048	 1073	 0.012515	 0.035108	 0.00904	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1048	 1278	 0.007835	 0.020707	 0.00485	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75513	 1048	 0.004745	 0.015476	 0.00411	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1048	 75795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1048	 75795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1049	 1060	 0.028698	 0.064386	 0.00103	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75795	 1049	 0.028172	 0.071646	 0.00113	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1049	 75802	 0.078121	 0.076438	 0.00108	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1050	 1051	 0.076406	 0.059892	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75522	 1050	 0.042804	 0.076936	 0.00138	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1051	 1052	 0.043213	 0.047529	 0.00063	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1051	 1055	 0.030605	 0.060595	 0.00089	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75522	 1052	 0.009183	 0.032806	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1052	 75796	 0.023117	 0.088939	 0.00152	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1053	 75796	 0.060437	 0.04783	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1054	 1074	 0.00243	 0.020179	 0.00789	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75521	 1054	 0.002972	 0.026987	 0.00879	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1054	 75796	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1054	 75796	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1055	 75801	 0.062242	 0.11231	 0.00162	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1056	 1057	 0.004136	 0.010932	 0.00256	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1056	 1058	 0.005878	 0.015534	 0.00364	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1057	 1065	 0.008704	 0.023367	 0.0053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75521	 1057	 0.01532	 0.055478	 0.0119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1058	 75797	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1058	 75797	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1059	 1060	 0.026947	 0.055144	 0.00136	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75797	 1059	 0.027398	 0.050943	 0.00119	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75787	 1060	 0.03678	 0.066109	 0.00119	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1061	 1252	 0.00312	 0.043263	 0.4339	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1061	 75798	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1062	 1064	 0.038681	 0.058667	 0.00084	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1062	 1233	 0.049973	 0.14334	 0.0022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75522	 1062	 0.034102	 0.19163	 0.00355	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1062	 75800	 0.01079	 0.031728	 0.00065	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75798	 1063	 0.003711	 0.010748	 0.00259	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1063	 75800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1063	 75800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75796	 1064	 0.014147	 0.073568	 0.00159	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75800	 1064	 0.019446	 0.064174	 0.00104	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75769	 1065	 0.010433	 0.031404	 0.00983	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1065	 75801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1065	 75801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1066	 1067	 0.097166	 0.062907	 0.0012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1066	 1068	 0.074001	 0.14652	 0.00215	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1066	 1070	 0.29041	 0.29344	 0.00389	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75787	 1066	 0.14032	 0.27789	 0.00408	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75797	 1066	 0.055855	 0.10231	 0.00177	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1069	 1070	 0.053699	 0.098357	 0.0017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1069	 1166	 0.03901	 0.10028	 0.00155	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 1072	 0.2104	 0.16653	 0.0021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1072	 1280	 0.071351	 0.092858	 0.0013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1072	 75802	 0.025684	 0.089869	 0.00186	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1073	 75802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1073	 75802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1074	 1075	 0.001281	 0.011928	 0.00369	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75798	 1075	 0.002495	 0.021611	 0.00776	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1076	 75803	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75804	 1076	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1076	 76044	 0.019991	 0.14099	 0.24207	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1077	 1078	 0.019491	 0.044778	 0.00068	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75804	 1077	 0.029947	 0.06849	 0.00167	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1078	 75854	 0.016751	 0.058651	 0.00162	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1079	 1083	 0.11738	 0.27257	 0.00405	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1079	 1243	 0.036144	 0.16174	 0.00333	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75524	 1079	 0.043575	 0.19419	 0.0033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75524	 1080	 0.3054	 0.24176	 0.00304	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75524	 1081	 0.3559	 0.23054	 0.00439	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1082	 1083	 0.068865	 0.22976	 0.00364	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1082	 75820	 0.048647	 0.1623	 0.00257	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1083	 1085	 0.03391	 0.089879	 0.00228	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 1085	 0.16381	 0.11005	 0.00194	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1085	 75805	 0.11095	 0.18693	 0.00266	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1086	 75805	 0.1416	 0.10237	 0.00155	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1087	 75805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1087	 75805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1088	 1190	 0.40527	 0.31785	 0.00408	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1089	 75807	 0.12163	 0.20317	 0.00345	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1089	 75830	 0.058686	 0.10749	 0.00186	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 1096	 0.04261	 0.11961	 0.03081	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75511	 1090	 0.003709	 0.022431	 0.00572	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75515	 1090	 0.020413	 0.055582	 0.01225	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 75806	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1090	 75806	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75806	 1091	 0.1347	 0.1066	 0.00134	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1092	 1093	 0.007971	 0.02479	 0.00517	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1092	 75807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1092	 75807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1093	 1191	 0.021014	 0.065359	 0.01364	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1094	 1104	 0.19473	 0.12609	 0.0024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1095	 1271	 0.053267	 0.14119	 0.00358	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1095	 75808	 0.046372	 0.17842	 0.00305	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1096	 75808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1096	 75808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75808	 1097	 0.098923	 0.078289	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1098	 1099	 0.20841	 0.16495	 0.00208	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75808	 1098	 0.073447	 0.14543	 0.00213	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75806	 1100	 0.094166	 0.2154	 0.00526	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75807	 1100	 0.096431	 0.14053	 0.00318	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1101	 1102	 0.069009	 0.12832	 0.003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75512	 1101	 0.041221	 0.12659	 0.00238	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1102	 1103	 0.071888	 0.1409	 0.00211	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1103	 1145	 0.12193	 0.18282	 0.00332	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75807	 1104	 0.011673	 0.071767	 0.00129	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75808	 1104	 0.043487	 0.14508	 0.0023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1105	 1109	 0.02661	 0.052685	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1105	 1124	 0.023458	 0.11032	 0.00205	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1105	 75809	 0.013886	 0.070245	 0.00122	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 75809	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1106	 75809	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1107	 1108	 0.00766	 0.021969	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1107	 1112	 0.015781	 0.045263	 0.0007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75809	 1107	 0.014705	 0.038873	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1108	 1111	 0.009369	 0.022187	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1109	 75810	 0.044004	 0.10216	 0.00152	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1110	 1146	 0.01247	 0.036766	 0.00855	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1110	 75810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1110	 75810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1111	 1113	 0.031846	 0.073936	 0.0011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1112	 1118	 0.027083	 0.085996	 0.00151	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75810	 1113	 0.073373	 0.12237	 0.00178	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1114	 1115	 0.066899	 0.048361	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1115	 1226	 0.11044	 0.086568	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75810	 1115	 0.027271	 0.058223	 0.00131	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1116	 1117	 0.039453	 0.10034	 0.00159	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1117	 1118	 0.025192	 0.089998	 0.00179	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75526	 1117	 0.090033	 0.25828	 0.00397	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75526	 1120	 0.21455	 0.1646	 0.00221	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1121	 1122	 0.024792	 0.096448	 0.00161	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75805	 1121	 0.052437	 0.20402	 0.00341	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1122	 1123	 0.018313	 0.080688	 0.0014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1123	 1135	 0.020327	 0.12497	 0.00225	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75809	 1123	 0.029339	 0.0901	 0.00169	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 1126	 0.014038	 0.067731	 0.0012	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1125	 1146	 0.010199	 0.027768	 0.00612	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1125	 1256	 0.019358	 0.051976	 0.01178	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1126	 75813	 0.020429	 0.10623	 0.0023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1127	 75811	 0.12968	 0.095418	 0.0014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1127	 75813	 0.15721	 0.11912	 0.00164	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1128	 1129	 0.008475	 0.022399	 0.00524	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1128	 1240	 0.01359	 0.034163	 0.00885	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1129	 1130	 0.0078	 0.020251	 0.00492	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1129	 75811	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1129	 75811	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1130	 1131	 0.00441	 0.012007	 0.00265	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1130	 75812	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1130	 75812	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1131	 75813	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1131	 75813	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1132	 1133	 0.002651	 0.007118	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1132	 1248	 0.007823	 0.020675	 0.00484	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1132	 75814	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1132	 75814	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1133	 1134	 0.003165	 0.009842	 0.00205	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1133	 75815	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1133	 75815	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1134	 75816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1134	 75816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75816	 1135	 0.008499	 0.043243	 0.00098	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1135	 75846	 0.11861	 0.19445	 0.00343	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1136	 1139	 0.005467	 0.015335	 0.00395	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1136	 1254	 0.00871	 0.029878	 0.00716	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1137	 1255	 0.26327	 0.20839	 0.00262	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1137	 75817	 0.090106	 0.17661	 0.00265	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1138	 1141	 0.004721	 0.018901	 0.00476	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1138	 1147	 0.003315	 0.026119	 0.00764	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1138	 75817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1138	 75817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1138	 75847	 0.033756	 0.13526	 0.03411	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1139	 1141	 0.004743	 0.013305	 0.00342	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1140	 1142	 0.024538	 0.048583	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1140	 75818	 0.008211	 0.03637	 0.00083	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1141	 75818	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1141	 75818	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1142	 1145	 0.21575	 0.26309	 0.00422	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1143	 1144	 0.10122	 0.080105	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75817	 1144	 0.18774	 0.13573	 0.00206	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 1148	 0.006489	 0.025981	 0.00655	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 1151	 0.012471	 0.049936	 0.01258	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1148	 1149	 0.006572	 0.02498	 0.00699	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1149	 1150	 0.005627	 0.022531	 0.00568	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1150	 1231	 0.009035	 0.038241	 0.00861	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1151	 1152	 0.004695	 0.018798	 0.00474	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1152	 1153	 0.004305	 0.01752	 0.00427	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 1154	 0.003894	 0.015307	 0.004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1154	 1232	 0.009901	 0.038915	 0.01018	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1155	 1156	 0.030352	 0.080238	 0.01879	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1155	 2826	 0.026738	 0.11322	 0.02549	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1155	 75819	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1155	 75819	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1156	 75820	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1156	 75820	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1157	 75821	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75525	 1158	 0.006079	 0.01411	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75820	 1158	 0.036855	 0.11093	 0.00217	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75822	 1158	 0.02888	 0.057181	 0.00084	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1159	 1160	 0.009823	 0.035569	 0.00763	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1160	 1163	 0.008819	 0.034662	 0.00907	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1161	 1162	 0.20543	 0.16259	 0.00205	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75822	 1161	 0.014031	 0.1066	 0.00243	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1161	 76294	 0.037684	 0.28011	 0.00668	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1163	 1164	 0.005884	 0.023558	 0.00593	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 1167	 0.006155	 0.02419	 0.00633	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 75823	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1164	 75823	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75823	 1165	 0.13329	 0.10549	 0.00133	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75823	 1166	 0.10461	 0.16026	 0.00225	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1166	 75824	 0.044188	 0.14742	 0.00234	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75821	 1167	 0.017204	 0.077481	 0.02062	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1167	 75824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1167	 75824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75824	 1168	 0.13722	 0.18036	 0.00247	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1169	 2799	 0.17121	 0.11085	 0.00211	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1170	 1171	 0.16983	 0.13441	 0.00169	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1171	 1281	 0.10252	 0.13342	 0.00187	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1172	 1173	 0.001687	 0.006754	 0.0017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1172	 1174	 0.000872	 0.003489	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1172	 75825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1172	 75825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1173	 1214	 0.003105	 0.010976	 0.00247	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75515	 1173	 0.00091	 0.006817	 0.00166	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1174	 1175	 0.000772	 0.003091	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1175	 75826	 0.001524	 0.006101	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75825	 1176	 0.00946	 0.01449	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1177	 75826	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1177	 75826	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1178	 1216	 0.048986	 0.096006	 0.00144	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1178	 75837	 0.008994	 0.04389	 0.00076	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1179	 1240	 0.02767	 0.10881	 0.02849	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75826	 1179	 0.003152	 0.022677	 0.00601	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1179	 75827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1179	 75827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75512	 1180	 0.05694	 0.15557	 0.00264	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1181	 1182	 0.016456	 0.026974	 0.00048	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75825	 1181	 0.01347	 0.026669	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1182	 1183	 0.029482	 0.041852	 0.00069	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75806	 1182	 0.19989	 0.14708	 0.00215	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75516	 1183	 0.01271	 0.032672	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1184	 1189	 0.005	 0.032206	 0.00844	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75515	 1184	 0.001017	 0.004429	 0.00126	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1184	 75828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1184	 75828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1185	 1187	 0.010767	 0.027678	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75828	 1185	 0.008843	 0.044994	 0.00102	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1186	 1187	 0.02007	 0.049127	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75828	 1186	 0.016027	 0.050889	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1187	 1188	 0.010625	 0.035444	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1187	 75829	 0.012064	 0.057908	 0.00173	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1189	 75829	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1189	 75829	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75515	 1191	 0.007643	 0.02622	 0.00628	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1191	 75830	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1191	 75830	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1192	 1193	 0.008938	 0.027142	 0.00594	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75826	 1192	 0.005761	 0.018789	 0.00499	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1193	 1195	 0.012251	 0.035139	 0.00865	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1193	 75831	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1193	 75831	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1194	 1251	 0.14677	 0.11616	 0.00146	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1195	 1257	 0.014658	 0.039354	 0.00892	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1196	 1198	 0.046259	 0.097228	 0.00177	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1196	 75843	 0.048128	 0.16056	 0.00255	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1197	 1201	 0.11402	 0.12149	 0.00173	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75831	 1197	 0.07162	 0.089996	 0.00135	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1198	 1200	 0.11179	 0.12296	 0.00164	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1198	 75832	 0.085928	 0.10476	 0.00168	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 1215	 0.020312	 0.053689	 0.01257	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 1223	 0.016476	 0.043547	 0.01019	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 1237	 0.010816	 0.032392	 0.0073	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 75832	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1199	 75832	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1200	 75838	 0.10201	 0.091415	 0.00187	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1201	 1216	 0.1076	 0.10763	 0.00145	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1202	 1215	 0.01007	 0.027416	 0.00604	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1202	 75833	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1202	 75833	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75531	 1203	 0.081638	 0.18071	 0.00296	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75833	 1203	 0.20248	 0.16026	 0.00202	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1203	 75838	 0.15346	 0.247	 0.00387	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1204	 1205	 0.065428	 0.17344	 0.0044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75829	 1204	 0.063717	 0.1689	 0.00428	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1205	 75834	 0.044313	 0.14783	 0.00234	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75519	 1206	 0.16682	 0.13203	 0.00166	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75532	 1206	 0.32205	 0.2329	 0.00353	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75518	 1207	 0.051345	 0.13058	 0.00206	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1207	 75834	 0.085649	 0.15927	 0.00373	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1208	 75834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1208	 75834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1209	 1217	 0.061284	 0.0485	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75531	 1209	 0.019227	 0.034692	 0.0005	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75834	 1209	 0.064951	 0.1508	 0.00224	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75531	 1210	 0.093681	 0.10005	 0.00212	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1210	 75836	 0.31034	 0.40411	 0.00565	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1211	 1219	 0.048492	 0.13028	 0.02955	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1211	 75835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1211	 75835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75517	 1212	 0.000699	 0.002798	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1212	 75836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1212	 75836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1214	 75837	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1214	 75837	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1215	 75838	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1215	 75838	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75531	 1217	 0.019915	 0.015761	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1218	 1220	 0.064156	 0.17006	 0.00431	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75528	 1218	 0.063127	 0.18107	 0.00278	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1220	 1222	 0.082245	 0.18658	 0.00372	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1221	 1222	 0.23234	 0.18391	 0.00232	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1222	 75839	 0.058592	 0.10572	 0.00153	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1223	 75839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1223	 75839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1224	 1225	 0.016162	 0.041961	 0.01018	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1224	 75840	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1224	 75840	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75517	 1225	 0.039645	 0.10648	 0.02415	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1227	 1228	 0.071431	 0.099555	 0.0017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1228	 1229	 0.034172	 0.05234	 0.00091	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75800	 1228	 0.024421	 0.064557	 0.00117	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75799	 1229	 0.019177	 0.049298	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1230	 75841	 0.028842	 0.057105	 0.00084	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75798	 1231	 0.004061	 0.018283	 0.00486	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75798	 1232	 0.003603	 0.016529	 0.00423	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1232	 75841	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1232	 75841	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75841	 1233	 0.040347	 0.086464	 0.00151	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1234	 1235	 0.24418	 0.19144	 0.00246	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75528	 1234	 0.34686	 0.3481	 0.00563	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1236	 1242	 0.072913	 0.13964	 0.0022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1236	 75842	 0.17736	 0.16635	 0.00257	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1237	 1239	 0.014509	 0.037668	 0.00914	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 75843	 0.13061	 0.10337	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 1246	 0.014624	 0.038652	 0.00905	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 75842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1239	 75842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1240	 75843	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1240	 75843	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75842	 1241	 0.11122	 0.072006	 0.00137	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 75844	 0.067346	 0.17313	 0.00268	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1243	 1244	 0.033143	 0.12699	 0.00359	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75529	 1244	 0.010355	 0.048077	 0.00131	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1245	 1249	 0.011678	 0.030319	 0.00736	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1245	 75844	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1245	 75844	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1246	 1247	 0.006373	 0.014792	 0.00451	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 75845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1247	 75845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1249	 75846	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1249	 75846	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75846	 1250	 0.11948	 0.094562	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 75848	 0.061527	 0.14285	 0.00212	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1252	 75847	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1253	 1254	 0.009317	 0.032933	 0.00742	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75847	 1253	 0.010275	 0.039975	 0.01068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1253	 75849	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1253	 75849	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75849	 1255	 0.086404	 0.17109	 0.00251	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1256	 1257	 0.024314	 0.064268	 0.01505	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1257	 75850	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1257	 75850	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75848	 1258	 0.095363	 0.15548	 0.00237	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75849	 1258	 0.16996	 0.15657	 0.00251	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1259	 1260	 0.094193	 0.20188	 0.00354	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75519	 1259	 0.14496	 0.37279	 0.00577	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1260	 75851	 0.05158	 0.106	 0.00202	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1261	 75851	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1261	 75851	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1262	 1263	 0.20589	 0.1515	 0.00222	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75534	 1262	 0.055305	 0.13728	 0.00228	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 1264	 0.21182	 0.13716	 0.00261	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1264	 75852	 0.28938	 0.22908	 0.00288	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1265	 75852	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1265	 75852	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1266	 1268	 0.34938	 0.23481	 0.00414	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75534	 1266	 0.30229	 0.27286	 0.00457	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1267	 1268	 0.095527	 0.070284	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75852	 1267	 0.3111	 0.24628	 0.0031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75530	 1268	 0.039569	 0.069587	 0.00131	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 75853	 0.066797	 0.097338	 0.0022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1269	 75853	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1269	 75853	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1270	 1271	 0.061046	 0.15694	 0.00243	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75853	 1270	 0.060917	 0.14143	 0.0021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1272	 75855	 0.082731	 0.065474	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1273	 1274	 0.001901	 0.009062	 0.00263	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75803	 1273	 0.004814	 0.022451	 0.00556	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1273	 75854	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1273	 75854	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1274	 1286	 0.002059	 0.01196	 0.00282	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1274	 1288	 0.001453	 0.005818	 0.00147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1274	 75855	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1274	 75855	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1275	 75858	 0.057319	 0.04493	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75854	 1276	 0.029211	 0.030733	 0.00045	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75854	 1277	 0.022496	 0.044089	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1278	 1279	 0.007132	 0.016555	 0.00504	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1279	 1284	 0.009308	 0.025956	 0.00545	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1280	 1281	 0.21215	 0.16791	 0.00211	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1280	 1282	 0.1238	 0.087698	 0.00139	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 1282	 0.064605	 0.10884	 0.00155	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 75856	 0.044962	 0.11006	 0.00188	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1283	 1284	 0.012792	 0.033212	 0.00806	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1283	 2805	 0.012162	 0.032652	 0.0074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1284	 75856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1284	 75856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1285	 1295	 0.037688	 0.096882	 0.0015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1285	 75857	 0.042384	 0.098403	 0.00146	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75537	 1286	 0.011724	 0.073488	 0.05297	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1286	 75857	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1286	 75857	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1287	 75858	 0.012718	 0.012755	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1288	 1289	 0.00319	 0.010749	 0.00267	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1288	 75858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1288	 75858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1289	 1292	 0.005637	 0.01688	 0.0038	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75858	 1290	 0.046129	 0.084491	 0.00146	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75857	 1291	 0.083706	 0.060512	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1292	 1294	 0.006273	 0.018493	 0.0043	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1293	 75859	 0.076293	 0.081288	 0.00116	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1294	 1304	 0.006845	 0.023063	 0.00573	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1294	 75859	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1294	 75859	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1295	 75861	 0.022302	 0.051768	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1296	 75860	 0.035536	 0.035892	 0.00048	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1297	 1298	 0.004052	 0.01071	 0.00251	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1297	 75860	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1297	 75860	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1298	 1300	 0.004344	 0.0149	 0.00357	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1298	 75861	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1298	 75861	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1299	 1303	 0.035459	 0.082323	 0.00122	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75860	 1299	 0.018279	 0.036191	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75541	 1300	 0.018388	 0.081963	 0.02228	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 3065	 0.038346	 0.097523	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 76363	 0.019613	 0.068669	 0.0019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1302	 76361	 0.029	 0.1036	 0.00206	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1303	 76367	 0.037155	 0.18132	 0.00313	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1304	 1307	 0.011771	 0.047902	 0.01167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1304	 75862	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1304	 75862	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75862	 1305	 0.042406	 0.064961	 0.00091	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1306	 1308	 0.064825	 0.085201	 0.00117	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1306	 75863	 0.036783	 0.10189	 0.00168	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1307	 1310	 0.003497	 0.017242	 0.00466	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75541	 1309	 0.005419	 0.014321	 0.00335	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1309	 75863	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1309	 75863	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75542	 1311	 0.071146	 0.046061	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1312	 1314	 0.17849	 0.13134	 0.00192	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1312	 2386	 0.49515	 0.39218	 0.00494	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1313	 1316	 0.11517	 0.090276	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1315	 1316	 0.057722	 0.042468	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1316	 1317	 0.056194	 0.0897	 0.00207	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1317	 1318	 0.046081	 0.036468	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1317	 75865	 0.031965	 0.14166	 0.00425	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1319	 1320	 0.043818	 0.032238	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1319	 1324	 0.034334	 0.067289	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1321	 75864	 0.059434	 0.065371	 0.00087	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1322	 1324	 0.064784	 0.050781	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1323	 1333	 0.005732	 0.018696	 0.00496	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1323	 75864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1323	 75864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75864	 1324	 0.012552	 0.055304	 0.00096	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75864	 1325	 0.059394	 0.046556	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1326	 1331	 0.048443	 0.031362	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1327	 1328	 0.058885	 0.043324	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1328	 1329	 0.004778	 0.037243	 0.0007	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1328	 75865	 0.005072	 0.034814	 0.00063	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1329	 1330	 0.002989	 0.024869	 0.00047	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1330	 1334	 0.003645	 0.030325	 0.00057	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1331	 1332	 0.022039	 0.019748	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1332	 75865	 0.01541	 0.03051	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1333	 75865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1333	 75865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1333	 75876	 0.003165	 0.021235	 0.00513	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1334	 1335	 0.003234	 0.028504	 0.00062	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1335	 1336	 0.047814	 0.034565	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1335	 75877	 0.010504	 0.035882	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1335	 75877	 0.010504	 0.035882	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1337	 75877	 0.081733	 0.060135	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1338	 75866	 0.027753	 0.021963	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 1341	 0.031943	 0.032264	 0.00043	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 1342	 0.019622	 0.015529	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 75866	 0.006361	 0.016352	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1340	 75866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1340	 75866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1340	 75876	 0.00211	 0.005424	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 1343	 0.026788	 0.035207	 0.00048	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1343	 1345	 0.022242	 0.040132	 0.00058	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1344	 1346	 0.060921	 0.046156	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 75867	 0.018432	 0.039499	 0.00069	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1346	 75875	 0.025374	 0.050238	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75467	 1347	 0.013593	 0.009826	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 1349	 0.00356	 0.012213	 0.00293	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75466	 1348	 0.003412	 0.014947	 0.00514	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 75876	 0.007821	 0.035217	 0.00937	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1349	 1350	 0.003543	 0.009108	 0.00226	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1349	 75867	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1349	 75867	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1350	 1355	 0.004092	 0.011411	 0.0024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1350	 1365	 0.010019	 0.02648	 0.0062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1350	 75868	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1350	 75868	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1351	 75869	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1352	 2388	 0.002444	 0.017581	 0.00466	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75466	 1352	 0.000877	 0.007474	 0.00186	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 75871	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1352	 75871	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1353	 1354	 0.033828	 0.051814	 0.0009	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75870	 1353	 0.006847	 0.036481	 0.00064	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75466	 1355	 0.003393	 0.019288	 0.00558	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 75872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1355	 75872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1356	 1357	 0.051743	 0.040558	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75872	 1357	 0.043393	 0.088804	 0.00219	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1358	 1359	 0.002626	 0.00694	 0.00162	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1358	 1365	 0.004348	 0.011288	 0.00274	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1359	 1360	 0.002382	 0.006296	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1360	 1361	 0.00236	 0.006237	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1361	 75873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1361	 75873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1362	 1532	 0.010606	 0.028031	 0.00656	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75466	 1362	 0.027116	 0.07168	 0.01678	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 75874	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1362	 75874	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1363	 1364	 0.051007	 0.033022	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75868	 1363	 0.056584	 0.050704	 0.00104	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 75875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1365	 75875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75875	 1366	 0.060637	 0.047988	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1367	 75876	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1368	 1369	 0.001061	 0.002805	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1368	 1375	 0.002308	 0.00907	 0.00237	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1368	 75878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1368	 75878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1369	 1370	 0.00117	 0.00345	 0.0008	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1370	 75879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1370	 75879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1371	 1378	 0.013961	 0.048848	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1371	 1378	 0.013961	 0.048848	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75504	 1371	 0.008838	 0.036121	 0.00073	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75879	 1371	 0.003168	 0.019251	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1372	 1404	 0.068525	 0.053713	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75878	 1372	 0.020055	 0.046075	 0.0007	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75878	 1373	 0.013	 0.01019	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1374	 1376	 0.051997	 0.034928	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1375	 1380	 0.003704	 0.015292	 0.00362	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75878	 1376	 0.008967	 0.017755	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1377	 1379	 0.011395	 0.044331	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1377	 1379	 0.011395	 0.044331	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75504	 1377	 0.005799	 0.022558	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75504	 1377	 0.005799	 0.022558	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1378	 1390	 0.020498	 0.062882	 0.0017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1378	 1390	 0.020498	 0.062882	 0.0017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 1390	 0.014555	 0.089486	 0.00161	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 1398	 0.086538	 0.068487	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 1854	 0.038627	 0.1702	 0.00296	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1380	 4243	 0.003185	 0.05655	 0.02844	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1380	 75880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1380	 75880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1381	 1792	 0.017605	 0.11817	 0.02855	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1381	 75881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1381	 75881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1382	 1386	 0.006784	 0.018917	 0.00397	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1382	 75882	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1382	 75882	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1383	 75884	 0.037948	 0.060573	 0.0014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 1406	 0.003442	 0.008651	 0.00224	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75472	 1384	 0.009922	 0.026638	 0.00604	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 75883	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1384	 75883	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1385	 1388	 0.009376	 0.036073	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75883	 1385	 0.009109	 0.030061	 0.00049	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1386	 1406	 0.003399	 0.008984	 0.0021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1386	 75884	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1386	 75884	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1387	 1388	 0.003249	 0.016336	 0.00044	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1387	 1389	 0.002224	 0.010673	 0.00032	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1388	 1389	 0.005428	 0.032988	 0.00061	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75473	 1388	 0.028954	 0.11587	 0.00245	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1389	 1390	 0.014104	 0.054867	 0.00092	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1389	 1390	 0.014104	 0.054867	 0.00092	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1391	 1402	 0.07706	 0.060985	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75881	 1391	 0.10802	 0.085485	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 1393	 0.031055	 0.11094	 0.0022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 1403	 0.15605	 0.11482	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75881	 1392	 0.022437	 0.11417	 0.00259	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1394	 75885	 0.035938	 0.02817	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75473	 1395	 0.11028	 0.087275	 0.0011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1396	 1398	 0.1099	 0.083268	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75509	 1397	 0.14537	 0.10696	 0.00156	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1399	 1401	 0.16612	 0.13148	 0.00166	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1400	 1401	 0.1351	 0.13647	 0.00181	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1401	 1797	 0.16385	 0.16034	 0.00227	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75504	 1405	 0.001617	 0.007508	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1406	 75885	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1406	 75885	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1407	 1531	 0.016785	 0.022061	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1408	 2370	 0.003396	 0.008975	 0.0021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1408	 75886	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1408	 75886	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1408	 75894	 0.005734	 0.019671	 0.00471	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75886	 1409	 0.08224	 0.065085	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1409	 75890	 0.056418	 0.044649	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75886	 1410	 0.05575	 0.04412	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1410	 75891	 0.022611	 0.036862	 0.00056	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1411	 1412	 0.003712	 0.008616	 0.00262	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1411	 75887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1411	 75887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1412	 1418	 0.004153	 0.01044	 0.0027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1412	 75888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1412	 75888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1413	 1414	 0.002993	 0.007909	 0.00185	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1413	 1415	 0.005047	 0.013338	 0.00312	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1413	 75889	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1413	 75889	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1414	 2230	 0.005896	 0.015307	 0.00372	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1414	 75890	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1414	 75890	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1415	 75891	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1415	 75891	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1415	 75894	 0.00367	 0.012973	 0.00292	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 1422	 0.00505	 0.013346	 0.00312	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 75892	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1416	 75892	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75892	 1417	 0.010656	 0.035548	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1417	 75903	 0.017346	 0.036457	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1418	 1447	 0.004653	 0.012296	 0.00288	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1419	 2372	 0.003049	 0.011094	 0.0034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1419	 75894	 0.002048	 0.007165	 0.00237	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 2372	 0.004832	 0.015759	 0.00418	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 75893	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1420	 75893	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1421	 2234	 0.000884	 0.010053	 0.0908	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1421	 2357	 0.000473	 0.005266	 0.04966	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1421	 75894	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1422	 1423	 0.002807	 0.007872	 0.00203	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1423	 1428	 0.002672	 0.009313	 0.00216	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1424	 75896	 0.017243	 0.017416	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1425	 75896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1425	 75896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1426	 1429	 0.007725	 0.013013	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75896	 1426	 0.003036	 0.014817	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1427	 75897	 0.035179	 0.023631	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1428	 75897	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1428	 75897	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1430	 1431	 0.026752	 0.048083	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75506	 1430	 0.008509	 0.037918	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1431	 76174	 0.053515	 0.058861	 0.00079	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75491	 1432	 0.010975	 0.028212	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75491	 1433	 0.016641	 0.042778	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1433	 76175	 0.075734	 0.0833	 0.00111	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1434	 2391	 0.002742	 0.016062	 0.00438	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1434	 75898	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1434	 75898	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1434	 75908	 0.002093	 0.014022	 0.0043	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75898	 1435	 0.054127	 0.076839	 0.00126	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1436	 2287	 0.006582	 0.025606	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1436	 75899	 0.003887	 0.01512	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1437	 1439	 0.003727	 0.009368	 0.00243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1437	 75899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1437	 75899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75888	 1438	 0.065686	 0.042525	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75895	 1438	 0.18401	 0.15148	 0.00307	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75899	 1438	 0.003817	 0.023467	 0.00042	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1439	 1440	 0.002412	 0.0056	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1439	 75900	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1439	 75900	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1440	 1442	 0.003038	 0.008028	 0.00188	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1441	 76396	 0.010344	 0.021168	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1441	 76401	 0.05382	 0.11014	 0.00271	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1442	 1448	 0.003507	 0.009547	 0.0021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1442	 3202	 0.005839	 0.015432	 0.00361	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1442	 75901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1442	 75901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1443	 75902	 0.012241	 0.02242	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1444	 1447	 0.002971	 0.008284	 0.00174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1444	 75902	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1444	 75902	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1445	 1446	 0.004956	 0.014916	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75901	 1445	 0.003703	 0.016409	 0.00049	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75902	 1446	 0.007972	 0.010477	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1447	 75903	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1447	 75903	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1448	 1451	 0.003825	 0.012889	 0.0032	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 76394	 0.034626	 0.062237	 0.00112	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75549	 1450	 0.018734	 0.066926	 0.00133	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1451	 1452	 0.00549	 0.01988	 0.00427	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1452	 1482	 0.005292	 0.017259	 0.00458	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1453	 1484	 0.001998	 0.009699	 0.00222	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1453	 1485	 0.003827	 0.01532	 0.00386	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1454	 1456	 0.000821	 0.002766	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75486	 1454	 0.002958	 0.009647	 0.00256	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1454	 75904	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1454	 75904	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1455	 3145	 0.002505	 0.012669	 0.00025	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75487	 1455	 0.015812	 0.03671	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75904	 1455	 0.005594	 0.011447	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1456	 1457	 0.000905	 0.002434	 0.00068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1457	 1462	 0.001104	 0.002968	 0.00083	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75904	 1458	 0.025588	 0.016566	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 1460	 0.01077	 0.008523	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1460	 1466	 0.005316	 0.011391	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75904	 1460	 0.006196	 0.023242	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1461	 75905	 0.008806	 0.006238	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1462	 1464	 0.001182	 0.004054	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1462	 1472	 0.001006	 0.0027	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75486	 1462	 0.000918	 0.006494	 0.00178	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1462	 75905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1462	 75905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75905	 1463	 0.009621	 0.007078	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1464	 75906	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1464	 75906	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1465	 1466	 0.005517	 0.010813	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75906	 1465	 0.003106	 0.007985	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1466	 1467	 0.008558	 0.006772	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 1468	 0.007164	 0.005616	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75906	 1469	 0.008673	 0.017171	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1470	 1471	 0.006083	 0.004475	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1471	 75907	 0.004032	 0.003191	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1472	 75907	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1472	 75907	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1473	 1478	 0.007268	 0.018683	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1473	 75909	 0.009421	 0.047116	 0.00084	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1474	 1475	 0.006686	 0.009492	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75907	 1474	 0.011098	 0.028528	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1475	 1476	 0.010591	 0.007792	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1477	 75908	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1477	 75908	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1478	 1479	 0.035796	 0.028329	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1480	 1482	 0.003588	 0.012308	 0.00295	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75486	 1480	 0.000668	 0.005621	 0.00166	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1480	 75909	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1480	 75909	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75486	 1481	 0.002399	 0.005569	 0.0017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 76372	 0.003431	 0.009212	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75486	 1482	 0.003183	 0.016856	 0.00427	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1483	 76373	 0.027685	 0.036029	 0.0005	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1484	 1518	 0.00453	 0.01722	 0.00482	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1484	 75910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1484	 75910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1485	 1518	 0.00308	 0.020142	 0.00512	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1485	 75911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1485	 75911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75911	 1486	 0.10245	 0.066329	 0.00126	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1487	 1488	 0.002929	 0.007528	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1487	 1524	 0.028972	 0.038078	 0.00052	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1488	 75912	 0.006043	 0.023153	 0.00065	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1489	 1491	 0.001962	 0.007856	 0.00198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75908	 1489	 0.002842	 0.024377	 0.00694	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1489	 75912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1489	 75912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1490	 1493	 0.008385	 0.005633	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1490	 75913	 0.005112	 0.013142	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 1492	 0.001175	 0.003277	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 2392	 0.01124	 0.027087	 0.00765	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 75913	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1491	 75913	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1492	 75914	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1492	 75914	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1494	 1495	 0.002933	 0.004576	 8e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75914	 1494	 0.002315	 0.006639	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1495	 1496	 0.009942	 0.007868	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1495	 1501	 0.003145	 0.007226	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1497	 1501	 0.013221	 0.013499	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1498	 1504	 0.029191	 0.022881	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1499	 1504	 0.001874	 0.006693	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1500	 1502	 0.013417	 0.010618	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1501	 1507	 0.012498	 0.022551	 0.00033	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1501	 1527	 0.00932	 0.01707	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1502	 1503	 0.002601	 0.00515	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1502	 1507	 0.01406	 0.011127	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1503	 1504	 0.004024	 0.007233	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1504	 1505	 0.011228	 0.008612	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1505	 1506	 0.004146	 0.008209	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1505	 1511	 0.004946	 0.009793	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1506	 1507	 0.008252	 0.005966	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1507	 75915	 0.003716	 0.00985	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1508	 1518	 0.004085	 0.01874	 0.0048	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1508	 1526	 0.005328	 0.01284	 0.00363	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1508	 75915	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1508	 75915	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1509	 1510	 0.007574	 0.005994	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75915	 1509	 0.007955	 0.006295	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1510	 1512	 0.013513	 0.010694	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1511	 1512	 0.012177	 0.009341	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1511	 1520	 0.004657	 0.011972	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1512	 1513	 0.003272	 0.008411	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1512	 1520	 0.004705	 0.011966	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1513	 1514	 0.002973	 0.004745	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1513	 1515	 0.014053	 0.011121	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 1515	 0.006399	 0.005016	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 1516	 0.005831	 0.011545	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1515	 1516	 0.003021	 0.007153	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75915	 1515	 0.00342	 0.006999	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1516	 1517	 0.004995	 0.010665	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75874	 1516	 0.084914	 0.21512	 0.00426	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75915	 1516	 0.006286	 0.016159	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1517	 1529	 0.016659	 0.042822	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 1528	 0.003631	 0.022564	 0.00637	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75908	 1518	 0.005324	 0.025374	 0.00735	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 75916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1518	 75916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75910	 1519	 0.01864	 0.066588	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 1521	 0.010992	 0.028256	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 1522	 0.040219	 0.030471	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75916	 1520	 0.011913	 0.052487	 0.00091	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1521	 1530	 0.006861	 0.026693	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1523	 1530	 0.09581	 0.075825	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1524	 1525	 0.05191	 0.04069	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1524	 76176	 0.10258	 0.074157	 0.00112	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75913	 1525	 0.004798	 0.009068	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1526	 1528	 0.001865	 0.006083	 0.00161	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1526	 2404	 0.002565	 0.01214	 0.00292	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1527	 75917	 0.003982	 0.015318	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1528	 75917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1528	 75917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75874	 1529	 0.076322	 0.19621	 0.00304	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75911	 1530	 0.009933	 0.056463	 0.00102	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1531	 76161	 0.013815	 0.035514	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1532	 75918	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1532	 75918	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1533	 1534	 0.10447	 0.081887	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75918	 1533	 0.014882	 0.035241	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75918	 1535	 0.1529	 0.098997	 0.00188	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1536	 2587	 0.05643	 0.044658	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1537	 1538	 0.017025	 0.012307	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1538	 1539	 0.030682	 0.024281	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1538	 75921	 0.011083	 0.028185	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1540	 1541	 0.008561	 0.021771	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1540	 75919	 0.005238	 0.017472	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1541	 1542	 0.008199	 0.01256	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 1543	 0.013748	 0.010115	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1544	 1546	 0.018903	 0.012238	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1544	 1547	 0.006932	 0.016094	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1544	 75919	 0.006141	 0.015786	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1545	 1551	 0.001463	 0.00502	 0.0012	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1545	 75919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1545	 75919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1547	 1549	 0.004266	 0.007932	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1548	 1549	 0.012318	 0.013548	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1549	 1550	 0.003202	 0.010682	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75507	 1550	 0.005075	 0.022612	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1551	 75920	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1551	 75920	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1552	 1588	 0.0048	 0.011143	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75920	 1552	 0.013311	 0.017494	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1553	 75921	 0.016564	 0.012187	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1554	 1555	 0.001226	 0.003615	 0.00084	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1554	 1574	 0.001782	 0.007757	 0.00221	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1554	 75921	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1554	 75921	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1555	 1586	 0.002201	 0.005992	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1556	 1578	 0.020741	 0.026992	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1557	 75923	 0.013918	 0.011015	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1558	 1559	 0.01164	 0.008564	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1559	 75922	 0.008583	 0.00944	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1560	 1561	 0.00063	 0.003059	 0.0007	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1560	 75922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1560	 75922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1561	 1562	 0.000383	 0.001533	 0.00039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1561	 75923	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1561	 75923	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1562	 1563	 0.000398	 0.001683	 0.00038	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1563	 1572	 0.000415	 0.001614	 0.00043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1564	 75924	 0.00778	 0.005037	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 75924	 0.012414	 0.009824	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1566	 1567	 0.010797	 0.00699	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1567	 1568	 0.008142	 0.006382	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1567	 75924	 0.003953	 0.011338	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1569	 1571	 0.008875	 0.005962	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1570	 1574	 0.002281	 0.006362	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1570	 75924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1570	 75924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1571	 75925	 0.005941	 0.010007	 0.00014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1572	 1574	 0.00084	 0.003468	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1572	 75925	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1572	 75925	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75922	 1573	 0.010099	 0.0073	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1575	 1577	 0.020345	 0.015948	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1576	 2584	 0.001247	 0.005721	 0.00147	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1577	 76043	 0.014438	 0.028585	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1578	 75926	 0.005239	 0.02038	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1579	 1993	 0.005093	 0.018002	 0.00406	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1579	 75926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1579	 75926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1580	 1583	 0.01708	 0.028773	 0.00041	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75926	 1580	 0.015937	 0.04213	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1581	 1582	 0.051332	 0.040236	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1582	 75927	 0.016066	 0.032877	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1584	 1586	 0.003165	 0.007956	 0.00206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1584	 1592	 0.00351	 0.009424	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1584	 75927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1584	 75927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1584	 76045	 0.006702	 0.041644	 0.01175	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1585	 1589	 0.011083	 0.025731	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75927	 1585	 0.006811	 0.016129	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1585	 75928	 0.007704	 0.019803	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1586	 75928	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1586	 75928	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75928	 1587	 0.010742	 0.018096	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1588	 1589	 0.003828	 0.008472	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1589	 1590	 0.00504	 0.009231	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75507	 1590	 0.004329	 0.011128	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1591	 1603	 0.025993	 0.020571	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1591	 75929	 0.004136	 0.016091	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1592	 75929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1592	 75929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1593	 1598	 0.005524	 0.016	 0.00386	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1593	 75930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1593	 75930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1594	 1595	 0.014097	 0.021596	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1594	 1596	 0.018994	 0.039921	 0.00073	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75927	 1595	 0.051097	 0.047066	 0.00075	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75930	 1595	 0.006413	 0.021393	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1595	 75932	 0.08874	 0.06956	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1596	 1658	 0.026647	 0.063099	 0.00115	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1597	 1684	 0.004128	 0.010378	 0.00269	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1597	 75931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1597	 75931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1598	 75936	 0.005749	 0.01695	 0.00394	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1599	 75932	 0.03728	 0.057102	 0.00099	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1600	 1601	 0.003522	 0.010952	 0.00229	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1600	 75936	 0.004482	 0.013212	 0.00307	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1601	 1602	 0.002074	 0.006211	 0.0014	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1602	 75932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1602	 75932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1603	 1604	 0.019051	 0.015077	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1604	 75933	 0.014155	 0.013676	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1605	 1615	 0.019013	 0.050255	 0.01176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1605	 75933	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1605	 75933	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1606	 1607	 0.019111	 0.015124	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75933	 1606	 0.010109	 0.020015	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1608	 1609	 0.079987	 0.060602	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75933	 1608	 0.017074	 0.04389	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 1619	 0.073809	 0.054304	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1610	 1611	 0.040947	 0.031409	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1610	 75934	 0.023748	 0.041764	 0.00078	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1612	 1616	 0.053686	 0.040675	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 1615	 0.001433	 0.003788	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 75934	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1613	 75934	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1613	 75961	 0.022032	 0.075597	 0.01812	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1614	 75935	 0.013282	 0.010063	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1615	 75935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1615	 75935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1616	 1617	 0.008841	 0.009724	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1617	 1618	 0.018898	 0.014955	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1617	 1620	 0.056999	 0.044679	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75935	 1617	 0.002722	 0.010213	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75935	 1619	 0.044041	 0.043264	 0.00073	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1621	 1623	 0.096898	 0.062734	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1622	 1623	 0.02397	 0.016979	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1623	 75937	 0.018238	 0.052308	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1624	 1697	 0.000172	 0.001879	 0.01844	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1624	 1940	 0.000952	 0.010984	 0.09631	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1624	 75936	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1625	 1634	 0.00061	 0.00166	 0.00037	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1625	 1637	 0.00116	 0.003235	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1625	 75938	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1625	 75938	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1626	 1627	 0.000814	 0.002152	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1626	 75939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1626	 75939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1627	 1628	 0.000644	 0.001619	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1627	 75940	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1627	 75940	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1628	 1648	 0.000657	 0.001688	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1628	 75941	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1628	 75941	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1629	 1630	 0.009203	 0.007283	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1630	 75942	 0.005763	 0.008828	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1631	 1632	 0.000811	 0.00244	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1631	 1634	 0.000495	 0.001307	 0.00031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1631	 75942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1631	 75942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75942	 1633	 0.005726	 0.004531	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1635	 1636	 0.00572	 0.004208	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75941	 1635	 0.007692	 0.007693	 0.0001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1637	 75943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1637	 75943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1638	 1644	 0.048064	 0.048547	 0.00064	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75939	 1638	 0.010154	 0.01106	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75943	 1638	 0.00306	 0.007595	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75943	 1639	 0.002389	 0.008361	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1639	 75945	 0.001718	 0.009764	 0.00018	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75938	 1640	 0.004554	 0.009017	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1641	 1654	 0.001272	 0.004364	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1641	 1660	 0.002002	 0.005291	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1641	 75944	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1641	 75944	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1642	 75945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1642	 75945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1642	 75951	 0.002476	 0.010076	 0.00245	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75939	 1643	 0.017872	 0.014143	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1644	 1645	 0.013818	 0.025309	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1644	 1888	 0.012645	 0.02316	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1645	 75946	 0.013629	 0.015122	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1646	 3025	 0.031963	 0.025295	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1647	 3026	 0.004343	 0.011275	 0.00274	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1647	 75946	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1647	 75946	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1648	 1650	 0.001729	 0.004641	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1649	 75947	 0.017341	 0.011227	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1650	 75947	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1650	 75947	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1650	 75955	 0.003916	 0.014178	 0.00304	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1651	 75955	 0.002663	 0.007426	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1652	 1653	 0.025943	 0.020335	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75503	 1652	 0.016386	 0.032442	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1654	 75948	 0.001215	 0.004865	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1655	 1665	 0.000341	 0.003725	 0.03657	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1655	 1680	 0.000169	 0.001857	 0.01804	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1655	 75948	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75944	 1656	 0.012211	 0.021039	 0.00033	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75931	 1657	 0.029301	 0.046769	 0.00108	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75949	 1657	 0.00708	 0.035813	 0.00062	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1658	 1659	 0.017558	 0.034764	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1658	 1663	 0.049671	 0.039309	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75949	 1658	 0.021997	 0.085576	 0.00143	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75931	 1659	 0.012891	 0.036972	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1660	 75950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1660	 75950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75950	 1661	 0.019508	 0.021457	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1662	 1666	 0.030048	 0.022765	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75945	 1662	 0.026506	 0.068136	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1662	 76022	 0.037708	 0.041838	 0.00082	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1664	 1666	 0.010121	 0.026016	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75950	 1664	 0.008816	 0.022421	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1665	 1930	 0.000712	 0.01242	 0.13442	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1665	 75951	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1666	 1892	 0.0212	 0.035713	 0.00051	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 1674	 0.001438	 0.00447	 0.00093	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 75953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1667	 75953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1667	 75955	 0.002603	 0.008929	 0.00214	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75953	 1668	 0.010355	 0.007943	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1669	 1679	 0.024666	 0.032418	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75953	 1669	 0.008613	 0.019698	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 1673	 0.002504	 0.007537	 0.00236	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 1681	 0.00353	 0.011515	 0.00306	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1671	 76351	 0.025639	 0.043192	 0.00062	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75503	 1672	 0.036994	 0.037365	 0.00049	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1673	 1674	 0.000947	 0.003299	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1674	 75954	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1674	 75954	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75503	 1675	 0.016324	 0.026055	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75954	 1675	 0.009406	 0.01126	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1676	 1677	 0.008722	 0.013362	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1676	 1678	 0.014545	 0.011401	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75953	 1676	 0.01095	 0.010952	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75503	 1677	 0.00733	 0.01684	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1679	 75957	 0.061025	 0.047834	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1680	 75955	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1680	 75955	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1681	 1686	 0.002608	 0.010146	 0.00271	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1681	 75956	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1681	 75956	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1682	 75960	 0.031692	 0.050587	 0.00117	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1683	 1684	 0.004131	 0.01109	 0.00251	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75948	 1683	 0.007375	 0.024848	 0.00618	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1683	 75957	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1683	 75957	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1683	 75959	 0.011349	 0.028529	 0.00739	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75957	 1685	 0.049563	 0.054514	 0.00073	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1686	 1687	 0.002895	 0.006976	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1686	 1688	 0.003332	 0.008945	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1687	 1689	 0.002382	 0.006295	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1688	 1691	 0.003912	 0.010338	 0.00242	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 3005	 0.003556	 0.009917	 0.00208	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1690	 75958	 0.054038	 0.042765	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75535	 1691	 0.003459	 0.01385	 0.00349	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1691	 75958	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1691	 75958	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1692	 75960	 0.027063	 0.021417	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1693	 1694	 7.5e-05	 0.000864	 0.00757	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1693	 75959	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1694	 1696	 0.000149	 0.001633	 0.01586	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1694	 75961	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75962	 1695	 0.019228	 0.015216	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1696	 1697	 0.000206	 0.002382	 0.02088	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1698	 1710	 0.00875	 0.055429	 0.01505	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75472	 1698	 0.002474	 0.025206	 0.0065	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1698	 75963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1698	 75963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1699	 1710	 0.003727	 0.016781	 0.00447	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1699	 3483	 0.006911	 0.027161	 0.00711	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75488	 1700	 0.002924	 0.018832	 0.00494	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1701	 1702	 0.003215	 0.014748	 0.00378	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75488	 1701	 0.004122	 0.019222	 0.00476	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1702	 1703	 0.002244	 0.008983	 0.00226	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1702	 75964	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1702	 75964	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1703	 2614	 0.002793	 0.011181	 0.00282	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1704	 1706	 0.11817	 0.15533	 0.00213	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1704	 75996	 0.14481	 0.14627	 0.00194	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1705	 75965	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1705	 75965	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1706	 1824	 0.084148	 0.16662	 0.00245	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75489	 1706	 0.014864	 0.056949	 0.00161	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1707	 1708	 0.11725	 0.075913	 0.00145	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1707	 1837	 0.059035	 0.076829	 0.00107	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75499	 1708	 0.023495	 0.078377	 0.00124	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75963	 1709	 0.058557	 0.15522	 0.00394	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 75966	 0.008634	 0.03359	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75488	 1710	 0.005269	 0.021441	 0.00522	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 75966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1710	 75966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1711	 75967	 0.011763	 0.015461	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1712	 75967	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1712	 75967	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1713	 1715	 0.055348	 0.10959	 0.00161	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75967	 1713	 0.017013	 0.011014	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1714	 1715	 0.038149	 0.098068	 0.00152	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1714	 1853	 0.057968	 0.092532	 0.00213	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75963	 1715	 0.045995	 0.11698	 0.00185	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1716	 1717	 0.002129	 0.009487	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1716	 75974	 0.002149	 0.008232	 0.00023	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1717	 1756	 0.003197	 0.011186	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1718	 1730	 0.002272	 0.007654	 0.0019	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1718	 1762	 0.00092	 0.003497	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1718	 1765	 0.002855	 0.009312	 0.00247	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1718	 75968	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1718	 75968	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1718	 75969	 0.001534	 0.006029	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1719	 75969	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1719	 75969	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1720	 1726	 0.012511	 0.02452	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75968	 1720	 0.005895	 0.01633	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1721	 1722	 0.017065	 0.013505	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1721	 1726	 0.018198	 0.014402	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1721	 1763	 0.035085	 0.025813	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1722	 1723	 0.004735	 0.008543	 0.00012	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1722	 75979	 0.005305	 0.015055	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1723	 1724	 0.001994	 0.006581	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1723	 1725	 0.006463	 0.011617	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1724	 1783	 0.00331	 0.009492	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1725	 75970	 0.004293	 0.009965	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1726	 75970	 0.019131	 0.014996	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1727	 1730	 0.002275	 0.006343	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1727	 75970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1727	 75970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75500	 1728	 0.013215	 0.009553	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75970	 1729	 0.014691	 0.011626	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1729	 75971	 0.018453	 0.014464	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1730	 75971	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1730	 75971	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1731	 1734	 0.002326	 0.006738	 0.00163	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1731	 75972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1731	 75972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1731	 75978	 0.002969	 0.014054	 0.00338	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1732	 1733	 0.005416	 0.010723	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1732	 75973	 0.00644	 0.014728	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1733	 1736	 0.003159	 0.01664	 0.0003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75972	 1733	 0.004864	 0.018923	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75969	 1734	 0.001742	 0.004676	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1734	 75973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1734	 75973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1735	 1738	 0.001881	 0.004972	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75496	 1735	 0.00125	 0.006324	 0.00176	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1735	 75974	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1735	 75974	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1736	 1740	 0.02312	 0.023351	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1736	 1750	 0.02364	 0.025748	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75974	 1737	 0.009857	 0.019319	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1738	 75975	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1738	 75975	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1739	 1810	 0.010796	 0.034278	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75975	 1739	 0.006864	 0.026701	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1741	 1742	 0.006279	 0.012433	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1741	 1749	 0.019434	 0.01538	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75972	 1741	 0.003068	 0.018643	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1742	 1744	 0.009182	 0.00902	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1743	 1744	 0.01396	 0.011048	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1743	 1745	 0.005278	 0.009214	 0.00014	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1743	 1747	 0.00339	 0.006644	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75970	 1744	 0.012767	 0.016779	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1745	 1746	 0.027983	 0.022145	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75500	 1745	 0.002115	 0.00883	 0.00025	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1747	 1748	 0.0086	 0.008781	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1748	 1751	 0.006182	 0.014352	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75971	 1748	 0.011798	 0.024144	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 1751	 0.020943	 0.020948	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1751	 1752	 0.004915	 0.012634	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1752	 1807	 0.008751	 0.018392	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75469	 1753	 0.008323	 0.045673	 0.01207	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1753	 75976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1753	 75976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1754	 1755	 0.011326	 0.044063	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75976	 1754	 0.011659	 0.038895	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1755	 75992	 0.013832	 0.061637	 0.00105	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1756	 1758	 0.012676	 0.017667	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75470	 1756	 0.05202	 0.052542	 0.0007	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1757	 1759	 0.005851	 0.031307	 0.00095	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1757	 75992	 0.002994	 0.02055	 0.00037	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75470	 1758	 0.019333	 0.029612	 0.00051	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75470	 1759	 0.004709	 0.03999	 0.00093	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1760	 1762	 0.001185	 0.006368	 0.00157	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1760	 1766	 0.001653	 0.005567	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1760	 75977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1760	 75977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1760	 75981	 0.002522	 0.010264	 0.0025	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75468	 1761	 0.00025	 0.00249	 0.00831	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1761	 75978	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1761	 75978	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1761	 76540	 0.009315	 0.105	 0.19308	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1761	 76540	 0.009315	 0.105	 0.19308	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75978	 1762	 0.00059	 0.00742	 0.0023	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75977	 1763	 0.016281	 0.032235	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1764	 1765	 0.001167	 0.003085	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1764	 1766	 0.002148	 0.005678	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1765	 75979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1765	 75979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1766	 1768	 0.001233	 0.004463	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1767	 1782	 0.010288	 0.018092	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75977	 1767	 0.012795	 0.026892	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1768	 1784	 0.002256	 0.005672	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1768	 75980	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1768	 75980	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75977	 1769	 0.012497	 0.013611	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1770	 1772	 0.00118	 0.003033	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1770	 75981	 0.002295	 0.007486	 0.00199	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 75981	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1772	 75983	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1772	 75983	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75510	 1773	 0.007482	 0.005921	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75983	 1773	 0.006568	 0.010483	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 75984	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1774	 75984	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1775	 1776	 0.007031	 0.011223	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75983	 1775	 0.005056	 0.010011	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1776	 1778	 0.009235	 0.005978	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1777	 1833	 0.024074	 0.043437	 0.00063	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1777	 1846	 0.041434	 0.032791	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1779	 1782	 0.009203	 0.021363	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1779	 1849	 0.020375	 0.078389	 0.00134	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1780	 1781	 0.012557	 0.029149	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75980	 1781	 0.00713	 0.014592	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75982	 1781	 0.029642	 0.070192	 0.00128	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75984	 1782	 0.017955	 0.018135	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 1788	 0.008892	 0.020428	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 75986	 0.019418	 0.029746	 0.00042	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1784	 75985	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1784	 75985	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1785	 75986	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1785	 75986	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1786	 1789	 0.003462	 0.010207	 0.00237	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1786	 75987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1786	 75987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1787	 1788	 0.021594	 0.017089	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1787	 1803	 0.028208	 0.02849	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75987	 1787	 0.046284	 0.032785	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75987	 1788	 0.010408	 0.020608	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 1792	 0.002483	 0.010104	 0.00246	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75469	 1789	 0.013205	 0.045303	 0.01085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 75988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 75988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1790	 1798	 0.025865	 0.041286	 0.00095	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75988	 1790	 0.017368	 0.057938	 0.00092	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1790	 75989	 0.007629	 0.025449	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1791	 75989	 0.008751	 0.013404	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1792	 75989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1792	 75989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75988	 1793	 0.010753	 0.047913	 0.00081	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 1795	 0.035424	 0.035779	 0.00047	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75989	 1794	 0.017684	 0.021952	 0.00048	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1795	 1796	 0.028464	 0.022526	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1795	 1799	 0.10227	 0.066212	 0.00126	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1800	 1802	 0.036007	 0.02728	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 75990	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1801	 75990	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1802	 1803	 0.009435	 0.022341	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75990	 1802	 0.008765	 0.020045	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75986	 1803	 0.011115	 0.023819	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1804	 1806	 0.008033	 0.02043	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75474	 1804	 0.013715	 0.035255	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1805	 75991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1805	 75991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1806	 1808	 0.012688	 0.024867	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75991	 1806	 0.026484	 0.040564	 0.0007	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1807	 1808	 0.005639	 0.010484	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1809	 1810	 0.011604	 0.020938	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1810	 1811	 0.012849	 0.024606	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75974	 1810	 0.027016	 0.077486	 0.00119	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1812	 1814	 0.019585	 0.056174	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75469	 1813	 0.00294	 0.020795	 0.00571	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1813	 75992	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1813	 75992	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75992	 1814	 0.008049	 0.035866	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 1816	 0.007901	 0.044912	 0.00081	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 1817	 0.03113	 0.073717	 0.00135	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 1818	 0.035014	 0.085708	 0.00147	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75992	 1816	 0.012378	 0.084966	 0.00155	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1817	 2775	 0.031996	 0.08225	 0.00127	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1818	 2775	 0.041199	 0.084313	 0.00207	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1819	 1822	 0.009061	 0.029553	 0.00785	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1819	 75993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1819	 75993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1820	 2779	 0.020502	 0.068394	 0.00108	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75993	 1820	 0.010364	 0.04386	 0.00083	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1821	 75996	 0.082354	 0.065175	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 1831	 0.004067	 0.016284	 0.0041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 75994	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1822	 75994	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75994	 1823	 0.050906	 0.040286	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1824	 1825	 0.038876	 0.029454	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1825	 75995	 0.017139	 0.022526	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1826	 1827	 0.000929	 0.002411	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1826	 75995	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1826	 75995	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1827	 1828	 0.001955	 0.005076	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1828	 1829	 0.004716	 0.013152	 0.00276	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1828	 75996	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1828	 75996	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1829	 1831	 0.007595	 0.019717	 0.00479	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1829	 75997	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1829	 75997	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75997	 1830	 0.0319	 0.02347	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75469	 1831	 0.002728	 0.017282	 0.00469	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75981	 1832	 0.003035	 0.010989	 0.00236	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1832	 75998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1832	 75998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75998	 1833	 0.033537	 0.026288	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1834	 1835	 0.028843	 0.018673	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75998	 1834	 0.027534	 0.022662	 0.00046	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75492	 1835	 0.032973	 0.026094	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75995	 1836	 0.019971	 0.042798	 0.00075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1836	 75999	 0.016812	 0.065403	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 75999	 0.039098	 0.050881	 0.00071	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 76000	 0.079861	 0.073562	 0.00118	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1838	 1839	 0.002532	 0.006893	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1838	 75999	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1838	 75999	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1839	 1845	 0.002841	 0.007626	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1839	 76000	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1839	 76000	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1840	 1848	 0.11436	 0.089648	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1840	 1851	 0.098474	 0.071189	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1840	 1853	 0.1082	 0.10823	 0.00146	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76000	 1840	 0.05637	 0.041473	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 1844	 0.010272	 0.007276	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1842	 1844	 0.006941	 0.007011	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1843	 1844	 0.018874	 0.012219	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1844	 76001	 0.00513	 0.02203	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1845	 76001	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1845	 76001	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1846	 1848	 0.008237	 0.023626	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75492	 1846	 0.014128	 0.028911	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1847	 1848	 0.029879	 0.021983	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75998	 1848	 0.060678	 0.10455	 0.00166	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1849	 1850	 0.028393	 0.11046	 0.00184	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1850	 1854	 0.04538	 0.1588	 0.00329	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1852	 1853	 0.11171	 0.088406	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1855	 2644	 0.10034	 0.064961	 0.00124	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1856	 1857	 0.031215	 0.047817	 0.00067	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1856	 2645	 0.051643	 0.10121	 0.00152	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1856	 2921	 0.02951	 0.07586	 0.00117	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1856	 2923	 0.079713	 0.087677	 0.00117	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1857	 2645	 0.020725	 0.048108	 0.00092	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1858	 1865	 0.019162	 0.019166	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1858	 1866	 0.003617	 0.008979	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1858	 1879	 0.009227	 0.00932	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1858	 2171	 0.007773	 0.009111	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1858	 76002	 0.012629	 0.013487	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1858	 76005	 0.048123	 0.048606	 0.00064	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1859	 1887	 0.002589	 0.006842	 0.0016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1859	 76002	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1859	 76002	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1860	 1861	 0.009055	 0.007166	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76002	 1861	 0.016988	 0.013444	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 1869	 0.004273	 0.018718	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 1883	 0.05924	 0.046882	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1865	 1868	 0.004843	 0.00959	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1866	 76003	 0.002238	 0.005554	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1867	 1873	 0.000667	 0.001731	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1867	 1932	 0.00677	 0.043613	 0.01143	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1867	 76003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1867	 76003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1868	 1869	 0.003723	 0.012718	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1868	 1870	 0.010626	 0.008329	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76003	 1868	 0.001509	 0.008579	 0.00016	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1869	 1908	 0.01362	 0.022943	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75501	 1869	 0.008117	 0.027728	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 1872	 0.004758	 0.012232	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 1877	 0.028858	 0.022837	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 1907	 0.006238	 0.012765	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 76009	 0.036602	 0.056071	 0.00079	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75501	 1872	 0.003977	 0.009417	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75501	 1874	 0.010448	 0.00819	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75501	 1875	 0.008224	 0.006508	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75501	 1876	 0.009409	 0.009503	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1877	 1878	 0.02444	 0.019342	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1877	 76005	 0.021377	 0.042325	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1878	 1901	 0.016553	 0.042097	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1878	 76005	 0.004907	 0.021866	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1880	 1881	 0.015162	 0.011999	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1880	 76005	 0.013439	 0.021451	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1882	 2904	 0.046267	 0.091606	 0.00134	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1884	 1885	 0.024132	 0.017754	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 1886	 0.009548	 0.018905	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1886	 2171	 0.045391	 0.03049	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1886	 76004	 0.010713	 0.024501	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75951	 1887	 0.005645	 0.016351	 0.00394	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1887	 76004	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1887	 76004	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76004	 1888	 0.012577	 0.028528	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75951	 1889	 0.003117	 0.014299	 0.00366	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1889	 76005	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1889	 76005	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75952	 1890	 0.021914	 0.056333	 0.00087	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76005	 1890	 0.010574	 0.027181	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1890	 76006	 0.014289	 0.040984	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1891	 1892	 0.024904	 0.016123	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 76022	 0.055196	 0.039901	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1893	 76025	 0.026708	 0.01965	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1894	 1895	 0.002055	 0.005432	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1894	 1941	 0.003177	 0.007374	 0.00225	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1894	 76006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1894	 76006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1895	 76007	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1895	 76007	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76007	 1896	 0.03659	 0.026451	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1896	 76008	 0.026378	 0.030921	 0.00054	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1897	 1898	 0.008914	 0.016846	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1898	 76026	 0.006799	 0.033177	 0.00057	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1899	 2081	 0.003789	 0.009525	 0.00247	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1899	 2082	 0.004552	 0.013421	 0.00312	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1899	 76008	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1899	 76008	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1900	 1904	 0.016832	 0.042806	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76008	 1900	 0.029668	 0.03861	 0.00054	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	1901	 1903	 0.013108	 0.027986	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76007	 1901	 0.027769	 0.042534	 0.00074	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1901	 76024	 0.07593	 0.10351	 0.0023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1902	 1913	 0.005356	 0.013904	 0.00337	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1902	 76009	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1902	 76009	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1903	 1907	 0.024699	 0.032462	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76009	 1903	 0.016972	 0.043627	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1904	 2088	 0.024065	 0.047646	 0.0007	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76009	 1904	 0.008428	 0.021666	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1905	 1906	 0.025446	 0.018722	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76009	 1905	 0.038796	 0.03041	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1906	 1908	 0.029244	 0.023143	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1908	 1909	 0.007998	 0.02034	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1909	 1910	 0.012513	 0.032165	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1910	 1911	 0.012843	 0.042842	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1911	 76021	 0.010069	 0.05365	 0.00094	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1912	 76010	 0.052981	 0.037529	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1913	 2089	 0.00512	 0.013939	 0.00307	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1913	 76010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1913	 76010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1914	 2739	 0.002383	 0.008176	 0.00196	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1914	 2741	 0.00413	 0.014954	 0.00321	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1914	 76011	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1914	 76011	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1915	 76012	 0.059342	 0.046963	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1916	 2162	 0.002924	 0.014945	 0.00407	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1916	 76012	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1916	 76012	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1916	 76272	 0.003335	 0.019532	 0.00532	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 76013	 0.010605	 0.051749	 0.00089	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 76016	 0.011511	 0.038399	 0.00061	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1918	 76013	 0.012927	 0.025594	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1919	 76013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1919	 76013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1919	 76014	 0.001671	 0.007908	 0.0019	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1920	 2698	 0.000352	 0.006182	 0.06614	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1920	 76014	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1921	 1922	 0.00151	 0.006572	 0.00187	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1921	 1924	 0.002296	 0.006404	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76014	 1921	 0.001155	 0.006408	 0.00195	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1922	 1923	 0.001879	 0.007525	 0.0019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 2094	 0.004618	 0.018491	 0.00466	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 76016	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1923	 76016	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1924	 1925	 0.002342	 0.006079	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1925	 2648	 0.004693	 0.012183	 0.00296	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1925	 76017	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1925	 76017	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76017	 1926	 0.022372	 0.022377	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76016	 1927	 0.02708	 0.053617	 0.00079	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1928	 1929	 0.012163	 0.040573	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1928	 76081	 0.014919	 0.03835	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1929	 76019	 0.011224	 0.044991	 0.00116	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1930	 2625	 0.000601	 0.010902	 0.109	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1930	 2698	 0.001301	 0.01442	 0.13735	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1930	 76018	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1931	 1932	 0.002835	 0.012763	 0.0034	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76018	 1931	 0.002423	 0.012375	 0.00311	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1931	 76020	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1931	 76020	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1932	 76021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1932	 76021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1933	 1934	 0.013968	 0.035907	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1933	 2920	 0.024904	 0.056955	 0.00139	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76021	 1934	 0.027852	 0.063989	 0.00097	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76020	 1935	 0.08252	 0.065306	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1936	 2904	 0.068475	 0.049501	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 1938	 0.02703	 0.037671	 0.00064	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 76024	 0.007107	 0.029667	 0.00086	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1939	 76022	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1939	 76022	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1939	 76023	 0.003862	 0.01077	 0.00226	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1940	 1953	 0.00017	 0.001931	 0.01757	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1940	 2006	 0.000693	 0.007846	 0.07144	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1940	 76023	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76023	 1941	 0.003326	 0.00855	 0.00212	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1941	 76025	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1941	 76025	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76023	 1942	 0.002412	 0.008526	 0.00192	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1942	 76026	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1942	 76026	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1943	 1945	 0.036208	 0.028655	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1944	 76027	 0.01626	 0.032193	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1944	 76031	 0.044187	 0.034636	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1945	 76027	 0.00912	 0.023636	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1946	 2080	 0.002502	 0.006496	 0.00158	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1946	 76027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1946	 76027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1947	 1948	 0.010863	 0.021289	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76027	 1947	 0.013	 0.026603	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1948	 1949	 0.021672	 0.017151	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1948	 76029	 0.02636	 0.026917	 0.00042	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1950	 1974	 0.002072	 0.005778	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1950	 76028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1950	 76028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1951	 76029	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1951	 76029	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1951	 76030	 0.001722	 0.004829	 0.00124	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76029	 1952	 0.004732	 0.010985	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1952	 76031	 0.013385	 0.024887	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1953	 2006	 0.000536	 0.006077	 0.05533	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1953	 76030	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1954	 1955	 0.021235	 0.015042	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76031	 1954	 0.013519	 0.026767	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76024	 1956	 0.016568	 0.026446	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76024	 1957	 0.016089	 0.053671	 0.00085	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1957	 76032	 0.027916	 0.028196	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1958	 1959	 0.001777	 0.004697	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1958	 76032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1958	 76032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1959	 1960	 0.002144	 0.005567	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1959	 76033	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1959	 76033	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1960	 1962	 0.001282	 0.003596	 0.00093	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1960	 76034	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1960	 76034	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76031	 1961	 0.031602	 0.081237	 0.00126	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76032	 1961	 0.029198	 0.018903	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1962	 1963	 0.001504	 0.005017	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1962	 76035	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1962	 76035	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1963	 1966	 0.001716	 0.005598	 0.00149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 1965	 0.017818	 0.019407	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1965	 76043	 0.007415	 0.018856	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1966	 1996	 0.000832	 0.003385	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1966	 76036	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1966	 76036	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76036	 1967	 0.015271	 0.009886	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76035	 1968	 0.029902	 0.023664	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1969	 76037	 0.016189	 0.014606	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76033	 1970	 0.016312	 0.012909	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76028	 1971	 0.010354	 0.019828	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1972	 1973	 0.001375	 0.003635	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1972	 1978	 0.002707	 0.009434	 0.00219	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1972	 76037	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1972	 76037	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1973	 1974	 0.001205	 0.003128	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1975	 1976	 0.024331	 0.015752	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1976	 2061	 0.014606	 0.022374	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1977	 76038	 0.021397	 0.023534	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1978	 1982	 0.001434	 0.006242	 0.00178	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1978	 76038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1978	 76038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1979	 1980	 0.004443	 0.010314	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1979	 2061	 0.006827	 0.018047	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 1981	 0.004442	 0.009336	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1981	 76039	 0.003401	 0.007814	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	1982	 1984	 0.00044	 0.003115	 0.00085	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1982	 76039	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1982	 76039	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1983	 1984	 0.000504	 0.00173	 0.00041	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1983	 2013	 0.000455	 0.001823	 0.00046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1984	 76040	 0.000701	 0.002537	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	1985	 1986	 0.000158	 0.001043	 0.00202	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1985	 76044	 0.000218	 0.001454	 0.00274	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	1986	 76040	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76041	 1986	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1987	 1988	 0.011727	 0.009192	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76041	 1987	 0.005883	 0.011647	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 1991	 0.015588	 0.010471	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1990	 1991	 0.012044	 0.009532	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1991	 76042	 0.003048	 0.010168	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	1992	 76042	 0.007784	 0.011805	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1993	 1994	 0.000561	 0.002525	 0.00067	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1993	 1996	 0.000718	 0.003126	 0.00089	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	1993	 76042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1993	 76042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1993	 76045	 0.000966	 0.007759	 0.00218	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1994	 2005	 0.000374	 0.001697	 0.00059	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76042	 1995	 0.014184	 0.011118	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	1997	 1998	 0.013346	 0.010562	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76042	 1998	 0.007251	 0.014838	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	1999	 2000	 0.001032	 0.003134	 0.00069	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	1999	 2002	 0.000986	 0.002907	 0.00068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2000	 76043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2000	 76043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2001	 2008	 0.01059	 0.007792	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2002	 2007	 0.001448	 0.004268	 0.00099	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2003	 2004	 0.010122	 0.007764	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2003	 76046	 0.007925	 0.009661	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2005	 2007	 0.000508	 0.002645	 0.00069	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2006	 76044	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76045	 2006	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2007	 2581	 0.001478	 0.003907	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76045	 2007	 0.000464	 0.003219	 0.00092	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2007	 76046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2007	 76046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76046	 2008	 0.003731	 0.005955	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75479	 2009	 0.001223	 0.003233	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2009	 76047	 0.000734	 0.001999	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2010	 76047	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2010	 76047	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2011	 2020	 0.000591	 0.001991	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76047	 2011	 0.000436	 0.00147	 0.00037	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 2013	 0.0008	 0.002179	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76047	 2012	 0.001307	 0.003558	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2013	 2014	 0.000642	 0.001697	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76040	 2013	 0.002218	 0.005758	 0.0014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76045	 2013	 0.004336	 0.011458	 0.00268	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2013	 76048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2013	 76048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2013	 76065	 0.001408	 0.005635	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2014	 2017	 0.000384	 0.000965	 0.00025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2015	 2016	 0.011832	 0.009275	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76048	 2015	 0.013066	 0.010022	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2015	 76049	 0.006832	 0.007514	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2017	 76049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2017	 76049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2018	 2019	 0.000846	 0.002237	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2018	 2056	 0.00065	 0.001718	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2018	 76050	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2018	 76050	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2019	 2020	 0.0007	 0.001688	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2019	 2044	 0.000913	 0.002617	 0.00064	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2019	 76051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2019	 76051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2020	 76052	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2020	 76052	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2021	 2023	 0.000853	 0.002379	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2021	 2032	 0.001044	 0.002912	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2021	 2044	 0.001235	 0.003316	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2022	 2045	 0.005518	 0.010925	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76052	 2022	 0.002019	 0.006734	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2023	 76053	 0.001005	 0.002963	 0.00069	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2024	 2025	 0.000422	 0.001061	 0.00027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75479	 2024	 0.001429	 0.003316	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76047	 2024	 0.000988	 0.002611	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2025	 76053	 0.000777	 0.001997	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2026	 76053	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2027	 2028	 0.007753	 0.005947	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2027	 76193	 0.009294	 0.006583	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75485	 2028	 0.001585	 0.004201	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2029	 2033	 0.000544	 0.001437	 0.00034	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2029	 76055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2029	 76055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2030	 2210	 0.003183	 0.02638	 0.08326	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75483	 2030	 7.2e-05	 0.000488	 0.00088	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76044	 2030	 0.000556	 0.003902	 0.00664	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	2030	 76056	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76057	 2030	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2031	 2038	 2.8e-05	 0.000312	 0.00284	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 76058	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2031	 76058	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2032	 2033	 0.000369	 0.001478	 0.00037	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2032	 2037	 0.000447	 0.001281	 0.00032	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2032	 76060	 0.000394	 0.001668	 0.00038	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76056	 2033	 0.000571	 0.002017	 0.00045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2033	 76059	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2033	 76059	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2034	 2035	 0.005082	 0.003674	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76059	 2034	 0.006069	 0.004803	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2036	 76063	 0.008569	 0.006304	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2037	 2046	 0.000552	 0.001717	 0.00036	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2038	 76060	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2038	 76060	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2039	 2431	 0.001512	 0.004728	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76060	 2039	 0.000571	 0.001924	 0.00048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 76061	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2039	 76061	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2040	 2422	 0.001081	 0.004865	 0.00129	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76060	 2040	 0.000229	 0.001836	 0.00052	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2040	 76062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2040	 76062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76062	 2041	 0.006659	 0.005269	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2042	 2043	 0.001999	 0.004893	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76062	 2042	 0.008632	 0.008718	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2043	 76063	 0.001607	 0.004608	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2044	 2048	 0.000436	 0.001423	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2045	 76063	 0.0075	 0.005313	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2046	 2047	 0.000401	 0.001657	 0.00039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76053	 2046	 0.001675	 0.005839	 0.00135	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2046	 76063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2046	 76063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2047	 2423	 0.000694	 0.002936	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2048	 2050	 0.001262	 0.003925	 0.00082	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2048	 76064	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2048	 76064	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76064	 2049	 0.00866	 0.006853	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2050	 2121	 0.001579	 0.00397	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2051	 2054	 0.000999	 0.002787	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2051	 2069	 0.000855	 0.002197	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2052	 2053	 0.012924	 0.010228	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76064	 2053	 0.008745	 0.006921	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2054	 2056	 0.001055	 0.003159	 0.00071	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2054	 76065	 0.000412	 0.001676	 0.00041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76050	 2055	 0.008101	 0.006137	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2057	 2106	 0.000351	 0.004247	 0.03754	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2057	 76065	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76049	 2058	 0.000999	 0.003496	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76066	 2058	 0.001834	 0.008173	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76066	 2059	 0.010853	 0.007845	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2060	 2065	 0.009722	 0.007694	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76066	 2060	 0.009167	 0.021282	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76066	 2061	 0.00847	 0.029654	 0.00082	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2062	 2075	 0.00165	 0.00443	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2062	 76067	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2062	 76067	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2063	 2066	 0.001255	 0.003499	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2063	 76068	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2063	 76068	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76067	 2064	 0.010463	 0.00828	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76068	 2064	 0.007362	 0.008097	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76065	 2066	 0.002387	 0.006198	 0.0015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2066	 76069	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2066	 76069	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2067	 76070	 0.016092	 0.012735	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2068	 2074	 0.002107	 0.005569	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76065	 2068	 0.001575	 0.005403	 0.00129	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2068	 76070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2068	 76070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2069	 2070	 0.000685	 0.001722	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2070	 2120	 0.00136	 0.003418	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2071	 2072	 0.012291	 0.008706	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76070	 2071	 0.017099	 0.012112	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2073	 2074	 0.000965	 0.00259	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2073	 2115	 0.001566	 0.004204	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2073	 76071	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2073	 76071	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2075	 2076	 0.002388	 0.006201	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2075	 76072	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2075	 76072	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2076	 76073	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2076	 76073	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76073	 2077	 0.010792	 0.019766	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76072	 2078	 0.035524	 0.022998	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 2080	 0.001888	 0.004383	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 76074	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2079	 76074	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2079	 76085	 0.007021	 0.0207	 0.00482	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76030	 2081	 0.00915	 0.024182	 0.00566	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2081	 76075	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2081	 76075	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2082	 2087	 0.004386	 0.01293	 0.00301	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2082	 76076	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2082	 76076	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76074	 2083	 0.010377	 0.026389	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 76077	 0.016681	 0.042424	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 76080	 0.085473	 0.067644	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2084	 2085	 0.005231	 0.01315	 0.00341	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2084	 76077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2084	 76077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2084	 76085	 0.005529	 0.014612	 0.00342	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2085	 2087	 0.002696	 0.010795	 0.00272	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2085	 2096	 0.002123	 0.013885	 0.00353	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2085	 76078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2085	 76078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2086	 2091	 0.003015	 0.007969	 0.00187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2086	 2094	 0.004633	 0.012613	 0.00278	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2086	 76079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2086	 76079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2087	 76080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2087	 76080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76010	 2088	 0.02398	 0.049073	 0.00121	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76080	 2088	 0.060399	 0.066432	 0.00089	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 2090	 0.002174	 0.007458	 0.00179	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2090	 2093	 0.002822	 0.007457	 0.00175	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2090	 76081	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2090	 76081	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2091	 76082	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2091	 76082	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2092	 76083	 0.027869	 0.022055	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2093	 2094	 0.00368	 0.013006	 0.00293	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2093	 76083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2093	 76083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2094	 2095	 0.001849	 0.005536	 0.00125	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2095	 2096	 0.003495	 0.009804	 0.00252	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2096	 2097	 0.002156	 0.008632	 0.00217	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2097	 2098	 0.001402	 0.005706	 0.00139	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2098	 2158	 0.001192	 0.006539	 0.00173	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 76100	 0.037435	 0.025146	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2100	 2101	 0.057951	 0.042637	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 76100	 0.025578	 0.050642	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2102	 76086	 0.050934	 0.040309	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2103	 76087	 0.0158	 0.039216	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2104	 76084	 0.006107	 0.01209	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2105	 76084	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2105	 76084	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2105	 76085	 0.001437	 0.004236	 0.00099	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2106	 2744	 0.000543	 0.00983	 0.1875	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2106	 76085	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76086	 2107	 0.00914	 0.018097	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2108	 2110	 0.0013	 0.003766	 0.00091	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76085	 2108	 0.001797	 0.007062	 0.00185	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2108	 76087	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2108	 76087	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2109	 76088	 0.011322	 0.00896	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2110	 76088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2110	 76088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2111	 2112	 0.002864	 0.006649	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2111	 2137	 0.007225	 0.016599	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 2114	 0.00301	 0.010043	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2113	 2114	 0.006586	 0.013479	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2113	 76089	 0.012126	 0.013337	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76086	 2114	 0.006286	 0.028009	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2115	 76089	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2115	 76089	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76071	 2116	 0.009533	 0.018683	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2116	 76090	 0.012643	 0.021084	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2117	 2118	 0.001029	 0.002762	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2117	 2120	 0.00114	 0.003014	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2118	 2124	 0.000827	 0.00192	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2118	 76090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2118	 76090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2119	 2121	 0.001454	 0.003843	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2119	 2122	 0.001169	 0.002713	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2121	 76091	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2121	 76091	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2122	 76092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2122	 76092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76092	 2123	 0.009193	 0.012082	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2124	 2203	 0.011012	 0.029103	 0.00681	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2124	 76093	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2124	 76093	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2125	 2137	 0.005991	 0.011741	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76093	 2125	 0.00982	 0.008392	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2126	 2127	 0.008863	 0.017549	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76093	 2126	 0.005759	 0.014805	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2127	 2129	 0.021553	 0.021558	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2127	 2410	 0.023692	 0.017431	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76092	 2127	 0.02358	 0.025935	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2128	 2130	 0.012502	 0.016431	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2128	 2414	 0.020975	 0.015163	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2128	 76184	 0.037784	 0.038163	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2129	 2134	 0.023452	 0.016612	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2130	 76094	 0.009866	 0.022901	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2131	 2188	 0.024806	 0.025055	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2131	 76094	 0.012545	 0.029125	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2132	 76094	 0.029411	 0.019756	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2133	 2198	 0.001801	 0.004834	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2133	 2306	 0.002297	 0.007181	 0.00208	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2133	 2417	 0.006814	 0.018008	 0.00422	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2133	 76094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2133	 76094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76094	 2134	 0.007014	 0.012606	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2135	 2136	 0.024246	 0.015697	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2135	 2140	 0.014808	 0.019271	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2135	 2199	 0.009863	 0.016168	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 2137	 0.011676	 0.019669	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2137	 2138	 0.00282	 0.006398	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76088	 2138	 0.004346	 0.011172	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2139	 2140	 0.009059	 0.017936	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76088	 2139	 0.005909	 0.015028	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2141	 76095	 0.022086	 0.022307	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 2145	 0.001678	 0.005757	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 2203	 0.002799	 0.007398	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 76095	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2142	 76095	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76095	 2143	 0.019547	 0.028483	 0.00064	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2144	 76096	 0.023571	 0.030979	 0.00042	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2145	 2156	 0.003062	 0.008869	 0.00214	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75476	 2145	 0.006088	 0.052218	 0.01486	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2145	 76096	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2145	 76096	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2146	 2147	 0.004027	 0.015666	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2146	 2149	 0.002404	 0.011732	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76096	 2147	 0.002956	 0.015373	 0.00033	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2147	 76099	 0.005332	 0.025726	 0.00045	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 76098	 0.003007	 0.01053	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 2152	 0.001079	 0.005619	 0.00147	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 2164	 0.000816	 0.005073	 0.00143	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 76097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2150	 76097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76097	 2151	 0.011955	 0.018132	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2152	 2153	 0.000824	 0.002914	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2152	 76098	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2152	 76098	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2153	 2155	 0.001092	 0.002938	 0.00082	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2154	 76099	 0.006514	 0.021498	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2154	 76102	 0.005098	 0.024878	 0.00043	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 2158	 0.004282	 0.011496	 0.00261	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 76099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2155	 76099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2156	 76100	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2156	 76100	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76100	 2157	 0.024219	 0.018984	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2158	 2159	 0.001041	 0.005135	 0.00139	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2159	 2160	 0.001096	 0.005507	 0.00143	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2160	 2161	 0.0015	 0.004082	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2160	 2737	 0.002523	 0.015983	 0.00434	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2160	 76101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2160	 76101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2161	 2162	 0.001798	 0.00629	 0.00208	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 76102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2161	 76102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2162	 2163	 0.00313	 0.008273	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2163	 2164	 0.001661	 0.005812	 0.00193	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2163	 2167	 0.002429	 0.009885	 0.00241	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 76110	 0.019967	 0.039533	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2167	 2168	 0.003226	 0.010521	 0.00279	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2167	 2209	 0.006721	 0.017278	 0.00428	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2168	 2742	 0.003682	 0.01263	 0.00303	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2169	 2782	 0.03201	 0.063377	 0.00093	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76018	 2170	 0.006134	 0.017105	 0.00359	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2170	 76103	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2170	 76103	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75876	 2172	 0.045751	 0.11885	 0.02887	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2172	 76104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2172	 76104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76104	 2173	 0.039012	 0.028201	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76104	 2174	 0.087725	 0.069426	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2175	 2176	 0.084448	 0.066833	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76104	 2175	 0.067632	 0.053013	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2177	 2427	 0.003867	 0.007657	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2177	 76189	 0.015694	 0.01242	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2178	 2180	 0.009822	 0.012342	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2178	 76188	 0.005611	 0.014271	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2179	 76185	 0.007088	 0.005556	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2180	 2181	 0.007856	 0.006217	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2181	 2183	 0.009822	 0.007699	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2182	 2187	 0.017054	 0.012328	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2182	 2414	 0.023711	 0.017141	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2182	 76105	 0.010504	 0.020796	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2183	 76105	 0.004353	 0.007854	 0.00011	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2184	 76105	 0.008789	 0.006955	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2185	 76105	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2185	 76105	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76105	 2186	 0.01128	 0.008299	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2188	 2559	 0.057376	 0.045407	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2189	 2563	 0.018008	 0.014115	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2190	 2565	 0.006713	 0.012113	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2190	 76106	 0.006486	 0.013847	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2191	 2192	 0.019072	 0.013509	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2191	 76219	 0.018754	 0.014701	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2192	 76114	 0.010346	 0.019814	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2193	 2222	 0.002554	 0.007941	 0.00166	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2193	 76106	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2193	 76106	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76106	 2194	 0.015988	 0.031333	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2195	 76142	 0.031423	 0.024867	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2196	 2205	 0.001279	 0.010973	 0.00312	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2196	 2306	 0.001459	 0.006694	 0.00171	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2196	 76107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2196	 76107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2197	 2204	 0.022328	 0.029345	 0.0004	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76107	 2197	 0.00978	 0.022705	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2198	 2306	 0.001393	 0.004035	 0.00097	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2198	 76108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2198	 76108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2199	 2201	 0.022102	 0.024309	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76108	 2199	 0.015	 0.022978	 0.00032	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2200	 2201	 0.025689	 0.016631	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2201	 2204	 0.006818	 0.026523	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2202	 76109	 0.018149	 0.014363	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 76109	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2203	 76109	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76096	 2204	 0.014959	 0.058195	 0.00097	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76109	 2204	 0.007704	 0.017885	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2205	 2206	 0.001227	 0.009955	 0.00317	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2206	 2207	 0.002423	 0.009859	 0.0024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2206	 2208	 0.002188	 0.013858	 0.00376	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2207	 2219	 0.002584	 0.010938	 0.00246	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2208	 2209	 0.001688	 0.014198	 0.00421	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2209	 76110	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2209	 76110	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2209	 76111	 0.001555	 0.00563	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75475	 2210	 0.000338	 0.002988	 0.01266	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2210	 76111	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76112	 2210	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2211	 2212	 0.002794	 0.008237	 0.00192	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2211	 2219	 0.00329	 0.009175	 0.00193	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2212	 2290	 0.004743	 0.011429	 0.00323	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2212	 2291	 0.002863	 0.009647	 0.0024	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2213	 2215	 0.024929	 0.037374	 0.00068	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75887	 2213	 0.018687	 0.048036	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2213	 76136	 0.020076	 0.066972	 0.00106	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75887	 2214	 0.044626	 0.035317	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2216	 2219	 0.002604	 0.006882	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2216	 76113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2216	 76113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2217	 76118	 0.009464	 0.020206	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2218	 76116	 0.040215	 0.029588	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75476	 2219	 0.007984	 0.035948	 0.00957	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2220	 2221	 0.044396	 0.034799	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2220	 2224	 0.012586	 0.028915	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2220	 2225	 0.005147	 0.01717	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 2223	 0.00162	 0.007861	 0.0018	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 2570	 0.003856	 0.010816	 0.00278	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 76114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2222	 76114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2223	 76115	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2223	 76115	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2223	 76117	 0.00111	 0.007447	 0.0018	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76115	 2224	 0.006544	 0.019244	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2225	 2226	 0.002493	 0.008729	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2226	 76116	 0.002479	 0.015242	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2227	 76116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2227	 76116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2227	 76117	 0.002031	 0.005697	 0.00147	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 2234	 0.000175	 0.003078	 0.03293	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 76117	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76113	 2229	 0.007936	 0.035152	 0.0008	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2229	 76120	 0.011463	 0.029467	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2230	 2231	 0.003682	 0.010024	 0.00221	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2230	 76119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2230	 76119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2231	 2303	 0.00344	 0.008647	 0.00224	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2231	 76120	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2231	 76120	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2232	 2233	 0.009037	 0.025919	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76118	 2232	 0.007797	 0.030448	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 76122	 0.026715	 0.040924	 0.00057	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2234	 2253	 0.000512	 0.005697	 0.05372	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	2234	 2357	 0.000455	 0.005172	 0.04671	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	2234	 76121	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2235	 2237	 0.003198	 0.009262	 0.00223	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76121	 2235	 0.003123	 0.010522	 0.00261	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2236	 2238	 0.002451	 0.006477	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2236	 2260	 0.002243	 0.006254	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2237	 2570	 0.002262	 0.006667	 0.00155	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2238	 2539	 0.002347	 0.006544	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2238	 2572	 0.001928	 0.005095	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2239	 2271	 0.068102	 0.083023	 0.00133	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2239	 76211	 0.030737	 0.024093	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2240	 76123	 0.011608	 0.017783	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2241	 2242	 0.001158	 0.003971	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2241	 2258	 0.00097	 0.003512	 0.00075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2242	 2524	 0.00308	 0.009577	 0.002	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2242	 2536	 0.001765	 0.006239	 0.00141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2242	 76123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2242	 76123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2242	 76126	 0.002896	 0.012905	 0.00351	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2243	 2246	 0.001462	 0.003797	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2243	 2513	 0.00264	 0.007086	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2243	 76124	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2243	 76124	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76124	 2244	 0.021287	 0.016686	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2245	 76125	 0.008285	 0.006557	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2246	 2247	 0.001127	 0.003232	 0.0008	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2246	 76125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2246	 76125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2247	 2248	 0.000331	 0.002342	 0.00064	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 2535	 0.002246	 0.007939	 0.00179	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2248	 2249	 0.001224	 0.0042	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2248	 2250	 0.000966	 0.004088	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2249	 2258	 0.000827	 0.002785	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2249	 76126	 0.00058	 0.004661	 0.00131	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2250	 76126	 0.001119	 0.004734	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2251	 2252	 0.013538	 0.010714	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75482	 2251	 0.024987	 0.027216	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2253	 76126	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76127	 2254	 0.013921	 0.010547	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2255	 2262	 0.001758	 0.00472	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2255	 76128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2255	 76128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2256	 2261	 0.007969	 0.014816	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2256	 76129	 0.003636	 0.009423	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2257	 2260	 0.002823	 0.009511	 0.00236	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76126	 2257	 0.002095	 0.007185	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2257	 76129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2257	 76129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2258	 76130	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2258	 76130	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76130	 2259	 0.011253	 0.008135	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2261	 76134	 0.011043	 0.019925	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2262	 2263	 0.001081	 0.002943	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2263	 76131	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2263	 76131	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2263	 76132	 0.001043	 0.002757	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2264	 76132	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76131	 2265	 0.028006	 0.022164	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2266	 2267	 0.021746	 0.01721	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2266	 2275	 0.04549	 0.032885	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2266	 76135	 0.013421	 0.039465	 0.00081	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2268	 2300	 0.007806	 0.019622	 0.00508	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76132	 2268	 0.004059	 0.013238	 0.00351	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2268	 76134	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2268	 76134	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2269	 2270	 0.017873	 0.018804	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2269	 2272	 0.01639	 0.025108	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76134	 2269	 0.009964	 0.019305	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2270	 2271	 0.011418	 0.022607	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76122	 2271	 0.011217	 0.033761	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2272	 2273	 0.024937	 0.019735	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 2275	 0.055768	 0.043713	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 76140	 0.007573	 0.023232	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2274	 2275	 0.034009	 0.026914	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2274	 76155	 0.026552	 0.052037	 0.00078	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2276	 2277	 0.02204	 0.024242	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2277	 2279	 0.010166	 0.026132	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2277	 76145	 0.023877	 0.031073	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2278	 76135	 0.032627	 0.025821	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76133	 2279	 0.011537	 0.051407	 0.00087	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2279	 76146	 0.05407	 0.087013	 0.00136	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76132	 2280	 0.001812	 0.006217	 0.00149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2280	 76135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2280	 76135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2281	 2282	 0.020734	 0.015255	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2282	 2283	 0.006332	 0.014699	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76135	 2282	 0.006957	 0.017883	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2283	 2284	 0.007131	 0.016556	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2284	 2285	 0.003446	 0.009109	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75482	 2285	 0.004468	 0.01738	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2286	 2322	 0.01891	 0.038698	 0.00095	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2286	 76143	 0.027893	 0.057082	 0.0014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2286	 76148	 0.05113	 0.091903	 0.00165	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2287	 2288	 0.013194	 0.051327	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2287	 76136	 0.025465	 0.065462	 0.00101	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2288	 2294	 0.007526	 0.026885	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2289	 76136	 0.043552	 0.034467	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2290	 2292	 0.005529	 0.018443	 0.00468	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2290	 76136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2290	 76136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2291	 2292	 0.002256	 0.009033	 0.00228	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 76137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2291	 76137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75476	 2292	 0.001337	 0.007966	 0.0021	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75495	 2292	 0.00143	 0.010773	 0.00299	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2292	 76138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2292	 76138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76112	 2293	 0.038669	 0.025034	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2294	 76139	 0.007283	 0.044774	 0.00081	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76137	 2295	 0.031176	 0.024672	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76138	 2295	 0.012452	 0.041539	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75476	 2296	 0.001061	 0.004317	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75495	 2296	 0.000305	 0.003755	 0.00121	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75477	 2297	 0.000649	 0.008313	 0.00248	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75495	 2297	 0.001173	 0.012585	 0.00328	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2297	 76139	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2297	 76139	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2298	 2299	 0.001881	 0.005051	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2298	 2343	 0.00204	 0.005391	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2299	 2300	 0.002306	 0.006094	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2300	 76140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2300	 76140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2301	 2302	 0.013764	 0.013804	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76122	 2301	 0.021466	 0.042501	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2301	 76141	 0.006573	 0.015565	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76121	 2303	 0.004695	 0.012188	 0.00296	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2303	 76141	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2303	 76141	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76119	 2304	 0.020545	 0.032793	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2304	 76161	 0.095982	 0.075237	 0.00097	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76122	 2305	 0.024746	 0.057442	 0.00109	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2305	 76154	 0.027796	 0.026066	 0.0004	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2306	 76142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2306	 76142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2307	 2309	 0.040726	 0.03223	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2307	 2597	 0.03712	 0.069022	 0.00162	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2307	 76143	 0.049135	 0.075271	 0.00106	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2308	 2310	 0.037472	 0.027088	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2310	 76143	 0.045839	 0.036276	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2311	 2317	 0.007554	 0.030246	 0.00762	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75481	 2311	 0.001616	 0.011814	 0.00349	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2311	 76143	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2311	 76143	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76143	 2312	 0.011883	 0.030545	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2312	 76147	 0.022253	 0.057674	 0.00109	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76143	 2313	 0.020307	 0.048086	 0.00088	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2313	 76147	 0.025407	 0.045843	 0.00066	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2314	 2316	 0.002483	 0.006447	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2314	 2318	 0.005749	 0.015652	 0.00345	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2314	 76144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2314	 76144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76144	 2315	 0.012894	 0.025528	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2316	 76145	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2316	 76145	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2317	 2318	 0.00219	 0.008518	 0.00228	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2317	 76146	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2317	 76146	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2318	 76152	 0.007734	 0.034464	 0.00937	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2319	 2320	 0.004428	 0.010672	 0.00301	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2319	 76147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2319	 76147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2320	 2325	 0.004317	 0.011207	 0.00272	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2321	 2322	 0.032491	 0.035389	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2323	 2325	 0.005955	 0.015309	 0.00379	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2323	 76148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2323	 76148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2324	 76149	 0.034719	 0.037817	 0.00051	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2325	 2332	 0.005505	 0.01455	 0.00341	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2325	 76149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2325	 76149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2325	 76152	 0.013493	 0.035663	 0.00835	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2326	 2327	 0.033142	 0.022262	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2327	 2328	 0.030096	 0.023818	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2327	 76153	 0.038379	 0.11008	 0.00169	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2329	 76150	 0.053942	 0.042689	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2330	 2331	 0.025536	 0.033232	 0.00046	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2330	 76153	 0.022036	 0.05218	 0.00095	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2332	 2334	 0.004613	 0.01219	 0.00285	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2333	 2334	 0.00292	 0.007717	 0.00181	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2333	 2366	 0.004483	 0.011847	 0.00277	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2334	 76150	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2334	 76150	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2334	 76152	 0.004526	 0.015526	 0.00372	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2335	 2377	 0.006217	 0.024436	 0.00639	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2335	 76151	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2335	 76151	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2335	 76170	 0.002525	 0.009925	 0.0026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2336	 2378	 0.000261	 0.002958	 0.02693	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	2336	 76152	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2337	 76154	 0.026653	 0.020193	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2338	 2349	 0.003699	 0.014389	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2338	 76162	 0.005906	 0.026023	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2339	 2340	 0.003557	 0.009045	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2339	 76154	 0.004144	 0.010653	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2340	 2347	 0.006046	 0.010632	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2341	 2342	 0.001595	 0.004141	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2341	 76154	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2341	 76154	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2342	 76155	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2342	 76155	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2342	 76160	 0.003951	 0.011648	 0.00271	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2343	 2344	 0.001278	 0.004385	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2343	 76156	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2343	 76156	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2344	 76160	 0.001596	 0.005376	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2345	 2346	 0.002921	 0.00774	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2345	 76159	 0.003938	 0.019217	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2346	 2347	 0.002799	 0.007196	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2347	 2348	 0.002241	 0.007656	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2347	 76161	 0.009049	 0.040321	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2348	 2349	 0.004407	 0.017142	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2349	 76157	 0.017236	 0.014186	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2350	 2351	 0.00165	 0.00436	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2350	 76157	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2350	 76157	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2351	 2355	 0.00203	 0.00545	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2352	 76158	 0.024174	 0.018949	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2353	 2354	 0.008923	 0.007062	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2354	 76159	 0.009534	 0.015543	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2355	 2368	 0.003685	 0.009893	 0.00224	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2355	 76158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2355	 76158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2356	 76159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2356	 76159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2356	 76160	 0.001688	 0.005125	 0.00112	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2357	 76160	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2358	 2360	 0.002747	 0.007661	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2358	 2363	 0.002176	 0.005593	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76144	 2359	 0.050052	 0.03961	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 76162	 0.00983	 0.02527	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 76162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2360	 76162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2361	 2362	 0.005178	 0.013312	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 76166	 0.011833	 0.025262	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2362	 76163	 0.004351	 0.011185	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2363	 2364	 0.001081	 0.003914	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2363	 76163	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2363	 76163	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2364	 2366	 0.003191	 0.010946	 0.00262	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 76164	 0.037344	 0.028293	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2366	 2377	 0.005591	 0.018839	 0.00468	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2366	 76164	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2366	 76164	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2367	 2368	 0.003234	 0.009368	 0.00226	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2367	 2374	 0.001854	 0.006358	 0.00152	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2367	 76165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2367	 76165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2368	 76166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2368	 76166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76165	 2369	 0.020929	 0.037763	 0.00055	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2370	 76167	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2370	 76167	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76165	 2371	 0.010078	 0.026711	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76167	 2371	 0.011112	 0.031871	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2372	 2373	 0.001909	 0.007644	 0.00193	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2373	 2374	 0.002761	 0.012668	 0.00325	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2373	 2376	 0.002874	 0.007388	 0.00183	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2374	 76168	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2374	 76168	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76168	 2375	 0.01145	 0.026579	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2375	 76169	 0.017453	 0.052532	 0.00103	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 2395	 0.00357	 0.009177	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2377	 76169	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2377	 76169	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2378	 76170	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2379	 2380	 0.018751	 0.020624	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76171	 2380	 0.016156	 0.037508	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2380	 76172	 0.009909	 0.02842	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2381	 2383	 0.004743	 0.01899	 0.00478	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76170	 2381	 0.001736	 0.006949	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2382	 2384	 0.001762	 0.010576	 0.0032	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76170	 2382	 0.002091	 0.012994	 0.00367	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2382	 76172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2382	 76172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2383	 2401	 0.00626	 0.023794	 0.00666	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2384	 2385	 0.00221	 0.014	 0.0038	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2385	 2388	 0.001596	 0.011652	 0.00299	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2385	 76173	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2385	 76173	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76173	 2386	 0.011222	 0.022218	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75870	 2387	 0.029601	 0.049367	 0.00072	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75871	 2387	 0.042643	 0.045539	 0.00096	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76173	 2387	 0.032826	 0.093151	 0.00146	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2389	 2391	 0.004373	 0.017187	 0.0045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2389	 2396	 0.002479	 0.008638	 0.002	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2389	 76174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2389	 76174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2390	 2394	 0.019652	 0.044578	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2390	 76175	 0.019494	 0.049576	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2391	 76175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2391	 76175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2392	 76176	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2392	 76176	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2393	 2396	 0.007075	 0.019845	 0.00511	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2393	 76177	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2393	 76177	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76177	 2394	 0.054597	 0.06005	 0.0008	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2395	 2396	 0.002819	 0.008087	 0.00199	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2396	 76178	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2396	 76178	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76151	 2397	 0.077452	 0.054865	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76171	 2398	 0.032065	 0.071939	 0.00115	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76177	 2398	 0.024956	 0.057929	 0.0011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75505	 2399	 0.060795	 0.079904	 0.0011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2400	 2401	 0.004075	 0.01549	 0.00434	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2400	 76179	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2400	 76179	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75466	 2401	 0.003496	 0.033568	 0.00977	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2401	 76180	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2401	 76180	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75870	 2402	 0.021766	 0.050533	 0.00075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76180	 2402	 0.020385	 0.041893	 0.0008	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2403	 2405	 0.003462	 0.015167	 0.00522	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75869	 2403	 0.003241	 0.021743	 0.00525	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2403	 76181	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2403	 76181	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2404	 2405	 0.003099	 0.016474	 0.00382	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2405	 76182	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2405	 76182	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76168	 2406	 0.027546	 0.021591	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 76187	 0.00226	 0.007909	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2408	 2409	 0.008484	 0.006714	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2409	 2410	 0.017473	 0.013238	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2409	 76183	 0.004674	 0.003699	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2411	 2413	 0.010825	 0.007271	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2412	 2413	 0.004729	 0.00689	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2412	 2415	 0.006877	 0.005442	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2412	 2416	 0.007576	 0.004905	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2412	 76184	 0.001803	 0.007942	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2413	 2414	 0.012696	 0.009952	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2417	 2418	 0.000735	 0.001941	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2417	 76183	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2417	 76183	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2418	 2419	 0.000446	 0.001245	 0.00026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2418	 76184	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2418	 76184	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2419	 2421	 0.000456	 0.001344	 0.00031	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2420	 2421	 0.000344	 0.001149	 0.00029	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2420	 2422	 0.000628	 0.00163	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2420	 2423	 0.000964	 0.002887	 0.00065	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2420	 76185	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2420	 76185	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2421	 76186	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2421	 76186	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2422	 76187	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2422	 76187	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2423	 76188	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2423	 76188	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2424	 2427	 0.002118	 0.004194	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76062	 2424	 0.003799	 0.009661	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2425	 2426	 0.002101	 0.006026	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76061	 2425	 0.001884	 0.008431	 0.00017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 2427	 0.002907	 0.005325	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 2432	 0.003089	 0.002	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 76190	 0.007064	 0.009192	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2428	 2495	 0.000679	 0.001795	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75484	 2428	 0.001352	 0.007921	 0.00216	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2428	 76189	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2428	 76189	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2429	 2430	 0.003905	 0.003944	 5e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2429	 2433	 0.00469	 0.003391	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2430	 76190	 0.002096	 0.002755	 4e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2431	 2486	 0.001449	 0.003889	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2431	 2556	 0.003403	 0.009135	 0.00207	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2431	 76190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2431	 76190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2433	 2434	 0.002042	 0.004835	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2434	 2436	 0.003079	 0.006097	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2434	 2438	 0.006916	 0.007533	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2434	 2479	 0.006343	 0.008255	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2434	 2483	 0.001492	 0.003464	 5e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2435	 2438	 0.003611	 0.00261	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2436	 2437	 0.000512	 0.002729	 5e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	2436	 2479	 0.008282	 0.006554	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75485	 2437	 0.001731	 0.009838	 0.00018	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2439	 2440	 0.00307	 0.003016	 5e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2439	 2608	 0.005486	 0.0043	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2440	 2442	 0.005765	 0.004562	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2440	 76191	 0.001885	 0.003563	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 2452	 0.001182	 0.00297	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 2477	 0.001143	 0.003851	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75484	 2441	 0.000692	 0.002162	 0.00063	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 76191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2441	 76191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2443	 2445	 0.001113	 0.00543	 9e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2443	 2449	 0.005196	 0.008754	 0.00012	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76191	 2443	 0.001222	 0.003748	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2444	 2445	 0.004041	 0.003168	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2445	 2447	 0.000705	 0.001868	 5e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2446	 2447	 0.001752	 0.005027	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2446	 2448	 0.0027	 0.009007	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75480	 2446	 0.009105	 0.035421	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2446	 76197	 0.002651	 0.00814	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 2457	 0.004105	 0.009432	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 76193	 0.002656	 0.005258	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2450	 2454	 0.001167	 0.004539	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2450	 76192	 0.001158	 0.005653	 0.0001	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2451	 2452	 0.000513	 0.00144	 0.00037	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2451	 2453	 0.000476	 0.001809	 0.00051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2451	 76192	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2451	 76192	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2452	 76193	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2452	 76193	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75479	 2453	 0.00035	 0.002171	 0.00053	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2454	 2457	 0.001619	 0.009956	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2454	 76222	 0.004541	 0.01054	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2455	 76222	 0.012847	 0.009287	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2456	 2461	 0.000815	 0.002501	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2456	 76194	 0.001388	 0.007021	 0.00012	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2457	 2460	 0.001037	 0.004238	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2458	 2460	 0.001046	 0.003661	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2458	 2465	 0.001999	 0.004571	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 2460	 0.005265	 0.004167	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2460	 2461	 0.001824	 0.005233	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75479	 2462	 0.001773	 0.008603	 0.00197	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2462	 76194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2462	 76194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2463	 2574	 0.015782	 0.011957	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2464	 2593	 0.005685	 0.013002	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2464	 76223	 0.004181	 0.01463	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2465	 2604	 0.006749	 0.01735	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75498	 2466	 0.008551	 0.006291	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2467	 2468	 0.005307	 0.004159	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 2470	 0.005701	 0.004038	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2469	 2473	 0.005628	 0.007843	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2469	 2602	 0.00467	 0.003024	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75498	 2470	 0.001592	 0.005569	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 76196	 0.003445	 0.015179	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2471	 2603	 0.00091	 0.002404	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2471	 76195	 0.000873	 0.003553	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2472	 76196	 0.004018	 0.00318	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2473	 2474	 0.006396	 0.005062	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2473	 76196	 0.002047	 0.004682	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2475	 76204	 0.007682	 0.006021	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2476	 76195	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2477	 2478	 0.000623	 0.001737	 0.00036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2477	 76197	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2477	 76197	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76195	 2478	 0.001055	 0.003729	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2478	 76198	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2478	 76198	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2479	 2480	 0.008338	 0.005398	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76198	 2479	 0.002984	 0.005908	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2480	 76201	 0.002594	 0.006596	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2481	 2487	 0.000456	 0.001204	 0.00028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2481	 76199	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2481	 76199	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2482	 2484	 0.007516	 0.005049	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76199	 2482	 0.004752	 0.003496	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76199	 2483	 0.001725	 0.005755	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2485	 76200	 0.00759	 0.005584	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2486	 2488	 0.000683	 0.002014	 0.00047	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76195	 2486	 0.00042	 0.003162	 0.00088	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2486	 76200	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2486	 76200	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76195	 2487	 0.000631	 0.002283	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2487	 76201	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2487	 76201	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2488	 76202	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2488	 76202	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2489	 2490	 0.007858	 0.006219	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2490	 2491	 0.006084	 0.004398	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76200	 2490	 0.004328	 0.008569	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76190	 2492	 0.010666	 0.008441	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2493	 2494	 0.002335	 0.005422	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76190	 2493	 0.002873	 0.007958	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2494	 76203	 0.002215	 0.005143	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2495	 76203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2495	 76203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2496	 2497	 0.007721	 0.005681	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2496	 2559	 0.008032	 0.006356	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2496	 2609	 0.005832	 0.0048	 0.0001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76203	 2496	 0.00248	 0.006557	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2497	 2557	 0.006111	 0.004836	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2498	 2501	 0.014954	 0.010045	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2498	 2555	 0.011934	 0.009444	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2499	 2501	 0.012331	 0.009759	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2500	 2501	 0.00882	 0.00571	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2500	 2503	 0.009329	 0.007312	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2501	 2502	 0.008138	 0.006165	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2501	 2505	 0.015158	 0.013583	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76202	 2501	 0.003747	 0.014576	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2504	 2509	 0.012343	 0.007991	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2505	 2507	 0.005182	 0.007859	 0.00011	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2506	 2507	 0.006525	 0.006304	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2506	 76209	 0.007653	 0.006858	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2507	 2508	 0.002572	 0.005092	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2507	 2522	 0.011014	 0.00713	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2508	 76207	 0.003991	 0.010149	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2509	 2516	 0.010384	 0.007506	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2510	 2516	 0.0081	 0.00641	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2511	 2515	 0.000885	 0.002409	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76195	 2511	 0.00121	 0.004077	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2511	 76204	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2511	 76204	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2512	 76205	 0.005081	 0.010061	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2513	 2519	 0.000941	 0.002486	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2513	 76205	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2513	 76205	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2514	 76206	 0.007993	 0.005175	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2515	 2518	 0.000565	 0.001465	 0.00036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2515	 76206	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2515	 76206	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2516	 2517	 0.008342	 0.006602	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76204	 2516	 0.002917	 0.006617	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2518	 2519	 0.00066	 0.001771	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2518	 76207	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2518	 76207	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2519	 2524	 0.00104	 0.002792	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2520	 2521	 0.008191	 0.005303	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2520	 2523	 0.005129	 0.00518	 7e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2522	 2523	 0.009704	 0.007139	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2523	 2525	 0.007702	 0.005456	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2523	 76208	 0.003365	 0.011224	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2524	 76208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2524	 76208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2526	 2527	 0.000847	 0.002042	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2526	 2532	 0.000726	 0.001949	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2527	 2598	 0.001099	 0.002552	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2527	 76209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2527	 76209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2528	 2529	 0.008942	 0.007009	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76209	 2528	 0.009902	 0.007836	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2529	 76212	 0.009475	 0.008548	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2530	 2531	 0.010828	 0.007827	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2531	 76211	 0.009753	 0.009075	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2532	 2535	 0.001929	 0.004477	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2533	 2534	 0.012697	 0.009341	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2534	 76210	 0.005021	 0.009197	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2535	 76210	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2535	 76210	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2536	 2537	 0.001242	 0.003282	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2536	 76211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2536	 76211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2537	 2539	 0.00093	 0.002458	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2538	 76212	 0.01444	 0.011319	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2538	 76221	 0.013733	 0.010868	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2539	 2541	 0.000648	 0.001911	 0.00044	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2540	 76212	 0.007229	 0.005721	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2541	 2601	 0.001452	 0.003838	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2541	 76212	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2541	 76212	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2542	 2550	 0.018886	 0.017396	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2542	 2552	 0.011916	 0.009808	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2542	 2600	 0.007302	 0.007173	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2542	 76213	 0.005792	 0.010947	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2542	 76220	 0.022701	 0.043474	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2543	 76214	 0.012118	 0.008915	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2544	 2601	 0.000714	 0.001795	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2544	 76213	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2544	 76213	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76213	 2545	 0.011105	 0.008705	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2545	 76214	 0.01458	 0.011428	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2546	 2548	 0.000671	 0.002088	 0.00044	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2546	 2573	 0.00144	 0.004372	 0.00096	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2546	 76214	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2546	 76214	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2547	 2548	 0.000731	 0.00199	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2547	 2562	 0.000832	 0.002319	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2548	 76215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2548	 76215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2549	 2550	 0.011543	 0.008176	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76215	 2550	 0.005445	 0.009172	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2551	 76217	 0.008613	 0.005576	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2552	 76216	 0.00757	 0.007593	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2553	 2600	 0.01814	 0.014219	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2554	 2556	 0.001007	 0.002616	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2554	 2598	 0.001136	 0.003094	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2554	 76216	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2554	 76216	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2555	 76217	 0.008343	 0.009176	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2556	 76217	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2556	 76217	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2558	 2559	 0.008785	 0.006886	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76203	 2559	 0.010206	 0.013414	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76217	 2559	 0.006943	 0.012527	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2560	 2563	 0.019651	 0.017608	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2561	 76218	 0.011743	 0.011861	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2562	 76218	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2562	 76218	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76114	 2563	 0.014194	 0.063248	 0.00107	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76218	 2563	 0.012191	 0.018676	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2564	 2565	 0.015263	 0.012079	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2565	 2599	 0.005174	 0.011887	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2566	 76219	 0.002968	 0.009105	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2566	 76220	 0.031164	 0.022528	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2567	 76220	 0.016683	 0.01206	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76214	 2568	 0.013008	 0.010294	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76215	 2568	 0.013782	 0.01014	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2569	 2599	 0.004875	 0.009064	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2569	 76220	 0.00362	 0.008405	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2570	 2572	 0.001971	 0.006761	 0.00162	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2570	 76219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2570	 76219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2571	 76220	 0.01584	 0.012536	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2572	 2573	 0.001201	 0.00354	 0.00082	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76121	 2572	 0.005743	 0.025593	 0.00695	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2572	 76220	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2572	 76220	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2573	 76221	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2573	 76221	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76194	 2574	 0.004052	 0.007126	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2575	 76222	 0.012017	 0.00951	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2576	 2577	 0.000558	 0.002271	 0.00055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75479	 2576	 0.000709	 0.004491	 0.00122	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2576	 76222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2576	 76222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2577	 2578	 0.000603	 0.002068	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2578	 2580	 0.000497	 0.001755	 0.0004	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76045	 2579	 0.002204	 0.00838	 0.00235	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2579	 76223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2579	 76223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2580	 2581	 0.000734	 0.001769	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2580	 76225	 0.001351	 0.005577	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2582	 2583	 0.010523	 0.008248	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2582	 2588	 0.006431	 0.012317	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76045	 2584	 0.002379	 0.011833	 0.00382	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2584	 76224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2584	 76224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2585	 2586	 0.013191	 0.009535	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76224	 2585	 0.009365	 0.014949	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75502	 2587	 0.008674	 0.01565	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76223	 2588	 0.00401	 0.015599	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2589	 2590	 0.008534	 0.006279	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2589	 2591	 0.00423	 0.009718	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2589	 76226	 0.002532	 0.008447	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 2592	 0.007633	 0.013772	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2593	 2594	 0.002152	 0.00753	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2593	 2607	 0.014874	 0.011409	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2594	 2596	 0.004262	 0.013075	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2595	 2596	 0.01538	 0.012056	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2602	 2610	 0.007933	 0.006085	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75485	 2605	 0.006958	 0.005507	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2606	 76225	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76198	 2608	 0.009094	 0.005888	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76105	 2609	 0.00601	 0.004756	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2611	 76230	 0.0569	 0.11266	 0.00165	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2612	 2890	 0.016945	 0.11086	 0.02821	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2612	 2932	 0.020098	 0.065564	 0.01741	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75488	 2612	 0.012647	 0.084768	 0.02598	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2612	 76227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2612	 76227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2613	 2615	 0.11716	 0.092721	 0.00117	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2614	 2618	 0.00322	 0.031556	 0.00988	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75488	 2614	 0.009214	 0.047103	 0.01284	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2614	 76228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2614	 76228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76228	 2615	 0.020039	 0.041008	 0.00101	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2616	 2617	 0.024666	 0.082284	 0.0013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76228	 2616	 0.006161	 0.023967	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2617	 2658	 0.038739	 0.092401	 0.00207	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2618	 2623	 0.001335	 0.011563	 0.00415	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 2620	 0.028137	 0.079845	 0.00125	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 2658	 0.027728	 0.10668	 0.00182	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2620	 2621	 0.010286	 0.023879	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2621	 76229	 0.011828	 0.01679	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2622	 2623	 0.000774	 0.007676	 0.00209	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2622	 76229	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2622	 76229	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2622	 76231	 0.00283	 0.021315	 0.00591	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2623	 76230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2623	 76230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76229	 2624	 0.007131	 0.040536	 0.00073	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2624	 76237	 0.026036	 0.09301	 0.00185	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2625	 2911	 0.001528	 0.020006	 0.18122	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2625	 76231	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76232	 2626	 0.013705	 0.065784	 0.00197	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2626	 76233	 0.007003	 0.034748	 0.00083	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2627	 2628	 0.000948	 0.005287	 0.00135	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2627	 2654	 0.005743	 0.016471	 0.00405	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2627	 76233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2627	 76233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2628	 2629	 0.002527	 0.007047	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2628	 76234	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2628	 76234	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2629	 2632	 0.00171	 0.004591	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2630	 76235	 0.008902	 0.020663	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2631	 2635	 0.005961	 0.026263	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2631	 2646	 0.012482	 0.033082	 0.00084	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2632	 2634	 0.001041	 0.002796	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2632	 76235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2632	 76235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2633	 2634	 0.001407	 0.003654	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2633	 76236	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2633	 76236	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2635	 2645	 0.021691	 0.045589	 0.00083	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76236	 2635	 0.009833	 0.025008	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2635	 76237	 0.009797	 0.053949	 0.00122	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2636	 2638	 0.006568	 0.012213	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2636	 76238	 0.009635	 0.020646	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2637	 2640	 0.002362	 0.009458	 0.00238	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76231	 2637	 0.001477	 0.01199	 0.00382	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2637	 76237	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2637	 76237	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2638	 2639	 0.002219	 0.007403	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76237	 2639	 0.004537	 0.020216	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2640	 2642	 0.001485	 0.004164	 0.00107	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2640	 76238	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2640	 76238	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76238	 2641	 0.011551	 0.009054	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2642	 2643	 0.001492	 0.004531	 0.00099	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2642	 76239	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2642	 76239	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2643	 76240	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2643	 76240	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76239	 2644	 0.01555	 0.029388	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76240	 2645	 0.006086	 0.034592	 0.00063	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76103	 2646	 0.017774	 0.033048	 0.00077	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2647	 2648	 0.007864	 0.02141	 0.00472	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2647	 76241	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2647	 76241	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2649	 2650	 0.007191	 0.018486	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2649	 2651	 0.011113	 0.011116	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2650	 76243	 0.020247	 0.078766	 0.00131	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2651	 2652	 0.03704	 0.056742	 0.0008	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76015	 2652	 0.032006	 0.063369	 0.00093	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2653	 76266	 0.04189	 0.055057	 0.00075	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2654	 2669	 0.004763	 0.016339	 0.00391	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2655	 2668	 0.12631	 0.099968	 0.00126	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2656	 2657	 0.016527	 0.070979	 0.0013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2656	 2658	 0.036808	 0.087163	 0.00159	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2656	 2659	 0.024707	 0.1101	 0.00187	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2657	 2665	 0.024258	 0.086658	 0.00172	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75976	 2658	 0.046135	 0.2837	 0.00512	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75993	 2659	 0.017151	 0.10544	 0.0019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2660	 2661	 0.017677	 0.068771	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2660	 2778	 0.020584	 0.08008	 0.00134	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2660	 2779	 0.00642	 0.056076	 0.00139	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2661	 2663	 0.023183	 0.061446	 0.00156	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2662	 2715	 0.001822	 0.008359	 0.00214	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2662	 2768	 0.006488	 0.030709	 0.00738	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2662	 76242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2662	 76242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76242	 2663	 0.007837	 0.022238	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2664	 2665	 0.02717	 0.053794	 0.00079	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2665	 2667	 0.018925	 0.031434	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2665	 2668	 0.033664	 0.066652	 0.00098	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2665	 76247	 0.033454	 0.077669	 0.00116	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2666	 2667	 0.018288	 0.042459	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2666	 76244	 0.007144	 0.013284	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2669	 2670	 0.00335	 0.011675	 0.00271	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2669	 2671	 0.008071	 0.020288	 0.00526	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2669	 76243	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2669	 76243	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2670	 2672	 0.00216	 0.008646	 0.00218	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2671	 76244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2671	 76244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2671	 76252	 0.004251	 0.012909	 0.00283	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2672	 2673	 0.000842	 0.004088	 0.00093	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2673	 2674	 0.000456	 0.003664	 0.00103	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75469	 2673	 0.023324	 0.14787	 0.04019	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75488	 2673	 0.025147	 0.15478	 0.04471	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76014	 2673	 0.006557	 0.043991	 0.01062	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2673	 76245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2673	 76245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2674	 76246	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2674	 76246	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2674	 76252	 0.000668	 0.00448	 0.00108	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2675	 2696	 0.010809	 0.011773	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2676	 2682	 0.004082	 0.010493	 0.0026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2676	 76247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2676	 76247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2676	 76252	 0.002668	 0.007991	 0.0018	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 2678	 0.047173	 0.03054	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76247	 2677	 0.009945	 0.015873	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2678	 76248	 0.01046	 0.016696	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2679	 2680	 0.0038	 0.00882	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76247	 2679	 0.006357	 0.021208	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2680	 2681	 0.001634	 0.007198	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2680	 2686	 0.00329	 0.010593	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2681	 76248	 0.00188	 0.009176	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2682	 2683	 0.001725	 0.005084	 0.00118	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2682	 76248	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2682	 76248	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2683	 2715	 0.003538	 0.014975	 0.00337	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2684	 76257	 0.021453	 0.023366	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2685	 2688	 0.000872	 0.002303	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2685	 76249	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2685	 76249	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2686	 2692	 0.003513	 0.009311	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76249	 2686	 0.00288	 0.009608	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2687	 76250	 0.005361	 0.003471	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2688	 2689	 0.000601	 0.001561	 0.00038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2688	 76250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2688	 76250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2689	 2711	 0.00194	 0.005208	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2689	 2713	 0.001463	 0.003928	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2690	 2712	 0.010832	 0.008491	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2691	 2692	 0.007923	 0.00627	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2692	 2693	 0.004845	 0.009496	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2693	 2694	 0.008524	 0.011203	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2694	 2705	 0.005788	 0.011343	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2694	 2712	 0.02004	 0.02518	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2694	 76253	 0.005371	 0.030221	 0.00065	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2695	 2701	 0.00072	 0.002009	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2695	 76251	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2695	 76251	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76251	 2696	 0.002101	 0.008334	 0.00024	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2696	 76253	 0.003292	 0.018715	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76246	 2697	 0.009074	 0.017149	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2698	 76252	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2699	 2729	 0.024688	 0.019537	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2700	 76254	 0.013623	 0.010781	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2701	 2702	 0.002415	 0.006382	 0.00149	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2701	 76254	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2701	 76254	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2702	 2708	 0.001428	 0.003983	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76254	 2703	 0.017365	 0.012776	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2704	 2705	 0.010611	 0.009774	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2704	 2707	 0.010031	 0.013184	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2705	 2706	 0.012339	 0.009765	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2706	 76256	 0.011446	 0.012589	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2707	 76255	 0.012166	 0.020494	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2708	 2724	 0.002786	 0.00777	 0.00163	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2709	 76255	 0.020276	 0.018168	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2710	 2711	 0.001424	 0.003822	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2710	 2721	 0.003696	 0.012053	 0.0032	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2710	 76255	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2710	 76255	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2711	 76256	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2711	 76256	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76250	 2712	 0.013376	 0.011985	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76256	 2712	 0.010796	 0.011874	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2713	 2719	 0.001672	 0.005454	 0.00145	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2713	 76257	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2713	 76257	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76257	 2714	 0.017028	 0.013476	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2715	 76258	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2715	 76258	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76258	 2716	 0.031264	 0.034053	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2717	 76260	 0.018008	 0.035654	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2718	 76259	 0.024566	 0.018074	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2719	 2721	 0.001897	 0.007596	 0.00191	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2719	 76259	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2719	 76259	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76259	 2720	 0.025975	 0.020556	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2721	 2722	 0.00335	 0.008611	 0.00213	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2721	 76260	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2721	 76260	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2722	 2723	 0.002195	 0.00753	 0.0018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2722	 2758	 0.001879	 0.011657	 0.00282	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2723	 2724	 0.002055	 0.006392	 0.00133	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2723	 2726	 0.004177	 0.011038	 0.00258	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 76261	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2724	 76261	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2725	 2726	 0.002985	 0.01024	 0.00245	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2725	 2755	 0.004275	 0.015112	 0.00341	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2726	 2781	 0.002821	 0.009506	 0.00236	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2726	 76262	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2726	 76262	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2727	 2741	 0.006378	 0.017364	 0.00383	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2727	 76263	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2727	 76263	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2728	 2731	 0.003372	 0.00994	 0.00231	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2728	 2781	 0.002065	 0.007084	 0.0017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2728	 76264	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2728	 76264	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2729	 2730	 0.008322	 0.021394	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76253	 2729	 0.008164	 0.020679	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76264	 2730	 0.005914	 0.025027	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2731	 2740	 0.004709	 0.012641	 0.00286	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2731	 76265	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2731	 76265	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2732	 2733	 0.004912	 0.014483	 0.00337	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76252	 2732	 0.002772	 0.010896	 0.00285	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2732	 76266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2732	 76266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2733	 76267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2733	 76267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2734	 2735	 0.005753	 0.014909	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76015	 2734	 0.032879	 0.036163	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76267	 2735	 0.005156	 0.019836	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76101	 2736	 0.012258	 0.034783	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2736	 76268	 0.005174	 0.024025	 0.00066	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2737	 2780	 0.002548	 0.010016	 0.00262	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2737	 76268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2737	 76268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2738	 2739	 0.00203	 0.006838	 0.0017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2738	 2740	 0.002766	 0.00731	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2738	 76269	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2738	 76269	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2740	 2780	 0.00257	 0.013129	 0.0033	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2740	 76270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2740	 76270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2741	 2748	 0.010293	 0.027205	 0.00637	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2741	 2756	 0.002855	 0.011618	 0.00283	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2741	 76271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2741	 76271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2742	 2746	 0.002145	 0.007802	 0.00239	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76271	 2743	 0.020819	 0.047224	 0.00094	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2743	 76273	 0.007332	 0.021028	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2744	 76272	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2744	 76272	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2745	 2746	 0.000545	 0.002119	 0.00057	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76272	 2745	 0.001052	 0.004454	 0.001	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2746	 2748	 0.001764	 0.013896	 0.00406	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2746	 76273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2746	 76273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75494	 2747	 0.020611	 0.018469	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75477	 2748	 0.002999	 0.012007	 0.00302	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75550	 2748	 0.008527	 0.033516	 0.00877	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2749	 3285	 0.002286	 0.007456	 0.00198	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75477	 2749	 0.001434	 0.005453	 0.00153	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2750	 2751	 0.004449	 0.023703	 0.00042	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75478	 2750	 0.022298	 0.037562	 0.00054	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76139	 2750	 0.018268	 0.06094	 0.00097	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2751	 76275	 0.00893	 0.045438	 0.00103	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2752	 76274	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2753	 2754	 0.001748	 0.01041	 0.00274	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76274	 2753	 0.001087	 0.007542	 0.00215	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 2755	 0.001062	 0.005248	 0.00153	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 76276	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2754	 76276	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2755	 2756	 0.001588	 0.006719	 0.00151	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76274	 2755	 0.005312	 0.021617	 0.00527	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76275	 2757	 0.060828	 0.11497	 0.00186	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76276	 2757	 0.07945	 0.062277	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2757	 76277	 0.062569	 0.045231	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2758	 2759	 0.004639	 0.025455	 0.00673	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2758	 76277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2758	 76277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2760	 2761	 0.010621	 0.027302	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2761	 76279	 0.013641	 0.06548	 0.00196	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2762	 2763	 0.008945	 0.022995	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2762	 3232	 0.079176	 0.13205	 0.00192	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2763	 2764	 0.00286	 0.009539	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 76278	 0.00284	 0.013858	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2765	 76278	 0.029234	 0.022149	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2766	 2767	 0.002283	 0.008971	 0.00235	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2766	 76278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2766	 76278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2767	 2770	 0.008855	 0.022763	 0.00564	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2767	 76279	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2767	 76279	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75490	 2769	 0.031099	 0.056961	 0.00098	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2770	 2772	 0.001231	 0.004221	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 76280	 0.013704	 0.010845	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2772	 76280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2772	 76280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2773	 2775	 0.006714	 0.048504	 0.00092	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76280	 2773	 0.001286	 0.009401	 0.00017	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76280	 2774	 0.021954	 0.03363	 0.00047	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2776	 76281	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2776	 76281	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2777	 2778	 0.072351	 0.055498	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76281	 2778	 0.013794	 0.06899	 0.00123	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75976	 2779	 0.00819	 0.067328	 0.00131	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75493	 2780	 0.018285	 0.04833	 0.01131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2780	 76282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2780	 76282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2781	 76283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2781	 76283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76019	 2782	 0.010717	 0.060921	 0.0011	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76082	 2782	 0.052945	 0.13465	 0.00213	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2783	 2785	 0.019936	 0.057179	 0.00088	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2784	 2794	 0.12295	 0.088884	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2785	 76286	 0.020257	 0.066848	 0.00108	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2786	 76284	 0.10462	 0.082799	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2787	 2971	 0.005584	 0.022355	 0.00563	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2787	 2973	 0.006119	 0.01617	 0.00378	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2787	 76284	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2787	 76284	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2788	 2790	 0.008925	 0.027103	 0.00594	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2788	 2797	 0.00919	 0.02858	 0.00596	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2789	 2960	 0.11266	 0.089164	 0.00112	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2790	 76285	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2790	 76285	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76285	 2791	 0.005958	 0.050601	 0.00118	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 76286	 0.006891	 0.056649	 0.0011	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2792	 2846	 0.021363	 0.059581	 0.01251	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2792	 76286	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2792	 76286	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2792	 76332	 0.015859	 0.098584	 0.02784	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2793	 2794	 0.014856	 0.025026	 0.00036	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76286	 2793	 0.008762	 0.022524	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2795	 2796	 0.016862	 0.056252	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76286	 2795	 0.014962	 0.066671	 0.00113	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2796	 76288	 0.072496	 0.20575	 0.00323	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 3064	 0.015331	 0.046558	 0.0102	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 2799	 0.03416	 0.11953	 0.00248	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 2834	 0.053876	 0.23742	 0.00412	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2799	 2800	 0.070511	 0.16371	 0.00243	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75824	 2799	 0.11767	 0.3927	 0.00623	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2800	 2801	 0.044809	 0.078803	 0.00148	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2801	 76287	 0.19417	 0.17403	 0.00356	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2803	 76287	 0.14045	 0.11116	 0.0014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2804	 2806	 0.012924	 0.032489	 0.00842	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2804	 76287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2804	 76287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2805	 2806	 0.011136	 0.02943	 0.00689	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2806	 76288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2806	 76288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76287	 2807	 0.262	 0.16967	 0.00323	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76288	 2808	 0.15069	 0.11812	 0.00152	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2809	 2810	 0.038194	 0.10955	 0.00168	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2809	 2935	 0.10639	 0.26412	 0.00439	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75556	 2810	 0.019723	 0.060505	 0.00164	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2810	 76448	 0.014099	 0.071743	 0.00163	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2811	 2815	 0.13409	 0.16053	 0.00267	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2812	 2815	 0.043526	 0.11189	 0.00173	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76227	 2812	 0.0846	 0.19643	 0.00292	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76227	 2813	 0.065442	 0.10669	 0.00163	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2814	 2824	 0.22801	 0.18047	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 76289	 0.019495	 0.085896	 0.00149	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2816	 2820	 0.00564	 0.014617	 0.00442	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2816	 2932	 0.011328	 0.071767	 0.01948	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2816	 76289	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2816	 76289	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2817	 2818	 0.024381	 0.047783	 0.00072	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2818	 76290	 0.010161	 0.044517	 0.00096	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2819	 76290	 0.042999	 0.027838	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2820	 2822	 0.006162	 0.028269	 0.00724	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2820	 76290	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2820	 76290	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76290	 2821	 0.024481	 0.04847	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2822	 3473	 0.009448	 0.029382	 0.00613	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2822	 76449	 0.007421	 0.03141	 0.00707	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2823	 3481	 0.006254	 0.016529	 0.00387	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2823	 76291	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2823	 76291	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75489	 2824	 0.052122	 0.20279	 0.00339	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76291	 2824	 0.09502	 0.095977	 0.00127	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2825	 76292	 0.43165	 0.33856	 0.00435	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2826	 3385	 0.012675	 0.051584	 0.01257	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2826	 76292	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2826	 76292	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2827	 2828	 0.10409	 0.2417	 0.0036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75819	 2827	 0.11188	 0.25979	 0.00386	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76292	 2827	 0.26652	 0.29324	 0.00391	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 76294	 0.11035	 0.3166	 0.00487	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 76434	 0.12677	 0.2665	 0.00486	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2829	 3387	 0.021912	 0.059666	 0.01315	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75545	 2829	 0.025479	 0.071489	 0.01841	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2829	 76293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2829	 76293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75545	 2830	 0.007178	 0.029638	 0.00701	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2830	 76294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2830	 76294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76294	 2831	 0.049159	 0.038904	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76294	 2832	 0.15683	 0.11539	 0.00169	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75546	 2833	 0.037206	 0.062677	 0.00089	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75546	 2834	 0.037651	 0.19048	 0.00331	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76293	 2835	 0.08497	 0.16274	 0.00256	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 76295	 0.21515	 0.16506	 0.00222	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2836	 2837	 0.017428	 0.047454	 0.01046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2836	 76295	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2836	 76295	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75545	 2837	 0.032142	 0.11031	 0.02645	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2839	 2841	 0.11106	 0.35776	 0.0061	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2840	 2843	 0.27312	 0.2162	 0.00272	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2841	 3416	 0.037751	 0.12896	 0.0028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2842	 3416	 0.23833	 0.15433	 0.00294	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2843	 76296	 0.067191	 0.15438	 0.00234	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2844	 76298	 0.16701	 0.10813	 0.00206	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2846	 76296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2846	 76296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76296	 2847	 0.074451	 0.11885	 0.00274	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2848	 2849	 0.007313	 0.03355	 0.0086	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2848	 2969	 0.008144	 0.033626	 0.00796	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2848	 76297	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2848	 76297	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2849	 2851	 0.006384	 0.030981	 0.00708	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2849	 76298	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2849	 76298	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2850	 76303	 0.16653	 0.13055	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2851	 76301	 0.004712	 0.020998	 0.00571	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 2853	 0.000215	 0.002432	 0.02214	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 3362	 0.003594	 0.038165	 0.57383	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 3362	 0.003594	 0.038165	 0.57383	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 76299	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2853	 76301	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76301	 2854	 0.004615	 0.01198	 0.00291	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2854	 76303	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2854	 76303	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2855	 2856	 0.021067	 0.014923	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2855	 2861	 0.0215	 0.013919	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2856	 76304	 0.034652	 0.027423	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2857	 2860	 0.013473	 0.00905	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2858	 76304	 0.018863	 0.013636	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2859	 2939	 0.004698	 0.012415	 0.00291	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2859	 2941	 0.004987	 0.013906	 0.00292	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2859	 76304	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2859	 76304	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2860	 2877	 0.003951	 0.00659	 0.0001	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2861	 76324	 0.009351	 0.01229	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2862	 2864	 0.013888	 0.010991	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2863	 2869	 0.007168	 0.005619	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2864	 2865	 0.026866	 0.019422	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2864	 2942	 0.021813	 0.028669	 0.00039	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2864	 76324	 0.004061	 0.024678	 0.00046	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2866	 2881	 0.001298	 0.00779	 0.00236	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2866	 2989	 0.002596	 0.01326	 0.00334	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2866	 76305	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2866	 76305	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76305	 2867	 0.00985	 0.020702	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2867	 76307	 0.003439	 0.011028	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2868	 76307	 0.011632	 0.009205	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2869	 76306	 0.006837	 0.008184	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2870	 2871	 0.00024	 0.001017	 0.00023	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2870	 2939	 0.000502	 0.002125	 0.00048	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2871	 2872	 0.000321	 0.001358	 0.00031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2872	 2873	 0.000657	 0.002254	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2872	 76306	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2872	 76306	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2873	 2881	 0.001138	 0.004738	 0.00148	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2873	 76307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2873	 76307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76307	 2874	 0.007138	 0.009382	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2875	 2879	 0.025279	 0.020006	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2875	 76308	 0.004806	 0.021177	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2876	 2877	 0.014593	 0.011548	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2877	 2878	 0.014775	 0.01087	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2877	 76324	 0.002397	 0.0105	 0.00023	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2880	 76308	 0.007021	 0.020136	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2880	 76312	 0.016377	 0.037148	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2881	 76308	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2881	 76308	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2881	 76309	 0.000867	 0.006592	 0.00207	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2882	 76309	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2883	 76311	 0.082273	 0.065111	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76304	 2884	 0.0527	 0.047547	 0.0008	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2885	 2939	 0.004296	 0.014476	 0.0036	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2885	 76311	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2885	 76311	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75539	 2886	 0.00449	 0.014643	 0.00389	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 76312	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2886	 76312	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2887	 2888	 0.028258	 0.043288	 0.00061	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76312	 2887	 0.016914	 0.055816	 0.0009	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2889	 2893	 0.007379	 0.018765	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2889	 76313	 0.011278	 0.037622	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2890	 2897	 0.003197	 0.012565	 0.00329	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2890	 76313	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2890	 76313	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2890	 76319	 0.003787	 0.01766	 0.00437	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2891	 2892	 0.004604	 0.010903	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2891	 2906	 0.01091	 0.02293	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2892	 76315	 0.005394	 0.019269	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 2894	 0.004817	 0.009537	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2894	 76314	 0.01642	 0.013515	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2895	 2897	 0.001859	 0.006571	 0.00148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2895	 2899	 0.001607	 0.005413	 0.00135	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2895	 2908	 0.001079	 0.0042	 0.00112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2895	 76314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2895	 76314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2895	 76319	 0.005475	 0.02191	 0.0074	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76314	 2896	 0.005225	 0.010345	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2897	 76315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2897	 76315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76315	 2898	 0.008466	 0.014119	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2899	 2903	 0.002676	 0.007889	 0.00184	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2900	 2901	 0.006974	 0.016023	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2900	 2902	 0.007166	 0.013325	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2901	 76318	 0.011618	 0.045197	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2902	 76316	 0.008517	 0.028412	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2903	 2905	 0.001111	 0.002936	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2904	 2906	 0.01471	 0.022298	 0.00046	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76019	 2904	 0.080893	 0.1815	 0.00289	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2904	 76316	 0.012605	 0.017182	 0.00038	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2905	 76316	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2905	 76316	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2907	 2908	 0.002655	 0.009289	 0.00308	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 2988	 0.003733	 0.011007	 0.00256	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 76317	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2907	 76317	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2909	 76318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2909	 76318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2909	 76319	 0.010248	 0.033425	 0.00887	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2910	 2986	 0.00368	 0.009554	 0.00232	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2910	 76319	 0.002289	 0.006051	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2911	 76319	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2912	 2913	 0.061883	 0.040064	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76312	 2913	 0.025397	 0.050285	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2914	 2916	 0.004851	 0.014731	 0.00323	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76319	 2914	 0.003983	 0.010693	 0.00242	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2915	 2926	 0.075706	 0.059343	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2915	 76321	 0.031721	 0.062806	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 2932	 0.011223	 0.072307	 0.01896	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 76321	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2916	 76321	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2917	 2918	 0.046516	 0.035681	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2918	 2919	 0.016327	 0.032327	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76321	 2918	 0.00853	 0.052441	 0.00095	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2919	 2923	 0.049072	 0.097161	 0.00143	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2919	 2924	 0.045624	 0.090333	 0.00133	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76320	 2919	 0.13777	 0.1811	 0.00248	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2920	 2921	 0.038696	 0.076615	 0.00112	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76313	 2920	 0.026455	 0.06728	 0.00106	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2922	 2923	 0.017032	 0.039535	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2922	 2931	 0.030128	 0.071344	 0.0013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2925	 2926	 0.10722	 0.078887	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 2928	 0.071746	 0.12362	 0.00197	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76311	 2927	 0.027272	 0.095487	 0.00264	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2929	 2934	 0.16675	 0.13197	 0.00166	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2929	 2945	 0.094915	 0.22039	 0.00328	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2929	 76322	 0.069732	 0.17736	 0.0028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 76322	 0.066675	 0.078159	 0.00136	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2931	 76322	 0.037368	 0.12466	 0.00198	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2932	 76322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2932	 76322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76322	 2933	 0.15166	 0.11491	 0.00158	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2935	 2967	 0.12484	 0.17034	 0.00304	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2935	 76331	 0.1204	 0.21644	 0.00389	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76318	 2936	 0.015015	 0.035555	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2936	 76323	 0.006011	 0.029333	 0.00051	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2937	 3034	 0.006189	 0.016068	 0.0039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2937	 76323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2937	 76323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76323	 2938	 0.038168	 0.030206	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76309	 2939	 0.00212	 0.013865	 0.00513	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2939	 76324	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2939	 76324	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76310	 2940	 0.005257	 0.010302	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2941	 2946	 0.005011	 0.017189	 0.00412	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2941	 76325	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2941	 76325	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75544	 2943	 0.014134	 0.068972	 0.00119	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2943	 76330	 0.023569	 0.084197	 0.00167	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75544	 2944	 0.016712	 0.047932	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2944	 76333	 0.051197	 0.047158	 0.00076	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 2947	 0.032163	 0.053718	 0.00091	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75543	 2946	 0.001728	 0.009479	 0.00251	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 76326	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2946	 76326	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2946	 76332	 0.006118	 0.020987	 0.00503	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76326	 2947	 0.054846	 0.05486	 0.00074	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2948	 2951	 0.002824	 0.00942	 0.00239	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2948	 2952	 0.003727	 0.00958	 0.00237	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75543	 2948	 0.003425	 0.019111	 0.00488	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2948	 76327	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2948	 76327	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2949	 2950	 0.01629	 0.020732	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76327	 2949	 0.005624	 0.012758	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 2953	 0.00171	 0.00859	 0.00224	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 76328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2951	 76328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2951	 76332	 0.001327	 0.008904	 0.00215	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2952	 2965	 0.008943	 0.024009	 0.00544	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2952	 76332	 0.006951	 0.017473	 0.00453	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2953	 2955	 0.003346	 0.01148	 0.00275	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	2953	 76329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2953	 76329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2954	 2976	 0.036872	 0.028902	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2955	 2962	 0.008709	 0.023426	 0.00657	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2956	 2961	 0.037638	 0.096755	 0.0015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76328	 2956	 0.015238	 0.045864	 0.0009	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2957	 76333	 0.014727	 0.029157	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2958	 76330	 0.098182	 0.077702	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2959	 2997	 0.010812	 0.028574	 0.00669	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2959	 76330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2959	 76330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2960	 2961	 0.043582	 0.098861	 0.00197	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76330	 2960	 0.04124	 0.094748	 0.00144	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	2962	 2973	 0.006909	 0.018811	 0.00414	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76329	 2963	 0.12568	 0.13691	 0.00186	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2964	 76331	 0.12927	 0.14219	 0.0019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2965	 76331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2965	 76331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76331	 2966	 0.076049	 0.11277	 0.00169	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2969	 2970	 0.007214	 0.027422	 0.00768	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2970	 2971	 0.005995	 0.024001	 0.00605	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76284	 2972	 0.032217	 0.081935	 0.0013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2974	 76332	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76325	 2975	 0.037722	 0.053549	 0.00088	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76329	 2976	 0.035805	 0.037671	 0.00055	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2977	 2979	 0.002987	 0.01196	 0.00301	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2977	 2994	 0.009155	 0.036656	 0.00924	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2977	 76334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2977	 76334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2978	 76335	 0.032702	 0.03271	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2979	 76335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2979	 76335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2980	 2981	 0.015403	 0.021015	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76335	 2980	 0.002652	 0.013792	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	2980	 76338	 0.011734	 0.045649	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76334	 2982	 0.01897	 0.048763	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2982	 76348	 0.026222	 0.067408	 0.00104	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2983	 2987	 0.002365	 0.009624	 0.00234	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75539	 2983	 0.003793	 0.015434	 0.00376	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75539	 2984	 0.000769	 0.008507	 0.00255	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76309	 2984	 0.001338	 0.010542	 0.00308	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2984	 76336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2984	 76336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2985	 76337	 0.036587	 0.028954	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75539	 2986	 0.004665	 0.010829	 0.0033	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2986	 76337	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2986	 76337	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2987	 2988	 0.001992	 0.007974	 0.00201	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2987	 76338	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2987	 76338	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2988	 3034	 0.002583	 0.016362	 0.00444	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2989	 2990	 0.003982	 0.019635	 0.00531	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2990	 2995	 0.005644	 0.022599	 0.00569	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2990	 2997	 0.004865	 0.023739	 0.00656	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	2991	 2992	 0.096855	 0.062707	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2992	 3031	 0.074271	 0.058778	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2992	 76353	 0.05254	 0.10297	 0.00154	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	2993	 76353	 0.066587	 0.043109	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	2994	 3001	 0.004146	 0.016129	 0.00431	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2995	 3000	 0.007515	 0.029238	 0.00781	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2995	 76339	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2995	 76339	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76339	 2996	 0.049255	 0.040541	 0.00082	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	2997	 2999	 0.00713	 0.02774	 0.00741	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2998	 3062	 0.048852	 0.14012	 0.00216	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76330	 2998	 0.041661	 0.10595	 0.00168	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	2999	 3046	 0.007173	 0.028191	 0.00738	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3000	 3015	 0.005534	 0.021752	 0.00569	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3000	 76340	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3000	 76340	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3001	 3002	 0.003019	 0.014079	 0.00349	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3001	 3032	 0.008267	 0.023053	 0.00484	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3001	 76341	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3001	 76341	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3002	 76342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3002	 76342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3002	 76356	 0.005739	 0.026765	 0.00663	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 3004	 0.05894	 0.038158	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3004	 76343	 0.058656	 0.064515	 0.00086	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3005	 3032	 0.013108	 0.038647	 0.00899	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75535	 3005	 0.001059	 0.008343	 0.00244	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3005	 76343	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3005	 76343	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75536	 3006	 0.009947	 0.016521	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75536	 3007	 0.065475	 0.051323	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 3013	 0.001053	 0.009028	 0.00257	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 3036	 0.006024	 0.017759	 0.00413	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75535	 3008	 0.001791	 0.013491	 0.00374	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3009	 3010	 0.002471	 0.011807	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3009	 3011	 0.002688	 0.013117	 0.00023	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3010	 76347	 0.017288	 0.070656	 0.00143	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3011	 3012	 0.023919	 0.015485	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75536	 3011	 0.00726	 0.038681	 0.00068	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3013	 3039	 0.002682	 0.022316	 0.00676	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3014	 76344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3014	 76344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3014	 76356	 0.005089	 0.012792	 0.00331	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3015	 76356	 0.004623	 0.016175	 0.00536	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3016	 3042	 0.002017	 0.007847	 0.0021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3016	 76356	 0.002731	 0.009936	 0.00304	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3017	 76345	 0.012381	 0.009798	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3018	 3019	 0.000223	 0.002177	 0.00061	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3018	 3020	 0.000354	 0.003603	 0.00093	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3018	 76345	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3018	 76345	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3019	 3037	 0.000379	 0.00344	 0.00112	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3019	 76346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3019	 76346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3020	 3021	 0.001307	 0.01217	 0.00377	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75535	 3021	 0.004624	 0.035968	 0.00934	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3021	 76347	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3021	 76347	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3022	 3029	 0.003393	 0.009237	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3022	 76348	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3022	 76348	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76348	 3023	 0.031705	 0.041669	 0.00057	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3023	 76350	 0.018162	 0.03596	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 3034	 0.002983	 0.011943	 0.00301	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75955	 3024	 0.005494	 0.02733	 0.00882	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 76349	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3024	 76349	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3025	 76350	 0.011989	 0.030819	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3026	 76350	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3026	 76350	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3027	 3029	 0.005165	 0.01365	 0.00319	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75959	 3027	 0.016057	 0.042438	 0.00993	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3027	 76351	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3027	 76351	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75956	 3028	 0.060077	 0.047544	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3029	 76352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3029	 76352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3030	 3031	 0.053292	 0.042175	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76352	 3030	 0.021238	 0.041149	 0.00089	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3032	 76353	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3032	 76353	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76349	 3033	 0.034702	 0.06356	 0.0011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76342	 3035	 0.042066	 0.042488	 0.00056	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3035	 76354	 0.014784	 0.028975	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3036	 76354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3036	 76354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75541	 3037	 0.000644	 0.006562	 0.00169	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76347	 3038	 0.012407	 0.028143	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3038	 76355	 0.018279	 0.035823	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3039	 76355	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3039	 76355	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3040	 76356	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3040	 76356	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75540	 3041	 0.01283	 0.025145	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3042	 3044	 0.001952	 0.009472	 0.00217	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3043	 76359	 0.045398	 0.033401	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3044	 3046	 0.001597	 0.007752	 0.00177	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3044	 76357	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3044	 76357	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76357	 3045	 0.021585	 0.01529	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3046	 76358	 0.002076	 0.020978	 0.00617	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3047	 3060	 0.000511	 0.005899	 0.05172	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3047	 76358	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76359	 3048	 0.02842	 0.026651	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3049	 3051	 0.002073	 0.006005	 0.00145	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76358	 3049	 0.002376	 0.007926	 0.00201	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3049	 76360	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3049	 76360	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3050	 3053	 0.041893	 0.030822	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76360	 3050	 0.013131	 0.025734	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3051	 3052	 0.003155	 0.007932	 0.00205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3052	 3055	 0.004241	 0.011546	 0.00254	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76358	 3052	 0.006166	 0.018725	 0.0041	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3052	 76361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3052	 76361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3052	 76366	 0.006857	 0.018122	 0.00424	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 3055	 0.002155	 0.005697	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 76362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3054	 76362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76362	 3056	 0.035107	 0.05378	 0.00076	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3056	 76367	 0.018041	 0.037918	 0.00069	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3057	 3058	 0.001376	 0.006558	 0.0019	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3057	 76363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3057	 76363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3058	 76364	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3058	 76364	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3058	 76366	 0.003381	 0.013959	 0.0033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3059	 3064	 0.009073	 0.026749	 0.00622	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3059	 76365	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3059	 76365	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3059	 76366	 0.004502	 0.011687	 0.00284	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3060	 76366	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3061	 3063	 0.14954	 0.11003	 0.00161	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76365	 3061	 0.018022	 0.035682	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76367	 3062	 0.026577	 0.075418	 0.00118	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3065	 3066	 0.1328	 0.1051	 0.00132	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76303	 3067	 0.17037	 0.12536	 0.00183	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3069	 3070	 0.053718	 0.096928	 0.0014	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3070	 3076	 0.059227	 0.099776	 0.00142	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3072	 3073	 0.11454	 0.089789	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3073	 76452	 0.033804	 0.095928	 0.00151	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3074	 76368	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3074	 76368	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3075	 3495	 0.07493	 0.12623	 0.0018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76368	 3075	 0.037075	 0.062457	 0.00089	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76368	 3076	 0.017662	 0.058918	 0.00093	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3077	 76369	 0.018709	 0.014806	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3078	 3197	 0.001226	 0.005625	 0.00144	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3078	 76369	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3078	 76369	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3078	 76370	 0.002323	 0.012351	 0.00287	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76369	 3079	 0.029305	 0.02156	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 3113	 0.004489	 0.015643	 0.00363	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 76370	 0.002354	 0.008524	 0.00183	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 3082	 6.4e-05	 0.0007	 0.00679	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 76370	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3082	 76372	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76371	 3083	 0.018379	 0.014406	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3084	 3085	 0.008642	 0.014433	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3084	 76374	 0.020652	 0.020859	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75548	 3085	 0.028014	 0.08035	 0.00124	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3086	 76374	 0.017679	 0.027083	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75486	 3087	 0.007923	 0.021269	 0.00482	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3087	 76374	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3087	 76374	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3088	 76381	 0.016612	 0.028999	 0.00045	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3089	 3090	 0.001172	 0.004244	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3089	 3123	 0.002191	 0.006109	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3090	 3091	 0.000615	 0.002464	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3090	 76375	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3090	 76375	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3091	 3092	 0.0011	 0.004403	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3092	 3253	 0.002335	 0.009347	 0.00235	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3093	 3124	 0.007199	 0.014253	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3094	 3097	 0.036551	 0.02865	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3095	 3096	 0.01676	 0.025671	 0.00045	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3095	 3097	 0.004145	 0.023292	 0.00043	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3095	 3100	 0.007236	 0.023205	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3095	 3100	 0.007236	 0.023205	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75547	 3095	 0.026174	 0.12773	 0.0022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76375	 3097	 0.004345	 0.020962	 0.00037	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3098	 3099	 0.010688	 0.065708	 0.00118	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75767	 3098	 0.008921	 0.054815	 0.00125	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3099	 3100	 0.012178	 0.047377	 0.00079	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3099	 3100	 0.012178	 0.047377	 0.00079	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3099	 3101	 0.011473	 0.050841	 0.00153	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3101	 76412	 0.022613	 0.12725	 0.00275	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3102	 3104	 0.007033	 0.023461	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3102	 3122	 0.003815	 0.020412	 0.00062	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3102	 3125	 0.003407	 0.011928	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3103	 3104	 0.010274	 0.02723	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3103	 3292	 0.017423	 0.067782	 0.00113	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3105	 76404	 0.01677	 0.013272	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3106	 3109	 0.028971	 0.022709	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3106	 76404	 0.012384	 0.022258	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3107	 3241	 0.003006	 0.007805	 0.00189	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3107	 76376	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3107	 76376	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76376	 3108	 0.023308	 0.018446	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3110	 3111	 0.006589	 0.013046	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3110	 3116	 0.027426	 0.021705	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3110	 3118	 0.024399	 0.019309	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76376	 3110	 0.012124	 0.031166	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3110	 76378	 0.012364	 0.031783	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 3112	 0.006679	 0.017311	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3112	 76377	 0.005702	 0.017511	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3113	 3115	 0.002184	 0.005773	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3113	 76377	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3113	 76377	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3114	 76378	 0.031814	 0.025177	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3115	 3119	 0.001784	 0.004716	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3115	 76378	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3115	 76378	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3117	 3121	 0.029249	 0.023148	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3117	 3126	 0.029353	 0.019003	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 3120	 0.002115	 0.005492	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 76379	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3119	 76379	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3120	 76380	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3120	 76380	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3121	 3124	 0.013118	 0.025972	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75547	 3121	 0.038328	 0.10993	 0.00169	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76380	 3122	 0.005519	 0.01931	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3122	 76381	 0.005116	 0.018276	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3123	 76381	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3123	 76381	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76381	 3124	 0.007725	 0.023699	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3125	 3293	 0.002842	 0.019283	 0.00036	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76379	 3125	 0.01491	 0.045789	 0.00086	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3127	 3129	 0.004277	 0.013951	 0.0037	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3127	 3146	 0.0026	 0.00906	 0.0021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3128	 3133	 0.007217	 0.037529	 0.00081	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3128	 76382	 0.005869	 0.03336	 0.0006	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3129	 3291	 0.010719	 0.042916	 0.01081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3129	 76382	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3129	 76382	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3130	 3135	 0.001798	 0.006997	 0.00187	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3130	 76383	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3130	 76383	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3131	 76384	 0.018447	 0.013067	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76383	 3132	 0.01958	 0.015348	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3133	 3134	 0.020652	 0.036888	 0.00054	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76383	 3133	 0.002584	 0.017738	 0.00032	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3135	 3299	 0.011253	 0.073596	 0.01872	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3135	 76384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3135	 76384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3136	 3137	 0.013425	 0.010297	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3136	 3139	 0.062893	 0.049773	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3136	 3140	 0.01996	 0.017886	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3136	 3141	 0.016358	 0.012822	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76384	 3136	 0.001827	 0.010266	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3138	 3140	 0.012896	 0.010206	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76384	 3142	 0.014604	 0.011064	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76383	 3143	 0.007941	 0.05192	 0.0012	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3143	 76419	 0.007605	 0.049068	 0.00156	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3144	 3148	 0.1154	 0.084906	 0.00124	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3145	 76385	 0.005865	 0.028619	 0.00049	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3146	 76385	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3146	 76385	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75548	 3147	 0.007709	 0.006043	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75548	 3148	 0.033605	 0.06586	 0.00099	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3149	 3194	 0.003175	 0.008227	 0.00249	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3149	 76386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3149	 76386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3150	 3240	 0.004982	 0.010675	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3150	 76404	 0.008003	 0.016819	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3151	 3152	 0.006717	 0.011219	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3152	 3161	 0.008043	 0.01232	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3152	 3163	 0.004775	 0.008583	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3152	 76387	 0.005088	 0.016973	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3152	 76388	 0.002139	 0.010886	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3153	 3154	 0.013346	 0.010111	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3153	 76387	 0.01018	 0.010282	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3155	 3185	 0.002308	 0.0061	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3155	 3241	 0.004574	 0.012088	 0.00283	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3155	 76387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3155	 76387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3156	 3160	 0.008064	 0.010598	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75549	 3156	 0.005102	 0.010932	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3157	 3175	 0.001221	 0.003405	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3158	 3160	 0.006867	 0.005383	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3158	 76390	 0.008994	 0.007118	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3159	 3160	 0.011413	 0.008397	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3162	 3163	 0.010551	 0.006831	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3164	 3247	 0.001028	 0.002883	 0.00074	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3164	 76388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3164	 76388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3165	 3167	 0.003863	 0.010238	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3165	 3168	 0.00433	 0.010253	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3166	 3167	 0.013077	 0.010349	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3167	 76399	 0.003522	 0.016907	 0.00051	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3168	 3171	 0.004865	 0.009633	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3169	 76389	 0.02501	 0.019604	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3170	 3171	 0.011339	 0.008591	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3170	 76389	 0.012386	 0.009709	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3171	 3172	 0.015115	 0.01112	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3172	 76390	 0.009009	 0.009035	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3173	 3177	 0.018179	 0.01425	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3173	 76389	 0.006641	 0.013015	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3174	 3175	 0.002465	 0.006399	 0.00155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3174	 76389	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3174	 76389	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3175	 76390	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3175	 76390	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3176	 3177	 0.01357	 0.008785	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76390	 3176	 0.005013	 0.008002	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3178	 3213	 0.017734	 0.011481	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76389	 3178	 0.009378	 0.018379	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3179	 3212	 0.014113	 0.023536	 0.00034	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76389	 3179	 0.008581	 0.028318	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3179	 76391	 0.007497	 0.014843	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3180	 3181	 0.000701	 0.002854	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3180	 3186	 0.000625	 0.002502	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3181	 3182	 0.000521	 0.002028	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3182	 3183	 0.000826	 0.003308	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3182	 76391	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3182	 76391	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3183	 3186	 0.001416	 0.005565	 0.00146	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3183	 76392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3183	 76392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3184	 3185	 0.000362	 0.001448	 0.00036	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3184	 3188	 0.002351	 0.008066	 0.00193	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3185	 3186	 0.000394	 0.001577	 0.0004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3185	 3190	 0.001656	 0.005401	 0.00143	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75549	 3187	 0.009602	 0.007599	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3188	 3276	 0.001734	 0.006278	 0.00135	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3188	 76393	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3188	 76393	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76393	 3189	 0.019311	 0.015282	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3190	 76394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3190	 76394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76394	 3191	 0.006101	 0.015517	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3192	 3193	 0.014587	 0.024572	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75549	 3192	 0.00754	 0.022693	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3194	 3195	 0.001893	 0.006379	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3195	 3197	 0.000709	 0.002479	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3196	 76395	 0.019481	 0.015417	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3197	 76395	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3197	 76395	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3198	 3266	 0.004116	 0.010582	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3198	 76407	 0.005529	 0.014005	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3199	 3200	 0.000518	 0.002015	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3199	 3202	 0.001015	 0.003859	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3199	 76396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3199	 76396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3200	 3201	 0.000398	 0.001595	 0.0004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3201	 3257	 0.000653	 0.002615	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3202	 76397	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3202	 76397	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3203	 3204	 0.027325	 0.020703	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3203	 3205	 0.01047	 0.034927	 0.00055	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3203	 3209	 0.017115	 0.040528	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75900	 3203	 0.021296	 0.054743	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76397	 3203	 0.007691	 0.029591	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 3206	 0.008982	 0.035945	 0.00076	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3206	 3288	 0.009605	 0.042802	 0.00073	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3207	 3208	 0.024138	 0.019867	 0.0004	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3208	 3289	 0.019839	 0.050455	 0.0008	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3209	 3210	 0.013858	 0.029587	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3209	 76401	 0.011044	 0.055867	 0.00097	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3210	 3211	 0.007281	 0.020883	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3211	 3256	 0.00742	 0.017699	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3214	 3215	 0.022039	 0.0203	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3215	 3216	 0.017731	 0.014032	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76389	 3215	 0.003675	 0.011273	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3217	 76398	 0.014007	 0.010612	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3218	 3220	 0.001809	 0.004781	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3218	 76398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3218	 76398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3219	 3227	 0.002614	 0.011771	 0.00313	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3220	 3221	 0.003016	 0.008411	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3221	 76399	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3221	 76399	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3222	 76400	 0.036446	 0.028843	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3223	 3255	 0.001443	 0.00495	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3223	 76400	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3223	 76400	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3224	 3227	 0.002958	 0.013571	 0.00348	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3224	 3230	 0.002331	 0.014766	 0.00401	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3224	 3233	 0.006266	 0.028745	 0.00736	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3224	 76401	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3224	 76401	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76398	 3225	 0.006909	 0.035467	 0.00067	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76401	 3225	 0.006896	 0.030728	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3226	 3235	 0.077843	 0.061605	 0.00078	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76401	 3226	 0.017371	 0.033266	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3228	 76403	 0.050544	 0.050693	 0.00082	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3229	 3230	 0.002666	 0.006188	 0.00189	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3229	 76402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3229	 76402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3230	 3233	 0.004206	 0.019618	 0.00486	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3230	 76403	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3230	 76403	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3231	 3234	 0.12102	 0.094867	 0.00122	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75552	 3231	 0.030851	 0.051245	 0.00109	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75551	 3232	 0.034536	 0.08018	 0.00119	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75554	 3236	 0.062084	 0.049132	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3237	 3238	 0.017301	 0.077095	 0.00131	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75554	 3237	 0.023726	 0.091279	 0.00156	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76386	 3239	 0.020558	 0.027019	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76386	 3240	 0.008807	 0.014709	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3241	 76404	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3241	 76404	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3242	 3246	 0.015826	 0.015985	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3243	 3246	 0.012655	 0.010015	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3244	 3245	 0.018938	 0.014988	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3245	 3246	 0.02288	 0.024433	 0.00052	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3245	 3249	 0.006395	 0.018343	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76376	 3245	 0.00586	 0.020016	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3246	 76405	 0.00398	 0.017094	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3247	 3254	 0.001152	 0.003953	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76376	 3248	 0.009852	 0.025326	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3249	 3250	 0.034185	 0.027053	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3249	 76406	 0.005031	 0.019277	 0.00054	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3251	 3252	 0.030065	 0.023793	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3252	 76406	 0.013221	 0.020052	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3254	 76405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3254	 76405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3255	 76406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3255	 76406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75553	 3256	 0.005078	 0.016757	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3257	 3267	 0.000452	 0.00158	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3258	 76407	 0.013479	 0.009744	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3259	 3260	 0.003297	 0.005051	 7e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3259	 3261	 0.008738	 0.011485	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3260	 3266	 0.003467	 0.006255	 9e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3261	 3262	 0.005991	 0.00512	 0.0001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3262	 3263	 0.016787	 0.012135	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3262	 3265	 0.00418	 0.006402	 0.00011	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3264	 3265	 0.015261	 0.012078	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3265	 3273	 0.002764	 0.00832	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3267	 76407	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3267	 76407	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75553	 3268	 0.008153	 0.005998	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 3270	 0.002419	 0.008069	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75553	 3269	 0.001735	 0.006749	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3270	 3271	 0.001851	 0.005934	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76392	 3270	 0.005426	 0.016663	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3271	 3272	 0.00236	 0.00908	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76407	 3272	 0.005649	 0.013114	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3272	 76408	 0.002621	 0.00725	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3273	 76408	 0.002173	 0.01061	 0.00022	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3274	 3275	 0.015009	 0.011878	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3275	 76408	 0.008906	 0.015002	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3276	 76408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3276	 76408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3277	 3284	 0.014242	 0.010295	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3278	 3284	 0.023332	 0.017166	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3279	 3280	 0.001648	 0.007346	 0.00012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3279	 3281	 0.026	 0.019129	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76402	 3279	 0.00236	 0.010516	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3280	 3282	 0.002049	 0.008199	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3282	 3283	 0.001307	 0.005822	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3283	 3284	 0.002796	 0.007188	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3283	 3287	 0.003518	 0.009045	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3284	 3289	 0.015335	 0.02767	 0.0004	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3284	 76409	 0.002129	 0.010767	 0.00019	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3285	 76409	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3285	 76409	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3286	 3287	 0.002016	 0.004773	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3286	 3288	 0.006992	 0.017781	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76409	 3286	 0.002262	 0.007463	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3288	 3289	 0.011868	 0.019993	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76139	 3288	 0.010424	 0.037237	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75551	 3289	 0.030696	 0.14811	 0.00262	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3290	 76414	 0.37881	 0.26848	 0.00424	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 3294	 0.001393	 0.006388	 0.00164	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 76410	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3291	 76410	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76382	 3292	 0.094338	 0.12861	 0.00285	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76410	 3292	 0.004997	 0.028404	 0.00051	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76410	 3293	 0.007176	 0.046922	 0.00109	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3294	 76411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3294	 76411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3295	 3297	 0.004747	 0.033807	 0.00076	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76410	 3295	 0.009621	 0.030852	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76410	 3295	 0.009621	 0.030852	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76411	 3295	 0.004829	 0.029688	 0.00054	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76411	 3296	 0.008248	 0.046882	 0.00085	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3296	 76418	 0.008351	 0.051342	 0.00093	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3297	 76419	 0.00652	 0.047219	 0.00119	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3298	 76412	 0.088893	 0.081882	 0.00131	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3299	 3300	 0.003366	 0.020359	 0.0052	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3299	 76412	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3299	 76412	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3301	 3303	 0.000959	 0.004996	 0.00131	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75746	 3302	 0.018778	 0.15195	 0.00392	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3302	 76413	 0.008967	 0.028754	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3302	 76413	 0.008967	 0.028754	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3303	 3304	 0.001761	 0.009705	 0.00227	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3303	 76413	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3303	 76413	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3304	 3306	 0.003819	 0.0182	 0.00527	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3304	 76414	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3304	 76414	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76414	 3305	 0.059276	 0.046463	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3306	 3307	 0.002843	 0.013041	 0.00334	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3307	 3310	 0.003154	 0.015306	 0.0035	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3308	 76415	 0.025447	 0.019947	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3309	 3310	 0.003464	 0.022313	 0.00585	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3309	 3315	 0.002635	 0.01324	 0.00345	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75745	 3309	 0.020139	 0.12004	 0.03161	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3309	 76415	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3309	 76415	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3310	 76416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3310	 76416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76416	 3311	 0.005386	 0.027243	 0.00047	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3311	 76417	 0.014879	 0.060809	 0.00123	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76415	 3312	 0.05194	 0.040713	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3313	 3314	 0.00215	 0.008449	 0.00221	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3313	 76417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3313	 76417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3314	 76418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3314	 76418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3315	 76419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3315	 76419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76415	 3316	 0.046237	 0.036242	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76415	 3317	 0.025511	 0.058609	 0.00089	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76416	 3317	 0.018525	 0.049099	 0.00125	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3318	 3322	 0.008919	 0.032295	 0.00693	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3318	 3379	 0.008708	 0.03035	 0.00704	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3318	 76420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3318	 76420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3319	 76421	 0.062982	 0.049843	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3320	 3325	 0.021246	 0.055165	 0.01339	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3320	 3378	 0.014473	 0.042671	 0.00993	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3320	 76421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3320	 76421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76421	 3321	 0.071248	 0.085293	 0.00142	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3322	 3323	 0.013897	 0.047678	 0.01142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3323	 3428	 0.018472	 0.063378	 0.01519	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3324	 76422	 0.026812	 0.053085	 0.00078	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3325	 76422	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3325	 76422	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3325	 76442	 0.032405	 0.10924	 0.02717	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3326	 76441	 0.22421	 0.2103	 0.00325	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3327	 76441	 0.16572	 0.13116	 0.00165	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3328	 3446	 0.22761	 0.18016	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3328	 76423	 0.15215	 0.11927	 0.00153	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3329	 76423	 0.17075	 0.13514	 0.0017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 3333	 0.014801	 0.039118	 0.00916	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 3445	 0.02155	 0.060101	 0.01262	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 76423	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3330	 76423	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76423	 3331	 0.18917	 0.1392	 0.00204	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3332	 3335	 0.15133	 0.097978	 0.00187	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3333	 3338	 0.021159	 0.057614	 0.01269	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3334	 3335	 0.11966	 0.094699	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3335	 3337	 0.020669	 0.052354	 0.00104	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3335	 76424	 0.007978	 0.024473	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3336	 3339	 0.027265	 0.10607	 0.00177	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3336	 76424	 0.016279	 0.038548	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3338	 7416	 0.004162	 0.02969	 0.0092	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75472	 3338	 0.014628	 0.071396	 0.01972	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3338	 76424	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3338	 76424	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75882	 3339	 0.026666	 0.076482	 0.00118	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3340	 3426	 0.033619	 0.13079	 0.00218	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3340	 76425	 0.020837	 0.081062	 0.00135	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3341	 3342	 0.005011	 0.011632	 0.00354	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3341	 3387	 0.013146	 0.030517	 0.0093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3342	 3343	 0.005092	 0.01322	 0.00321	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3343	 76425	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3343	 76425	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3344	 3345	 0.020807	 0.048307	 0.00072	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3344	 3346	 0.10782	 0.085333	 0.00107	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3344	 3424	 0.25124	 0.34296	 0.00613	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76295	 3344	 0.10668	 0.19839	 0.00464	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76425	 3344	 0.10464	 0.10496	 0.0017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3345	 3349	 0.042757	 0.12264	 0.00189	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3347	 3404	 0.033155	 0.10676	 0.00182	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3347	 3426	 0.038744	 0.15073	 0.00252	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3347	 3447	 0.12782	 0.18629	 0.00421	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3348	 3447	 0.049217	 0.14117	 0.00217	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3350	 3351	 0.004988	 0.022226	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3350	 3364	 0.005647	 0.02197	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75555	 3352	 0.023904	 0.018737	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3353	 76426	 0.008146	 0.005993	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3354	 76426	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3354	 76426	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75555	 3355	 0.021891	 0.014172	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 3358	 0.001828	 0.011109	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 3382	 0.001985	 0.011282	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3357	 3358	 0.001966	 0.007022	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3357	 3358	 0.001966	 0.007022	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76426	 3357	 0.002662	 0.010242	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76426	 3357	 0.002662	 0.010242	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3358	 3359	 0.004445	 0.018167	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3359	 3376	 0.011313	 0.016774	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3360	 76427	 0.096758	 0.07119	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3361	 3396	 0.00743	 0.028244	 0.00791	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3361	 76427	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3361	 76427	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3361	 76428	 0.002721	 0.021434	 0.00627	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3362	 3542	 0.000676	 0.012043	 0.12494	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3362	 3557	 0.004287	 0.042637	 0.73549	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3362	 3557	 0.004287	 0.042637	 0.73549	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3362	 76428	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76427	 3363	 0.021162	 0.082326	 0.00137	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76427	 3363	 0.021162	 0.082326	 0.00137	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76429	 3363	 0.014526	 0.050828	 0.00105	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76429	 3363	 0.014526	 0.050828	 0.00105	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3364	 3399	 0.077585	 0.14427	 0.00338	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76429	 3364	 0.012893	 0.065222	 0.00113	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3365	 3366	 0.015474	 0.010018	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75555	 3365	 0.008063	 0.013392	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3367	 76430	 0.021227	 0.021674	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76428	 3368	 0.005965	 0.020462	 0.0049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3368	 76430	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3368	 76430	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76429	 3369	 0.03136	 0.056015	 0.00083	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3370	 3371	 0.032474	 0.060382	 0.00141	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76430	 3370	 0.014242	 0.062752	 0.00109	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3371	 3372	 0.077465	 0.050152	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3373	 76431	 0.12725	 0.10071	 0.00127	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3374	 3379	 0.007468	 0.0299	 0.00753	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3374	 76431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3374	 76431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3375	 3376	 0.049936	 0.039519	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3376	 4605	 0.36269	 0.55065	 0.0079	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3377	 3378	 0.007638	 0.021908	 0.00539	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3377	 3383	 0.007877	 0.027022	 0.00647	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3380	 3465	 0.026806	 0.091569	 0.00199	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3380	 3465	 0.026806	 0.091569	 0.00199	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76420	 3380	 0.028904	 0.11245	 0.00188	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76420	 3380	 0.028904	 0.11245	 0.00188	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3381	 3383	 0.001685	 0.004331	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3381	 76432	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3381	 76432	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76432	 3382	 0.003022	 0.012919	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76428	 3383	 0.005273	 0.018451	 0.00611	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3383	 76433	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3383	 76433	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76433	 3384	 0.014935	 0.011706	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3385	 3386	 0.013769	 0.045938	 0.01165	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3385	 76434	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3385	 76434	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3386	 3417	 0.009866	 0.034384	 0.00797	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3389	 3390	 0.1648	 0.13043	 0.00164	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 3400	 0.071786	 0.20592	 0.00317	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 3422	 0.019303	 0.13747	 0.00309	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 3397	 0.1841	 0.13949	 0.00192	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3392	 3398	 0.14521	 0.13013	 0.00266	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3392	 76435	 0.022744	 0.081252	 0.00161	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3392	 76435	 0.022744	 0.081252	 0.00161	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3393	 3394	 0.000167	 0.002787	 0.00158	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3393	 76435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3393	 76435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3394	 3395	 0.000653	 0.002567	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3394	 76436	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3394	 76436	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3395	 3396	 0.006367	 0.025911	 0.00631	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3397	 3401	 0.035206	 0.13545	 0.00231	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3397	 3401	 0.035206	 0.13545	 0.00231	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76427	 3397	 0.039369	 0.12625	 0.00312	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76427	 3397	 0.039369	 0.12625	 0.00312	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3399	 4224	 0.041842	 0.12001	 0.00185	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3400	 3402	 0.038042	 0.10911	 0.00168	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3401	 3402	 0.027632	 0.096689	 0.002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3401	 3402	 0.027632	 0.096689	 0.002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3402	 76437	 0.030134	 0.10544	 0.00218	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3402	 76437	 0.030134	 0.10544	 0.00218	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3403	 76437	 0.14698	 0.11632	 0.00146	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3404	 76437	 0.037503	 0.11908	 0.00209	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3405	 3421	 0.054299	 0.14363	 0.03366	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3405	 76437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3405	 76437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3406	 3450	 0.061081	 0.11188	 0.00193	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3407	 3416	 0.16539	 0.1309	 0.00165	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3408	 3409	 0.048528	 0.11267	 0.00168	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3408	 3461	 0.038993	 0.10024	 0.00155	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3409	 3416	 0.055296	 0.11622	 0.00212	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 3461	 0.015369	 0.068486	 0.00116	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 76447	 0.025073	 0.12684	 0.00221	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3411	 76438	 0.11556	 0.090585	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3412	 3462	 0.020531	 0.049483	 0.01397	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76299	 3412	 0.033115	 0.1006	 0.02204	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3412	 76438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3412	 76438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76438	 3413	 0.22786	 0.18035	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76300	 3414	 0.20934	 0.13555	 0.00258	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3415	 3416	 0.13345	 0.10461	 0.00134	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76300	 3416	 0.058639	 0.29848	 0.00677	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3417	 3418	 0.007389	 0.026756	 0.00574	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3418	 3419	 0.002618	 0.012391	 0.00298	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3418	 76439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3418	 76439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3419	 3420	 0.002019	 0.008082	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3420	 3421	 0.001739	 0.005965	 0.00143	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3421	 76440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3421	 76440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76440	 3422	 0.020496	 0.13343	 0.00271	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 3424	 0.24137	 0.19105	 0.00241	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3424	 3425	 0.042574	 0.084295	 0.00124	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76434	 3425	 0.15114	 0.32399	 0.00568	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76439	 3425	 0.053878	 0.13703	 0.00217	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3427	 3430	 0.19196	 0.14125	 0.00207	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3428	 76441	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3428	 76441	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3428	 76442	 0.010264	 0.053212	 0.01299	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3429	 3441	 0.16951	 0.10975	 0.00209	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3430	 76443	 0.073527	 0.091274	 0.00199	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3431	 76443	 0.056329	 0.041443	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3432	 3441	 0.058284	 0.098186	 0.0014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3432	 76443	 0.014719	 0.037836	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3433	 8218	 0.001869	 0.019974	 0.29369	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3433	 8218	 0.001869	 0.019974	 0.29369	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3433	 76442	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3434	 3435	 0.14545	 0.09771	 0.00172	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3435	 3437	 0.01167	 0.027094	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 3437	 0.018069	 0.011698	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76443	 3437	 0.002949	 0.014155	 0.00042	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3438	 3439	 0.10954	 0.077598	 0.00123	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76443	 3438	 0.010537	 0.035995	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3440	 3443	 0.00761	 0.022436	 0.00522	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3440	 3445	 0.015415	 0.04545	 0.01057	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3442	 76444	 0.16194	 0.16359	 0.00217	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76442	 3443	 0.017439	 0.052227	 0.01177	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3443	 76444	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3443	 76444	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3444	 76445	 0.19503	 0.15436	 0.00194	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 76445	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3445	 76445	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3447	 3448	 0.15573	 0.12325	 0.00155	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3447	 76446	 0.027703	 0.19018	 0.00347	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3449	 3450	 0.11334	 0.089696	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 76446	 0.040381	 0.07914	 0.00119	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3453	 3457	 0.094924	 0.075123	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3454	 3455	 0.022625	 0.017734	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3455	 3456	 0.017035	 0.011443	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3458	 3460	 0.038057	 0.029831	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3458	 76446	 0.007764	 0.012967	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76299	 3459	 0.024052	 0.14341	 0.03778	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3459	 76446	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3459	 76446	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76446	 3461	 0.008439	 0.037606	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3462	 76447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3462	 76447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76447	 3463	 0.18064	 0.14297	 0.0018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3464	 3465	 0.018583	 0.072293	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3464	 3465	 0.018583	 0.072293	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76447	 3464	 0.027833	 0.095079	 0.00207	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76447	 3464	 0.027833	 0.095079	 0.00207	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75556	 3466	 0.012776	 0.016791	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3467	 3499	 0.28883	 0.22864	 0.00288	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3467	 76448	 0.066472	 0.13028	 0.00195	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3468	 76448	 0.18267	 0.1432	 0.00184	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3469	 3470	 0.16639	 0.12764	 0.00171	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 3475	 0.23703	 0.18762	 0.00236	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3471	 3475	 0.13697	 0.10378	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3472	 3473	 0.008203	 0.024183	 0.00563	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3472	 76448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3472	 76448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3474	 3475	 0.046215	 0.1188	 0.00184	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3474	 3479	 0.03949	 0.080816	 0.00199	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 3476	 0.035703	 0.080987	 0.00162	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3476	 3478	 0.044392	 0.090849	 0.00224	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3478	 76451	 0.054974	 0.12761	 0.00243	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3479	 76450	 0.024479	 0.062254	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3480	 76450	 0.078695	 0.062279	 0.00078	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3481	 3483	 0.004049	 0.018232	 0.00485	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3481	 76449	 0.001539	 0.010884	 0.00299	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75471	 3482	 0.002143	 0.033638	 0.07144	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75475	 3482	 0.008671	 0.085561	 0.29524	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 76449	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76450	 3482	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3483	 76451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3483	 76451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76300	 3484	 0.08812	 0.069074	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3485	 3488	 0.1246	 0.090077	 0.00137	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76438	 3485	 0.20834	 0.1649	 0.00208	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3486	 3487	 0.055813	 0.037491	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76438	 3486	 0.16445	 0.15891	 0.00231	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3488	 3489	 0.24998	 0.16796	 0.00296	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3489	 3490	 0.021163	 0.050115	 0.00092	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3489	 3492	 0.03715	 0.095499	 0.00148	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3491	 3493	 0.10097	 0.16118	 0.00371	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 3495	 0.049117	 0.11404	 0.0017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3493	 3494	 0.13427	 0.09879	 0.00144	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76368	 3496	 0.11555	 0.074814	 0.00142	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 3498	 0.12327	 0.089115	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 76452	 0.087411	 0.17308	 0.00254	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3500	 76452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3500	 76452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76452	 3501	 0.041038	 0.062866	 0.00088	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 3503	 0.0	 1e-05	 4e-05	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 3509	 0.00012	 0.002035	 0.0442	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 76453	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3502	 76453	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3502	 76453	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3503	 7549	 0.000216	 0.002458	 0.02219	 1300.0	 1300.0	 1300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3503	 76454	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3503	 76454	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3503	 76454	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76455	 3503	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 0	 -30.0	 30.0;
	76455	 3503	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 0	 -30.0	 30.0;
	3504	 3526	 0.000287	 0.003314	 0.02905	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3504	 5646	 0.001741	 0.031506	 0.49912	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3504	 6694	 3.9e-05	 0.000401	 0.0063	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3504	 76456	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3504	 76456	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3505	 6819	 3.2e-05	 0.000297	 0.00117	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3505	 76457	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3505	 76457	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3506	 3508	 3e-06	 4.1e-05	 0.00071	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3506	 6698	 0.000335	 0.003871	 0.03394	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3506	 76458	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3506	 76458	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3507	 6690	 0.011404	 0.11122	 0.39768	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3507	 76460	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3507	 76460	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76461	 3507	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76461	 3507	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3507	 76542	 0.003446	 0.022368	 0.04456	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3508	 3526	 0.000129	 0.001824	 0.01739	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3508	 4207	 0.002085	 0.037525	 0.73554	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3508	 6525	 0.000951	 0.016746	 0.27836	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3508	 6694	 0.000414	 0.00454	 0.0441	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3508	 76462	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3508	 76462	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3509	 3510	 0.001535	 0.017729	 0.15552	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 3547	 0.001525	 0.016653	 0.16359	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 6091	 0.001862	 0.021105	 0.19233	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 7549	 0.000174	 0.003155	 0.03154	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 7568	 0.000231	 0.003674	 0.06031	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 8324	 0.00075	 0.010192	 0.2069	 1646.0	 1728.3	 1810.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 76463	 6.6e-05	 0.005263	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3509	 76463	 6.6e-05	 0.005263	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3510	 3512	 0.004148	 0.045179	 0.45093	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 3516	 0.002921	 0.033143	 0.30248	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 76466	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3510	 76466	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3511	 5579	 0.020238	 0.079566	 0.02082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3511	 5608	 0.003838	 0.02106	 0.00557	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3511	 5610	 0.003727	 0.026361	 0.00723	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3511	 5619	 0.006664	 0.050202	 0.01393	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3511	 8258	 0.004434	 0.037293	 0.01105	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3511	 76469	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3511	 76469	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3511	 76951	 0.026006	 0.08924	 0.02139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3512	 7711	 0.000912	 0.011315	 0.10487	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3512	 76470	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3512	 76470	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3513	 7829	 0.00045	 0.005532	 0.08863	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3513	 76472	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3513	 76472	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3513	 76472	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3514	 7541	 7.1e-05	 0.0007	 0.01198	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3514	 7541	 7.1e-05	 0.0007	 0.01198	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3514	 9930	 0.000114	 0.001147	 0.01887	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3514	 9930	 0.000114	 0.001147	 0.01887	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3514	 76475	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3514	 76475	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3515	 5877	 0.000277	 0.001872	 0.00345	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3515	 76476	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3515	 76476	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76477	 3515	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76477	 3515	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3516	 8218	 0.003601	 0.035762	 0.61546	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3516	 8218	 0.003601	 0.035762	 0.61546	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3516	 76478	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3516	 76478	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3517	 3547	 0.002327	 0.032187	 0.54724	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3517	 7711	 0.001397	 0.025867	 0.24892	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3517	 76479	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3517	 76479	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3518	 8051	 0.002412	 0.013858	 0.00393	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 8054	 0.000594	 0.003024	 0.0011	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 8056	 0.000721	 0.006782	 0.00205	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 76481	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3518	 76481	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3519	 4753	 0.00277	 0.016502	 0.00434	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3519	 5186	 0.000281	 0.004142	 0.00202	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3519	 6001	 0.001365	 0.005465	 0.00138	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3519	 6007	 0.000952	 0.003812	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3519	 6024	 0.000142	 0.000592	 0.00018	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3519	 6041	 9.8e-05	 0.000802	 0.00022	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3519	 76482	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3519	 76482	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3520	 3528	 2.5e-05	 0.000269	 0.00264	 811.0	 811.0	 811.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3520	 3722	 5.5e-05	 0.000879	 0.00904	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3520	 6132	 0.00013	 0.001471	 0.01339	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3520	 6251	 0.000235	 0.002717	 0.02382	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3520	 76483	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3520	 76483	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76484	 3520	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76484	 3520	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3521	 3546	 0.000262	 0.003179	 0.03081	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3521	 7829	 0.000214	 0.003083	 0.02829	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3521	 76485	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3521	 76485	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3522	 3571	 0.0	 1e-05	 4e-05	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3522	 76487	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3522	 76487	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3523	 5105	 0.000119	 0.001955	 0.01903	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3523	 6091	 6.6e-05	 0.001148	 0.01242	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3523	 6132	 5.8e-05	 0.000657	 0.00598	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3523	 76488	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3523	 76488	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3524	 6819	 0.000142	 0.001122	 0.00389	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3524	 7240	 0.000592	 0.006385	 0.01267	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3524	 7240	 0.000592	 0.006385	 0.01267	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3524	 76490	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3524	 76490	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3524	 76496	 6.1e-05	 0.000603	 0.00201	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3525	 3528	 1e-05	 0.000115	 0.00108	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3525	 76491	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3525	 76491	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76492	 3525	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76492	 3525	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3526	 6698	 0.000167	 0.001828	 0.01776	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3526	 76493	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3526	 76493	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3527	 4198	 0.054253	 0.15143	 0.03182	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3527	 4259	 0.014346	 0.092441	 0.02424	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3527	 7743	 0.019435	 0.046841	 0.01323	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3527	 8158	 0.007152	 0.039687	 0.01206	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3527	 8159	 0.007188	 0.02422	 0.00602	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3527	 76495	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3527	 76495	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3528	 6091	 0.000162	 0.002951	 0.02925	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3528	 76496	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3528	 76496	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76497	 3528	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76497	 3528	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3529	 5516	 0.00109	 0.004142	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3529	 5517	 3.8e-05	 0.000151	 4e-05	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3529	 5518	 0.000733	 0.002515	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3529	 76498	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3529	 76498	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3530	 8503	 0.009621	 0.04332	 0.01153	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3530	 76499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3530	 76499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3531	 4729	 0.000439	 0.001758	 0.00044	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3531	 4734	 0.000433	 0.002065	 0.0006	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3531	 4882	 0.000108	 0.000694	 0.00018	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3531	 6000	 0.000615	 0.002072	 0.00051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3531	 76500	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3531	 76500	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3532	 3565	 1.4e-05	 0.000113	 3e-05	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3532	 5730	 0.002556	 0.009714	 0.00272	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3532	 5736	 0.002978	 0.01551	 0.00407	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3532	 5738	 0.000846	 0.005983	 0.00164	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3532	 5932	 0.000561	 0.002725	 0.00062	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 7744	 0.021988	 0.075445	 0.01808	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 7755	 0.011907	 0.031468	 0.00737	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 8506	 0.011074	 0.029267	 0.00685	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 76501	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3533	 76501	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3534	 4561	 0.00547	 0.024629	 0.00655	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3534	 76502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3534	 76502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3535	 7945	 0.001193	 0.012393	 0.00383	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3535	 7950	 0.001207	 0.004985	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3535	 8079	 0.010901	 0.070229	 0.01842	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3535	 76503	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3535	 76503	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3535	 76528	 5.8e-05	 0.000577	 0.00016	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3536	 3537	 0.000343	 0.004316	 0.00134	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3536	 76504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3536	 76504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3536	 76526	 0.019922	 0.15279	 0.04099	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3537	 4220	 0.00226	 0.027461	 0.0074	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3537	 4231	 0.024336	 0.097473	 0.02457	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3537	 4601	 0.056853	 0.20128	 0.04545	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3538	 8503	 0.004008	 0.018387	 0.00471	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3538	 76505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3538	 76505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3539	 5849	 0.000763	 0.004185	 0.00111	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3539	 7301	 0.000831	 0.002522	 0.00055	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3539	 76506	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3539	 76506	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3540	 4219	 0.001959	 0.021128	 0.00605	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3540	 4221	 0.002127	 0.027245	 0.00813	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3540	 76507	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3540	 76507	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3541	 4160	 0.000965	 0.003221	 0.00082	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3541	 4165	 0.006015	 0.024478	 0.00596	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3541	 4179	 0.019378	 0.099097	 0.02702	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3541	 4182	 0.00281	 0.0258	 0.02215	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3541	 4579	 0.013183	 0.083526	 0.02268	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3541	 4581	 0.006029	 0.090762	 0.06393	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3541	 76508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3541	 76508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3541	 78886	 0.00771	 0.12915	 0.07338	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3542	 76509	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3542	 76509	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3543	 7661	 0.007093	 0.051805	 0.01332	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3543	 76511	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3543	 76511	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3544	 7780	 0.029615	 0.11864	 0.02991	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3544	 76512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3544	 76512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3545	 3569	 0.000376	 0.002458	 0.00063	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3545	 8016	 0.000428	 0.001195	 0.00025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3545	 8020	 0.0022	 0.008003	 0.00245	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3545	 8043	 0.005721	 0.020017	 0.00663	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3545	 76513	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3545	 76513	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3546	 5105	 0.00057	 0.009271	 0.14474	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3546	 7829	 0.000329	 0.005993	 0.0594	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3546	 76514	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3546	 76514	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3547	 7549	 0.001292	 0.014175	 0.13775	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3547	 76517	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3547	 76517	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3548	 7619	 0.012439	 0.037774	 0.00827	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3548	 76520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3548	 76520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3549	 4649	 0.000623	 0.002423	 0.00065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3549	 5693	 0.009893	 0.064697	 0.01646	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3549	 76521	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3549	 76521	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3550	 6510	 0.001703	 0.008399	 0.00227	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3550	 6511	 0.000157	 0.001183	 0.00033	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3550	 76522	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3550	 76522	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3551	 6410	 0.000384	 0.002662	 0.00076	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3551	 6411	 0.005652	 0.022998	 0.0056	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3551	 76523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3551	 76523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3552	 5901	 0.000825	 0.002218	 0.00062	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3552	 76524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3552	 76524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3553	 7300	 0.004358	 0.003416	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76506	 3553	 0.000119	 0.000884	 2e-05	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3553	 77345	 0.010995	 0.057174	 0.00124	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 4410	 0.022479	 0.033331	 0.0005	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 4412	 0.002651	 0.011749	 0.00035	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 4589	 0.022201	 0.051543	 0.00077	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 76727	 0.002225	 0.008656	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 76727	 0.002225	 0.008656	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3555	 8464	 0.000828	 0.002761	 0.0007	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3555	 8473	 0.002747	 0.010443	 0.00292	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3556	 76525	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3556	 76525	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3556	 77196	 0.003526	 0.022331	 0.00606	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3556	 77197	 0.002367	 0.006356	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3556	 77200	 0.000308	 0.001806	 0.00049	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 76526	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3557	 76526	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3558	 7912	 0.001049	 0.01119	 0.02276	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3558	 8033	 7.2e-05	 0.000642	 0.0013	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3558	 76528	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3558	 76528	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3559	 7764	 0.031504	 0.12829	 0.03129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3559	 76529	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3559	 76529	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3560	 4431	 0.053432	 0.096412	 0.00139	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 4432	 0.029127	 0.057669	 0.00085	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 76562	 0.001352	 0.004068	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 77106	 0.004016	 0.011517	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3561	 3574	 0.000577	 0.006332	 0.06151	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3561	 4497	 0.000444	 0.007846	 0.07341	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3561	 76530	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3561	 76530	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3562	 5801	 0.002392	 0.006014	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 5809	 0.000647	 0.003438	 0.0008	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 5815	 0.001597	 0.005476	 0.00131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 76532	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3562	 76532	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3563	 8085	 0.002161	 0.008572	 0.00024	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3563	 8086	 0.011081	 0.06299	 0.00114	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3563	 8087	 0.006101	 0.020353	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3564	 7901	 0.001572	 0.018794	 0.03712	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75578	 3564	 0.001832	 0.018705	 0.05941	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3564	 76533	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3564	 76533	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76534	 3564	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76534	 3564	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3565	 5730	 0.002538	 0.009649	 0.0027	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 5932	 0.000408	 0.002532	 0.00071	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 8374	 0.006381	 0.039649	 0.01119	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 76535	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3565	 76535	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3566	 8079	 0.006099	 0.02397	 0.00627	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3566	 76536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3566	 76536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3567	 7871	 0.007373	 0.011182	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3567	 7873	 0.007233	 0.028139	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3567	 7875	 0.003536	 0.007235	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3567	 7876	 0.009244	 0.015573	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3567	 7880	 0.007378	 0.021161	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3568	 7849	 0.001947	 0.008677	 0.00236	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3568	 7899	 0.001525	 0.009474	 0.00267	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3568	 76537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3568	 76537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3569	 8080	 0.006552	 0.041501	 0.01127	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3569	 76538	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3569	 76538	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3570	 7861	 0.003353	 0.008862	 0.00207	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3570	 76539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3570	 76539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3571	 7711	 0.000881	 0.01017	 0.08917	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3571	 76540	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3571	 76540	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3572	 4729	 0.000225	 0.000931	 0.00022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3572	 6000	 0.000308	 0.000858	 0.00018	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3573	 6425	 0.002508	 0.006447	 0.0016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3573	 6432	 0.000919	 0.002997	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3573	 6527	 0.000857	 0.005431	 0.00147	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3573	 76541	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3573	 76541	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3574	 4497	 0.001085	 0.011846	 0.11633	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3574	 76542	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3574	 76542	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3575	 4054	 0.002139	 0.009918	 0.00021	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3575	 4055	 0.004112	 0.004391	 9e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3575	 4056	 0.004997	 0.012845	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3575	 4059	 0.035907	 0.033074	 0.00053	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3575	 4062	 0.008296	 0.021325	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3575	 4064	 0.007638	 0.005987	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3576	 4153	 0.001875	 0.006535	 0.00152	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3576	 76545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3576	 76545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3577	 7642	 0.004077	 0.016322	 0.00411	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3577	 7652	 0.005877	 0.023532	 0.00593	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3578	 6746	 0.000188	 0.001717	 0.00062	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3578	 6750	 0.000198	 0.001252	 0.00034	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3578	 76546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3578	 76546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3579	 4781	 0.000915	 0.003595	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3579	 76547	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3579	 76547	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3580	 7830	 0.008092	 0.021448	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3580	 7848	 0.02756	 0.021811	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3580	 7909	 0.003107	 0.013846	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76537	 3580	 0.00017	 0.000451	 1e-05	 77.0	 77.0	 77.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3581	 3582	 0.00047	 0.001385	 0.00032	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3581	 3778	 0.000523	 0.005114	 0.00143	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76492	 3581	 0.00032	 0.002912	 0.00073	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3581	 76582	 0.00111	 0.003867	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3582	 3728	 0.000385	 0.002389	 0.00058	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3583	 5190	 0.00053	 0.0014	 0.00033	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3583	 76548	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3583	 76548	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3584	 7442	 3.2e-05	 0.000352	 0.00031	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3584	 7452	 0.000126	 0.001651	 0.00079	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3585	 3685	 0.001989	 0.009805	 0.00265	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3585	 7435	 0.001081	 0.00621	 0.00176	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3585	 76549	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3585	 76549	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3586	 7980	 0.00101	 0.00397	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3586	 7982	 0.000639	 0.00243	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3586	 77445	 0.006986	 0.043409	 0.01225	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3587	 7582	 0.00133	 0.00949	 0.00294	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3587	 7583	 0.002069	 0.013878	 0.00335	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3587	 7588	 0.001041	 0.004637	 0.00126	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3587	 10395	 0.001996	 0.032719	 0.01029	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3587	 76550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3587	 76550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3588	 4126	 0.000345	 0.003455	 0.00115	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3588	 12673	 0.004922	 0.04809	 0.0135	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3588	 76551	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3588	 76551	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3589	 5535	 0.004806	 0.003111	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3589	 5544	 0.004204	 0.010691	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3589	 5581	 0.005123	 0.016905	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3589	 76931	 0.01015	 0.007956	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3590	 4607	 0.009871	 0.025626	 0.00622	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3591	 3657	 0.006188	 0.023806	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3591	 3658	 0.000829	 0.002766	 4e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3591	 7690	 0.004934	 0.024679	 0.00044	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3592	 3707	 0.028515	 0.087478	 0.00237	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3592	 3710	 0.0504	 0.30995	 0.00559	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3592	 3717	 0.087113	 0.14676	 0.00209	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3593	 4207	 0.00443	 0.063303	 0.60443	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3593	 6621	 0.000179	 0.002835	 0.02977	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3593	 76552	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3593	 76552	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3594	 4697	 0.089093	 0.20686	 0.00308	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3594	 4701	 0.007728	 0.053044	 0.00097	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3594	 4702	 0.013287	 0.038108	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3595	 6448	 0.00468	 0.012743	 0.00281	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3595	 6463	 0.001375	 0.004118	 0.00093	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3595	 6543	 0.001744	 0.008761	 0.00228	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3596	 8145	 0.003877	 0.00986	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3596	 8146	 0.004904	 0.00971	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3596	 8154	 0.015656	 0.038323	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3596	 8156	 0.008469	 0.037313	 0.00065	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3597	 7760	 0.014266	 0.036282	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3597	 7761	 0.024347	 0.081219	 0.00129	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3598	 6120	 0.000174	 0.000708	 0.00017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3598	 6128	 0.000136	 0.000536	 0.00014	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3599	 7642	 0.003499	 0.014448	 0.00342	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3599	 76554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3599	 76554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3600	 6389	 0.011461	 0.058328	 0.02115	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3600	 6675	 0.006586	 0.029652	 0.00789	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3600	 76555	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3600	 76555	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3601	 7623	 0.062177	 0.12725	 0.00313	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3601	 7624	 0.028413	 0.094786	 0.0015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3602	 4634	 0.034635	 0.11676	 0.02904	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3602	 76556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3602	 76556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3603	 5497	 0.007887	 0.028561	 0.00613	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3603	 5499	 0.0068	 0.025849	 0.00724	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3604	 5475	 0.00207	 0.014978	 0.00806	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3604	 6415	 0.021877	 0.16412	 0.0401	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3604	 76557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3604	 76557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3605	 4706	 0.005482	 0.030733	 0.00085	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3605	 4708	 0.008812	 0.033902	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3606	 5862	 0.001975	 0.006883	 0.0016	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3606	 5866	 0.000331	 0.000799	 0.00023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3606	 76558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3606	 76558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3607	 7816	 0.008704	 0.013333	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3607	 7881	 0.009961	 0.025332	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3608	 8098	 0.06409	 0.098181	 0.00138	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3608	 8103	 0.10942	 0.17938	 0.00317	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3608	 8104	 0.011167	 0.016559	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3608	 8105	 0.015478	 0.035934	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3608	 8107	 0.031825	 0.075363	 0.00138	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 7627	 0.001982	 0.005145	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 76559	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3609	 76559	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3610	 4231	 0.029977	 0.19018	 0.05174	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3610	 7638	 0.004297	 0.068147	 0.04313	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3610	 76560	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3610	 76560	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3611	 5530	 0.009122	 0.02264	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3611	 5533	 0.001622	 0.005412	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3611	 5563	 0.002896	 0.009197	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3611	 76932	 0.000691	 0.003782	 7e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3612	 8114	 0.00034	 0.0053	 0.02226	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3612	 8117	 0.000179	 0.0027	 0.00969	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3612	 76561	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3612	 76561	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3613	 76563	 0.007182	 0.023699	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3614	 6296	 0.00053	 0.002309	 0.00066	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3614	 76562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3614	 76562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3615	 7646	 0.000605	 0.002472	 5e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3615	 7651	 0.05725	 0.14211	 0.00236	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3616	 7619	 0.03464	 0.09303	 0.02109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3616	 7633	 0.022158	 0.063563	 0.01564	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3616	 76563	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3616	 76563	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3617	 7571	 0.001069	 0.003567	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3617	 7603	 0.000543	 0.002535	 0.00063	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3618	 7647	 0.009353	 0.024044	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3618	 7648	 0.045754	 0.11762	 0.00182	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3618	 8227	 0.038563	 0.21924	 0.00397	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3618	 8228	 0.25779	 0.20406	 0.00257	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3619	 4728	 6.3e-05	 0.000659	 0.00043	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3619	 4730	 6.4e-05	 0.000934	 0.00058	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3619	 4977	 0.001914	 0.017821	 0.00552	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3619	 76779	 0.000203	 0.002186	 0.00117	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3620	 7643	 0.012877	 0.033102	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3620	 8233	 0.002847	 0.010954	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3621	 4689	 0.030112	 0.18302	 0.00338	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3621	 4690	 0.20318	 0.16081	 0.00202	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3621	 6382	 0.011103	 0.039662	 0.00079	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3621	 6384	 0.14246	 0.10092	 0.0016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3622	 4667	 0.008212	 0.021704	 0.00508	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3622	 76564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3622	 76564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3623	 4664	 0.000764	 0.004294	 8e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3623	 76767	 0.007294	 0.024915	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3624	 5478	 0.022417	 0.057626	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3624	 6385	 0.18919	 0.19112	 0.00253	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3625	 7635	 0.007898	 0.018703	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3626	 5714	 0.013613	 0.047631	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3626	 5714	 0.013613	 0.047631	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3626	 76771	 0.009332	 0.077631	 0.00147	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3627	 4727	 2.1e-05	 0.000274	 0.0046	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3627	 6067	 0.000207	 0.00369	 0.03827	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3627	 76565	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3627	 76565	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3628	 6283	 0.001355	 0.008409	 0.00204	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3628	 6284	 0.00262	 0.00996	 0.00279	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3628	 76566	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3628	 76566	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3629	 4592	 0.005988	 0.015392	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 3631	 0.000852	 0.003348	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 3670	 0.001657	 0.006633	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 76567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3630	 76567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3631	 76568	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3631	 76568	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3631	 77359	 0.0017	 0.00869	 0.00237	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 3636	 0.00423	 0.011182	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 3673	 0.015113	 0.027269	 0.00039	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 3680	 0.006603	 0.016973	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 76569	 0.013674	 0.03347	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3633	 3677	 0.032929	 0.023804	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3633	 3679	 0.060513	 0.039177	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3633	 3694	 0.008032	 0.016437	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3634	 3635	 0.027498	 0.027773	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3634	 3647	 0.022017	 0.015595	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3634	 76569	 0.011363	 0.0342	 0.00067	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3635	 3679	 0.026702	 0.021132	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3635	 3694	 0.011024	 0.018312	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3636	 3637	 0.002313	 0.005314	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3636	 3638	 0.003838	 0.008909	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3636	 3639	 0.005962	 0.011085	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3637	 3643	 0.004532	 0.011525	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3638	 3642	 0.003927	 0.010093	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76568	 3639	 0.006214	 0.013061	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3640	 3642	 0.007302	 0.005372	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3641	 7414	 0.006204	 0.024137	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3641	 76570	 0.002585	 0.012614	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3642	 3652	 0.000722	 0.006721	 0.00013	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3642	 76569	 0.002214	 0.009867	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3643	 3644	 0.002961	 0.005506	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3643	 76569	 0.003457	 0.008187	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3644	 3648	 0.00415	 0.007717	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3645	 3646	 0.028632	 0.022443	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3645	 76569	 0.017876	 0.023494	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3646	 3681	 0.02142	 0.036083	 0.00051	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3648	 3649	 0.003249	 0.007465	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3649	 3650	 0.005855	 0.01505	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 76571	 0.005109	 0.016861	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3651	 3655	 0.00152	 0.006434	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3651	 76569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3651	 76569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3652	 3653	 0.00183	 0.006039	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3652	 76570	 0.004089	 0.013493	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3653	 76570	 0.002116	 0.006493	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76487	 3654	 0.000705	 0.003882	 0.0014	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 76570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3654	 76570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3654	 77359	 0.001217	 0.003394	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 77426	 0.021743	 0.056455	 0.01371	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76487	 3655	 0.000308	 0.00309	 0.00103	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3655	 76571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3655	 76571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3656	 3657	 0.017865	 0.014003	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 7400	 0.014373	 0.024212	 0.00034	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 7401	 0.012558	 0.019238	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3658	 3659	 0.003231	 0.012568	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3659	 76572	 0.003992	 0.013978	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3660	 7402	 0.004116	 0.007538	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3660	 7404	 0.011252	 0.019642	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3660	 76573	 0.00769	 0.027471	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3661	 3662	 0.00319	 0.007809	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3661	 7406	 0.003249	 0.006649	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3661	 7407	 0.007662	 0.014033	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3662	 76573	 0.009397	 0.024155	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3663	 7407	 0.005031	 0.012932	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3663	 7408	 0.002185	 0.013432	 0.00024	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3663	 7409	 0.004752	 0.027013	 0.00049	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3663	 76572	 0.036629	 0.081072	 0.00133	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3664	 3666	 0.003174	 0.010889	 0.00261	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3664	 76572	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3664	 76572	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3664	 77426	 0.00565	 0.029926	 0.00759	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 76573	 0.015235	 0.020023	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3666	 76573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3666	 76573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3667	 76575	 0.015582	 0.03085	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76572	 3668	 0.023178	 0.030463	 0.00042	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76573	 3669	 0.012596	 0.036128	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3669	 76574	 0.006232	 0.02777	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 76574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3670	 76574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3671	 3678	 0.002625	 0.006938	 0.00162	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3671	 76575	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3671	 76575	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3671	 77426	 0.00711	 0.023957	 0.00595	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3672	 3680	 0.011223	 0.014605	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3673	 3674	 0.032523	 0.032849	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76575	 3674	 0.043955	 0.048346	 0.00065	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3675	 3693	 0.00328	 0.008668	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3675	 77426	 0.007783	 0.02057	 0.00481	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3676	 7709	 0.032503	 0.032511	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76575	 3676	 0.04575	 0.035861	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3677	 76576	 0.007326	 0.014504	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3678	 76576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3678	 76576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3679	 3680	 0.019683	 0.019741	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76576	 3679	 0.016651	 0.022697	 0.0005	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3679	 77427	 0.04158	 0.1277	 0.0024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3681	 3683	 0.009738	 0.029311	 0.00057	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3681	 3695	 0.012817	 0.027365	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76571	 3682	 0.010856	 0.031135	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3682	 76577	 0.010645	 0.041412	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3683	 76577	 0.005856	 0.02092	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3684	 3696	 0.005996	 0.030126	 0.00784	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76470	 3684	 0.001676	 0.009734	 0.00229	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3684	 76577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3684	 76577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3685	 7434	 0.00359	 0.013965	 0.00373	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3685	 76578	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3685	 76578	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3686	 3687	 0.005409	 0.018928	 0.00627	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76470	 3686	 0.000581	 0.004576	 0.00134	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3686	 76579	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3686	 76579	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3687	 4654	 0.005485	 0.021557	 0.00564	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3687	 76580	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3687	 76580	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76580	 3688	 0.088237	 0.069831	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3689	 3690	 0.02678	 0.068106	 0.00108	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3689	 3691	 0.010721	 0.021227	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3689	 3702	 0.20923	 0.16052	 0.00215	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3690	 3704	 0.069044	 0.13671	 0.00201	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76471	 3690	 0.01198	 0.04753	 0.00136	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3691	 76581	 0.04493	 0.049418	 0.00066	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3692	 7728	 0.03841	 0.049986	 0.0007	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3692	 76581	 0.029016	 0.066662	 0.00101	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3693	 3696	 0.004539	 0.012186	 0.00276	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3694	 3695	 0.00618	 0.015886	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3694	 3699	 0.010979	 0.028223	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3696	 76581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3696	 76581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3697	 3698	 0.02739	 0.02147	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3698	 3701	 0.12345	 0.097703	 0.00123	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76581	 3698	 0.034811	 0.06376	 0.0011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3699	 3700	 0.01079	 0.027737	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76581	 3700	 0.007019	 0.018043	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3703	 3704	 0.16385	 0.11846	 0.0018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3704	 4655	 0.16991	 0.13034	 0.00175	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3705	 3709	 0.1195	 0.094572	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3706	 3717	 0.23417	 0.18358	 0.00236	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3707	 3708	 0.05328	 0.17775	 0.00282	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3707	 8504	 0.01878	 0.10552	 0.00195	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76505	 3707	 0.018397	 0.092497	 0.00251	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3708	 3709	 0.052862	 0.13701	 0.00259	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3709	 3710	 0.017263	 0.14362	 0.00272	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3709	 3716	 0.03096	 0.1106	 0.0022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3709	 3716	 0.03096	 0.1106	 0.0022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3710	 3711	 0.01242	 0.080131	 0.00255	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3710	 3714	 0.1231	 0.22552	 0.00389	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3710	 3715	 0.2068	 0.14952	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3711	 3713	 0.013807	 0.08233	 0.0023	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3712	 77438	 0.093736	 0.18561	 0.00272	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3713	 7777	 0.23321	 0.18283	 0.00235	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3713	 77438	 0.040005	 0.22744	 0.00412	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3716	 4121	 0.037167	 0.11919	 0.00295	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3716	 4121	 0.037167	 0.11919	 0.00295	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3718	 7281	 0.001445	 0.012397	 0.00353	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76497	 3718	 0.000287	 0.002759	 0.0008	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3719	 3723	 0.005995	 0.004745	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3720	 3764	 0.004157	 0.004572	 6e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3720	 3771	 0.004485	 0.00355	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3721	 3764	 0.001578	 0.004057	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3721	 76586	 0.001014	 0.004948	 9e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3722	 4050	 0.00042	 0.004756	 0.0433	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	3722	 76582	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3723	 3741	 0.007331	 0.005802	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3723	 76585	 0.003895	 0.008835	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76583	 3724	 0.006351	 0.004112	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3725	 3783	 0.007663	 0.005878	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3726	 3727	 0.000296	 0.00085	 0.00021	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76582	 3726	 0.000278	 0.001006	 0.00022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3727	 3728	 0.000245	 0.000684	 0.00014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3728	 76584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3728	 76584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3729	 3753	 0.000838	 0.003357	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3729	 3778	 0.000797	 0.00413	 0.00101	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3729	 76585	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3729	 76585	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76584	 3730	 0.009061	 0.009965	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3731	 3733	 0.000405	 0.002646	 6e-05	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76584	 3731	 0.000352	 0.00274	 5e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3732	 3733	 0.000388	 0.002839	 5e-05	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3732	 76589	 0.000647	 0.00398	 7e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3734	 76586	 0.004784	 0.003097	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3735	 3737	 0.00039	 0.002396	 4e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3735	 3756	 0.006143	 0.009411	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76583	 3735	 0.000627	 0.005219	 0.0001	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3736	 3738	 0.000364	 0.001542	 0.00035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3736	 3762	 0.000233	 0.000934	 0.00024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3737	 3739	 0.003274	 0.003601	 5e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3737	 76589	 0.002015	 0.008978	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3738	 7282	 0.001922	 0.01126	 0.00307	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3738	 76586	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3738	 76586	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76586	 3740	 0.00679	 0.005373	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3742	 3744	 0.00139	 0.003573	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3742	 3758	 0.002112	 0.004183	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76585	 3743	 0.005488	 0.003967	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3744	 3748	 0.001208	 0.002999	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76582	 3745	 0.000705	 0.0023	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3745	 76587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3745	 76587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3746	 3788	 0.003911	 0.003095	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3747	 3843	 0.003155	 0.002473	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3748	 3749	 0.004486	 0.00355	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3748	 3809	 0.006583	 0.005418	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76585	 3748	 0.002837	 0.009464	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3750	 3752	 0.003114	 0.002464	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3750	 3756	 0.005469	 0.007462	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3750	 76597	 0.002205	 0.005609	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3751	 3813	 0.006092	 0.006635	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3753	 3762	 0.000805	 0.003276	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3753	 3857	 0.000661	 0.001661	 0.00043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3753	 76588	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3753	 76588	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3754	 6240	 0.001761	 0.005873	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76587	 3754	 0.005338	 0.009926	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3754	 76597	 0.004479	 0.008578	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3755	 3766	 0.005561	 0.004401	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76588	 3755	 0.001676	 0.002994	 4e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3757	 3759	 0.001197	 0.002738	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3757	 3761	 0.006857	 0.005045	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76587	 3757	 0.002069	 0.007927	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3758	 3760	 0.001912	 0.004392	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3759	 3798	 0.005228	 0.004138	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3759	 3820	 0.001983	 0.005097	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76586	 3760	 0.003267	 0.007585	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3762	 3849	 0.000445	 0.001499	 0.00037	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3763	 3769	 0.00036	 0.00112	 0.00023	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3763	 76589	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3763	 76589	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3764	 3773	 0.003692	 0.002922	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3765	 3767	 0.005366	 0.003948	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3765	 3795	 0.001587	 0.006175	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76589	 3765	 0.00101	 0.004337	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3768	 76607	 0.004112	 0.008141	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3769	 3770	 0.000265	 0.000959	 0.00021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3770	 3778	 0.000552	 0.001628	 0.00038	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 3774	 0.002218	 0.004248	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 76590	 0.001725	 0.004004	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3774	 3791	 0.005097	 0.00375	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3775	 3811	 0.006167	 0.00488	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3775	 76590	 0.004823	 0.005305	 7e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3776	 3780	 0.003661	 0.007247	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3776	 3781	 0.011765	 0.008334	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3776	 76599	 0.005851	 0.022761	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 76607	 0.005095	 0.004778	 7e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3778	 76590	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3778	 76590	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3779	 3834	 0.001002	 0.006159	 0.00011	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3779	 76598	 0.00454	 0.013022	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3779	 76599	 0.002136	 0.008216	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3779	 76599	 0.002136	 0.008216	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3782	 3783	 0.011547	 0.008496	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3782	 3785	 0.001513	 0.004992	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76585	 3782	 0.002755	 0.007082	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76590	 3782	 0.001562	 0.008779	 0.00016	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3784	 3797	 0.000482	 0.002643	 0.0007	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3784	 7290	 0.001138	 0.005929	 0.00155	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3785	 3787	 0.004856	 0.003806	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3785	 3788	 0.004582	 0.006022	 8e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3785	 3790	 0.005051	 0.003959	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3786	 3787	 0.003839	 0.002824	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3789	 3790	 0.005073	 0.003844	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3792	 76591	 0.005573	 0.00441	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3793	 3795	 0.008518	 0.006741	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3794	 3797	 0.000353	 0.002065	 0.00056	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3794	 3800	 0.000212	 0.001343	 0.00036	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3794	 76591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3794	 76591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3795	 3796	 0.001777	 0.005041	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3796	 3805	 0.002422	 0.005565	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3799	 3831	 0.005944	 0.004297	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3800	 3806	 0.000235	 0.001487	 0.0004	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3801	 3867	 0.001011	 0.002673	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3801	 76592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3801	 76592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3802	 3803	 0.002757	 0.002471	 5e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3802	 3804	 0.004145	 0.004056	 6e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3802	 76594	 0.002349	 0.010465	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3803	 3819	 0.002875	 0.002115	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3804	 3805	 0.001377	 0.002951	 5e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3804	 3808	 0.003686	 0.009336	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76590	 3804	 0.006439	 0.020445	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3804	 76595	 0.001466	 0.008331	 0.00015	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3805	 3807	 0.006531	 0.005169	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3806	 3830	 0.0005	 0.003076	 0.00089	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3806	 76593	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3806	 76593	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3808	 3813	 0.00176	 0.004523	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3808	 3973	 0.004899	 0.006439	 9e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76593	 3810	 0.008132	 0.006436	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76593	 3812	 0.012026	 0.009517	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3813	 3966	 0.005853	 0.003789	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3814	 3815	 0.006598	 0.005222	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3815	 76598	 0.010044	 0.007949	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3816	 3818	 0.00033	 0.000899	 0.0002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3816	 3875	 0.000251	 0.000985	 0.00026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3816	 4001	 0.000491	 0.001776	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3816	 76594	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3816	 76594	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3817	 3834	 0.001109	 0.004913	 0.00015	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76593	 3817	 0.00095	 0.005403	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3818	 76595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3818	 76595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3820	 3821	 0.002229	 0.005729	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76592	 3821	 0.002545	 0.005454	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76592	 3822	 0.005754	 0.00416	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3823	 3824	 0.007226	 0.005224	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3824	 76596	 0.001714	 0.003979	 6e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3825	 76606	 0.003332	 0.002637	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3826	 76596	 0.002697	 0.001746	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3827	 3828	 0.000231	 0.001158	 0.0003	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3827	 3861	 0.000343	 0.001546	 0.00041	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3827	 76596	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3827	 76596	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76582	 3828	 0.001997	 0.00685	 0.00164	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3828	 76597	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3828	 76597	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3828	 77095	 0.000803	 0.004421	 0.0016	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76597	 3829	 0.00278	 0.0022	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3830	 3907	 0.000151	 0.001336	 0.00036	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3830	 76598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3830	 76598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76583	 3831	 0.01002	 0.028435	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76592	 3831	 0.002138	 0.005233	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3832	 3833	 0.002048	 0.005209	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3832	 3836	 0.003749	 0.009534	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3832	 77096	 0.002516	 0.009642	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3833	 3837	 0.001494	 0.003469	 5e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76597	 3835	 0.001364	 0.002701	 4e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3837	 3848	 0.001353	 0.004357	 7e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3838	 3901	 0.00054	 0.002163	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3838	 3903	 0.000384	 0.001101	 0.00027	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76492	 3838	 0.002384	 0.01948	 0.00529	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3838	 76599	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3838	 76599	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3839	 3848	 0.001058	 0.003529	 6e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3839	 6250	 0.002189	 0.007476	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3840	 3841	 0.00555	 0.003593	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3841	 3844	 0.006853	 0.004954	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76599	 3841	 0.00203	 0.005217	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3842	 3851	 0.00036	 0.001414	 0.00037	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3842	 3898	 0.000506	 0.00399	 0.00117	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3842	 76600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3842	 76600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3842	 77098	 0.0002	 0.002214	 0.00066	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3843	 3852	 0.000945	 0.002429	 4e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3843	 3891	 0.002039	 0.003585	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76600	 3843	 0.001087	 0.004935	 0.00011	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3845	 3869	 0.003159	 0.0025	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3845	 76608	 0.002582	 0.004641	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3846	 3847	 0.00019	 0.000761	 0.00019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3846	 3854	 0.000419	 0.001775	 0.0004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3846	 3871	 0.000738	 0.003637	 0.00098	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3846	 3890	 0.000387	 0.001471	 0.00041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3846	 76601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3846	 76601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3847	 3862	 0.000209	 0.000837	 0.00021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3848	 76603	 0.000739	 0.003696	 7e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3849	 3862	 0.000244	 0.000863	 0.00019	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3849	 76602	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3849	 76602	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3850	 76603	 0.004153	 0.003255	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3851	 3858	 0.000239	 0.001011	 0.00023	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3851	 76603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3851	 76603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3852	 3853	 0.002249	 0.002271	 3e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3854	 3857	 0.000317	 0.001088	 0.00026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3854	 76604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3854	 76604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76602	 3855	 0.001643	 0.002623	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76604	 3855	 0.000871	 0.002238	 3e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3856	 3868	 0.000872	 0.002473	 4e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76600	 3856	 0.002244	 0.008731	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3857	 76605	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3857	 76605	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3858	 3861	 0.000235	 0.000854	 0.00026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3859	 3887	 0.005189	 0.004107	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3860	 76606	 0.002692	 0.00213	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3861	 76606	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3861	 76606	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3862	 76607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3862	 76607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76606	 3863	 0.001092	 0.00373	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76606	 3863	 0.001092	 0.00373	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3863	 76608	 0.000327	 0.002923	 7e-05	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3864	 3865	 0.004439	 0.003479	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3865	 3949	 0.002519	 0.004615	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3866	 3874	 0.005598	 0.004118	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3866	 76610	 0.001117	 0.002594	 4e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3867	 3870	 0.000434	 0.001182	 0.00026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3867	 3875	 0.000746	 0.002601	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3867	 76608	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3867	 76608	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3868	 3877	 0.001979	 0.003878	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3868	 76609	 0.001252	 0.003218	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 3872	 0.000327	 0.000965	 0.00022	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 76609	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3870	 76609	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3871	 3895	 0.000199	 0.001168	 0.00032	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3871	 76610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3871	 76610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3872	 3878	 0.000313	 0.000788	 0.0002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76609	 3873	 0.004035	 0.002969	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3875	 3878	 0.000293	 0.000773	 0.00018	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3876	 3885	 0.005946	 0.004705	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3877	 3889	 0.005788	 0.003747	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3878	 3880	 0.000231	 0.000925	 0.00023	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3879	 3880	 7.3e-05	 0.000302	 9e-05	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3879	 3888	 9.6e-05	 0.000465	 0.00011	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3880	 4001	 0.000423	 0.001693	 0.00043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3880	 76611	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3880	 76611	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3881	 3885	 0.007883	 0.006179	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3882	 76612	 0.00293	 0.002319	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3883	 3886	 0.000195	 0.000792	 0.00019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3883	 4006	 0.000259	 0.001055	 0.00026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3883	 76612	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3883	 76612	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3884	 3989	 0.004412	 0.003491	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3884	 76613	 0.001651	 0.003236	 5e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76601	 3885	 0.002178	 0.004313	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 3900	 0.000209	 0.000717	 0.00017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 3991	 0.000587	 0.002387	 0.00058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 76613	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3886	 76613	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76605	 3887	 0.002596	 0.004144	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3888	 3898	 0.000198	 0.001053	 0.00024	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3890	 3899	 0.00015	 0.000601	 0.00015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3891	 3892	 0.004298	 0.003368	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76610	 3893	 0.004207	 0.003297	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3894	 3904	 0.006592	 0.006594	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3894	 77099	 0.004094	 0.007738	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3895	 3945	 0.000282	 0.001604	 0.00046	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3896	 3904	 0.004592	 0.003319	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3897	 3901	 0.000342	 0.001209	 0.00027	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3897	 3926	 0.000349	 0.001215	 0.00028	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3898	 3902	 0.000291	 0.001167	 0.00029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3898	 76614	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3898	 76614	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3899	 3901	 0.000165	 0.000669	 0.00016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3900	 3902	 0.000239	 0.000957	 0.00024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3903	 3924	 0.000433	 0.001531	 0.00035	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 3906	 5.9e-05	 0.000606	 0.00016	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 3914	 0.000837	 0.002104	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 3932	 0.001335	 0.005513	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 76615	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3905	 76615	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3905	 77098	 0.000488	 0.005172	 0.00154	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3906	 3908	 9.5e-05	 0.000791	 0.00031	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3907	 3910	 0.000135	 0.001099	 0.00035	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3908	 4007	 7.8e-05	 0.000652	 0.0002	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3908	 76616	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3908	 76616	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3909	 3910	 0.000108	 0.000829	 0.00022	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3909	 3931	 0.00053	 0.003105	 0.00085	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3909	 3933	 0.000319	 0.001389	 0.0004	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3909	 76617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3909	 76617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3910	 76618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3910	 76618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76616	 3911	 0.005225	 0.004095	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 76619	 0.003324	 0.003657	 5e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76615	 3913	 0.003752	 0.002658	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3914	 3918	 0.00052	 0.001451	 0.0003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3914	 76619	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3914	 76619	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3915	 3916	 0.008037	 0.00636	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76598	 3915	 0.009479	 0.006136	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3917	 3933	 0.000219	 0.002101	 0.00061	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3917	 3935	 0.000208	 0.002168	 0.00073	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3917	 5719	 0.001143	 0.019577	 0.00563	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3918	 3921	 0.00029	 0.000809	 0.00017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 3920	 0.000569	 0.001476	 0.00036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 3921	 0.000294	 0.001175	 0.0003	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 4018	 0.00065	 0.001915	 0.00045	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3920	 4026	 0.000713	 0.001987	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3921	 3927	 0.000283	 0.001133	 0.00029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3921	 76620	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3921	 76620	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3922	 3924	 0.000587	 0.002074	 0.00047	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3922	 76621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3922	 76621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3922	 76654	 0.000687	 0.00657	 0.00217	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3923	 3930	 0.000337	 0.001426	 0.00032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3923	 3963	 0.000319	 0.002483	 0.00064	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3923	 76622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3923	 76622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76620	 3925	 0.004068	 0.003188	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3926	 3931	 0.000355	 0.001394	 0.00036	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3927	 6277	 0.000311	 0.001266	 0.00031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3928	 76623	 0.005752	 0.00756	 0.0001	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3929	 3934	 0.000304	 0.001215	 0.00031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3929	 6277	 0.000455	 0.001533	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3929	 76623	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3929	 76623	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3930	 3932	 0.000172	 0.000689	 0.00017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 76624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3931	 76624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3931	 76654	 0.000777	 0.006242	 0.00175	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3932	 3934	 0.00035	 0.001374	 0.00036	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3932	 3937	 0.000471	 0.003607	 0.00097	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3933	 3939	 0.000405	 0.003683	 0.00093	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3935	 76654	 0.000282	 0.002988	 0.00089	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76622	 3936	 0.006577	 0.011079	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	3936	 76625	 0.00128	 0.006245	 0.00011	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 3944	 0.000257	 0.002515	 0.00071	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 76625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3937	 76625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3938	 3964	 0.009065	 0.007174	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 76626	 0.006088	 0.006149	 8e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3939	 3940	 0.000169	 0.000677	 0.00017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3939	 76626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3939	 76626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3939	 76654	 0.000781	 0.004573	 0.00125	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3940	 3941	 0.000173	 0.000692	 0.00017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3941	 3942	 0.000152	 0.000553	 0.00017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3942	 3946	 0.00021	 0.00084	 0.00021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3943	 3944	 0.00024	 0.002056	 0.00059	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3943	 8277	 0.00015	 0.000899	 0.00027	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3944	 3954	 0.000276	 0.001106	 0.00028	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3945	 3946	 0.000234	 0.000966	 0.00023	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3945	 3948	 0.000339	 0.001356	 0.00034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3945	 3959	 0.000338	 0.001981	 0.00054	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3947	 76627	 0.003541	 0.002802	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3948	 3950	 0.000198	 0.000793	 0.0002	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3948	 3951	 0.000902	 0.002319	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3948	 76627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3948	 76627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76627	 3949	 0.001448	 0.003544	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3950	 3953	 0.000311	 0.001354	 0.00039	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3951	 3995	 0.00081	 0.002206	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3952	 76630	 0.006442	 0.00417	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3953	 3955	 0.000164	 0.000678	 0.00016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3953	 3992	 0.001619	 0.005724	 0.00129	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3953	 4030	 0.000902	 0.002383	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3954	 3958	 0.000171	 0.001329	 0.00035	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3954	 3960	 0.000131	 0.001015	 0.00026	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3954	 8294	 0.001008	 0.003459	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3955	 3979	 0.000316	 0.001588	 0.00041	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3956	 3957	 0.003541	 0.002776	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3957	 76628	 0.002499	 0.002506	 4e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3958	 8295	 0.000203	 0.00153	 0.00042	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3959	 3961	 0.000125	 0.000868	 0.00025	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3959	 76628	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3959	 76628	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3960	 3963	 0.000281	 0.002558	 0.00065	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3961	 3965	 0.000423	 0.002432	 0.00069	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3961	 76629	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3961	 76629	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3962	 3970	 0.001461	 0.005404	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76629	 3962	 0.001504	 0.004314	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3963	 76630	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3963	 76630	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3965	 76631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3965	 76631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3965	 76655	 0.000258	 0.002346	 0.00059	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76626	 3967	 0.007789	 0.006164	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3968	 3969	 0.001469	 0.003776	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76588	 3968	 0.004234	 0.010884	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3969	 3971	 0.001641	 0.002864	 4e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3969	 3978	 0.001489	 0.00412	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76631	 3970	 0.003047	 0.006033	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3970	 76632	 0.008629	 0.006764	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3970	 76636	 0.002678	 0.00548	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3971	 3972	 0.002687	 0.003666	 7e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3972	 3973	 0.001863	 0.002424	 3e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3974	 3977	 0.000273	 0.000964	 0.00022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3974	 3988	 0.000186	 0.000628	 0.00016	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3974	 76632	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3974	 76632	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3975	 3976	 0.00318	 0.002059	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76595	 3975	 0.005892	 0.01063	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3977	 3979	 0.00033	 0.000988	 0.00022	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3978	 3980	 0.00062	 0.002536	 5e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3979	 3981	 0.000296	 0.000782	 0.00018	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3979	 3986	 0.000368	 0.00124	 0.00031	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3980	 3982	 0.004058	 0.002934	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3980	 76638	 0.000862	 0.004749	 0.00011	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3981	 4034	 0.000673	 0.00178	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3981	 76633	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3981	 76633	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76633	 3983	 0.003107	 0.002459	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3984	 3986	 0.000399	 0.001053	 0.00025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3984	 3998	 0.00032	 0.001115	 0.00026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3984	 4034	 0.00052	 0.001785	 0.00043	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 3987	 0.001749	 0.002276	 3e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	3986	 3992	 0.001074	 0.003165	 0.00074	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	3986	 3996	 0.000288	 0.000987	 0.00024	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76611	 3987	 0.000835	 0.001976	 4e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3988	 3992	 0.000452	 0.001524	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3988	 76634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3988	 76634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3990	 76635	 0.003655	 0.002893	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3991	 3993	 0.000258	 0.000885	 0.00021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3991	 76635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3991	 76635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3992	 4048	 0.000407	 0.001867	 0.00048	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3992	 76636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3992	 76636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3992	 76655	 0.000666	 0.003057	 0.00078	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	3993	 3995	 0.000253	 0.001044	 0.00025	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3993	 4003	 0.00054	 0.001507	 0.00032	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76634	 3994	 0.003777	 0.00273	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	3995	 3999	 0.000294	 0.001028	 0.00034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3996	 4002	 0.000294	 0.00101	 0.00024	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	3997	 3999	 0.000218	 0.000857	 0.00022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3997	 4001	 0.00062	 0.00256	 0.00061	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	3998	 4000	 0.000284	 0.001029	 0.00022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4000	 4017	 0.000247	 0.000972	 0.00025	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4000	 76637	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4000	 76637	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4001	 76638	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4001	 76638	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4002	 4014	 0.000324	 0.001113	 0.00027	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4003	 4016	 0.000732	 0.002054	 0.00053	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4004	 4011	 0.003062	 0.004691	 7e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76636	 4004	 0.007926	 0.006272	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 4006	 0.000228	 0.000887	 0.00024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 4007	 0.000108	 0.000893	 0.00023	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 4013	 0.0003	 0.001202	 0.0003	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 4012	 0.001949	 0.001495	 2e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4009	 4010	 0.003879	 0.003041	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4009	 76640	 0.002978	 0.005837	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4011	 76653	 0.002824	 0.00559	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 76639	 0.001175	 0.002326	 3e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 4016	 0.000254	 0.001073	 0.00024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 76639	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4013	 76639	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4014	 4027	 0.000289	 0.000991	 0.00024	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4015	 4016	 0.000385	 0.001017	 0.00024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4015	 4020	 0.000509	 0.001345	 0.00031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4016	 4022	 0.000308	 0.000775	 0.0002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4016	 4024	 0.000966	 0.002693	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4016	 76640	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4016	 76640	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4017	 4025	 0.000253	 0.001014	 0.00026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4018	 4026	 0.001015	 0.002763	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4018	 76641	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4018	 76641	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76641	 4019	 0.001876	 0.005382	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4019	 76642	 0.001663	 0.002064	 4e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4020	 4024	 0.000425	 0.001067	 0.00028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4020	 76642	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4020	 76642	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4021	 4037	 0.000256	 0.001452	 0.00042	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4021	 4040	 0.000299	 0.001737	 0.00041	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4021	 76643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4021	 76643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4022	 4030	 0.000387	 0.00104	 0.00024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4023	 4044	 0.013154	 0.01041	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4023	 4046	 0.008697	 0.006883	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4023	 76651	 0.002111	 0.005369	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4024	 4028	 0.000278	 0.001007	 0.00022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4024	 76644	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4024	 76644	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4025	 4037	 0.000388	 0.001853	 0.00065	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4025	 76645	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4025	 76645	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4026	 76646	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4026	 76646	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4026	 77556	 0.00236	 0.012064	 0.00329	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4027	 4035	 0.000298	 0.001134	 0.00032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4027	 76647	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4027	 76647	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4028	 4034	 0.00022	 0.000756	 0.00018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4029	 76648	 0.009635	 0.007625	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4031	 4048	 0.000258	 0.001538	 0.0004	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4031	 76648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4031	 76648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4031	 77556	 0.000467	 0.003243	 0.00093	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 4042	 0.000978	 0.003669	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76648	 4032	 0.00751	 0.005943	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 76650	 0.0011	 0.00428	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 76649	 0.003557	 0.002571	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4034	 76649	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4034	 76649	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4035	 4039	 0.000274	 0.001116	 0.00027	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4035	 76650	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4035	 76650	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76646	 4036	 0.001333	 0.003391	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4037	 4039	 0.000153	 0.000581	 0.00016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4037	 76651	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4037	 76651	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4037	 77556	 0.001326	 0.005159	 0.00138	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76645	 4038	 0.027168	 0.0215	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4040	 8327	 0.000253	 0.001411	 0.00036	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4040	 76652	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4040	 76652	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4041	 8325	 0.012735	 0.012863	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76652	 4041	 0.0077	 0.005665	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4042	 8326	 0.001561	 0.006954	 0.00012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4043	 4044	 0.005792	 0.004584	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4045	 4046	 0.004733	 0.003746	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4047	 4053	 0.030015	 0.021698	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4047	 77557	 0.005545	 0.010479	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4048	 76653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4048	 76653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76653	 4049	 0.006343	 0.004972	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4050	 8324	 8.3e-05	 0.00103	 0.00954	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4050	 76654	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4050	 76654	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4051	 6264	 0.001157	 0.00781	 0.01438	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4051	 76655	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4051	 76655	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4051	 77555	 0.000202	 0.001733	 0.00381	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76648	 4052	 0.005748	 0.008413	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4054	 4066	 0.004028	 0.01044	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4056	 4086	 0.024671	 0.019524	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4057	 76656	 0.016851	 0.013335	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4058	 4060	 0.001022	 0.006472	 0.00176	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4058	 13557	 0.00626	 0.071579	 0.02184	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4058	 76656	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4058	 76656	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4059	 76657	 0.008691	 0.017207	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4060	 4078	 0.005039	 0.013317	 0.00312	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4060	 4083	 0.00254	 0.014878	 0.00405	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4060	 76657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4060	 76657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4061	 4069	 0.010431	 0.006753	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4062	 4063	 0.002174	 0.00457	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76656	 4062	 0.002431	 0.010834	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76657	 4062	 0.01091	 0.03129	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4063	 4065	 0.003379	 0.013144	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76656	 4063	 0.002034	 0.009926	 0.00017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4065	 4066	 0.003864	 0.011866	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4066	 4067	 0.009821	 0.019248	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4066	 4099	 0.011853	 0.030469	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4066	 4105	 0.010819	 0.025619	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4067	 4068	 0.023617	 0.015289	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4067	 4085	 0.069689	 0.054626	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76656	 4069	 0.011126	 0.021804	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 76664	 0.12926	 0.095109	 0.00139	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4071	 4072	 0.007453	 0.026346	 0.00594	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4071	 4267	 0.010553	 0.035557	 0.00884	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4071	 76658	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4071	 76658	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4072	 4075	 0.006509	 0.023006	 0.00518	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 76659	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4072	 76659	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76658	 4073	 0.16262	 0.11965	 0.00175	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4074	 4088	 0.013553	 0.044208	 0.01174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4074	 8134	 0.009407	 0.032271	 0.00773	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4074	 76660	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4074	 76660	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4075	 4076	 0.003659	 0.009841	 0.00276	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4075	 76661	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4075	 76661	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4076	 4078	 0.002428	 0.006416	 0.0015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76661	 4077	 0.016927	 0.04387	 0.00083	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4077	 76664	 0.107	 0.098565	 0.00158	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4078	 76662	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4078	 76662	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4079	 4216	 0.039161	 0.095857	 0.00164	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76662	 4079	 0.033002	 0.084837	 0.00131	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4080	 76689	 0.19027	 0.1348	 0.00213	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4081	 4215	 0.013894	 0.04532	 0.01203	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4081	 4282	 0.023091	 0.081641	 0.0184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4082	 76663	 0.12498	 0.12763	 0.00199	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4083	 4104	 0.016097	 0.04489	 0.00942	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4083	 76663	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4083	 76663	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76663	 4084	 0.02402	 0.059619	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4087	 4103	 0.030605	 0.02422	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4088	 4104	 0.003945	 0.011813	 0.00266	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4088	 76664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4088	 76664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4089	 4090	 0.01292	 0.00934	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4089	 4091	 0.028705	 0.018584	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4089	 4095	 0.00768	 0.020303	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4089	 76665	 0.00456	 0.0313	 0.00057	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 4098	 0.027782	 0.02044	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4093	 4094	 0.045277	 0.03549	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 4095	 0.018711	 0.028663	 0.0004	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4095	 4096	 0.009434	 0.008453	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 4098	 0.00506	 0.01341	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 76666	 0.00493	 0.028023	 0.00051	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4098	 4107	 0.036076	 0.024233	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4098	 8137	 0.11697	 0.11732	 0.0019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 4100	 0.01443	 0.010933	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 4103	 0.009488	 0.015553	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4100	 4101	 0.005509	 0.005564	 7e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4101	 4102	 0.006192	 0.007412	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 4105	 0.017117	 0.023353	 0.00042	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4104	 4106	 0.002263	 0.007764	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4104	 8136	 0.012259	 0.043334	 0.00977	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4104	 76665	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4104	 76665	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4104	 76684	 0.040109	 0.16077	 0.04056	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76656	 4105	 0.023516	 0.060452	 0.00094	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76665	 4105	 0.005376	 0.026233	 0.00045	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4106	 76666	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4106	 76666	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4107	 8138	 0.071572	 0.056641	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76665	 4108	 0.094463	 0.074046	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 4595	 0.026572	 0.021028	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 4116	 0.033395	 0.12528	 0.00225	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 4116	 0.033395	 0.12528	 0.00225	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 4122	 0.032156	 0.1251	 0.00209	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 4122	 0.032156	 0.1251	 0.00209	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 4123	 0.021472	 0.1305	 0.00241	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76505	 4111	 0.16911	 0.12443	 0.00182	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 4118	 0.016893	 0.13167	 0.00246	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 77609	 0.01915	 0.13998	 0.00258	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4113	 4116	 0.052357	 0.22162	 0.00418	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76505	 4113	 0.15547	 0.35732	 0.00543	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4114	 4115	 0.076718	 0.12246	 0.00282	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4114	 76751	 0.023012	 0.047092	 0.00116	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4116	 4117	 0.023757	 0.11593	 0.002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4117	 4118	 0.043779	 0.17032	 0.00284	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4118	 4128	 0.0123	 0.10233	 0.00194	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4119	 4124	 0.015125	 0.058188	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4119	 4124	 0.015125	 0.058188	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4119	 4128	 0.01339	 0.11009	 0.00213	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76551	 4120	 0.17962	 0.1163	 0.00221	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4121	 76667	 0.016962	 0.052034	 0.00141	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4121	 76667	 0.016962	 0.052034	 0.00141	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76551	 4122	 0.039366	 0.17249	 0.00371	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4122	 79100	 0.047747	 0.18577	 0.0031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4122	 79100	 0.047747	 0.18577	 0.0031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4123	 4180	 0.024599	 0.11869	 0.0021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 76667	 0.003635	 0.012986	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 76667	 0.003635	 0.012986	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76551	 4125	 0.014472	 0.010647	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4126	 76667	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4126	 76667	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76667	 4127	 0.016327	 0.017783	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4129	 6689	 0.002679	 0.022975	 0.00654	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4129	 8268	 0.002562	 0.02197	 0.00625	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 4131	 0.005993	 0.028564	 0.00827	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 6689	 0.007048	 0.037952	 0.01043	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4131	 4132	 0.006132	 0.023309	 0.00653	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4131	 76668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4131	 76668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4132	 4134	 0.006552	 0.022077	 0.00549	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 76669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4132	 76669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76668	 4133	 0.014976	 0.094043	 0.00206	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4133	 76671	 0.013864	 0.07881	 0.00143	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4134	 4141	 0.004979	 0.016239	 0.00431	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4135	 77167	 0.066043	 0.052266	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4136	 4137	 0.008668	 0.031387	 0.00673	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4136	 6550	 0.010201	 0.034371	 0.00854	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4136	 76670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4136	 76670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4137	 8165	 0.008571	 0.027954	 0.00742	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76495	 4138	 0.024286	 0.093052	 0.00263	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76670	 4138	 0.05039	 0.16811	 0.00266	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4139	 4146	 0.11916	 0.11919	 0.00161	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76495	 4139	 0.27941	 0.27957	 0.00378	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4140	 7750	 0.025354	 0.08367	 0.00136	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4140	 76672	 0.023135	 0.06132	 0.00156	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4141	 4147	 0.001764	 0.004434	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4141	 76671	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4141	 76671	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4142	 4143	 0.017342	 0.013724	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76671	 4142	 0.010641	 0.024705	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4143	 4144	 0.010151	 0.007786	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4145	 76672	 0.034863	 0.02565	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4146	 76672	 0.013105	 0.014414	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4147	 76672	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4147	 76672	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4148	 4149	 0.019013	 0.015046	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4148	 4154	 0.015173	 0.034858	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4148	 76673	 0.006439	 0.018468	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4148	 76678	 0.005984	 0.022925	 0.00065	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76545	 4150	 0.009017	 0.017853	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76545	 4151	 0.013744	 0.010773	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4152	 4154	 0.008857	 0.016468	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76545	 4152	 0.002209	 0.006337	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4153	 76673	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4153	 76673	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76545	 4155	 0.018781	 0.014863	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4156	 4182	 0.001072	 0.009732	 0.00737	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4156	 4573	 0.002481	 0.0261	 0.01466	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4157	 4159	 0.10019	 0.064863	 0.00123	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4158	 4159	 0.018568	 0.014242	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76508	 4159	 0.009236	 0.021871	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4160	 76674	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4160	 76674	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4161	 4164	 0.013046	 0.017784	 0.00039	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76674	 4161	 0.009637	 0.015383	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4162	 4166	 0.22677	 0.16066	 0.00254	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76674	 4162	 0.025982	 0.051443	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4163	 4164	 0.009172	 0.021294	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4163	 76675	 0.014503	 0.033671	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4165	 4167	 0.00659	 0.025049	 0.00701	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4165	 4172	 0.043301	 0.12082	 0.02538	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4165	 76675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4165	 76675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4167	 76676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4167	 76676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4168	 4170	 0.088069	 0.078919	 0.00161	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4169	 4175	 0.047673	 0.12636	 0.00321	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76676	 4169	 0.02557	 0.099478	 0.00166	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4170	 4171	 0.19011	 0.15047	 0.00189	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76676	 4170	 0.051902	 0.13452	 0.00254	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4172	 76677	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4172	 76677	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4173	 4177	 0.057077	 0.10788	 0.00174	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76677	 4173	 0.055759	 0.11411	 0.00281	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4174	 4175	 0.06389	 0.083148	 0.00116	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76675	 4174	 0.08705	 0.2238	 0.00346	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4174	 76678	 0.04556	 0.097636	 0.00171	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4175	 4177	 0.017369	 0.067571	 0.00113	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76545	 4176	 0.042145	 0.083445	 0.00122	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4177	 4178	 0.008418	 0.040618	 0.00072	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76545	 4178	 0.005938	 0.023763	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 76678	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4179	 76678	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76678	 4180	 0.019925	 0.097232	 0.00168	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76673	 4181	 0.026162	 0.086338	 0.0014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 4188	 0.001045	 0.005071	 0.00116	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 4198	 0.003668	 0.012584	 0.00301	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 76679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4183	 76679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4184	 4186	 0.016051	 0.010391	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 4186	 0.019113	 0.015126	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4186	 4187	 0.006594	 0.015614	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4186	 4201	 0.023377	 0.0185	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4186	 76682	 0.015484	 0.035412	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4187	 76680	 0.003427	 0.008681	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4188	 4198	 0.002192	 0.014707	 0.00355	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4188	 76680	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4188	 76680	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4188	 78605	 0.007517	 0.11256	 0.03788	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4189	 4190	 0.02183	 0.017276	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76680	 4189	 0.005503	 0.014145	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4191	 4192	 0.01366	 0.01081	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76680	 4191	 0.016377	 0.016381	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4193	 7747	 0.067449	 0.1734	 0.00268	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4193	 8141	 0.049401	 0.12093	 0.00207	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4194	 4196	 0.006183	 0.020627	 0.00523	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4194	 7746	 0.008632	 0.025981	 0.00813	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4195	 76682	 0.02302	 0.049147	 0.00111	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4196	 4197	 0.000975	 0.003284	 0.00082	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4197	 4198	 0.002288	 0.00916	 0.00231	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4197	 76681	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4197	 76681	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4198	 76682	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4198	 76682	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76681	 4199	 0.031398	 0.04086	 0.00057	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76682	 4200	 0.00853	 0.017456	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4202	 8143	 0.031978	 0.11424	 0.00227	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76679	 4202	 0.019933	 0.10705	 0.00254	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4203	 4204	 0.023635	 0.037726	 0.00087	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76680	 4203	 0.012919	 0.032066	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4205	 4209	 0.009595	 0.032914	 0.00789	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4205	 5499	 0.009117	 0.036502	 0.0092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4205	 76683	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4205	 76683	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4206	 4210	 0.011431	 0.045769	 0.01153	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4206	 6554	 0.019339	 0.076029	 0.0199	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4207	 4272	 0.001212	 0.013996	 0.12274	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4207	 76684	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76685	 4208	 0.009535	 0.007848	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4209	 76686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4209	 76686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76684	 4210	 0.00153	 0.006126	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4210	 76687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4210	 76687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4211	 6715	 0.21666	 0.17149	 0.00216	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76685	 4211	 0.071355	 0.12457	 0.00193	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4212	 4214	 0.041911	 0.094031	 0.0015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76687	 4212	 0.074214	 0.16427	 0.00269	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4213	 4215	 0.006734	 0.026199	 0.007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76684	 4213	 0.016107	 0.050353	 0.01459	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4213	 76688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4213	 76688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4214	 4216	 0.044994	 0.083663	 0.00196	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4215	 76689	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4215	 76689	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76661	 4216	 0.049216	 0.14117	 0.00217	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76688	 4216	 0.050991	 0.1913	 0.00344	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76507	 4217	 0.089543	 0.23021	 0.00356	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76507	 4218	 0.080765	 0.15992	 0.00235	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4219	 4220	 0.003811	 0.042152	 0.01264	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4221	 4223	 0.001296	 0.016871	 0.00488	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4222	 4230	 0.089253	 0.070636	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76509	 4223	 0.000211	 0.002658	 0.00082	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76510	 4224	 0.001359	 0.005024	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4225	 4226	 0.00183	 0.007041	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4225	 4229	 0.014018	 0.027473	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76510	 4225	 0.00586	 0.02611	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4226	 4227	 0.001729	 0.007315	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4227	 4235	 0.003248	 0.015851	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4228	 4235	 0.018128	 0.014346	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4230	 4234	 0.011095	 0.081952	 0.00171	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76507	 4230	 0.029427	 0.18093	 0.00326	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4230	 76691	 0.01111	 0.081202	 0.0015	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4231	 4232	 0.004305	 0.041332	 0.01202	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4231	 76690	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4231	 76690	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4232	 76691	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4232	 76691	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4233	 4597	 0.092272	 0.092297	 0.00125	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76691	 4233	 0.043648	 0.069672	 0.0016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4234	 4235	 0.005806	 0.033001	 0.0006	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4236	 4238	 0.13029	 0.14331	 0.00191	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4237	 4238	 0.15333	 0.11763	 0.00158	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4237	 4244	 0.14554	 0.11409	 0.00146	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4238	 77363	 0.062741	 0.16129	 0.0025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4239	 4242	 0.064411	 0.097693	 0.0014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4239	 76692	 0.074287	 0.069666	 0.00108	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4240	 4243	 0.009231	 0.036282	 0.00949	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4240	 7435	 0.005127	 0.024884	 0.00569	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4240	 76692	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4240	 76692	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76692	 4241	 0.095729	 0.069204	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4242	 4248	 0.026665	 0.076478	 0.00118	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4242	 4663	 0.027375	 0.064824	 0.00119	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4242	 76693	 0.015562	 0.078724	 0.00137	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4243	 4245	 0.013738	 0.036884	 0.00836	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76478	 4243	 0.003948	 0.04061	 0.01152	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4243	 76693	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4243	 76693	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4245	 4252	 0.010747	 0.028404	 0.00665	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76693	 4246	 0.10553	 0.11607	 0.00155	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4246	 76696	 0.22376	 0.17711	 0.00223	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4247	 4249	 0.001188	 0.006069	 0.00153	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4247	 4250	 0.005266	 0.021922	 0.00684	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4248	 76694	 0.003342	 0.011149	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76478	 4249	 0.001991	 0.012741	 0.00429	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4249	 76694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4249	 76694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4250	 4254	 0.009242	 0.03267	 0.00736	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4250	 76695	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4250	 76695	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76695	 4251	 0.14611	 0.11564	 0.00146	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4252	 4312	 0.020426	 0.04923	 0.0139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4252	 76696	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4252	 76696	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76696	 4253	 0.064445	 0.11511	 0.0017	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4253	 76711	 0.050744	 0.097181	 0.00153	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4254	 4316	 0.007865	 0.0265	 0.00659	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4255	 4256	 0.079462	 0.051445	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4255	 4329	 0.076948	 0.063336	 0.00128	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76695	 4256	 0.092738	 0.067042	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4257	 76697	 0.23428	 0.18544	 0.00233	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4258	 4259	 0.007149	 0.018892	 0.00442	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4258	 6540	 0.023187	 0.064668	 0.01358	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4258	 76697	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4258	 76697	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4259	 4261	 0.002805	 0.008767	 0.00254	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4259	 4262	 0.003457	 0.012519	 0.00269	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4260	 4261	 0.003584	 0.012076	 0.003	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4260	 4262	 0.004571	 0.011751	 0.00291	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4260	 4267	 0.012867	 0.042925	 0.01089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4260	 4268	 0.012475	 0.032069	 0.00794	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4260	 6543	 0.038539	 0.11368	 0.02646	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4260	 76698	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4260	 76698	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4261	 4262	 0.000981	 0.002672	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4262	 76699	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4262	 76699	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4263	 4264	 0.015938	 0.012613	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76699	 4263	 0.006566	 0.015549	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76699	 4265	 0.004742	 0.008523	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76698	 4266	 0.096851	 0.097826	 0.0013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4266	 77510	 0.027863	 0.09295	 0.00147	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 8134	 0.015653	 0.052745	 0.01311	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 8164	 0.010018	 0.04011	 0.01011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 76700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4268	 76700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4269	 4270	 0.13441	 0.10638	 0.00134	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4269	 4278	 0.046016	 0.1572	 0.00342	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4269	 6706	 0.0485	 0.12335	 0.00195	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4269	 77203	 0.039573	 0.18915	 0.00414	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4271	 77203	 0.18805	 0.14884	 0.00187	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 4274	 0.000721	 0.008061	 0.07532	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 6376	 0.003283	 0.037969	 0.33389	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 76701	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4272	 76701	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76701	 4273	 0.10316	 0.20426	 0.003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 12280	 0.001694	 0.023536	 0.3944	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 76702	 6.9e-05	 0.005555	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76703	 4274	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4275	 4276	 0.1984	 0.14599	 0.00214	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4276	 4277	 0.020705	 0.014968	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4276	 4280	 0.04441	 0.24958	 0.00462	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76701	 4276	 0.034143	 0.28077	 0.00544	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4278	 4279	 0.032571	 0.12671	 0.00212	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4279	 4280	 0.041574	 0.13333	 0.0033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76480	 4279	 0.032959	 0.17563	 0.00308	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4279	 76766	 0.051098	 0.15677	 0.00425	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4280	 8173	 0.056786	 0.18741	 0.00304	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4281	 8111	 0.000703	 0.011385	 0.04416	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76702	 4281	 0.001419	 0.014139	 0.04719	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4281	 78955	 0.003135	 0.046645	 0.17323	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4282	 8129	 0.008864	 0.061505	 0.01756	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76703	 4282	 0.007314	 0.060707	 0.01597	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4282	 76704	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4282	 76704	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4283	 4312	 0.013381	 0.035366	 0.00828	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 4344	 0.010549	 0.027387	 0.00665	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4284	 4292	 0.06643	 0.052072	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4285	 4286	 0.072967	 0.055971	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4286	 4292	 0.032787	 0.064257	 0.00096	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4286	 4359	 0.034032	 0.026933	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4287	 4318	 0.092876	 0.076447	 0.00155	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4287	 76713	 0.021151	 0.10205	 0.0018	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4287	 76714	 0.042979	 0.11049	 0.00171	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4288	 4289	 0.005568	 0.019404	 0.0045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4288	 4344	 0.00799	 0.03037	 0.0085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4289	 4315	 0.007471	 0.026037	 0.00604	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 4291	 0.006631	 0.037691	 0.00068	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 76705	 0.006944	 0.037001	 0.00065	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 76715	 0.008982	 0.032086	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 76715	 0.008982	 0.032086	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4291	 4292	 0.00811	 0.035532	 0.00076	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4292	 4336	 0.069993	 0.11173	 0.00257	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4292	 76705	 0.014786	 0.056884	 0.00097	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4292	 76710	 0.04326	 0.14432	 0.00229	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4293	 6720	 0.006589	 0.02638	 0.00665	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76467	 4293	 0.003235	 0.031057	 0.00903	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4293	 76705	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4293	 76705	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4294	 4299	 0.08326	 0.065264	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76705	 4295	 0.093257	 0.073101	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4296	 4346	 0.00241	 0.006257	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76467	 4296	 0.002886	 0.011345	 0.00297	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76518	 4296	 0.003915	 0.010529	 0.00295	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4296	 76706	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4296	 76706	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4297	 4301	 0.032281	 0.020899	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4298	 4346	 0.001851	 0.007035	 0.00197	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4298	 6721	 0.003764	 0.015932	 0.00359	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76518	 4298	 0.00907	 0.023315	 0.00577	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4298	 76707	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4298	 76707	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4299	 4301	 0.013135	 0.025742	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4299	 4343	 0.028034	 0.018149	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4300	 4301	 0.035922	 0.028428	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76468	 4301	 0.018982	 0.067812	 0.00135	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 4303	 0.053967	 0.039013	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 77516	 0.095563	 0.074908	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4303	 76708	 0.080773	 0.052294	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4304	 4306	 0.003153	 0.008333	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4304	 8190	 0.008986	 0.024125	 0.00547	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4304	 76708	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4304	 76708	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4305	 76709	 0.045771	 0.029632	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4306	 4320	 0.002242	 0.006432	 0.00158	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4306	 76709	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4306	 76709	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4307	 4309	 0.020194	 0.05191	 0.0008	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4307	 4317	 0.026179	 0.060777	 0.0009	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4308	 4310	 0.071293	 0.056421	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4309	 4310	 0.02527	 0.034447	 0.00076	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4309	 4326	 0.018248	 0.046408	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4311	 4330	 0.092431	 0.06682	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4313	 76710	 0.042538	 0.033664	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4314	 76710	 0.049358	 0.039061	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4315	 6717	 0.005438	 0.022453	 0.00531	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4315	 76710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4315	 76710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4316	 4335	 0.007314	 0.0244	 0.00619	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4316	 76711	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4316	 76711	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4317	 4319	 0.059414	 0.043713	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4317	 4321	 0.033069	 0.070866	 0.00124	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 4319	 0.043637	 0.035917	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4320	 4350	 0.001461	 0.004875	 0.00124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4320	 76712	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4320	 76712	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4321	 4322	 0.01096	 0.025441	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 4358	 0.012302	 0.022532	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76712	 4322	 0.007169	 0.031945	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4323	 4325	 0.014521	 0.037329	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4323	 4355	 0.01196	 0.021906	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4324	 4355	 0.023825	 0.02383	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76468	 4324	 0.043506	 0.10303	 0.00188	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4324	 76719	 0.011383	 0.037972	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 8200	 0.008461	 0.01964	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4326	 4338	 0.060355	 0.047309	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4326	 76720	 0.010938	 0.037364	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4327	 76720	 0.025633	 0.020286	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4328	 4329	 0.032641	 0.031937	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4328	 77519	 0.032704	 0.046426	 0.00076	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 4331	 0.044132	 0.034593	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4331	 77519	 0.048447	 0.094949	 0.00142	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4332	 76713	 0.030107	 0.023826	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4333	 76713	 0.051632	 0.040861	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 8178	 0.007211	 0.019632	 0.00433	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 8181	 0.006108	 0.016143	 0.00378	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 76713	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4334	 76713	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4335	 4344	 0.008283	 0.029993	 0.00644	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4335	 76714	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4335	 76714	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4336	 4345	 0.15267	 0.12083	 0.00152	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4337	 76715	 0.041029	 0.03247	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4339	 76720	 0.034451	 0.027264	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4340	 4357	 0.002189	 0.009037	 0.00214	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4340	 76715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4340	 76715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76468	 4341	 0.008268	 0.018995	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76519	 4341	 0.009663	 0.022882	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76468	 4342	 0.054906	 0.043452	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4344	 76716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4344	 76716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76716	 4345	 0.02786	 0.021108	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76467	 4346	 0.006935	 0.018882	 0.00416	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76518	 4346	 0.006704	 0.017999	 0.00408	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4346	 76717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4346	 76717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76717	 4347	 0.00554	 0.018479	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4347	 77172	 0.009684	 0.032304	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76707	 4348	 0.022361	 0.017696	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76717	 4348	 0.023074	 0.01826	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4349	 76718	 0.008338	 0.00917	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4350	 4356	 0.000772	 0.003092	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4350	 76718	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4350	 76718	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4351	 76719	 0.007385	 0.011313	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4352	 4353	 0.012321	 0.009335	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4352	 76719	 0.008438	 0.012296	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4354	 76719	 0.013578	 0.008791	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76518	 4356	 0.005862	 0.037132	 0.01008	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4356	 76719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4356	 76719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76467	 4357	 0.002683	 0.012308	 0.00315	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4357	 76720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4357	 76720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76706	 4360	 0.022337	 0.014461	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4361	 4364	 0.011644	 0.02282	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4361	 76752	 0.017793	 0.035228	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4362	 4366	 0.015302	 0.011594	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4362	 76752	 0.015551	 0.023823	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4363	 4581	 0.002154	 0.00739	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4363	 76721	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4363	 76721	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4364	 4365	 0.002802	 0.009347	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4364	 4580	 0.003522	 0.022118	 0.00048	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4365	 4368	 0.007036	 0.015785	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4365	 4519	 0.01944	 0.015384	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4366	 4367	 0.010175	 0.007976	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4366	 4368	 0.011768	 0.011886	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4368	 4509	 0.005886	 0.007735	 0.00011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4368	 76741	 0.012247	 0.024248	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4369	 4374	 0.011284	 0.007305	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4370	 4371	 0.002086	 0.009295	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4370	 4377	 0.0039	 0.010025	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4370	 4429	 0.004884	 0.018999	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4370	 4582	 0.002338	 0.009894	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4370	 4583	 0.002202	 0.010743	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4371	 4373	 0.002566	 0.011306	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4372	 4373	 0.004182	 0.008962	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4372	 76722	 0.00507	 0.010656	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4373	 76752	 0.00108	 0.009933	 0.0002	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4374	 4585	 0.005689	 0.011263	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4375	 4376	 0.00302	 0.00715	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4375	 4483	 0.020721	 0.016398	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4375	 4585	 0.01163	 0.010712	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4375	 76739	 0.005956	 0.015147	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4376	 76724	 0.004747	 0.012204	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4377	 4382	 0.004072	 0.007571	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4378	 4379	 0.000841	 0.002884	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4378	 76722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4378	 76722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4379	 4381	 0.001146	 0.003432	 0.00077	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4379	 76723	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4379	 76723	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76723	 4380	 0.010504	 0.008233	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4381	 4496	 0.002082	 0.00754	 0.00162	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4381	 76724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4381	 76724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4382	 4584	 0.001837	 0.010442	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 4586	 0.002252	 0.010761	 0.00024	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 76753	 0.019746	 0.036166	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4383	 4384	 0.003569	 0.010236	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4383	 4385	 0.00439	 0.012457	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4383	 4406	 0.003154	 0.007323	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4384	 4586	 0.004976	 0.009852	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4385	 76753	 0.002058	 0.00884	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4386	 76753	 0.01041	 0.020402	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4387	 4388	 0.003278	 0.007435	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4387	 76753	 0.0053	 0.010847	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4388	 4389	 0.001843	 0.006081	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4389	 76733	 0.002909	 0.01018	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4390	 76753	 0.013158	 0.009321	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4391	 76753	 0.00608	 0.012037	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4392	 4396	 0.008482	 0.006712	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4393	 4396	 0.00595	 0.010694	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4393	 76753	 0.005615	 0.01428	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4394	 4395	 0.012524	 0.008108	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 4396	 0.007343	 0.007725	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 4400	 0.006719	 0.017272	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 4491	 0.004402	 0.012491	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4397	 4398	 0.016066	 0.012593	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4397	 4399	 0.020625	 0.02106	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4397	 4400	 0.005023	 0.011895	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4397	 4401	 0.003755	 0.009652	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4397	 76725	 0.03533	 0.04816	 0.00107	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4398	 4444	 0.003782	 0.010846	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4399	 4477	 0.008222	 0.01506	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4401	 4402	 0.003638	 0.007445	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4402	 4404	 0.002889	 0.005912	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4403	 4404	 0.007147	 0.01415	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4403	 4408	 0.005517	 0.01403	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4403	 4410	 0.004308	 0.008815	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4404	 4451	 0.008565	 0.006778	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4405	 4406	 0.008514	 0.013043	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4405	 4407	 0.003169	 0.009539	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4405	 76753	 0.004508	 0.017342	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4407	 4408	 0.003573	 0.011791	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4408	 4416	 0.005633	 0.012778	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4409	 4410	 0.020003	 0.01583	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4409	 4414	 0.014828	 0.011735	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4409	 4416	 0.002735	 0.007031	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4410	 4411	 0.015131	 0.011132	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4411	 4413	 0.009475	 0.007178	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4412	 4413	 0.004958	 0.009817	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4412	 4454	 0.009175	 0.015456	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 4425	 0.011873	 0.008995	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 4427	 0.006611	 0.01641	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 4589	 0.006896	 0.010048	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4416	 4418	 0.012327	 0.013426	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4417	 4418	 0.004708	 0.009322	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4417	 4419	 0.002736	 0.006959	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4417	 4589	 0.009485	 0.008107	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4419	 4420	 0.001927	 0.004473	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4420	 4421	 0.003623	 0.009313	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4421	 4586	 0.001837	 0.007288	 0.00021	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4421	 4587	 0.002367	 0.006716	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4422	 4423	 0.010106	 0.007998	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4422	 4424	 0.005792	 0.011468	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4423	 4587	 0.011583	 0.014741	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4424	 4428	 0.004032	 0.010365	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4426	 4427	 0.002895	 0.007363	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4426	 4428	 0.003541	 0.009004	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 4429	 0.002621	 0.007251	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4429	 4430	 0.008005	 0.006335	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4431	 76727	 0.02478	 0.0637	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4432	 4433	 0.013847	 0.034369	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4433	 77108	 0.016023	 0.041189	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4434	 4445	 0.001358	 0.004575	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4434	 4590	 0.0009	 0.003089	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4435	 76754	 0.015664	 0.015134	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 76754	 0.015544	 0.030463	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4437	 4441	 0.000889	 0.002995	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4437	 6314	 0.001626	 0.005057	 0.00106	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4438	 4441	 0.001387	 0.003565	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4438	 4442	 0.002373	 0.00637	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4438	 76725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4438	 76725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76725	 4439	 0.017821	 0.014104	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 4440	 0.020556	 0.01486	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4442	 4588	 0.003547	 0.015013	 0.00338	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76530	 4442	 0.008229	 0.022949	 0.00482	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4442	 76726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4442	 76726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4443	 4446	 0.005489	 0.01411	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76726	 4443	 0.005438	 0.013831	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76726	 4444	 0.003135	 0.010052	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4445	 4447	 0.000879	 0.003016	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4446	 4454	 0.00871	 0.020626	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4447	 4448	 0.001213	 0.004088	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4448	 4453	 0.000913	 0.003132	 0.00075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 76727	 0.008416	 0.021635	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76530	 4450	 0.006052	 0.024232	 0.0061	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4450	 76727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4450	 76727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4451	 4452	 0.009502	 0.00752	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4452	 76728	 0.010754	 0.010862	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4453	 76728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4453	 76728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76727	 4454	 0.008817	 0.027075	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76728	 4454	 0.001925	 0.007406	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4455	 4478	 0.008238	 0.021176	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4455	 4479	 0.008883	 0.017588	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4456	 76729	 0.037865	 0.029966	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4457	 4458	 0.006115	 0.029503	 0.00052	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4457	 4479	 0.005969	 0.01833	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4458	 4459	 0.020434	 0.018436	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4458	 76730	 0.010802	 0.019415	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4458	 76731	 0.033109	 0.085111	 0.00132	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4458	 76745	 0.006725	 0.03583	 0.00063	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 4461	 0.002153	 0.00862	 0.00217	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 6304	 0.003442	 0.014008	 0.00341	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 76729	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4460	 76729	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4461	 4468	 0.002812	 0.007431	 0.00174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4461	 4553	 0.00165	 0.009462	 0.00314	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4461	 76730	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4461	 76730	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4462	 4469	 0.00544	 0.011133	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4462	 4479	 0.012502	 0.029605	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4463	 76731	 0.034449	 0.022303	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76530	 4464	 0.002677	 0.009693	 0.00208	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4464	 76731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4464	 76731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4465	 4466	 0.024115	 0.019085	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 4467	 0.025286	 0.020011	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 4471	 0.010458	 0.026884	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 76732	 0.020824	 0.031582	 0.00045	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4468	 76732	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4468	 76732	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76732	 4469	 0.01012	 0.018536	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4470	 4471	 0.014782	 0.010686	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76731	 4471	 0.010312	 0.024419	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4472	 4475	 0.014564	 0.023363	 0.00043	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76731	 4472	 0.060496	 0.059192	 0.00084	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4473	 4475	 0.009883	 0.019369	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76726	 4473	 0.005815	 0.014949	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4474	 4475	 0.016169	 0.012674	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4475	 4476	 0.029708	 0.023287	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4475	 4477	 0.008329	 0.016491	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4477	 4490	 0.004073	 0.010795	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4478	 4489	 0.006156	 0.012599	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4479	 76736	 0.01642	 0.072348	 0.00126	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4480	 4481	 0.006505	 0.016722	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4480	 4485	 0.006073	 0.015611	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4480	 4550	 0.012666	 0.032558	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4480	 76736	 0.003012	 0.020675	 0.00038	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4481	 4549	 0.008259	 0.014752	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4482	 76736	 0.037715	 0.024417	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4483	 4503	 0.009501	 0.013241	 0.00023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4484	 4485	 0.011145	 0.015532	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4486	 4495	 0.003725	 0.016411	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4486	 76736	 0.004396	 0.016842	 0.00048	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4487	 4488	 0.001812	 0.011135	 0.00025	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4487	 4489	 0.004152	 0.011908	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4487	 4490	 0.003164	 0.012309	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 4495	 0.002001	 0.007002	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 76734	 0.005464	 0.019117	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4491	 76733	 0.00428	 0.016465	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4492	 76733	 0.01195	 0.009457	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4493	 76733	 0.012583	 0.009958	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4494	 4496	 0.001096	 0.003761	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4494	 76733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4494	 76733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4496	 76734	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4496	 76734	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4496	 76735	 0.001506	 0.00731	 0.00167	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4497	 8495	 0.0012	 0.017425	 0.15769	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4497	 76735	 9.2e-05	 0.007399	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4497	 95339	 0.001642	 0.029926	 0.65667	 1959.0	 2056.9	 2154.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4498	 4502	 0.009558	 0.013928	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76736	 4498	 0.012479	 0.024707	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4499	 4500	 0.023057	 0.018247	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4500	 76740	 0.00721	 0.011508	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4501	 4508	 0.001997	 0.00785	 0.00205	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76735	 4501	 0.00194	 0.007896	 0.00192	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4501	 76737	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4501	 76737	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76737	 4502	 0.014325	 0.015755	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76734	 4503	 0.010894	 0.021569	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4503	 76738	 0.00331	 0.011043	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4504	 4506	 0.002117	 0.00634	 0.00143	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76735	 4504	 0.001579	 0.006321	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4504	 76738	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4504	 76738	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4505	 4585	 0.015146	 0.023633	 0.00039	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76738	 4505	 0.00601	 0.01395	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4505	 76741	 0.028323	 0.020838	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 76739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4506	 76739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4507	 4535	 0.003555	 0.02206	 0.00534	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4507	 4541	 0.004049	 0.016475	 0.00401	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76735	 4507	 0.002605	 0.012843	 0.00347	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4507	 76740	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4507	 76740	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4508	 4581	 0.002707	 0.010638	 0.00278	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4508	 76741	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4508	 76741	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4509	 4510	 0.006928	 0.010614	 0.00015	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76741	 4510	 0.007493	 0.014686	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4511	 4512	 0.016231	 0.012845	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4512	 4514	 0.029465	 0.022601	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4512	 4515	 0.029818	 0.019304	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76741	 4512	 0.010115	 0.02901	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76740	 4513	 0.028247	 0.022354	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4514	 4520	 0.023191	 0.018353	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 4591	 0.03649	 0.026846	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4517	 4580	 0.008252	 0.014889	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4517	 4592	 0.021772	 0.015422	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4518	 4521	 0.001528	 0.010995	 0.00036	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4518	 4580	 0.001202	 0.010208	 0.00024	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4521	 76742	 0.001624	 0.015918	 0.00031	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4522	 4523	 0.017831	 0.035305	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4522	 76743	 0.012166	 0.031274	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4524	 4526	 0.000727	 0.009422	 0.00373	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4524	 4535	 0.001788	 0.014615	 0.00397	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4524	 76742	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4524	 76742	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76742	 4525	 0.032518	 0.025489	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4526	 4527	 0.000811	 0.010519	 0.00416	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4527	 4570	 0.000798	 0.0115	 0.00418	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4528	 4531	 0.006679	 0.025984	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4528	 4531	 0.006679	 0.025984	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4528	 4569	 0.019636	 0.070147	 0.00139	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4528	 4569	 0.019636	 0.070147	 0.00139	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4529	 4530	 0.01691	 0.013383	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4529	 4531	 0.010906	 0.031278	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4529	 4532	 0.012611	 0.032418	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76742	 4531	 0.014537	 0.064049	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 4533	 0.059626	 0.046738	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 4537	 0.057545	 0.11278	 0.00169	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4534	 76743	 0.047487	 0.030743	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 76743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4535	 76743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76743	 4536	 0.022449	 0.042428	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4537	 4539	 0.026108	 0.051691	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76502	 4537	 0.06481	 0.17134	 0.00311	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4538	 4539	 0.020047	 0.012978	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4540	 4541	 0.003094	 0.013094	 0.00295	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4540	 4561	 0.004677	 0.016935	 0.00363	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 4560	 0.003166	 0.014764	 0.00366	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76735	 4542	 0.004069	 0.027299	 0.00659	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 76744	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4542	 76744	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4543	 4548	 0.010413	 0.046402	 0.00079	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76744	 4543	 0.006742	 0.031243	 0.0006	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4544	 4550	 0.031161	 0.031473	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4545	 4551	 0.0086	 0.034414	 0.00073	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76736	 4545	 0.019154	 0.073386	 0.00207	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76744	 4545	 0.013124	 0.04331	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4546	 4549	 0.015792	 0.012498	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4547	 4550	 0.027148	 0.020824	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4548	 4550	 0.00457	 0.015991	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4551	 4552	 0.006347	 0.024691	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4552	 76746	 0.01495	 0.049873	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4553	 4555	 0.003622	 0.016142	 0.00439	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4553	 76745	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4553	 76745	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4554	 6317	 0.030308	 0.077912	 0.00121	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4554	 76747	 0.037229	 0.08642	 0.00165	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4555	 4557	 0.003397	 0.019896	 0.00542	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4555	 76746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4555	 76746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4556	 4557	 0.00073	 0.005865	 0.00165	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4556	 4642	 0.003019	 0.022737	 0.00631	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4557	 76747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4557	 76747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4558	 4559	 0.001269	 0.006609	 0.00173	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4558	 4561	 0.003397	 0.021106	 0.00596	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4558	 4653	 0.002499	 0.032526	 0.0094	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4559	 4560	 0.00176	 0.008073	 0.00207	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4559	 76748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4559	 76748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4562	 4563	 0.011721	 0.079597	 0.00197	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76502	 4562	 0.01166	 0.066335	 0.00204	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4563	 4564	 0.0812	 0.10672	 0.00146	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4563	 76749	 0.011228	 0.093406	 0.00177	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4564	 4567	 0.053277	 0.066134	 0.00144	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4565	 4579	 0.012596	 0.0798	 0.02167	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4565	 8503	 0.008497	 0.034579	 0.00843	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4565	 76749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4565	 76749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4566	 4567	 0.039344	 0.051709	 0.00071	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4566	 4569	 0.011519	 0.05133	 0.00087	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4566	 4576	 0.021428	 0.10339	 0.00183	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4567	 4577	 0.18486	 0.14631	 0.00184	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4568	 4569	 0.004925	 0.048262	 0.00094	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4568	 76750	 0.020041	 0.077104	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4568	 76750	 0.020041	 0.077104	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4569	 4577	 0.073336	 0.15072	 0.00287	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4570	 4571	 0.000404	 0.006288	 0.00195	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4571	 4573	 0.000716	 0.011737	 0.00369	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4572	 76750	 0.035223	 0.027875	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4573	 76750	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4573	 76750	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76750	 4574	 0.092691	 0.073356	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4575	 4595	 0.072948	 0.047227	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76750	 4575	 0.07237	 0.055512	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4576	 4594	 0.016045	 0.085489	 0.0015	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4577	 4578	 0.032587	 0.047484	 0.00107	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76749	 4577	 0.018272	 0.10948	 0.00263	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4579	 76751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4579	 76751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4581	 4588	 0.002051	 0.014751	 0.00391	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4581	 76752	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4581	 76752	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76752	 4582	 0.003516	 0.021619	 0.00039	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76721	 4583	 0.009737	 0.019926	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76722	 4584	 0.001524	 0.009259	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76739	 4585	 0.004716	 0.013062	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76752	 4585	 0.008898	 0.019694	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4587	 4589	 0.008477	 0.018099	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76735	 4588	 0.00487	 0.019139	 0.00501	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4588	 76753	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4588	 76753	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76530	 4590	 0.002271	 0.009094	 0.00229	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 76754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4590	 76754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76740	 4591	 0.013796	 0.035463	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76751	 4593	 0.017219	 0.013497	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76751	 4594	 0.009663	 0.05941	 0.00107	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4596	 4639	 0.014322	 0.029308	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4596	 6325	 0.040214	 0.09523	 0.00174	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4597	 4598	 0.25143	 0.19713	 0.00253	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4597	 4603	 0.15824	 0.12404	 0.00159	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 4600	 0.097597	 0.10735	 0.00143	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76690	 4599	 0.2098	 0.24601	 0.00428	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4600	 76755	 0.1582	 0.12136	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4601	 76755	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4601	 76755	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4602	 4604	 0.20319	 0.20527	 0.00272	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76691	 4602	 0.26972	 0.29942	 0.00584	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4604	 4605	 0.030815	 0.17316	 0.00321	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76755	 4604	 0.047241	 0.23631	 0.00421	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4605	 4606	 0.029009	 0.11161	 0.00191	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4606	 76756	 0.028863	 0.11229	 0.00187	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 76756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4607	 76756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4608	 4609	 0.16338	 0.24785	 0.00355	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4608	 8231	 0.26254	 0.19321	 0.00283	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76755	 4609	 0.15286	 0.26891	 0.00505	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 4612	 0.017973	 0.12195	 0.00228	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76527	 4610	 0.017604	 0.12084	 0.0022	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4611	 4615	 0.076373	 0.15122	 0.00222	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76504	 4611	 0.042066	 0.11938	 0.00188	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4612	 4616	 0.038781	 0.18713	 0.0033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4613	 4616	 0.16421	 0.11031	 0.00195	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4614	 4616	 0.028236	 0.06335	 0.00101	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4614	 4617	 0.17857	 0.14133	 0.00178	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4615	 4616	 0.056367	 0.061997	 0.00083	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76504	 4616	 0.091696	 0.26305	 0.00405	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4618	 7636	 0.26466	 0.20949	 0.00264	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4619	 4621	 0.34627	 0.27415	 0.00345	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76690	 4619	 0.37527	 0.27624	 0.00404	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4620	 4621	 0.057995	 0.11483	 0.00169	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4620	 4622	 0.047618	 0.21221	 0.0036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4620	 4623	 0.27853	 0.20141	 0.00305	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76755	 4620	 0.076633	 0.19702	 0.00305	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76560	 4622	 0.055421	 0.2705	 0.00467	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4624	 4625	 0.015433	 0.068768	 0.00117	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4624	 7648	 0.059089	 0.12093	 0.00298	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4624	 7649	 0.063262	 0.1609	 0.00254	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4625	 4627	 0.030107	 0.12305	 0.00249	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 4633	 0.010516	 0.059085	 0.00109	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 76759	 0.016997	 0.065121	 0.00184	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 76958	 0.056083	 0.11788	 0.00215	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4627	 4628	 0.015344	 0.13058	 0.00341	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4627	 76758	 0.03015	 0.13285	 0.00231	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4628	 4684	 0.017145	 0.11062	 0.00352	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4628	 5714	 0.02858	 0.12736	 0.00216	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4629	 6413	 0.016414	 0.15778	 0.04598	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4629	 76757	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4629	 76757	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4630	 4631	 0.004567	 0.017766	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4630	 4631	 0.004567	 0.017766	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4630	 76758	 0.003554	 0.013826	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4630	 76758	 0.003554	 0.013826	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 4635	 0.004218	 0.020246	 0.0006	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76757	 4631	 0.008935	 0.031919	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76757	 4631	 0.008935	 0.031919	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4632	 76758	 0.022468	 0.016242	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4633	 76758	 0.001301	 0.00696	 0.00021	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4634	 76758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4634	 76758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4635	 4636	 0.003985	 0.014733	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4635	 4636	 0.003985	 0.014733	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4635	 5705	 0.017469	 0.13616	 0.00254	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4636	 5712	 0.012629	 0.051614	 0.00104	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76757	 4636	 0.010777	 0.041924	 0.0007	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76757	 4636	 0.010777	 0.041924	 0.0007	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4637	 4638	 0.008223	 0.021732	 0.00509	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4637	 5706	 0.005338	 0.014886	 0.00312	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4638	 76759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4638	 76759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4639	 76760	 0.020488	 0.052668	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4640	 4648	 0.006234	 0.033044	 0.01103	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4640	 5693	 0.004986	 0.029202	 0.00795	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 76761	 0.038762	 0.091791	 0.00168	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 77189	 0.19571	 0.16112	 0.00326	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4642	 4643	 0.00853	 0.034153	 0.0086	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4642	 6665	 0.010635	 0.065398	 0.01887	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4642	 76760	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4642	 76760	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4643	 4644	 0.000517	 0.00364	 0.00207	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4643	 4653	 0.002352	 0.029592	 0.00917	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4643	 76761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4643	 76761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4644	 4645	 0.000428	 0.002568	 0.00078	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4644	 4646	 0.000969	 0.003878	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4645	 4647	 0.000317	 0.002009	 0.00055	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4646	 4649	 0.001325	 0.005305	 0.00134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4647	 4648	 0.000513	 0.002916	 0.00084	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4648	 76762	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4648	 76762	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4649	 76763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4649	 76763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76521	 4650	 0.022367	 0.10915	 0.00188	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4650	 76764	 0.007176	 0.035018	 0.0006	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4651	 5480	 0.009836	 0.030746	 0.00891	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4651	 76764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4651	 76764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4652	 8494	 0.010824	 0.079951	 0.00167	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76764	 4652	 0.013869	 0.10137	 0.00187	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4653	 76765	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4653	 76765	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4654	 4662	 0.005243	 0.021336	 0.0052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76564	 4655	 0.16783	 0.1189	 0.00188	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4656	 7742	 0.050446	 0.18023	 0.00358	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76580	 4656	 0.091517	 0.25355	 0.00419	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4657	 4659	 0.011483	 0.03035	 0.0071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76479	 4657	 0.018921	 0.051518	 0.01135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4658	 76766	 0.028946	 0.15424	 0.00271	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4658	 77511	 0.026748	 0.13531	 0.00235	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4659	 8212	 0.018567	 0.050554	 0.01114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4659	 76766	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4659	 76766	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76564	 4660	 0.013989	 0.026011	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4660	 76767	 0.028328	 0.094503	 0.0015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76564	 4661	 0.073844	 0.05844	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4662	 4665	 0.007096	 0.016471	 0.00502	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76478	 4662	 0.007422	 0.021883	 0.00509	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4662	 76767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4662	 76767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4663	 4664	 0.005703	 0.022187	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76478	 4665	 0.000981	 0.003816	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4666	 76768	 0.01996	 0.039519	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4667	 8167	 0.010247	 0.028576	 0.006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4668	 8167	 0.008989	 0.027954	 0.00583	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76478	 4668	 0.002857	 0.023189	 0.00738	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4668	 76768	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4668	 76768	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4669	 4670	 0.41239	 0.26718	 0.00509	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4669	 7637	 0.55683	 0.42234	 0.00582	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4671	 8229	 0.46285	 0.29994	 0.00571	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4672	 4691	 0.5627	 0.4268	 0.00588	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4673	 6401	 0.010418	 0.039602	 0.01109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4673	 6701	 0.013374	 0.05661	 0.01274	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4673	 76769	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4673	 76769	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4674	 4676	 0.005917	 0.031527	 0.00055	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 76770	 0.009272	 0.044504	 0.00133	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4675	 6413	 0.005979	 0.023261	 0.00621	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4675	 76770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4675	 76770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4676	 4677	 0.003057	 0.014918	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4677	 4678	 0.034944	 0.027654	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4677	 4686	 0.012007	 0.04671	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 4685	 0.064035	 0.046291	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4680	 4681	 0.000575	 0.005349	 0.00166	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4680	 4687	 0.002339	 0.022851	 0.00641	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 5715	 0.006657	 0.041367	 0.01168	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 76771	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4681	 76771	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76771	 4682	 0.11784	 0.086701	 0.00127	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 4684	 0.027767	 0.092631	 0.00147	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76771	 4683	 0.021844	 0.08404	 0.00143	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4684	 4689	 0.027259	 0.11654	 0.00263	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4685	 4686	 0.049289	 0.039006	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76770	 4686	 0.011609	 0.096576	 0.00183	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4686	 76772	 0.011035	 0.041394	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4686	 76772	 0.011035	 0.041394	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4687	 4688	 0.002974	 0.025329	 0.00632	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4687	 76772	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4687	 76772	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4688	 6360	 0.002383	 0.020296	 0.00506	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4691	 5478	 0.24149	 0.26568	 0.00355	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4692	 4697	 0.034297	 0.19498	 0.00353	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4692	 4698	 0.028259	 0.14296	 0.00249	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4693	 4696	 0.090127	 0.17665	 0.00265	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4694	 4695	 0.19778	 0.14299	 0.00217	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4695	 4708	 0.046325	 0.091722	 0.00135	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4696	 4699	 0.045175	 0.11613	 0.0018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4697	 4699	 0.01714	 0.060013	 0.00166	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4698	 4716	 0.040466	 0.15743	 0.00263	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4698	 7639	 0.021841	 0.1814	 0.00444	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4699	 4700	 0.037582	 0.044054	 0.00077	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4699	 76773	 0.026408	 0.099069	 0.00178	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4699	 76922	 0.036298	 0.22797	 0.00498	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4700	 4703	 0.07433	 0.075077	 0.00099	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4701	 4716	 0.031925	 0.11405	 0.00226	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4701	 5474	 0.040359	 0.10375	 0.00161	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 4703	 0.029727	 0.067986	 0.00166	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4703	 4704	 0.030445	 0.087321	 0.00134	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4704	 4713	 0.032529	 0.021059	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4704	 76773	 0.003923	 0.015261	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4705	 4714	 0.008147	 0.028507	 0.00945	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4705	 76773	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4705	 76773	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4706	 4707	 0.002915	 0.016054	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4707	 4712	 0.004484	 0.022684	 0.00039	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4708	 4710	 0.018331	 0.12115	 0.00239	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4709	 4710	 0.19128	 0.12385	 0.00236	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4710	 4715	 0.037345	 0.13068	 0.00271	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4710	 4715	 0.037345	 0.13068	 0.00271	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4710	 76774	 0.022856	 0.11153	 0.00193	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 4712	 0.012221	 0.020382	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76773	 4712	 0.006144	 0.015794	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 5475	 0.012498	 0.049126	 0.01285	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 76774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4714	 76774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4715	 6671	 0.033525	 0.13043	 0.00218	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4715	 6671	 0.033525	 0.13043	 0.00218	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 4721	 0.000292	 0.000735	 0.00019	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 4729	 0.000698	 0.002327	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 76775	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4717	 76775	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4718	 4776	 0.00017	 0.001303	 0.00035	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4718	 76776	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4718	 76776	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4718	 76779	 0.000107	 0.000949	 0.00025	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4719	 4720	 0.000922	 0.001689	 3e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4719	 4722	 0.003003	 0.002376	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4720	 76777	 0.00078	 0.001984	 3e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 4723	 0.00039	 0.001061	 0.00023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 76777	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4721	 76777	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4723	 4745	 0.000454	 0.001412	 0.00029	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4723	 76778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4723	 76778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4724	 4726	 0.004589	 0.00459	 6e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4724	 4739	 0.001525	 0.00459	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76778	 4724	 0.003167	 0.003861	 6e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4725	 4726	 0.005776	 0.005176	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76775	 4725	 0.004448	 0.00352	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4726	 4731	 0.003546	 0.006398	 9e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4727	 9563	 0.000135	 0.002065	 0.04765	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4727	 76779	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4728	 4775	 5.4e-05	 0.000661	 0.00031	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4729	 76781	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4729	 76781	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4730	 4766	 0.000101	 0.0016	 0.00101	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4730	 76782	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4730	 76782	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76781	 4731	 0.00139	 0.003536	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4732	 76814	 0.005119	 0.003314	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4733	 4768	 0.005817	 0.003766	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4734	 4741	 0.000503	 0.001957	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4734	 76783	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4734	 76783	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4735	 4737	 0.002126	 0.004167	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76783	 4735	 0.003876	 0.003915	 5e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4736	 76788	 0.008808	 0.006367	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4737	 4852	 0.004768	 0.004471	 7e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4737	 76784	 0.001574	 0.003908	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4738	 4740	 0.005077	 0.004018	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4738	 4744	 0.007844	 0.006148	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4738	 76788	 0.004082	 0.003658	 7e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4739	 4742	 0.00125	 0.003213	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 4806	 0.000256	 0.000973	 0.00027	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 76784	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4741	 76784	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76784	 4742	 0.001611	 0.003439	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76778	 4743	 0.004388	 0.004827	 6e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4745	 76785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4745	 76785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4746	 4749	 0.000732	 0.003264	 6e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4746	 4762	 0.00136	 0.004172	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76785	 4747	 0.00778	 0.005624	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76785	 4748	 0.003866	 0.002929	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4749	 4751	 0.000668	 0.002339	 6e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4750	 4761	 0.000492	 0.0024	 4e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4750	 4765	 0.001167	 0.004557	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4751	 4752	 0.003266	 0.002585	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4751	 76787	 0.000923	 0.004616	 8e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4753	 4829	 0.000602	 0.00578	 0.00168	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76565	 4753	 0.000171	 0.002857	 0.00087	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4753	 76786	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4753	 76786	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4754	 4755	 0.003024	 0.002393	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4754	 76787	 0.001916	 0.003141	 6e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4756	 4836	 0.005413	 0.003982	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4757	 4834	 6.8e-05	 0.0008	 0.00041	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4757	 7442	 0.000355	 0.005048	 0.00266	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4757	 76787	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4757	 76787	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4758	 4763	 0.000937	 0.005328	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76786	 4758	 0.000717	 0.005588	 0.0001	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4759	 4760	 0.000326	 0.002346	 8e-05	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76787	 4759	 0.000333	 0.002768	 7e-05	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4760	 4762	 0.000463	 0.003842	 9e-05	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4761	 4763	 0.000601	 0.002661	 8e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4762	 4764	 0.000949	 0.003694	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4762	 4764	 0.000949	 0.003694	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4763	 4774	 0.003591	 0.004674	 7e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4764	 76788	 0.000756	 0.002941	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4764	 76788	 0.000756	 0.002941	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76785	 4765	 0.000903	 0.004097	 9e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4766	 7453	 0.000513	 0.007999	 0.00523	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4766	 76788	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4766	 76788	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4767	 4772	 0.006378	 0.005047	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76778	 4767	 0.002886	 0.007418	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76782	 4768	 0.001442	 0.005611	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76782	 4768	 0.001442	 0.005611	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76788	 4768	 0.001147	 0.004461	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76788	 4768	 0.001147	 0.004461	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4769	 4804	 0.005861	 0.004638	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76782	 4770	 0.005292	 0.003426	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4771	 4773	 0.000496	 0.002664	 6e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76782	 4771	 0.000668	 0.004106	 7e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4773	 76789	 0.000575	 0.002805	 6e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 4799	 0.00197	 0.004031	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4775	 4776	 0.000123	 0.000794	 0.00021	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4775	 4786	 6.8e-05	 0.000668	 0.00051	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4775	 76789	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4775	 76789	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4776	 4781	 0.000209	 0.001793	 0.00051	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4777	 4780	 0.000901	 0.004395	 8e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76776	 4777	 0.000654	 0.003719	 7e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76780	 4778	 0.008495	 0.006516	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76786	 4779	 0.001249	 0.002447	 4e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4780	 76790	 0.000608	 0.003078	 5e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4781	 4782	 0.000118	 0.001073	 0.00035	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4781	 76790	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4781	 76790	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4782	 4793	 0.000146	 0.00124	 0.00031	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 76791	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4782	 76791	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4783	 4784	 0.003109	 0.00314	 4e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76791	 4783	 0.001505	 0.002979	 4e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4784	 76795	 0.002696	 0.003543	 5e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4785	 76792	 0.00461	 0.003614	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4786	 4787	 4.8e-05	 0.00054	 0.0003	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4786	 76792	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4786	 76792	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4787	 4791	 7.1e-05	 0.000786	 0.00047	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4787	 76793	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4787	 76793	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4788	 4848	 0.015451	 0.012228	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76547	 4788	 0.002862	 0.005666	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 4802	 0.001093	 0.004253	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 4802	 0.001093	 0.004253	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76793	 4789	 0.000316	 0.00294	 6e-05	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4790	 76794	 0.004634	 0.003667	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4791	 4792	 4.8e-05	 0.000499	 0.00033	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4791	 76794	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4791	 76794	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4792	 4795	 6.4e-05	 0.000666	 0.00044	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4792	 76795	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4792	 76795	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4793	 4894	 0.00015	 0.001201	 0.00034	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4794	 76796	 0.004452	 0.004546	 7e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4795	 4903	 0.00017	 0.001929	 0.00108	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4795	 5086	 0.00179	 0.008157	 0.00259	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76779	 4795	 0.00032	 0.00347	 0.00213	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4795	 76796	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4795	 76796	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76794	 4796	 0.005668	 0.004097	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4797	 4801	 0.000586	 0.003229	 7e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76547	 4797	 0.000995	 0.006759	 0.00017	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4798	 4800	 0.003769	 0.00267	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 4801	 0.000731	 0.003239	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76783	 4799	 0.005295	 0.020369	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4800	 4802	 0.000928	 0.007234	 0.00014	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4800	 4805	 0.000332	 0.002302	 5e-05	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 4803	 0.000364	 0.003572	 7e-05	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76782	 4802	 0.000957	 0.006568	 0.00012	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 4808	 0.000789	 0.002421	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 4808	 0.000789	 0.002421	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76784	 4804	 0.000779	 0.003757	 7e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4804	 76798	 0.002264	 0.006656	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4805	 4810	 0.000511	 0.00351	 6e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4806	 4809	 0.000289	 0.001137	 0.0003	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4806	 76797	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4806	 76797	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76797	 4807	 0.003433	 0.002432	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4808	 4812	 0.000774	 0.003451	 6e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76788	 4808	 0.00094	 0.002883	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76788	 4808	 0.00094	 0.002883	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4809	 4811	 0.000201	 0.000704	 0.00023	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4810	 4878	 0.000538	 0.003306	 6e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4811	 4813	 0.00015	 0.000782	 0.00021	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4811	 76798	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4811	 76798	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4812	 4814	 0.000702	 0.003426	 6e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4813	 4815	 0.000144	 0.00079	 0.00021	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4814	 4816	 0.005513	 0.003569	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4814	 4820	 0.000815	 0.004632	 8e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4815	 4829	 7.5e-05	 0.001049	 0.00036	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76565	 4815	 0.000227	 0.003158	 0.00174	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4815	 76799	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4815	 76799	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4817	 4819	 0.000601	 0.0032	 6e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76799	 4817	 0.000695	 0.002546	 6e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4818	 4820	 0.004435	 0.003206	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4818	 4840	 0.005352	 0.004235	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4819	 4821	 0.000572	 0.002536	 8e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4820	 76804	 0.000836	 0.005139	 9e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4821	 4822	 0.004612	 0.003615	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4821	 4823	 0.007082	 0.005605	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76547	 4821	 0.00086	 0.005903	 0.00011	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4824	 4826	 0.003452	 0.002495	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 4829	 0.000156	 0.001694	 0.00053	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 5141	 0.000399	 0.00428	 0.00111	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 76800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4825	 76800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4826	 4844	 0.000727	 0.005666	 0.00011	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 4870	 0.000678	 0.005288	 0.0001	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4827	 4841	 0.003993	 0.004033	 5e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4827	 76801	 0.001266	 0.003255	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4828	 76804	 0.007805	 0.005914	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4829	 4831	 0.000133	 0.000823	 0.0002	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4829	 76801	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4829	 76801	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4830	 4834	 0.000177	 0.001863	 0.00105	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4830	 4846	 0.000124	 0.001334	 0.00071	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4830	 76802	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4830	 76802	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4831	 4832	 0.00014	 0.00082	 0.00022	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4832	 4833	 0.000177	 0.000951	 0.00023	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4832	 76803	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4832	 76803	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4833	 4835	 0.000261	 0.001385	 0.00032	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4834	 76804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4834	 76804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4835	 4871	 0.000446	 0.001694	 0.00047	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4835	 76805	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4835	 76805	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4836	 4838	 0.009542	 0.007229	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76787	 4836	 0.003579	 0.005713	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76805	 4837	 0.004065	 0.003217	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 4850	 0.014929	 0.010983	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76803	 4839	 0.004439	 0.003654	 7e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76802	 4842	 0.011881	 0.00798	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4843	 4845	 0.006601	 0.004676	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4843	 5471	 0.007475	 0.005916	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76800	 4843	 0.001911	 0.004436	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4844	 76806	 0.000267	 0.002219	 4e-05	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4845	 5143	 0.005917	 0.004278	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4846	 4853	 3.9e-05	 0.000623	 0.0002	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4846	 76806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4846	 76806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4847	 4849	 0.003945	 0.002852	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4849	 4950	 0.006475	 0.005124	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4851	 4853	 3.7e-05	 0.000572	 0.00018	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4851	 4946	 4.4e-05	 0.000682	 0.00021	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4851	 76807	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4851	 76807	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4854	 76810	 0.008372	 0.006052	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 4857	 0.005834	 0.004617	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 4870	 0.000828	 0.007707	 0.00015	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 4944	 0.000318	 0.002956	 6e-05	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4856	 4860	 0.005271	 0.003878	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 4867	 0.000425	 0.001731	 0.00042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 4882	 0.000132	 0.000675	 0.00018	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 76808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4858	 76808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4859	 4861	 0.004149	 0.003283	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 4863	 0.001626	 0.005424	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76808	 4860	 0.000755	 0.002938	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4861	 4870	 0.005645	 0.004467	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 4917	 0.001915	 0.004535	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 4930	 0.005512	 0.003569	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 4932	 0.002908	 0.006887	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 5178	 0.002429	 0.006727	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 4866	 0.001376	 0.003258	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 4887	 0.001946	 0.003981	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4865	 4902	 0.000257	 0.001365	 0.00032	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4865	 5186	 0.000971	 0.00516	 0.0012	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4865	 76809	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4865	 76809	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4866	 4868	 0.001345	 0.003816	 6e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 4869	 0.000244	 0.000994	 0.00024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 76810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4867	 76810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4868	 4881	 0.001755	 0.004653	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4869	 4871	 0.000281	 0.001124	 0.00028	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4869	 76811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4869	 76811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4870	 4872	 0.000855	 0.00204	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4870	 4881	 0.005595	 0.00964	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4872	 4874	 0.000725	 0.002419	 4e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4873	 4875	 0.002033	 0.00378	 9e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4873	 4900	 0.001096	 0.003111	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 4876	 0.000725	 0.002419	 4e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4875	 76812	 0.001559	 0.002489	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4876	 4878	 0.000772	 0.002271	 5e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4877	 4879	 0.000263	 0.000787	 0.00018	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4877	 76812	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4877	 76812	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4878	 4881	 0.002471	 0.007087	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4879	 76813	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4879	 76813	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4880	 4881	 0.003319	 0.002602	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4881	 4883	 0.00062	 0.002172	 6e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76782	 4881	 0.002354	 0.019355	 0.00038	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4882	 76814	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4882	 76814	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4883	 4885	 0.000833	 0.003239	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4884	 4888	 0.000321	 0.001263	 0.00033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4884	 4988	 0.000163	 0.000653	 0.00016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4885	 4887	 0.000806	 0.003134	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76812	 4886	 0.001094	 0.004819	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76813	 4886	 0.000454	 0.003082	 6e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4886	 76815	 0.001225	 0.004765	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4886	 76815	 0.001225	 0.004765	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4887	 4889	 0.00033	 0.002029	 5e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4888	 4974	 0.000322	 0.001329	 0.00031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4888	 76815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4888	 76815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4889	 4891	 0.001513	 0.002719	 5e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4889	 4917	 0.00187	 0.010298	 0.00023	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4890	 4984	 0.006118	 0.004796	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76796	 4891	 0.002154	 0.005001	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4892	 76835	 0.006066	 0.004801	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4893	 76816	 0.00491	 0.003885	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4894	 4895	 0.00012	 0.000935	 0.00024	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4894	 76816	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4894	 76816	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4895	 4897	 0.000178	 0.001262	 0.00035	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4896	 4902	 0.000404	 0.00215	 0.0005	 212.0	 212.0	 212.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4896	 4974	 0.000312	 0.001213	 0.00032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4896	 76817	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4896	 76817	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4897	 76818	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4897	 76818	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4898	 4900	 0.000894	 0.002742	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4898	 76819	 0.001048	 0.004078	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4899	 4901	 0.000325	 0.002284	 5e-05	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76818	 4899	 0.000379	 0.002601	 5e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76811	 4900	 0.000769	 0.005276	 0.0001	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4901	 76820	 0.000322	 0.002576	 5e-05	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4902	 4910	 0.000266	 0.001065	 0.00027	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4902	 76819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4902	 76819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4903	 5120	 0.000116	 0.001283	 0.00066	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 76820	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4903	 76820	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4904	 76821	 0.004901	 0.003879	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4905	 4906	 0.000329	 0.002067	 5e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4905	 4915	 0.004807	 0.009838	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76820	 4905	 0.000522	 0.002299	 4e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 4907	 0.000307	 0.002221	 4e-05	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4907	 4909	 0.000398	 0.003104	 6e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 4910	 0.000341	 0.001407	 0.00033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 5470	 0.000356	 0.001449	 0.00035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 76821	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4908	 76821	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4909	 4917	 0.0004	 0.002581	 8e-05	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4910	 76822	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4910	 76822	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4911	 4915	 0.00465	 0.003421	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4912	 4916	 0.000649	 0.002861	 5e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76817	 4912	 0.000914	 0.004236	 9e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4913	 4921	 0.000715	 0.002193	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4913	 4921	 0.000715	 0.002193	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4913	 5115	 0.001905	 0.005845	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4913	 5115	 0.001905	 0.005845	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 4982	 0.000218	 0.000712	 0.00019	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 76823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4914	 76823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4915	 4919	 0.002113	 0.002576	 4e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4916	 4933	 0.001035	 0.005234	 9e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76823	 4916	 0.001228	 0.004097	 6e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76822	 4918	 0.004298	 0.003107	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4919	 4928	 0.004712	 0.003615	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76821	 4920	 0.004297	 0.003368	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4921	 4923	 0.00062	 0.002171	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4921	 4923	 0.00062	 0.002171	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4922	 4924	 0.000535	 0.003012	 7e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4922	 76881	 0.001598	 0.004584	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4922	 76921	 0.001064	 0.003933	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4922	 76921	 0.001064	 0.003933	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4923	 4925	 0.000611	 0.002377	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4923	 4925	 0.000611	 0.002377	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4924	 4927	 0.000444	 0.002056	 4e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4924	 76873	 0.00078	 0.003475	 6e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4925	 4934	 0.000653	 0.002231	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4925	 4934	 0.000653	 0.002231	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4925	 76856	 0.001149	 0.005064	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 4929	 0.000288	 0.000741	 0.00018	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 4951	 0.000373	 0.001217	 0.00032	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 76824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4926	 76824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76824	 4927	 0.000526	 0.002316	 4e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 76825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4929	 76825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4931	 4933	 0.001572	 0.003113	 5e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76825	 4931	 0.001797	 0.003522	 5e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4932	 4944	 0.001703	 0.004502	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4933	 4935	 0.004791	 0.003791	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76825	 4933	 0.002797	 0.005879	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4934	 4936	 0.000617	 0.0024	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4934	 4936	 0.000617	 0.0024	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 4942	 0.001068	 0.004007	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 4942	 0.001068	 0.004007	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4937	 76827	 0.007583	 0.005482	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4938	 5084	 0.001217	 0.004733	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4938	 5084	 0.001217	 0.004733	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4938	 76833	 0.001269	 0.004935	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4938	 76833	 0.001269	 0.004935	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4939	 4941	 0.000203	 0.000719	 0.00016	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4939	 4979	 0.00024	 0.000782	 0.00021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4939	 76826	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4939	 76826	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4940	 4942	 0.005468	 0.004023	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4941	 4943	 0.000287	 0.000832	 0.0002	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4942	 4944	 0.000901	 0.003507	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4942	 4944	 0.000901	 0.003507	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4943	 4945	 0.000252	 0.000839	 0.00021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4943	 76827	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4943	 76827	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4944	 76828	 0.000442	 0.003758	 0.0001	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4944	 76833	 0.001331	 0.00712	 0.00022	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4945	 4949	 0.000419	 0.001678	 0.00042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4946	 4952	 4.3e-05	 0.000555	 0.00016	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4946	 76828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4946	 76828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4947	 76829	 0.004788	 0.003789	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4948	 4950	 0.003294	 0.002607	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4949	 4951	 0.00022	 0.000719	 0.00019	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4949	 76829	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4949	 76829	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4950	 76831	 0.001288	 0.002551	 4e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4951	 5044	 0.00041	 0.001451	 0.00033	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 4957	 4.4e-05	 0.00055	 0.00017	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4953	 4956	 0.000701	 0.001628	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4953	 5132	 0.000312	 0.001251	 0.00032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4953	 76830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4953	 76830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76830	 4954	 0.003518	 0.002698	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4955	 4959	 0.000119	 0.001155	 0.00076	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4955	 7444	 0.000863	 0.010224	 0.00523	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4955	 76831	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4955	 76831	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4956	 76832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4956	 76832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4957	 4959	 4.4e-05	 0.00055	 0.00017	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4958	 4960	 0.000646	 0.002881	 5e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76832	 4958	 0.000487	 0.003343	 6e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 4965	 4.4e-05	 0.00046	 0.00026	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 76833	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4959	 76833	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4960	 4962	 0.001187	 0.003403	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76831	 4961	 0.003474	 0.00275	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4962	 4964	 0.001797	 0.003558	 5e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76831	 4963	 0.007785	 0.006161	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4964	 4966	 0.003817	 0.004157	 6e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4965	 4971	 0.0001	 0.001047	 0.00059	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76826	 4966	 0.005396	 0.005935	 8e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4967	 4969	 0.000535	 0.003672	 7e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4967	 5057	 0.01006	 0.007272	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4967	 5059	 0.003764	 0.00295	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4967	 76856	 0.001894	 0.009582	 0.00017	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4968	 4976	 0.000182	 0.00073	 0.00018	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4968	 5037	 0.000207	 0.000828	 0.00021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4969	 76834	 0.000342	 0.00232	 4e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 4972	 0.001252	 0.002965	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 5036	 0.001495	 0.004288	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4971	 4973	 5.5e-05	 0.000825	 0.00028	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4971	 76834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4971	 76834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4972	 5022	 0.004891	 0.003752	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4972	 76846	 0.003556	 0.009142	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4973	 4977	 0.000217	 0.003135	 0.001	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 76835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4974	 76835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4975	 5038	 0.005737	 0.00454	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4976	 5005	 0.000227	 0.000863	 0.00024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4977	 5006	 0.000533	 0.001665	 0.00048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	4977	 5012	 0.000585	 0.002343	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	4977	 76836	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4977	 76836	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76826	 4978	 0.00642	 0.004723	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4979	 4999	 0.00063	 0.001716	 0.00038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4979	 5132	 0.002746	 0.007953	 0.00192	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4979	 76837	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4979	 76837	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4980	 5001	 0.000851	 0.002612	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76837	 4980	 0.001137	 0.004424	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76836	 4981	 0.011895	 0.009012	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4982	 4983	 0.000305	 0.000882	 0.00021	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4983	 76838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4983	 76838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4984	 4985	 0.0022	 0.005055	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76838	 4984	 0.00194	 0.002972	 5e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4985	 4986	 0.001064	 0.001978	 5e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	4986	 4987	 0.000296	 0.00231	 4e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	4986	 4992	 0.000854	 0.004854	 9e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4987	 76839	 0.000271	 0.002228	 4e-05	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4988	 5316	 0.001077	 0.00289	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4988	 76839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4988	 76839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4989	 5002	 0.002375	 0.007923	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4989	 76843	 0.001092	 0.006204	 0.00011	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4990	 76898	 0.008159	 0.005898	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4991	 4997	 0.009789	 0.007673	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4991	 5002	 0.002673	 0.002626	 4e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4992	 76840	 0.001205	 0.00531	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4993	 5002	 0.004734	 0.006221	 9e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	4994	 4995	 0.000191	 0.000481	 0.00012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4994	 5321	 0.000712	 0.0021	 0.00049	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4994	 76840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4994	 76840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4995	 4998	 0.000397	 0.00103	 0.00025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4996	 76841	 0.002932	 0.002157	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	4998	 4999	 0.000201	 0.000506	 0.00013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	4998	 76841	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4998	 76841	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5000	 5002	 0.004691	 0.003677	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76838	 5001	 0.001026	 0.004572	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5003	 5004	 0.000868	 0.004189	 7e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76837	 5003	 0.000541	 0.00304	 6e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5004	 5011	 0.001172	 0.005163	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5005	 5009	 0.000387	 0.001549	 0.00039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5005	 76842	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5005	 76842	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5006	 76843	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5006	 76843	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5007	 5016	 0.00364	 0.002881	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5007	 76844	 0.001277	 0.002528	 4e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 5010	 0.006635	 0.004797	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76843	 5008	 0.00358	 0.005309	 8e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5009	 5013	 0.000289	 0.001157	 0.00029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5009	 76844	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5009	 76844	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76844	 5011	 0.000595	 0.002315	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5012	 76845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5012	 76845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5013	 5354	 0.000291	 0.000972	 0.00025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76845	 5014	 0.003827	 0.003028	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5015	 5021	 0.00063	 0.004914	 9e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76845	 5015	 0.000321	 0.002991	 6e-05	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5017	 5020	 0.005001	 0.003615	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76842	 5017	 0.004777	 0.004778	 6e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 5021	 0.004225	 0.002735	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5019	 5021	 0.000472	 0.002601	 6e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5019	 5233	 0.000673	 0.003782	 7e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5021	 5023	 0.003308	 0.002506	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5024	 5025	 0.001335	 0.003396	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5024	 76846	 0.001975	 0.005665	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5025	 5367	 0.001774	 0.004118	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 5029	 0.000929	 0.004829	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 5234	 0.000878	 0.004442	 8e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5027	 76850	 0.006554	 0.005187	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5028	 5060	 0.000402	 0.001093	 0.00024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5028	 5366	 0.000808	 0.002773	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5028	 76846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5028	 76846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5029	 5032	 0.000989	 0.003849	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5029	 5032	 0.000989	 0.003849	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5029	 5220	 0.001111	 0.004323	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5029	 5220	 0.001111	 0.004323	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76836	 5029	 0.003363	 0.013081	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76836	 5029	 0.003363	 0.013081	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5030	 5031	 0.006152	 0.004869	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5031	 5056	 0.00296	 0.003543	 6e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5032	 5033	 0.000973	 0.003742	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5032	 5033	 0.000973	 0.003742	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76836	 5033	 0.000594	 0.004494	 0.00015	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76843	 5033	 0.002893	 0.010853	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 5052	 0.003618	 0.002863	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5035	 5036	 0.001617	 0.004157	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5035	 5054	 0.002588	 0.006841	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5036	 5056	 0.00346	 0.008588	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5036	 76847	 0.001128	 0.005027	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5037	 5039	 0.000249	 0.000999	 0.00025	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5037	 76847	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5037	 76847	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76836	 5038	 0.005938	 0.006531	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5039	 5040	 0.00021	 0.000824	 0.00022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5040	 5042	 0.000224	 0.000881	 0.00023	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 5043	 0.000494	 0.004196	 0.0001	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76836	 5041	 0.00206	 0.007924	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76836	 5041	 0.00206	 0.007924	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5042	 5050	 0.000236	 0.000944	 0.00024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5042	 76848	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5042	 76848	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5043	 5045	 0.000457	 0.003754	 7e-05	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 5130	 0.000323	 0.001126	 0.00026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 76849	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5044	 76849	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5045	 5047	 0.000382	 0.00284	 7e-05	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76849	 5046	 0.004423	 0.003133	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5047	 5049	 0.001225	 0.003513	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5047	 5218	 0.000414	 0.003856	 7e-05	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5048	 76853	 0.006388	 0.005055	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5049	 5070	 0.001523	 0.005081	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5050	 5075	 0.000259	 0.001055	 0.00026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5051	 5055	 0.007923	 0.00627	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5052	 5054	 0.002847	 0.002184	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5053	 5055	 0.003893	 0.003081	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5054	 5089	 0.001801	 0.008024	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5055	 76854	 0.005421	 0.010381	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76846	 5056	 0.002927	 0.007587	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5056	 76860	 0.002953	 0.018152	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5058	 76851	 0.005577	 0.004414	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5060	 5066	 0.000458	 0.001862	 0.00045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5060	 76850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5060	 76850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5061	 5063	 0.004067	 0.003119	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5062	 5434	 0.001903	 0.006662	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76850	 5062	 0.00099	 0.00441	 7e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 5065	 0.004533	 0.002935	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 5082	 0.005189	 0.005298	 8e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 77302	 0.006406	 0.004713	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5066	 5093	 0.000385	 0.001499	 0.0004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5066	 76851	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5066	 76851	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5067	 5069	 0.005514	 0.004322	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 76854	 0.004767	 0.003446	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5068	 5071	 0.001211	 0.003719	 7e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5068	 76858	 0.001523	 0.004368	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 5074	 0.001073	 0.004175	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5071	 5073	 0.000914	 0.003556	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5072	 5074	 0.005112	 0.004046	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5073	 76852	 0.000801	 0.003116	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5074	 5076	 0.001713	 0.004402	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5074	 5078	 0.001179	 0.004358	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5074	 5078	 0.001179	 0.004358	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5074	 5195	 0.00133	 0.005174	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5074	 5195	 0.00133	 0.005174	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 5077	 0.000152	 0.00079	 0.00021	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 5087	 0.000315	 0.001333	 0.0003	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 76852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5075	 76852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5076	 5098	 0.001465	 0.003726	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5077	 5079	 0.000168	 0.000764	 0.00027	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5078	 76854	 0.001132	 0.004404	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5078	 76854	 0.001132	 0.004404	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5079	 5083	 0.000218	 0.001238	 0.00036	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5079	 76853	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5079	 76853	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5080	 5086	 0.000356	 0.001681	 0.00054	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5080	 76854	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5080	 76854	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5081	 76855	 0.005877	 0.004163	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 5084	 0.001905	 0.003733	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5083	 5103	 0.000196	 0.001242	 0.00034	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5083	 76855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5083	 76855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5084	 76856	 0.000775	 0.002982	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5084	 76856	 0.000775	 0.002982	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76855	 5085	 0.005499	 0.004166	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5086	 76856	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5086	 76856	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5087	 5099	 0.000303	 0.001179	 0.00031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5087	 76857	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5087	 76857	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5088	 5090	 0.004723	 0.003702	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76856	 5088	 0.002862	 0.003761	 5e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5089	 5091	 0.005757	 0.004513	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76857	 5089	 0.000548	 0.003072	 8e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5092	 5102	 0.000709	 0.002531	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5092	 5102	 0.000709	 0.002531	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76856	 5092	 0.001795	 0.005508	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76856	 5092	 0.001795	 0.005508	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5093	 5095	 0.000306	 0.001296	 0.00029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5093	 76858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5093	 76858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5094	 5096	 0.004379	 0.003433	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5095	 7102	 0.000182	 0.000714	 0.00019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5095	 76859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5095	 76859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5096	 5100	 0.00085	 0.003306	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 5100	 0.00085	 0.003306	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 5102	 0.001255	 0.004881	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 5102	 0.001255	 0.004881	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 76861	 0.00124	 0.006051	 0.0001	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 77299	 0.001181	 0.004133	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5098	 5181	 0.001565	 0.004024	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5099	 5101	 7.8e-05	 0.000749	 0.00022	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5099	 7090	 0.000701	 0.003341	 0.00097	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5099	 7096	 0.000127	 0.001042	 0.00028	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5099	 76860	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5099	 76860	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5100	 76864	 0.001264	 0.004918	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 76864	 0.001264	 0.004918	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5101	 5103	 7.4e-05	 0.000515	 0.0003	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5101	 76861	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5101	 76861	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5103	 76862	 0.000199	 0.00332	 0.00101	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 5115	 0.012231	 0.007918	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5105	 6091	 0.000152	 0.002511	 0.02353	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5105	 9563	 0.000255	 0.004449	 0.09166	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5105	 76862	 0.000128	 0.010206	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5106	 5114	 0.004948	 0.003916	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5107	 76864	 0.004564	 0.002955	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 5127	 0.001067	 0.006066	 0.00011	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76855	 5108	 0.000708	 0.002837	 7e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5109	 5125	 0.001057	 0.00423	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5109	 76864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5109	 76864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5110	 5111	 0.000529	 0.002056	 3e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 5111	 0.000529	 0.002056	 3e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 5172	 0.000707	 0.002472	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 5172	 0.000707	 0.002472	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5111	 5113	 0.00111	 0.004272	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5111	 5113	 0.00111	 0.004272	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 5168	 0.000453	 0.003426	 0.00011	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 5170	 0.004225	 0.003343	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 5172	 0.001423	 0.00486	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 5172	 0.001423	 0.00486	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5113	 5114	 0.000425	 0.003185	 6e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5113	 5123	 0.000397	 0.002753	 6e-05	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5114	 5115	 0.000389	 0.003238	 6e-05	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5115	 5116	 0.005763	 0.004561	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5115	 5119	 0.002565	 0.005893	 9e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5117	 5118	 0.003977	 0.002817	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 5119	 0.003429	 0.00263	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 76865	 0.00093	 0.002666	 4e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5120	 5126	 0.0001	 0.001579	 0.00054	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5120	 76865	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5120	 76865	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5121	 5136	 0.00264	 0.006786	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5121	 5138	 0.004431	 0.003507	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5121	 5142	 0.009265	 0.005998	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76863	 5121	 0.003761	 0.009565	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76865	 5122	 0.000537	 0.002578	 8e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5122	 76867	 0.000758	 0.004257	 8e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76865	 5123	 0.000621	 0.004839	 9e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5124	 5136	 0.006424	 0.005084	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 5126	 0.000103	 0.000895	 0.00025	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 76866	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5125	 76866	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5126	 5131	 0.000106	 0.001	 0.0003	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5126	 76867	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5126	 76867	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5127	 76870	 0.000545	 0.003641	 8e-05	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5128	 5129	 0.000648	 0.002523	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5128	 5129	 0.000648	 0.002523	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76818	 5128	 0.000505	 0.001866	 3e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76818	 5128	 0.000505	 0.001866	 3e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5129	 5135	 0.00087	 0.003387	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5129	 5135	 0.00087	 0.003387	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5129	 76871	 0.000784	 0.004817	 9e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5130	 5134	 0.000436	 0.001579	 0.00034	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5131	 5137	 0.000218	 0.002029	 0.00063	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5131	 5341	 0.000465	 0.005521	 0.00192	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5131	 76868	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5131	 76868	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5132	 5134	 0.000252	 0.001387	 0.00032	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5132	 76869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5132	 76869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5133	 5135	 0.00097	 0.003394	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 5135	 0.00097	 0.003394	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 5472	 0.001083	 0.003323	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 5472	 0.001083	 0.003323	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5134	 5157	 0.000645	 0.002452	 0.00069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76862	 5134	 0.000592	 0.003137	 0.00105	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5134	 76870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5134	 76870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5136	 5144	 0.005035	 0.00364	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5137	 5141	 0.00014	 0.001431	 0.00037	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5137	 76871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5137	 76871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76871	 5139	 0.001477	 0.002924	 4e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 76872	 0.002163	 0.005499	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 5159	 0.000365	 0.000964	 0.00023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 5208	 0.000332	 0.001155	 0.00027	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76862	 5140	 0.00088	 0.003345	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5141	 76872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5141	 76872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5142	 76877	 0.002416	 0.004035	 7e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5144	 76876	 0.005818	 0.004604	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76872	 5145	 0.004843	 0.003796	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76870	 5146	 0.003402	 0.003436	 5e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5147	 5156	 0.001017	 0.003633	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5147	 5156	 0.001017	 0.003633	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5147	 5158	 0.002103	 0.007357	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5147	 5158	 0.002103	 0.007357	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 5173	 0.000464	 0.001618	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 76873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5148	 76873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5149	 5154	 0.000277	 0.000745	 0.00017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5149	 5316	 0.000479	 0.001882	 0.00049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5149	 76874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5149	 76874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5150	 5314	 0.004085	 0.003233	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76874	 5151	 0.004333	 0.003397	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 76880	 0.006395	 0.005061	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5153	 5312	 0.001191	 0.003654	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5153	 76875	 0.00065	 0.002866	 5e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 76875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5154	 76875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76870	 5155	 0.005178	 0.006805	 9e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 5472	 0.001098	 0.00427	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 5472	 0.001098	 0.00427	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76875	 5156	 0.000486	 0.003337	 6e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5157	 5164	 0.000196	 0.001217	 0.00034	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5157	 5169	 0.000303	 0.001012	 0.00026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5157	 76876	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5157	 76876	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5158	 5160	 0.001554	 0.006046	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5158	 5161	 0.000512	 0.002876	 5e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5158	 5165	 0.000632	 0.005885	 0.00011	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5158	 5326	 0.00202	 0.01081	 0.00033	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5159	 5162	 0.000337	 0.000977	 0.00024	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5159	 5164	 0.000544	 0.001412	 0.00034	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5159	 76877	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5159	 76877	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5160	 5163	 0.000329	 0.003053	 7e-05	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5160	 5301	 0.000807	 0.003597	 6e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5160	 5310	 0.000566	 0.003482	 6e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5161	 5310	 0.000762	 0.003677	 6e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5162	 5199	 0.000484	 0.001458	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5162	 76878	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5162	 76878	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5163	 5165	 0.000744	 0.002896	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5163	 5165	 0.000744	 0.002896	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5164	 5190	 0.000263	 0.001633	 0.00046	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5164	 5199	 0.001181	 0.003171	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5164	 76879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5164	 76879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5165	 5168	 0.000602	 0.00234	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 5168	 0.000602	 0.00234	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5166	 5167	 0.000995	 0.003056	 6e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76879	 5166	 0.001191	 0.004169	 0.00012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5167	 5177	 0.000502	 0.003054	 6e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5167	 76885	 0.002432	 0.004523	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76866	 5168	 0.001265	 0.00432	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76866	 5168	 0.001265	 0.00432	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5169	 5171	 0.000221	 0.000745	 0.00019	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5171	 5175	 0.000302	 0.000874	 0.00021	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5171	 76880	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5171	 76880	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5173	 5175	 0.000432	 0.001141	 0.00027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5173	 76881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5173	 76881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5174	 5176	 0.001168	 0.004544	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5174	 5297	 0.004693	 0.003453	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5174	 5302	 0.003047	 0.008439	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76864	 5176	 0.001032	 0.004598	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5177	 76882	 0.000733	 0.003419	 8e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	5178	 76882	 0.001362	 0.002788	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5179	 5293	 0.001609	 0.006258	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5179	 5300	 0.000869	 0.002665	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5180	 5184	 0.000154	 0.000884	 0.00025	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5180	 5470	 0.000449	 0.002095	 0.00052	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5180	 76882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5180	 76882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5181	 5183	 0.00054	 0.003067	 6e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76864	 5181	 0.001144	 0.007032	 0.00013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76500	 5182	 0.001226	 0.00477	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76500	 5182	 0.001226	 0.00477	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5182	 76883	 0.000668	 0.00481	 0.00016	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 5185	 0.000623	 0.002976	 7e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	5184	 5186	 0.000159	 0.000912	 0.00026	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5184	 76883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5184	 76883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5185	 5294	 0.001195	 0.005766	 0.0001	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5186	 76884	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5186	 76884	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5187	 5189	 0.000524	 0.002886	 7e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5187	 5246	 0.000571	 0.002741	 8e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76884	 5188	 0.000957	 0.00342	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76884	 5188	 0.000957	 0.00342	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 76885	 0.000838	 0.002995	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 76885	 0.000838	 0.002995	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 5191	 0.000434	 0.003172	 6e-05	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 76885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5190	 76885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5191	 5193	 0.004731	 0.003744	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5191	 5197	 0.002088	 0.004458	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76864	 5191	 0.002126	 0.01307	 0.00024	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5192	 5194	 0.002477	 0.001823	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 5196	 0.003095	 0.00567	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76548	 5194	 0.001813	 0.004293	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5195	 5197	 0.000876	 0.00281	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5195	 5197	 0.000876	 0.00281	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76878	 5196	 0.001659	 0.002719	 5e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 5198	 0.000522	 0.003209	 6e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5198	 5200	 0.000521	 0.003083	 6e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5199	 5201	 0.000501	 0.00204	 0.0005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5199	 5203	 0.000275	 0.001164	 0.00026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5199	 76886	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5199	 76886	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5200	 5211	 0.000768	 0.003404	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5201	 5215	 0.000372	 0.001535	 0.00036	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5201	 76887	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5201	 76887	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5202	 5246	 0.002556	 0.00657	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 76888	 0.004039	 0.010383	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5203	 5212	 0.000174	 0.000718	 0.00017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 5211	 0.000521	 0.002307	 7e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 5213	 0.001884	 0.006067	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 5244	 0.001606	 0.004128	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 76888	 0.000922	 0.005239	 9e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 5254	 0.002507	 0.007544	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 76888	 0.001181	 0.003939	 6e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76886	 5206	 0.005031	 0.003257	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5207	 5209	 0.000341	 0.000791	 0.00024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5207	 76888	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5207	 76888	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5208	 5210	 0.00024	 0.000976	 0.00024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5208	 76889	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5208	 76889	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5209	 5271	 0.001008	 0.006385	 0.00173	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5209	 76890	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5209	 76890	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5210	 5215	 0.000442	 0.001797	 0.00044	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5212	 5215	 0.0003	 0.00122	 0.0003	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5212	 76891	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5212	 76891	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5213	 5214	 0.000855	 0.003328	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 5216	 0.000855	 0.003056	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5215	 6735	 0.000403	 0.002025	 0.00053	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5215	 76892	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5215	 76892	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5215	 77042	 0.00086	 0.008848	 0.00251	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5216	 5217	 0.000714	 0.003145	 5e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5217	 5218	 0.001094	 0.004873	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 5224	 0.001952	 0.006513	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5219	 5224	 0.005292	 0.004188	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 5222	 0.000836	 0.003252	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 5222	 0.000836	 0.003252	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5221	 5225	 0.003383	 0.003753	 7e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76892	 5221	 0.001446	 0.008219	 0.00015	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5222	 5224	 0.000354	 0.003423	 7e-05	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5223	 5225	 0.001887	 0.004468	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76889	 5223	 0.00167	 0.004248	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5224	 5226	 0.000843	 0.003281	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5224	 5226	 0.000843	 0.003281	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5226	 5227	 0.001089	 0.004235	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5226	 5227	 0.001089	 0.004235	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5226	 5230	 0.00173	 0.005548	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76890	 5227	 0.001264	 0.004743	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76890	 5227	 0.001264	 0.004743	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5228	 5229	 0.006989	 0.005478	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76890	 5228	 0.003307	 0.006334	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5229	 5239	 0.004609	 0.003647	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 5232	 0.001571	 0.00524	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 5233	 0.003876	 0.015078	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 5237	 0.006583	 0.012442	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 76893	 0.015694	 0.049831	 0.00087	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5231	 5232	 0.001201	 0.004807	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5231	 5234	 0.001196	 0.004581	 0.00013	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5232	 5236	 0.00523	 0.004139	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5232	 5238	 0.009659	 0.007107	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5233	 5235	 0.002764	 0.004657	 7e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 7267	 0.042958	 0.033673	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76890	 5240	 0.008	 0.006331	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5241	 5257	 0.007959	 0.006239	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76890	 5241	 0.013405	 0.011033	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76888	 5242	 0.006569	 0.004253	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5243	 5244	 0.002005	 0.005099	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5243	 5253	 0.00142	 0.00365	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 5248	 0.007995	 0.006327	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5246	 5247	 0.001498	 0.003547	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5247	 5248	 0.001367	 0.003514	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5248	 5249	 0.000995	 0.003057	 6e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5248	 5289	 0.001431	 0.00371	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 5250	 0.001063	 0.003263	 6e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 5259	 0.001843	 0.004214	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 5252	 0.003622	 0.002866	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 5253	 0.001649	 0.004729	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 5259	 0.001474	 0.004863	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5254	 5256	 0.001507	 0.005796	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 5256	 0.004568	 0.003302	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5256	 5258	 0.000885	 0.003616	 7e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5258	 76894	 0.001774	 0.005853	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5259	 5260	 0.003497	 0.002741	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5259	 5264	 0.005642	 0.004151	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5259	 5267	 0.002222	 0.006374	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5259	 76893	 0.00431	 0.014224	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 5281	 0.003783	 0.002994	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5262	 5276	 0.005503	 0.003563	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5263	 5268	 0.007275	 0.005757	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5265	 5266	 0.001227	 0.003153	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5265	 76894	 0.001155	 0.002969	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5266	 5267	 0.00133	 0.003419	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5267	 5268	 0.001881	 0.003497	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5268	 5276	 0.003468	 0.006258	 9e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5269	 5273	 0.001343	 0.005378	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5269	 5384	 0.000656	 0.002578	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5269	 76893	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5269	 76893	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5270	 5272	 0.004763	 0.003653	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 5413	 0.014383	 0.011382	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76893	 5270	 0.002966	 0.007625	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 76895	 0.017217	 0.01739	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5271	 5273	 0.000405	 0.001856	 0.00048	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5271	 76894	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5271	 76894	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5272	 5275	 0.014394	 0.009319	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5273	 5274	 0.000752	 0.00549	 0.00141	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5273	 76895	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5273	 76895	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5274	 7270	 0.001385	 0.008313	 0.00252	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5276	 5403	 0.004165	 0.00542	 8e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5277	 5384	 0.000771	 0.002099	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5277	 76896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5277	 76896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5278	 5279	 0.0088	 0.006475	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76896	 5278	 0.004721	 0.003056	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 5281	 0.001111	 0.004322	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76896	 5280	 0.000646	 0.003442	 6e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	5281	 5282	 0.001133	 0.003002	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5282	 5283	 0.004752	 0.003761	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5282	 5284	 0.001436	 0.004558	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 5285	 0.000842	 0.003276	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5285	 5288	 0.004944	 0.003201	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5285	 5289	 0.001321	 0.004054	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5285	 5294	 0.002476	 0.009631	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5285	 5304	 0.003466	 0.009837	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 5287	 0.001141	 0.003273	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 5304	 0.001568	 0.003209	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5287	 5290	 0.001801	 0.006008	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 5293	 0.000993	 0.003314	 5e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5291	 5292	 0.004685	 0.003447	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5291	 5302	 0.006909	 0.007599	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5294	 5295	 0.004912	 0.003887	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 5297	 0.007349	 0.005761	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 5299	 0.000526	 0.001614	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 5302	 0.001177	 0.00458	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5299	 5301	 0.000909	 0.004052	 7e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76864	 5300	 0.000778	 0.003426	 6e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5302	 76897	 0.002651	 0.00928	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5303	 5304	 0.002383	 0.005009	 9e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5303	 5308	 0.001103	 0.003055	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5304	 5305	 0.000669	 0.004068	 8e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5304	 76897	 0.001961	 0.007005	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5305	 5334	 0.000745	 0.004186	 8e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5306	 5332	 0.00026	 0.00104	 0.00026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5306	 76897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5306	 76897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5307	 5308	 0.005042	 0.00399	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 5331	 0.001861	 0.00665	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5309	 5330	 0.005775	 0.00457	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5310	 5330	 0.000323	 0.003165	 6e-05	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 5312	 0.003637	 0.003884	 8e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5312	 5328	 0.001999	 0.004092	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5313	 76898	 0.004417	 0.003193	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5314	 5327	 0.000432	 0.002658	 5e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76874	 5314	 0.000373	 0.002909	 5e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5315	 76898	 0.004608	 0.003647	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5316	 76898	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5316	 76898	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5317	 5318	 0.004939	 0.003742	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 5326	 0.002721	 0.005212	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5319	 5322	 0.005449	 0.004313	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76840	 5320	 0.003569	 0.00357	 5e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 5324	 0.000368	 0.001557	 0.00035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 76899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5321	 76899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76899	 5322	 0.002574	 0.005097	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5323	 76900	 0.004867	 0.003151	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5324	 5342	 0.000165	 0.001347	 0.00037	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76862	 5324	 0.005523	 0.018948	 0.00454	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5324	 76900	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5324	 76900	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5325	 5326	 0.001023	 0.002705	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76900	 5325	 0.000818	 0.002796	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5326	 5327	 0.000506	 0.0021	 5e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76900	 5326	 0.002158	 0.00619	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5328	 5329	 0.004722	 0.004428	 7e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5328	 76902	 0.001529	 0.003888	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5330	 5331	 0.000388	 0.00319	 6e-05	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76900	 5331	 0.006383	 0.014819	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5331	 76901	 0.000642	 0.00313	 6e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 5341	 0.00023	 0.001047	 0.00033	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 76901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5332	 76901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5333	 5335	 0.000719	 0.002517	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 5335	 0.000719	 0.002517	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76897	 5333	 0.001224	 0.004763	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76901	 5333	 0.000298	 0.002477	 5e-05	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 5335	 0.00158	 0.004754	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 5377	 0.000864	 0.004602	 8e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	5335	 5336	 0.000505	 0.003105	 6e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5336	 5337	 0.000543	 0.002825	 6e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5337	 5381	 0.00109	 0.004878	 0.0001	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5337	 5383	 0.006357	 0.004983	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5338	 5339	 0.005573	 0.004029	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5339	 5344	 0.006912	 0.00547	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 5343	 0.005267	 0.004169	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5341	 5342	 0.00011	 0.000961	 0.00026	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5342	 76902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5342	 76902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5343	 5350	 0.006317	 0.004566	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 5345	 0.00101	 0.003534	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 5350	 0.00103	 0.005026	 9e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5345	 5379	 0.001777	 0.005865	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5345	 5380	 0.004512	 0.003461	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5346	 5347	 0.000854	 0.003287	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5346	 5357	 0.001118	 0.00435	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5347	 5348	 0.000744	 0.00328	 6e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5348	 5349	 0.000595	 0.002975	 5e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5348	 76903	 0.001313	 0.004593	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5349	 5350	 0.000467	 0.002623	 5e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76900	 5350	 0.001444	 0.005616	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76900	 5350	 0.001444	 0.005616	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 5352	 0.003386	 0.00268	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76899	 5351	 0.002189	 0.003949	 6e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5353	 5354	 0.000268	 0.00072	 0.0002	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5353	 5359	 0.000515	 0.003319	 0.00087	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5353	 76903	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5353	 76903	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5355	 5356	 0.000908	 0.002309	 4e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76899	 5355	 0.00165	 0.011195	 0.00021	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76903	 5355	 0.001852	 0.00476	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5356	 5360	 0.001001	 0.002323	 4e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5357	 76904	 0.001347	 0.004135	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5358	 5376	 0.003008	 0.005427	 8e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5358	 76904	 0.002621	 0.004272	 7e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5359	 5362	 0.000216	 0.000783	 0.00017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5359	 76904	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5359	 76904	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5360	 5361	 0.001798	 0.004112	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 5364	 0.001145	 0.003821	 6e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5361	 5363	 0.003986	 0.003154	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5361	 76905	 0.002072	 0.005326	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 5370	 0.000232	 0.000783	 0.00019	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 76905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5362	 76905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76842	 5364	 0.001796	 0.009569	 0.00017	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 76908	 0.004439	 0.003513	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5366	 5374	 0.000418	 0.001165	 0.00024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5366	 76906	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5366	 76906	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76906	 5367	 0.00081	 0.003477	 6e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 76915	 0.000919	 0.004071	 0.00012	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5368	 5369	 0.000924	 0.003595	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5368	 5432	 0.000782	 0.003816	 7e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5369	 76907	 0.001018	 0.004534	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5370	 5371	 0.000427	 0.001298	 0.00028	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5371	 5374	 0.000825	 0.00218	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5371	 76907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5371	 76907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76907	 5372	 0.005339	 0.004225	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76905	 5373	 0.008651	 0.006846	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 76908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5374	 76908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5375	 5376	 0.00607	 0.004466	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5376	 5378	 0.001167	 0.003086	 6e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5376	 5388	 0.002444	 0.004839	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5377	 76909	 0.002311	 0.010295	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5378	 5379	 0.000782	 0.001788	 4e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5381	 76909	 0.001436	 0.00531	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5382	 76909	 0.004841	 0.003831	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76862	 5384	 0.005817	 0.023673	 0.00577	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5384	 76909	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5384	 76909	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5385	 5387	 0.000586	 0.002445	 7e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76909	 5385	 0.000616	 0.002732	 8e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 5387	 0.002587	 0.005943	 9e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 5402	 0.000715	 0.002386	 4e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76909	 5386	 0.000895	 0.005086	 9e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 5390	 0.005715	 0.004523	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 5392	 0.010976	 0.008604	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 5398	 0.003146	 0.012102	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5388	 5389	 0.005413	 0.004284	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76909	 5388	 0.004956	 0.011386	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 5393	 0.005299	 0.003431	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 5391	 0.005485	 0.003886	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5392	 5394	 0.00682	 0.00493	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 5419	 0.009328	 0.007382	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 5397	 0.004082	 0.002642	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5397	 5398	 0.001195	 0.003428	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5397	 5407	 0.001903	 0.003894	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5398	 5411	 0.009514	 0.010362	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5399	 5400	 0.004531	 0.00321	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 5401	 0.00452	 0.003577	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 5402	 0.004535	 0.003589	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5402	 5404	 0.002982	 0.008551	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76909	 5403	 0.004734	 0.005207	 7e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5404	 5405	 0.001152	 0.002961	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5405	 5406	 0.006019	 0.004763	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5405	 5411	 0.00165	 0.004196	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5405	 5412	 0.004284	 0.00339	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5407	 5408	 0.001122	 0.002883	 4e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5408	 5409	 0.000689	 0.001955	 3e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 76911	 0.000954	 0.002528	 6e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5410	 5411	 0.001288	 0.003311	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5410	 5414	 0.001647	 0.003901	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5414	 76911	 0.00335	 0.00766	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5415	 5416	 0.000407	 0.001219	 0.00027	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5415	 5420	 0.000723	 0.002895	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5415	 7265	 0.001105	 0.006997	 0.0019	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5415	 76910	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5415	 76910	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5416	 76911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5416	 76911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5417	 5418	 0.009641	 0.010604	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76909	 5418	 0.013089	 0.039397	 0.00077	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5418	 76912	 0.002231	 0.005178	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5418	 77342	 0.005132	 0.022866	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76904	 5419	 0.00504	 0.011699	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5420	 5421	 0.00024	 0.000961	 0.00024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5420	 5439	 0.000526	 0.003329	 0.0009	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5421	 5422	 0.000278	 0.001113	 0.00028	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5422	 5423	 0.000384	 0.001508	 0.00039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 5424	 0.000347	 0.001362	 0.00036	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 76912	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5423	 76912	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5424	 5461	 0.000274	 0.00116	 0.00026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5424	 76913	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5424	 76913	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5425	 76919	 0.007398	 0.00742	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5426	 5427	 0.003975	 0.002574	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 5428	 0.007519	 0.00595	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 76916	 0.002441	 0.004833	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5429	 5430	 0.005391	 0.003819	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5430	 5431	 0.003313	 0.002622	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5430	 76916	 0.003743	 0.007411	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5432	 76916	 0.000533	 0.002361	 7e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 5435	 0.000543	 0.002296	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 7108	 0.000874	 0.003803	 0.00108	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 76914	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5433	 76914	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5434	 5448	 0.001605	 0.005734	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 5439	 0.000347	 0.001414	 0.00034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 76915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5435	 76915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5436	 5447	 0.006459	 0.005063	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76914	 5436	 0.006394	 0.004139	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5437	 5438	 0.001512	 0.003886	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5437	 5444	 0.001481	 0.003766	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5438	 5463	 0.001783	 0.004585	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5439	 76916	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5439	 76916	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5440	 5441	 0.002248	 0.00279	 6e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76916	 5440	 0.001749	 0.003463	 5e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 5442	 0.003084	 0.003392	 5e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5442	 5443	 0.003706	 0.003414	 5e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5443	 5444	 0.005136	 0.004731	 8e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5444	 5446	 0.006916	 0.005	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76915	 5444	 0.005558	 0.014286	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5444	 76920	 0.001702	 0.007584	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 5448	 0.001715	 0.00351	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 5460	 0.001688	 0.003454	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5448	 5449	 0.00134	 0.003446	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5449	 76918	 0.001926	 0.003942	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5450	 76917	 0.003796	 0.002793	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5451	 5452	 0.000324	 0.001319	 0.00032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5451	 5453	 0.000293	 0.001172	 0.0003	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5451	 76917	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5451	 76917	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5452	 5462	 0.000494	 0.001663	 0.00041	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 76918	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5452	 76918	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5453	 5454	 0.000342	 0.001411	 0.00033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5453	 7158	 0.000863	 0.003392	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5454	 5455	 0.000164	 0.000657	 0.00017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5455	 6737	 0.000238	 0.000926	 0.00025	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76918	 5456	 0.007355	 0.005412	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5457	 5459	 0.0061	 0.004827	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5458	 5464	 0.006932	 0.005486	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5459	 76920	 0.005449	 0.00418	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 76920	 0.001764	 0.004178	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 5462	 0.000316	 0.001263	 0.00032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 76919	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5461	 76919	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5462	 7090	 0.003153	 0.014705	 0.00364	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5462	 76920	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5462	 76920	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76914	 5463	 0.002072	 0.005326	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5464	 5465	 0.004278	 0.003093	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5464	 5466	 0.000602	 0.003698	 8e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76920	 5464	 0.000571	 0.004697	 9e-05	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5466	 6773	 0.004927	 0.016435	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5466	 6780	 0.001818	 0.009456	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5466	 77298	 0.020088	 0.067013	 0.00106	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76913	 5467	 0.005094	 0.003608	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76920	 5467	 0.004261	 0.006856	 0.00011	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5468	 5469	 0.006736	 0.005331	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76920	 5469	 0.008798	 0.017419	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 76921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5470	 76921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5473	 5474	 0.21477	 0.15804	 0.00231	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5475	 7638	 0.005917	 0.10127	 0.05498	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5475	 76922	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5475	 76922	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5476	 5478	 0.1779	 0.17971	 0.00238	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76557	 5476	 0.2671	 0.25057	 0.00387	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76557	 5477	 0.013345	 0.047673	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76557	 5477	 0.013345	 0.047673	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76922	 5477	 0.028761	 0.11065	 0.00189	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76922	 5477	 0.028761	 0.11065	 0.00189	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5479	 6388	 0.26509	 0.29167	 0.00389	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76557	 5479	 0.043399	 0.19704	 0.00427	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 5683	 0.0137	 0.031803	 0.00969	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 76923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5480	 76923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76923	 5481	 0.041273	 0.1061	 0.00164	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 76924	 0.077991	 0.11417	 0.00176	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 76924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5482	 76924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5482	 76951	 0.027122	 0.069735	 0.01727	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 5651	 0.043245	 0.1004	 0.00149	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76923	 5483	 0.029244	 0.082987	 0.0013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5484	 5485	 0.017773	 0.013633	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5485	 5489	 0.014056	 0.077403	 0.00175	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76924	 5485	 0.019339	 0.094371	 0.00163	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5486	 5635	 0.1011	 0.080014	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5487	 6578	 0.057764	 0.1058	 0.00183	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76924	 5487	 0.030236	 0.07401	 0.00127	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5488	 5489	 0.003076	 0.021112	 0.00038	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5488	 5490	 0.057338	 0.045377	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76529	 5488	 0.018074	 0.16628	 0.0033	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5491	 6578	 0.18392	 0.14418	 0.00185	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5492	 8500	 0.18954	 0.13704	 0.00208	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5493	 5494	 0.076749	 0.060739	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5494	 7761	 0.042008	 0.088292	 0.00161	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76924	 5494	 0.12721	 0.29538	 0.00563	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 5497	 0.008907	 0.036778	 0.0087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 6533	 0.009712	 0.039523	 0.00963	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 76925	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5495	 76925	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76925	 5496	 0.034807	 0.026699	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5497	 76926	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5497	 76926	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76926	 5498	 0.11812	 0.12062	 0.00188	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5499	 76927	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5499	 76927	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76927	 5500	 0.067283	 0.048639	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5501	 77125	 0.15449	 0.11169	 0.00169	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5502	 5503	 0.002612	 0.011167	 0.00025	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76523	 5502	 0.009714	 0.043287	 0.00074	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5503	 5504	 0.02415	 0.02164	 0.00044	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5503	 5505	 0.011035	 0.075746	 0.00138	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5505	 5506	 0.016845	 0.04284	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5505	 77163	 0.047072	 0.20978	 0.00356	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5506	 5510	 0.026357	 0.069859	 0.00177	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5507	 6476	 0.11308	 0.12438	 0.00166	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 5510	 0.005878	 0.019608	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 77163	 0.022203	 0.11232	 0.00195	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76523	 5509	 0.050407	 0.11937	 0.00218	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 5537	 0.004772	 0.007446	 0.00012	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 5581	 0.012902	 0.009492	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 5582	 0.031359	 0.020302	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 76938	 0.021377	 0.035651	 0.00052	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 5514	 0.006138	 0.004857	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 5544	 0.005832	 0.009309	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 5545	 0.006149	 0.004866	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5513	 5524	 0.004344	 0.006934	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5513	 76935	 0.002001	 0.007783	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5514	 5582	 0.013187	 0.010436	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5515	 5571	 0.011168	 0.008838	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5515	 5582	 0.013167	 0.009976	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5516	 76928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5516	 76928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5517	 76929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5517	 76929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5518	 5520	 0.001088	 0.002874	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5518	 76930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5518	 76930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76930	 5519	 0.009741	 0.006306	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5520	 5521	 0.000864	 0.002319	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 5579	 0.0036	 0.009346	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 76931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5521	 76931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5522	 5536	 0.004438	 0.006798	 0.00012	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76931	 5522	 0.004266	 0.008447	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5523	 5557	 0.010124	 0.007449	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5523	 5587	 0.018051	 0.014149	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 5525	 0.011267	 0.007294	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 5526	 0.002981	 0.007664	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 5583	 0.011199	 0.008778	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 5531	 0.009808	 0.008073	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5526	 5569	 0.007845	 0.016811	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5527	 5530	 0.019986	 0.012939	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 5531	 0.008969	 0.006795	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5529	 5530	 0.010376	 0.006717	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5530	 5531	 0.004583	 0.007613	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5532	 5640	 0.013978	 0.010956	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5533	 5562	 0.00331	 0.007569	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5534	 76932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5534	 76932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5534	 76951	 0.002781	 0.011135	 0.00281	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5535	 5543	 0.00782	 0.005063	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76931	 5535	 0.011987	 0.009395	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5536	 5537	 0.009179	 0.009017	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5537	 5589	 0.007636	 0.006043	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5538	 5544	 0.003594	 0.008344	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76930	 5538	 0.003342	 0.011148	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5539	 5577	 0.00491	 0.009623	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5539	 5592	 0.004029	 0.00954	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5540	 5544	 0.013268	 0.009591	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 5542	 0.00663	 0.004292	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5542	 5544	 0.004991	 0.009881	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5542	 5571	 0.006836	 0.010472	 0.00015	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5546	 5548	 0.008462	 0.006226	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5546	 5575	 0.009358	 0.006885	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5547	 5549	 0.000971	 0.003331	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5547	 5574	 0.000584	 0.002375	 0.00058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5547	 76933	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5547	 76933	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5548	 76934	 0.006472	 0.006491	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 5550	 0.000413	 0.001441	 0.00033	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 76934	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5549	 76934	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5550	 5552	 0.000466	 0.001556	 0.00039	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76933	 5551	 0.010699	 0.007734	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5552	 76935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5552	 76935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5552	 76951	 0.003848	 0.024375	 0.00662	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 5566	 0.004711	 0.008628	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76933	 5553	 0.00535	 0.013752	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5554	 5566	 0.017568	 0.0127	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5554	 5602	 0.014763	 0.011572	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5555	 5556	 0.014227	 0.011152	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5555	 5561	 0.007403	 0.009421	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5555	 76938	 0.006655	 0.011705	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5556	 5560	 0.005763	 0.0075	 0.0001	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5556	 5565	 0.005769	 0.007583	 0.0001	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5556	 5586	 0.019446	 0.015242	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5557	 5558	 0.010595	 0.008385	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5557	 5559	 0.006842	 0.00691	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5558	 5562	 0.004605	 0.009026	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5558	 5585	 0.004313	 0.0079	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5559	 5560	 0.013447	 0.010642	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5559	 5562	 0.009619	 0.007612	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5560	 5563	 0.006276	 0.012426	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5561	 5681	 0.06698	 0.04928	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5561	 5701	 0.023971	 0.026109	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76932	 5561	 0.005005	 0.026362	 0.00047	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	5563	 5564	 0.009579	 0.007581	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5565	 5588	 0.019915	 0.012893	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5565	 76938	 0.00653	 0.010424	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5566	 5567	 0.003571	 0.005699	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 5569	 0.007314	 0.01448	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 5612	 0.028027	 0.046741	 0.00068	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 5637	 0.028697	 0.022711	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5568	 5569	 0.011842	 0.009282	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5569	 5639	 0.005677	 0.01318	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5570	 5572	 0.010615	 0.006872	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5571	 5575	 0.007277	 0.00853	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 5575	 0.009211	 0.014372	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 5595	 0.034538	 0.027073	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 5599	 0.021776	 0.014098	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76929	 5572	 0.013705	 0.03523	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 76936	 0.030605	 0.02422	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5573	 76936	 0.0148	 0.011601	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 5601	 0.001238	 0.004956	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 76936	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5574	 76936	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5576	 5590	 0.001758	 0.004419	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5576	 76937	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5576	 76937	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5577	 5665	 0.017562	 0.022855	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 5580	 0.005726	 0.010292	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 76938	 0.002796	 0.012389	 0.00037	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5579	 5677	 0.001656	 0.006025	 0.00184	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5579	 76938	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5579	 76938	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5579	 76951	 0.003145	 0.019922	 0.00541	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5582	 5584	 0.007658	 0.011731	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76935	 5582	 0.014838	 0.018419	 0.0004	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5583	 5584	 0.007036	 0.007514	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5584	 5585	 0.016301	 0.01235	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76932	 5584	 0.017381	 0.035568	 0.00088	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5587	 5589	 0.008308	 0.006574	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76938	 5587	 0.010439	 0.020669	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76931	 5588	 0.020036	 0.020237	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5590	 5594	 0.003274	 0.008654	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5590	 76939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5590	 76939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76939	 5591	 0.020217	 0.015847	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5592	 5593	 0.00611	 0.012504	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76929	 5593	 0.006461	 0.017896	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5594	 5702	 0.001741	 0.004674	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5594	 76940	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5594	 76940	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5595	 5600	 0.024103	 0.015604	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76929	 5596	 0.013687	 0.034809	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76940	 5596	 0.011283	 0.018741	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 5603	 0.002441	 0.006808	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 5702	 0.001641	 0.004261	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5598	 5600	 0.022096	 0.016256	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5600	 76941	 0.015707	 0.017276	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5601	 5606	 0.002956	 0.012512	 0.00282	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5601	 76941	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5601	 76941	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76941	 5602	 0.009037	 0.012809	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5603	 5606	 0.002654	 0.007226	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5604	 76942	 0.033765	 0.024409	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5605	 5606	 0.001282	 0.004487	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5605	 5609	 0.002018	 0.006583	 0.00175	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5605	 76942	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5605	 76942	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5606	 5607	 0.002829	 0.007476	 0.00175	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5607	 5610	 0.003159	 0.011167	 0.00252	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5607	 5611	 0.001769	 0.005123	 0.00124	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5608	 5609	 0.003394	 0.01107	 0.00294	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5608	 76943	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5608	 76943	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5610	 76944	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5610	 76944	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5611	 76945	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5611	 76945	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76945	 5612	 0.030353	 0.050694	 0.00086	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5613	 5618	 0.011492	 0.03261	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76945	 5613	 0.008808	 0.029067	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76944	 5614	 0.10022	 0.073741	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5615	 5618	 0.007945	 0.020423	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5615	 76948	 0.007734	 0.01988	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5616	 76949	 0.014105	 0.020647	 0.00032	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5617	 5618	 0.030782	 0.019928	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 5624	 0.002752	 0.009439	 0.00226	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 76946	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5619	 76946	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5620	 5621	 0.021056	 0.014915	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5620	 5626	 0.010348	 0.024024	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5620	 5631	 0.047922	 0.056175	 0.00098	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5622	 5623	 0.006798	 0.033173	 0.00057	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76946	 5622	 0.005169	 0.028286	 0.00055	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5623	 6556	 0.012562	 0.043983	 0.00122	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5624	 5625	 0.002034	 0.005375	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5624	 76947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5624	 76947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5625	 5628	 0.002628	 0.006607	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5625	 76948	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5625	 76948	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76947	 5626	 0.009196	 0.02135	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 76949	 0.00986	 0.006985	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5628	 76949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5628	 76949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76949	 5629	 0.010552	 0.022612	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 5631	 0.038509	 0.030475	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5631	 5632	 0.048645	 0.038497	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5631	 5644	 0.017881	 0.045475	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5632	 5633	 0.032319	 0.025333	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5634	 5644	 0.053536	 0.03466	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5635	 5636	 0.018215	 0.055937	 0.00105	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5635	 76953	 0.021294	 0.087029	 0.00176	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 6556	 0.028584	 0.072694	 0.00115	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5638	 5639	 0.023993	 0.018988	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5639	 5641	 0.009377	 0.02177	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5640	 5641	 0.015171	 0.012006	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5641	 5642	 0.015195	 0.038643	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5641	 5643	 0.033021	 0.024294	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5642	 76952	 0.00572	 0.024564	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5644	 5647	 0.042082	 0.027244	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5644	 6556	 0.050065	 0.13235	 0.0024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5644	 6565	 0.088576	 0.29237	 0.00474	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76949	 5644	 0.032736	 0.066993	 0.00165	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5644	 76952	 0.009659	 0.035713	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5644	 76952	 0.009659	 0.035713	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5645	 5684	 0.002633	 0.012081	 0.00309	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5645	 76950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5645	 76950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5645	 76951	 0.001809	 0.009379	 0.00229	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 8495	 0.001949	 0.023779	 0.22858	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 76951	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76951	 5648	 0.003548	 0.012364	 0.00287	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5648	 76953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5648	 76953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5649	 5650	 0.046286	 0.031092	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76950	 5649	 0.010622	 0.025153	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76953	 5651	 0.033848	 0.078584	 0.00117	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5652	 5660	 0.0331	 0.036052	 0.00049	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5652	 5665	 0.053846	 0.048581	 0.00081	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76937	 5652	 0.023409	 0.023414	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5653	 5660	 0.054404	 0.043054	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5654	 5660	 0.082277	 0.065114	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5654	 5688	 0.067939	 0.049113	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5655	 5668	 0.023186	 0.017566	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5655	 5671	 0.022299	 0.016406	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 5657	 0.0446	 0.035296	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 5672	 0.02297	 0.045479	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 5686	 0.091378	 0.064729	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5657	 5658	 0.032955	 0.02608	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5657	 5661	 0.035185	 0.025435	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 5661	 0.011576	 0.018478	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 5663	 0.01877	 0.014854	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 5665	 0.008652	 0.020084	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 5663	 0.012962	 0.008707	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76937	 5662	 0.018411	 0.01457	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 5665	 0.018448	 0.013572	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76498	 5665	 0.004221	 0.028641	 0.00053	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 5669	 0.019861	 0.014612	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76928	 5666	 0.015453	 0.016996	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5667	 5668	 0.02623	 0.018962	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5668	 5670	 0.007497	 0.019271	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76928	 5670	 0.006294	 0.024484	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5671	 5672	 0.016694	 0.015655	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 76955	 0.017466	 0.039619	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 5677	 0.002352	 0.009954	 0.00224	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 5683	 0.003688	 0.023357	 0.00634	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 5684	 0.006184	 0.021212	 0.00508	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 76954	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5673	 76954	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5674	 5676	 0.021887	 0.024073	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76954	 5675	 0.020751	 0.016422	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 76955	 0.006528	 0.014807	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5677	 76955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5677	 76955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76938	 5678	 0.015319	 0.022321	 0.0005	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76954	 5678	 0.016417	 0.038875	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5679	 5680	 0.014857	 0.029117	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5679	 5682	 0.011928	 0.027057	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 5681	 0.017455	 0.020895	 0.00035	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 5691	 0.044387	 0.034048	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 76957	 0.028574	 0.072668	 0.00115	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5683	 5684	 0.002529	 0.012708	 0.00331	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5683	 5693	 0.001272	 0.012519	 0.00517	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5683	 76956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5683	 76956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5684	 76957	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5684	 76957	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76764	 5685	 0.035216	 0.10804	 0.00293	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76923	 5685	 0.030024	 0.055826	 0.00131	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76956	 5685	 0.051193	 0.077644	 0.00111	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5686	 5688	 0.057876	 0.063657	 0.00085	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 5688	 0.045227	 0.035792	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5688	 5694	 0.026251	 0.075291	 0.00116	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5689	 5690	 0.029872	 0.037081	 0.00081	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5689	 5692	 0.042298	 0.030577	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76954	 5689	 0.014733	 0.062987	 0.00142	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5690	 5700	 0.083633	 0.084474	 0.00112	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76954	 5691	 0.038802	 0.039192	 0.00052	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 6666	 0.011671	 0.046732	 0.01177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76951	 5693	 0.009831	 0.046862	 0.01358	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5694	 5695	 0.028161	 0.072393	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5695	 6669	 0.047774	 0.10926	 0.00267	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5696	 5699	 0.035506	 0.037917	 0.0008	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5697	 5698	 0.007382	 0.015107	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5697	 6667	 0.034936	 0.09914	 0.00156	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5698	 5699	 0.008677	 0.01718	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5698	 5700	 0.027418	 0.036035	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76954	 5699	 0.094533	 0.18719	 0.00275	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5703	 5710	 0.021991	 0.017237	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5704	 5707	 0.002795	 0.009325	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5704	 76958	 0.00314	 0.012079	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5705	 5711	 0.010506	 0.033358	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5705	 76958	 0.002535	 0.009861	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5706	 7722	 0.019097	 0.049095	 0.01216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5706	 76958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5706	 76958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5707	 5711	 0.006004	 0.01722	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5708	 5711	 0.009658	 0.007643	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5709	 5710	 0.005005	 0.011621	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5709	 5711	 0.0066	 0.021252	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5711	 77428	 0.078552	 0.18048	 0.00274	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 5717	 0.016901	 0.096074	 0.00174	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5713	 5714	 0.020702	 0.11633	 0.00215	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5713	 5717	 0.026251	 0.1328	 0.00231	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5715	 5716	 0.004243	 0.02438	 0.00691	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5716	 7738	 0.006876	 0.035818	 0.00939	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5717	 5718	 0.037329	 0.12453	 0.00197	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5717	 77431	 0.060681	 0.17406	 0.00268	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5718	 7730	 0.045838	 0.11784	 0.00182	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5719	 5720	 0.000891	 0.003625	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5719	 5724	 0.001334	 0.008286	 0.00234	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5719	 5730	 0.001318	 0.008433	 0.00284	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5720	 5721	 0.000864	 0.003282	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 5724	 0.001055	 0.004147	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5722	 5724	 0.000877	 0.003411	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5722	 7384	 0.001052	 0.004281	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5723	 76959	 0.00768	 0.006078	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5724	 5725	 0.000844	 0.003379	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5724	 5736	 0.001235	 0.005991	 0.00137	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5724	 76959	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5724	 76959	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5725	 5749	 0.002055	 0.013239	 0.00347	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5725	 76960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5725	 76960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5726	 5751	 0.006952	 0.017681	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5726	 76962	 0.006222	 0.016124	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5727	 5729	 0.027101	 0.021448	 0.00027	 28.0	 28.0	 28.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76535	 5727	 0.020402	 0.032831	 0.00051	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5728	 5729	 0.006169	 0.012214	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5728	 76961	 0.009225	 0.022897	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5730	 76961	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5730	 76961	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76961	 5731	 0.003125	 0.007947	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5732	 5734	 0.005236	 0.01346	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76535	 5732	 0.005845	 0.018822	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 5734	 0.029771	 0.023561	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5734	 5735	 0.014786	 0.01159	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5734	 5737	 0.025043	 0.017739	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5736	 76962	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5736	 76962	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5738	 5741	 0.00132	 0.005186	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5738	 76963	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5738	 76963	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76963	 5739	 0.011629	 0.014436	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5740	 76964	 0.012516	 0.01645	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5741	 5744	 0.001475	 0.005139	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5741	 76964	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5741	 76964	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5742	 5755	 0.022066	 0.017462	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5742	 76965	 0.015018	 0.009723	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5743	 5744	 0.001245	 0.003389	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5743	 76965	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5743	 76965	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5744	 5760	 0.002722	 0.006843	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5744	 76966	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5744	 76966	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5745	 5764	 0.012773	 0.029654	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76535	 5745	 0.014233	 0.063422	 0.00108	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5745	 77015	 0.004942	 0.030384	 0.00055	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5746	 5771	 0.000646	 0.002284	 0.00051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5746	 76967	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5746	 76967	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5747	 5748	 0.003007	 0.010031	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 7394	 0.002007	 0.007807	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 76968	 0.0043	 0.012332	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5749	 5750	 0.001327	 0.003613	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5749	 5759	 0.001975	 0.007763	 0.00203	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5749	 76968	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5749	 76968	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5750	 5773	 0.001078	 0.002893	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5751	 5752	 0.005937	 0.014735	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5752	 5753	 0.013827	 0.012475	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5752	 5755	 0.003627	 0.012099	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5753	 5758	 0.00488	 0.009663	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76968	 5753	 0.005606	 0.011473	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5754	 5758	 0.010887	 0.016512	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5755	 5756	 0.005422	 0.004463	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5755	 76970	 0.009841	 0.022079	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76966	 5757	 0.019555	 0.015475	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5757	 76970	 0.020666	 0.016199	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5758	 76969	 0.003868	 0.00898	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76515	 5759	 0.002751	 0.010703	 0.00286	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5759	 76969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5759	 76969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5760	 5761	 0.001035	 0.003377	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5760	 76970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5760	 76970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76515	 5761	 0.001396	 0.005589	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5762	 5765	 0.015145	 0.011985	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5763	 5764	 0.009868	 0.007476	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5764	 5765	 0.001731	 0.01052	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76516	 5764	 0.001859	 0.017302	 0.00033	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 5766	 0.0029	 0.01399	 0.00025	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5766	 5767	 0.00864	 0.006246	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5766	 5768	 0.012266	 0.008867	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5766	 5814	 0.005737	 0.013317	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76486	 5766	 0.019887	 0.056435	 0.00089	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5769	 7397	 0.009883	 0.007821	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5770	 5772	 0.01606	 0.01271	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5771	 5773	 0.001002	 0.002796	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5771	 76971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5771	 76971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76971	 5772	 0.006994	 0.009102	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5773	 76972	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5773	 76972	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76971	 5774	 0.011213	 0.01889	 0.00027	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5774	 76973	 0.004225	 0.009808	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5775	 5776	 0.000377	 0.001482	 0.00039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5775	 7128	 0.000402	 0.00158	 0.00041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 5777	 0.000803	 0.002706	 0.00067	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 76973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5776	 76973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5777	 5779	 0.000567	 0.002401	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5777	 76974	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5777	 76974	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5778	 5787	 0.012907	 0.032694	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5778	 5837	 0.00252	 0.009805	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76974	 5778	 0.008527	 0.010208	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5779	 5782	 0.000414	 0.001657	 0.00042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5780	 5781	 0.014635	 0.009831	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 5786	 0.004836	 0.009575	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5782	 5788	 0.001704	 0.006695	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 5784	 0.000792	 0.002126	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 5790	 0.002154	 0.005537	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5784	 5785	 0.000963	 0.002586	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5784	 76975	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5784	 76975	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5785	 76976	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5785	 76976	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5786	 76977	 0.005463	 0.01118	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76975	 5787	 0.008732	 0.013377	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 76977	 0.006171	 0.012681	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5788	 76977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5788	 76977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5788	 76980	 0.003695	 0.014524	 0.0038	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5789	 5791	 0.002351	 0.007843	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76977	 5789	 0.001654	 0.006434	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5790	 5798	 0.001056	 0.002875	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 5792	 0.007974	 0.01832	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 5797	 0.002563	 0.013503	 0.00024	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	5792	 76995	 0.007708	 0.018252	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76972	 5793	 0.008071	 0.008877	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5794	 5995	 0.004683	 0.010871	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76969	 5794	 0.008639	 0.020056	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76971	 5794	 0.013982	 0.031976	 0.00078	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5795	 5995	 0.005818	 0.011519	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5795	 76978	 0.008645	 0.015598	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76970	 5796	 0.023934	 0.015495	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5797	 5802	 0.001911	 0.008421	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5797	 76978	 0.001718	 0.009651	 0.00018	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 5799	 0.000678	 0.001791	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 5800	 0.000483	 0.001296	 0.00029	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 76978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5799	 76978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5799	 76980	 0.002135	 0.008548	 0.00215	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5800	 5801	 0.000743	 0.002071	 0.00043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 76979	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5801	 76979	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5802	 5803	 0.001833	 0.00655	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5803	 5804	 0.00168	 0.006003	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 5812	 0.001513	 0.005297	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5805	 5806	 0.007292	 0.00577	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76979	 5805	 0.01086	 0.010668	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5807	 5810	 0.013414	 0.010616	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5808	 5877	 0.001669	 0.01099	 0.02126	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	5808	 7240	 0.001127	 0.013616	 0.0446	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76514	 5808	 7.1e-05	 0.000659	 0.00255	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5808	 76980	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76981	 5808	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5809	 76982	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5809	 76982	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76982	 5810	 0.006522	 0.012781	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5811	 5813	 0.001052	 0.003273	 0.00068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5811	 5818	 0.000625	 0.001882	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5812	 76983	 0.003915	 0.011229	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5813	 76983	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5813	 76983	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5814	 76984	 0.003284	 0.010956	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5815	 5817	 0.000598	 0.003502	 0.00095	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76980	 5815	 0.000996	 0.005981	 0.00181	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5815	 76984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5815	 76984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5816	 5817	 0.00031	 0.001761	 0.00051	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5816	 5953	 0.00089	 0.004471	 0.00116	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5816	 76985	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5816	 76985	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5818	 5819	 0.000751	 0.002531	 0.00063	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5819	 5821	 0.000967	 0.003258	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5820	 5823	 0.004702	 0.015685	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5820	 5824	 0.017681	 0.013562	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5820	 76986	 0.002417	 0.012569	 0.00027	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76485	 5821	 0.005541	 0.014644	 0.00343	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5821	 76986	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5821	 76986	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5822	 5830	 0.006433	 0.011608	 0.00017	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76986	 5822	 0.005993	 0.013594	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5823	 5895	 0.006206	 0.012287	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76985	 5825	 0.008897	 0.007041	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5826	 5954	 0.017711	 0.013882	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5827	 5829	 0.003193	 0.012422	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76486	 5827	 0.001808	 0.010278	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5828	 5831	 0.008383	 0.015355	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 5831	 0.004699	 0.010747	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5830	 5831	 0.006147	 0.011048	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5831	 5832	 0.002657	 0.01184	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76486	 5831	 0.004376	 0.023417	 0.00071	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5832	 5833	 0.004651	 0.010797	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5832	 5835	 0.005453	 0.015475	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 5834	 0.002973	 0.006901	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5834	 77013	 0.0083	 0.016267	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5835	 76987	 0.00633	 0.014696	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76485	 5836	 0.002807	 0.013842	 0.00374	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 76987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5836	 76987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5837	 5838	 0.007934	 0.008726	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 7152	 0.00278	 0.012246	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5838	 5842	 0.007545	 0.009916	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5839	 5845	 0.003713	 0.011176	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76976	 5839	 0.007652	 0.014996	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5840	 5841	 0.003596	 0.009243	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76976	 5840	 0.008424	 0.01087	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5841	 5858	 0.005624	 0.014457	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5842	 5843	 0.003616	 0.007599	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5843	 5844	 0.004579	 0.013781	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5843	 7160	 0.007592	 0.021774	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5844	 5845	 0.002747	 0.008437	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5844	 76992	 0.006388	 0.028467	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5846	 5848	 0.001212	 0.004853	 0.00122	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5846	 5860	 0.000742	 0.002971	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5846	 76988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5846	 76988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5847	 5848	 0.000639	 0.002639	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 5857	 0.001041	 0.004236	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5848	 6980	 0.001946	 0.013055	 0.00315	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5848	 7172	 0.001246	 0.004846	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5848	 76989	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5848	 76989	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5849	 5851	 0.00137	 0.00447	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5849	 7206	 0.002793	 0.010977	 0.00287	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76476	 5849	 0.004687	 0.020884	 0.00567	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5849	 76990	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5849	 76990	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5850	 7307	 0.006179	 0.009004	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76990	 5850	 0.013532	 0.010709	 0.00013	 33.0	 33.0	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5851	 76991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5851	 76991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5852	 7181	 0.004684	 0.012974	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76991	 5852	 0.006015	 0.018103	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5853	 5854	 0.013405	 0.012347	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5854	 76992	 0.007482	 0.019232	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5855	 5913	 0.017414	 0.013781	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76991	 5856	 0.014315	 0.024114	 0.00034	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76476	 5857	 0.002409	 0.012303	 0.00309	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 76992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5857	 76992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76988	 5858	 0.006972	 0.017921	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5858	 76996	 0.021931	 0.033243	 0.00069	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5859	 76993	 0.009479	 0.006974	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5860	 5862	 0.000943	 0.003669	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5860	 76993	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5860	 76993	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5861	 5864	 0.021137	 0.016727	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5861	 76994	 0.008226	 0.016286	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 5873	 0.000991	 0.003895	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 76994	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5862	 76994	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5863	 5913	 0.011151	 0.02012	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 76996	 0.00504	 0.010314	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5864	 5872	 0.005251	 0.009764	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5864	 76995	 0.00391	 0.008217	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5865	 5876	 0.006991	 0.016229	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76558	 5865	 0.003212	 0.00738	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5866	 76995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5866	 76995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76995	 5867	 0.010496	 0.006795	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5868	 5870	 0.012613	 0.009981	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5869	 5878	 0.003224	 0.012404	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76558	 5869	 0.003428	 0.015277	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5870	 5878	 0.009295	 0.018404	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5871	 5883	 0.02151	 0.013926	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5872	 76996	 0.003848	 0.009893	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5873	 5875	 0.000618	 0.00255	 0.0006	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5873	 76996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5873	 76996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5874	 5880	 0.009331	 0.015295	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76476	 5875	 0.000417	 0.004134	 0.00112	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5876	 76997	 0.003894	 0.01285	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5877	 76997	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5877	 76997	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5878	 5883	 0.00501	 0.017113	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5879	 5880	 0.014541	 0.014686	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5880	 5889	 0.00444	 0.01586	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76997	 5880	 0.003581	 0.024296	 0.00045	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5881	 5882	 0.002758	 0.010731	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76997	 5881	 0.003439	 0.016779	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5882	 5893	 0.001781	 0.006853	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5883	 5884	 0.007589	 0.012784	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5883	 5886	 0.002993	 0.011515	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76982	 5883	 0.014219	 0.040783	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76983	 5884	 0.0059	 0.010605	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5885	 5887	 0.003459	 0.021266	 0.00038	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5885	 5895	 0.006213	 0.014275	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5885	 5899	 0.005108	 0.012991	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5886	 5887	 0.003174	 0.009747	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5886	 5888	 0.012204	 0.009658	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5887	 5889	 0.001965	 0.006556	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5889	 5890	 0.002833	 0.007282	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5890	 5891	 0.006097	 0.012071	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5891	 5892	 0.003611	 0.008384	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76524	 5892	 0.0019	 0.009082	 0.0002	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	5893	 5894	 0.003048	 0.00936	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76524	 5894	 0.003713	 0.010143	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5895	 5896	 0.004011	 0.009498	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5896	 5897	 0.0041	 0.009708	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5897	 5898	 0.008087	 0.012389	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76987	 5897	 0.029183	 0.038355	 0.00053	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 5902	 0.004847	 0.012461	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5900	 76998	 0.017554	 0.013892	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5901	 76998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5901	 76998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5902	 5904	 0.00794	 0.014543	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5903	 5905	 0.002771	 0.009897	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76998	 5903	 0.003114	 0.013933	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5904	 5905	 0.006725	 0.015613	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5904	 5908	 0.018149	 0.014938	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5905	 5906	 0.002484	 0.007629	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5906	 5909	 0.004655	 0.011393	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5907	 5979	 0.015782	 0.01237	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76987	 5908	 0.011409	 0.020897	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5909	 5912	 0.003991	 0.012257	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76987	 5909	 0.016956	 0.043587	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5910	 5994	 0.004281	 0.011317	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76987	 5910	 0.003794	 0.01164	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5911	 5912	 0.007736	 0.015161	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5911	 5994	 0.005865	 0.015077	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5912	 5984	 0.004124	 0.013757	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5914	 5922	 0.010758	 0.024975	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76477	 5914	 0.002365	 0.005491	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5915	 5916	 0.001521	 0.006091	 0.00153	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5915	 7303	 0.001165	 0.004239	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5916	 5918	 0.001475	 0.005904	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5916	 76999	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5916	 76999	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76999	 5917	 0.012351	 0.009774	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76476	 5918	 0.001842	 0.008588	 0.00213	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5918	 77000	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5918	 77000	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77000	 5919	 0.003125	 0.006187	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5920	 5921	 0.008826	 0.00638	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5920	 5923	 0.004411	 0.008202	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77000	 5920	 0.006287	 0.014596	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5922	 5923	 0.002868	 0.006657	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76477	 5924	 0.021255	 0.049347	 0.00073	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5925	 5927	 0.017503	 0.013852	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5926	 77001	 0.005381	 0.013833	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5927	 5930	 0.017553	 0.026889	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5928	 5940	 0.005259	 0.018402	 0.0061	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5928	 8380	 0.005987	 0.03792	 0.01029	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5928	 77001	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5928	 77001	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5929	 5930	 0.004832	 0.011443	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77001	 5929	 0.005396	 0.017134	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5930	 5937	 0.010074	 0.025003	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77001	 5931	 0.002865	 0.016286	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5931	 77002	 0.003785	 0.016935	 0.00035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5932	 77002	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5932	 77002	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77001	 5933	 0.002915	 0.01553	 0.00027	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77002	 5933	 0.005245	 0.023111	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5934	 5935	 0.001956	 0.007832	 0.00197	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5934	 5940	 0.002732	 0.011118	 0.00271	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5935	 5940	 0.004646	 0.018907	 0.00461	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5935	 5997	 0.001332	 0.004489	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76980	 5935	 0.003383	 0.020303	 0.00615	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5935	 77003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5935	 77003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5936	 5937	 0.007534	 0.008287	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5936	 5938	 0.041703	 0.030683	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5937	 77004	 0.022151	 0.041188	 0.00096	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5939	 7788	 0.067073	 0.053081	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5940	 5942	 0.001338	 0.008029	 0.00243	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76473	 5940	 0.004275	 0.043561	 0.01123	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5940	 77004	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5940	 77004	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77004	 5941	 0.010566	 0.019064	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5942	 7789	 0.001426	 0.008556	 0.00259	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5943	 5944	 0.000837	 0.004802	 0.0016	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5943	 7822	 0.001205	 0.006639	 0.0024	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5943	 77005	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5943	 77005	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5944	 5961	 0.000877	 0.005224	 0.00137	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5945	 5946	 0.004176	 0.012826	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77004	 5945	 0.009984	 0.044487	 0.00076	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77005	 5946	 0.004858	 0.016594	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5947	 5949	 0.008902	 0.018217	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5947	 5952	 0.008653	 0.022243	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5947	 77015	 0.002304	 0.016839	 0.00031	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5948	 5949	 0.01677	 0.010857	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5949	 5950	 0.008348	 0.021459	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5950	 5951	 0.017411	 0.012586	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5950	 77010	 0.025232	 0.045069	 0.00067	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5952	 77007	 0.008126	 0.023307	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5953	 5955	 0.001184	 0.00543	 0.00139	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5954	 77006	 0.005464	 0.010817	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76485	 5955	 0.000689	 0.003519	 0.00089	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5955	 77006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5955	 77006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5956	 5959	 0.001581	 0.005424	 0.0013	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5956	 77007	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5956	 77007	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77007	 5957	 0.014194	 0.010443	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5958	 77008	 0.010583	 0.011301	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5959	 5960	 0.000849	 0.002279	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5959	 77008	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5959	 77008	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5960	 5963	 0.001131	 0.003154	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5960	 77009	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5960	 77009	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5961	 5963	 0.001521	 0.004404	 0.00106	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5961	 77010	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5961	 77010	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5961	 77450	 0.001789	 0.008343	 0.00207	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5962	 77011	 0.016175	 0.010472	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5963	 77011	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5963	 77011	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5964	 5965	 0.006079	 0.01488	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5964	 5966	 0.012341	 0.009674	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77009	 5964	 0.009305	 0.009398	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5965	 77012	 0.00826	 0.019174	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5967	 5968	 0.000646	 0.003423	 0.00114	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76485	 5967	 0.000219	 0.001401	 0.00047	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5968	 5969	 0.001493	 0.005675	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5968	 5971	 0.001784	 0.006461	 0.00139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	5968	 7835	 0.001748	 0.012361	 0.00339	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76485	 5968	 0.000813	 0.005049	 0.00142	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5969	 77012	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5969	 77012	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5969	 77450	 0.002018	 0.008782	 0.0025	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5970	 77013	 0.013505	 0.010585	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5971	 77013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5971	 77013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5972	 5973	 0.002283	 0.008157	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77012	 5972	 0.004957	 0.020259	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5973	 5974	 0.018338	 0.014512	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5973	 5975	 0.006846	 0.017598	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5973	 77452	 0.020787	 0.027321	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5975	 5976	 0.004105	 0.010439	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5976	 77460	 0.00569	 0.01321	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5977	 5978	 0.001478	 0.005774	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77013	 5977	 0.001812	 0.007188	 0.00021	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	5978	 5979	 0.003531	 0.011778	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5979	 5980	 0.011502	 0.012282	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5979	 5981	 0.016597	 0.013134	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5979	 5982	 0.016715	 0.021753	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	5979	 77460	 0.007597	 0.046708	 0.00084	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5982	 5983	 0.013811	 0.010161	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5982	 5994	 0.005728	 0.014216	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5984	 5985	 0.004951	 0.014049	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5985	 5989	 0.002312	 0.008993	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5985	 5992	 0.088593	 0.057357	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5986	 5990	 0.014076	 0.010356	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5987	 5990	 0.023948	 0.018952	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5988	 5990	 0.014372	 0.011266	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	5989	 77014	 0.007847	 0.023618	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5990	 7859	 0.00591	 0.015191	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 77014	 0.007677	 0.015046	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5993	 7863	 0.001067	 0.00282	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5993	 77014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5993	 77014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77002	 5996	 0.010092	 0.038826	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77003	 5996	 0.003202	 0.014266	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	5997	 77015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5997	 77015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5998	 6281	 0.005307	 0.020644	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5998	 6281	 0.005307	 0.020644	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5998	 7445	 0.018743	 0.072915	 0.00122	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5998	 7445	 0.018743	 0.072915	 0.00122	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5998	 9550	 0.00168	 0.015458	 0.00031	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5999	 6009	 0.000698	 0.001621	 2e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5999	 6014	 0.003043	 0.007064	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76500	 5999	 0.008317	 0.016113	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	5999	 77016	 0.003889	 0.003582	 6e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6000	 6007	 0.000751	 0.003054	 0.00074	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6001	 6003	 0.000391	 0.001049	 0.00024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6001	 77016	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6001	 77016	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6002	 6004	 0.000599	 0.003544	 7e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6002	 6012	 0.000597	 0.00233	 5e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6003	 6007	 0.001104	 0.002919	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6003	 6011	 0.000795	 0.002102	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6003	 77017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6003	 77017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6004	 6280	 0.00107	 0.007733	 0.00015	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6004	 6281	 0.000824	 0.003207	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6004	 6281	 0.000824	 0.003207	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76482	 6004	 0.015054	 0.041125	 0.0007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76884	 6005	 0.004893	 0.003537	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 6015	 0.001465	 0.003367	 5e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 77018	 0.002332	 0.004618	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6007	 6017	 0.000244	 0.000836	 0.0002	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6007	 77018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6007	 77018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6008	 6280	 0.000527	 0.002092	 6e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6008	 77020	 0.001597	 0.005586	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6009	 6010	 0.00132	 0.002828	 5e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6010	 6026	 0.002161	 0.0038	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77018	 6010	 0.001022	 0.002439	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6011	 77019	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6011	 77019	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77019	 6012	 0.000438	 0.002463	 5e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6013	 6014	 0.002418	 0.004363	 6e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77016	 6013	 0.001814	 0.003374	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 6032	 0.000609	 0.003465	 6e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6015	 6019	 0.001848	 0.004376	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6015	 77021	 0.005395	 0.00427	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6016	 6036	 0.000775	 0.002162	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6016	 77020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6016	 77020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6017	 6018	 0.000221	 0.000641	 0.00015	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6018	 6021	 0.000161	 0.000502	 0.0001	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76482	 6019	 0.000826	 0.003164	 9e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77017	 6020	 0.005882	 0.004512	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6021	 6022	 0.000175	 0.00061	 0.00014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6021	 77021	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6021	 77021	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6022	 6024	 0.00024	 0.000848	 0.00019	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6023	 6025	 0.000874	 0.002223	 4e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77017	 6023	 0.001324	 0.003798	 6e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6025	 6030	 0.002816	 0.007238	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6026	 6027	 0.001402	 0.002531	 4e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6027	 6029	 0.001226	 0.003517	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 6030	 0.002416	 0.004013	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6029	 6031	 0.000592	 0.003639	 8e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 77022	 0.002631	 0.006973	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6031	 77023	 0.000595	 0.004083	 7e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6031	 77024	 0.000814	 0.005004	 9e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6032	 6033	 0.001183	 0.002746	 4e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6032	 6040	 0.000836	 0.003588	 7e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6033	 6035	 0.001375	 0.003536	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6034	 6036	 0.00062	 0.00173	 0.00036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6034	 6064	 0.000497	 0.001289	 0.00031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6034	 77022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6034	 77022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6035	 77026	 0.001477	 0.005768	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6037	 6044	 0.000302	 0.001037	 0.00025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6037	 77023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6037	 77023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6038	 6040	 0.002859	 0.005158	 7e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6038	 6042	 0.004011	 0.002597	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77023	 6039	 0.001382	 0.003208	 5e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6039	 77027	 0.000999	 0.003171	 6e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6040	 77025	 0.000839	 0.003718	 0.00011	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6041	 6055	 0.000149	 0.000904	 0.00023	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6041	 77024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6041	 77024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6043	 6045	 0.005173	 0.003349	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6044	 6059	 0.0003	 0.001001	 0.00025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6045	 77025	 0.002224	 0.004359	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6046	 6047	 0.000155	 0.000824	 0.00019	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6046	 77029	 0.000263	 0.001371	 0.00036	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6047	 6056	 0.000243	 0.001151	 0.00028	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6048	 77039	 0.001889	 0.004284	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6049	 6060	 0.000252	 0.000866	 0.00021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6049	 77025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6049	 77025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6050	 6052	 0.005469	 0.004328	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6051	 6053	 0.00079	 0.002821	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6051	 6053	 0.00079	 0.002821	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6051	 77030	 0.0013	 0.003988	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6051	 77030	 0.0013	 0.003988	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6052	 77026	 0.001107	 0.002265	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6053	 77041	 0.000481	 0.004657	 9e-05	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6054	 6056	 0.000209	 0.000821	 0.00021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6054	 6060	 0.000285	 0.001139	 0.00029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6054	 77026	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6054	 77026	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6054	 77029	 0.000523	 0.003311	 0.0009	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6055	 6057	 0.000228	 0.001208	 0.0004	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 77027	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6056	 77027	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6057	 77033	 0.000436	 0.00248	 0.00072	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 6066	 0.00051	 0.002719	 5e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77026	 6058	 0.000515	 0.003439	 8e-05	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6059	 6061	 0.000394	 0.001073	 0.00024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6059	 77028	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6059	 77028	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6061	 6065	 0.000356	 0.001032	 0.00025	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6062	 77035	 0.003459	 0.004547	 6e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6063	 77029	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77030	 6063	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6063	 77032	 4.4e-05	 0.000474	 0.00094	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6063	 77032	 4.4e-05	 0.000474	 0.00094	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6063	 77627	 0.001928	 0.019996	 0.04307	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6063	 77627	 0.001928	 0.019996	 0.04307	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6064	 6068	 0.000683	 0.001774	 0.00043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6065	 77031	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6065	 77031	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6065	 77033	 0.00024	 0.000935	 0.00025	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6066	 77036	 0.001083	 0.004771	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6067	 6077	 2e-05	 0.000205	 0.00322	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6067	 6077	 2e-05	 0.000205	 0.00322	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6067	 8513	 9.7e-05	 0.002304	 0.04171	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6067	 77032	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6068	 6076	 0.000494	 0.002009	 0.00049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6068	 77035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6068	 77035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77034	 6069	 0.001117	 0.002555	 6e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77035	 6070	 0.007445	 0.005892	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 77045	 0.00235	 0.004652	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6072	 6074	 0.003016	 0.00591	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6072	 77036	 0.001535	 0.004357	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6073	 6075	 0.001047	 0.004074	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6073	 6080	 0.005798	 0.005437	 8e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77031	 6073	 0.001014	 0.003902	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6075	 77038	 0.001405	 0.002953	 5e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6076	 6082	 0.000197	 0.000834	 0.00019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6076	 77036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6076	 77036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6077	 6091	 2e-05	 0.000202	 0.00328	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6077	 6091	 2e-05	 0.000202	 0.00328	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6077	 77037	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6078	 6084	 0.001867	 0.003259	 5e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77038	 6079	 0.001692	 0.003317	 5e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6081	 6093	 0.000179	 0.000904	 0.00025	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6081	 6100	 0.000221	 0.001054	 0.00031	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6082	 6086	 0.000157	 0.000813	 0.0002	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6082	 6090	 0.000403	 0.001615	 0.00041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6082	 77039	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6082	 77039	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77038	 6083	 0.002904	 0.00674	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 6088	 0.001255	 0.003225	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6085	 6087	 0.001642	 0.004075	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6085	 77043	 0.004004	 0.010293	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6085	 77044	 0.001431	 0.003709	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6086	 6090	 9e-05	 0.000769	 0.00022	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77037	 6086	 0.000222	 0.002332	 0.00131	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	6086	 77040	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6086	 77040	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6087	 77043	 0.002394	 0.0049	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6088	 6092	 0.000707	 0.003152	 5e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6088	 6094	 0.002703	 0.005531	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77040	 6088	 0.000914	 0.005137	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6089	 77043	 0.002494	 0.002767	 5e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6090	 6096	 0.000174	 0.000822	 0.0002	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6090	 77041	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6090	 77041	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6090	 77042	 0.00093	 0.003533	 0.00099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6091	 77042	 9.7e-05	 0.007789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6092	 6098	 0.000694	 0.003094	 5e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77042	 6093	 0.000382	 0.002705	 0.00074	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6093	 77044	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6093	 77044	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6095	 6108	 0.001612	 0.003817	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77043	 6095	 0.001601	 0.00635	 0.00018	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6095	 77047	 0.00271	 0.005311	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6096	 6103	 0.000204	 0.000828	 0.0002	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6096	 77045	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6096	 77045	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6097	 6099	 0.002021	 0.003371	 5e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6098	 6105	 0.000608	 0.003076	 5e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6099	 6106	 0.00089	 0.003638	 7e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77043	 6099	 0.000869	 0.004783	 0.00011	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 6101	 0.000127	 0.00096	 0.00027	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 6102	 0.000184	 0.000925	 0.00024	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 77046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6100	 77046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76488	 6101	 0.000388	 0.002746	 0.00075	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77042	 6102	 0.00046	 0.003193	 0.00091	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6102	 77047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6102	 77047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6103	 6109	 0.000204	 0.000841	 0.0002	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6103	 77048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6103	 77048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77047	 6104	 0.001232	 0.004066	 7e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 77049	 0.001011	 0.003933	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6105	 6112	 0.000815	 0.002851	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77048	 6105	 0.001672	 0.005579	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6106	 6107	 0.004518	 0.003575	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6106	 6110	 0.001068	 0.003275	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 6111	 0.002921	 0.002869	 5e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 6119	 0.003139	 0.00807	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77042	 6109	 0.000469	 0.001698	 0.00036	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6110	 6117	 0.001634	 0.00433	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6110	 6119	 0.001745	 0.004271	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 6116	 0.00139	 0.005563	 0.00012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 6118	 0.001289	 0.003314	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77046	 6113	 0.003208	 0.008245	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6113	 77050	 0.001894	 0.004352	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 6125	 0.001925	 0.004949	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6115	 6122	 0.000309	 0.001009	 0.00027	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6115	 77049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6115	 77049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77043	 6116	 0.000616	 0.003866	 8e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77049	 6117	 0.001707	 0.003923	 6e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6118	 6123	 0.000415	 0.00236	 7e-05	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6118	 77051	 0.000984	 0.006051	 0.00011	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6119	 6126	 0.001241	 0.005528	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 6122	 0.00039	 0.00103	 0.00024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76488	 6120	 0.000843	 0.002814	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 77050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6120	 77050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6121	 9611	 0.000879	 0.00798	 0.0026	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77042	 6121	 0.000164	 0.001099	 0.00034	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6121	 77051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6121	 77051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6122	 6130	 0.00041	 0.001144	 0.00024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6122	 77052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6122	 77052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6123	 6129	 0.00053	 0.002758	 6e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 6126	 0.003469	 0.003504	 5e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77052	 6124	 0.001044	 0.003917	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 6131	 0.000737	 0.00606	 0.00012	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 9632	 0.004259	 0.016568	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 9632	 0.004259	 0.016568	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77043	 6125	 0.002791	 0.014202	 0.00032	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6126	 77058	 0.003143	 0.006223	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77051	 6127	 0.00127	 0.003006	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6128	 77054	 0.000265	 0.00108	 0.00026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6129	 6135	 0.000826	 0.003176	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6130	 77056	 0.000368	 0.001086	 0.00025	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6131	 6144	 0.001863	 0.005343	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6131	 6150	 0.002621	 0.005946	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6132	 77053	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6133	 6135	 0.002495	 0.005732	 9e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77043	 6133	 0.002796	 0.009784	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77043	 6133	 0.002796	 0.009784	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 77059	 0.00581	 0.021795	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 77065	 0.004286	 0.011019	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 77067	 0.017542	 0.017912	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6134	 9599	 0.000544	 0.00531	 0.01849	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77053	 6134	 4.2e-05	 0.000429	 0.00083	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6134	 77056	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77057	 6134	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6135	 6141	 0.001289	 0.003279	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6136	 6137	 0.000237	 0.000857	 0.00018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77056	 6136	 0.000295	 0.000993	 0.00025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6137	 77058	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6137	 77058	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6138	 6149	 0.000664	 0.00167	 0.00043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6138	 77059	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6138	 77059	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77055	 6139	 0.001119	 0.002875	 4e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6140	 6794	 0.00078	 0.002964	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77054	 6140	 0.000301	 0.001272	 0.00029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77056	 6140	 0.000361	 0.00187	 0.00046	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6140	 77060	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6140	 77060	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6141	 6144	 0.001671	 0.004251	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 77063	 0.000639	 0.003117	 5e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6142	 6143	 0.000452	 0.001992	 3e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77057	 6142	 0.000553	 0.002765	 5e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 6153	 0.000819	 0.003152	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77055	 6143	 0.001048	 0.005268	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 77061	 0.001546	 0.003916	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6145	 6146	 0.000218	 0.000749	 0.00018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6145	 6148	 0.000309	 0.000802	 0.00019	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6145	 77061	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6145	 77061	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6146	 6158	 0.000257	 0.001012	 0.00026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6146	 77062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6146	 77062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6147	 6152	 0.000317	 0.000838	 0.0002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6147	 77063	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6147	 77063	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6148	 6149	 0.000257	 0.000758	 0.00018	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6148	 77064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6148	 77064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6150	 6154	 0.001097	 0.003838	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6164	 0.004618	 0.007372	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77060	 6151	 0.00135	 0.004456	 7e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6152	 6157	 0.000248	 0.000829	 0.00021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6152	 77065	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6152	 77065	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6153	 6155	 0.002395	 0.003148	 4e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6154	 77067	 0.00171	 0.003131	 5e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6155	 6156	 0.002979	 0.002335	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6157	 6163	 0.000311	 0.0008	 0.0002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6158	 6159	 0.000218	 0.00077	 0.00017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6158	 77066	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6158	 77066	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6159	 6168	 0.000277	 0.000951	 0.00023	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6160	 6165	 0.000359	 0.001002	 0.00021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6160	 77067	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6160	 77067	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77066	 6161	 0.001238	 0.002534	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77066	 6162	 0.001684	 0.003447	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6163	 6165	 0.000263	 0.001863	 0.00051	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6163	 6167	 0.000207	 0.000829	 0.00021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6165	 6169	 0.00016	 0.000938	 0.00026	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6165	 9654	 0.000413	 0.006067	 0.00186	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 77070	 0.002637	 0.004442	 6e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6167	 6171	 0.000225	 0.000882	 0.00023	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6168	 6172	 0.00035	 0.0014	 0.00035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6168	 77068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6168	 77068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6169	 6178	 0.000319	 0.001523	 0.00044	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77068	 6170	 0.001417	 0.003255	 5e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6171	 6175	 0.000208	 0.000833	 0.00021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6171	 77069	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6171	 77069	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6172	 6174	 0.000261	 0.001064	 0.00026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 77070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6172	 77070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77069	 6173	 0.010566	 0.007774	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6173	 77072	 0.00131	 0.003206	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 6182	 0.000258	 0.001251	 0.00029	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 77071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6174	 77071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6175	 6179	 0.000177	 0.00081	 0.00021	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6176	 6177	 0.001588	 0.002675	 4e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77071	 6176	 0.001416	 0.003288	 5e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 77074	 0.002204	 0.003848	 6e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6178	 6189	 0.000619	 0.002431	 0.00064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6178	 77072	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6178	 77072	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6179	 6183	 0.000182	 0.000727	 0.00018	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6180	 6190	 0.000129	 0.001175	 0.00038	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6180	 6243	 0.000334	 0.003588	 0.00093	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6181	 6185	 0.001297	 0.003334	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77072	 6181	 0.000822	 0.002935	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6181	 77073	 0.002403	 0.007378	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6182	 6190	 0.000222	 0.00102	 0.00026	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 6191	 0.000463	 0.00151	 0.0004	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 77073	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6183	 77073	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6184	 6186	 0.000197	 0.000776	 0.0002	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 6190	 0.000251	 0.000977	 0.00026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6185	 77075	 0.003635	 0.003409	 5e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 6188	 0.000356	 0.001032	 0.00025	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 6192	 0.000331	 0.00089	 0.0002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 6245	 0.001198	 0.003217	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 77074	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6186	 77074	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77073	 6187	 0.00148	 0.002643	 4e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6188	 6218	 0.000388	 0.001112	 0.00027	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6189	 6193	 0.000245	 0.000842	 0.0002	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6189	 77075	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6189	 77075	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6190	 6196	 0.000363	 0.000913	 0.00024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76582	 6190	 0.001366	 0.00361	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6191	 6195	 0.000402	 0.001121	 0.00024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6191	 6218	 0.000908	 0.002334	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6192	 6220	 0.000435	 0.001168	 0.00026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6193	 6206	 0.000901	 0.002937	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6193	 77076	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6193	 77076	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6194	 6196	 0.000494	 0.001378	 0.00029	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76582	 6194	 0.00076	 0.001954	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6195	 6200	 0.000382	 0.001026	 0.00023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77076	 6197	 0.001271	 0.003155	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6198	 6201	 0.000359	 0.000963	 0.00022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6198	 6245	 0.000554	 0.001393	 0.00036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6199	 6204	 0.002067	 0.00162	 2e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6199	 6205	 0.00341	 0.002673	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6200	 6218	 0.000346	 0.000964	 0.0002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6201	 6222	 0.000716	 0.001996	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6201	 77077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6201	 77077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6202	 6207	 0.000398	 0.00134	 0.00033	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6202	 77078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6202	 77078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77077	 6203	 0.004252	 0.003365	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6204	 77079	 0.001491	 0.002952	 4e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6205	 77083	 0.005831	 0.004215	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6206	 6209	 0.000263	 0.000682	 0.00017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6206	 6254	 0.000629	 0.001582	 0.00041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6206	 77079	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6206	 77079	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6207	 6213	 0.000457	 0.001568	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6208	 6210	 0.003474	 0.0032	 5e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6208	 77092	 0.005323	 0.005854	 8e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6209	 6211	 0.000408	 0.001078	 0.00025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6210	 6227	 0.004598	 0.005008	 7e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6210	 77081	 0.002086	 0.004941	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6211	 6215	 0.000368	 0.001002	 0.00022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 77081	 0.002001	 0.003194	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6213	 6221	 0.000223	 0.001186	 0.00028	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6213	 6233	 0.000739	 0.004331	 0.00118	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6213	 77080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6213	 77080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6214	 6229	 0.000441	 0.001187	 0.00033	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76582	 6214	 0.000979	 0.003919	 0.00099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6214	 77081	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6214	 77081	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6214	 77095	 0.002257	 0.008171	 0.00175	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6215	 6217	 0.000329	 0.000763	 0.00023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6215	 77082	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6215	 77082	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77081	 6216	 0.007379	 0.00584	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6217	 6229	 0.000392	 0.001066	 0.00023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6218	 6220	 0.000323	 0.000854	 0.0002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77082	 6219	 0.001199	 0.003677	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 77086	 0.001174	 0.006675	 0.00012	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 77089	 0.005088	 0.006316	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 77083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6220	 77083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6221	 6226	 0.000137	 0.000801	 0.00022	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6221	 77084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6221	 77084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6222	 6254	 0.000411	 0.001033	 0.00027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 77085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6222	 77085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6223	 77089	 0.005873	 0.004604	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 6227	 0.005021	 0.003973	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77085	 6224	 0.004722	 0.003737	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6225	 6226	 0.000102	 0.000596	 0.00016	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6225	 6228	 9.6e-05	 0.000724	 0.0002	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6225	 77086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6225	 77086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6228	 6232	 9e-05	 0.000726	 0.0002	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6228	 8748	 0.000481	 0.007344	 0.00237	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6228	 77087	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6228	 77087	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6229	 77088	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6229	 77088	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6230	 6255	 0.005037	 0.003986	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77088	 6231	 0.00447	 0.003538	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6232	 6236	 0.000105	 0.000751	 0.00023	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6233	 6235	 0.000205	 0.000822	 0.00021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6233	 77089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6233	 77089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6234	 6235	 0.000503	 0.00164	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6234	 6238	 0.000305	 0.001047	 0.00025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6235	 77090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6235	 77090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6236	 6241	 0.000132	 0.000988	 0.00024	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77090	 6237	 0.004521	 0.002927	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6238	 6242	 0.00024	 0.000977	 0.00024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6238	 77091	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6238	 77091	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77091	 6239	 0.003981	 0.003151	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77090	 6240	 0.00215	 0.004399	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 6244	 0.000112	 0.000748	 0.00023	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6242	 6248	 0.000309	 0.001235	 0.00031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76484	 6243	 0.000149	 0.001546	 0.00048	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 6248	 0.000352	 0.001385	 0.00036	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 6249	 0.000336	 0.001171	 0.00027	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76582	 6245	 0.000479	 0.001882	 0.00049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6245	 77092	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6245	 77092	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6246	 77093	 0.002075	 0.002946	 5e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6247	 77093	 0.004149	 0.008214	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6248	 77093	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6248	 77093	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6248	 77095	 0.000287	 0.001148	 0.00029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6249	 77095	 0.000527	 0.001776	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6250	 77096	 0.000706	 0.003146	 5e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 8305	 0.000543	 0.00596	 0.05789	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 77094	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6252	 6257	 0.000399	 0.001155	 0.00028	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77095	 6252	 0.000238	 0.000818	 0.0002	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77096	 6253	 0.002725	 0.005576	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77090	 6255	 0.001544	 0.003548	 5e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6256	 6260	 0.00185	 0.004904	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6256	 6278	 0.006174	 0.004886	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6256	 77097	 0.000466	 0.002371	 5e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6257	 77097	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6257	 77097	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77097	 6258	 0.001515	 0.003852	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6259	 6260	 0.002824	 0.002235	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6260	 6261	 0.001737	 0.003438	 5e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6262	 6263	 0.004473	 0.003389	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6262	 6265	 0.002108	 0.004893	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77094	 6264	 0.0002	 0.001828	 0.00352	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6264	 77098	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77099	 6264	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6265	 6266	 0.004008	 0.002595	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77099	 6265	 0.000501	 0.003438	 6e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77099	 6267	 0.002179	 0.004315	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6268	 6269	 0.006925	 0.005428	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77099	 6268	 0.002717	 0.005559	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6270	 6271	 0.000176	 0.000902	 0.00025	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77098	 6270	 0.000654	 0.002701	 0.00064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6270	 77100	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6270	 77100	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6271	 6275	 0.000386	 0.001019	 0.00024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6271	 77101	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6271	 77101	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6272	 6273	 0.009503	 0.007449	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77100	 6272	 0.002008	 0.003531	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76614	 6274	 0.002907	 0.011308	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77101	 6274	 0.000911	 0.003545	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 6276	 9.1e-05	 0.000688	 0.00019	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77098	 6275	 0.000931	 0.00452	 0.00103	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6276	 6277	 0.000253	 0.00179	 0.00049	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6277	 77102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6277	 77102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77020	 6279	 0.002412	 0.004776	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6282	 77103	 0.013092	 0.009632	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6283	 77103	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6283	 77103	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6284	 77104	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6284	 77104	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6285	 6287	 0.010195	 0.007991	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6285	 6288	 0.00127	 0.006769	 0.00012	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77103	 6285	 0.001664	 0.007372	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6286	 6289	 0.01182	 0.007652	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6286	 6291	 0.005054	 0.01686	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77103	 6286	 0.004386	 0.019323	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6288	 77105	 0.001285	 0.006844	 0.00012	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	6290	 6294	 0.000751	 0.002213	 0.00051	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6290	 77105	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6290	 77105	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6291	 6292	 0.003977	 0.010113	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6292	 77106	 0.018403	 0.024187	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77105	 6293	 0.011935	 0.008454	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6294	 6295	 0.000716	 0.002495	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6295	 77106	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6295	 77106	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6296	 77107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6296	 77107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6297	 6298	 0.008085	 0.018771	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6297	 6299	 0.003035	 0.010124	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77107	 6297	 0.002013	 0.009663	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6298	 6300	 0.004995	 0.011828	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6299	 6300	 0.003059	 0.011475	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6300	 6301	 0.003961	 0.010032	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6300	 6310	 0.015963	 0.049022	 0.00092	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6301	 6303	 0.012839	 0.025419	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6301	 6306	 0.014723	 0.036543	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6302	 6337	 0.012307	 0.030124	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76566	 6302	 0.00557	 0.024821	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6303	 6337	 0.023784	 0.036435	 0.00051	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77104	 6303	 0.012759	 0.036595	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76543	 6304	 0.004415	 0.017354	 0.00454	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76530	 6305	 0.00492	 0.016576	 0.00412	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6306	 77108	 0.016334	 0.040542	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6307	 6340	 0.002533	 0.011095	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76531	 6307	 0.00155	 0.008708	 0.00016	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76531	 6308	 0.010994	 0.011566	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76530	 6309	 0.001593	 0.006261	 0.00164	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6309	 77108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6309	 77108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6310	 6340	 0.003951	 0.013834	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77108	 6310	 0.007014	 0.017838	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6311	 6312	 0.004217	 0.006731	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77108	 6311	 0.005741	 0.011367	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6312	 6313	 0.004137	 0.008107	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76754	 6313	 0.00562	 0.013047	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76530	 6314	 0.00134	 0.004597	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76544	 6315	 0.006091	 0.014908	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6316	 6323	 0.069557	 0.053355	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6317	 6318	 0.008151	 0.020954	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6318	 6323	 0.015387	 0.039555	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6319	 6320	 0.002075	 0.006768	 0.0018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6319	 6329	 0.005255	 0.02104	 0.0053	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6319	 77109	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6319	 77109	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6320	 77110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6320	 77110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6321	 6323	 0.018971	 0.01487	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6322	 6324	 0.019791	 0.012813	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77109	 6322	 0.007329	 0.011698	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77110	 6323	 0.005249	 0.020193	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6325	 6326	 0.097287	 0.097313	 0.00131	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77109	 6325	 0.049508	 0.11724	 0.00214	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6326	 6327	 0.020556	 0.06306	 0.00171	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6326	 6662	 0.018524	 0.063277	 0.00138	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6326	 6663	 0.017353	 0.06676	 0.00114	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76461	 6326	 0.059245	 0.19766	 0.00313	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76461	 6327	 0.025909	 0.090715	 0.00251	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6328	 6668	 0.016799	 0.12167	 0.00306	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76461	 6328	 0.005352	 0.038515	 0.00126	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76460	 6329	 0.007083	 0.032493	 0.00832	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6329	 77111	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6329	 77111	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77111	 6330	 0.086648	 0.062639	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6331	 6332	 0.066493	 0.052121	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77111	 6332	 0.16331	 0.12802	 0.00164	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76544	 6333	 0.022751	 0.065252	 0.001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6334	 6335	 0.02147	 0.016991	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76566	 6334	 0.010906	 0.03207	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6336	 6341	 0.013948	 0.03303	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6336	 77112	 0.023653	 0.067841	 0.00104	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6337	 6341	 0.011812	 0.03004	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6338	 77112	 0.094569	 0.074842	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76460	 6339	 0.017142	 0.078659	 0.02016	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76543	 6339	 0.007903	 0.050913	 0.01335	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6339	 77112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6339	 77112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6342	 77114	 0.013065	 0.01034	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6343	 6347	 0.000266	 0.002086	 0.00095	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6343	 6348	 0.000201	 0.001576	 0.00072	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6344	 6351	 0.001481	 0.009107	 0.00016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6344	 6414	 0.018085	 0.013701	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6344	 77115	 0.001616	 0.009082	 0.00017	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6345	 6355	 0.000364	 0.003557	 0.001	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6345	 6413	 0.000692	 0.004642	 0.00112	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6345	 77113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6345	 77113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6346	 6348	 0.000151	 0.001093	 0.00059	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6346	 6413	 0.000298	 0.002258	 0.00111	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6347	 6350	 0.000172	 0.002403	 0.00081	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6347	 77114	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6347	 77114	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77114	 6349	 0.00774	 0.006125	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6350	 6406	 0.000193	 0.001948	 0.00057	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6350	 77115	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6350	 77115	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6350	 77121	 0.000323	 0.005283	 0.00261	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6351	 77118	 0.002072	 0.012736	 0.00023	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6352	 6355	 0.000269	 0.002502	 0.00078	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6352	 6359	 0.00017	 0.00163	 0.00047	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6353	 77128	 0.016053	 0.010393	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76770	 6354	 0.010866	 0.053916	 0.00129	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77113	 6354	 0.003572	 0.015915	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 77132	 0.014792	 0.033982	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6355	 77116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6355	 77116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77116	 6356	 0.00433	 0.010254	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6356	 77128	 0.00785	 0.020344	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77115	 6357	 0.009397	 0.007366	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6358	 6375	 0.002344	 0.011438	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6358	 6407	 0.002399	 0.009231	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6359	 6406	 0.000149	 0.001385	 0.00043	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6360	 6413	 0.000578	 0.004925	 0.00123	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6360	 77117	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6360	 77117	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6361	 6380	 0.025792	 0.016697	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6361	 77132	 0.028198	 0.020746	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6362	 6397	 0.054435	 0.042669	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6362	 77118	 0.005141	 0.01276	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6363	 77118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6363	 77118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6363	 77121	 0.001137	 0.004553	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6364	 6402	 0.006496	 0.02655	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6364	 77127	 0.003115	 0.013723	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6365	 6371	 0.001821	 0.008978	 0.00243	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6365	 6405	 0.00091	 0.004647	 0.00117	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6365	 77119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6365	 77119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77119	 6366	 0.015019	 0.01105	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6367	 6368	 0.001466	 0.011291	 0.00022	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6367	 6370	 0.01863	 0.014744	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6367	 77127	 0.001488	 0.013322	 0.00028	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6368	 77120	 0.001631	 0.011781	 0.00022	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6369	 6405	 0.001109	 0.005573	 0.00145	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6369	 6415	 0.001391	 0.006858	 0.00185	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6369	 77120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6369	 77120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6371	 6386	 0.00188	 0.009955	 0.00252	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6372	 6402	 0.006865	 0.030078	 0.00065	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6372	 77130	 0.01562	 0.078536	 0.00213	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6373	 77131	 0.094458	 0.094738	 0.00153	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6374	 77122	 0.017641	 0.025705	 0.00058	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6375	 77122	 0.003102	 0.015784	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6376	 6536	 0.001493	 0.02384	 0.24129	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6376	 77121	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6377	 6378	 0.001741	 0.006971	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77121	 6377	 0.001141	 0.004337	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6378	 6403	 0.002849	 0.011196	 0.00293	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6379	 6382	 0.022744	 0.10135	 0.00172	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6379	 77133	 0.014467	 0.056498	 0.00125	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77117	 6381	 0.12272	 0.088721	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6383	 6385	 0.16947	 0.13413	 0.00169	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6385	 6388	 0.056161	 0.14438	 0.00223	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6386	 6387	 0.002672	 0.015133	 0.00375	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6387	 6389	 0.005927	 0.032889	 0.01	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6388	 77133	 0.041824	 0.12831	 0.00348	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6389	 77123	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6389	 77123	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77123	 6390	 0.028148	 0.084724	 0.00166	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6390	 77129	 0.0251	 0.087828	 0.00182	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6391	 6392	 0.00575	 0.032688	 0.00059	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6391	 6396	 0.006324	 0.03888	 0.0007	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6392	 6393	 0.008383	 0.040445	 0.00071	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6392	 77124	 0.017714	 0.078934	 0.00134	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6393	 77131	 0.018379	 0.081408	 0.00186	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77118	 6394	 0.022563	 0.015982	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77122	 6395	 0.015379	 0.032833	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77118	 6396	 0.005694	 0.035753	 0.00078	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77118	 6398	 0.076012	 0.12678	 0.00184	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6399	 6400	 0.006005	 0.02404	 0.00606	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6399	 6412	 0.008236	 0.032975	 0.00831	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6399	 77124	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6399	 77124	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6400	 6401	 0.006107	 0.022216	 0.0068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6400	 77125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6400	 77125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6403	 6415	 0.00563	 0.02254	 0.00568	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6403	 77126	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6403	 77126	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6404	 6408	 0.015324	 0.028493	 0.00067	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77122	 6404	 0.030351	 0.080233	 0.00146	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6405	 77127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6405	 77127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6406	 77128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6406	 77128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77115	 6407	 0.003217	 0.012516	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77115	 6407	 0.003217	 0.012516	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77122	 6407	 0.001981	 0.014254	 0.00047	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77126	 6408	 0.016057	 0.053565	 0.00085	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6409	 6411	 0.008623	 0.038426	 0.01044	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6409	 6676	 0.008095	 0.040673	 0.01059	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6409	 77129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6409	 77129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6410	 6412	 0.002083	 0.013621	 0.00346	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6410	 6531	 0.007935	 0.080873	 0.02085	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77121	 6410	 0.007121	 0.061086	 0.01739	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6411	 77130	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6411	 77130	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6412	 77131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6412	 77131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77121	 6413	 0.000807	 0.011471	 0.00603	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6413	 77132	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6413	 77132	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6415	 77133	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6415	 77133	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6416	 6420	 0.007179	 0.013148	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 6433	 0.028582	 0.02262	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 6434	 0.006069	 0.015601	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 77158	 0.028038	 0.072074	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6417	 6418	 0.01576	 0.011163	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6417	 6421	 0.006021	 0.006429	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6417	 77155	 0.006246	 0.017301	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6419	 6423	 0.000694	 0.002513	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6419	 6519	 0.00171	 0.006499	 0.00182	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6419	 6523	 0.000641	 0.002435	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6419	 77134	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6419	 77134	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6420	 6421	 0.004243	 0.0084	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6420	 6426	 0.010479	 0.007939	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6420	 6435	 0.016563	 0.012186	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6421	 6422	 0.005828	 0.00595	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6422	 77135	 0.004191	 0.006214	 9e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6423	 6427	 0.000588	 0.001916	 0.00051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6423	 77135	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6423	 77135	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77134	 6424	 0.018545	 0.014676	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6425	 6430	 0.001096	 0.003692	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6425	 77136	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 77136	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6425	 77157	 0.001831	 0.00666	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6426	 77137	 0.006045	 0.007867	 0.00011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6427	 6428	 0.000445	 0.001276	 0.00031	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6427	 77137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6427	 77137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6428	 6436	 0.000408	 0.001079	 0.00025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6429	 77138	 0.011167	 0.008073	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6430	 6442	 0.000916	 0.003784	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6430	 77138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6430	 77138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77138	 6431	 0.004834	 0.006862	 0.00011	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6431	 77139	 0.00693	 0.011674	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6432	 77139	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6432	 77139	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6432	 77157	 0.002322	 0.009126	 0.00239	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6433	 6437	 0.01122	 0.00888	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6434	 6439	 0.003507	 0.008882	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6434	 77140	 0.002466	 0.011433	 0.00024	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6435	 77141	 0.019974	 0.015807	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6436	 6441	 0.000605	 0.001598	 0.00037	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6438	 6457	 0.001437	 0.007641	 0.00177	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6438	 6514	 0.000651	 0.004191	 0.0011	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6438	 77140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6438	 77140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6439	 6440	 0.009118	 0.011984	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6439	 6446	 0.01075	 0.009632	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6439	 6447	 0.007442	 0.004818	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6441	 6450	 0.000957	 0.002568	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6441	 77141	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6441	 77141	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6442	 6452	 0.001026	 0.003457	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6442	 77142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6442	 77142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6443	 6453	 0.017138	 0.015462	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77142	 6443	 0.013553	 0.010726	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76541	 6444	 0.019819	 0.015685	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6445	 6455	 0.003892	 0.009859	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77140	 6445	 0.002797	 0.00933	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6446	 6458	 0.01134	 0.008974	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6446	 77146	 0.010069	 0.015422	 0.00027	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6448	 6450	 0.001182	 0.002743	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6448	 6461	 0.001475	 0.005606	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6448	 77143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6448	 77143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6448	 77157	 0.004894	 0.019593	 0.00494	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6449	 77144	 0.006623	 0.005191	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6450	 77144	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6450	 77144	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77144	 6451	 0.011117	 0.008798	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6451	 77145	 0.009584	 0.007585	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6452	 6462	 0.001003	 0.003137	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6452	 77145	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6452	 77145	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76541	 6453	 0.027448	 0.030189	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77140	 6454	 0.028801	 0.018646	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6455	 6456	 0.00279	 0.006477	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6456	 77146	 0.004573	 0.008962	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6457	 6465	 0.000483	 0.002044	 0.00046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6457	 77146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6457	 77146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6459	 6460	 0.011875	 0.007977	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6459	 6464	 0.019104	 0.024861	 0.00035	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77143	 6459	 0.006645	 0.008733	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6461	 6468	 0.001059	 0.004118	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6462	 6463	 0.000671	 0.001978	 0.00046	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77146	 6464	 0.005339	 0.010463	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6465	 6466	 0.000465	 0.001808	 0.00048	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6466	 6468	 0.000714	 0.002905	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6467	 6468	 0.000978	 0.003422	 0.00113	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6467	 6544	 0.001597	 0.006393	 0.00161	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6468	 77147	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6468	 77147	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6469	 6470	 0.016133	 0.010837	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77147	 6469	 0.019256	 0.015239	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6471	 6476	 0.059496	 0.039966	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6472	 6473	 0.011436	 0.050388	 0.00088	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6472	 6678	 0.011965	 0.065891	 0.00149	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6473	 6475	 0.03881	 0.028554	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6473	 6493	 0.036482	 0.02764	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6473	 77158	 0.0348	 0.079951	 0.00121	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 6475	 0.022911	 0.016856	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6476	 77159	 0.024517	 0.062351	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6477	 6478	 0.030349	 0.024018	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6478	 6479	 0.026524	 0.02099	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6478	 77158	 0.01863	 0.036885	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6480	 6481	 0.007704	 0.012849	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6481	 6482	 0.013814	 0.021161	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6481	 6485	 0.004399	 0.014519	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6481	 6520	 0.02572	 0.020354	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6481	 77158	 0.023164	 0.053779	 0.0008	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6482	 6483	 0.018719	 0.012118	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6484	 6485	 0.004761	 0.017009	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6484	 6492	 0.00706	 0.021656	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6486	 6487	 0.001139	 0.004558	 0.00154	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6486	 6490	 0.000902	 0.00453	 0.00118	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6486	 77148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6486	 77148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6487	 6519	 0.003006	 0.014589	 0.00334	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6488	 6497	 0.011506	 0.029577	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6488	 77149	 0.006382	 0.014817	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6489	 6491	 0.000973	 0.006881	 0.00189	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6489	 6494	 0.002093	 0.012028	 0.00341	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6489	 77149	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6489	 77149	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6490	 6491	 0.000885	 0.004587	 0.00112	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6491	 77150	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6491	 77150	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77150	 6492	 0.006161	 0.021572	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6494	 6682	 0.003213	 0.020351	 0.00552	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6495	 6498	 0.002642	 0.010578	 0.00266	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6495	 6683	 0.012223	 0.048044	 0.01257	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6496	 6498	 0.002095	 0.015069	 0.00399	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6496	 6688	 0.004122	 0.029156	 0.008	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6497	 77151	 0.013072	 0.033602	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6498	 6499	 0.000707	 0.005646	 0.00139	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6498	 6501	 0.003349	 0.015079	 0.00401	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6499	 6500	 0.001476	 0.01112	 0.00309	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6500	 6510	 0.002457	 0.014637	 0.00385	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6500	 77151	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6500	 77151	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6501	 6502	 0.006992	 0.021854	 0.00633	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6502	 6549	 0.006571	 0.020539	 0.00595	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6502	 77152	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6502	 77152	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6503	 6506	 0.053654	 0.042461	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6504	 6505	 0.021751	 0.017213	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6505	 6506	 0.050201	 0.03556	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6506	 6548	 0.068928	 0.090594	 0.00124	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76522	 6506	 0.017317	 0.057145	 0.00093	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6507	 6508	 0.01748	 0.01286	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6508	 6542	 0.056458	 0.036552	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6508	 6546	 0.035828	 0.028354	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6508	 77154	 0.014726	 0.037451	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76522	 6509	 0.042323	 0.033174	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6511	 6512	 0.000333	 0.002458	 0.00071	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6511	 77153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6511	 77153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6512	 6514	 0.00066	 0.004316	 0.0011	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6512	 77154	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6512	 77154	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77154	 6513	 0.021726	 0.01646	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6515	 6518	 0.019504	 0.012627	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77148	 6516	 0.032141	 0.025193	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6517	 6518	 0.015529	 0.013915	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6517	 77155	 0.009623	 0.023554	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6519	 77155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6519	 77155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6521	 6522	 0.021588	 0.015883	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6521	 77158	 0.018439	 0.03327	 0.00048	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6523	 77156	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6523	 77156	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6523	 77157	 0.001925	 0.007567	 0.00198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76541	 6524	 0.011711	 0.011714	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6524	 77158	 0.010783	 0.03773	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6525	 6536	 0.000152	 0.002686	 0.02813	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	6525	 77157	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77157	 6526	 0.000677	 0.007179	 0.00213	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6526	 77159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6526	 77159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6526	 77162	 0.001104	 0.009185	 0.00278	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6527	 6533	 0.003391	 0.017319	 0.00436	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6528	 6529	 0.048179	 0.037765	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6528	 6530	 0.048911	 0.038708	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76541	 6528	 0.018021	 0.046325	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6531	 6532	 0.001354	 0.006674	 0.0018	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6531	 6537	 0.000922	 0.006179	 0.00189	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77157	 6531	 0.004025	 0.025013	 0.00706	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6532	 6533	 0.001036	 0.005029	 0.00115	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6533	 6539	 0.005019	 0.023027	 0.0059	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6533	 77160	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6533	 77160	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6534	 6535	 0.041076	 0.032507	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77160	 6535	 0.013011	 0.02173	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6536	 77161	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77162	 6537	 0.000992	 0.007434	 0.00181	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77163	 6538	 0.069618	 0.055096	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6539	 6554	 0.006169	 0.028772	 0.00713	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6540	 6543	 0.005832	 0.017555	 0.00549	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6540	 77164	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6540	 77164	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6541	 6545	 0.09795	 0.07081	 0.00107	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6543	 6544	 0.001445	 0.005966	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6544	 77165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6544	 77165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77143	 6545	 0.023082	 0.059334	 0.00092	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6547	 6548	 0.089169	 0.069896	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6549	 6550	 0.006751	 0.022522	 0.00571	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6549	 77166	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6549	 77166	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6550	 77167	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6550	 77167	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6551	 6552	 0.071193	 0.066763	 0.00103	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76670	 6551	 0.13288	 0.13422	 0.00178	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77165	 6552	 0.15313	 0.14362	 0.00222	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77164	 6553	 0.15744	 0.1246	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77165	 6555	 0.059502	 0.046641	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6556	 6557	 0.00702	 0.048186	 0.00088	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6556	 6563	 0.034813	 0.11614	 0.00184	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6557	 77168	 0.006713	 0.044864	 0.00099	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6558	 6559	 0.003953	 0.014313	 0.00307	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6558	 6560	 0.006129	 0.024538	 0.00618	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6558	 8255	 0.00404	 0.022963	 0.00665	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6559	 77168	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6559	 77168	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6560	 8264	 0.004796	 0.018848	 0.00493	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6560	 77169	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6560	 77169	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77169	 6561	 0.056223	 0.051787	 0.00083	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6562	 6570	 0.059263	 0.13759	 0.00205	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6562	 77170	 0.020344	 0.099274	 0.00171	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6562	 77531	 0.013002	 0.088222	 0.00165	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6563	 6579	 0.087776	 0.1738	 0.00255	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6564	 6566	 0.06698	 0.080182	 0.00134	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6565	 6566	 0.010845	 0.027879	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6565	 6569	 0.019796	 0.050888	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6565	 6570	 0.040399	 0.10385	 0.00161	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77168	 6565	 0.010183	 0.053639	 0.00096	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	6566	 6567	 0.021905	 0.01717	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6566	 6568	 0.010268	 0.019664	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6568	 6569	 0.016094	 0.016932	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6569	 6571	 0.037672	 0.10805	 0.00166	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6571	 6572	 0.031823	 0.10502	 0.0017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6572	 77170	 0.028621	 0.094453	 0.00153	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6573	 77170	 0.065009	 0.065662	 0.00087	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6574	 6576	 0.026888	 0.021076	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6575	 7752	 0.008339	 0.025933	 0.00541	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6575	 77170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6575	 77170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6576	 6577	 0.032862	 0.026007	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77170	 6576	 0.00382	 0.009821	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6579	 6580	 0.22181	 0.14363	 0.00273	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 77171	 0.015354	 0.012151	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6582	 77171	 0.017167	 0.01241	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6583	 6584	 0.001135	 0.002917	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6583	 6587	 0.000861	 0.003385	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6583	 6598	 0.002355	 0.010804	 0.00277	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6583	 77171	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6583	 77171	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6584	 6585	 0.000876	 0.002443	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6585	 6586	 0.000569	 0.001503	 0.00035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6586	 6627	 0.001613	 0.004264	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6586	 77172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6586	 77172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6587	 6625	 0.001776	 0.007227	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6588	 77173	 0.021091	 0.021302	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6589	 6590	 0.003362	 0.011215	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6589	 6612	 0.003699	 0.010246	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6590	 77188	 0.0033	 0.011274	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6591	 6658	 0.001328	 0.005317	 0.00134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76552	 6591	 0.000631	 0.002294	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6591	 77173	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6591	 77173	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76553	 6592	 0.008492	 0.016814	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6593	 77174	 0.01516	 0.015312	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6594	 77174	 0.007371	 0.009593	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6595	 6615	 0.004463	 0.018889	 0.00425	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6595	 77174	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6595	 77174	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6596	 6597	 0.033504	 0.064164	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6596	 6601	 0.027479	 0.048325	 0.00091	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6596	 8213	 0.02373	 0.06806	 0.00105	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76519	 6597	 0.018703	 0.043422	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76467	 6598	 0.003213	 0.013599	 0.00306	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76518	 6598	 0.002758	 0.010839	 0.00284	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6598	 77175	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6598	 77175	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6599	 6601	 0.04115	 0.04116	 0.00056	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77175	 6599	 0.038394	 0.042229	 0.00056	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77171	 6600	 0.01236	 0.02869	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6602	 6603	 0.009939	 0.019034	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6602	 6605	 0.027625	 0.021862	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6603	 8213	 0.04795	 0.073456	 0.00103	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6603	 77176	 0.027981	 0.071162	 0.00113	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6604	 6608	 0.003307	 0.026056	 0.00762	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6604	 6625	 0.005474	 0.035797	 0.0091	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6604	 77176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6604	 77176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6606	 6607	 0.035326	 0.064703	 0.00112	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6606	 8205	 0.016213	 0.046501	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6607	 77177	 0.030603	 0.071049	 0.00106	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6608	 8121	 0.005941	 0.029848	 0.00777	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6608	 77177	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6608	 77177	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6609	 6612	 0.004773	 0.021665	 0.00047	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77177	 6609	 0.004819	 0.023513	 0.00041	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77177	 6610	 0.038817	 0.030426	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6611	 6612	 0.006952	 0.02434	 0.00067	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76553	 6611	 0.005267	 0.029937	 0.00054	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6613	 6658	 0.002325	 0.009044	 0.00242	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6613	 8122	 0.008295	 0.03321	 0.00837	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76553	 6614	 0.019559	 0.078406	 0.00202	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77174	 6614	 0.02652	 0.14605	 0.0033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6615	 6616	 0.003358	 0.013444	 0.00339	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6615	 77178	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6615	 77178	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6616	 8133	 0.007561	 0.032	 0.0072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6617	 6618	 0.007439	 0.06116	 0.00119	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77178	 6617	 0.006511	 0.060616	 0.00117	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6618	 6619	 0.013201	 0.082896	 0.00181	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6618	 6648	 0.12362	 0.097832	 0.00123	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6619	 6620	 0.068386	 0.05412	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76553	 6619	 0.010041	 0.050791	 0.00088	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6621	 6642	 0.0007	 0.007761	 0.0739	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	6621	 77179	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6622	 6623	 0.030733	 0.024322	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77180	 6622	 0.004453	 0.032545	 0.0006	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6622	 77185	 0.010439	 0.036549	 0.00101	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77176	 6624	 0.096906	 0.075961	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6625	 77181	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6625	 77181	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6626	 6632	 0.027655	 0.079318	 0.00122	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6626	 77182	 0.009084	 0.016891	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6627	 6628	 0.001908	 0.004954	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6628	 6630	 0.002877	 0.007604	 0.00178	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76518	 6628	 0.008082	 0.032359	 0.00815	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6628	 77182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6628	 77182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77182	 6629	 0.037279	 0.027427	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6630	 6631	 0.003283	 0.008252	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6631	 6637	 0.004684	 0.016961	 0.00364	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 6633	 0.003408	 0.024911	 0.00046	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 6659	 0.020381	 0.052392	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6633	 6634	 0.005856	 0.045639	 0.00085	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6634	 6635	 0.003445	 0.019584	 0.00035	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6634	 6636	 0.012866	 0.056686	 0.00098	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6634	 77185	 0.01794	 0.069019	 0.00118	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6634	 77185	 0.01794	 0.069019	 0.00118	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6635	 6657	 0.005916	 0.027467	 0.00075	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6636	 77183	 0.02249	 0.076825	 0.00167	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76455	 6637	 0.004934	 0.0289	 0.00787	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76455	 6637	 0.004934	 0.0289	 0.00787	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6637	 77183	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6637	 77183	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6638	 6722	 0.006312	 0.016681	 0.0039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6638	 6723	 0.004054	 0.010422	 0.00258	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77183	 6639	 0.059172	 0.042775	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6640	 77184	 0.031296	 0.056468	 0.00082	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6641	 6643	 0.036422	 0.028824	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6641	 6655	 0.002028	 0.012278	 0.00038	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6641	 77184	 0.002456	 0.023778	 0.00048	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6642	 7549	 0.000469	 0.005338	 0.0482	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	6642	 77184	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6642	 77184	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77184	 6644	 0.064841	 0.051315	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77179	 6645	 0.005	 0.02116	 0.00476	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6645	 77185	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6645	 77185	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77185	 6646	 0.03288	 0.048129	 0.00074	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6647	 6651	 0.029858	 0.059117	 0.00087	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77180	 6647	 0.014082	 0.06875	 0.00144	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	6649	 77186	 0.024123	 0.031394	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6650	 6652	 0.004556	 0.022111	 0.00505	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77179	 6650	 0.007444	 0.03317	 0.00901	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6650	 77186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6650	 77186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77186	 6651	 0.060207	 0.047648	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6652	 7585	 0.005494	 0.022358	 0.00545	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6652	 77187	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6652	 77187	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6653	 7554	 0.031888	 0.081972	 0.00127	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77187	 6653	 0.033259	 0.085496	 0.00132	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6654	 6655	 0.009068	 0.007176	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6655	 6657	 0.001464	 0.009935	 0.00019	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6656	 6657	 0.013517	 0.010595	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6658	 77188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6658	 77188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77172	 6659	 0.047975	 0.11138	 0.00166	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77176	 6659	 0.023607	 0.071053	 0.00139	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77181	 6659	 0.040102	 0.072358	 0.00105	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6660	 6662	 0.060549	 0.0392	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6661	 6662	 0.02387	 0.059246	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76760	 6661	 0.10572	 0.16036	 0.0023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6662	 6663	 0.007107	 0.014936	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6663	 6664	 0.037352	 0.14013	 0.00252	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6664	 77189	 0.005754	 0.031017	 0.00063	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6665	 6666	 0.008378	 0.035462	 0.00798	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6665	 77189	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6665	 77189	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6667	 6669	 0.029952	 0.099918	 0.00158	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6668	 6669	 0.022032	 0.18115	 0.00351	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76555	 6670	 0.099551	 0.078786	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6671	 6672	 0.020355	 0.079189	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6671	 6672	 0.020355	 0.079189	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6672	 77190	 0.006458	 0.02388	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6672	 77190	 0.006458	 0.02388	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6673	 6674	 0.007256	 0.028518	 0.00746	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6673	 77190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6673	 77190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6674	 6675	 0.008596	 0.038306	 0.01041	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6674	 6679	 0.005585	 0.032711	 0.00891	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76458	 6674	 0.002707	 0.032067	 0.01641	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6674	 77191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6674	 77191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6676	 6679	 0.008573	 0.040863	 0.01184	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6677	 77192	 0.11193	 0.088584	 0.00112	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6678	 77192	 0.009007	 0.054534	 0.00171	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6678	 77193	 0.011532	 0.083315	 0.00157	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6679	 77192	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6679	 77192	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77191	 6680	 0.010383	 0.10175	 0.00199	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6680	 77194	 0.022768	 0.069846	 0.00189	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6680	 77194	 0.022768	 0.069846	 0.00189	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6681	 77193	 0.061372	 0.039733	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6682	 6683	 0.003673	 0.027297	 0.01041	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6682	 77193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6682	 77193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76493	 6683	 0.002579	 0.037235	 0.01182	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6683	 77194	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6683	 77194	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6684	 77195	 0.022666	 0.015226	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6685	 6686	 0.017696	 0.012792	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6685	 77195	 0.012395	 0.024542	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6687	 6688	 0.001146	 0.008466	 0.00244	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6687	 6691	 0.002122	 0.023883	 0.00627	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6687	 77195	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6687	 77195	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6689	 77196	 0.002214	 0.023133	 0.00779	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6690	 6695	 0.000315	 0.003309	 0.01434	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6690	 77196	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6690	 77196	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6691	 6696	 0.00189	 0.010838	 0.0036	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77196	 6691	 0.002307	 0.015478	 0.00374	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76459	 6692	 0.13652	 0.10702	 0.00137	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76494	 6693	 0.025772	 0.051026	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76525	 6693	 0.052649	 0.069198	 0.00095	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6694	 6698	 8.8e-05	 0.001019	 0.00894	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	6694	 77197	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76456	 6695	 8.8e-05	 0.000858	 0.00299	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76462	 6695	 0.001746	 0.012029	 0.02124	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	6696	 6697	 0.000956	 0.003827	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77197	 6696	 0.001485	 0.005646	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6697	 77199	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6697	 77199	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6697	 77200	 0.001417	 0.005154	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6698	 77200	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6698	 77200	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6699	 6701	 0.008206	 0.032857	 0.00828	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6699	 6705	 0.00752	 0.029556	 0.00773	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6700	 6703	 0.030304	 0.14789	 0.00255	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6700	 6704	 0.069131	 0.10479	 0.00218	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6700	 77201	 0.042833	 0.20904	 0.00361	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76769	 6702	 0.082674	 0.12665	 0.00178	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76686	 6703	 0.034191	 0.16966	 0.00405	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6704	 77202	 0.061535	 0.13187	 0.00231	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6705	 7739	 0.00824	 0.041402	 0.01077	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6705	 77201	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6705	 77201	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77201	 6706	 0.047213	 0.13542	 0.00208	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6707	 6710	 0.002455	 0.008422	 0.00202	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6707	 77202	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6707	 77202	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6708	 6709	 0.021377	 0.016918	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6709	 6712	 0.005066	 0.003588	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6709	 77203	 0.013418	 0.026566	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6710	 77203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6710	 77203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77203	 6711	 0.019639	 0.014449	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6713	 6714	 0.023005	 0.1019	 0.00232	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77202	 6713	 0.009336	 0.041601	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76685	 6714	 0.029842	 0.17669	 0.00344	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76701	 6715	 0.11846	 0.08716	 0.00127	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6716	 77204	 0.063823	 0.050509	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6717	 6733	 0.004409	 0.016041	 0.00491	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6717	 77204	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6717	 77204	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6718	 6719	 0.02771	 0.019628	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 77205	 0.075806	 0.068396	 0.00114	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6720	 6726	 0.00706	 0.024605	 0.00571	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6720	 77205	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6720	 77205	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6721	 6722	 0.004292	 0.011141	 0.0027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6721	 6725	 0.007704	 0.019365	 0.00502	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6723	 8473	 0.004474	 0.011825	 0.00277	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 6725	 0.005506	 0.01455	 0.00341	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 8474	 0.005595	 0.01502	 0.0034	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6726	 6729	 0.002239	 0.007914	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6727	 6729	 0.005446	 0.014392	 0.00337	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6727	 77206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6727	 77206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6728	 8485	 0.016161	 0.029048	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77206	 6728	 0.013337	 0.033103	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6729	 77207	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6729	 77207	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6730	 77209	 0.030517	 0.060421	 0.00089	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77207	 6731	 0.005344	 0.044457	 0.00084	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6731	 77208	 0.011354	 0.069804	 0.00126	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6732	 6734	 0.004888	 0.013712	 0.00353	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6732	 8488	 0.003688	 0.014349	 0.00383	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6732	 77208	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6732	 77208	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6733	 6734	 0.003212	 0.010821	 0.00269	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6733	 77209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6733	 77209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6735	 6739	 0.000189	 0.001542	 0.00042	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6735	 6871	 0.00057	 0.00313	 0.00083	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6736	 77212	 0.006709	 0.005309	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6737	 6742	 0.000387	 0.001522	 0.0004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6737	 77210	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6737	 77210	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77210	 6738	 0.006237	 0.004508	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6739	 6746	 0.000162	 0.001359	 0.0004	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6740	 6758	 0.000694	 0.0038	 7e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6740	 77211	 0.000537	 0.003686	 7e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6741	 6742	 0.000372	 0.000964	 0.00029	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6741	 77211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6741	 77211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6742	 7164	 0.001415	 0.004295	 0.00094	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6742	 77212	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6742	 77212	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77212	 6743	 0.006965	 0.004934	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6744	 6745	 0.003576	 0.002315	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6745	 6747	 0.000532	 0.002131	 4e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6745	 6748	 0.001641	 0.006313	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6745	 6755	 0.001677	 0.005534	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77212	 6745	 0.001879	 0.00705	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77212	 6745	 0.001879	 0.00705	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6747	 6753	 0.000488	 0.001708	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6748	 6749	 0.001454	 0.003737	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6748	 7167	 0.000605	 0.003441	 6e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6749	 6751	 0.000455	 0.002767	 5e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6749	 7167	 0.000882	 0.004645	 8e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76488	 6750	 0.00013	 0.001117	 0.00032	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6751	 6830	 0.000457	 0.0026	 5e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6752	 6753	 0.000655	 0.002339	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6752	 6828	 0.001538	 0.005917	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6754	 77213	 0.002648	 0.003446	 5e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6755	 6760	 0.000888	 0.00293	 5e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76546	 6756	 0.003863	 0.010013	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6756	 77215	 0.005914	 0.01171	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6757	 6758	 0.002332	 0.001686	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6758	 6764	 0.000606	 0.00233	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76489	 6759	 0.002656	 0.001784	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6760	 6762	 0.000792	 0.002272	 3e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6760	 6816	 0.001299	 0.005197	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6761	 6792	 0.002057	 0.001332	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6762	 6763	 0.001232	 0.003167	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6762	 6773	 0.001063	 0.005375	 9e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6763	 6814	 0.001741	 0.004122	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6764	 6766	 0.002895	 0.005732	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6764	 6771	 0.004389	 0.003473	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6765	 6768	 0.001493	 0.003656	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6765	 6792	 0.001181	 0.00274	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6766	 6769	 0.000526	 0.003613	 7e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76920	 6766	 0.001819	 0.011054	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6767	 6788	 0.004408	 0.003488	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6767	 6789	 0.008814	 0.006976	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76489	 6767	 0.001873	 0.00899	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6767	 77217	 0.004546	 0.011687	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6767	 77220	 0.002091	 0.005318	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6768	 77214	 0.000999	 0.003333	 5e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6769	 6773	 0.000738	 0.004635	 0.0001	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6770	 6772	 0.000575	 0.001604	 0.00034	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6770	 6774	 0.000126	 0.000984	 0.00029	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6770	 6775	 0.000219	 0.00136	 0.00038	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76488	 6770	 0.000348	 0.003161	 0.0008	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6770	 77213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6770	 77213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6772	 6787	 0.000493	 0.001324	 0.0003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6772	 77214	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6772	 77214	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6773	 6776	 0.001155	 0.005638	 0.0001	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6774	 6775	 0.000127	 0.000907	 0.00028	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6774	 6866	 7.7e-05	 0.001112	 0.00035	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6775	 6777	 0.000338	 0.00085	 0.00022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6775	 77215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6775	 77215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6775	 77236	 0.000461	 0.002831	 0.00103	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6776	 6793	 0.00164	 0.006008	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6777	 6778	 0.000303	 0.000704	 0.00021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6778	 6781	 0.000289	 0.000866	 0.0002	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6779	 6795	 0.000344	 0.002013	 0.00055	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6779	 7265	 0.000625	 0.002956	 0.00071	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6779	 77216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6779	 77216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77216	 6780	 0.001536	 0.006148	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6781	 6782	 0.000399	 0.001155	 0.00028	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6781	 77217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6781	 77217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6782	 6827	 0.000276	 0.001001	 0.00021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6782	 77218	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6782	 77218	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77218	 6783	 0.003724	 0.002919	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6783	 77232	 0.004488	 0.003552	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6784	 6785	 0.000278	 0.0007	 0.00018	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6784	 6800	 0.000628	 0.00171	 0.00038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6785	 6786	 0.000303	 0.000779	 0.00019	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6785	 77219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6785	 77219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6786	 6787	 0.000318	 0.00084	 0.0002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6787	 77220	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6787	 77220	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6789	 6790	 0.004383	 0.003362	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6789	 6791	 0.00589	 0.004661	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6791	 77221	 0.00214	 0.002762	 6e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76489	 6792	 0.000551	 0.004298	 8e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77213	 6792	 0.003472	 0.007874	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6793	 6797	 0.001353	 0.004739	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6794	 6796	 0.000172	 0.000687	 0.00017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6795	 7259	 0.000315	 0.001643	 0.00043	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6796	 6802	 0.000431	 0.001405	 0.00037	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6796	 77221	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6796	 77221	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6797	 6801	 0.001602	 0.006165	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77219	 6798	 0.009118	 0.006591	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6798	 77222	 0.00058	 0.002595	 5e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6798	 77228	 0.001279	 0.005698	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6799	 6803	 0.004164	 0.003296	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6800	 6802	 0.000348	 0.001229	 0.00028	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6800	 6804	 0.000145	 0.00073	 0.00019	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76457	 6800	 0.000254	 0.001609	 0.00044	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6800	 77222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6800	 77222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6800	 77224	 0.000258	 0.001432	 0.00044	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6801	 6803	 0.00112	 0.004483	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6801	 6811	 0.005242	 0.003856	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6801	 6812	 0.000533	 0.00285	 9e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6801	 6857	 0.001924	 0.007635	 0.00022	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6803	 6807	 0.001016	 0.002573	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6803	 77223	 0.002254	 0.005794	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6804	 77224	 0.000159	 0.000871	 0.00023	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6805	 7248	 0.000292	 0.001739	 0.00046	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6805	 7259	 0.000449	 0.002413	 0.00059	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6805	 77223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6805	 77223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6806	 6819	 7.8e-05	 0.000751	 0.00266	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 8523	 0.000494	 0.00756	 0.0264	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76483	 6806	 0.000102	 0.000645	 0.00135	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76491	 6806	 0.000153	 0.001029	 0.0019	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76496	 6806	 7.9e-05	 0.000964	 0.00198	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 77224	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77225	 6806	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6807	 6809	 0.001494	 0.003469	 5e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77225	 6808	 0.00367	 0.002904	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6809	 6857	 0.002235	 0.005135	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76490	 6810	 8.2e-05	 0.001157	 0.00038	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76492	 6810	 0.000242	 0.001624	 0.00039	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76497	 6810	 8.2e-05	 0.000923	 0.00024	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6812	 6818	 0.0005	 0.002674	 8e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6813	 77226	 0.004336	 0.003135	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6814	 6816	 0.001955	 0.004537	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6815	 6823	 0.000363	 0.001452	 0.00037	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76457	 6815	 4.9e-05	 0.000428	 0.00015	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76490	 6815	 0.000783	 0.003184	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6815	 77226	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6815	 77226	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6816	 6818	 0.000352	 0.002539	 5e-05	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6816	 77227	 0.005244	 0.011894	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6817	 6827	 0.000332	 0.001106	 0.00028	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76457	 6817	 0.000167	 0.00079	 0.00019	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6819	 6842	 5.9e-05	 0.000614	 0.00118	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6820	 6826	 0.007361	 0.005825	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6821	 6823	 9.5e-05	 0.000714	 0.00017	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6821	 6836	 9.2e-05	 0.000674	 0.00017	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6822	 6846	 0.009052	 0.00586	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6823	 6834	 0.000111	 0.001066	 0.00031	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6824	 6841	 0.000599	 0.002537	 0.00057	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6824	 77227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6824	 77227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6825	 6834	 0.000363	 0.001478	 0.00036	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6825	 6960	 0.000142	 0.001789	 0.00055	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76457	 6825	 0.000343	 0.002466	 0.00065	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76490	 6825	 0.000219	 0.001875	 0.00053	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6826	 6830	 0.001185	 0.004542	 0.00013	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77227	 6826	 0.000781	 0.002396	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6827	 77228	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6827	 77228	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6828	 6829	 0.004111	 0.003253	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77227	 6828	 0.001891	 0.005691	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6830	 6831	 0.001086	 0.003007	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6831	 6832	 0.001121	 0.002563	 6e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6832	 6833	 0.001772	 0.004506	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6833	 77244	 0.002044	 0.008485	 0.00022	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6833	 77330	 0.000861	 0.005287	 0.00012	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6833	 77331	 0.001054	 0.00369	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6834	 6960	 0.000115	 0.000833	 0.00045	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6835	 6838	 0.000644	 0.002467	 7e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6835	 77244	 0.002411	 0.005167	 9e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6835	 77331	 0.000745	 0.003637	 8e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	6836	 6839	 8.6e-05	 0.000646	 0.00018	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6837	 77244	 0.004955	 0.003922	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6838	 6840	 0.001052	 0.00411	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6839	 6844	 0.000107	 0.000767	 0.0002	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6839	 77229	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6839	 77229	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6840	 77230	 0.001128	 0.004387	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6841	 6897	 0.000713	 0.002403	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6841	 77230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6841	 77230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6842	 6845	 3e-05	 0.000341	 0.00067	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6842	 77231	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77232	 6842	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77227	 6843	 0.004584	 0.003628	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6844	 77233	 0.000107	 0.000778	 0.0002	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6845	 6860	 5.2e-05	 0.000496	 0.00181	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77032	 6845	 0.000278	 0.004254	 0.01486	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77053	 6845	 0.000286	 0.003088	 0.00613	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6845	 77233	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6845	 77233	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6846	 6848	 0.00059	 0.001692	 3e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6846	 6852	 0.00058	 0.002828	 5e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77230	 6846	 0.00083	 0.004664	 9e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6847	 6849	 0.000356	 0.000924	 0.00022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77231	 6847	 0.000552	 0.001458	 0.00034	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6847	 77234	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6847	 77234	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6848	 6850	 0.002252	 0.006458	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77233	 6849	 8.8e-05	 0.000756	 0.00022	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6849	 77235	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6849	 77235	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6849	 77236	 0.000102	 0.001047	 0.0003	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6850	 6894	 0.001501	 0.003859	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6851	 6858	 0.006841	 0.005247	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77235	 6851	 0.004809	 0.003806	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6852	 6854	 0.000523	 0.001867	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77234	 6853	 0.004849	 0.003505	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6854	 6857	 0.001159	 0.003326	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77215	 6855	 0.005555	 0.004396	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6856	 6891	 0.005722	 0.003705	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6856	 6894	 0.009538	 0.007018	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 6861	 0.005496	 0.004164	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 6865	 0.001477	 0.006469	 0.00014	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 77243	 0.011461	 0.022692	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 77339	 0.006072	 0.013772	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6858	 6859	 0.004737	 0.003749	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77215	 6858	 0.004543	 0.00696	 0.0001	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6860	 6918	 5.4e-05	 0.000587	 0.00128	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6860	 77236	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77237	 6860	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6862	 6863	 0.0053	 0.004195	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77223	 6862	 0.004913	 0.003614	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6864	 6914	 0.000345	 0.001382	 0.00035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6864	 6915	 0.000286	 0.001041	 0.00032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6864	 77238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6864	 77238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6864	 77254	 0.000324	 0.001488	 0.00038	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6865	 6867	 0.000497	 0.002191	 4e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6866	 6871	 0.000329	 0.001812	 0.00042	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6866	 6929	 0.000963	 0.007734	 0.00217	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76488	 6866	 0.000449	 0.004759	 0.00141	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6866	 77239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6866	 77239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6866	 77254	 0.000578	 0.00366	 0.00099	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6867	 6868	 0.003017	 0.002387	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6867	 6869	 0.001056	 0.004063	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6869	 6870	 0.000531	 0.002041	 3e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6870	 6872	 0.000812	 0.0029	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6871	 6884	 0.000273	 0.001392	 0.00035	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6871	 77240	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6871	 77240	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6872	 77338	 0.001769	 0.005838	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6873	 6874	 0.002321	 0.001819	 2e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6874	 6876	 0.000758	 0.002503	 4e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77240	 6874	 0.002691	 0.006105	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6875	 6878	 0.007361	 0.005416	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6875	 6881	 0.002993	 0.004585	 6e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6875	 7235	 0.001171	 0.004	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6875	 77338	 0.00186	 0.006508	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6876	 77253	 0.001517	 0.003004	 4e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6877	 6949	 0.009593	 0.00621	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6879	 6880	 0.000114	 0.000512	 0.00014	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6879	 6884	 0.000246	 0.001122	 0.00036	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6879	 77241	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6879	 77241	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6880	 6905	 0.000219	 0.001062	 0.00024	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6881	 6883	 0.001256	 0.001831	 4e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77241	 6882	 0.004365	 0.003454	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6883	 6886	 0.001378	 0.002477	 4e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6885	 6888	 0.001005	 0.005711	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6885	 6934	 0.000644	 0.003662	 7e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6886	 6887	 0.00182	 0.002905	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6887	 6888	 0.001969	 0.005061	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6888	 6892	 0.000968	 0.006646	 0.00012	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6889	 6892	 0.005428	 0.004296	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6890	 6905	 0.001456	 0.003848	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6890	 77242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6890	 77242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6892	 6895	 0.000556	 0.004331	 8e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77242	 6893	 0.016978	 0.013308	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6894	 6895	 0.001991	 0.005119	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6895	 6896	 0.00218	 0.004672	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6895	 77243	 0.002209	 0.008463	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6896	 77249	 0.001877	 0.004866	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6897	 77243	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6897	 77243	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6897	 77335	 0.002963	 0.011861	 0.00299	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6898	 6900	 0.000415	 0.001468	 0.00033	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6898	 7226	 0.000287	 0.001851	 0.00049	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6898	 77244	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6898	 77244	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6899	 6905	 0.000957	 0.004388	 0.00112	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6899	 7087	 0.000532	 0.002196	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6899	 7090	 0.000136	 0.002088	 0.00058	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76862	 6899	 0.000228	 0.002873	 0.00089	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6900	 7228	 0.000389	 0.001558	 0.00039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6900	 77245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6900	 77245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6901	 6904	 0.000156	 0.001175	 0.00033	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6901	 7229	 0.0003	 0.00212	 0.00058	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6901	 77246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6901	 77246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6902	 77248	 0.011053	 0.008664	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6903	 7023	 0.004822	 0.003779	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6903	 77247	 0.006194	 0.004161	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6904	 6907	 0.000179	 0.001243	 0.00035	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6904	 77247	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6904	 77247	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6905	 6915	 0.000381	 0.001448	 0.00041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6905	 77248	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6905	 77248	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6906	 7021	 0.000873	 0.004213	 7e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6906	 7022	 0.001153	 0.004034	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6906	 7031	 0.002465	 0.009588	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77243	 6906	 0.002074	 0.007408	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77243	 6906	 0.002074	 0.007408	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6907	 7019	 0.000793	 0.005611	 0.00154	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6907	 77249	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6907	 77249	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77249	 6908	 0.005788	 0.003747	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6909	 6910	 0.000119	 0.000954	 0.00027	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6909	 7075	 0.000191	 0.001534	 0.00043	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6910	 6913	 0.000117	 0.000972	 0.00029	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6910	 77250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6910	 77250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6911	 6917	 0.001928	 0.004408	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6911	 7020	 0.001307	 0.004311	 7e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6912	 77251	 0.000755	 0.003975	 7e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	6912	 77255	 0.000765	 0.004078	 7e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	6913	 6914	 0.00016	 0.001205	 0.00033	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6913	 77251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6913	 77251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6914	 77252	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6914	 77252	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6914	 77254	 0.000244	 0.001639	 0.0004	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6915	 77253	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6915	 77253	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77251	 6916	 0.003033	 0.007182	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77252	 6916	 0.003406	 0.00344	 5e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77253	 6916	 0.00115	 0.002956	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6917	 6920	 0.001548	 0.004748	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6917	 6922	 0.002699	 0.004712	 7e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6917	 6932	 0.005583	 0.009324	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6917	 77285	 0.005278	 0.012589	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6918	 77254	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6918	 77254	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6919	 6921	 5.3e-05	 0.000371	 0.00021	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77254	 6919	 3.7e-05	 0.00046	 0.0002	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6920	 6926	 0.006424	 0.004726	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6920	 6928	 0.002635	 0.0067	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6920	 7016	 0.004643	 0.007611	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 6923	 7e-05	 0.000503	 0.00027	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6922	 6924	 0.001322	 0.002386	 3e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6923	 6925	 0.000131	 0.000815	 0.00023	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6923	 6951	 0.00031	 0.00157	 0.00044	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6923	 7052	 0.000494	 0.002396	 0.00055	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6924	 6932	 0.001445	 0.002307	 5e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6925	 6927	 0.000177	 0.000826	 0.0002	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6925	 77255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6925	 77255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6927	 7052	 0.000238	 0.000935	 0.00024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6927	 77256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6927	 77256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6928	 7011	 0.001958	 0.004637	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6929	 7026	 0.000772	 0.005916	 0.00158	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6929	 77257	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6929	 77257	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6930	 6945	 0.000159	 0.001352	 0.00034	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6930	 7050	 0.000285	 0.001297	 0.00041	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6930	 77258	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6930	 77258	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77258	 6931	 0.003757	 0.002432	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6932	 6936	 0.001187	 0.004566	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6932	 6938	 0.001802	 0.004583	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6933	 6948	 0.000234	 0.002563	 0.00071	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6933	 7042	 0.000131	 0.001261	 0.00037	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6933	 77259	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6933	 77259	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6934	 6936	 0.000626	 0.002433	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6934	 6949	 0.002521	 0.00723	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6935	 7002	 0.002298	 0.006076	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6935	 77260	 0.000902	 0.003509	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6935	 77260	 0.000902	 0.003509	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6935	 77278	 0.000553	 0.002261	 5e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6937	 77260	 0.001775	 0.002124	 4e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6938	 6940	 0.001293	 0.003165	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6939	 6943	 0.000251	 0.001037	 0.00025	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6939	 77260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6939	 77260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6940	 6942	 0.005352	 0.004055	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6940	 6946	 0.003189	 0.00509	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6941	 77261	 0.001772	 0.002122	 4e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6943	 6948	 0.000377	 0.001481	 0.00039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6943	 77261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6943	 77261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6944	 6946	 0.006315	 0.004997	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6945	 6958	 0.000216	 0.00203	 0.00061	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6945	 77262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6945	 77262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6946	 6949	 0.008149	 0.008963	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77262	 6947	 0.000768	 0.00182	 3e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6947	 77263	 0.000812	 0.002087	 3e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6948	 6955	 0.000342	 0.002016	 0.00164	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6948	 77263	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6948	 77263	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6949	 77265	 0.00283	 0.009441	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77263	 6950	 0.000255	 0.001984	 4e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6950	 77264	 0.000311	 0.002588	 5e-05	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6951	 6955	 0.000436	 0.002635	 0.00067	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6951	 77264	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6951	 77264	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77264	 6952	 0.003096	 0.004069	 6e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6953	 6968	 0.000684	 0.002229	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6953	 77265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6953	 77265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77237	 6954	 0.000303	 0.001178	 2e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77237	 6954	 0.000303	 0.001178	 2e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6954	 77266	 0.001129	 0.004393	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6954	 77266	 0.001129	 0.004393	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76457	 6955	 0.000404	 0.003572	 0.00196	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6955	 77266	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6955	 77266	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77265	 6956	 0.010401	 0.008232	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77266	 6957	 0.000969	 0.00551	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6957	 77267	 0.001019	 0.004973	 9e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6958	 6960	 0.000454	 0.00309	 0.00105	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6958	 77267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6958	 77267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6959	 6960	 0.000235	 0.00189	 0.00053	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6959	 6964	 0.000227	 0.001706	 0.00047	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6961	 6965	 0.006441	 0.010851	 0.00015	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6961	 7192	 0.002475	 0.007278	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6961	 77323	 0.004485	 0.015702	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6962	 6969	 0.00052	 0.002317	 4e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77267	 6962	 0.000866	 0.003816	 7e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6963	 6973	 0.000551	 0.002093	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6963	 7189	 0.000403	 0.001409	 0.00047	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6963	 77268	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6963	 77268	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6964	 6972	 0.000264	 0.001897	 0.0005	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6964	 77269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6964	 77269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77268	 6965	 0.010236	 0.006627	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6966	 6971	 0.000539	 0.00281	 0.00074	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76490	 6966	 0.000731	 0.005478	 0.00134	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6966	 77270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6966	 77270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6967	 77271	 0.008274	 0.006548	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6968	 6980	 0.001044	 0.003637	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	6968	 77271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6968	 77271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6969	 6970	 0.000603	 0.001851	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6970	 77273	 0.000599	 0.002329	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6971	 6975	 0.000293	 0.001525	 0.0004	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6971	 77272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6971	 77272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6972	 6978	 0.000209	 0.001571	 0.00044	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6972	 77273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6972	 77273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6973	 6980	 0.000526	 0.002104	 0.00053	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77273	 6974	 0.003671	 0.002905	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6975	 6981	 0.000288	 0.0015	 0.00039	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77268	 6976	 0.008609	 0.006334	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6977	 77274	 0.004489	 0.003552	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6977	 77276	 0.00631	 0.004085	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6978	 6987	 0.000156	 0.001103	 0.0003	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6978	 77274	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6978	 77274	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77274	 6979	 0.004673	 0.003698	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6980	 7019	 0.000678	 0.006505	 0.00189	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6980	 77275	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6980	 77275	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6981	 6983	 0.00018	 0.000856	 0.00025	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6981	 77276	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6981	 77276	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77275	 6982	 0.004144	 0.003279	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6983	 6984	 0.000296	 0.001445	 0.0004	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6984	 6989	 0.000184	 0.001078	 0.00029	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6984	 77277	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6984	 77277	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6985	 6987	 0.00017	 0.001138	 0.00035	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6985	 7003	 0.000116	 0.000657	 0.00019	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6985	 77278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6985	 77278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6986	 7085	 0.004766	 0.00796	 0.00014	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6986	 7156	 0.002099	 0.007497	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77275	 6986	 0.001739	 0.007662	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77273	 6988	 0.003554	 0.011729	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77277	 6988	 0.002342	 0.004793	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6989	 6997	 0.000234	 0.001327	 0.00033	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	6990	 7252	 0.00019	 0.002437	 0.00073	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6990	 7261	 0.000249	 0.002123	 0.00053	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76490	 6990	 0.000639	 0.008664	 0.00501	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	6990	 77279	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6990	 77279	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6991	 77283	 0.001868	 0.009451	 0.00016	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6991	 77340	 0.003795	 0.014601	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6992	 7086	 0.007713	 0.006104	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77275	 6993	 0.008339	 0.006135	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6994	 6996	 0.002403	 0.004014	 7e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6994	 7008	 0.001393	 0.004878	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6994	 7085	 0.000934	 0.004976	 9e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	6995	 77280	 0.004335	 0.00343	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	6996	 6998	 0.001554	 0.003857	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6996	 7082	 0.00168	 0.004319	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	6997	 7007	 0.000271	 0.001321	 0.00036	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	6997	 77280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6997	 77280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6998	 7000	 0.000672	 0.004865	 0.00012	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 7066	 0.001483	 0.006535	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	6999	 7001	 0.002487	 0.001968	 2e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7000	 77285	 0.00105	 0.008739	 0.00017	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7001	 7002	 0.001491	 0.002922	 4e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77280	 7002	 0.002902	 0.007459	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7002	 77281	 0.00101	 0.001815	 3e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7003	 7004	 0.000308	 0.001741	 0.00043	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7003	 77281	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7003	 77281	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7004	 7018	 0.000228	 0.001147	 0.0003	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7004	 77282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7004	 77282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7005	 7017	 0.001696	 0.004482	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77282	 7005	 0.001104	 0.003391	 6e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7006	 7008	 0.001881	 0.007528	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7006	 7012	 0.001683	 0.004279	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7006	 7016	 0.000649	 0.003473	 0.00011	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7007	 7010	 0.000198	 0.001011	 0.00025	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7009	 7011	 0.001413	 0.005498	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77275	 7009	 0.001773	 0.006822	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7010	 7015	 0.000169	 0.000688	 0.00017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7010	 77283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7010	 77283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7011	 7012	 0.003201	 0.006337	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7013	 7015	 0.000319	 0.001297	 0.00032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7013	 7218	 0.000216	 0.000849	 0.00022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 7209	 0.000982	 0.003822	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 77286	 0.001144	 0.005096	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7015	 77284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7015	 77284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7016	 77285	 0.000412	 0.003838	 7e-05	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77284	 7017	 0.001324	 0.003134	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7018	 7026	 0.00021	 0.001025	 0.00028	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7019	 77285	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7019	 77285	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7019	 77335	 0.00148	 0.01378	 0.00427	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7020	 7021	 0.001014	 0.003946	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7022	 7025	 0.001784	 0.005951	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7024	 7025	 0.000933	 0.003263	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7024	 7353	 0.001652	 0.006428	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7025	 7029	 0.001315	 0.00506	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7026	 7207	 0.000143	 0.001118	 0.00051	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7026	 77286	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7026	 77286	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7027	 7353	 0.007612	 0.0056	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7028	 7030	 0.000636	 0.002474	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7028	 7190	 0.000814	 0.003165	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7029	 7037	 0.001576	 0.005256	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7030	 7032	 0.000839	 0.002157	 3e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7030	 7034	 0.001834	 0.004715	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7031	 7033	 0.001795	 0.005149	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7032	 7034	 0.001015	 0.002404	 4e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77285	 7033	 0.002755	 0.007007	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7034	 7036	 0.001213	 0.003478	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7034	 7038	 0.000855	 0.003326	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7035	 7037	 0.005238	 0.00371	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77278	 7036	 0.001759	 0.005044	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7037	 7039	 0.001641	 0.004708	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7038	 7040	 0.000485	 0.001775	 4e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7039	 7041	 0.000941	 0.003766	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77285	 7039	 0.002107	 0.004891	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77259	 7040	 0.000324	 0.001435	 4e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7041	 7049	 0.000883	 0.003935	 7e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7042	 7045	 0.000202	 0.001834	 0.0006	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7042	 77287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7042	 77287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7043	 7049	 0.002898	 0.007449	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7043	 7354	 0.003043	 0.008728	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77287	 7044	 0.006023	 0.004721	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7045	 7191	 0.000161	 0.001542	 0.00045	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7045	 77288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7045	 77288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7046	 7047	 0.007726	 0.006056	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 7049	 0.001214	 0.00887	 0.00016	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 7051	 0.007964	 0.006303	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 7053	 0.009762	 0.007652	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 7056	 0.003002	 0.006143	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 7063	 0.003496	 0.00889	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 7357	 0.028819	 0.018657	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7048	 7054	 0.000187	 0.001254	 0.0003	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7048	 7062	 0.000242	 0.001252	 0.00031	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7048	 77289	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7048	 77289	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7050	 7054	 0.000118	 0.000672	 0.00019	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7050	 77290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7050	 77290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7052	 7055	 0.000117	 0.001185	 0.00035	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7054	 77291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7054	 77291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7055	 7058	 0.000663	 0.002653	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7055	 7061	 0.000481	 0.001676	 0.00039	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7055	 77292	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7055	 77292	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7056	 7098	 0.001543	 0.006002	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7057	 7074	 0.000435	 0.002336	 6e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77256	 7057	 0.007691	 0.013525	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77292	 7057	 0.004071	 0.006174	 9e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7057	 77294	 0.00052	 0.003197	 6e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7058	 7183	 0.000427	 0.001496	 0.0005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7058	 77293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7058	 77293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77293	 7059	 0.004349	 0.003442	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7060	 7095	 0.002422	 0.006227	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7060	 7098	 0.002841	 0.005815	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7061	 77294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7061	 77294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7062	 7185	 0.000295	 0.002087	 0.00057	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7062	 77295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7062	 77295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7063	 7064	 0.00534	 0.004226	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7063	 7065	 0.001645	 0.004227	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7063	 7082	 0.004794	 0.009809	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7065	 7068	 0.001957	 0.00503	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7066	 7070	 0.001713	 0.006272	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77288	 7067	 0.007526	 0.005331	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7068	 7070	 0.001525	 0.003785	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7069	 7184	 0.007613	 0.005968	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77295	 7069	 0.006943	 0.004495	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 7071	 0.001209	 0.003467	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 7079	 0.002606	 0.006699	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 7094	 0.004848	 0.012462	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7071	 7073	 0.000955	 0.003186	 5e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7072	 7075	 0.000268	 0.001106	 0.00026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7072	 7077	 0.000192	 0.000755	 0.0002	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7073	 7091	 0.001387	 0.005129	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7073	 7094	 0.009284	 0.006711	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7074	 77296	 0.000589	 0.003347	 6e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7075	 77296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7075	 77296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7076	 7088	 0.001317	 0.003384	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7076	 77297	 0.001659	 0.004264	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7077	 7080	 0.000274	 0.001095	 0.00028	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7078	 7079	 0.000953	 0.002366	 4e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7078	 7088	 0.001248	 0.002554	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7079	 7081	 0.003471	 0.002554	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7080	 7087	 0.000397	 0.001545	 0.00041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7080	 7134	 0.000157	 0.000965	 0.00028	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7083	 77307	 0.006199	 0.004906	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7084	 7085	 0.005108	 0.003758	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7085	 7086	 0.00116	 0.005598	 0.0001	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7086	 77297	 0.001546	 0.006133	 0.00018	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7089	 7133	 0.000306	 0.000885	 0.00021	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7089	 77297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7089	 77297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7090	 7131	 0.000461	 0.001875	 0.00046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7090	 77298	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7090	 77298	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7091	 7092	 0.00072	 0.002803	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7092	 77303	 0.001076	 0.004187	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7093	 7129	 0.002566	 0.01086	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76861	 7093	 0.002031	 0.005618	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77298	 7093	 0.001013	 0.005759	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7094	 7116	 0.006268	 0.008898	 0.00015	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7095	 7116	 0.004617	 0.011869	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7096	 7097	 5.9e-05	 0.000795	 0.00022	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7096	 7127	 0.000121	 0.00091	 0.00025	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7097	 7099	 4.6e-05	 0.000475	 0.00018	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7098	 7101	 0.007757	 0.005608	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7099	 7102	 8.2e-05	 0.000904	 0.00027	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7099	 77299	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7099	 77299	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7100	 7102	 0.000129	 0.000894	 0.00026	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7100	 7106	 0.000313	 0.001364	 0.00039	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7100	 7143	 0.000776	 0.002823	 0.00086	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7100	 77300	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7100	 77300	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7101	 7356	 0.002339	 0.005948	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7101	 77357	 0.005671	 0.010387	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7103	 7105	 0.006946	 0.00511	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7103	 77357	 0.00923	 0.007305	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77300	 7104	 0.007168	 0.005619	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7105	 7107	 0.006335	 0.005013	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7106	 7108	 0.000309	 0.00144	 0.00036	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7106	 77301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7106	 77301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7107	 7114	 0.006058	 0.004749	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7108	 77302	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7108	 77302	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7109	 7111	 0.004322	 0.00318	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7109	 7398	 0.009701	 0.007677	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7110	 7115	 0.010078	 0.007976	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7112	 7398	 0.012023	 0.009109	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77301	 7113	 0.007358	 0.005768	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77301	 7115	 0.00812	 0.006426	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7116	 77303	 0.003643	 0.010448	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7116	 77357	 0.008228	 0.020924	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7117	 77310	 0.007553	 0.005977	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7118	 7120	 0.001283	 0.002626	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7118	 77310	 0.001215	 0.003089	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7119	 7121	 0.000463	 0.001676	 0.00036	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7119	 7128	 0.000528	 0.001722	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7120	 7122	 0.001565	 0.004023	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7121	 77303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7121	 77303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7122	 7123	 0.001117	 0.003051	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7123	 7129	 0.002149	 0.006599	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7124	 7129	 0.005741	 0.003717	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7125	 77304	 0.006548	 0.005133	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77303	 7126	 0.009287	 0.006833	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7127	 7131	 0.000207	 0.001526	 0.00044	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7127	 77304	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7127	 77304	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7128	 77305	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7128	 77305	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7130	 7135	 0.000918	 0.00409	 7e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77305	 7130	 0.000607	 0.003198	 6e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	7131	 7136	 0.00013	 0.001123	 0.0004	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7132	 7135	 0.000608	 0.003737	 7e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77297	 7132	 0.001701	 0.006619	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7132	 77306	 0.000552	 0.003137	 6e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7133	 77306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7133	 77306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7134	 7136	 8.8e-05	 0.000548	 0.00015	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7134	 77307	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7134	 77307	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7135	 7138	 0.005906	 0.004674	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7135	 7152	 0.001835	 0.004756	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7136	 7137	 0.000245	 0.000826	 0.00021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7137	 7139	 0.00043	 0.001498	 0.00035	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7139	 7183	 0.000422	 0.00132	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7140	 7141	 0.006027	 0.00477	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77306	 7140	 0.007622	 0.006032	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7142	 7152	 0.011292	 0.008936	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7142	 7154	 0.007654	 0.004955	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7143	 7144	 0.000518	 0.002193	 0.00049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7143	 7149	 0.001357	 0.003487	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7143	 7157	 0.000514	 0.0018	 0.0006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7143	 77308	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7143	 77308	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7144	 7175	 0.000285	 0.001207	 0.00027	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7145	 7146	 0.002043	 0.005001	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7145	 7152	 0.002598	 0.006678	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7146	 7147	 0.002111	 0.005427	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7147	 7148	 0.002186	 0.005537	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7147	 7165	 0.010268	 0.010371	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 7150	 0.00694	 0.00544	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 7160	 0.001392	 0.002849	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7149	 7176	 0.000389	 0.001584	 0.00039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7149	 77309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7149	 77309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7151	 7162	 0.000631	 0.004915	 9e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77309	 7151	 0.000422	 0.002724	 9e-05	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7153	 7161	 0.004429	 0.002867	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77309	 7153	 0.008834	 0.006258	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 77310	 0.004984	 0.003944	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7156	 7159	 0.001088	 0.00408	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7157	 7158	 0.00023	 0.000958	 0.0003	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7157	 77310	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7157	 77310	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7159	 7160	 0.00108	 0.004811	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7160	 7170	 0.001771	 0.004194	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7162	 7163	 0.000457	 0.003185	 7e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7163	 77311	 0.000678	 0.004106	 0.00013	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7164	 7169	 0.00085	 0.002246	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7164	 77311	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7164	 77311	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7165	 7174	 0.01275	 0.012878	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7166	 7168	 0.000352	 0.002532	 8e-05	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77311	 7166	 0.000628	 0.004748	 0.00016	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7167	 7168	 0.000359	 0.003047	 7e-05	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7169	 7212	 0.000368	 0.001103	 0.00025	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7170	 7171	 0.001692	 0.003927	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7171	 77316	 0.00202	 0.005136	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7172	 7189	 0.000672	 0.002691	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7172	 77312	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7172	 77312	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7173	 7198	 0.000769	 0.005994	 0.00011	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7173	 77315	 0.000826	 0.006441	 0.00012	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7174	 7178	 0.005053	 0.003652	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76989	 7174	 0.006795	 0.011447	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7175	 7177	 0.000159	 0.000635	 0.00016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7176	 7186	 0.000322	 0.001288	 0.00032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7177	 7179	 0.000144	 0.000566	 0.00015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7179	 7180	 0.000349	 0.00142	 0.00035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7179	 77313	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7179	 77313	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7180	 7185	 0.000122	 0.000903	 0.00026	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7180	 7186	 0.000299	 0.001218	 0.0003	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7181	 7194	 0.001977	 0.007061	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77313	 7182	 0.000479	 0.004695	 9e-05	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7182	 77314	 0.000405	 0.003973	 8e-05	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7183	 77314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7183	 77314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7186	 77315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7186	 77315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7187	 7195	 0.004524	 0.003205	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7188	 7192	 0.002098	 0.004797	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77312	 7188	 0.003891	 0.008339	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7189	 77316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7189	 77316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77286	 7190	 0.002283	 0.005806	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7191	 7193	 0.000148	 0.001146	 0.0004	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7191	 77317	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7191	 77317	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7192	 7194	 0.001448	 0.006454	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7193	 7196	 0.000102	 0.000818	 0.00023	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7193	 77318	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7193	 77318	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77317	 7195	 0.005008	 0.005023	 8e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7196	 7205	 0.000108	 0.000787	 0.00027	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77318	 7197	 0.01065	 0.007836	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7198	 7199	 0.000447	 0.002544	 8e-05	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7199	 7211	 0.001471	 0.006555	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7199	 77319	 0.001878	 0.00466	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7200	 7201	 0.000207	 0.000948	 0.00024	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7200	 7212	 0.000481	 0.001926	 0.00049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7200	 77319	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7200	 77319	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7201	 7204	 0.000123	 0.000656	 0.00015	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7202	 7203	 0.000275	 0.001285	 0.00032	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7202	 7204	 0.000116	 0.000607	 0.00016	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7202	 7216	 0.000222	 0.000888	 0.00022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7202	 77320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7202	 77320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7203	 7207	 0.000134	 0.000968	 0.00052	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7203	 77321	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7203	 77321	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7203	 77335	 0.000672	 0.007126	 0.00212	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7205	 7214	 0.000444	 0.003347	 0.00093	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7205	 77322	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7205	 77322	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7206	 7244	 0.001338	 0.005863	 0.00202	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7206	 77323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7206	 77323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7207	 77324	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7207	 77324	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77286	 7208	 0.001459	 0.003352	 5e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7209	 7210	 0.001253	 0.003685	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7209	 77328	 0.00632	 0.004092	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77321	 7210	 0.001063	 0.002705	 4e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7211	 77326	 0.001149	 0.00431	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7212	 77325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7212	 77325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7213	 7220	 0.000656	 0.005461	 0.0001	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77325	 7213	 0.000529	 0.004491	 0.0001	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7214	 7221	 0.0002	 0.001741	 0.00048	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7214	 77326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7214	 77326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7215	 7222	 0.000455	 0.003326	 6e-05	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77320	 7215	 0.000506	 0.003642	 0.00012	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7216	 7217	 0.000308	 0.001169	 0.00033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7217	 7218	 0.000278	 0.001176	 0.00026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7217	 77327	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7217	 77327	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7218	 77328	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7218	 77328	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77327	 7219	 0.004971	 0.003934	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7220	 7223	 0.00149	 0.004227	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7220	 77330	 0.001564	 0.004797	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7220	 77330	 0.001564	 0.004797	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7221	 7227	 0.000446	 0.002914	 0.00074	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7221	 77329	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7221	 77329	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7222	 77332	 0.002013	 0.012377	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77329	 7223	 0.000609	 0.002334	 7e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77329	 7224	 0.000469	 0.003431	 6e-05	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7224	 77330	 0.000658	 0.004046	 9e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7225	 7226	 0.000206	 0.0008	 0.00021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7225	 77330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7225	 77330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7226	 77331	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7226	 77331	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7227	 7228	 0.000462	 0.00185	 0.00047	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7227	 7243	 0.000623	 0.002495	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7227	 77332	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7227	 77332	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7229	 7348	 0.000382	 0.003276	 0.00093	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7229	 77333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7229	 77333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77333	 7230	 0.006064	 0.004753	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7231	 77337	 0.008504	 0.006666	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7232	 7233	 0.000404	 0.003759	 7e-05	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77332	 7232	 0.000506	 0.004953	 0.0001	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7233	 7351	 0.000506	 0.004713	 9e-05	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7234	 7236	 0.001751	 0.005639	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77265	 7234	 0.002419	 0.008071	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7235	 7236	 0.001202	 0.003326	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7237	 7242	 0.009205	 0.007284	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7238	 7239	 0.000248	 0.001136	 0.00029	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7238	 77334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7238	 77334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7238	 77335	 0.000471	 0.001946	 0.00046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7239	 7252	 7.2e-05	 0.000888	 0.00042	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7239	 77335	 9.4e-05	 0.001063	 0.00041	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7240	 77335	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77336	 7240	 0.000318	 0.022264	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7241	 7242	 0.0093	 0.006723	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77336	 7241	 0.00211	 0.003711	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77335	 7243	 0.000633	 0.003601	 0.00104	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7243	 77337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7243	 77337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7244	 7248	 0.000506	 0.002966	 0.00081	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7244	 77338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7244	 77338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77338	 7245	 0.006297	 0.004076	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77336	 7246	 0.007022	 0.007723	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7247	 7250	 0.005501	 0.003977	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7247	 7251	 0.009072	 0.007179	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7247	 77339	 0.002625	 0.004211	 8e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7248	 77339	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7248	 77339	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7249	 7343	 0.0006	 0.002779	 5e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77334	 7249	 0.000894	 0.005082	 9e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7252	 7261	 0.000487	 0.002766	 0.0008	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7252	 77340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7252	 77340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7253	 7255	 0.000985	 0.003022	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7253	 7255	 0.000985	 0.003022	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7253	 7262	 0.000939	 0.005335	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77340	 7253	 0.000816	 0.005018	 9e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7254	 7255	 0.000403	 0.002258	 6e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7254	 77354	 0.001143	 0.00578	 0.0001	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7255	 7256	 0.00036	 0.002803	 5e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7256	 7257	 0.000533	 0.002643	 6e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77334	 7256	 0.001369	 0.003739	 6e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7257	 7336	 0.000887	 0.0034	 0.0001	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7258	 77354	 0.001584	 0.002847	 5e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7260	 7328	 0.005201	 0.005089	 7e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7261	 7266	 0.000427	 0.002499	 0.00068	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7261	 7329	 0.000678	 0.003019	 0.00082	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7261	 77341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7261	 77341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77279	 7262	 0.001127	 0.00634	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7263	 77342	 0.006491	 0.011889	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7264	 7310	 0.003224	 0.007407	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77341	 7264	 0.002038	 0.009081	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7265	 77342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7265	 77342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7266	 7269	 0.000293	 0.001887	 0.00049	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7268	 77344	 0.016864	 0.013346	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7269	 7271	 0.000282	 0.001789	 0.00049	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7269	 77343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7269	 77343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7270	 7272	 0.000272	 0.001827	 0.00044	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7270	 77344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7270	 77344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7271	 7282	 0.000164	 0.001021	 0.00029	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7272	 7274	 0.000272	 0.001724	 0.00047	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77270	 7273	 0.001166	 0.011424	 0.00022	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77343	 7273	 0.002201	 0.015676	 0.00035	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7274	 7275	 0.000201	 0.001293	 0.00034	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7275	 7276	 0.000384	 0.002324	 0.00059	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7276	 7280	 0.001132	 0.004302	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7276	 77345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7276	 77345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7277	 77347	 0.010324	 0.008171	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77345	 7278	 0.013372	 0.009666	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7279	 7280	 0.000359	 0.001409	 0.00037	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7279	 7283	 0.00053	 0.002083	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7281	 7282	 0.000577	 0.002311	 0.00058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7281	 77346	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7281	 77346	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7282	 77347	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7282	 77347	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7283	 7284	 0.000373	 0.001538	 0.00036	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7283	 77348	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7283	 77348	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7284	 7287	 0.000624	 0.002268	 0.00069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7285	 77349	 0.004572	 0.003618	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7286	 7287	 0.000716	 0.001891	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7286	 7301	 0.001374	 0.00363	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7287	 7297	 0.001299	 0.005496	 0.00124	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7287	 77349	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7287	 77349	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7288	 7289	 0.000896	 0.004321	 8e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77346	 7288	 0.002063	 0.00923	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7289	 77350	 0.001518	 0.005905	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7290	 7304	 0.001044	 0.003969	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7290	 77350	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7290	 77350	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7291	 7296	 0.001828	 0.011241	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77350	 7291	 0.001142	 0.007169	 0.00016	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7292	 77352	 0.013203	 0.010449	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7293	 7304	 0.000447	 0.001791	 0.00045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7293	 7313	 0.0006	 0.002359	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7294	 7295	 0.001195	 0.005326	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7294	 7299	 0.001917	 0.008196	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7295	 7314	 0.003046	 0.010053	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7296	 7299	 0.001359	 0.007723	 0.00014	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7297	 7302	 0.000465	 0.001918	 0.00045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7297	 77351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7297	 77351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77351	 7298	 0.005966	 0.006562	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7301	 77352	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7301	 77352	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7302	 7303	 0.000436	 0.001744	 0.00044	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7305	 7308	 0.00202	 0.004619	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77350	 7305	 0.002787	 0.008196	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7306	 7307	 0.004223	 0.00762	 0.00011	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76506	 7306	 0.002137	 0.004372	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76506	 7307	 0.004919	 0.011419	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7308	 7309	 0.002099	 0.008401	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7308	 7311	 0.000885	 0.006074	 0.00011	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77346	 7309	 0.002278	 0.011116	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7311	 7325	 0.001197	 0.007084	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77348	 7312	 0.038903	 0.028123	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7313	 7332	 0.000873	 0.003695	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7314	 7315	 0.002018	 0.005787	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7315	 7316	 0.002083	 0.007115	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7315	 7316	 0.002083	 0.007115	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7315	 7318	 0.000877	 0.006413	 0.00012	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7315	 7319	 0.008021	 0.006348	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7315	 7383	 0.005881	 0.027654	 0.00051	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7316	 7320	 0.00736	 0.005415	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7316	 7322	 0.002214	 0.007747	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7316	 7322	 0.002214	 0.007747	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7317	 7382	 0.000658	 0.001739	 0.00041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7317	 7384	 0.000858	 0.00349	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7317	 77353	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7317	 77353	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7318	 7381	 0.001796	 0.004761	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77353	 7318	 0.00091	 0.007091	 0.00013	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7321	 7333	 0.000991	 0.005151	 0.00011	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7321	 7380	 0.0009	 0.007654	 0.0002	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7321	 77355	 0.00148	 0.005178	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7321	 77355	 0.00148	 0.005178	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7322	 7324	 0.001192	 0.007968	 0.00018	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7322	 7331	 0.003051	 0.010178	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7323	 7331	 0.009314	 0.007371	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7324	 7325	 0.000433	 0.003375	 6e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7325	 7326	 0.001141	 0.002334	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7326	 7327	 0.001746	 0.004616	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7327	 7328	 0.001418	 0.004729	 7e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77341	 7328	 0.001348	 0.005596	 0.00015	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7329	 77354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7329	 77354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7330	 7335	 0.004142	 0.003277	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77354	 7330	 0.006143	 0.006691	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7331	 7334	 0.001797	 0.004619	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77354	 7331	 0.001768	 0.01087	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7332	 77355	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7332	 77355	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7333	 7377	 0.000969	 0.005163	 9e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	7334	 7337	 0.000982	 0.003509	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7334	 7338	 0.001733	 0.0043	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77355	 7334	 0.002379	 0.006822	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7336	 7337	 0.001308	 0.004578	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7336	 7344	 0.016968	 0.013428	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7338	 7339	 0.00375	 0.002656	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77355	 7338	 0.002187	 0.005562	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7340	 7341	 0.005501	 0.003977	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7341	 7343	 0.004873	 0.003738	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7342	 7343	 0.001197	 0.004655	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7342	 7345	 0.002783	 0.010288	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7345	 7346	 0.001765	 0.007215	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7345	 7372	 0.001665	 0.011124	 0.00025	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77337	 7345	 0.002434	 0.011682	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7346	 7347	 0.001461	 0.006438	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 7349	 0.001381	 0.007183	 0.00016	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 7362	 0.00163	 0.011357	 0.00027	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 77356	 0.001047	 0.004074	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 77356	 0.001047	 0.004074	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77335	 7348	 0.00036	 0.003902	 0.00164	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7348	 77356	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7348	 77356	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7349	 7350	 0.000899	 0.004175	 0.00011	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7350	 7361	 0.00101	 0.005109	 9e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7351	 7352	 0.001371	 0.005335	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7351	 7352	 0.001371	 0.005335	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77333	 7351	 0.002518	 0.006472	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7352	 7353	 0.001258	 0.00386	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7352	 7353	 0.001258	 0.00386	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7353	 7354	 0.002172	 0.012206	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7354	 7360	 0.01313	 0.00966	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7354	 7361	 0.001455	 0.005576	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7354	 7363	 0.008244	 0.0151	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7354	 77357	 0.007312	 0.029009	 0.00083	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7355	 7357	 0.00129	 0.007839	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7355	 7362	 0.002933	 0.018034	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7356	 7357	 0.002877	 0.005888	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7357	 77357	 0.002663	 0.012781	 0.00038	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7358	 7364	 0.004366	 0.010339	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7358	 77357	 0.004044	 0.010285	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7359	 7375	 0.001237	 0.007427	 0.00225	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76980	 7359	 0.007596	 0.026579	 0.00881	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7359	 77357	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7359	 77357	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7363	 7371	 0.001207	 0.007422	 0.00013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7364	 7368	 0.002363	 0.005404	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7365	 7366	 0.003817	 0.009706	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7365	 7367	 0.00956	 0.007566	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7365	 7387	 0.003802	 0.014792	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7365	 77358	 0.00458	 0.015277	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7366	 77358	 0.002321	 0.006153	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7368	 7369	 0.001942	 0.006479	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7369	 7370	 0.001221	 0.004752	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7369	 7370	 0.001221	 0.004752	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7369	 7374	 0.000892	 0.003952	 0.00012	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7370	 7371	 0.001621	 0.006305	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7370	 7371	 0.001621	 0.006305	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7371	 7372	 0.001245	 0.007652	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7371	 7373	 0.001304	 0.006948	 0.00012	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	7373	 7379	 0.001197	 0.006803	 0.00012	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7374	 77358	 0.000858	 0.005889	 0.00011	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7375	 7382	 0.000646	 0.001801	 0.00038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7375	 77358	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7375	 77358	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7376	 7378	 0.001371	 0.005801	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7376	 7380	 0.000777	 0.006954	 0.00015	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7376	 7381	 0.001945	 0.005	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77358	 7376	 0.002156	 0.008294	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77358	 7376	 0.002156	 0.008294	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7377	 7378	 0.00114	 0.005766	 0.0001	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77355	 7379	 0.00123	 0.008444	 0.00015	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76960	 7383	 0.002607	 0.013185	 0.00023	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7385	 7386	 0.012984	 0.010275	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7386	 7388	 0.003498	 0.010032	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76960	 7386	 0.002194	 0.009778	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7387	 7390	 0.004719	 0.014205	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7388	 7390	 0.007006	 0.012642	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7389	 7390	 0.006876	 0.006448	 0.0001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7390	 7392	 0.007867	 0.015575	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7390	 7394	 0.00413	 0.011847	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76962	 7390	 0.025534	 0.046073	 0.00067	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7391	 7392	 0.003144	 0.009016	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77357	 7391	 0.004111	 0.01179	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7392	 7393	 0.002716	 0.005051	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7392	 7395	 0.010541	 0.008342	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7393	 7397	 0.005097	 0.010092	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7396	 7397	 0.001581	 0.009607	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76967	 7396	 0.000744	 0.005045	 9e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7397	 7398	 0.002587	 0.009051	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77357	 7398	 0.002031	 0.00991	 0.00017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7399	 7400	 0.014599	 0.019188	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7399	 7691	 0.011303	 0.011306	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7400	 7401	 0.019698	 0.01544	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7401	 7403	 0.015888	 0.017475	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7401	 7412	 0.018554	 0.012012	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7402	 7403	 0.004996	 0.00609	 0.0001	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7404	 7405	 0.002904	 0.007465	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7404	 7411	 0.004566	 0.011737	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7405	 7406	 0.002707	 0.006958	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76574	 7408	 0.003794	 0.026689	 0.00053	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7409	 7410	 0.009804	 0.014869	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7409	 7431	 0.00408	 0.025067	 0.00057	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7410	 7411	 0.009471	 0.018751	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76540	 7413	 0.000129	 0.000878	 0.00158	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	7413	 77359	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7413	 77359	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76567	 7414	 0.005083	 0.016774	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7415	 77360	 0.014695	 0.014842	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 8243	 0.016818	 0.098545	 0.02686	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7416	 77360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7416	 77360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7417	 7418	 0.13611	 0.10669	 0.00137	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7418	 7673	 0.055411	 0.1086	 0.00163	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7419	 7690	 0.079485	 0.060222	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7420	 7421	 0.083195	 0.065841	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7420	 7423	 0.11693	 0.09166	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7421	 7422	 0.053127	 0.052189	 0.00088	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7421	 7690	 0.026822	 0.068949	 0.00107	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7422	 7431	 0.057098	 0.058303	 0.00091	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7424	 7425	 0.011944	 0.1112	 0.00215	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77360	 7424	 0.017397	 0.1239	 0.00278	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7425	 7426	 0.011798	 0.10039	 0.00262	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7426	 7427	 0.081885	 0.064804	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7426	 7431	 0.025882	 0.099577	 0.0017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7426	 7431	 0.025882	 0.099577	 0.0017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7428	 7432	 0.082582	 0.053465	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7429	 7431	 0.003986	 0.033158	 0.00063	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7429	 77361	 0.004669	 0.045749	 0.0009	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7430	 7431	 0.042478	 0.033297	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7432	 77361	 0.059424	 0.047028	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77359	 7433	 0.001652	 0.006008	 0.00184	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7433	 77361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7433	 77361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76487	 7434	 0.001424	 0.008845	 0.0025	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7434	 77362	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7434	 77362	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7435	 77363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7435	 77363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7436	 7438	 0.046765	 0.083532	 0.00123	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7436	 7439	 0.057021	 0.044696	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77362	 7436	 0.037696	 0.096904	 0.0015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76549	 7437	 0.003849	 0.00762	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7438	 7440	 0.16217	 0.12835	 0.00162	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7441	 7443	 0.001059	 0.005796	 0.00011	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7441	 77366	 0.002585	 0.011518	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7442	 77364	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7442	 77364	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7443	 7445	 0.000621	 0.003817	 7e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7444	 7457	 0.000169	 0.001861	 0.00111	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7444	 77365	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7444	 77365	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7445	 7446	 0.000357	 0.003364	 7e-05	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7445	 7467	 0.000931	 0.007742	 0.00015	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7446	 7447	 0.007295	 0.005168	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7446	 77371	 0.002344	 0.007192	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7446	 77371	 0.002344	 0.007192	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7448	 7464	 0.014112	 0.011168	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7449	 7450	 0.001554	 0.004767	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7449	 7450	 0.001554	 0.004767	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77365	 7449	 0.000577	 0.005356	 0.00012	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7450	 7464	 0.002411	 0.009379	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7450	 7464	 0.002411	 0.009379	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 7452	 8.9e-05	 0.001229	 0.00085	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 7470	 0.000318	 0.004894	 0.00272	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 77366	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7451	 77366	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7452	 77367	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7452	 77367	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7453	 7457	 0.000103	 0.001344	 0.00059	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7453	 7458	 0.000119	 0.001864	 0.00122	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7453	 77368	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7453	 77368	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7454	 77371	 0.009872	 0.010753	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7455	 77369	 0.007337	 0.005398	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7456	 77370	 0.009845	 0.007791	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7457	 77369	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7457	 77369	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7458	 7510	 0.000154	 0.002581	 0.00146	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77369	 7459	 0.002732	 0.009333	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77369	 7459	 0.002732	 0.009333	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7459	 77372	 0.002349	 0.009138	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7459	 77372	 0.002349	 0.009138	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7460	 7465	 0.000373	 0.002813	 0.00078	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7460	 7495	 0.000481	 0.003787	 0.00111	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7460	 77370	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7460	 77370	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77369	 7461	 0.004353	 0.016935	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77369	 7461	 0.004353	 0.016935	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7461	 77372	 0.001989	 0.007651	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7461	 77372	 0.001989	 0.007651	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7462	 77373	 0.011807	 0.009344	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7463	 7464	 0.003298	 0.012829	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7463	 7464	 0.003298	 0.012829	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7463	 7472	 0.003375	 0.010354	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7463	 7472	 0.003375	 0.010354	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77369	 7463	 0.004468	 0.021449	 0.00064	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7465	 77371	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7465	 77371	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77371	 7466	 0.006946	 0.004497	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77371	 7467	 0.000901	 0.008291	 0.00016	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7468	 7469	 0.000211	 0.001562	 0.0008	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7468	 77372	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7468	 77372	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7469	 7474	 0.000156	 0.001099	 0.00063	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7470	 7486	 0.000137	 0.002171	 0.00137	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7470	 7513	 0.000668	 0.009644	 0.00306	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7470	 77373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7470	 77373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7470	 78036	 0.00022	 0.003582	 0.00214	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7471	 7486	 0.000304	 0.002397	 0.0007	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7471	 7495	 0.000411	 0.003947	 0.00115	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7471	 77374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7471	 77374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7472	 7473	 0.002934	 0.010482	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7472	 77375	 0.004937	 0.015144	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7472	 77375	 0.004937	 0.015144	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7473	 7479	 0.00189	 0.00889	 0.00017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7474	 7475	 0.00017	 0.001194	 0.00068	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7475	 7477	 0.000192	 0.001328	 0.00078	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77374	 7476	 0.013087	 0.010357	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7477	 7487	 0.000209	 0.0019	 0.00062	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7477	 7536	 0.001431	 0.011421	 0.00281	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7477	 77375	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7477	 77375	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7478	 7489	 0.009856	 0.0078	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7479	 7481	 0.004166	 0.007978	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7479	 77389	 0.006389	 0.049211	 0.00094	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7480	 7481	 0.011769	 0.009314	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7482	 7484	 0.003169	 0.008213	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7482	 77377	 0.002571	 0.007374	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7483	 7491	 0.017141	 0.012611	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7484	 77379	 0.001999	 0.008346	 0.00024	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	7485	 77376	 0.005936	 0.003843	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7486	 7519	 9.4e-05	 0.001531	 0.00091	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7486	 77376	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7486	 77376	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7487	 7492	 0.000884	 0.005779	 0.00147	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7487	 77377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7487	 77377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7488	 7492	 0.001139	 0.003298	 0.0008	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7488	 77378	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7488	 77378	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77376	 7489	 0.00772	 0.008122	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7490	 7497	 0.003912	 0.009263	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7490	 7501	 0.00871	 0.022391	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7490	 7506	 0.014698	 0.011632	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7490	 7507	 0.005565	 0.012919	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7490	 77389	 0.020237	 0.032463	 0.0006	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7491	 7494	 0.001651	 0.005449	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7491	 77379	 0.003056	 0.007235	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7492	 7513	 0.000671	 0.010793	 0.00353	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7492	 7534	 0.002677	 0.010413	 0.00278	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7492	 7536	 0.000653	 0.00665	 0.00171	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7492	 9969	 0.003963	 0.057212	 0.01817	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7492	 77379	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7492	 77379	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7493	 7494	 0.001691	 0.006254	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7493	 7507	 0.002361	 0.008066	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7495	 7496	 0.00014	 0.002134	 0.00069	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7495	 77380	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7495	 77380	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7496	 7514	 0.000215	 0.002266	 0.00127	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	7496	 77381	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7496	 77381	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7497	 7498	 0.013303	 0.010427	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7497	 7499	 0.011691	 0.009252	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77380	 7500	 0.013999	 0.011079	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7501	 7504	 0.002111	 0.008123	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7501	 7509	 0.017452	 0.013811	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7502	 7503	 0.001167	 0.007174	 0.00013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7502	 77382	 0.001477	 0.007905	 0.00024	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7503	 7507	 0.001201	 0.005261	 0.00011	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7504	 7522	 0.003546	 0.01183	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7504	 77382	 0.001962	 0.009926	 0.00017	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7505	 7526	 0.001981	 0.008179	 0.00194	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7505	 77382	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7505	 77382	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7508	 7510	 0.000126	 0.002104	 0.00119	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7508	 7513	 6.9e-05	 0.001154	 0.00065	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 77383	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7510	 77383	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7511	 77384	 0.024838	 0.019469	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7512	 77385	 0.01593	 0.012487	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7513	 7514	 0.00015	 0.002334	 0.00152	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7513	 77384	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7513	 77384	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7514	 7515	 9.6e-05	 0.001371	 0.00072	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7514	 77390	 0.000399	 0.006223	 0.00407	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7515	 7534	 0.000163	 0.002206	 0.00128	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7515	 77385	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7515	 77385	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7516	 7518	 0.002007	 0.007419	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7516	 7518	 0.002007	 0.007419	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7516	 7533	 0.002336	 0.007981	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7516	 7533	 0.002336	 0.007981	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7517	 77386	 0.010882	 0.027674	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7518	 9570	 0.00716	 0.027853	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7518	 9570	 0.00716	 0.027853	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77381	 7518	 0.003009	 0.007734	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7519	 7523	 8.1e-05	 0.001268	 0.00039	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7519	 77390	 0.000538	 0.009543	 0.0048	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77382	 7520	 0.006461	 0.011834	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7521	 7522	 0.002538	 0.008139	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7521	 77386	 0.003823	 0.014873	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7523	 7531	 8.6e-05	 0.00136	 0.00046	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7524	 77387	 0.00494	 0.007012	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76475	 7525	 0.002602	 0.016479	 0.00447	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7525	 77386	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7525	 77386	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76475	 7526	 0.00112	 0.005221	 0.00129	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7527	 7528	 8.3e-05	 0.001419	 0.00041	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7527	 7545	 0.000119	 0.00176	 0.00054	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7527	 77387	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7527	 77387	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7528	 7531	 9.4e-05	 0.001613	 0.00046	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7529	 7530	 0.011082	 0.00877	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7529	 7532	 0.004887	 0.007327	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77386	 7532	 0.008372	 0.024012	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7533	 77391	 0.003844	 0.013448	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7533	 77391	 0.003844	 0.013448	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7534	 7542	 0.000245	 0.003867	 0.00116	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7534	 7543	 0.000713	 0.004518	 0.00123	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7534	 77388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7534	 77388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77388	 7535	 0.017451	 0.011298	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76475	 7536	 0.00037	 0.005553	 0.00325	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7536	 77389	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7536	 77389	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7537	 7538	 0.008121	 0.006229	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7538	 7539	 0.002317	 0.004489	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77388	 7538	 0.005396	 0.01224	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77389	 7538	 0.004262	 0.010837	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77389	 7539	 0.004851	 0.009927	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7539	 77391	 0.011481	 0.026655	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77389	 7540	 0.019676	 0.015423	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7541	 77390	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7541	 77390	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7541	 77626	 3.6e-05	 0.000657	 0.01211	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77390	 7542	 0.000232	 0.00357	 0.001	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7543	 7545	 0.000181	 0.002548	 0.00087	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77390	 7543	 0.000223	 0.003646	 0.0018	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7543	 77391	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7543	 77391	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7544	 77392	 0.00809	 0.006402	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7545	 77392	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7545	 77392	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77387	 7546	 0.008591	 0.006798	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7547	 77393	 0.00587	 0.011621	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77390	 7548	 0.001321	 0.006635	 0.00173	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7548	 77393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7548	 77393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7549	 7550	 0.000182	 0.002065	 0.0188	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	7549	 77394	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7549	 77394	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7550	 77395	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77396	 7551	 0.008602	 0.017032	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7552	 7555	 0.005571	 0.014167	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77396	 7552	 0.009361	 0.022166	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7552	 77397	 0.004599	 0.020495	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7553	 7577	 0.00301	 0.012051	 0.00304	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77394	 7553	 0.004968	 0.019889	 0.00501	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7553	 77397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7553	 77397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77397	 7554	 0.023562	 0.05215	 0.00086	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7555	 7556	 0.007082	 0.01801	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76465	 7556	 0.0043	 0.008513	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7557	 7561	 0.001423	 0.007151	 0.00186	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7557	 7565	 0.00234	 0.014822	 0.00402	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76464	 7557	 0.000279	 0.002471	 0.00136	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7557	 77398	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7557	 77398	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77398	 7558	 0.003576	 0.006388	 9e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77398	 7559	 0.00908	 0.015296	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77398	 7560	 0.007421	 0.033206	 0.00068	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7560	 77406	 0.008856	 0.034451	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7561	 7564	 0.001638	 0.00693	 0.00156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7561	 77399	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7561	 77399	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77399	 7562	 0.006817	 0.016143	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7562	 77400	 0.025587	 0.020249	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 7574	 0.001332	 0.005334	 0.00134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76464	 7563	 0.003755	 0.017224	 0.00441	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 77400	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7563	 77400	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7564	 7565	 0.001405	 0.004819	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7565	 7567	 0.000673	 0.007369	 0.00204	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7566	 7567	 0.002045	 0.005256	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7566	 77411	 0.002068	 0.005316	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7567	 8430	 0.002416	 0.018201	 0.00505	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7568	 7609	 5e-05	 0.000879	 0.00941	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	7568	 77401	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7569	 7574	 0.002254	 0.007594	 0.00189	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77401	 7569	 0.002532	 0.006574	 0.0016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7570	 7571	 0.000951	 0.004955	 0.0013	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7570	 7579	 0.001675	 0.006583	 0.00172	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76464	 7570	 0.007539	 0.029632	 0.00775	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7570	 77403	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7570	 77403	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7571	 77404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7571	 77404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77402	 7572	 0.017708	 0.045521	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77403	 7572	 0.004117	 0.022669	 0.00051	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7573	 7576	 0.009548	 0.018904	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7573	 77406	 0.007649	 0.01716	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7575	 7576	 0.008924	 0.011214	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77403	 7575	 0.008926	 0.011732	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7577	 7578	 0.001564	 0.006617	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7577	 7582	 0.001844	 0.013388	 0.00463	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7578	 7581	 0.001362	 0.004766	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7579	 7581	 0.001098	 0.004271	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7579	 77405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7579	 77405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7580	 77406	 0.010827	 0.007827	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7581	 77406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7581	 77406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7582	 7585	 0.002476	 0.009915	 0.0025	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7583	 7584	 0.002646	 0.008036	 0.00176	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7583	 77407	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7583	 77407	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7584	 7588	 0.002227	 0.008916	 0.00225	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7584	 77408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7584	 77408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76550	 7586	 0.006302	 0.004987	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7587	 7589	 0.017897	 0.013728	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7587	 77409	 0.014329	 0.011232	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7588	 77409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7588	 77409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7590	 7592	 0.001247	 0.008335	 0.00018	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77407	 7590	 0.002061	 0.016062	 0.0003	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7591	 7592	 0.001793	 0.010894	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7591	 7593	 0.004804	 0.008093	 0.00012	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7591	 7598	 0.00198	 0.009506	 0.00028	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7593	 7599	 0.006274	 0.0067	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7594	 7599	 0.004758	 0.009324	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7594	 7601	 0.003131	 0.016682	 0.00029	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77403	 7594	 0.013826	 0.035541	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7595	 7597	 0.014282	 0.011302	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7595	 7598	 0.003129	 0.007262	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77405	 7595	 0.004741	 0.011008	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7596	 7597	 0.008447	 0.006621	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7598	 7600	 0.014439	 0.011427	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77403	 7598	 0.007892	 0.018688	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77408	 7601	 0.00473	 0.029077	 0.00052	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77404	 7602	 0.009608	 0.024697	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7603	 7604	 0.001073	 0.003615	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7604	 7605	 0.000776	 0.005847	 0.00162	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7604	 8864	 0.003326	 0.023075	 0.00659	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7605	 7606	 0.000633	 0.003931	 0.00111	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7606	 7607	 0.001159	 0.004787	 0.00113	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7606	 7612	 0.001154	 0.007744	 0.00187	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7606	 8415	 0.003815	 0.030645	 0.00861	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76464	 7606	 0.013101	 0.045663	 0.01059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77401	 7607	 0.002722	 0.010899	 0.00275	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7607	 77410	 0.001552	 0.005619	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7608	 7610	 9.4e-05	 0.001044	 0.00984	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	7608	 7611	 9.5e-05	 0.00111	 0.01065	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7608	 77410	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7608	 77410	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7609	 7610	 4.4e-05	 0.000516	 0.00446	 1000.0	 1050.0	 1100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7609	 77411	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7609	 77411	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7611	 7613	 8.3e-05	 0.00091	 0.00884	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	7612	 77412	 0.0013	 0.006762	 0.00199	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7613	 8410	 0.000196	 0.002172	 0.02068	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	7613	 77412	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7613	 77412	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76526	 7614	 0.001937	 0.012996	 0.00314	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7614	 77413	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7614	 77413	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7615	 7617	 0.13276	 0.095974	 0.00146	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76520	 7615	 0.010382	 0.019621	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7616	 7636	 0.1875	 0.43554	 0.00648	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77413	 7616	 0.006546	 0.035029	 0.00106	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7618	 7626	 0.16381	 0.18019	 0.00241	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7618	 77414	 0.11193	 0.1825	 0.00278	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7619	 77414	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7619	 77414	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77414	 7620	 0.18038	 0.14277	 0.0018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7621	 7624	 0.034909	 0.038023	 0.00052	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7621	 7632	 0.13257	 0.13391	 0.00177	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7622	 7624	 0.066027	 0.048579	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7622	 7625	 0.047818	 0.037482	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77414	 7622	 0.071119	 0.16513	 0.00246	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7624	 7625	 0.03641	 0.026321	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76559	 7626	 0.08648	 0.11255	 0.00157	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7627	 7633	 0.029264	 0.078584	 0.01781	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7627	 77415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7627	 77415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7628	 7629	 0.010887	 0.014168	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77415	 7628	 0.016577	 0.026461	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7629	 7630	 0.069392	 0.062181	 0.00127	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7630	 7631	 0.078113	 0.20082	 0.00311	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7630	 7640	 0.23264	 0.18238	 0.00234	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7631	 7639	 0.047541	 0.12601	 0.0032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7631	 77416	 0.11064	 0.19765	 0.00292	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7632	 7634	 0.10235	 0.081002	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7632	 77416	 0.039298	 0.043223	 0.00058	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7633	 77416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7633	 77416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76560	 7635	 0.021715	 0.076032	 0.0021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76563	 7635	 0.011465	 0.038248	 0.00061	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76560	 7636	 0.049735	 0.15275	 0.00287	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76560	 7637	 0.14963	 0.26322	 0.00495	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7639	 7641	 0.24517	 0.17371	 0.00275	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77416	 7639	 0.13309	 0.32588	 0.00557	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7643	 7644	 0.025367	 0.020075	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 8214	 0.002307	 0.013116	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 77524	 0.003635	 0.017737	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 77526	 0.011432	 0.089106	 0.00167	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7645	 7646	 0.022272	 0.051708	 0.00077	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76556	 7645	 0.035893	 0.066739	 0.00156	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76511	 7646	 0.001767	 0.014701	 0.00028	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76556	 7647	 0.017953	 0.04615	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7649	 7651	 0.043681	 0.11109	 0.00176	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7649	 7666	 0.14201	 0.091944	 0.00175	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7650	 77418	 0.073516	 0.054089	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76759	 7651	 0.041528	 0.18196	 0.00391	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7651	 77421	 0.044928	 0.13798	 0.00259	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7652	 7653	 0.00245	 0.010368	 0.00233	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7652	 77417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7652	 77417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7653	 7662	 0.002621	 0.010495	 0.00264	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7653	 77418	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7653	 77418	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7654	 7656	 0.068907	 0.080775	 0.0014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77417	 7654	 0.029225	 0.075126	 0.00116	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7655	 7656	 0.09361	 0.074083	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7657	 7659	 0.000353	 0.001803	 0.00045	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7657	 7662	 0.001452	 0.005995	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7657	 77419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7657	 77419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7658	 7660	 0.024903	 0.019102	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77419	 7658	 0.006002	 0.013931	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7659	 7661	 0.001457	 0.007587	 0.00199	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7661	 7670	 0.005209	 0.018861	 0.00405	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7661	 7672	 0.008151	 0.034497	 0.00776	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7661	 77420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7661	 77420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77420	 7663	 0.031857	 0.075437	 0.00138	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7664	 77421	 0.022847	 0.017909	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77420	 7665	 0.050401	 0.03263	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7667	 7668	 0.13855	 0.1086	 0.00139	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7667	 7720	 0.086083	 0.063335	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7668	 7669	 0.011008	 0.041293	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7668	 77421	 0.007783	 0.047301	 0.00087	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7669	 7719	 0.015886	 0.052993	 0.00084	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7670	 77421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7670	 77421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77421	 7671	 0.04613	 0.050737	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7672	 7681	 0.001838	 0.013426	 0.00345	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7672	 77422	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7672	 77422	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7673	 7674	 0.064246	 0.048676	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7673	 8249	 0.02617	 0.10027	 0.00283	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77422	 7673	 0.009559	 0.054381	 0.00167	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7675	 7676	 0.007336	 0.005806	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7675	 7683	 0.044571	 0.045018	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7677	 7679	 0.015026	 0.02794	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7677	 7684	 0.010921	 0.028072	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7678	 7679	 0.027839	 0.043438	 0.00073	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7679	 77423	 0.023392	 0.054307	 0.00081	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7680	 7686	 0.039469	 0.029038	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7681	 7687	 0.003136	 0.011086	 0.0025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7681	 77426	 0.004729	 0.031722	 0.00766	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7682	 7689	 0.018163	 0.04301	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7682	 77423	 0.011978	 0.027803	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7683	 7686	 0.01849	 0.037839	 0.00093	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7684	 7685	 0.004017	 0.022836	 0.00041	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76572	 7684	 0.007979	 0.038301	 0.00114	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7685	 77427	 0.008659	 0.053235	 0.00096	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7686	 77423	 0.004576	 0.016012	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7687	 77423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7687	 77423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7688	 7689	 0.079363	 0.051381	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7689	 77427	 0.0134	 0.044702	 0.00071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7690	 7691	 0.020756	 0.020964	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7690	 77427	 0.020619	 0.12948	 0.00283	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7692	 7693	 0.010569	 0.006842	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7692	 7710	 0.017181	 0.011123	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7694	 7713	 0.014424	 0.028557	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7694	 7716	 0.019554	 0.056083	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7694	 77429	 0.006492	 0.015072	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7695	 7701	 0.007565	 0.00832	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7695	 77429	 0.006698	 0.012269	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7696	 77424	 0.01762	 0.012738	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7697	 7707	 0.001453	 0.003839	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7697	 77424	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7697	 77424	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7697	 77426	 0.003338	 0.008962	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77424	 7698	 0.011306	 0.008863	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7699	 7700	 0.01216	 0.009623	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7699	 77429	 0.006772	 0.010566	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7701	 7702	 0.010434	 0.007905	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7703	 7734	 0.021736	 0.017201	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7704	 7705	 0.009304	 0.007293	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7705	 7734	 0.005454	 0.016037	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7705	 77425	 0.001862	 0.008299	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7706	 7707	 0.001237	 0.003213	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7706	 7722	 0.005844	 0.023396	 0.00589	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7706	 77425	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7706	 77425	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7706	 77426	 0.005613	 0.014572	 0.00354	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7708	 7709	 0.009357	 0.024249	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7708	 7724	 0.013505	 0.020688	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7708	 77427	 0.008867	 0.047245	 0.00083	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	7709	 7712	 0.033927	 0.026594	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7710	 77427	 0.010559	 0.022543	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7711	 77426	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7713	 7714	 0.015973	 0.01252	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7715	 7719	 0.010532	 0.036873	 0.00102	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7715	 77429	 0.006076	 0.034538	 0.00062	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7716	 7717	 0.021026	 0.0261	 0.00057	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7716	 77428	 0.007916	 0.035273	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7718	 7719	 0.029421	 0.02229	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7721	 7728	 0.034372	 0.022252	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7722	 7738	 0.017746	 0.10738	 0.02742	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77426	 7722	 0.008357	 0.034006	 0.00829	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7722	 77428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7722	 77428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7723	 7728	 0.019276	 0.015254	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7724	 7725	 0.008148	 0.013006	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7725	 7727	 0.021708	 0.017179	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7725	 7732	 0.021245	 0.016813	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77425	 7725	 0.00659	 0.016939	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7726	 7728	 0.027904	 0.02053	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7728	 7734	 0.020418	 0.040425	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77428	 7729	 0.062856	 0.04927	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77428	 7730	 0.053179	 0.12345	 0.00235	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7731	 7732	 0.012863	 0.010082	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77426	 7733	 0.002519	 0.010086	 0.00254	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7733	 77429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7733	 77429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77429	 7734	 0.013127	 0.02813	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7735	 77430	 0.074237	 0.12506	 0.00178	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7736	 7738	 0.006538	 0.025435	 0.00679	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76479	 7736	 0.017096	 0.072372	 0.01629	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7736	 77430	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7736	 77430	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77430	 7737	 0.00905	 0.040496	 0.00083	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7737	 77432	 0.020073	 0.10154	 0.00177	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7738	 77431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7738	 77431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7739	 77432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7739	 77432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76480	 7740	 0.022194	 0.098896	 0.00168	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77432	 7740	 0.020586	 0.095453	 0.00198	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77430	 7741	 0.081125	 0.1486	 0.00257	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76480	 7742	 0.016538	 0.056494	 0.00123	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7743	 7744	 0.013751	 0.036918	 0.00837	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7743	 77433	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7743	 77433	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7744	 7746	 0.006082	 0.024749	 0.00603	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7744	 77434	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7744	 77434	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7745	 7772	 0.11392	 0.086315	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77434	 7745	 0.13911	 0.098549	 0.00156	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7746	 77435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7746	 77435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77435	 7747	 0.053548	 0.13619	 0.00215	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7748	 7752	 0.003836	 0.017599	 0.00451	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7748	 8270	 0.005513	 0.025293	 0.00648	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7749	 7750	 0.013444	 0.038558	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7749	 77436	 0.018537	 0.043036	 0.00064	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7749	 77534	 0.039479	 0.17593	 0.00299	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7751	 7752	 0.004372	 0.012664	 0.00305	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7751	 7754	 0.007263	 0.019774	 0.00436	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7751	 77436	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7751	 77436	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7752	 77437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7752	 77437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77437	 7753	 0.046071	 0.050181	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7754	 7755	 0.011369	 0.030048	 0.00703	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7756	 7757	 0.039178	 0.072848	 0.00171	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76501	 7756	 0.054694	 0.1391	 0.0022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76495	 7757	 0.028563	 0.053111	 0.00124	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7758	 7771	 0.01283	 0.03391	 0.00794	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7758	 8508	 0.011638	 0.027015	 0.00823	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7759	 7760	 0.18136	 0.12848	 0.00203	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76512	 7760	 0.036188	 0.07606	 0.00139	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7761	 7762	 0.15295	 0.12105	 0.00152	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7763	 7764	 0.001609	 0.00438	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7763	 77438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7763	 77438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7764	 77439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7764	 77439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7765	 7766	 0.013857	 0.010861	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77438	 7765	 0.00492	 0.018928	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77439	 7765	 0.004355	 0.014371	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7767	 7776	 0.21937	 0.17363	 0.00219	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76512	 7767	 0.009521	 0.08864	 0.00172	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77439	 7767	 0.035834	 0.12539	 0.0026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77439	 7767	 0.035834	 0.12539	 0.0026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7768	 7775	 0.046531	 0.14006	 0.00274	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76512	 7768	 0.044451	 0.15185	 0.0033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76512	 7768	 0.044451	 0.15185	 0.0033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7768	 77440	 0.010061	 0.058673	 0.00118	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7769	 7771	 0.009214	 0.025695	 0.00539	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7769	 77440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7769	 77440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77440	 7770	 0.068851	 0.069543	 0.00092	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7773	 7774	 0.038372	 0.11006	 0.00169	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77435	 7773	 0.055361	 0.15879	 0.00244	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7774	 77441	 0.040613	 0.083113	 0.00205	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7775	 7779	 0.033117	 0.10929	 0.00177	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7778	 77441	 0.10235	 0.20267	 0.00298	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7779	 77441	 0.029388	 0.083394	 0.00131	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7780	 77441	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7780	 77441	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7781	 7782	 0.005637	 0.014492	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77441	 7781	 0.025094	 0.063817	 0.00101	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7782	 7784	 0.009045	 0.014437	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7783	 7784	 0.006603	 0.015326	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77441	 7783	 0.02563	 0.065885	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7784	 7785	 0.009374	 0.036466	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7784	 7786	 0.045833	 0.036271	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7784	 7787	 0.15729	 0.12448	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76682	 7785	 0.030478	 0.10671	 0.00295	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7788	 77442	 0.046419	 0.04643	 0.00063	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7789	 7790	 0.001035	 0.006209	 0.00188	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76473	 7790	 0.004339	 0.021948	 0.00611	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7790	 77442	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7790	 77442	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7791	 7792	 0.005442	 0.012445	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77442	 7791	 0.008154	 0.020737	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7792	 7793	 0.00442	 0.012678	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7793	 77443	 0.007101	 0.018403	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7794	 7795	 0.001053	 0.004287	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7794	 77443	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7794	 77443	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7794	 77445	 0.001373	 0.005586	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7795	 7806	 0.001399	 0.0056	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7795	 77444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7795	 77444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7796	 7901	 0.000866	 0.008379	 0.02964	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76472	 7796	 8.8e-05	 0.001537	 0.00516	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76472	 7796	 8.8e-05	 0.001537	 0.00516	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7796	 77445	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77446	 7796	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76474	 7797	 0.058522	 0.041455	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7798	 7882	 0.011634	 0.029906	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77446	 7798	 0.007302	 0.019353	 0.00049	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7799	 7800	 0.000389	 0.003121	 0.00088	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7799	 7801	 0.000295	 0.002298	 0.00069	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7799	 77447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7799	 77447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7800	 7803	 0.000482	 0.003868	 0.00109	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7801	 7806	 0.000627	 0.004771	 0.0015	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77442	 7802	 0.015568	 0.040018	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7803	 7822	 0.000915	 0.005981	 0.00152	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7803	 77448	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7803	 77448	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7804	 7805	 0.002533	 0.009743	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7804	 77449	 0.004556	 0.015197	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77448	 7805	 0.004333	 0.014455	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7806	 7808	 0.00308	 0.009352	 0.00205	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77445	 7806	 0.002913	 0.012979	 0.00353	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7807	 77449	 0.016223	 0.012716	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7808	 77449	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7808	 77449	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7809	 7810	 0.017391	 0.011259	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7809	 7815	 0.012188	 0.023886	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77444	 7809	 0.006594	 0.013494	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7811	 7812	 0.009139	 0.023493	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77449	 7811	 0.006412	 0.015696	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7812	 7815	 0.011424	 0.038109	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7812	 7827	 0.00702	 0.016296	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7813	 7814	 0.001975	 0.009989	 0.00017	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77443	 7813	 0.002643	 0.01576	 0.00044	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77446	 7813	 0.004794	 0.01865	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7814	 7816	 0.004006	 0.017128	 0.00039	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77446	 7815	 0.011315	 0.037341	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7816	 7817	 0.012422	 0.009831	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7816	 7819	 0.006464	 0.013229	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7818	 7826	 0.017802	 0.02727	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7818	 7827	 0.009279	 0.023852	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7819	 7820	 0.005639	 0.010174	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7819	 7893	 0.007044	 0.017914	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7820	 7821	 0.005733	 0.009575	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7821	 7826	 0.009642	 0.01608	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7823	 7828	 0.003987	 0.017768	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77448	 7823	 0.004348	 0.017769	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7824	 7832	 0.013847	 0.032147	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77449	 7824	 0.009354	 0.021716	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7825	 7827	 0.018588	 0.01457	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7826	 77464	 0.007511	 0.021313	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7828	 77451	 0.009484	 0.036896	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7829	 77450	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7830	 7847	 0.011842	 0.027493	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7831	 77464	 0.035278	 0.024989	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7832	 7833	 0.010244	 0.021953	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7833	 77454	 0.00887	 0.020593	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77451	 7834	 0.006127	 0.026842	 0.00058	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7834	 77454	 0.007775	 0.030249	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7835	 7836	 0.001149	 0.00695	 0.00177	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7835	 7857	 0.001378	 0.006323	 0.00162	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77450	 7835	 0.001527	 0.011283	 0.00326	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7835	 77452	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7835	 77452	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7836	 77453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7836	 77453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7836	 77465	 0.005349	 0.035883	 0.00866	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7837	 7862	 0.006942	 0.015876	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76539	 7837	 0.004242	 0.012473	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7838	 7840	 0.001304	 0.005073	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7838	 7845	 0.000374	 0.001716	 0.00044	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77450	 7838	 0.001935	 0.013683	 0.00375	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7838	 77454	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7838	 77454	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77453	 7839	 0.005258	 0.015079	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7839	 77455	 0.003268	 0.010785	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7840	 7842	 0.000848	 0.005213	 0.0015	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7840	 77455	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7840	 77455	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7841	 7853	 0.004904	 0.012607	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76539	 7841	 0.010481	 0.026943	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77455	 7841	 0.005638	 0.01309	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7842	 7849	 0.001345	 0.004892	 0.0015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7842	 77456	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7842	 77456	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77456	 7843	 0.012994	 0.008728	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77456	 7844	 0.011246	 0.020292	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7845	 7910	 0.003303	 0.019825	 0.006	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7845	 77457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7845	 77457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7846	 7847	 0.005468	 0.014055	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77456	 7846	 0.00411	 0.010565	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77457	 7846	 0.00202	 0.009858	 0.00017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7849	 7850	 0.001505	 0.00491	 0.0013	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7849	 77458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7849	 77458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7850	 77459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7850	 77459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7851	 7852	 0.005725	 0.01029	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7851	 7853	 0.005674	 0.014586	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7852	 7854	 0.026811	 0.021218	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77456	 7854	 0.026866	 0.036622	 0.00081	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7855	 7856	 0.014892	 0.010957	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7856	 7878	 0.009525	 0.021882	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7856	 7954	 0.00233	 0.010385	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77459	 7856	 0.002913	 0.016039	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7857	 7858	 0.000716	 0.003944	 0.00142	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7857	 77460	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7857	 77460	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7858	 7860	 0.000952	 0.003447	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7858	 7861	 0.00083	 0.002848	 0.00068	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77460	 7859	 0.00784	 0.018198	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7860	 7865	 0.000718	 0.002461	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7861	 77461	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7861	 77461	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77461	 7862	 0.005636	 0.013084	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7863	 7865	 0.001504	 0.004037	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7863	 77462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7863	 77462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77462	 7864	 0.020963	 0.01659	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7865	 77463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7865	 77463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7866	 7867	 0.004132	 0.010621	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77463	 7866	 0.005412	 0.013912	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7867	 7868	 0.007379	 0.014611	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7868	 7873	 0.006497	 0.012732	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7869	 7872	 0.005392	 0.013198	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77461	 7869	 0.006048	 0.019475	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7870	 7871	 0.013989	 0.010292	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7872	 7873	 0.003262	 0.008385	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7873	 7874	 0.008923	 0.009112	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7876	 7879	 0.012956	 0.010155	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7877	 7958	 0.0429	 0.072269	 0.00103	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7878	 7880	 0.005201	 0.01421	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7881	 7887	 0.010807	 0.025591	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7882	 7883	 0.010012	 0.025736	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7883	 7888	 0.006217	 0.015981	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 7886	 0.015344	 0.023502	 0.00041	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 7891	 0.043277	 0.033923	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7885	 7902	 0.025409	 0.01645	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7886	 7887	 0.008451	 0.034539	 0.0007	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7886	 7903	 0.017765	 0.019711	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7886	 77488	 0.049101	 0.1032	 0.00188	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7887	 7888	 0.006966	 0.01617	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7887	 7896	 0.016291	 0.021411	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7889	 7890	 0.001038	 0.004157	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7889	 7905	 0.002213	 0.007713	 0.00179	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7890	 7981	 0.001649	 0.006979	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7892	 77483	 0.023583	 0.018485	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7893	 7894	 0.004164	 0.010705	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7894	 7895	 0.015771	 0.014789	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 7896	 0.010846	 0.018115	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 7898	 0.012103	 0.023962	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7897	 77464	 0.02257	 0.026456	 0.00046	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7898	 77466	 0.009313	 0.023941	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7899	 77464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7899	 77464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7899	 77465	 0.001384	 0.007071	 0.00178	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77464	 7900	 0.022145	 0.016293	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7901	 8033	 0.002121	 0.013434	 0.02813	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	7901	 77465	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77466	 7901	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7902	 7903	 0.013892	 0.025066	 0.00036	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7903	 77467	 0.008667	 0.024857	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7904	 7916	 0.003216	 0.014332	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7904	 77467	 0.003416	 0.014964	 0.00032	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76528	 7905	 0.00538	 0.021892	 0.00533	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77465	 7905	 0.003657	 0.019027	 0.0056	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 77467	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7905	 77467	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7906	 7907	 0.023	 0.018202	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7907	 8023	 0.010574	 0.027181	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7908	 7910	 0.000665	 0.002707	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7908	 7914	 0.00303	 0.0085	 0.00219	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7908	 77468	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7908	 77468	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7909	 77469	 0.006135	 0.020465	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7910	 77469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7910	 77469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7911	 7913	 0.009321	 0.010252	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77468	 7911	 0.011033	 0.011755	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76514	 7912	 0.002286	 0.022466	 0.07707	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7912	 77470	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77471	 7912	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7913	 77472	 0.015494	 0.013979	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7914	 7929	 0.002268	 0.007397	 0.00196	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77470	 7914	 0.000905	 0.004967	 0.00131	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7914	 77472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7914	 77472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7915	 7939	 0.00401	 0.01787	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77471	 7915	 0.004412	 0.022316	 0.00039	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 7917	 0.003626	 0.014161	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77471	 7916	 0.006336	 0.032049	 0.00056	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7917	 77478	 0.0181	 0.051363	 0.00081	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7918	 7919	 0.01518	 0.011644	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7918	 7920	 0.027402	 0.021685	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7918	 8036	 0.007284	 0.016907	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7921	 7922	 0.00141	 0.003839	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7921	 77473	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7921	 77473	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7922	 7925	 0.001425	 0.004086	 0.00101	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7922	 77474	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7922	 77474	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7923	 7955	 0.00994	 0.019681	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77474	 7923	 0.027499	 0.025787	 0.0004	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77469	 7924	 0.003901	 0.013324	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7924	 77477	 0.005747	 0.015233	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7925	 7927	 0.001254	 0.003315	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7925	 77475	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7925	 77475	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7926	 7964	 0.00736	 0.01892	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77475	 7926	 0.003748	 0.014059	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7927	 7930	 0.001038	 0.003617	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7927	 77476	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7927	 77476	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7928	 7965	 0.00538	 0.016523	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77476	 7928	 0.00359	 0.012824	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7929	 7930	 0.000546	 0.001929	 0.00043	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	7929	 77477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7929	 77477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77477	 7931	 0.012551	 0.010331	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7932	 7933	 0.017316	 0.012518	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7933	 7937	 0.024273	 0.017858	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77472	 7933	 0.006708	 0.016419	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77477	 7934	 0.020201	 0.013078	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7935	 7936	 0.008241	 0.010831	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7935	 7965	 0.0131	 0.013989	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7936	 7941	 0.012888	 0.016194	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7938	 7940	 0.007294	 0.024331	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7938	 7941	 0.011656	 0.018698	 0.00035	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7938	 77478	 0.011034	 0.031646	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7939	 7940	 0.002699	 0.010501	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7942	 7943	 0.01382	 0.029046	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7943	 77479	 0.004314	 0.024524	 0.00044	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	7944	 7945	 0.002095	 0.008651	 0.00205	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7944	 77478	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7944	 77478	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7945	 77479	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7945	 77479	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77479	 7946	 0.011211	 0.017171	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7947	 8047	 0.006553	 0.016844	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7947	 77480	 0.00466	 0.009537	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7948	 7949	 0.013514	 0.009573	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7949	 77480	 0.004741	 0.012187	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7950	 77480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7950	 77480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77480	 7951	 0.003157	 0.019825	 0.00043	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7951	 77482	 0.005133	 0.022872	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7951	 77490	 0.007509	 0.023037	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7952	 7953	 0.004759	 0.012235	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77458	 7952	 0.002298	 0.012657	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77473	 7952	 0.002182	 0.012275	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7953	 7955	 0.004531	 0.010729	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7954	 7956	 0.003364	 0.010786	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7956	 7957	 0.004249	 0.013682	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7957	 7958	 0.004708	 0.011685	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7957	 7963	 0.019932	 0.045792	 0.0007	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7959	 7960	 0.01535	 0.012148	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7960	 7961	 0.098207	 0.070996	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7960	 7962	 0.006206	 0.012287	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7962	 7963	 0.00455	 0.00931	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7963	 7964	 0.002534	 0.01257	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77478	 7963	 0.052067	 0.10944	 0.00199	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7964	 7965	 0.014152	 0.023841	 0.00034	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7965	 7966	 0.021016	 0.016632	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7965	 7968	 0.012846	 0.030418	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77478	 7965	 0.035617	 0.08269	 0.00123	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7967	 7968	 0.006955	 0.013771	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7969	 7970	 0.022206	 0.014376	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7970	 7971	 0.030891	 0.024214	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77478	 7971	 0.013096	 0.0304	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7972	 7973	 0.012644	 0.01937	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	7972	 7975	 0.002714	 0.011658	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77479	 7972	 0.007145	 0.027486	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7974	 77481	 0.017892	 0.027917	 0.00047	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7975	 77481	 0.002999	 0.013364	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7976	 7977	 0.001716	 0.004534	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7976	 77481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7976	 77481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7977	 8049	 0.002693	 0.007118	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7977	 77482	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7977	 77482	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77482	 7978	 0.034216	 0.02682	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7979	 7980	 0.001766	 0.007185	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76533	 7979	 0.002163	 0.008803	 0.00214	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7981	 7982	 0.001459	 0.006173	 0.00139	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7981	 77483	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7981	 77483	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7982	 7985	 0.001119	 0.006713	 0.00203	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7983	 7990	 0.00642	 0.016328	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77483	 7983	 0.007213	 0.017656	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7984	 77484	 0.029774	 0.023338	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7985	 7997	 0.001716	 0.006984	 0.0017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7985	 77484	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7985	 77484	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7986	 7991	 0.011801	 0.027113	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7986	 7995	 0.006874	 0.017816	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7986	 8011	 0.009427	 0.031448	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7987	 7988	 0.015942	 0.013625	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7988	 7991	 0.006801	 0.013466	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7988	 8026	 0.010789	 0.025548	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7989	 7990	 0.010682	 0.030638	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7989	 8024	 0.008524	 0.016515	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	7990	 7995	 0.004138	 0.014489	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	7991	 7992	 0.013366	 0.010252	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7993	 8026	 0.006388	 0.024853	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7993	 8028	 0.015681	 0.015404	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7993	 8038	 0.013792	 0.039559	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7994	 7995	 0.008028	 0.013389	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77484	 7994	 0.01235	 0.024203	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7996	 8012	 0.023098	 0.018279	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 8000	 0.001137	 0.004695	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 8020	 0.008083	 0.032362	 0.00815	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 77485	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7997	 77485	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76534	 7998	 0.020904	 0.016543	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	7999	 8001	 0.009852	 0.02016	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	7999	 8002	 0.009456	 0.019351	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76533	 8000	 0.000775	 0.002713	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76534	 8001	 0.006533	 0.016933	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8002	 8014	 0.0174	 0.036571	 0.00067	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8003	 8014	 0.039322	 0.031119	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8004	 8010	 0.0091	 0.016356	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77485	 8004	 0.008325	 0.023878	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8005	 8006	 0.008213	 0.018631	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8005	 8007	 0.008425	 0.018647	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8005	 8012	 0.012907	 0.025554	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8006	 8017	 0.011175	 0.023488	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8006	 8041	 0.019969	 0.03059	 0.00043	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8007	 8011	 0.008238	 0.019124	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8008	 8009	 0.02367	 0.015324	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8009	 8014	 0.010148	 0.026898	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8009	 8019	 0.005012	 0.016139	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8010	 8011	 0.015732	 0.015889	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8011	 8014	 0.015761	 0.040083	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8012	 8038	 0.01889	 0.02575	 0.00057	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8013	 8014	 0.026696	 0.020925	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76513	 8014	 0.041323	 0.095939	 0.00143	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8015	 8017	 0.015758	 0.036584	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8015	 77487	 0.014723	 0.033824	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8016	 77486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8016	 77486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8018	 8021	 0.010827	 0.035728	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8018	 8022	 0.037813	 0.029925	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76513	 8018	 0.009099	 0.035007	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8019	 77487	 0.005011	 0.016717	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8020	 77487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8020	 77487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8021	 77489	 0.012794	 0.033821	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8023	 8024	 0.009821	 0.022798	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8023	 8030	 0.023567	 0.019397	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8023	 8031	 0.019367	 0.012538	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8023	 77488	 0.0054	 0.028773	 0.0005	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8024	 8025	 0.016307	 0.012905	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8026	 8027	 0.001921	 0.011813	 0.00021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8027	 77488	 0.003103	 0.020289	 0.00047	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8029	 8034	 0.030046	 0.02172	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8032	 8037	 0.003112	 0.00998	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8032	 77488	 0.002286	 0.012586	 0.00028	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8033	 77488	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8033	 77488	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8034	 8035	 0.006386	 0.012643	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76503	 8034	 0.00865	 0.019621	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8035	 8047	 0.005886	 0.018076	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76503	 8035	 0.007631	 0.021655	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8036	 8037	 0.004233	 0.008662	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8038	 8045	 0.014793	 0.038026	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8039	 8041	 0.033191	 0.026016	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8040	 8042	 0.010344	 0.024495	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76481	 8040	 0.004924	 0.017241	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76481	 8041	 0.022877	 0.057948	 0.00115	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8042	 8063	 0.014019	 0.033197	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8043	 77489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8043	 77489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8044	 8045	 0.022107	 0.016958	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8045	 77493	 0.003084	 0.021171	 0.00039	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8046	 77490	 0.029491	 0.023339	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8047	 77493	 0.008306	 0.04055	 0.00085	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8048	 77490	 0.009468	 0.018745	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8049	 8051	 0.002046	 0.008191	 0.00206	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8049	 77490	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8049	 77490	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77490	 8050	 0.021985	 0.014233	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8051	 8054	 0.006266	 0.0151	 0.00426	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8051	 77491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8051	 77491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8052	 8059	 0.007183	 0.0147	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76481	 8052	 0.004531	 0.030742	 0.00057	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77491	 8053	 0.00719	 0.01337	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8053	 77493	 0.01096	 0.023035	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8054	 8079	 0.011959	 0.047884	 0.01206	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8054	 77492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8054	 77492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8055	 77493	 0.033207	 0.02628	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8056	 77493	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8056	 77493	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77491	 8057	 0.028341	 0.022428	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77491	 8058	 0.03415	 0.025125	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8059	 8060	 0.041065	 0.030213	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8059	 8068	 0.013107	 0.033693	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8060	 8072	 0.078145	 0.052493	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8061	 8064	 0.014052	 0.033276	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8061	 8073	 0.010507	 0.020804	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8062	 8065	 0.023099	 0.054699	 0.001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8062	 8075	 0.013295	 0.034177	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8062	 8076	 0.009511	 0.024449	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8063	 8064	 0.022291	 0.029297	 0.0004	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8063	 8066	 0.039072	 0.030921	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77489	 8063	 0.019828	 0.038416	 0.00083	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77492	 8064	 0.016964	 0.043143	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8065	 77494	 0.01523	 0.04672	 0.00127	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77489	 8067	 0.082138	 0.053178	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8068	 8069	 0.005913	 0.015199	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8069	 8070	 0.034699	 0.02746	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8069	 8071	 0.028625	 0.022653	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8069	 8073	 0.03296	 0.033291	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8069	 8075	 0.024215	 0.057342	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77492	 8069	 0.014762	 0.051685	 0.00143	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8073	 8074	 0.02259	 0.017877	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8076	 8093	 0.015325	 0.039395	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76536	 8077	 0.01412	 0.040498	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76538	 8077	 0.009671	 0.03576	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8077	 77495	 0.01577	 0.11828	 0.00239	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8078	 8081	 0.016447	 0.063983	 0.00107	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8078	 77494	 0.01221	 0.043618	 0.00087	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8079	 77494	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8079	 77494	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8080	 77495	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8080	 77495	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77495	 8081	 0.012347	 0.03174	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8082	 8083	 0.006334	 0.0526	 0.00129	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77495	 8082	 0.016648	 0.056868	 0.00124	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77495	 8082	 0.016648	 0.056868	 0.00124	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8083	 8084	 0.007926	 0.047258	 0.00132	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8084	 8086	 0.00993	 0.055873	 0.00121	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8085	 8088	 0.031568	 0.056959	 0.00082	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8085	 8098	 0.089354	 0.18365	 0.0035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 8102	 0.038392	 0.054418	 0.00111	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8089	 8096	 0.022033	 0.085716	 0.00143	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8089	 8096	 0.022033	 0.085716	 0.00143	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77495	 8089	 0.011123	 0.043273	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77495	 8089	 0.011123	 0.043273	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8090	 8092	 0.024301	 0.043405	 0.00064	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8091	 8096	 0.052395	 0.041465	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8092	 8094	 0.015198	 0.035989	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8092	 8095	 0.064148	 0.04544	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77495	 8092	 0.056997	 0.13095	 0.00199	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8093	 8094	 0.009948	 0.025573	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8096	 8097	 0.049537	 0.03883	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8096	 8099	 0.009601	 0.075669	 0.0016	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 8100	 0.029369	 0.083341	 0.00131	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 8101	 0.077938	 0.06168	 0.00078	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8099	 8100	 0.016788	 0.044496	 0.00113	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8099	 8103	 0.020423	 0.051939	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8102	 8105	 0.043251	 0.072237	 0.00123	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8106	 8107	 0.074588	 0.059029	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8107	 8108	 0.23294	 0.18438	 0.00232	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77468	 8109	 0.006819	 0.013955	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77471	 8109	 0.029828	 0.059058	 0.00087	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77474	 8109	 0.012021	 0.0401	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8110	 8173	 0.040057	 0.15412	 0.00263	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8110	 8173	 0.040057	 0.15412	 0.00263	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76561	 8110	 0.018298	 0.071185	 0.00119	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76561	 8110	 0.018298	 0.071185	 0.00119	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8111	 8114	 0.000544	 0.00946	 0.03176	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8112	 8113	 0.014439	 0.087755	 0.00162	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76704	 8112	 0.024193	 0.14875	 0.00268	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8113	 8115	 0.021531	 0.083765	 0.0014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8113	 8115	 0.021531	 0.083765	 0.0014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8113	 77500	 0.038653	 0.11086	 0.0017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8114	 77496	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8114	 77496	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8115	 8116	 0.004035	 0.030514	 0.00101	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8116	 8127	 0.025418	 0.097789	 0.00167	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8116	 8127	 0.025418	 0.097789	 0.00167	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77496	 8116	 0.01065	 0.040972	 0.0007	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77496	 8116	 0.01065	 0.040972	 0.0007	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8117	 8120	 0.000496	 0.007781	 0.02583	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8117	 77497	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8117	 77497	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8118	 8123	 0.012125	 0.042425	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8118	 8123	 0.012125	 0.042425	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77497	 8118	 0.015579	 0.060606	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77497	 8118	 0.015579	 0.060606	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8119	 77499	 0.058337	 0.046167	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76454	 8120	 0.004815	 0.044195	 0.17477	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8120	 77498	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77499	 8120	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8121	 8122	 0.003413	 0.015495	 0.00538	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77498	 8122	 0.002886	 0.031134	 0.00891	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8123	 8126	 0.015485	 0.060242	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8123	 8126	 0.015485	 0.060242	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8124	 8126	 0.010423	 0.040549	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8124	 8126	 0.010423	 0.040549	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8124	 8127	 0.024468	 0.091789	 0.00165	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8124	 8127	 0.024468	 0.091789	 0.00165	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8124	 77502	 0.044859	 0.1726	 0.00295	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8125	 8126	 0.11496	 0.090112	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76553	 8126	 0.05046	 0.31032	 0.0056	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77499	 8126	 0.031294	 0.1069	 0.00232	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77499	 8126	 0.031294	 0.1069	 0.00232	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8127	 8128	 0.01395	 0.068072	 0.00117	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8128	 77501	 0.018954	 0.087889	 0.00183	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8129	 8130	 0.004298	 0.021972	 0.00599	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8129	 77500	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8129	 77500	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8130	 8131	 0.006789	 0.027627	 0.00673	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8130	 77501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8130	 77501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8131	 8132	 0.005896	 0.023607	 0.00595	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8132	 8133	 0.005207	 0.02119	 0.00516	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8132	 77502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8132	 77502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8134	 77503	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8134	 77503	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8135	 8136	 0.012651	 0.044721	 0.01008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8135	 8162	 0.010789	 0.037013	 0.00887	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8135	 77504	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8135	 77504	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8136	 77505	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8136	 77505	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77505	 8139	 0.062949	 0.082735	 0.00113	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8140	 8142	 0.045363	 0.10742	 0.00196	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77505	 8140	 0.057988	 0.16633	 0.00256	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77504	 8141	 0.048716	 0.12523	 0.00194	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8142	 8143	 0.032417	 0.085696	 0.00156	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8144	 8145	 0.0035	 0.007162	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8144	 8151	 0.003544	 0.007252	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8144	 8155	 0.027385	 0.019398	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8146	 8147	 0.020459	 0.016191	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8147	 8148	 0.023182	 0.017056	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8148	 8149	 0.033524	 0.024665	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8148	 77507	 0.013658	 0.031237	 0.00076	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8150	 8151	 0.007873	 0.009598	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8150	 77507	 0.096622	 0.069849	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8151	 8152	 0.007094	 0.035478	 0.00063	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8152	 77508	 0.014944	 0.084949	 0.00154	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8153	 8154	 0.02808	 0.044822	 0.00103	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8156	 77506	 0.019184	 0.044532	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8157	 8158	 0.00711	 0.02478	 0.00575	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8157	 8162	 0.007825	 0.026366	 0.00655	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8157	 8163	 0.008372	 0.023346	 0.0049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8157	 77506	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8157	 77506	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8158	 8164	 0.00569	 0.027613	 0.00631	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8158	 77507	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8158	 77507	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8159	 77508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8159	 77508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8160	 8161	 0.17888	 0.12017	 0.00212	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77433	 8160	 0.068744	 0.13611	 0.002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77508	 8160	 0.13361	 0.094652	 0.0015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8163	 8164	 0.006519	 0.017228	 0.00403	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8163	 77509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8163	 77509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8164	 8165	 0.007327	 0.01967	 0.00446	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8165	 77510	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8165	 77510	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76495	 8166	 0.16246	 0.10914	 0.00193	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8167	 8168	 0.003496	 0.016545	 0.00398	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8167	 77511	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8167	 77511	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8168	 8169	 0.001978	 0.005953	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8168	 77512	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8168	 77512	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8169	 8210	 0.001595	 0.005637	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77511	 8170	 0.10959	 0.070952	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8171	 8172	 0.12717	 0.097549	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8171	 8175	 0.065668	 0.051969	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77511	 8171	 0.054507	 0.13863	 0.00219	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8173	 77521	 0.036347	 0.11151	 0.00302	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8173	 77521	 0.036347	 0.11151	 0.00302	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8174	 8211	 0.012724	 0.03271	 0.0081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8174	 8212	 0.00941	 0.037676	 0.00949	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8174	 77513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8174	 77513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8176	 8188	 0.086931	 0.066683	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8177	 8178	 0.003851	 0.010177	 0.00238	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8177	 8210	 0.004239	 0.012498	 0.00291	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8178	 8181	 0.003822	 0.0101	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8178	 8190	 0.01368	 0.035168	 0.00871	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76478	 8178	 0.023126	 0.094143	 0.02295	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8178	 77514	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8178	 77514	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77514	 8179	 0.049704	 0.054669	 0.00073	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8180	 8186	 0.024636	 0.019497	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8181	 77515	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8181	 77515	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8182	 8183	 0.017124	 0.013422	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8183	 8184	 0.015807	 0.01163	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8183	 8185	 0.007672	 0.015036	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77515	 8183	 0.005069	 0.008849	 0.00014	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8185	 8186	 0.004665	 0.011419	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8186	 8188	 0.009805	 0.020064	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8186	 8191	 0.051424	 0.063834	 0.00139	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8187	 8188	 0.008135	 0.006438	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8188	 8193	 0.025751	 0.1169	 0.00254	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77514	 8188	 0.013801	 0.036578	 0.00093	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77515	 8189	 0.039028	 0.025267	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8190	 77516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8190	 77516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8191	 8192	 0.071719	 0.056758	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77516	 8192	 0.10853	 0.085896	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77513	 8193	 0.020209	 0.11488	 0.00208	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8194	 8195	 0.011533	 0.070907	 0.00128	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8194	 77520	 0.015368	 0.082237	 0.00249	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8195	 8197	 0.006225	 0.032372	 0.0007	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8196	 8197	 0.046265	 0.036265	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 8199	 0.025498	 0.067406	 0.00122	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76519	 8197	 0.12358	 0.2026	 0.00358	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76712	 8198	 0.022951	 0.04544	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76712	 8199	 0.029141	 0.074911	 0.00116	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8200	 8201	 0.019091	 0.037798	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76468	 8200	 0.016876	 0.065652	 0.0011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8201	 8203	 0.020511	 0.052726	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8202	 8203	 0.022303	 0.051771	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8202	 8213	 0.0209	 0.053727	 0.00083	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8204	 8213	 0.016534	 0.087098	 0.00156	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8204	 77517	 0.020315	 0.097515	 0.00291	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8205	 77517	 0.016169	 0.091911	 0.00166	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8206	 8209	 0.002953	 0.011821	 0.00298	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8206	 77517	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8206	 77517	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8207	 77520	 0.10683	 0.069164	 0.00132	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8208	 8209	 0.002136	 0.017453	 0.00474	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77498	 8208	 0.001874	 0.017043	 0.0043	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8209	 8211	 0.006126	 0.034824	 0.01008	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8209	 77518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8209	 77518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8210	 77519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8210	 77519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8211	 77520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8211	 77520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8212	 77521	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8212	 77521	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8214	 8215	 0.001339	 0.009786	 0.00018	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8215	 8223	 0.006919	 0.026916	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8215	 8223	 0.006919	 0.026916	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8215	 77522	 0.002689	 0.010462	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8216	 8217	 0.000597	 0.003844	 0.00101	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8216	 8221	 0.00108	 0.005461	 0.00152	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8216	 77522	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8216	 77522	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8217	 77523	 0.0005	 0.003102	 0.00075	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8218	 77523	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77524	 8219	 0.007034	 0.047723	 0.00089	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8219	 77525	 0.007813	 0.030393	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8219	 77525	 0.007813	 0.030393	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8220	 8226	 0.090008	 0.071232	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8221	 77525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8221	 77525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8222	 8224	 0.006448	 0.025086	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8222	 8224	 0.006448	 0.025086	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77525	 8222	 0.008126	 0.031613	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77525	 8222	 0.008126	 0.031613	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76554	 8223	 0.006997	 0.027222	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76554	 8223	 0.006997	 0.027222	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8224	 8225	 0.014573	 0.044705	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8224	 8225	 0.014573	 0.044705	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76511	 8225	 0.00955	 0.069162	 0.00174	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76556	 8225	 0.006917	 0.061796	 0.00146	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8226	 8227	 0.037558	 0.088939	 0.00163	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77525	 8226	 0.048808	 0.11558	 0.00211	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8227	 8231	 0.068696	 0.25406	 0.00471	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8229	 8230	 0.2373	 0.17462	 0.00255	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8230	 8232	 0.070666	 0.16163	 0.00395	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76756	 8230	 0.13608	 0.3462	 0.00548	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8231	 8232	 0.044204	 0.13576	 0.00255	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8233	 8234	 0.014629	 0.010575	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8235	 8236	 0.075293	 0.14908	 0.00219	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8235	 8239	 0.080562	 0.20712	 0.00321	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8235	 8240	 0.10835	 0.089189	 0.00181	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77524	 8235	 0.021396	 0.079112	 0.00146	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77524	 8235	 0.021396	 0.079112	 0.00146	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8237	 8238	 0.036287	 0.14831	 0.003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8237	 8239	 0.042343	 0.14126	 0.00224	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76756	 8238	 0.045691	 0.20134	 0.0035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8240	 8241	 0.16795	 0.10874	 0.00207	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8242	 77526	 0.061862	 0.074056	 0.00123	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77523	 8243	 0.005161	 0.025498	 0.00745	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8243	 77526	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8243	 77526	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8244	 8245	 0.18973	 0.15017	 0.00189	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8244	 8246	 0.025533	 0.094411	 0.00175	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77526	 8244	 0.018509	 0.099406	 0.00236	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8246	 8248	 0.028449	 0.11068	 0.00185	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77360	 8247	 0.16277	 0.1276	 0.00164	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8248	 8249	 0.017926	 0.073265	 0.00148	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8250	 8251	 0.016733	 0.034243	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76469	 8250	 0.011042	 0.028384	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76943	 8250	 0.040751	 0.074641	 0.00129	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8251	 8252	 0.037412	 0.061325	 0.00108	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8252	 8253	 0.072098	 0.056514	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76946	 8254	 0.028869	 0.057158	 0.00084	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8255	 8259	 0.004866	 0.018932	 0.00506	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8255	 77527	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8255	 77527	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8256	 77528	 0.067973	 0.050011	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8257	 8258	 0.001933	 0.014561	 0.00404	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8257	 8261	 0.00274	 0.029041	 0.00862	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8257	 77528	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8257	 77528	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8258	 8259	 0.005495	 0.022002	 0.00554	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8259	 77529	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8259	 77529	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77529	 8260	 0.060018	 0.047498	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8261	 8267	 0.00273	 0.029592	 0.00925	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8261	 77530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8261	 77530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76469	 8262	 0.037366	 0.21243	 0.00384	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77530	 8262	 0.009683	 0.059531	 0.00107	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8263	 77531	 0.024657	 0.07072	 0.00109	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8263	 77532	 0.016853	 0.044667	 0.00113	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8264	 8265	 0.00137	 0.005486	 0.00138	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8265	 8266	 0.003292	 0.019609	 0.00516	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8265	 77531	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8265	 77531	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8266	 8271	 0.003291	 0.026275	 0.00648	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8266	 77532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8266	 77532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8267	 8268	 0.002151	 0.024215	 0.007	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8268	 8269	 0.006101	 0.03243	 0.00752	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8268	 8271	 0.009254	 0.052609	 0.01523	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77196	 8268	 0.003603	 0.052976	 0.0162	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8269	 8270	 0.005757	 0.027247	 0.00655	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8270	 77533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8270	 77533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8271	 77534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8271	 77534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8272	 77538	 0.003966	 0.006466	 0.0001	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8273	 8274	 0.004123	 0.003232	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8273	 77538	 0.003052	 0.005367	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8275	 8278	 9.6e-05	 0.001197	 0.00235	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8275	 77535	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77536	 8275	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8275	 77555	 0.000912	 0.006222	 0.0112	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77536	 8276	 0.002902	 0.005746	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77535	 8277	 0.000204	 0.001639	 0.00046	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8278	 77537	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77538	 8278	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8278	 77548	 0.000312	 0.002858	 0.01128	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8279	 8280	 0.000647	 0.001874	 0.00045	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77535	 8279	 0.000576	 0.004904	 0.00122	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77537	 8279	 0.000407	 0.001628	 0.00041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8279	 77540	 0.001214	 0.007234	 0.0019	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8280	 8282	 0.000411	 0.001646	 0.00041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77537	 8280	 0.001321	 0.003492	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8281	 8282	 0.000444	 0.001569	 0.00035	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8281	 8289	 0.000352	 0.001209	 0.00029	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8282	 8287	 0.000403	 0.002437	 0.00062	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8282	 8303	 0.000882	 0.003025	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8283	 77539	 0.009778	 0.007664	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8284	 8285	 0.000583	 0.00283	 0.00065	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8284	 8750	 0.001506	 0.011451	 0.0036	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8284	 77539	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8284	 77539	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8284	 77542	 0.0008	 0.003952	 0.00115	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8285	 77540	 0.000393	 0.001543	 0.0004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8286	 8288	 7.2e-05	 0.000812	 0.0074	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8286	 8305	 3.1e-05	 0.000346	 0.00315	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8286	 77540	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8286	 77540	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77540	 8287	 0.000325	 0.002374	 0.0007	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8288	 8410	 6.9e-05	 0.000786	 0.00716	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8288	 77541	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77542	 8288	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8289	 8291	 0.000612	 0.001833	 0.00041	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8290	 77543	 0.008451	 0.006109	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77537	 8291	 0.001046	 0.002715	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8291	 77543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8291	 77543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77538	 8292	 0.006093	 0.006702	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8293	 8296	 0.01741	 0.013778	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77535	 8294	 0.000654	 0.002946	 0.00078	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8294	 77544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8294	 77544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77535	 8295	 0.000228	 0.001718	 0.00048	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77543	 8296	 0.003999	 0.010924	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8296	 77554	 0.005887	 0.015134	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8297	 8300	 0.013053	 0.009603	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8298	 8299	 0.007058	 0.014444	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8298	 8300	 0.004878	 0.00956	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77544	 8298	 0.002047	 0.006827	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76643	 8299	 0.002656	 0.006165	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8300	 8301	 0.012102	 0.009577	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8301	 77560	 0.016976	 0.013435	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8302	 77560	 0.00671	 0.00531	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77540	 8303	 0.000668	 0.0034	 0.00123	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8303	 77545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8303	 77545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8304	 8318	 0.000297	 0.002592	 0.00103	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77542	 8304	 0.000599	 0.006419	 0.00205	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8304	 77546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8304	 77546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8305	 8306	 1.2e-05	 0.0002	 0.00363	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8305	 8324	 0.000171	 0.003161	 0.03037	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8305	 77547	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8305	 77547	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8306	 8773	 0.000362	 0.006148	 0.13359	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8306	 77548	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8306	 77548	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77547	 8307	 0.006366	 0.018259	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8307	 77549	 0.005555	 0.011367	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8308	 8312	 0.000558	 0.001914	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8308	 8415	 0.001537	 0.005565	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8309	 77550	 0.012143	 0.0092	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8310	 8312	 0.001485	 0.003923	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8310	 8314	 0.000181	 0.001917	 0.00057	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8310	 8415	 0.002827	 0.009853	 0.00228	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77542	 8310	 0.001224	 0.007344	 0.00222	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8310	 77549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8310	 77549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8311	 8347	 0.00305	 0.008747	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8311	 77550	 0.003059	 0.010206	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8312	 77550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8312	 77550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77550	 8313	 0.007271	 0.005754	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8314	 8315	 0.000693	 0.002774	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8314	 8350	 0.000733	 0.004644	 0.00126	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8314	 77551	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8314	 77551	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8315	 8344	 0.000554	 0.002286	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8315	 77552	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8315	 77552	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77552	 8316	 0.010725	 0.008487	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8317	 8319	 0.012488	 0.008846	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8317	 77563	 0.006214	 0.011169	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8318	 8323	 0.000265	 0.0029	 0.0008	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8320	 77554	 0.003904	 0.009245	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8320	 77561	 0.006006	 0.006542	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8321	 8322	 0.000387	 0.001505	 0.0004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8321	 8333	 0.000602	 0.002409	 0.00061	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8321	 77553	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8321	 77553	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8322	 8323	 0.00015	 0.001416	 0.00043	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8322	 8333	 0.000947	 0.003793	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8322	 77554	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8322	 77554	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8324	 77555	 7.6e-05	 0.00606	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8325	 8329	 0.010512	 0.007964	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77557	 8325	 0.002902	 0.005939	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77557	 8326	 0.001728	 0.009209	 0.00016	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8327	 8328	 0.000214	 0.00121	 0.0003	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8327	 77558	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8327	 77558	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8328	 8333	 0.00019	 0.001112	 0.0003	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8329	 8330	 0.00512	 0.004052	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8331	 8338	 0.000834	 0.002863	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8331	 8339	 0.000909	 0.002761	 0.0006	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8331	 8352	 0.001159	 0.004508	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77556	 8331	 0.000872	 0.002991	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8331	 77559	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8331	 77559	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8332	 8353	 0.012561	 0.009941	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77559	 8332	 0.005788	 0.006366	 8e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8333	 77560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8333	 77560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8334	 8335	 0.002787	 0.00647	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8334	 77562	 0.01064	 0.006888	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77553	 8335	 0.002524	 0.006488	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8336	 8338	 0.000922	 0.003107	 0.00077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8336	 8343	 0.000569	 0.002011	 0.00045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8336	 77561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8336	 77561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77561	 8337	 0.007095	 0.00522	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8338	 77562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8338	 77562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8339	 8340	 0.00064	 0.002196	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8340	 8342	 0.000573	 0.002076	 0.00045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8341	 77565	 0.011904	 0.008758	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8342	 8345	 0.000909	 0.002737	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8343	 8344	 0.000918	 0.003325	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8344	 8345	 0.000806	 0.00226	 0.00058	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77537	 8344	 0.003409	 0.01365	 0.00344	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77540	 8344	 0.00138	 0.009758	 0.00268	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77556	 8344	 0.004999	 0.013939	 0.00293	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8344	 77563	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8344	 77563	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77551	 8346	 0.001751	 0.009838	 0.00018	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8346	 77564	 0.002662	 0.008176	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8347	 77582	 0.004502	 0.010661	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8348	 8349	 0.000721	 0.002932	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8348	 8409	 0.000545	 0.002181	 0.00055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8349	 8350	 0.00096	 0.003649	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8350	 8351	 0.001449	 0.004041	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8350	 77564	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8350	 77564	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8351	 8366	 0.001627	 0.004223	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8352	 8366	 0.001759	 0.004648	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8352	 77565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8352	 77565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8354	 8355	 0.002997	 0.012015	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77557	 8354	 0.00409	 0.015912	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77557	 8354	 0.00409	 0.015912	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8354	 77567	 0.003339	 0.016294	 0.00028	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8355	 8356	 0.002795	 0.010873	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8356	 77566	 0.001782	 0.008698	 0.00015	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8357	 77567	 0.0044	 0.007412	 0.00011	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8358	 8359	 0.00053	 0.001785	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8358	 8361	 0.001097	 0.003762	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8358	 77566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8358	 77566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8359	 8372	 0.001791	 0.005841	 0.00155	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8360	 8365	 0.004038	 0.010023	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77566	 8360	 0.00274	 0.007579	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8361	 77567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8361	 77567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8362	 8364	 0.001043	 0.00775	 0.00018	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77567	 8362	 0.001003	 0.006703	 0.00015	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77567	 8363	 0.005335	 0.010563	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77565	 8364	 0.000992	 0.009719	 0.00019	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8365	 77569	 0.009609	 0.022308	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8367	 8369	 0.023834	 0.018682	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8368	 77582	 0.011333	 0.014067	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77564	 8369	 0.004962	 0.017725	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77564	 8369	 0.004962	 0.017725	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8369	 77568	 0.002932	 0.024902	 0.00058	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8370	 8371	 0.002352	 0.006315	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8370	 8406	 0.00134	 0.006733	 0.00175	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8370	 77568	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8370	 77568	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8371	 8372	 0.001305	 0.003146	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8372	 77569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8372	 77569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8373	 77570	 0.008669	 0.022284	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8374	 8389	 0.001428	 0.005429	 0.00152	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8374	 77570	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8374	 77570	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77570	 8375	 0.012834	 0.008621	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77570	 8376	 0.025294	 0.020017	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8377	 77573	 0.017804	 0.013099	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8378	 8379	 0.025558	 0.016546	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77570	 8379	 0.007296	 0.03904	 0.00118	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8379	 77571	 0.004	 0.017525	 0.00038	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8380	 8381	 0.000679	 0.002805	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8380	 77571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8380	 77571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8381	 8382	 0.000485	 0.002297	 0.00055	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8382	 8386	 0.001657	 0.009419	 0.00273	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8382	 77572	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8382	 77572	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8383	 8384	 0.008019	 0.010539	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77572	 8383	 0.004168	 0.00853	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8385	 8390	 0.003007	 0.022555	 0.00046	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77572	 8385	 0.002518	 0.014149	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8386	 8493	 0.000704	 0.004328	 0.00125	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8387	 8389	 0.000971	 0.003778	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8387	 8405	 0.001927	 0.007839	 0.00191	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8388	 77573	 0.009433	 0.006819	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8389	 77573	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8389	 77573	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8390	 77578	 0.004227	 0.032117	 0.00073	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8391	 8392	 0.00066	 0.00467	 0.00128	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8391	 8493	 0.000642	 0.004537	 0.00125	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8391	 77574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8391	 77574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8392	 8393	 0.000795	 0.003182	 0.00107	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8392	 8395	 0.000557	 0.003739	 0.0009	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8393	 8400	 0.000379	 0.001903	 0.0005	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8394	 8396	 0.000371	 0.001511	 0.00037	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8394	 8400	 0.001199	 0.004342	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8395	 8438	 0.000622	 0.0044	 0.00121	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8396	 8421	 0.000742	 0.002916	 0.00076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8397	 77575	 0.002887	 0.009631	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8397	 77588	 0.003267	 0.01116	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8398	 8399	 0.000522	 0.002393	 0.00061	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8398	 8402	 0.000948	 0.003794	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8398	 8419	 0.000825	 0.003304	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8398	 8422	 0.001502	 0.007823	 0.00205	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8398	 77575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8398	 77575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8399	 8400	 0.000425	 0.00167	 0.00044	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8400	 8404	 0.000921	 0.00401	 0.00114	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8400	 77576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8400	 77576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77576	 8401	 0.011385	 0.008065	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8402	 8403	 0.00095	 0.003805	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8403	 8406	 0.00166	 0.006523	 0.00171	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8403	 77577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8403	 77577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8404	 8405	 0.001391	 0.005567	 0.0014	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8404	 8489	 0.005687	 0.02277	 0.00574	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8404	 77578	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8404	 77578	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8405	 77579	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8405	 77579	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8406	 77580	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8406	 77580	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77580	 8407	 0.004813	 0.023486	 0.00041	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8407	 77581	 0.00264	 0.01335	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8408	 8416	 0.000875	 0.003504	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8408	 8419	 0.001126	 0.004581	 0.00112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8408	 77581	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8408	 77581	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8409	 8416	 0.001321	 0.005453	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8409	 77582	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8409	 77582	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8410	 77583	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8410	 77583	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77542	 8411	 0.001838	 0.004772	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77583	 8411	 0.000881	 0.002741	 0.00057	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8411	 77584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8411	 77584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8412	 8413	 0.000408	 0.002343	 0.00066	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8412	 8427	 0.002164	 0.006034	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77412	 8412	 0.002655	 0.01096	 0.00259	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8413	 8415	 0.001617	 0.006354	 0.00166	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8413	 77585	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8413	 77585	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77585	 8414	 0.007669	 0.015694	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8414	 77586	 0.017218	 0.022629	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8415	 77586	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8415	 77586	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8416	 8417	 0.002078	 0.005224	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8416	 77587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8416	 77587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8417	 8418	 0.001834	 0.004848	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8418	 8422	 0.000619	 0.003394	 0.0009	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8418	 77588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8418	 77588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8420	 8421	 0.001179	 0.004045	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8420	 8423	 0.00158	 0.005585	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8421	 77589	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8421	 77589	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8422	 77590	 0.000276	 0.003591	 0.00104	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8423	 8489	 0.001137	 0.004553	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8424	 8427	 0.002964	 0.006879	 0.0021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8424	 77593	 0.002074	 0.005784	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8425	 77592	 0.034808	 0.022535	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8426	 8428	 0.000507	 0.003438	 0.00626	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77541	 8426	 0.000872	 0.006894	 0.02393	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8426	 77590	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77591	 8426	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8427	 77592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8427	 77592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8428	 77593	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8428	 77593	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8429	 8430	 0.000459	 0.003184	 0.00091	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77411	 8429	 0.001579	 0.013774	 0.00378	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77593	 8429	 0.000169	 0.001445	 0.00124	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8430	 77594	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8430	 77594	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77594	 8431	 0.025903	 0.0205	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8432	 8434	 0.00097	 0.008051	 0.00212	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8432	 8453	 0.00149	 0.005797	 0.00155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8432	 8454	 0.002323	 0.009035	 0.00241	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8433	 8434	 0.001181	 0.005936	 0.00154	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8433	 8438	 0.000833	 0.006151	 0.00178	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8433	 8489	 0.001213	 0.005051	 0.00157	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8434	 8436	 0.001222	 0.005964	 0.00165	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8435	 77595	 0.014353	 0.015787	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8436	 8437	 0.001115	 0.005021	 0.00134	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8436	 77595	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8436	 77595	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8437	 8439	 0.001117	 0.012773	 0.0039	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76464	 8437	 0.005964	 0.041379	 0.01181	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8439	 8450	 0.001033	 0.009453	 0.00379	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8440	 8446	 0.071755	 0.056245	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8441	 8444	 0.075343	 0.059626	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8441	 77596	 0.020151	 0.078395	 0.00131	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8441	 77596	 0.020151	 0.078395	 0.00131	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8442	 77596	 0.063041	 0.044655	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8443	 8445	 0.001043	 0.014198	 0.00508	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8443	 8488	 0.003834	 0.015068	 0.00394	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8445	 8491	 0.000341	 0.004188	 0.00199	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8445	 77596	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8445	 77596	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8446	 77597	 0.036084	 0.044792	 0.00098	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8447	 8449	 0.001252	 0.010527	 0.00312	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8447	 8464	 0.003142	 0.046941	 0.01389	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8447	 8491	 0.000347	 0.00426	 0.00203	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8447	 77597	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8447	 77597	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8448	 77598	 0.004054	 0.010422	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8449	 8450	 0.00095	 0.010063	 0.00299	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8449	 77598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8449	 77598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8451	 77605	 0.045018	 0.031889	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77598	 8452	 0.032845	 0.021264	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8453	 8456	 0.001389	 0.005562	 0.0014	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8454	 8455	 0.001556	 0.006331	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8455	 8456	 0.000708	 0.003492	 0.00094	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8455	 8457	 0.000764	 0.003233	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8455	 8459	 0.000313	 0.003316	 0.00098	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8456	 77599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8456	 77599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8457	 8458	 0.000863	 0.003357	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8458	 8460	 0.000496	 0.001804	 0.00055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8459	 8462	 0.001022	 0.010236	 0.00341	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8460	 8477	 0.003421	 0.013697	 0.00345	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8461	 77600	 0.023878	 0.018897	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8462	 8469	 0.003327	 0.015262	 0.00391	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8462	 8470	 0.002237	 0.010264	 0.00263	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8462	 77600	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8462	 77600	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8463	 8470	 0.001789	 0.008056	 0.00214	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76455	 8463	 0.000268	 0.002576	 0.00075	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8464	 8468	 0.001336	 0.004502	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8464	 8480	 0.007831	 0.031354	 0.0079	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76455	 8464	 0.000235	 0.003431	 0.00213	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76455	 8464	 0.000235	 0.003431	 0.00213	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8465	 8466	 0.018036	 0.014273	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8466	 77601	 0.003764	 0.009675	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8467	 8468	 0.00154	 0.004462	 0.00108	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8467	 8474	 0.003361	 0.008883	 0.00208	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8468	 77601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8468	 77601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76453	 8469	 0.000881	 0.00623	 0.00171	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76464	 8469	 0.004079	 0.013304	 0.00353	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8469	 77602	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8469	 77602	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8470	 77603	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8470	 77603	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77601	 8471	 0.069965	 0.045296	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8472	 8475	 0.033579	 0.021739	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77601	 8472	 0.030778	 0.030114	 0.00043	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8473	 77604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8473	 77604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8476	 8478	 0.003433	 0.02294	 0.00051	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77604	 8476	 0.007089	 0.065213	 0.00129	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8477	 8480	 0.002964	 0.010372	 0.00344	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8477	 77605	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8477	 77605	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8478	 8479	 0.051832	 0.039759	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8478	 8481	 0.019664	 0.015562	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8478	 8482	 0.016061	 0.021109	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77206	 8478	 0.010589	 0.0469	 0.00107	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8480	 77606	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8480	 77606	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8482	 8486	 0.031374	 0.023083	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77606	 8483	 0.049683	 0.07611	 0.00107	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8484	 8485	 0.033319	 0.023602	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8484	 8487	 0.032899	 0.023783	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77401	 8489	 0.004533	 0.027873	 0.00804	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77590	 8489	 0.002141	 0.008572	 0.00216	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8489	 77607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8489	 77607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77599	 8490	 0.006205	 0.004565	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77602	 8492	 0.008924	 0.017668	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77603	 8492	 0.006243	 0.009562	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8494	 8498	 0.010691	 0.088782	 0.00217	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8495	 77608	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8495	 77608	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8496	 8497	 0.015447	 0.092554	 0.00223	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76502	 8496	 0.00869	 0.053424	 0.00096	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8497	 8502	 0.15758	 0.12472	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76499	 8497	 0.013381	 0.098834	 0.00206	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76499	 8498	 0.027996	 0.10891	 0.00182	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76499	 8498	 0.027996	 0.10891	 0.00182	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76529	 8498	 0.026532	 0.098102	 0.00182	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8499	 8500	 0.15119	 0.11966	 0.00151	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76529	 8500	 0.019024	 0.046566	 0.0008	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8501	 8504	 0.016188	 0.090961	 0.00168	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76499	 8501	 0.00869	 0.033808	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76499	 8501	 0.00869	 0.033808	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76529	 8501	 0.024013	 0.073665	 0.002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76529	 8501	 0.024013	 0.073665	 0.002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8503	 77609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8503	 77609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8505	 8509	 0.086592	 0.087462	 0.00116	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76501	 8505	 0.038043	 0.08831	 0.00168	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8506	 8508	 0.012024	 0.032736	 0.00721	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8507	 77610	 0.18455	 0.1358	 0.00199	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8508	 77610	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8508	 77610	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8510	 8527	 0.000209	 0.005153	 0.37982	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8510	 14149	 0.000352	 0.004205	 0.31556	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8510	 77611	 0.000137	 0.010999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8510	 77611	 0.000137	 0.010999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8511	 13836	 0.003056	 0.036113	 0.63437	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77611	 8511	 1.1e-05	 0.000116	 0.00174	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77611	 8511	 1.1e-05	 0.000116	 0.00174	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8511	 77615	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8511	 77615	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77616	 8511	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77616	 8511	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8511	 77642	 0.000625	 0.011052	 0.1816	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8512	 8544	 1.5e-05	 0.000215	 0.00083	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77612	 8512	 0.006465	 0.080384	 0.29185	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77612	 8512	 0.006465	 0.080384	 0.29185	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8512	 77617	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8512	 77617	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77618	 8512	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77618	 8512	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8513	 9505	 2.1e-05	 0.000373	 0.00711	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8513	 77619	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8513	 77619	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8514	 11329	 0.000657	 0.006452	 0.02213	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77612	 8514	 0.004643	 0.063167	 0.283	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77612	 8514	 0.004643	 0.063167	 0.283	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8514	 77622	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8514	 77622	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8514	 78104	 0.003976	 0.040214	 0.09132	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8514	 78104	 0.003976	 0.040214	 0.09132	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8515	 8530	 0.001428	 0.005809	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8515	 10418	 0.001407	 0.005631	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8515	 77623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8515	 77623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8515	 77643	 0.001462	 0.016546	 0.00929	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8516	 8527	 2.5e-05	 0.000503	 0.0337	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8516	 11967	 2.5e-05	 0.000421	 0.03277	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8516	 77624	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8516	 77624	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8517	 8529	 3.8e-05	 0.00044	 0.00023	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8517	 9980	 0.008223	 0.05517	 0.01332	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8517	 10189	 0.001005	 0.008621	 0.00245	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8517	 10190	 0.000549	 0.004488	 0.00122	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8517	 10201	 0.00068	 0.007106	 0.00195	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8518	 9426	 0.000116	 0.00139	 0.10424	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8518	 77626	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8518	 77626	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77628	 8518	 0.000243	 0.018209	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77628	 8518	 0.000243	 0.018209	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8519	 8520	 4.1e-05	 0.000482	 0.00442	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8519	 9928	 0.000117	 0.001851	 0.03039	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8519	 77629	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8519	 77629	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8520	 77631	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8520	 77631	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8521	 8675	 0.00678	 0.048779	 0.01293	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8521	 8705	 0.007273	 0.029117	 0.00734	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8521	 8707	 0.002834	 0.014761	 0.00387	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8521	 8719	 0.001379	 0.011824	 0.00336	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8521	 9158	 0.003562	 0.008585	 0.00242	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8521	 9202	 0.013904	 0.090949	 0.02314	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77613	 8521	 0.050636	 0.19938	 0.05229	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8521	 77633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8521	 77633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8522	 9202	 0.005817	 0.016847	 0.00406	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8522	 9209	 0.001306	 0.008104	 0.00196	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8522	 77634	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8522	 77634	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8523	 8839	 0.000264	 0.003102	 0.00692	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8523	 77635	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8523	 77635	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77636	 8523	 0.000262	 0.019645	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77636	 8523	 0.000262	 0.019645	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8524	 9767	 0.000555	 0.005734	 0.09011	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8524	 9767	 0.000555	 0.005734	 0.09011	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8524	 9930	 6.2e-05	 0.000654	 0.00978	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8524	 9930	 6.2e-05	 0.000654	 0.00978	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8524	 77637	 0.000125	 0.009999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8524	 77637	 0.000125	 0.009999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77638	 8524	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77638	 8524	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8525	 8704	 0.016934	 0.086588	 0.02361	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8525	 9206	 0.003043	 0.008813	 0.00213	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8525	 9215	 0.002509	 0.015894	 0.00431	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77613	 8525	 0.031875	 0.12771	 0.03221	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8525	 77639	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8525	 77639	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8526	 9269	 0.000719	 0.006843	 0.025	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8526	 10592	 0.000113	 0.001377	 0.00446	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8526	 77640	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8526	 77640	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77641	 8526	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77641	 8526	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8527	 13455	 0.000132	 0.003267	 0.27121	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8527	 77642	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8527	 77642	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77643	 8527	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77643	 8527	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8528	 9144	 0.00091	 0.009201	 0.00271	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8528	 9428	 0.000289	 0.001799	 0.00051	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8528	 13128	 0.002379	 0.009254	 0.00247	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8529	 10197	 0.002887	 0.012217	 0.00275	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8529	 10210	 0.00115	 0.005178	 0.00138	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8529	 77644	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8529	 77644	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8530	 10418	 0.000135	 0.001293	 0.00038	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8530	 79698	 0.001401	 0.01664	 0.0058	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8531	 8942	 0.000713	 0.011474	 0.00375	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8531	 8947	 0.000297	 0.004508	 0.00166	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8531	 9019	 0.00397	 0.028556	 0.00757	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8531	 11323	 0.004746	 0.012321	 0.00299	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8531	 77645	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8531	 77645	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8531	 77846	 0.000253	 0.00372	 0.00114	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8531	 78608	 0.000957	 0.004391	 0.00112	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8531	 78611	 0.001625	 0.015599	 0.00454	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8532	 9512	 0.000111	 0.001179	 0.0024	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8532	 9512	 0.000111	 0.001179	 0.0024	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8532	 9576	 0.00016	 0.001732	 0.0034	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8532	 9576	 0.00016	 0.001732	 0.0034	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8532	 77646	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8532	 77646	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77647	 8532	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77647	 8532	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8533	 8758	 0.000769	 0.004656	 0.00015	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8533	 8759	 0.002558	 0.011272	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8533	 8760	 0.001439	 0.014102	 0.00028	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8533	 10365	 0.000875	 0.006396	 0.00012	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8534	 8667	 0.001029	 0.00272	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8534	 8675	 0.001633	 0.00424	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8534	 77648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8534	 77648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8535	 9767	 0.001847	 0.01909	 0.30038	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8535	 9767	 0.001847	 0.01909	 0.30038	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8535	 77649	 9.3e-05	 0.007407	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8535	 77649	 9.3e-05	 0.007407	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8535	 79044	 0.001162	 0.012301	 0.18404	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8535	 79044	 0.001162	 0.012301	 0.18404	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8536	 9840	 0.000769	 0.004729	 0.00136	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8536	 9842	 0.00021	 0.002933	 0.00099	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8536	 9884	 8.3e-05	 0.001354	 0.00081	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8536	 77652	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8536	 77652	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8536	 78132	 0.00056	 0.008249	 0.00403	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8537	 9926	 0.000722	 0.00745	 0.11708	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8537	 9926	 0.000722	 0.00745	 0.11708	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8537	 9928	 8.8e-05	 0.000934	 0.01397	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8537	 9928	 8.8e-05	 0.000934	 0.01397	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8537	 77653	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8537	 77653	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8538	 9878	 0.000646	 0.002537	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8538	 9954	 0.006886	 0.028021	 0.00683	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8538	 77654	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8538	 77654	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8539	 10598	 0.000265	 0.001675	 0.00045	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8539	 77655	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8539	 77655	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8540	 9275	 4.6e-05	 0.000617	 0.00036	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8540	 9276	 0.000383	 0.004377	 0.00133	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8540	 9277	 0.000176	 0.001941	 0.00099	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8541	 9193	 0.003419	 0.01238	 0.00266	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8541	 9198	 0.001603	 0.005401	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8541	 9199	 0.003429	 0.011762	 0.00282	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8541	 9202	 0.006231	 0.035734	 0.01188	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8541	 77656	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8541	 77656	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8542	 9777	 0.002876	 0.01995	 0.00569	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8542	 9790	 0.00097	 0.007557	 0.00226	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8542	 9797	 0.000256	 0.00176	 0.00051	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8542	 9797	 0.000256	 0.00176	 0.00051	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8542	 9798	 0.000378	 0.00476	 0.00147	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8542	 9851	 0.000473	 0.002938	 0.00071	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8542	 9862	 0.001276	 0.004963	 0.00133	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8543	 9269	 0.000413	 0.004488	 0.0088	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8543	 9269	 0.000413	 0.004488	 0.0088	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8543	 9576	 0.000125	 0.001408	 0.00258	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8543	 9576	 0.000125	 0.001408	 0.00258	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8543	 77657	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8543	 77657	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8544	 10279	 0.000144	 0.001655	 0.00598	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8544	 77658	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8544	 77658	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77659	 8544	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77659	 8544	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8545	 9040	 0.000773	 0.002008	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8546	 9276	 0.000385	 0.001677	 0.00048	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8547	 9431	 0.000332	 0.003756	 0.01401	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8547	 9435	 0.000106	 0.001777	 0.00646	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8547	 77660	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8547	 77660	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8547	 77726	 0.000262	 0.003825	 0.01466	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8547	 79344	 0.001797	 0.019616	 0.03805	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8547	 79344	 0.001797	 0.019616	 0.03805	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8548	 10561	 0.000823	 0.008722	 0.00259	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8548	 10564	 0.001124	 0.007191	 0.00242	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8548	 10568	 0.00024	 0.003506	 0.00218	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77640	 8548	 0.00246	 0.018437	 0.0045	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8548	 77661	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8548	 77661	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8549	 9209	 0.000779	 0.003913	 0.00102	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8549	 9216	 0.000255	 0.001463	 0.00041	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8550	 9931	 0.00046	 0.001215	 0.00028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8550	 77662	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8550	 77662	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8551	 9181	 0.009868	 0.025619	 0.00622	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8551	 9183	 0.001232	 0.004463	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8551	 77663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8551	 77663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8552	 9658	 0.000503	 0.008091	 0.00264	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8552	 9667	 0.001065	 0.014251	 0.0039	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8552	 10477	 0.005785	 0.052627	 0.01329	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8552	 77664	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8552	 77664	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8553	 8634	 0.000104	 0.002799	 0.23486	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8553	 12620	 3e-05	 0.000386	 0.02462	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8553	 77665	 0.000173	 0.01294	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8553	 77665	 0.000173	 0.01294	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77666	 8553	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77666	 8553	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8554	 11613	 0.000119	 0.002392	 0.25063	 3450.0	 3622.5	 3795.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8554	 12510	 0.000496	 0.006418	 0.40986	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8554	 12783	 0.000123	 0.003206	 0.34082	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8554	 12945	 1.7e-05	 0.000293	 0.02568	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8554	 77667	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8554	 77667	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8555	 12348	 0.00245	 0.022469	 0.08873	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8555	 15694	 0.012784	 0.088269	 0.15635	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8555	 77668	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8555	 77668	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8556	 10894	 0.000757	 0.014059	 0.93123	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8556	 11795	 0.000981	 0.023467	 2.1394	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8556	 11795	 0.000981	 0.023467	 2.1394	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8556	 77669	 8.9e-05	 0.007096	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8556	 77669	 8.9e-05	 0.007096	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8557	 8560	 0.000252	 0.003003	 0.22533	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8557	 8583	 0.000496	 0.013103	 1.0833	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8557	 77673	 0.000102	 0.008148	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8557	 77673	 0.000102	 0.008148	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8557	 77673	 0.000102	 0.008148	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77674	 8557	 0.000173	 0.013839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77674	 8557	 0.000173	 0.013839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8558	 8559	 1.8e-05	 0.000299	 0.02329	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8558	 10894	 0.000247	 0.003975	 0.36564	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8558	 77675	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8558	 77675	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8559	 12053	 0.000866	 0.023009	 1.9166	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8559	 77677	 7.1e-05	 0.005641	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8559	 77677	 7.1e-05	 0.005641	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77678	 8559	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77678	 8559	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8560	 20279	 0.00127	 0.01519	 1.1444	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8560	 77679	 0.000125	 0.009999	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8560	 77679	 0.000125	 0.009999	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8561	 10832	 0.000434	 0.005269	 0.01706	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8561	 77683	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8561	 77683	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77684	 8561	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77684	 8561	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8561	 78451	 6.1e-05	 0.000559	 0.00221	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8562	 12219	 0.000217	 0.004009	 0.03851	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8562	 12241	 0.002023	 0.032935	 0.68173	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77669	 8562	 5.5e-05	 0.001083	 0.01702	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8562	 77685	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8562	 77685	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77686	 8562	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77686	 8562	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8563	 10894	 0.000908	 0.011749	 0.75143	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8563	 12156	 0.001027	 0.02738	 2.2914	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8563	 12156	 0.001027	 0.02738	 2.2914	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 0	 -30.0	 30.0;
	8563	 20230	 0.000221	 0.002642	 0.19819	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8563	 77687	 8.9e-05	 0.007096	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8563	 77687	 8.9e-05	 0.007096	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8564	 10971	 0.001759	 0.017182	 0.00482	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8564	 12132	 0.016409	 0.099279	 0.02535	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8564	 13650	 0.003067	 0.012979	 0.00292	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8564	 13652	 0.001039	 0.005122	 0.00138	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8564	 77691	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8564	 77691	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8565	 11209	 0.001488	 0.019679	 0.0717	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8565	 77692	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8565	 77692	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77693	 8565	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77693	 8565	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8565	 78767	 0.003135	 0.037894	 0.12426	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8566	 10170	 0.001091	 0.01899	 0.06378	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8566	 10655	 0.000582	 0.008966	 0.01976	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8566	 77694	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8566	 77694	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8567	 11209	 0.000676	 0.009504	 0.03942	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8567	 11252	 0.000168	 0.002812	 0.01022	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8567	 77695	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8567	 77695	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77696	 8567	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77696	 8567	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8568	 8579	 9e-06	 9.4e-05	 3e-05	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8568	 13091	 0.00045	 0.002391	 0.00055	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8568	 13101	 0.000245	 0.002596	 0.00077	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8568	 13104	 0.000978	 0.006077	 0.00172	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8568	 13115	 0.000779	 0.002058	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8568	 77697	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8568	 77697	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8568	 79341	 0.000229	 0.002194	 0.00064	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8569	 11598	 0.000827	 0.003217	 0.00086	 195.0	 195.0	 195.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8569	 11599	 0.001744	 0.006785	 0.00181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8569	 11603	 0.002301	 0.007892	 0.00189	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8569	 12908	 0.005244	 0.01799	 0.00431	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8570	 77698	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8570	 77698	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8570	 77768	 2.9e-05	 0.000338	 0.00118	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8571	 9718	 0.000238	 0.002353	 0.04027	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8571	 9718	 0.000238	 0.002353	 0.04027	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8571	 9926	 0.000811	 0.008183	 0.13471	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8571	 9926	 0.000811	 0.008183	 0.13471	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8571	 13428	 0.001377	 0.014576	 0.21814	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8571	 13428	 0.001377	 0.014576	 0.21814	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8571	 77699	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8571	 77699	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77700	 8571	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77700	 8571	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8572	 11967	 1.2e-05	 0.000155	 0.01061	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8572	 77701	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8572	 77701	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8573	 11947	 9e-06	 0.000221	 0.02233	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8573	 11948	 1e-06	 2.1e-05	 0.00175	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8573	 77702	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8573	 77702	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77703	 8573	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77703	 8573	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8574	 10828	 4.3e-05	 0.000516	 0.00474	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8574	 13699	 0.000403	 0.007309	 0.07306	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8574	 77704	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8574	 77704	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8575	 8641	 0.000353	 0.009322	 0.76936	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8575	 14950	 0.000482	 0.008619	 0.61252	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8575	 77706	 0.00011	 0.008799	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8575	 77706	 0.00011	 0.008799	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77707	 8575	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77707	 8575	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8576	 12236	 0.001238	 0.017491	 0.28284	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8576	 13699	 0.000417	 0.007713	 0.07412	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77673	 8576	 6.4e-05	 0.000822	 0.01379	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8576	 77708	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8576	 77708	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8577	 13656	 0.005088	 0.03304	 0.06584	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8577	 20284	 0.00455	 0.040035	 0.08358	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77688	 8577	 0.000104	 0.000822	 0.00158	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8577	 77709	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8577	 77709	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8577	 78924	 0.000989	 0.006748	 0.01215	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8578	 11090	 0.009283	 0.037776	 0.0092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8578	 11091	 0.001492	 0.007242	 0.00166	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8578	 11094	 0.007138	 0.029472	 0.00697	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8578	 11095	 0.00657	 0.021429	 0.00569	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8578	 11463	 0.027331	 0.072248	 0.01691	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8578	 11707	 0.01124	 0.045741	 0.01115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8578	 12229	 0.014397	 0.12356	 0.0352	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8578	 77710	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8578	 77710	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8579	 13074	 0.000668	 0.008408	 0.0026	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8579	 13078	 0.00131	 0.005546	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8579	 13091	 0.000392	 0.002108	 0.00058	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8579	 77711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8579	 77711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8579	 79341	 0.000272	 0.002219	 0.0006	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8580	 13006	 0.000881	 0.003022	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8580	 13009	 0.001762	 0.013202	 0.00322	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8580	 77712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8580	 77712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8581	 11626	 0.003172	 0.044308	 0.14489	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8581	 14737	 0.003906	 0.038943	 0.13011	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8581	 77713	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8581	 77713	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77714	 8581	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77714	 8581	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8582	 12509	 0.001912	 0.019829	 0.04271	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8582	 12509	 0.001912	 0.019829	 0.04271	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8582	 13028	 0.000324	 0.003291	 0.00823	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77649	 8582	 0.001186	 0.013326	 0.02438	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77649	 8582	 0.001186	 0.013326	 0.02438	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8582	 77715	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8582	 77715	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77716	 8582	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77716	 8582	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8583	 11303	 0.000914	 0.023863	 2.2016	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8583	 11303	 0.000914	 0.023863	 2.2016	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8583	 12053	 0.001944	 0.029129	 1.8995	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8583	 12648	 0.000583	 0.016773	 1.1725	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8583	 20230	 0.001664	 0.028738	 2.2737	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8583	 20230	 0.001664	 0.028738	 2.2737	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 0	 -30.0	 30.0;
	8583	 77717	 0.000118	 0.009419	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8583	 77717	 0.000118	 0.009419	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8584	 11517	 0.002203	 0.01395	 0.00379	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8584	 11520	 0.004237	 0.044906	 0.01333	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8584	 11525	 0.004307	 0.019758	 0.00506	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8585	 12395	 0.003733	 0.031793	 0.00793	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8585	 13873	 0.003101	 0.012065	 0.00322	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8585	 77720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8585	 77720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8586	 13482	 0.005084	 0.029776	 0.00811	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8586	 13486	 0.003454	 0.010183	 0.00237	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8587	 11301	 0.001354	 0.01153	 0.00288	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8587	 13568	 0.011087	 0.074392	 0.01796	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8587	 77721	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8587	 77721	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8588	 10978	 0.000118	 0.00131	 0.01247	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8588	 11076	 6e-05	 0.000966	 0.00983	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8588	 77722	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8588	 77722	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8589	 11279	 0.008171	 0.058785	 0.01558	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8589	 11526	 0.001095	 0.006795	 0.00165	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8589	 11527	 0.00199	 0.01763	 0.00469	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8589	 78671	 0.004352	 0.026757	 0.00772	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8590	 8607	 0.001583	 0.006699	 0.00151	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8590	 12705	 0.014492	 0.058027	 0.01462	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8590	 13595	 0.006208	 0.034221	 0.008	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8590	 77723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8590	 77723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8591	 11545	 0.00078	 0.008414	 0.00241	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8591	 11546	 0.001072	 0.006655	 0.00161	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8591	 77724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8591	 77724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8592	 8609	 0.000112	 0.001257	 0.0004	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8592	 78851	 0.000716	 0.004159	 0.00098	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8593	 8620	 0.00131	 0.005409	 0.00128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8593	 77725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8593	 77725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8594	 11276	 0.010478	 0.041183	 0.01077	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8594	 11278	 0.005455	 0.025025	 0.00641	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8594	 11529	 0.001827	 0.013344	 0.00343	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8595	 77726	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8595	 77726	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77727	 8595	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77727	 8595	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8595	 78831	 2.4e-05	 0.000371	 0.00856	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8595	 78834	 1.5e-05	 0.000355	 0.00669	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8596	 13212	 0.000391	 0.001033	 0.00024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8596	 13226	 0.000973	 0.002928	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8597	 9039	 0.000249	 0.003126	 0.00097	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8597	 13453	 0.000252	 0.002984	 0.00085	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8598	 13825	 0.001398	 0.011909	 0.00297	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8598	 13844	 0.003998	 0.015199	 0.00425	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8598	 77728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8598	 77728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8599	 8608	 0.006725	 0.04135	 0.01193	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8599	 11271	 0.001647	 0.007555	 0.00194	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8599	 11272	 0.002176	 0.021797	 0.00726	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8599	 11528	 0.00203	 0.009607	 0.00231	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8600	 8943	 0.000195	 0.00208	 0.00377	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8600	 11321	 7.2e-05	 0.000701	 0.00244	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8601	 12031	 0.000517	 0.003275	 0.00089	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8601	 78841	 0.000686	 0.002904	 0.00065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8602	 10690	 0.000134	 0.001929	 0.0177	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8602	 77729	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8602	 77729	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8602	 78477	 0.000164	 0.002882	 0.03083	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8603	 12462	 0.001017	 0.004815	 0.00116	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8603	 12467	 0.000538	 0.003405	 0.00092	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8603	 77731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8603	 77731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8604	 11836	 0.000944	 0.002571	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8604	 11852	 0.005389	 0.021576	 0.00544	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8604	 77732	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8604	 77732	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8605	 11161	 0.005557	 0.033108	 0.00871	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8605	 11162	 0.006538	 0.046247	 0.01269	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8605	 11533	 0.001104	 0.011702	 0.00347	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8606	 12632	 0.004217	 0.019959	 0.0048	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8606	 13482	 0.001097	 0.007358	 0.00178	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8606	 77733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8606	 77733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8607	 13584	 0.004926	 0.038809	 0.01135	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8607	 13588	 0.004594	 0.039402	 0.01121	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8607	 77734	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8607	 77734	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8608	 11526	 0.003133	 0.01092	 0.00253	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8608	 78671	 0.001675	 0.01775	 0.00527	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8609	 78843	 0.000198	 0.00319	 0.00104	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8609	 78851	 0.000757	 0.004952	 0.00126	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8610	 12037	 0.000276	 0.000731	 0.00017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8610	 77735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8610	 77735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8611	 13784	 0.002916	 0.018468	 0.00501	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8611	 13787	 0.003912	 0.027142	 0.00775	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8611	 77736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8611	 77736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8612	 78645	 0.000591	 0.002501	 0.00056	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8613	 13605	 0.002733	 0.007096	 0.00172	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8613	 77737	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8613	 77737	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8614	 13044	 0.007346	 0.02941	 0.00741	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8614	 13046	 0.003767	 0.040662	 0.01393	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8614	 13061	 0.001649	 0.010447	 0.00284	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8614	 13520	 0.001824	 0.008852	 0.00202	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8614	 13520	 0.001824	 0.008852	 0.00202	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8614	 13526	 0.004537	 0.013142	 0.00317	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8614	 77738	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8614	 77738	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8614	 79092	 0.018625	 0.12004	 0.0315	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8615	 11168	 0.008197	 0.032818	 0.00827	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8615	 13532	 0.008244	 0.023124	 0.00595	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8615	 77739	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8615	 77739	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8616	 13808	 0.000979	 0.005623	 0.00159	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8616	 13809	 0.002538	 0.00855	 0.00212	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8616	 77740	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8616	 77740	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8617	 12147	 0.004448	 0.015257	 0.00365	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8618	 11968	 0.001024	 0.00357	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8618	 78853	 0.000811	 0.002209	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8619	 8622	 0.000196	 0.00064	 0.00017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8620	 13504	 0.004314	 0.018261	 0.00411	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8620	 77741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8620	 77741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8621	 13490	 0.006163	 0.024677	 0.00622	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8621	 77742	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8621	 77742	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8622	 12600	 0.000871	 0.012805	 0.00392	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8622	 12614	 0.001008	 0.007292	 0.00392	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8622	 77743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8622	 77743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8623	 13690	 0.000656	 0.004075	 0.00115	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77704	 8623	 9.9e-05	 0.000421	 9e-05	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8623	 77744	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8623	 77744	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8624	 12144	 0.003636	 0.029028	 0.00715	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8624	 12147	 0.001591	 0.0073	 0.00187	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8624	 77745	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8624	 77745	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8625	 12159	 0.002358	 0.016064	 0.00547	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8625	 12167	 0.006024	 0.031228	 0.00762	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8625	 77746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8625	 77746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8626	 13541	 0.002704	 0.015841	 0.00431	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8626	 13542	 0.003883	 0.016434	 0.0037	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8626	 77747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8626	 77747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8627	 13498	 0.000603	 0.002415	 0.00061	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8627	 77748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8627	 77748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8628	 11788	 0.000234	 0.002589	 0.00084	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 11798	 0.000674	 0.006681	 0.00205	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 77749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8628	 77749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8629	 13812	 0.001204	 0.007479	 0.00211	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8629	 79454	 0.000937	 0.004978	 0.00116	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8630	 11197	 0.000385	 0.004396	 0.00134	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8630	 11223	 0.002212	 0.007451	 0.00185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8630	 11231	 0.00213	 0.017912	 0.00531	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8630	 11232	 0.000623	 0.006893	 0.00207	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8630	 77750	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8630	 77750	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8631	 12329	 0.003487	 0.012154	 0.00282	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8631	 12332	 0.003005	 0.017899	 0.00471	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8631	 13834	 0.003284	 0.013148	 0.00331	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8631	 77751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8631	 77751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8632	 11123	 0.000546	 0.008172	 0.00275	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8632	 25199	 0.003826	 0.045436	 0.01583	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8632	 77752	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8632	 77752	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8632	 78550	 0.00042	 0.004101	 0.00115	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8633	 13546	 0.017459	 0.07498	 0.00137	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8633	 79381	 0.030748	 0.071385	 0.00106	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8634	 12510	 0.000296	 0.006682	 0.6683	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8634	 12628	 1.6e-05	 0.000189	 0.01417	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8634	 12640	 4.5e-05	 0.000774	 0.06021	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8634	 77753	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8634	 77753	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8635	 11191	 0.001438	 0.005878	 0.00012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8635	 11192	 0.000335	 0.001907	 3e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8635	 78555	 0.004376	 0.010157	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8636	 12793	 0.000671	 0.002839	 0.00064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8636	 12794	 0.000901	 0.002655	 0.00062	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8637	 12863	 0.000443	 0.002225	 0.00058	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8637	 12896	 0.000947	 0.005882	 0.00166	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8637	 77754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8637	 77754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8638	 12633	 0.000445	 0.003577	 0.00672	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77753	 8638	 0.000117	 0.001174	 0.00243	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8638	 77755	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8638	 77755	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8639	 12577	 0.00037	 0.004562	 0.00147	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8639	 12579	 0.000327	 0.003524	 0.00101	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8639	 77756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8639	 77756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8640	 12645	 0.003586	 0.01281	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8640	 12645	 0.003586	 0.01281	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8640	 12665	 0.007505	 0.028874	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8640	 12665	 0.007505	 0.028874	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8640	 12666	 0.002382	 0.009268	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8640	 12666	 0.002382	 0.009268	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8641	 11613	 0.000371	 0.009133	 0.92542	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8641	 11613	 0.000371	 0.009133	 0.92542	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8641	 11795	 0.000501	 0.008283	 0.72725	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8641	 14878	 0.000452	 0.005837	 0.37271	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8641	 77757	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8641	 77757	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8642	 11704	 0.005527	 0.033173	 0.01005	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8642	 11705	 0.002688	 0.012329	 0.00316	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8642	 11707	 0.009938	 0.033155	 0.00841	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8642	 77759	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8642	 77759	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8643	 13119	 0.000288	 0.005118	 0.00257	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8643	 79357	 3.3e-05	 0.000548	 0.00031	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8644	 13542	 0.007315	 0.03356	 0.0086	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8644	 13543	 0.00446	 0.017856	 0.0045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8644	 77760	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8644	 77760	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8645	 13532	 0.003782	 0.012744	 0.00317	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8645	 13533	 0.007066	 0.023807	 0.00592	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8645	 77761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8645	 77761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8646	 12150	 0.014799	 0.099318	 0.02399	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8646	 12673	 0.005347	 0.078622	 0.02405	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8646	 12679	 0.003519	 0.050814	 0.01613	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8646	 13605	 0.009576	 0.033848	 0.00763	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8646	 13606	 0.009228	 0.027207	 0.00633	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8646	 77762	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8646	 77762	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8647	 11814	 0.002051	 0.007427	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8647	 77763	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8647	 77763	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8647	 78775	 0.008581	 0.022679	 0.00531	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8648	 10670	 0.002891	 0.017484	 0.00446	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8648	 10683	 0.002439	 0.019592	 0.00551	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8648	 77764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8648	 77764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8649	 13876	 0.008093	 0.018508	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8649	 13877	 0.005944	 0.032732	 0.00074	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77714	 8649	 0.089054	 0.29395	 0.00476	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8649	 79872	 0.02956	 0.078349	 0.00199	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8650	 13480	 0.026586	 0.049434	 0.00116	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8650	 13483	 0.013242	 0.051516	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8651	 10957	 0.016538	 0.016542	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8651	 10962	 0.003664	 0.012822	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8651	 10993	 0.003546	 0.01419	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8651	 10995	 0.010902	 0.007323	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8651	 10997	 0.006716	 0.015592	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8652	 12214	 0.000206	 0.001385	 0.00033	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8652	 12215	 0.000191	 0.000806	 0.00018	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8652	 78935	 0.00283	 0.020019	 0.00549	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8653	 11862	 0.00209	 0.011182	 0.00034	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8653	 78786	 0.0032	 0.008227	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8654	 12160	 0.003315	 0.0116	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8654	 12162	 0.005968	 0.015177	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8654	 12165	 0.010403	 0.046357	 0.00079	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8654	 12166	 0.13302	 0.10528	 0.00133	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8655	 12578	 0.002395	 0.010423	 0.00297	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8655	 12607	 0.001903	 0.013202	 0.00377	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8655	 77765	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8655	 77765	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8656	 12287	 0.001429	 0.006936	 0.00159	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8656	 77766	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8656	 77766	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8656	 78956	 0.002036	 0.019546	 0.00569	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8656	 78958	 0.001068	 0.006071	 0.00176	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8657	 9412	 0.000349	 0.008572	 0.86834	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8657	 9412	 0.000349	 0.008572	 0.86834	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8657	 12783	 0.000276	 0.0068	 0.81063	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8657	 77767	 6.9e-05	 0.0055	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8657	 77767	 6.9e-05	 0.0055	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77769	 8657	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77769	 8657	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8658	 12197	 0.00141	 0.022307	 0.00669	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8658	 12199	 0.001821	 0.025749	 0.00853	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8658	 77770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8658	 77770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8659	 11435	 0.000612	 0.001616	 0.00038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8659	 77771	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8659	 77771	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8660	 12951	 0.000953	 0.002395	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8660	 77772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8660	 77772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8661	 10974	 0.000386	 0.001873	 0.00043	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8661	 11046	 0.002248	 0.010311	 0.00264	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8661	 77773	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8661	 77773	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8662	 10672	 0.00073	 0.002869	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8662	 10673	 0.002182	 0.015434	 0.00424	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8662	 10686	 0.00285	 0.018356	 0.00481	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8662	 77774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8662	 77774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8663	 77775	 0.007163	 0.016382	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8664	 8665	 0.002102	 0.009366	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8664	 8726	 0.01617	 0.011454	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8664	 8727	 0.00298	 0.013816	 0.00029	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8665	 8666	 0.001121	 0.004938	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8666	 77775	 0.002812	 0.010939	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8667	 8674	 0.000661	 0.001799	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8668	 8669	 0.002566	 0.007108	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8668	 77776	 0.004015	 0.009225	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77648	 8669	 0.001872	 0.005368	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8670	 8710	 0.005815	 0.031229	 0.00074	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77648	 8670	 0.003954	 0.022478	 0.00041	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8671	 77776	 0.002951	 0.016603	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8671	 77778	 0.006825	 0.03023	 0.00069	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8672	 77776	 0.01289	 0.009483	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8673	 77777	 0.010059	 0.007271	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8674	 77775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8674	 77775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8675	 8676	 0.000849	 0.003338	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8675	 77776	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8675	 77776	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8676	 8680	 0.002104	 0.006203	 0.00144	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8676	 77777	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8676	 77777	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8677	 10301	 0.034477	 0.10577	 0.00287	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8677	 10301	 0.034477	 0.10577	 0.00287	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8677	 77778	 0.011062	 0.043034	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8677	 77778	 0.011062	 0.043034	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8678	 77778	 0.02666	 0.021098	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8679	 8680	 0.001231	 0.003433	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8679	 77778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8679	 77778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8681	 8682	 0.005226	 0.016048	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8681	 8688	 0.022838	 0.041831	 0.00072	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8682	 77786	 0.00323	 0.016436	 0.00037	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 8689	 0.041163	 0.054101	 0.00074	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 8731	 0.057235	 0.057249	 0.00077	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8684	 8731	 0.039257	 0.031067	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8684	 77782	 0.016936	 0.039318	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8685	 8704	 0.005101	 0.032858	 0.00861	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8685	 10291	 0.005394	 0.030994	 0.00878	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8686	 8731	 0.037199	 0.024082	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8686	 77782	 0.041247	 0.065839	 0.00152	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8687	 8688	 0.072996	 0.057768	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8688	 77782	 0.030104	 0.046972	 0.00079	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8689	 77779	 0.072942	 0.18752	 0.0029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8690	 77779	 0.062727	 0.11318	 0.00164	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 8692	 0.006093	 0.034636	 0.00063	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 9149	 0.009423	 0.057932	 0.00104	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8692	 8999	 0.020268	 0.14679	 0.00369	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8692	 77779	 0.011734	 0.080543	 0.00147	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8693	 77779	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8693	 77779	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8693	 77917	 0.009388	 0.059467	 0.01614	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77779	 8694	 0.038252	 0.035234	 0.00056	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77779	 8695	 0.00724	 0.0346	 0.00076	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8695	 77780	 0.015838	 0.070185	 0.00211	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8696	 9211	 0.005619	 0.022086	 0.00578	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8696	 77780	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8696	 77780	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77780	 8697	 0.020196	 0.051361	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8697	 77919	 0.016569	 0.063746	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8698	 8699	 0.038899	 0.098927	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77780	 8698	 0.054678	 0.14056	 0.00218	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8699	 77781	 0.032062	 0.058725	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8700	 8701	 0.050737	 0.13043	 0.00202	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8700	 77783	 0.108	 0.079461	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8701	 8702	 0.10305	 0.15788	 0.00222	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77780	 8701	 0.029981	 0.076248	 0.00121	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8702	 8708	 0.11091	 0.087773	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8703	 8704	 0.002173	 0.008973	 0.00212	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8703	 8705	 0.002072	 0.009806	 0.00236	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8703	 77781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8703	 77781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8704	 77782	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8704	 77782	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8705	 77783	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8705	 77783	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8706	 8707	 0.002775	 0.014038	 0.00391	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8706	 8716	 0.000952	 0.003931	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8706	 77784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8706	 77784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8707	 77785	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8707	 77785	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77785	 8708	 0.074869	 0.055084	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8709	 8712	 0.001709	 0.005143	 0.00161	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8709	 77786	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8709	 77786	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8710	 8711	 0.008213	 0.016807	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77786	 8710	 0.008044	 0.02228	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8711	 8714	 0.007688	 0.019474	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8712	 8715	 0.001269	 0.008171	 0.00214	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8712	 77787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8712	 77787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77784	 8713	 0.027819	 0.022015	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8714	 8723	 0.026055	 0.06049	 0.0009	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77784	 8714	 0.005124	 0.031503	 0.00057	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77787	 8714	 0.011766	 0.017145	 0.00039	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8715	 8716	 0.000609	 0.003785	 0.00107	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8716	 8717	 0.000637	 0.005426	 0.00135	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8717	 8719	 0.000833	 0.00589	 0.00162	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8717	 77788	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8717	 77788	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77788	 8718	 0.020923	 0.016558	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8719	 8721	 0.001495	 0.004288	 0.00106	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8719	 77789	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8719	 77789	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77789	 8720	 0.024481	 0.019374	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8721	 77790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8721	 77790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77789	 8722	 0.029594	 0.022421	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8723	 8724	 0.005994	 0.008985	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8724	 8725	 0.001667	 0.007055	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8724	 8728	 0.003334	 0.016003	 0.00048	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8725	 8730	 0.005694	 0.025478	 0.00052	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8727	 8728	 0.001852	 0.010405	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8727	 8729	 0.007536	 0.005964	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77790	 8730	 0.007318	 0.036796	 0.001	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8732	 77827	 0.009402	 0.021827	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8732	 77831	 0.008594	 0.058989	 0.00108	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8733	 77798	 0.034191	 0.0268	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8734	 8735	 0.006552	 0.013408	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8734	 77806	 0.053509	 0.17852	 0.00283	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8735	 77798	 0.010609	 0.020555	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8736	 8737	 0.00074	 0.002578	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8736	 8741	 0.001413	 0.003939	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8736	 77791	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8736	 77791	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8737	 8738	 0.00066	 0.001987	 0.00062	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8737	 77792	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8737	 77792	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8738	 8739	 0.00107	 0.003672	 0.00088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8739	 8891	 0.000601	 0.003523	 0.00096	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8739	 77793	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8739	 77793	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77793	 8740	 0.001901	 0.005037	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8740	 77794	 0.00237	 0.012324	 0.00027	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8740	 77836	 0.005836	 0.011942	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8741	 8767	 0.001397	 0.004047	 0.00098	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8741	 77794	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8741	 77794	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8742	 77795	 0.012454	 0.008063	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8743	 8869	 0.000761	 0.002565	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8743	 8892	 0.002171	 0.005636	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77635	 8743	 0.003838	 0.010448	 0.0023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8743	 77795	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8743	 77795	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8744	 8761	 0.00033	 0.004765	 0.00151	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77620	 8744	 0.002018	 0.017626	 0.00698	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8744	 77796	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8744	 77796	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8745	 8746	 0.00873	 0.007185	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8745	 8747	 0.002111	 0.007041	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8745	 8786	 0.013913	 0.010906	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8745	 8866	 0.004231	 0.009823	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8747	 8788	 0.002677	 0.007596	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8748	 8777	 6.8e-05	 0.001069	 0.00036	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8748	 77797	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8748	 77797	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8749	 8753	 0.007184	 0.023707	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8749	 8810	 0.007515	 0.015378	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8749	 77798	 0.007763	 0.018383	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8750	 8751	 0.003286	 0.008516	 0.00258	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8750	 8904	 0.002461	 0.015128	 0.00436	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8750	 77798	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8750	 77798	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8751	 8769	 0.005437	 0.014626	 0.0041	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8751	 77799	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8751	 77799	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77799	 8752	 0.023779	 0.015394	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8753	 8756	 0.003333	 0.014914	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77791	 8754	 0.002724	 0.013075	 0.00039	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77799	 8754	 0.007973	 0.020494	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8755	 8756	 0.012189	 0.009646	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77791	 8755	 0.010779	 0.011511	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8756	 8841	 0.005753	 0.014788	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77792	 8756	 0.015702	 0.02405	 0.00042	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8757	 8758	 0.001225	 0.006969	 0.00021	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8757	 8774	 0.002524	 0.013123	 0.00028	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8759	 8792	 0.004345	 0.013343	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8760	 77835	 0.003238	 0.016839	 0.00037	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8761	 8883	 0.000812	 0.005535	 0.00189	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8761	 8884	 0.000454	 0.003539	 0.00106	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8761	 77800	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8761	 77800	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8762	 8881	 0.000667	 0.002323	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8762	 8900	 0.000603	 0.001594	 0.00037	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8762	 77801	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8762	 77801	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77080	 8763	 0.00484	 0.018828	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77080	 8763	 0.00484	 0.018828	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77636	 8763	 0.010864	 0.042264	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77636	 8763	 0.010864	 0.042264	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77797	 8763	 0.00116	 0.006251	 0.00013	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8764	 8787	 0.002192	 0.008433	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8764	 8788	 0.002238	 0.006737	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8765	 8850	 0.001018	 0.004077	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8765	 8904	 0.001205	 0.004198	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8765	 77802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8765	 77802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8766	 77804	 0.027795	 0.021997	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8767	 8769	 0.002107	 0.005569	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8767	 8893	 0.001526	 0.009159	 0.00277	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77537	 8767	 0.00204	 0.017159	 0.00508	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8767	 77803	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8767	 77803	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8768	 77804	 0.011202	 0.011315	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77635	 8769	 0.001619	 0.009547	 0.00777	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8769	 77804	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8769	 77804	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77804	 8770	 0.019737	 0.012778	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77804	 8771	 0.009764	 0.025304	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8772	 8775	 0.002421	 0.011226	 0.00023	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8772	 77806	 0.003207	 0.018232	 0.00033	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8773	 10379	 0.00027	 0.00267	 0.0457	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8773	 10379	 0.00027	 0.00267	 0.0457	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8773	 77805	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77806	 8774	 0.002872	 0.014529	 0.00025	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8775	 8776	 0.002539	 0.011189	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8776	 8860	 0.005379	 0.028659	 0.0005	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8776	 8885	 0.00664	 0.019046	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77806	 8776	 0.003486	 0.024824	 0.00056	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8777	 8778	 0.000149	 0.001354	 0.00071	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8778	 8867	 0.00023	 0.003124	 0.00181	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8778	 9589	 0.000524	 0.003252	 0.00079	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8778	 77807	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8778	 77807	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8779	 77808	 0.008539	 0.013324	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8780	 8781	 0.002413	 0.005602	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8780	 8816	 0.006226	 0.017857	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8781	 77808	 0.003822	 0.007107	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8782	 77808	 0.013291	 0.010519	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8783	 8785	 0.000974	 0.00282	 0.00068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8783	 77808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8783	 77808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77808	 8784	 0.002289	 0.004089	 6e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77635	 8785	 0.001553	 0.010421	 0.00252	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8785	 77809	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8785	 77809	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77809	 8787	 0.001194	 0.00418	 0.00012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 8828	 0.000744	 0.006177	 0.00242	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 8849	 0.001053	 0.009558	 0.00311	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8790	 8908	 0.013957	 0.032398	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8790	 78307	 0.007391	 0.030207	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8791	 8792	 0.010097	 0.010998	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8792	 78293	 0.002189	 0.012441	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8793	 8794	 0.000296	 0.001892	 0.00064	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8793	 8796	 0.000316	 0.001944	 0.00071	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8794	 8821	 0.000284	 0.0018	 0.00049	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8795	 78293	 0.006566	 0.014895	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8796	 10329	 0.000316	 0.002521	 0.00062	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8797	 8798	 0.013048	 0.013179	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8798	 8875	 0.015523	 0.025888	 0.00038	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77806	 8798	 0.00323	 0.017015	 0.00031	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8799	 8800	 0.000934	 0.002468	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8799	 8876	 0.00177	 0.008255	 0.00204	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8799	 8892	 0.000531	 0.002438	 0.00062	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8799	 77820	 0.002396	 0.01163	 0.00266	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8800	 77810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8800	 77810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77810	 8801	 0.009272	 0.006703	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8802	 8805	 0.000529	 0.00208	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8802	 8835	 0.00041	 0.001642	 0.00041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8803	 77812	 0.011861	 0.008727	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8804	 8820	 0.000478	 0.003028	 0.00082	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8804	 77811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8804	 77811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8804	 77820	 0.001932	 0.005696	 0.00132	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8805	 8806	 0.000491	 0.001685	 0.0004	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8805	 8893	 0.001098	 0.006044	 0.00218	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8806	 8808	 0.000713	 0.002856	 0.00072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8806	 8893	 0.001202	 0.007612	 0.00207	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8806	 10329	 0.001502	 0.014675	 0.00412	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8806	 77812	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8806	 77812	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8807	 8808	 0.000744	 0.002893	 0.00077	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8807	 8869	 0.000629	 0.002617	 0.00082	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8809	 77839	 0.022783	 0.045109	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8810	 8879	 0.009137	 0.021635	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8811	 8812	 0.000456	 0.00216	 0.00052	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8811	 77813	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8811	 77813	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8811	 77820	 0.000578	 0.002926	 0.00081	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8812	 8823	 0.000526	 0.002413	 0.00062	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8813	 77839	 0.032788	 0.024123	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 8903	 0.001798	 0.005997	 0.00152	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 77814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8814	 77814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8815	 8871	 0.005664	 0.014559	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8815	 8897	 0.00947	 0.018559	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8816	 8817	 0.013104	 0.010272	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8816	 77830	 0.007776	 0.03025	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8818	 77815	 0.01841	 0.014569	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8818	 77821	 0.00293	 0.016463	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8818	 77830	 0.002402	 0.007367	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8819	 8840	 0.000609	 0.00386	 0.00105	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77635	 8819	 0.000332	 0.00325	 0.00102	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8819	 77815	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8819	 77815	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8820	 8886	 0.001095	 0.005105	 0.00126	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8820	 77816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8820	 77816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8821	 8822	 0.000186	 0.00118	 0.00032	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8822	 8823	 0.000395	 0.001872	 0.00045	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8822	 77817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8822	 77817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8824	 8884	 0.000629	 0.005137	 0.00139	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8824	 77818	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8824	 77818	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8824	 78040	 0.001322	 0.011532	 0.00317	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8825	 8882	 0.00184	 0.012626	 0.00023	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8825	 77956	 0.001655	 0.013772	 0.00026	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8826	 8827	 0.006861	 0.012254	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8826	 77956	 0.0029	 0.009675	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8828	 8863	 0.000564	 0.005418	 0.00158	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8829	 8830	 0.014611	 0.037558	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8829	 77828	 0.006	 0.021009	 0.00058	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8831	 77828	 0.015406	 0.019606	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8832	 77828	 0.011321	 0.032125	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8833	 8860	 0.005532	 0.016989	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77810	 8833	 0.00409	 0.015736	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8834	 8835	 0.000422	 0.001787	 0.0004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8834	 8880	 0.000837	 0.003541	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8834	 77819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8834	 77819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8836	 8872	 0.022768	 0.017846	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8836	 8898	 0.012923	 0.021583	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8836	 77831	 0.018489	 0.028042	 0.0004	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8836	 77840	 0.002304	 0.015813	 0.00029	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8837	 8838	 0.014419	 0.033475	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8837	 8861	 0.021684	 0.014038	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8837	 77826	 0.021903	 0.07669	 0.00212	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77814	 8838	 0.005431	 0.02008	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8839	 10400	 0.000655	 0.008354	 0.02844	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76463	 8839	 0.005446	 0.03753	 0.06629	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8839	 77820	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77821	 8839	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77820	 8840	 0.000914	 0.005354	 0.00146	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8840	 77822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8840	 77822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8841	 77824	 0.006554	 0.016668	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8842	 8843	 0.019484	 0.01542	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77793	 8843	 0.001669	 0.00801	 0.00024	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8843	 77832	 0.003186	 0.008071	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8844	 8845	 0.001147	 0.010679	 0.00021	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77818	 8844	 0.002415	 0.012924	 0.00039	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8845	 9573	 0.000652	 0.004932	 0.00016	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8846	 77960	 0.01018	 0.008056	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8847	 8849	 0.000691	 0.004075	 0.00332	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8847	 10377	 0.001147	 0.01656	 0.00526	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8847	 77823	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8847	 77823	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77823	 8848	 0.032771	 0.025934	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8849	 10374	 0.000619	 0.007356	 0.00256	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8849	 10383	 0.001266	 0.012801	 0.00376	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8850	 8851	 0.000853	 0.003415	 0.00086	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8851	 8856	 0.001199	 0.0048	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8851	 77824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8851	 77824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8852	 8853	 0.004945	 0.008922	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8852	 8854	 0.011806	 0.011924	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77636	 8852	 0.00398	 0.021783	 0.00043	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 8855	 0.00872	 0.006415	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8856	 8877	 0.00162	 0.004071	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8856	 77825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8856	 77825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8857	 77826	 0.009239	 0.016923	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8858	 8903	 0.000532	 0.005771	 0.0018	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77805	 8858	 0.000918	 0.014524	 0.00436	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8858	 77826	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8858	 77826	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77806	 8859	 0.011042	 0.04248	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77806	 8859	 0.011042	 0.04248	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77825	 8859	 0.002638	 0.020795	 0.00044	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8862	 8878	 0.026783	 0.021196	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77814	 8862	 0.013276	 0.031438	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8863	 8864	 0.000605	 0.005089	 0.00151	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8864	 8865	 0.001644	 0.004422	 0.00124	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8864	 77827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8864	 77827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8865	 77828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8865	 77828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77807	 8866	 0.001653	 0.012885	 0.00024	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8866	 77829	 0.002041	 0.015719	 0.0003	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77635	 8867	 8.1e-05	 0.001216	 0.00086	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8867	 77829	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8867	 77829	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8868	 77830	 0.012467	 0.009445	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8869	 8870	 0.001185	 0.003226	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8869	 8894	 0.001842	 0.005136	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77635	 8869	 0.002862	 0.007563	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77635	 8870	 0.001677	 0.004432	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8870	 77830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8870	 77830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8871	 77831	 0.003467	 0.021314	 0.00038	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8873	 77831	 0.017948	 0.014069	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8874	 8910	 0.001275	 0.008556	 0.00207	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77805	 8874	 0.002619	 0.010487	 0.00264	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8874	 77831	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8874	 77831	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8876	 8877	 0.000684	 0.001841	 0.00052	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8876	 77832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8876	 77832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8879	 77839	 0.00593	 0.01266	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8880	 8886	 0.000718	 0.004309	 0.0013	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8880	 77833	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8880	 77833	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8881	 8883	 0.000481	 0.003225	 0.00078	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8881	 10335	 0.00034	 0.002513	 0.00073	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8882	 77834	 0.001555	 0.009209	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8883	 77834	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8883	 77834	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77833	 8885	 0.005705	 0.015802	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8886	 10372	 0.001748	 0.016453	 0.00498	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8886	 77835	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8886	 77835	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8887	 8897	 0.030319	 0.023766	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77827	 8888	 0.0171	 0.033857	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8889	 8890	 0.001481	 0.006565	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77804	 8889	 0.005818	 0.011906	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8890	 77836	 0.00194	 0.010916	 0.00024	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8891	 8892	 0.000686	 0.004347	 0.00118	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8891	 77836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8891	 77836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8892	 8893	 0.000787	 0.003331	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 8894	 0.001532	 0.004048	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77803	 8895	 0.014281	 0.027988	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77791	 8896	 0.01921	 0.015057	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77792	 8896	 0.019485	 0.021224	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77804	 8896	 0.057944	 0.041887	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77801	 8899	 0.004883	 0.014997	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8899	 78293	 0.019629	 0.025798	 0.00035	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8900	 77837	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8900	 77837	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8901	 10340	 0.002697	 0.006197	 9e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77837	 8901	 0.00401	 0.009309	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8902	 77838	 0.020177	 0.013553	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8903	 8904	 0.000906	 0.007137	 0.00209	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8903	 77838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8903	 77838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8904	 77839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8904	 77839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77802	 8905	 0.007448	 0.015241	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77838	 8905	 0.005129	 0.012731	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77813	 8906	 0.007681	 0.019533	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8907	 8908	 0.022743	 0.017999	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8909	 8910	 0.00094	 0.004635	 0.00125	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8909	 10326	 0.001325	 0.007123	 0.00175	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8910	 77840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8910	 77840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8911	 9142	 0.001135	 0.005803	 0.00158	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8911	 77841	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8911	 77841	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8912	 8913	 0.014374	 0.010391	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77841	 8913	 0.014524	 0.014831	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77841	 8914	 0.003779	 0.013498	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77841	 8914	 0.003779	 0.013498	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8914	 77842	 0.004842	 0.017297	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8914	 77842	 0.004842	 0.017297	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8915	 13437	 0.000764	 0.007722	 0.00227	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8915	 77842	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8915	 77842	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77841	 8916	 0.014405	 0.0114	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77841	 8917	 0.014486	 0.02868	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8918	 8919	 0.01447	 0.010646	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8918	 8933	 0.004683	 0.014366	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8918	 8933	 0.004683	 0.014366	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77842	 8918	 0.004544	 0.015523	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77842	 8918	 0.004544	 0.015523	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8920	 8922	 0.003595	 0.011028	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8920	 77869	 0.003873	 0.016167	 0.00047	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	8921	 77869	 0.02174	 0.017205	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8922	 8923	 0.002777	 0.00734	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8923	 8924	 0.003949	 0.009666	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8924	 8926	 0.002883	 0.015776	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8924	 9053	 0.005378	 0.030262	 0.00065	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8925	 8982	 0.007203	 0.018516	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8925	 9052	 0.005668	 0.018907	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8926	 8985	 0.003201	 0.029804	 0.00058	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8926	 77898	 0.018352	 0.070605	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8927	 8928	 0.006079	 0.023386	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8927	 8928	 0.006079	 0.023386	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8927	 77869	 0.009838	 0.034424	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8927	 77869	 0.009838	 0.034424	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8928	 8929	 0.001738	 0.013144	 0.00044	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8929	 8930	 0.003135	 0.028838	 0.00057	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8930	 77843	 0.003229	 0.022994	 0.00052	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 8979	 0.001093	 0.005224	 0.00183	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 77843	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8931	 77843	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8932	 8934	 0.001069	 0.008896	 0.00017	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77842	 8932	 0.00702	 0.02731	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77842	 8932	 0.00702	 0.02731	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77843	 8932	 0.006389	 0.028468	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8932	 77844	 0.007857	 0.030228	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8932	 77844	 0.007857	 0.030228	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77843	 8933	 0.006332	 0.024362	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77843	 8933	 0.006332	 0.024362	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8934	 8935	 0.001047	 0.00816	 0.00015	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8935	 8936	 0.000762	 0.005176	 0.00013	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8936	 77844	 0.001644	 0.010986	 0.00024	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8937	 8939	 0.001235	 0.005759	 0.00143	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8937	 77844	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8937	 77844	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8938	 8940	 0.003319	 0.016012	 0.00028	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8938	 11309	 0.003896	 0.018063	 0.00038	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8939	 77846	 0.001842	 0.008448	 0.00216	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8940	 77847	 0.003146	 0.017675	 0.00033	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8941	 8944	 0.013212	 0.026158	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8942	 8946	 0.000294	 0.004236	 0.00154	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8942	 8950	 0.000592	 0.006914	 0.00541	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8942	 8951	 0.001307	 0.007655	 0.00209	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8942	 77845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8942	 77845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8943	 77846	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77847	 8943	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8944	 8970	 0.003424	 0.011986	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77645	 8944	 0.01972	 0.045783	 0.00068	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8945	 77848	 0.015835	 0.012531	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8946	 8947	 0.000172	 0.002483	 0.0009	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8947	 77848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8947	 77848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77645	 8948	 0.016312	 0.012909	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8949	 11442	 0.006649	 0.02558	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77845	 8949	 0.006801	 0.030305	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77700	 8950	 0.000503	 0.006971	 0.00481	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8950	 77849	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8950	 77849	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8951	 8953	 0.001914	 0.009618	 0.0025	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8951	 77850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8951	 77850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8952	 9018	 0.032089	 0.085053	 0.00216	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8952	 77859	 0.006882	 0.04724	 0.00086	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8953	 77851	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8953	 77851	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8954	 8955	 0.000524	 0.005444	 0.00168	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8954	 9719	 0.000363	 0.005456	 0.0032	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77700	 8954	 0.000964	 0.010331	 0.0033	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8954	 77852	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8954	 77852	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8955	 9016	 0.001972	 0.005119	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77622	 8955	 0.00154	 0.01007	 0.00256	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77700	 8955	 0.000964	 0.006937	 0.00184	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8956	 9018	 0.013354	 0.033962	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8956	 77862	 0.011224	 0.022969	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8957	 8960	 0.013835	 0.049424	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8957	 8960	 0.013835	 0.049424	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8957	 8964	 0.013865	 0.046253	 0.00073	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8957	 8996	 0.011724	 0.041881	 0.00083	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8957	 8996	 0.011724	 0.041881	 0.00083	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8958	 8964	 0.004718	 0.015737	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77851	 8958	 0.039217	 0.11248	 0.00173	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8959	 8961	 0.017748	 0.041204	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8959	 8962	 0.004495	 0.0246	 0.00048	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8959	 10299	 0.011234	 0.076222	 0.00142	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8960	 8963	 0.006919	 0.026918	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8960	 8963	 0.006919	 0.026918	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8961	 77861	 0.051656	 0.11868	 0.0018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	8962	 8963	 0.003803	 0.02162	 0.00039	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8963	 77861	 0.012188	 0.042673	 0.00118	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77851	 8965	 0.019922	 0.047176	 0.00086	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8966	 77860	 0.02291	 0.041337	 0.0006	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8967	 77860	 0.018436	 0.018621	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8968	 77860	 0.015768	 0.012359	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77645	 8969	 0.011455	 0.070384	 0.00161	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8970	 8971	 0.002203	 0.009002	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8971	 8975	 0.002365	 0.011539	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8972	 8974	 0.026355	 0.020857	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8973	 8974	 0.003389	 0.011183	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8973	 8980	 0.005266	 0.014386	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8974	 77853	 0.008232	 0.023611	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8974	 77854	 0.014172	 0.013693	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8975	 77853	 0.001927	 0.009745	 0.00017	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8976	 8977	 0.000705	 0.004127	 0.00112	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77846	 8976	 0.000623	 0.005005	 0.00141	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8976	 77853	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8976	 77853	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8977	 8979	 0.000508	 0.002917	 0.00083	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8977	 77854	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8977	 77854	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77854	 8978	 0.012631	 0.009996	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8979	 77855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8979	 77855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8980	 8988	 0.002927	 0.01914	 0.00044	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77855	 8980	 0.010625	 0.024298	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8981	 8982	 0.001369	 0.010345	 0.00031	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8981	 8983	 0.001938	 0.016121	 0.00031	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8982	 77873	 0.004576	 0.025197	 0.00057	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8983	 8984	 0.004426	 0.017028	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8983	 8984	 0.004426	 0.017028	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8983	 9006	 0.003865	 0.020099	 0.00044	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8984	 8986	 0.006348	 0.024695	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8984	 8986	 0.006348	 0.024695	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8985	 8986	 0.003856	 0.027857	 0.00053	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8986	 8989	 0.004843	 0.01884	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8986	 8989	 0.004843	 0.01884	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8987	 8988	 0.001671	 0.013026	 0.00024	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8987	 8989	 0.001681	 0.013457	 0.00028	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8989	 8990	 0.001288	 0.009174	 0.00021	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8989	 8991	 0.027184	 0.021308	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8990	 8992	 0.003407	 0.0249	 0.00046	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	8992	 77860	 0.007534	 0.028865	 0.00082	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	8993	 8995	 0.00695	 0.033378	 0.00065	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	8993	 9002	 0.007441	 0.0423	 0.00077	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	8994	 8995	 0.024762	 0.02501	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	8995	 77860	 0.005807	 0.017815	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8996	 8998	 0.035334	 0.027962	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	8996	 77856	 0.014884	 0.053172	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8996	 77856	 0.014884	 0.053172	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8997	 9001	 0.001657	 0.011101	 0.0034	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8997	 77856	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8997	 77856	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8999	 9020	 0.021251	 0.1442	 0.00269	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9000	 77858	 0.091669	 0.11519	 0.00173	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9001	 9005	 0.001058	 0.006078	 0.00172	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9001	 77857	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9001	 77857	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9002	 9006	 0.009562	 0.069893	 0.00129	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9003	 9011	 0.003797	 0.027044	 0.00061	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77857	 9003	 0.004562	 0.029084	 0.00071	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9004	 9005	 0.002103	 0.012528	 0.0033	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9004	 9127	 0.002754	 0.019476	 0.00534	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9004	 77858	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9004	 77858	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9006	 9007	 0.00222	 0.012621	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9006	 9009	 0.004521	 0.024089	 0.00042	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9006	 9014	 0.020767	 0.022841	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9006	 9015	 0.026356	 0.040375	 0.00057	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9006	 77874	 0.005832	 0.035442	 0.00065	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9007	 77874	 0.003768	 0.023165	 0.00042	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9008	 9009	 0.00387	 0.015055	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9008	 9009	 0.00387	 0.015055	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9008	 9098	 0.006983	 0.02142	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9008	 9098	 0.006983	 0.02142	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9009	 9011	 0.003258	 0.030335	 0.00059	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9010	 9013	 0.048884	 0.038686	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9010	 9098	 0.01676	 0.032847	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9012	 77891	 0.047886	 0.037897	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9016	 9017	 0.002361	 0.013537	 0.0045	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77700	 9016	 0.001165	 0.007376	 0.002	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9016	 77859	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9016	 77859	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9016	 78645	 0.00191	 0.012101	 0.00328	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9017	 10223	 0.005615	 0.032889	 0.00896	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9019	 77860	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9019	 77860	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9020	 10281	 0.027094	 0.1409	 0.00305	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9021	 77862	 0.041337	 0.032713	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9022	 9024	 0.002268	 0.00923	 0.00225	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77700	 9022	 0.003718	 0.03703	 0.01375	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9022	 77861	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9022	 77861	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77852	 9023	 0.031238	 0.023667	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9024	 77862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9024	 77862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9025	 9034	 0.00332	 0.012773	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9025	 77866	 0.003074	 0.021097	 0.00038	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9026	 9037	 0.014292	 0.010124	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9027	 9028	 0.013613	 0.00984	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9028	 77895	 0.006066	 0.011888	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9029	 9030	 0.000296	 0.00319	 0.00091	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9029	 9139	 0.000413	 0.004565	 0.00137	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9030	 9032	 0.000265	 0.002905	 0.00081	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9031	 9034	 0.013978	 0.010284	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9032	 9033	 0.000629	 0.002391	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9032	 9048	 0.000333	 0.003361	 0.00099	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9032	 77863	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9032	 77863	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9033	 9044	 0.000728	 0.002862	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9033	 77864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9033	 77864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77864	 9034	 0.00233	 0.013246	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9034	 79355	 0.009071	 0.049952	 0.00113	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9035	 77865	 0.013068	 0.010342	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9036	 9039	 0.000469	 0.004368	 0.00135	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9036	 9150	 0.0005	 0.004288	 0.00122	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9036	 77865	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9036	 77865	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9037	 9038	 0.004088	 0.005957	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9037	 77866	 0.005029	 0.011674	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9038	 77867	 0.00356	 0.00662	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9039	 77866	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9039	 77866	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9040	 77867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9040	 77867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9041	 9066	 0.002337	 0.010721	 0.00275	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9041	 9144	 0.000754	 0.004778	 0.0013	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9041	 77868	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9041	 77868	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77864	 9042	 0.009457	 0.007484	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9043	 9044	 0.000554	 0.002346	 0.00053	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9043	 9050	 0.000976	 0.00397	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9045	 9046	 0.000697	 0.002792	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9045	 77869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9045	 77869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9046	 9049	 0.000912	 0.004428	 0.00101	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9047	 77870	 0.001989	 0.010597	 0.00019	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9047	 77871	 0.001	 0.006142	 0.00014	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9048	 77870	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9048	 77870	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9048	 77896	 0.000301	 0.002887	 0.00084	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9049	 77871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9049	 77871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9049	 77896	 0.001508	 0.006384	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9050	 9051	 0.00074	 0.004336	 0.00118	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9050	 9055	 0.003293	 0.016832	 0.00459	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9050	 9065	 0.000684	 0.005084	 0.00194	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9050	 77896	 0.002682	 0.010739	 0.00271	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9051	 77872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9051	 77872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77872	 9052	 0.00491	 0.020066	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77872	 9053	 0.001804	 0.008659	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9053	 77873	 0.003589	 0.016878	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9054	 9063	 0.000933	 0.00395	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9054	 77873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9054	 77873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9055	 77874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9055	 77874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9056	 9058	 0.001362	 0.005543	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9056	 9060	 0.001503	 0.006117	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9057	 77875	 0.016882	 0.01336	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9058	 9087	 0.001285	 0.005438	 0.00122	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9058	 77875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9058	 77875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9059	 77876	 0.017445	 0.019188	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9060	 77876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9060	 77876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9061	 9062	 0.001003	 0.004014	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9061	 9085	 0.000793	 0.003084	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9062	 9063	 0.000722	 0.002836	 0.00074	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9064	 9084	 0.017449	 0.012614	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9065	 9070	 0.000296	 0.002933	 0.0008	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9066	 9083	 0.000605	 0.002421	 0.00082	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9066	 77877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9066	 77877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9067	 9072	 0.003814	 0.012585	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9067	 9079	 0.003765	 0.009679	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77877	 9067	 0.001491	 0.008375	 0.00016	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77865	 9068	 0.005894	 0.009928	 0.00014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77867	 9068	 0.003144	 0.01223	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9068	 77902	 0.002297	 0.007847	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9069	 77878	 0.014212	 0.010274	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9070	 9071	 0.000238	 0.002289	 0.00067	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9071	 9150	 0.000295	 0.003169	 0.00082	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9071	 77878	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9071	 77878	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9072	 77902	 0.002827	 0.010875	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9073	 77903	 0.020958	 0.016428	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9074	 9075	 0.000588	 0.002427	 0.00057	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9074	 9144	 0.000703	 0.002814	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9075	 9091	 0.001217	 0.00515	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9075	 9151	 0.001042	 0.003575	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9075	 77879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9075	 77879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9076	 77989	 0.02184	 0.017284	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77879	 9077	 0.00611	 0.013094	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9077	 77903	 0.006767	 0.00986	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9078	 9080	 0.00246	 0.009571	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9078	 77899	 0.002248	 0.009011	 0.00023	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9079	 9082	 0.003734	 0.011454	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9080	 9081	 0.003942	 0.008068	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9081	 9082	 0.001826	 0.010379	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9081	 9090	 0.00461	 0.01538	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9082	 9088	 0.002586	 0.011054	 0.00025	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9083	 9085	 0.000976	 0.003836	 0.001	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9083	 77880	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9083	 77880	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77880	 9084	 0.007755	 0.015353	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9085	 77881	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9085	 77881	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77881	 9086	 0.016664	 0.012261	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9087	 77882	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9087	 77882	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9087	 77996	 0.003322	 0.022288	 0.00538	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77882	 9088	 0.003387	 0.01509	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9089	 9093	 0.015371	 0.016742	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9090	 77901	 0.004226	 0.016441	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9091	 9145	 0.001168	 0.004005	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9091	 9427	 0.000773	 0.004107	 0.00095	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9091	 77883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9091	 77883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9092	 77901	 0.019721	 0.019919	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9093	 9112	 0.01593	 0.014373	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9093	 77901	 0.006803	 0.02617	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77882	 9094	 0.020172	 0.014841	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9095	 9111	 0.000866	 0.003369	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9095	 77884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9095	 77884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9096	 9102	 0.002149	 0.009189	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77884	 9096	 0.001649	 0.011321	 0.00021	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9097	 9098	 0.004532	 0.032741	 0.00062	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9097	 9101	 0.002813	 0.012536	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77882	 9097	 0.012335	 0.047986	 0.0008	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9098	 9099	 0.00518	 0.029444	 0.00053	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77876	 9098	 0.005855	 0.020487	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9099	 9100	 0.002452	 0.016832	 0.00031	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9099	 77891	 0.00362	 0.030111	 0.00057	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9100	 9103	 0.002162	 0.016216	 0.00033	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9101	 9102	 0.002332	 0.009681	 0.00025	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77882	 9102	 0.012009	 0.025734	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9103	 77885	 0.002414	 0.020081	 0.00038	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9104	 9125	 0.008437	 0.018927	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9104	 77885	 0.009848	 0.018311	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9105	 9109	 0.001372	 0.004622	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9105	 77885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9105	 77885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9106	 9115	 0.027832	 0.027839	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9107	 9108	 0.003987	 0.009256	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9107	 9123	 0.008356	 0.019399	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9108	 77886	 0.005433	 0.011418	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9109	 9146	 0.001106	 0.003358	 0.00074	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9109	 77886	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9109	 77886	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9110	 9111	 0.000953	 0.003814	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9110	 9118	 0.000719	 0.004212	 0.00115	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9110	 9146	 0.00149	 0.004179	 0.00108	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9110	 77887	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9110	 77887	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9111	 77888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9111	 77888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77888	 9112	 0.015173	 0.015177	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77887	 9113	 0.01667	 0.013192	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9114	 9115	 0.006162	 0.017485	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9114	 77889	 0.006175	 0.035104	 0.00064	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9115	 9124	 0.022921	 0.02068	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9116	 77889	 0.014495	 0.022202	 0.00039	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9117	 9118	 0.000926	 0.003917	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9117	 77996	 0.00119	 0.004765	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9118	 77889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9118	 77889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9118	 77996	 0.001369	 0.007595	 0.00231	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9119	 9120	 0.009807	 0.015023	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9119	 9122	 0.009999	 0.025704	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9119	 9124	 0.014846	 0.019511	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9119	 9148	 0.022575	 0.027024	 0.00045	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9120	 77893	 0.014403	 0.024055	 0.00041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9121	 9456	 0.016594	 0.032521	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9122	 9455	 0.007898	 0.020303	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9123	 9124	 0.013414	 0.014754	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9123	 9125	 0.006725	 0.019287	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9126	 9127	 0.000593	 0.004332	 0.00128	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9126	 9135	 0.002992	 0.013724	 0.00352	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9126	 77890	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9126	 77890	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9126	 77996	 0.005702	 0.032762	 0.00928	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9127	 77891	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9127	 77891	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9128	 9129	 0.052362	 0.041439	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9128	 9132	 0.012562	 0.032291	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9130	 9149	 0.084806	 0.061307	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9131	 9132	 0.008374	 0.034225	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9131	 9149	 0.008313	 0.036836	 0.00111	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77890	 9132	 0.026212	 0.04954	 0.0008	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9133	 9476	 0.030613	 0.019819	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9134	 9135	 0.001119	 0.008381	 0.00204	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9134	 9472	 0.001007	 0.006915	 0.00202	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9134	 77892	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9134	 77892	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9135	 77893	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9135	 77893	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77892	 9136	 0.022371	 0.014483	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9137	 9474	 0.003855	 0.013225	 0.00317	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9137	 77894	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9137	 77894	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9138	 9139	 0.000136	 0.001558	 0.00048	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9138	 13426	 0.000322	 0.004056	 0.00126	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9139	 77895	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9139	 77895	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9140	 77896	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77897	 9140	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9140	 79344	 0.000211	 0.001937	 0.00764	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77864	 9141	 0.008597	 0.017022	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77896	 9142	 0.000733	 0.006821	 0.00211	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9142	 77898	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9142	 77898	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9142	 79297	 0.001473	 0.008626	 0.00235	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9143	 9151	 0.000575	 0.002302	 0.00058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9143	 77899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9143	 77899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9144	 77900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9144	 77900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9145	 77901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9145	 77901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9147	 77997	 0.032767	 0.03604	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77779	 9149	 0.019941	 0.09731	 0.00168	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77894	 9149	 0.005916	 0.036348	 0.00083	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9150	 77902	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9150	 77902	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9151	 77903	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9151	 77903	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9152	 9153	 0.007062	 0.016394	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9152	 9154	 0.015311	 0.011264	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77633	 9152	 0.012997	 0.052012	 0.0011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9153	 9155	 0.012472	 0.019106	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9155	 9157	 0.035082	 0.027763	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9156	 9157	 0.040637	 0.03216	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9158	 77904	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9158	 77904	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9159	 9164	 0.031943	 0.071666	 0.00114	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77904	 9159	 0.028201	 0.065473	 0.00097	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9160	 9161	 0.047342	 0.06161	 0.00086	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9161	 9162	 0.013107	 0.034739	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9161	 9163	 0.031348	 0.072767	 0.00139	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9161	 9169	 0.042416	 0.16502	 0.00276	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9161	 9184	 0.035256	 0.12044	 0.00262	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9162	 9185	 0.025357	 0.070144	 0.00163	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9163	 9164	 0.022656	 0.046364	 0.00114	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9164	 9166	 0.020065	 0.061554	 0.00167	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9165	 9170	 0.085455	 0.062873	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9166	 9167	 0.057952	 0.058533	 0.00078	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9166	 9170	 0.049658	 0.11529	 0.00171	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9167	 9169	 0.045923	 0.062654	 0.00112	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9168	 77906	 0.12343	 0.097687	 0.00123	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9169	 77906	 0.022312	 0.057826	 0.00109	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9170	 9172	 0.016093	 0.02345	 0.00053	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9171	 9172	 0.014647	 0.012056	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9172	 9173	 0.032472	 0.025698	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9172	 77905	 0.019142	 0.085296	 0.00145	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9174	 9175	 0.017229	 0.034113	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9174	 9178	 0.029283	 0.018957	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9175	 77905	 0.019112	 0.049131	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9176	 9177	 0.017789	 0.01594	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9177	 9178	 0.034707	 0.035055	 0.00046	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9177	 9182	 0.013127	 0.028131	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9177	 77905	 0.045659	 0.090403	 0.00133	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9178	 9179	 0.028142	 0.019934	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9180	 77905	 0.049339	 0.039046	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77616	 9181	 0.033081	 0.18838	 0.05467	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9181	 77905	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9181	 77905	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77663	 9182	 0.008159	 0.027218	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9182	 77906	 0.012073	 0.022448	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9183	 77906	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9183	 77906	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77639	 9184	 0.012543	 0.069073	 0.00156	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9185	 9186	 0.021717	 0.081469	 0.00146	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9186	 9188	 0.031747	 0.072013	 0.00144	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9186	 9190	 0.063431	 0.16307	 0.00252	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9187	 9188	 0.03018	 0.085644	 0.00135	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9187	 77907	 0.016329	 0.063526	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 9199	 0.004167	 0.014522	 0.00337	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77616	 9189	 0.01472	 0.069678	 0.01676	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 77907	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9189	 77907	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9190	 77912	 0.019265	 0.059162	 0.00111	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9191	 9192	 0.0045	 0.017106	 0.00479	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9191	 10424	 0.005934	 0.025114	 0.00565	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9191	 77908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9191	 77908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9192	 9200	 0.001754	 0.007423	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9192	 77909	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9192	 77909	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9193	 10412	 0.005938	 0.023772	 0.00599	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9193	 10414	 0.004487	 0.0289	 0.00758	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9194	 9204	 0.023426	 0.067189	 0.00103	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77656	 9194	 0.007792	 0.053483	 0.00097	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9195	 9196	 0.000665	 0.001812	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9195	 9197	 0.000789	 0.00279	 0.00063	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9195	 9200	 0.000835	 0.003447	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9196	 77910	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9196	 77910	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9197	 9198	 0.000786	 0.002697	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9197	 77911	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9197	 77911	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9199	 9200	 0.002412	 0.006766	 0.00174	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9199	 77912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9199	 77912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9200	 77913	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9200	 77913	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9201	 77914	 0.019182	 0.015036	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9202	 9203	 0.001637	 0.004394	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9202	 9206	 0.003701	 0.009781	 0.00229	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9203	 9206	 0.004811	 0.01249	 0.00303	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9203	 77914	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9203	 77914	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9204	 9205	 0.070502	 0.055795	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77634	 9204	 0.031696	 0.062757	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77914	 9205	 0.021472	 0.035809	 0.00052	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9207	 9210	 0.009427	 0.018053	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9207	 77915	 0.005883	 0.018944	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9208	 9214	 0.001304	 0.007022	 0.00193	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9208	 9216	 0.000701	 0.003339	 0.00097	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9208	 77915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9208	 77915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9208	 77917	 0.00414	 0.010942	 0.00256	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9210	 77916	 0.015197	 0.027834	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9211	 9215	 0.001977	 0.011954	 0.00305	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9211	 77916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 77916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9211	 77917	 0.008673	 0.024185	 0.00508	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77916	 9212	 0.013628	 0.017912	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77615	 9213	 0.002317	 0.034662	 0.08113	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9213	 77917	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77918	 9213	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9214	 9480	 0.002355	 0.011427	 0.00261	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77917	 9214	 0.001834	 0.008413	 0.00216	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9214	 77919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9214	 77919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9215	 77920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9215	 77920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9217	 9293	 0.006796	 0.01041	 0.00015	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9218	 9219	 0.000662	 0.001751	 0.00041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9218	 9292	 0.000632	 0.00172	 0.00038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9219	 9343	 0.000886	 0.002377	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9219	 77921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9219	 77921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9220	 9222	 0.001615	 0.007195	 0.00012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9220	 9355	 0.003034	 0.007799	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77921	 9220	 0.000703	 0.004826	 9e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9221	 9222	 0.004529	 0.003274	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9222	 9224	 0.001312	 0.008069	 0.00015	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9223	 9225	 0.000677	 0.001843	 0.00041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9223	 9300	 0.000724	 0.002438	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9223	 9307	 0.00065	 0.004253	 0.00108	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9223	 77922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9223	 77922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9224	 9289	 0.001583	 0.005026	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77922	 9224	 0.00092	 0.004417	 0.00013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9224	 77924	 0.00331	 0.014749	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9225	 9227	 0.00099	 0.003396	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9225	 77923	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9225	 77923	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9226	 9227	 0.00025	 0.001235	 0.00033	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9226	 77924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9226	 77924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9227	 9283	 0.001116	 0.003112	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9227	 9284	 0.000285	 0.001487	 0.00039	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9228	 77942	 0.007579	 0.005998	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9229	 9233	 0.00195	 0.004959	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9229	 77942	 0.003537	 0.008996	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9230	 9232	 0.01017	 0.007801	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77924	 9230	 0.003679	 0.008541	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77923	 9231	 0.008124	 0.005977	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9233	 77928	 0.002817	 0.007241	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9234	 9307	 0.000818	 0.003328	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9234	 9329	 0.000426	 0.001952	 0.0005	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9234	 77925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9234	 77925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9235	 9236	 0.000487	 0.001765	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9235	 9310	 0.000625	 0.00221	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9236	 9239	 0.000346	 0.00141	 0.00034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9237	 9238	 0.000143	 0.001223	 0.00035	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9237	 9388	 0.000188	 0.00171	 0.00056	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9237	 77926	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9237	 77926	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9238	 9321	 0.00032	 0.002742	 0.00078	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9239	 9319	 0.000301	 0.001906	 0.00052	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9239	 77927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9239	 77927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9240	 9241	 0.000823	 0.003646	 0.00011	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77927	 9240	 0.000955	 0.005374	 0.00012	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9241	 9314	 0.001699	 0.005667	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77925	 9241	 0.001987	 0.005981	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9242	 9329	 0.000426	 0.001324	 0.00028	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9242	 9423	 0.000584	 0.001569	 0.00036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9242	 77928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9242	 77928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9243	 77986	 0.006279	 0.004922	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9244	 9247	 0.000632	 0.001626	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9244	 9265	 0.000565	 0.001493	 0.00035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9244	 77929	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9244	 77929	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9245	 77930	 0.008775	 0.006944	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9246	 9249	 0.000482	 0.001273	 0.0003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9246	 9328	 0.000889	 0.002386	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9246	 77930	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9246	 77930	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9247	 9423	 0.000692	 0.001928	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77929	 9248	 0.008119	 0.006425	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9249	 9424	 0.001238	 0.003213	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9249	 77931	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9249	 77931	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77931	 9250	 0.009292	 0.007354	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9251	 9252	 0.00182	 0.005041	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9251	 9261	 0.000863	 0.004213	 7e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9251	 77953	 0.002597	 0.005141	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9252	 9253	 0.002005	 0.006687	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9253	 10559	 0.002062	 0.009083	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9254	 77932	 0.008269	 0.005978	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9255	 9257	 0.000942	 0.002701	 0.00066	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9255	 9258	 0.000268	 0.00166	 0.0004	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9255	 10560	 0.000669	 0.003686	 0.00133	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9255	 77932	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9255	 77932	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9256	 9258	 0.00021	 0.001092	 0.00032	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9256	 9259	 0.000279	 0.001476	 0.00037	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9256	 77933	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9256	 77933	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9257	 10550	 0.001021	 0.004086	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9257	 10562	 0.000778	 0.004672	 0.00141	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9257	 77937	 0.001277	 0.008087	 0.00219	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9259	 9424	 0.000352	 0.001231	 0.00041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9259	 77934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9259	 77934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77933	 9260	 0.008403	 0.00665	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9261	 9262	 0.000683	 0.003295	 6e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9262	 9263	 0.00129	 0.005016	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77931	 9263	 0.001995	 0.005722	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77934	 9263	 0.00816	 0.007516	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9264	 9424	 0.00041	 0.001882	 0.00048	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9264	 77935	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9264	 77935	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9264	 77937	 0.000584	 0.002338	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9265	 9268	 0.000451	 0.001862	 0.00044	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9265	 9420	 0.000242	 0.001145	 0.00028	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9265	 77936	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9265	 77936	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9266	 9284	 0.000279	 0.00132	 0.00032	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9266	 9420	 0.000257	 0.001117	 0.00032	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9267	 9419	 0.000986	 0.003778	 0.00011	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77936	 9267	 0.000663	 0.002848	 5e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9268	 77937	 0.00048	 0.002201	 0.00056	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9269	 10652	 0.004756	 0.049352	 0.10642	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9269	 10652	 0.004756	 0.049352	 0.10642	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9269	 77937	 9.4e-05	 0.007517	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77938	 9269	 0.000247	 0.018554	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9269	 77987	 0.000226	 0.002408	 0.0049	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9269	 77987	 0.000226	 0.002408	 0.0049	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9270	 9280	 0.001474	 0.004229	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77938	 9270	 0.001946	 0.007568	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77938	 9270	 0.001946	 0.007568	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9270	 77939	 0.001469	 0.005138	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9270	 77939	 0.001469	 0.005138	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9271	 9272	 0.000106	 0.001048	 0.00032	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9271	 77939	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9271	 77939	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9272	 9273	 0.000287	 0.001187	 0.00028	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9272	 9274	 0.000367	 0.002105	 0.0007	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9272	 10641	 0.003177	 0.014818	 0.00367	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9273	 9274	 0.000316	 0.001266	 0.00032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9274	 9275	 0.000425	 0.004078	 0.00119	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9274	 9276	 0.000268	 0.003876	 0.00123	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9274	 9283	 0.000588	 0.005742	 0.00161	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9274	 77940	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9274	 77940	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9275	 77988	 0.000309	 0.005161	 0.00293	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9276	 9583	 0.00081	 0.006949	 0.00198	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9276	 9588	 0.000534	 0.003382	 0.00092	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77657	 9276	 0.000164	 0.002507	 0.00081	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9276	 78040	 0.000229	 0.003633	 0.0023	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77657	 9277	 0.000177	 0.002604	 0.0008	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77940	 9278	 0.007786	 0.005728	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9279	 9281	 0.00084	 0.003504	 0.0001	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77939	 9279	 0.001046	 0.00502	 0.00015	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77939	 9280	 0.002944	 0.007569	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9281	 9282	 0.00086	 0.005595	 0.00011	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9281	 9587	 0.002504	 0.00974	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9281	 9587	 0.002504	 0.00974	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77939	 9281	 0.002726	 0.010605	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9282	 77941	 0.000742	 0.005784	 0.00011	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9283	 9310	 0.001785	 0.011962	 0.00366	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77937	 9283	 0.000418	 0.004018	 0.00117	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9283	 77941	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9283	 77941	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9284	 9322	 0.0011	 0.006837	 0.00193	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9284	 77942	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9284	 77942	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9285	 9286	 0.000606	 0.003413	 7e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9285	 77943	 0.000883	 0.005022	 9e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9286	 9287	 0.000464	 0.003186	 6e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9287	 9288	 0.001092	 0.004866	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9287	 9289	 0.001507	 0.005797	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9287	 77985	 0.00692	 0.011922	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77924	 9288	 0.001355	 0.006371	 0.00012	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9290	 9291	 0.0007	 0.001849	 0.00043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9290	 9583	 0.001058	 0.00272	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9290	 77943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9290	 77943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9291	 9292	 0.000604	 0.001685	 0.00035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77921	 9293	 0.00297	 0.0098	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9293	 77944	 0.002191	 0.008523	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9294	 9295	 0.000556	 0.001551	 0.00033	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9294	 9583	 0.001068	 0.005434	 0.00197	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9294	 77944	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9294	 77944	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9295	 9341	 0.001065	 0.002814	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9296	 9297	 0.001657	 0.00339	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9296	 9378	 0.001998	 0.005135	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9297	 9298	 0.002645	 0.006049	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9298	 9301	 0.002773	 0.006342	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9299	 9355	 0.001065	 0.005356	 0.00015	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9299	 77945	 0.000803	 0.005717	 0.00013	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9300	 77945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9300	 77945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9301	 9302	 0.003104	 0.006082	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9302	 9303	 0.001646	 0.007943	 0.00014	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9302	 9309	 0.002799	 0.007194	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9303	 9304	 0.001369	 0.005348	 0.00012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9303	 77946	 0.001891	 0.006622	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77945	 9304	 0.001028	 0.005346	 0.00012	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77922	 9305	 0.00663	 0.005247	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9306	 77946	 0.008757	 0.00633	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9307	 77946	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9307	 77946	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9308	 9309	 0.00138	 0.006147	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77946	 9308	 0.00176	 0.005049	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9309	 9381	 0.001168	 0.004772	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9310	 9383	 0.00068	 0.002461	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9310	 9388	 0.000669	 0.006088	 0.00154	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9310	 77947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9310	 77947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9311	 9312	 0.001383	 0.004724	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77947	 9311	 0.001067	 0.003811	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9312	 9313	 0.001383	 0.004247	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9313	 9314	 0.002532	 0.005182	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77946	 9313	 0.00182	 0.00811	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9315	 9325	 0.007039	 0.005517	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9316	 9317	 0.000438	 0.001905	 0.00054	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9316	 10563	 0.000499	 0.002768	 0.00084	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9316	 77948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9316	 77948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9317	 9318	 0.000252	 0.001388	 0.00032	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9317	 77949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9317	 77949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9318	 9319	 0.000277	 0.001958	 0.00054	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9318	 77950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9318	 77950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9320	 9324	 0.000646	 0.001813	 0.00047	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9320	 77951	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9320	 77951	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9321	 9322	 0.000133	 0.001142	 0.00033	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9322	 9327	 0.000904	 0.003618	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9322	 9328	 0.000237	 0.001191	 0.00031	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9323	 77952	 0.005121	 0.00613	 0.0001	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9324	 9327	 0.000576	 0.002793	 0.00064	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9324	 10560	 0.000721	 0.003954	 0.00105	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9324	 77952	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9324	 77952	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9325	 77953	 0.003303	 0.005565	 8e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9326	 77954	 0.005493	 0.00369	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9327	 77953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9327	 77953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9328	 9329	 0.000476	 0.001852	 0.00049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9328	 77954	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9328	 77954	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9330	 9331	 0.000787	 0.003151	 0.00079	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9330	 9334	 0.00032	 0.002232	 0.00084	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9330	 9357	 0.000933	 0.010506	 0.00304	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9330	 10310	 0.000325	 0.004699	 0.00149	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9330	 77955	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9330	 77955	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9331	 9332	 0.000557	 0.002507	 0.00067	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9332	 9340	 0.002313	 0.005573	 0.00157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9332	 77956	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9332	 77956	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9333	 77959	 0.012126	 0.015937	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9334	 9335	 0.000294	 0.002568	 0.00071	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9335	 9337	 0.000795	 0.003928	 0.00115	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9335	 9360	 0.000752	 0.008931	 0.00311	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9335	 77957	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9335	 77957	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9336	 9349	 0.001831	 0.007044	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9336	 77958	 0.003487	 0.006834	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9336	 77959	 0.007683	 0.01975	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9337	 9339	 0.0005	 0.003106	 0.00088	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9337	 9342	 0.001089	 0.002878	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9337	 77958	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9337	 77958	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9338	 77959	 0.009257	 0.007326	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9339	 9340	 0.000463	 0.002017	 0.00057	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9339	 77959	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9339	 77959	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9340	 77960	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9340	 77960	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9340	 78040	 0.001414	 0.012243	 0.00439	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9341	 9342	 0.000584	 0.001591	 0.00035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9342	 77961	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9342	 77961	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9343	 77962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9343	 77962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9344	 9345	 0.002449	 0.009053	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9344	 9345	 0.002449	 0.009053	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9344	 9359	 0.003298	 0.012194	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9344	 9359	 0.003298	 0.012194	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9344	 77963	 0.005055	 0.022524	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9345	 10307	 0.003901	 0.015175	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9345	 10307	 0.003901	 0.015175	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77955	 9345	 0.002075	 0.011142	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9346	 9347	 0.000958	 0.005823	 0.00011	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9346	 9361	 0.00185	 0.012697	 0.00023	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77957	 9347	 0.001647	 0.009363	 0.00017	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9348	 9349	 0.001739	 0.006766	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9348	 9350	 0.00212	 0.009445	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9350	 9351	 0.003418	 0.011403	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9350	 9356	 0.00222	 0.00681	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9350	 9356	 0.00222	 0.00681	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77962	 9350	 0.004696	 0.020925	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9351	 9354	 0.002903	 0.008326	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9352	 9353	 0.011278	 0.008925	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9353	 9354	 0.002765	 0.007107	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9353	 9355	 0.001446	 0.008139	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77962	 9354	 0.002423	 0.006423	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9355	 77985	 0.032576	 0.038996	 0.00065	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9356	 9363	 0.00148	 0.008413	 0.00015	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9356	 9367	 0.001163	 0.006271	 0.00013	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9357	 9411	 0.000185	 0.002512	 0.00145	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9357	 77963	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9357	 77963	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77963	 9358	 0.01588	 0.012567	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9359	 77964	 0.003488	 0.010701	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9359	 77964	 0.003488	 0.010701	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9360	 9408	 0.000237	 0.00256	 0.00137	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9360	 77964	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9360	 77964	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9361	 9364	 0.002452	 0.013939	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77964	 9361	 0.002963	 0.011856	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9362	 9364	 0.009462	 0.007488	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9363	 9364	 0.00118	 0.007037	 0.0002	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9364	 9365	 0.016119	 0.012756	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9364	 9409	 0.003762	 0.021386	 0.00039	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9364	 77965	 0.001985	 0.010574	 0.00019	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9364	 77984	 0.019633	 0.076379	 0.00128	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9364	 77984	 0.019633	 0.076379	 0.00128	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9366	 9368	 0.000982	 0.002941	 0.00066	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9366	 77965	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9366	 77965	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77965	 9367	 0.000985	 0.005988	 0.00011	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9368	 77966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9368	 77966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9369	 9371	 0.00351	 0.01229	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9369	 77982	 0.005277	 0.027796	 0.0005	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9370	 9377	 0.004261	 0.013072	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9370	 9377	 0.004261	 0.013072	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9370	 77975	 0.005653	 0.020193	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9370	 77975	 0.005653	 0.020193	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9371	 9372	 0.004295	 0.013772	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9371	 9372	 0.004295	 0.013772	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9371	 9401	 0.006503	 0.035588	 0.0007	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9372	 77967	 0.003579	 0.013925	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9372	 77967	 0.003579	 0.013925	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9373	 9374	 0.000814	 0.002114	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9373	 77967	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9373	 77967	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9374	 9382	 0.001791	 0.004501	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9374	 77968	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9374	 77968	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9375	 77969	 0.009158	 0.00925	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9376	 9385	 0.009811	 0.007764	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9377	 9385	 0.002621	 0.020428	 0.00038	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9377	 9386	 0.007562	 0.019438	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9378	 9379	 0.010338	 0.008103	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77966	 9378	 0.005255	 0.013508	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77968	 9378	 0.002256	 0.005846	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9379	 9380	 0.002512	 0.004922	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9380	 77969	 0.001671	 0.006179	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9381	 77970	 0.002059	 0.007888	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9382	 9383	 0.000569	 0.002059	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9382	 77969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9382	 77969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9383	 77970	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9383	 77970	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9384	 9387	 0.002973	 0.009129	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77947	 9384	 0.00373	 0.010584	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9385	 9387	 0.006727	 0.014889	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77970	 9385	 0.001627	 0.010002	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9386	 9389	 0.002776	 0.012369	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9386	 9390	 0.003227	 0.012553	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9387	 77971	 0.001887	 0.008566	 0.00019	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9388	 9397	 0.000767	 0.008439	 0.00501	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9388	 77971	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9388	 77971	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77971	 9389	 0.002322	 0.007444	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9390	 9395	 0.003702	 0.016496	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9391	 9392	 0.004132	 0.008456	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9391	 9393	 0.00562	 0.014446	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77926	 9392	 0.00593	 0.01174	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9393	 78360	 0.003719	 0.016572	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9394	 78361	 0.013903	 0.011003	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9395	 78361	 0.003176	 0.012708	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9396	 9397	 0.000388	 0.006133	 0.00184	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9396	 10617	 0.000273	 0.004395	 0.00144	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9396	 77972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9396	 77972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9397	 9402	 0.001008	 0.007128	 0.00196	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9397	 77973	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9397	 77973	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77973	 9398	 0.004306	 0.026476	 0.00048	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9398	 78361	 0.0026	 0.012428	 0.00027	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9399	 10614	 0.002472	 0.008655	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77972	 9399	 0.006476	 0.028533	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9399	 78362	 0.009979	 0.038821	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9400	 9404	 0.002114	 0.008949	 0.00201	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9400	 10109	 0.002103	 0.007992	 0.00224	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9400	 77974	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9400	 77974	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9401	 77976	 0.003208	 0.019424	 0.00061	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9402	 9404	 0.00079	 0.007587	 0.00221	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9402	 9406	 0.003447	 0.013408	 0.00358	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9402	 77975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9402	 77975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77974	 9403	 0.005931	 0.018194	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77975	 9403	 0.005551	 0.018318	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9404	 10116	 0.000526	 0.008034	 0.00259	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9405	 77982	 0.016601	 0.013137	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9406	 77976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9406	 77976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9406	 77983	 0.002401	 0.009438	 0.00247	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9407	 9408	 0.000229	 0.002393	 0.00158	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9407	 9414	 0.000302	 0.003714	 0.00177	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9408	 77977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9408	 77977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77977	 9409	 0.001718	 0.010563	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9410	 9411	 0.000239	 0.00352	 0.00172	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9410	 9413	 0.000282	 0.003105	 0.00184	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9410	 10324	 0.000392	 0.005712	 0.00183	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9410	 77983	 0.00066	 0.008565	 0.00541	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9412	 9426	 0.000195	 0.003056	 0.29697	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9412	 77978	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9412	 77978	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9413	 77983	 0.000527	 0.006109	 0.00326	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9414	 9415	 0.000104	 0.001261	 0.00071	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9414	 77981	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9414	 77981	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9415	 77982	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9415	 77982	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9415	 77983	 0.00026	 0.003909	 0.00229	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9416	 77984	 0.029999	 0.023741	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77767	 9417	 0.002112	 0.021828	 0.34361	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77767	 9417	 0.002112	 0.021828	 0.34361	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77978	 9417	 9.7e-05	 0.000965	 0.01651	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77978	 9417	 9.7e-05	 0.000965	 0.01651	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9417	 77983	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9417	 77983	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77981	 9418	 0.012202	 0.009657	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77935	 9419	 0.000875	 0.005379	 0.0001	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9421	 9586	 0.000173	 0.001912	 0.00057	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77937	 9421	 0.000724	 0.006814	 0.00206	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9421	 77985	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9421	 77985	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77942	 9422	 0.009061	 0.006865	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9423	 77986	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9423	 77986	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77938	 9425	 0.001614	 0.006279	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77938	 9425	 0.001614	 0.006279	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77939	 9425	 0.002361	 0.010522	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9425	 78391	 0.017645	 0.046644	 0.00085	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9426	 77987	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77988	 9426	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9427	 9446	 0.001632	 0.006529	 0.00221	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9427	 77989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9427	 77989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9428	 9429	 0.000675	 0.00453	 0.00109	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9428	 9433	 0.000617	 0.004959	 0.00139	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9429	 9444	 0.000723	 0.004112	 0.00119	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9430	 9451	 0.00549	 0.016861	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9430	 77991	 0.003779	 0.021482	 0.00039	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9431	 9447	 0.000567	 0.007327	 0.0166	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9431	 77990	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77991	 9431	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9432	 9433	 0.000865	 0.006282	 0.00217	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9432	 9434	 0.000803	 0.007963	 0.00217	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9433	 79357	 0.004645	 0.014445	 0.00301	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77660	 9434	 0.000799	 0.004017	 0.00105	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9434	 77992	 0.00083	 0.00949	 0.00266	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9435	 9489	 0.000394	 0.00495	 0.01732	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77726	 9435	 0.000347	 0.003305	 0.01208	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9435	 77992	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9435	 77992	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9436	 9437	 0.001974	 0.01176	 0.00309	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77992	 9436	 0.002092	 0.013681	 0.00348	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9437	 9438	 0.002351	 0.009412	 0.00237	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9437	 77993	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9437	 77993	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9438	 9450	 0.002073	 0.008298	 0.00209	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9439	 9464	 0.00139	 0.010158	 0.003	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9439	 9484	 0.001807	 0.014517	 0.00408	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9440	 9451	 0.006383	 0.013062	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9440	 77998	 0.007728	 0.019865	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9441	 9443	 0.028256	 0.020789	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9442	 77995	 0.015592	 0.012339	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9443	 9449	 0.006115	 0.016164	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9443	 77994	 0.001713	 0.011758	 0.00021	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9444	 9445	 0.001261	 0.006569	 0.00172	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77990	 9444	 0.001272	 0.007576	 0.00199	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9444	 77994	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9444	 77994	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9445	 9446	 0.000992	 0.004893	 0.00132	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9445	 77995	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9445	 77995	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9447	 77996	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77997	 9447	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9448	 9449	 0.006719	 0.017271	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77997	 9448	 0.008388	 0.019863	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77996	 9450	 0.002031	 0.008132	 0.00205	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9450	 77998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9450	 77998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9452	 9453	 0.003295	 0.015817	 0.00047	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9452	 9455	 0.00668	 0.03341	 0.00059	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9452	 9456	 0.032742	 0.059077	 0.00085	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77997	 9452	 0.010952	 0.048801	 0.00083	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9453	 77999	 0.002262	 0.01355	 0.00033	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9454	 9457	 0.001206	 0.00375	 0.00078	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9454	 9461	 0.001436	 0.005645	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9454	 77999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9454	 77999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9456	 78000	 0.004313	 0.020283	 0.00038	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9457	 78000	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9457	 78000	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9458	 9459	 0.001921	 0.008813	 0.00226	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9458	 9460	 0.001921	 0.006471	 0.00161	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9458	 9463	 0.000895	 0.004818	 0.00132	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77996	 9459	 0.002528	 0.009833	 0.00263	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9460	 9461	 0.000973	 0.003339	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9461	 9462	 0.001569	 0.004698	 0.00106	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9462	 9477	 0.002608	 0.008946	 0.00214	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9463	 9464	 0.000372	 0.00279	 0.00068	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9463	 78001	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9463	 78001	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9464	 78002	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9464	 78002	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9465	 9485	 0.0175	 0.032538	 0.00076	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78002	 9465	 0.005539	 0.012859	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9466	 9470	 0.006951	 0.028407	 0.00057	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9466	 78003	 0.005245	 0.028169	 0.00067	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9467	 9468	 0.030165	 0.023872	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9468	 9470	 0.003874	 0.008993	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77997	 9468	 0.043789	 0.1037	 0.0019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78001	 9468	 0.004188	 0.02353	 0.00044	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9469	 9470	 0.014965	 0.009688	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9471	 9477	 0.002655	 0.010804	 0.00263	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9471	 9483	 0.004138	 0.016837	 0.0041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9471	 78003	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9471	 78003	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9472	 9473	 0.000658	 0.005458	 0.00144	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9473	 9475	 0.001096	 0.007753	 0.00213	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9473	 78004	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9473	 78004	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9474	 9475	 0.003748	 0.013573	 0.00291	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9475	 9477	 0.004461	 0.016231	 0.00497	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9475	 9480	 0.002555	 0.021214	 0.0083	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9476	 78005	 0.0187	 0.037024	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9477	 78005	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9477	 78005	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9478	 9481	 0.01396	 0.042017	 0.00082	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9478	 78006	 0.014258	 0.063533	 0.00108	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9479	 78006	 0.074961	 0.058759	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9480	 9482	 0.000539	 0.003612	 0.00111	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9480	 78006	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9480	 78006	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78003	 9481	 0.020783	 0.038644	 0.0009	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77917	 9482	 0.001634	 0.011558	 0.00317	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9483	 10410	 0.004221	 0.019688	 0.00488	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9484	 9486	 0.001924	 0.012186	 0.00331	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9484	 9487	 0.005709	 0.023573	 0.00558	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77993	 9485	 0.04786	 0.05941	 0.00129	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9486	 10408	 0.002193	 0.013891	 0.00377	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9487	 10402	 0.002113	 0.013383	 0.00363	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9487	 78007	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9487	 78007	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9487	 78008	 0.004742	 0.0142	 0.0032	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78007	 9488	 0.046065	 0.036456	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77701	 9489	 0.000313	 0.0042	 0.01483	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9489	 78008	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9489	 78008	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9490	 9600	 0.008234	 0.006516	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9490	 78009	 0.003692	 0.006133	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9491	 9494	 0.00022	 0.001249	 0.00036	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9491	 9630	 0.000244	 0.001511	 0.00037	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9492	 9496	 6e-05	 0.000952	 0.0006	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9492	 9630	 8.3e-05	 0.001308	 0.00083	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9493	 9495	 0.000212	 0.001472	 0.00042	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9493	 78030	 0.000249	 0.00191	 0.00051	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9494	 9495	 0.000152	 0.000932	 0.00034	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9494	 78009	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9494	 78009	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9496	 9638	 0.000655	 0.004066	 0.00098	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77620	 9496	 0.000216	 0.003522	 0.0021	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9496	 78010	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9496	 78010	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78010	 9497	 0.00491	 0.003886	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77620	 9498	 0.0012	 0.003016	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9498	 78011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9498	 78011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78011	 9499	 0.008654	 0.006848	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9500	 9501	 0.001671	 0.004792	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78011	 9500	 0.002085	 0.006955	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9501	 9502	 0.0024	 0.005044	 9e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9502	 9504	 0.000462	 0.003599	 7e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9502	 78031	 0.000501	 0.003487	 8e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9503	 9504	 0.000758	 0.004958	 0.00011	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9503	 9647	 0.001546	 0.006013	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9503	 9647	 0.001546	 0.006013	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78011	 9503	 0.001574	 0.012268	 0.00023	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9505	 9563	 0.000226	 0.003777	 0.03489	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9505	 78012	 0.000109	 0.008705	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9506	 9508	 0.000348	 0.001393	 0.00035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78012	 9506	 0.000274	 0.001452	 0.00048	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9506	 78014	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9506	 78014	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9507	 78015	 0.004536	 0.004582	 6e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9508	 9514	 0.000277	 0.001125	 0.00027	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9508	 9548	 0.000382	 0.00159	 0.0005	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9508	 78015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9508	 78015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9509	 9510	 0.000469	 0.002251	 7e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9509	 78031	 0.001006	 0.006651	 0.00013	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9510	 9511	 0.000992	 0.003182	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9510	 9547	 0.005828	 0.004612	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9511	 9549	 0.005046	 0.003823	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9511	 9555	 0.001824	 0.005602	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77619	 9512	 0.000159	 0.001693	 0.00344	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77619	 9512	 0.000159	 0.001693	 0.00344	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9512	 78016	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78017	 9512	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9513	 9519	 0.000225	 0.001425	 0.00039	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77646	 9513	 0.000357	 0.005195	 0.00166	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9513	 78018	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9513	 78018	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9514	 9515	 0.000441	 0.00132	 0.0003	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9514	 78019	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9514	 78019	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9515	 9516	 0.00027	 0.000838	 0.00017	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9516	 9542	 0.00064	 0.002562	 0.00065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9516	 78020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9516	 78020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9517	 9541	 0.000691	 0.003027	 7e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9517	 78029	 0.000489	 0.00297	 5e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78017	 9518	 0.002272	 0.008839	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78017	 9518	 0.002272	 0.008839	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9518	 78022	 0.00258	 0.010037	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9518	 78022	 0.00258	 0.010037	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9519	 9521	 0.000296	 0.00138	 0.00034	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9519	 78021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9519	 78021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9520	 9522	 0.001971	 0.003902	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78018	 9520	 0.00242	 0.008071	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9521	 9528	 0.00041	 0.001693	 0.0004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9522	 9523	 0.002382	 0.00553	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9523	 9545	 0.002126	 0.004885	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9524	 9525	 0.003072	 0.004707	 7e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9524	 9545	 0.002635	 0.005538	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9525	 9526	 0.006719	 0.005317	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9525	 9655	 0.008185	 0.016042	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78021	 9525	 0.004566	 0.015069	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9527	 9531	 0.000986	 0.002908	 0.00068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9527	 78022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9527	 78022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9528	 9529	 0.00034	 0.001384	 0.00034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9528	 78023	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9528	 78023	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9529	 9532	 0.000336	 0.001345	 0.00034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9530	 9545	 0.002442	 0.007182	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9530	 78025	 0.001878	 0.007305	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9531	 78024	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9531	 78024	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9532	 9534	 0.000307	 0.00123	 0.00031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9533	 78026	 0.006971	 0.004513	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9534	 9535	 0.000989	 0.004185	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9534	 78025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9534	 78025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9535	 9542	 0.002694	 0.010241	 0.00287	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9535	 78036	 0.001504	 0.009685	 0.00254	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9536	 9537	 0.000696	 0.001839	 0.00043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9536	 9559	 0.002761	 0.009622	 0.00223	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78016	 9536	 0.002175	 0.00855	 0.00224	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9536	 78026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9536	 78026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9537	 9539	 0.000548	 0.001491	 0.00033	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9537	 78027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9537	 78027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9538	 9539	 0.000587	 0.001577	 0.00036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9538	 9556	 0.000579	 0.002048	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9538	 78028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9538	 78028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78028	 9540	 0.005843	 0.005645	 8e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9541	 9552	 0.001275	 0.005476	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9542	 78029	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9542	 78029	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9543	 78031	 0.006425	 0.005085	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78020	 9544	 0.008645	 0.006776	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78023	 9545	 0.00314	 0.006217	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9546	 9599	 0.000237	 0.002397	 0.00544	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9546	 9599	 0.000237	 0.002397	 0.00544	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77619	 9546	 6e-05	 0.000623	 0.00134	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77619	 9546	 6e-05	 0.000623	 0.00134	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9546	 78030	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9546	 78030	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9548	 78031	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9548	 78031	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78029	 9550	 0.000819	 0.007928	 0.00016	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9551	 9552	 0.001689	 0.004279	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9551	 9553	 0.003339	 0.008172	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9553	 78032	 0.004017	 0.010327	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9554	 9648	 0.000636	 0.002215	 0.00051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77620	 9554	 0.001782	 0.009439	 0.00239	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9554	 78032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9554	 78032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78032	 9555	 0.003222	 0.006878	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9556	 9559	 0.001441	 0.005092	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9556	 78033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9556	 78033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9557	 9558	 0.003739	 0.009508	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9557	 9560	 0.000812	 0.006144	 0.0002	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78033	 9557	 0.000698	 0.00424	 8e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9558	 78034	 0.004227	 0.008283	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9559	 78034	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9559	 78034	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9559	 78036	 0.00057	 0.003141	 0.00113	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9560	 78035	 0.002571	 0.009892	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9560	 78035	 0.002571	 0.009892	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9561	 9566	 7.7e-05	 0.001257	 0.00075	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9561	 78035	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9561	 78035	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9561	 78036	 0.000188	 0.003062	 0.00183	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78035	 9562	 0.002641	 0.004216	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77626	 9563	 0.0003	 0.003177	 0.04752	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77626	 9563	 0.0003	 0.003177	 0.04752	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9563	 78036	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9563	 78036	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9564	 78038	 0.004099	 0.002963	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9565	 9566	 2.6e-05	 0.000416	 0.00025	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9565	 9567	 7e-05	 0.001087	 0.00071	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9565	 78038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9565	 78038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9567	 10641	 0.000409	 0.00573	 0.00465	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9567	 78039	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9567	 78039	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78039	 9568	 0.004206	 0.002723	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9569	 9570	 0.000648	 0.004446	 8e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78039	 9569	 0.001005	 0.008357	 0.00016	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9570	 9571	 0.002341	 0.002597	 5e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78037	 9570	 0.006762	 0.026307	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78037	 9570	 0.006762	 0.026307	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9572	 9573	 0.001544	 0.007533	 0.00013	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9572	 9575	 0.001838	 0.007044	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77960	 9573	 0.003316	 0.013553	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77944	 9574	 0.006014	 0.007653	 0.00011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9574	 78042	 0.00471	 0.007866	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77944	 9575	 0.002109	 0.010466	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9576	 78040	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9576	 78040	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9577	 9578	 0.000651	 0.00172	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9577	 9588	 0.001623	 0.004213	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9578	 9579	 0.000241	 0.000636	 0.00015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9579	 9580	 0.000791	 0.002091	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9579	 78041	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9579	 78041	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9580	 78042	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9580	 78042	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9581	 9582	 0.000868	 0.003549	 7e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78041	 9581	 0.000507	 0.002882	 5e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77943	 9582	 0.002601	 0.007461	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9583	 9586	 0.000117	 0.001007	 0.00029	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9584	 9585	 0.001031	 0.004974	 9e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78042	 9584	 0.007822	 0.017971	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9584	 78044	 0.001635	 0.010053	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9585	 78043	 0.001059	 0.004721	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9586	 78043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9586	 78043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9587	 78044	 0.000903	 0.006498	 0.00021	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9588	 78044	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9588	 78044	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9589	 9591	 0.000451	 0.001753	 0.00047	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9589	 78045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9589	 78045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9590	 78046	 0.009414	 0.007748	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9591	 9592	 0.000353	 0.001938	 0.00051	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9591	 78046	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9591	 78046	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9592	 9606	 0.000323	 0.001712	 0.00043	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9593	 9594	 0.000441	 0.001678	 0.00047	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9593	 9603	 0.000386	 0.001634	 0.00037	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9594	 78047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9594	 78047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9595	 9596	 0.000471	 0.001642	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9595	 9597	 0.000595	 0.002103	 0.00047	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9596	 9607	 0.000366	 0.001279	 0.00042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9597	 78048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9597	 78048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9598	 9613	 0.000171	 0.002475	 0.00079	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9598	 9615	 0.000236	 0.001806	 0.00048	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9598	 78049	 0.000228	 0.002474	 0.00152	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77094	 9599	 0.000819	 0.008312	 0.02669	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9599	 78049	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9599	 78049	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9601	 78051	 0.011012	 0.008715	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9602	 78051	 0.002255	 0.002909	 6e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9603	 9654	 0.000211	 0.000948	 0.00025	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9604	 78050	 0.00889	 0.007035	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9605	 9606	 0.000147	 0.000656	 0.00018	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9605	 9614	 0.000645	 0.00294	 0.00093	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9605	 78050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9605	 78050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9606	 78051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9606	 78051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9607	 9613	 0.000124	 0.000876	 0.0005	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9607	 9654	 0.000131	 0.000946	 0.00051	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9608	 9609	 0.002119	 0.002308	 3e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78050	 9608	 0.001102	 0.003548	 6e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9608	 78052	 0.001669	 0.006494	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9610	 78052	 0.009321	 0.007306	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9611	 9614	 0.000103	 0.001104	 0.00029	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9611	 78052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9611	 78052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78052	 9612	 0.000793	 0.002709	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9612	 78053	 0.000939	 0.004184	 7e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9613	 78053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9613	 78053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9614	 9615	 0.000154	 0.001164	 0.00032	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9614	 9616	 6.7e-05	 0.000515	 0.00038	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9614	 78054	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9614	 78054	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9615	 78055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9615	 78055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9616	 9617	 7.5e-05	 0.000665	 0.00037	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9616	 78056	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9616	 78056	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9617	 9618	 7.3e-05	 0.000764	 0.00043	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9618	 9621	 7e-05	 0.000708	 0.00043	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9618	 78057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9618	 78057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9619	 9620	 0.000566	 0.003887	 7e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78057	 9619	 0.000876	 0.004931	 0.00011	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9620	 78058	 0.001958	 0.003877	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9620	 78060	 0.000698	 0.003911	 0.00011	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9621	 9622	 6.1e-05	 0.000657	 0.0004	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9621	 78058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9621	 78058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9622	 9625	 5.1e-05	 0.000614	 0.00035	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9622	 78059	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9622	 78059	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9623	 9624	 0.000402	 0.001402	 0.00033	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9623	 78060	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9623	 78060	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9624	 9627	 7.9e-05	 0.000897	 0.00043	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78049	 9624	 0.000143	 0.002251	 0.00077	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9624	 78061	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9624	 78061	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9625	 9627	 4.6e-05	 0.000536	 0.00032	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9626	 78062	 0.005183	 0.004102	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9627	 9628	 5.6e-05	 0.000637	 0.0003	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9627	 9630	 0.000114	 0.001258	 0.00075	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9627	 78062	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9627	 78062	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9628	 9630	 7.8e-05	 0.000797	 0.00047	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9628	 78063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9628	 78063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9629	 78064	 0.004646	 0.003677	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9630	 78064	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9630	 78064	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9631	 9639	 0.001688	 0.007521	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78063	 9631	 0.00111	 0.00432	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9632	 9634	 0.007573	 0.005738	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78057	 9632	 0.001663	 0.005103	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78057	 9632	 0.001663	 0.005103	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9632	 78065	 0.001933	 0.016417	 0.00038	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78054	 9633	 0.004737	 0.003485	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9635	 78065	 0.012009	 0.013081	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9636	 9649	 0.001994	 0.002431	 4e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9637	 78065	 0.006186	 0.006738	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9638	 78065	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9638	 78065	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9639	 9645	 0.001221	 0.006862	 0.00013	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9640	 9641	 0.002205	 0.004366	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9640	 9642	 0.005041	 0.003989	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9641	 9643	 0.001307	 0.004011	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9643	 9649	 0.000702	 0.003551	 6e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78010	 9643	 0.002964	 0.012114	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9644	 9645	 0.002669	 0.00285	 6e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9645	 9646	 0.000829	 0.002542	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9645	 9646	 0.000829	 0.002542	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78010	 9645	 0.001329	 0.00747	 0.00014	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9646	 9647	 0.00081	 0.003152	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9646	 9647	 0.00081	 0.003152	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9648	 78066	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9648	 78066	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78066	 9649	 0.000365	 0.0026	 6e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9650	 9652	 0.00113	 0.003994	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9650	 78067	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9650	 78067	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9651	 9652	 0.000483	 0.002346	 0.00054	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77620	 9651	 0.001767	 0.009035	 0.00246	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77621	 9653	 0.015462	 0.021549	 0.00037	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9654	 78068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9654	 78068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9656	 9667	 0.001201	 0.017342	 0.00551	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9656	 10464	 0.001318	 0.019368	 0.00592	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77664	 9657	 0.011093	 0.046054	 0.0012	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9657	 78402	 0.00852	 0.055461	 0.00113	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9658	 10661	 0.001345	 0.014811	 0.00758	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9658	 78403	 0.003014	 0.01654	 0.00437	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9659	 78069	 0.010292	 0.052061	 0.00091	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9659	 78404	 0.01003	 0.057018	 0.00103	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9660	 9661	 0.00117	 0.016075	 0.0058	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9660	 10664	 0.001923	 0.014056	 0.00415	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77650	 9660	 0.0009	 0.012038	 0.00329	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9661	 9663	 0.001369	 0.020451	 0.00605	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9662	 9664	 0.000913	 0.010843	 0.00378	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77650	 9662	 0.00326	 0.043605	 0.01192	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9662	 78069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9662	 78069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9663	 9672	 0.000931	 0.013679	 0.00418	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9664	 9665	 0.001204	 0.016102	 0.0044	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9665	 9669	 0.001564	 0.016578	 0.00492	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9665	 78070	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9665	 78070	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77664	 9666	 0.039122	 0.030961	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9667	 78071	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9667	 78071	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9668	 9670	 0.052029	 0.064585	 0.00141	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77664	 9668	 0.028192	 0.086577	 0.00162	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9669	 10477	 0.001088	 0.013223	 0.00356	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9669	 78072	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9669	 78072	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9670	 9671	 0.046237	 0.050855	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9671	 9674	 0.030379	 0.060148	 0.00088	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9672	 9676	 0.002479	 0.008639	 0.002	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9672	 10434	 0.00337	 0.041067	 0.01358	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9672	 10475	 0.00197	 0.029222	 0.00901	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77650	 9672	 0.003767	 0.054876	 0.01757	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9672	 78073	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9672	 78073	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9673	 9680	 0.010565	 0.10353	 0.00203	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78073	 9673	 0.006765	 0.056276	 0.00107	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9674	 9679	 0.030469	 0.067437	 0.00111	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9674	 78074	 0.008574	 0.022725	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9675	 78074	 0.047722	 0.052489	 0.0007	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9676	 78074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9676	 78074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9677	 9678	 0.007731	 0.020432	 0.00478	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77650	 9677	 0.014597	 0.040708	 0.00854	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9678	 11391	 0.006822	 0.022987	 0.00571	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9678	 78075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9678	 78075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9679	 78098	 0.031964	 0.07421	 0.0011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9680	 9737	 0.013295	 0.063853	 0.00123	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78075	 9680	 0.013605	 0.083645	 0.00151	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9680	 78076	 0.010504	 0.037525	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9680	 78076	 0.010504	 0.037525	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9681	 11391	 0.002664	 0.010469	 0.00274	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9681	 78076	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9681	 78076	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9682	 9683	 0.000344	 0.002177	 0.00059	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9682	 9708	 0.001029	 0.00663	 0.00174	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77622	 9682	 0.000893	 0.00549	 0.00201	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77700	 9682	 0.003004	 0.013525	 0.0036	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9682	 78077	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9682	 78077	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9683	 9706	 0.00051	 0.002004	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9683	 78078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9683	 78078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9684	 78086	 0.01426	 0.010309	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78077	 9685	 0.003767	 0.014654	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78078	 9685	 0.001823	 0.006082	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9685	 78079	 0.003272	 0.012727	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9686	 9688	 0.007858	 0.006219	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9686	 78079	 0.004348	 0.007088	 0.00011	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9687	 9704	 0.000628	 0.002468	 0.00065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9687	 9708	 0.000745	 0.002983	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9687	 78079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9687	 78079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9689	 9691	 0.000505	 0.001984	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9689	 9706	 0.000232	 0.000903	 0.00024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9690	 9691	 0.000503	 0.002399	 0.0007	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9690	 9698	 0.001173	 0.003101	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9690	 9703	 0.000283	 0.002378	 0.0007	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77622	 9690	 0.0014	 0.012733	 0.00321	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9690	 78080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9690	 78080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9691	 78081	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9691	 78081	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9692	 9693	 0.011004	 0.007124	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9692	 9697	 0.004947	 0.012718	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9692	 78083	 0.002986	 0.006829	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9692	 78639	 0.002695	 0.016567	 0.0003	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9694	 9695	 0.000491	 0.002254	 0.00058	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9694	 11424	 0.00057	 0.002564	 0.00068	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9695	 9731	 0.000371	 0.00271	 0.0008	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9695	 11433	 0.002216	 0.008711	 0.00228	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9696	 9698	 0.001013	 0.002678	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9696	 9729	 0.000941	 0.002774	 0.00065	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9696	 78082	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9696	 78082	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78082	 9697	 0.002086	 0.004732	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9698	 78083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9698	 78083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78083	 9699	 0.009609	 0.007605	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9700	 9703	 0.000859	 0.002307	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9700	 9729	 0.001134	 0.002997	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9701	 9702	 0.000506	 0.00199	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9701	 9724	 0.000755	 0.003023	 0.00076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9702	 9703	 0.000497	 0.002238	 0.0006	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9704	 9705	 0.000542	 0.001971	 0.0006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9705	 9713	 0.000993	 0.005962	 0.00181	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9705	 78084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9705	 78084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9707	 9711	 0.001318	 0.010383	 0.00304	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77622	 9707	 0.000168	 0.001618	 0.00047	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9707	 78085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9707	 78085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9708	 9710	 0.000286	 0.00248	 0.00089	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77622	 9708	 0.000876	 0.006784	 0.00238	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9708	 78086	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9708	 78086	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78085	 9709	 0.024353	 0.022837	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9710	 9711	 0.000365	 0.003236	 0.00086	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9711	 9723	 0.000317	 0.003584	 0.00201	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9711	 78087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9711	 78087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78084	 9712	 0.005295	 0.013466	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78087	 9712	 0.034946	 0.022624	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9712	 78088	 0.005774	 0.014844	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9713	 9724	 0.001893	 0.005886	 0.00123	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9713	 9726	 0.000743	 0.008788	 0.0025	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77622	 9713	 0.001935	 0.016881	 0.00464	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9713	 78088	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9713	 78088	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78088	 9714	 0.02082	 0.021259	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9715	 9720	 0.001079	 0.005511	 0.00139	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9715	 9748	 0.00174	 0.008578	 0.00232	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9716	 10069	 0.003061	 0.021652	 0.00594	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9716	 78089	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9716	 78089	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9716	 78090	 0.001264	 0.009832	 0.00255	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9717	 9723	 0.000562	 0.005837	 0.00181	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9717	 9751	 0.000979	 0.01006	 0.00318	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9718	 9926	 0.000576	 0.006094	 0.09114	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9718	 9926	 0.000576	 0.006094	 0.09114	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9718	 78090	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9718	 78090	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9719	 9723	 0.000557	 0.004471	 0.00126	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78090	 9719	 0.000179	 0.002915	 0.00174	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9720	 9722	 0.000922	 0.004708	 0.00118	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9720	 78091	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9720	 78091	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78091	 9721	 0.026531	 0.020796	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9722	 9723	 0.000823	 0.004285	 0.00112	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9724	 78092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9724	 78092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78092	 9725	 0.003381	 0.024715	 0.00046	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9725	 78093	 0.008971	 0.050993	 0.00092	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9726	 9727	 0.000765	 0.007666	 0.00255	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9727	 9728	 0.000435	 0.004606	 0.00137	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9728	 9735	 0.001704	 0.017927	 0.01007	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9728	 9745	 0.001043	 0.010191	 0.00286	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9728	 9921	 0.001482	 0.020353	 0.00734	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9728	 78093	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9728	 78093	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9729	 9730	 0.001141	 0.004645	 0.00113	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9730	 9733	 0.001158	 0.004635	 0.00117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9730	 78094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9730	 78094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9731	 9732	 0.000304	 0.002166	 0.00067	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9732	 9733	 0.000707	 0.004477	 0.00121	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9732	 78095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9732	 78095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9733	 9741	 0.002927	 0.028101	 0.00817	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9733	 78096	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9733	 78096	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78096	 9734	 0.01988	 0.015732	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9735	 78097	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9735	 78097	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9735	 78621	 0.002943	 0.038815	 0.02377	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9736	 11427	 0.004358	 0.040573	 0.00079	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78097	 9736	 0.002866	 0.023843	 0.00045	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78097	 9737	 0.019958	 0.076785	 0.00131	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9738	 9741	 0.00031	 0.002681	 0.00096	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9738	 10492	 0.002111	 0.017561	 0.00532	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9738	 78098	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9738	 78098	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9739	 9740	 0.027216	 0.025068	 0.0004	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78096	 9740	 0.019577	 0.046359	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9742	 9743	 0.000475	 0.005256	 0.00158	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9742	 9746	 0.002316	 0.011637	 0.00303	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9742	 9757	 0.000272	 0.001865	 0.00054	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9743	 10487	 0.000631	 0.00684	 0.00214	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9744	 10491	 0.013013	 0.033452	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9744	 78099	 0.012001	 0.040035	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9745	 9757	 0.00067	 0.004742	 0.0013	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9745	 78099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9745	 78099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9746	 9749	 0.00146	 0.006508	 0.00177	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9746	 78100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9746	 78100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9747	 9751	 0.001211	 0.009161	 0.0045	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9747	 9923	 0.000857	 0.009792	 0.00299	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9747	 78101	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9747	 78101	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9748	 9749	 0.002093	 0.009602	 0.00246	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9750	 9751	 0.002344	 0.009383	 0.00236	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9750	 9754	 0.004242	 0.016502	 0.00441	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78090	 9751	 0.001866	 0.018229	 0.00512	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9752	 78102	 0.007692	 0.019562	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9753	 78102	 0.010165	 0.023247	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9754	 78102	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9754	 78102	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9755	 9756	 0.003911	 0.022234	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9755	 78166	 0.008608	 0.038355	 0.00065	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78101	 9756	 0.004764	 0.029915	 0.00065	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78099	 9758	 0.022038	 0.017441	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9759	 10440	 0.000634	 0.008597	 0.00497	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9759	 10442	 0.000538	 0.007192	 0.00197	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9759	 78103	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9759	 78103	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9759	 78105	 0.000797	 0.010856	 0.00388	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9759	 78389	 0.001546	 0.023094	 0.00683	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9760	 9761	 0.002804	 0.019042	 0.00047	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78103	 9760	 0.005514	 0.019699	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78103	 9760	 0.005514	 0.019699	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9761	 9765	 0.002384	 0.014488	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9762	 9763	 0.025447	 0.019947	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9762	 9764	 0.004504	 0.012919	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9762	 9765	 0.003326	 0.019398	 0.00039	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9762	 78106	 0.005321	 0.023581	 0.00071	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9764	 78106	 0.00343	 0.01849	 0.00037	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9765	 9772	 0.001912	 0.007327	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9765	 78388	 0.003498	 0.014297	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9766	 9777	 0.002196	 0.006473	 0.00151	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9766	 10638	 0.001706	 0.00907	 0.0021	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9766	 78105	 0.001016	 0.006814	 0.00164	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9767	 78104	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9767	 78104	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9768	 9791	 0.004812	 0.023876	 0.00057	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78106	 9768	 0.003711	 0.027835	 0.00056	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9768	 78113	 0.003583	 0.017919	 0.00032	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9769	 78167	 0.019467	 0.015259	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9770	 78107	 0.035323	 0.027954	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78105	 9771	 0.002804	 0.007279	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9771	 78107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9771	 78107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9772	 9773	 0.003043	 0.011836	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9772	 78388	 0.00534	 0.013727	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9773	 9774	 0.002697	 0.009972	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9774	 9775	 0.003096	 0.010327	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9775	 9776	 0.004684	 0.010711	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9776	 9785	 0.002395	 0.022302	 0.00043	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9776	 78108	 0.002807	 0.02086	 0.0005	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78105	 9777	 0.001499	 0.009654	 0.00253	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9777	 78108	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9777	 78108	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9778	 9794	 0.002374	 0.006463	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9778	 9927	 0.002346	 0.006543	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9779	 9794	 0.000663	 0.002808	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9779	 9848	 0.001239	 0.007847	 0.00213	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9779	 78109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9779	 78109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9780	 9932	 0.012613	 0.011618	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78109	 9780	 0.008033	 0.012183	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9781	 9782	 0.000563	 0.003627	 0.00095	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9781	 9788	 0.000713	 0.004432	 0.00125	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9782	 9783	 0.000345	 0.001902	 0.00069	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9783	 10628	 0.001766	 0.0081	 0.00207	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9783	 78110	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9783	 78110	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9784	 9785	 0.021149	 0.015288	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78110	 9785	 0.002845	 0.022175	 0.00041	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9786	 9791	 0.019875	 0.020074	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9787	 78118	 0.012503	 0.024754	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9788	 9789	 0.000226	 0.002446	 0.00076	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9788	 9811	 0.000764	 0.004619	 0.00118	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9788	 78111	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9788	 78111	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9789	 9804	 0.000379	 0.004107	 0.00128	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9790	 9793	 0.000807	 0.003229	 0.00109	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9790	 9795	 0.00048	 0.00531	 0.00159	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9790	 78112	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9790	 78112	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78112	 9791	 0.00409	 0.023016	 0.0005	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9791	 78118	 0.00181	 0.013669	 0.00041	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78112	 9792	 0.003128	 0.010951	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9793	 9843	 0.001321	 0.008507	 0.00223	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9793	 78113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9793	 78113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9794	 9797	 0.001073	 0.002837	 0.00066	 132.0	 132.0	 132.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9794	 9797	 0.001073	 0.002837	 0.00066	 132.0	 132.0	 132.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9794	 9797	 0.001073	 0.002837	 0.00066	 132.0	 132.0	 132.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9794	 78114	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9794	 78114	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9795	 9798	 0.000335	 0.004212	 0.0013	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9795	 9806	 0.000392	 0.002622	 0.00165	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9795	 78168	 0.000562	 0.008113	 0.00258	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78114	 9796	 0.009071	 0.013894	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9799	 9802	 0.00022	 0.002988	 0.00173	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9799	 78115	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9799	 78115	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9799	 78168	 0.000269	 0.004401	 0.00218	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9800	 9802	 0.000175	 0.001828	 0.0012	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9800	 9822	 0.000221	 0.002674	 0.00152	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9800	 78116	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9800	 78116	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9801	 9824	 0.001616	 0.009094	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9801	 78117	 0.001844	 0.012657	 0.00023	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9802	 78117	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9802	 78117	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9803	 9804	 0.000695	 0.00294	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9803	 78118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9803	 78118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9804	 9806	 0.000315	 0.003963	 0.00123	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9804	 78119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9804	 78119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78119	 9805	 0.011544	 0.009049	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9806	 78120	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9806	 78120	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9807	 9809	 0.004059	 0.014501	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9807	 9809	 0.004059	 0.014501	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9807	 10602	 0.014402	 0.011289	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78110	 9807	 0.004468	 0.015962	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78110	 9807	 0.004468	 0.015962	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9808	 9809	 0.00185	 0.013315	 0.00044	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9808	 78121	 0.001662	 0.016288	 0.00032	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9809	 10594	 0.003412	 0.011937	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9809	 10594	 0.003412	 0.011937	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9809	 78123	 0.005725	 0.018435	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9810	 78121	 0.001595	 0.011477	 0.00038	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9810	 78122	 0.00194	 0.016476	 0.00038	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9811	 78121	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9811	 78121	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9812	 9813	 0.000122	 0.00199	 0.00119	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9812	 9821	 0.00055	 0.004184	 0.00131	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9812	 9822	 0.000187	 0.002061	 0.00122	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9813	 9814	 0.000146	 0.002596	 0.00131	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9813	 78122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9813	 78122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9814	 9815	 0.000102	 0.001663	 0.00099	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9814	 78123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9814	 78123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9815	 10596	 0.000177	 0.00266	 0.00156	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9815	 78124	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9815	 78124	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9816	 9817	 0.003352	 0.008884	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78124	 9816	 0.004889	 0.010476	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9817	 9818	 0.00353	 0.010841	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9817	 9820	 0.002851	 0.011902	 0.00034	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9818	 78127	 0.002587	 0.011574	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9819	 9820	 0.001244	 0.00647	 0.00014	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9819	 78127	 0.003577	 0.016586	 0.00034	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9820	 78125	 0.003524	 0.012589	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9820	 78125	 0.003524	 0.012589	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9821	 9826	 0.000518	 0.0058	 0.00184	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9821	 78125	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9821	 78125	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9823	 9824	 0.001818	 0.01023	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78125	 9823	 0.002648	 0.012345	 0.00028	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9824	 9825	 0.004183	 0.009609	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9825	 78126	 0.004335	 0.010611	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9826	 9833	 0.000634	 0.002538	 0.00064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9826	 78126	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9826	 78126	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9826	 78168	 0.000604	 0.009072	 0.00531	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9827	 9837	 0.000232	 0.002509	 0.00498	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9827	 9837	 0.000232	 0.002509	 0.00498	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77637	 9827	 8.4e-05	 0.000921	 0.00179	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77637	 9827	 8.4e-05	 0.000921	 0.00179	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9827	 78127	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9827	 78127	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9828	 78129	 0.001564	 0.010227	 0.00024	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9828	 78170	 0.001822	 0.011756	 0.00037	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9829	 9830	 0.000158	 0.002414	 0.00078	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77390	 9829	 0.00036	 0.004734	 0.00438	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77638	 9829	 0.000448	 0.007493	 0.00425	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9829	 78128	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9829	 78128	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9830	 78129	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9830	 78129	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9830	 78130	 0.000174	 0.002742	 0.00094	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9830	 78370	 0.000672	 0.008447	 0.00262	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9831	 10592	 0.000266	 0.003344	 0.0117	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9831	 78130	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9831	 78130	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9831	 78171	 2.1e-05	 0.000346	 0.0013	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78126	 9832	 0.00312	 0.012137	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78126	 9832	 0.00312	 0.012137	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9832	 78133	 0.001526	 0.013638	 0.00032	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9833	 9839	 0.000603	 0.002413	 0.00061	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9834	 78134	 0.010491	 0.006792	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9835	 9836	 0.000118	 0.002015	 0.00058	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9835	 78132	 0.000112	 0.001918	 0.00055	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9836	 9838	 0.000227	 0.001641	 0.00088	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9836	 78131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9836	 78131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77631	 9837	 0.001033	 0.011393	 0.02165	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77631	 9837	 0.001033	 0.011393	 0.02165	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9837	 78132	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78133	 9837	 0.000321	 0.02569	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9838	 9841	 0.000106	 0.001625	 0.00045	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9839	 9840	 0.00037	 0.002206	 0.00058	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9839	 78134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9839	 78134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9840	 78135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9840	 78135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9841	 9842	 0.000132	 0.001706	 0.00067	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9841	 78136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9841	 78136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9843	 9844	 0.000277	 0.001699	 0.00062	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9843	 78137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9843	 78137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9844	 9845	 0.00014	 0.00114	 0.00036	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9844	 78138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9844	 78138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9845	 9848	 0.000131	 0.001261	 0.00037	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9846	 9848	 0.000257	 0.003486	 0.00201	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9846	 9858	 0.000458	 0.007475	 0.00446	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9846	 10470	 0.000619	 0.002842	 0.00073	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9846	 78139	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9846	 78139	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78139	 9847	 0.014189	 0.011229	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9848	 9850	 0.000456	 0.001854	 0.00045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9849	 9853	 0.005652	 0.009426	 0.00014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9850	 9852	 0.000632	 0.003292	 0.00086	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9850	 78140	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9850	 78140	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9851	 9852	 0.001173	 0.004696	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9852	 78141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9852	 78141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78139	 9853	 0.00447	 0.020726	 0.00043	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78140	 9853	 0.003209	 0.01414	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9854	 9860	 0.000741	 0.003594	 0.00082	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9854	 78142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9854	 78142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9855	 9856	 0.001189	 0.008161	 0.00238	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9855	 9860	 0.000778	 0.004287	 0.00155	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9856	 9858	 0.000518	 0.005494	 0.00163	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9856	 9918	 0.001303	 0.01283	 0.0053	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9856	 78143	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9856	 78143	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9857	 9858	 0.000215	 0.002544	 0.0013	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9857	 9916	 0.000159	 0.001754	 0.0009	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9857	 78144	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9857	 78144	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78142	 9859	 0.023703	 0.017439	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9860	 9867	 0.003401	 0.012316	 0.00264	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9861	 9933	 0.011429	 0.0201	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9862	 9872	 0.001408	 0.005532	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9862	 78145	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9862	 78145	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9863	 9869	 0.002618	 0.013094	 0.00023	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9863	 9933	 0.002714	 0.017513	 0.00056	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9863	 78147	 0.00498	 0.019375	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9863	 78147	 0.00498	 0.019375	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78143	 9864	 0.007004	 0.028027	 0.00059	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9864	 78147	 0.004339	 0.019117	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9865	 9866	 0.000822	 0.004724	 0.00134	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9865	 9904	 0.000422	 0.003968	 0.0012	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9865	 78146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9865	 78146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9866	 9867	 0.000759	 0.004316	 0.00125	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9867	 78147	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9867	 78147	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9868	 9903	 0.00373	 0.014351	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9868	 9903	 0.00373	 0.014351	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9868	 78148	 0.004151	 0.014523	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9868	 78148	 0.004151	 0.014523	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9869	 78148	 0.002848	 0.016188	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9870	 9874	 0.001509	 0.005872	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9870	 78148	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9870	 78148	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9871	 78149	 0.00837	 0.012196	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9872	 9873	 0.000689	 0.002709	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9873	 9874	 0.000822	 0.003293	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77629	 9874	 0.000226	 0.003872	 0.0021	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9874	 78149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9874	 78149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9874	 78165	 0.001914	 0.032734	 0.01775	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9874	 78168	 0.001109	 0.012546	 0.00705	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9875	 78150	 0.022348	 0.014468	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9876	 9878	 0.000171	 0.002576	 0.00151	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77629	 9876	 0.000414	 0.003614	 0.00099	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77653	 9876	 0.000165	 0.002314	 0.00188	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9876	 78150	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9876	 78150	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77630	 9877	 0.000923	 0.006639	 0.00022	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77632	 9877	 0.000558	 0.003432	 6e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9877	 78153	 0.009564	 0.02714	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9878	 9879	 0.00018	 0.003008	 0.0017	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77629	 9878	 0.000545	 0.005774	 0.00171	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9879	 9884	 0.000287	 0.004794	 0.00272	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9879	 9931	 0.001899	 0.00488	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9879	 78151	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9879	 78151	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9880	 9893	 0.00393	 0.015287	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77654	 9880	 0.001958	 0.008726	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9881	 9882	 0.003115	 0.010906	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78151	 9881	 0.002445	 0.01338	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9882	 9883	 0.002607	 0.012083	 0.00023	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9882	 9896	 0.001408	 0.013108	 0.00025	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9882	 9901	 0.007794	 0.02391	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77652	 9882	 0.005429	 0.029051	 0.00088	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9883	 9885	 0.003594	 0.013825	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77652	 9885	 0.004588	 0.015305	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9886	 9902	 0.013161	 0.051199	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9886	 78201	 0.008712	 0.042032	 0.00074	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9887	 9888	 0.002944	 0.011452	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9887	 9888	 0.002944	 0.011452	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9887	 9902	 0.004666	 0.016667	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9887	 9902	 0.004666	 0.016667	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9888	 9890	 0.005019	 0.019526	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9888	 9890	 0.005019	 0.019526	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77631	 9889	 0.00035	 0.002454	 0.00418	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9889	 78152	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78153	 9889	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9890	 9891	 0.014266	 0.009236	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9890	 9892	 0.017212	 0.013491	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 9890	 0.008522	 0.032784	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 9890	 0.008522	 0.032784	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9893	 9896	 0.003469	 0.010641	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 9894	 0.035938	 0.028441	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9895	 9896	 0.003585	 0.016612	 0.00032	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 9895	 0.005001	 0.02319	 0.00048	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9896	 9898	 0.009866	 0.025362	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9897	 9899	 0.001957	 0.004715	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78152	 9897	 0.002374	 0.009885	 0.00308	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9897	 78154	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9897	 78154	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78154	 9898	 0.008033	 0.019023	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9899	 9963	 0.001872	 0.004947	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9900	 10032	 0.006322	 0.038868	 0.0007	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 9900	 0.008851	 0.044771	 0.00078	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9901	 9960	 0.004734	 0.021097	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9902	 9903	 0.002158	 0.008396	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9902	 9903	 0.002158	 0.008396	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9902	 9911	 0.038818	 0.03072	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78146	 9902	 0.004037	 0.026678	 0.00053	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9902	 78157	 0.013363	 0.040993	 0.00111	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9902	 78157	 0.013363	 0.040993	 0.00111	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9904	 9910	 0.000595	 0.005899	 0.0016	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9905	 9907	 0.000807	 0.005602	 0.0016	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9905	 10047	 0.002437	 0.013374	 0.00353	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9905	 78155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9905	 78155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9906	 78156	 0.027638	 0.021872	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9907	 9909	 0.00032	 0.004711	 0.00144	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9907	 78156	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9907	 78156	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9907	 78165	 0.000762	 0.01033	 0.00597	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9908	 78158	 0.030514	 0.03082	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9909	 9912	 0.00053	 0.003835	 0.00206	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9910	 9912	 0.000327	 0.002368	 0.00127	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9910	 78157	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9910	 78157	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9912	 78158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9912	 78158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9913	 9914	 0.000324	 0.003663	 0.00206	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9913	 9920	 0.000396	 0.004906	 0.00265	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9913	 78159	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9913	 78159	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9914	 9915	 0.000267	 0.00279	 0.00184	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9915	 9916	 0.000281	 0.002958	 0.00166	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	9915	 78160	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9915	 78160	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9917	 10472	 0.034668	 0.045564	 0.00062	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78160	 9917	 0.002457	 0.020436	 0.00039	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9917	 78161	 0.006985	 0.037513	 0.00089	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77622	 9918	 0.004359	 0.066618	 0.02147	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9918	 78161	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9918	 78161	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78161	 9919	 0.007679	 0.019739	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9920	 9921	 0.000871	 0.006128	 0.00348	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9920	 9922	 0.000788	 0.008347	 0.00248	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9920	 78162	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9920	 78162	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9922	 9923	 0.000643	 0.006603	 0.00209	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9922	 78163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9922	 78163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9923	 78164	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9923	 78164	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9924	 9925	 0.002072	 0.010109	 0.00017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78164	 9924	 0.00265	 0.011579	 0.0003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78163	 9925	 0.002673	 0.011913	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9926	 78165	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9926	 78165	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9927	 78167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9927	 78167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77626	 9928	 0.00055	 0.005445	 0.0932	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77626	 9928	 0.00055	 0.005445	 0.0932	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9928	 78168	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9928	 78168	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77638	 9929	 0.001188	 0.008244	 0.00235	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9929	 78170	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9929	 78170	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9930	 78171	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9930	 78171	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78138	 9932	 0.004552	 0.013056	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78145	 9933	 0.005873	 0.022848	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9934	 9935	 0.052627	 0.041648	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9935	 9942	 0.021383	 0.050636	 0.00093	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9936	 9942	 0.033113	 0.021437	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9937	 9938	 0.033307	 0.021563	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9938	 9939	 0.005103	 0.013118	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9938	 9950	 0.024808	 0.017933	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9939	 9950	 0.006608	 0.013522	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9939	 78172	 0.002824	 0.010864	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9940	 9966	 0.00245	 0.006361	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9940	 9971	 0.003625	 0.021596	 0.00568	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9940	 78172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9940	 78172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9941	 9942	 0.010677	 0.019266	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9941	 9945	 0.036722	 0.028784	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78172	 9941	 0.012024	 0.010848	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9942	 9944	 0.008949	 0.020772	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9942	 78178	 0.01699	 0.081975	 0.00145	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9943	 9972	 0.033854	 0.037236	 0.0005	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9944	 9948	 0.009553	 0.024558	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9946	 9947	 0.002863	 0.0069	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9946	 9968	 0.004366	 0.011333	 0.00275	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9947	 9969	 0.002145	 0.005569	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9948	 78179	 0.007148	 0.01526	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9949	 78200	 0.021498	 0.083633	 0.0014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9950	 9951	 0.015698	 0.011119	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9950	 9952	 0.015895	 0.036518	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9950	 9956	 0.017548	 0.013755	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9952	 78173	 0.0157	 0.032265	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9953	 9960	 0.015348	 0.032257	 0.00059	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9953	 78173	 0.008818	 0.014855	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9954	 9957	 0.002805	 0.007281	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9954	 78173	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9954	 78173	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9955	 78174	 0.007203	 0.014262	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9957	 9966	 0.002198	 0.00613	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9957	 78174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9957	 78174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78173	 9958	 0.01014	 0.018295	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9959	 9960	 0.021719	 0.015385	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9960	 9965	 0.003025	 0.013477	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9961	 9964	 0.001463	 0.005019	 0.0012	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9961	 78175	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9961	 78175	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9962	 78176	 0.032402	 0.024854	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9963	 9964	 0.001281	 0.003384	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9964	 78176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9964	 78176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78175	 9965	 0.00563	 0.013068	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78176	 9965	 0.002855	 0.015624	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9966	 78177	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9966	 78177	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78175	 9967	 0.026516	 0.052499	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78177	 9967	 0.035764	 0.026313	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9968	 10031	 0.003901	 0.013593	 0.00315	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9968	 78178	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9968	 78178	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9969	 9971	 0.000905	 0.003738	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9969	 9980	 0.003036	 0.027616	 0.00697	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9969	 10073	 0.000567	 0.006082	 0.00158	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	9970	 78179	 0.015559	 0.012196	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9971	 78179	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9971	 78179	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9972	 9974	 0.044623	 0.045071	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78179	 9972	 0.005422	 0.023889	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9973	 9976	 0.044745	 0.031696	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9975	 9984	 0.020768	 0.01528	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9976	 78213	 0.008689	 0.02201	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9977	 78213	 0.011577	 0.022921	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9978	 9981	 0.008803	 0.029367	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9978	 10038	 0.009952	 0.043602	 0.00094	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9979	 9981	 0.016653	 0.012252	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9980	 10011	 0.001837	 0.008915	 0.00204	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9980	 78180	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9980	 78180	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9981	 9982	 0.012485	 0.022526	 0.00033	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9981	 78212	 0.008762	 0.020341	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	9982	 78186	 0.003499	 0.015328	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9983	 78212	 0.023708	 0.02329	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9984	 9986	 0.006179	 0.011106	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9985	 9988	 0.009544	 0.01748	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9986	 9988	 0.003003	 0.010018	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9987	 78181	 0.011688	 0.008279	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9988	 78182	 0.002954	 0.014943	 0.00026	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9988	 78212	 0.011671	 0.051423	 0.00089	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	9989	 9990	 0.000936	 0.003121	 0.00079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9989	 9993	 0.001579	 0.005418	 0.0013	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9989	 78181	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9989	 78181	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9990	 78182	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9990	 78182	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9991	 78183	 0.028739	 0.022743	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	9992	 9993	 0.001136	 0.004016	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9992	 78183	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9992	 78183	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9993	 78184	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9993	 78184	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9994	 10000	 0.002029	 0.006961	 0.00167	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	9994	 78185	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9994	 78185	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78185	 9995	 0.017581	 0.019149	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9996	 9997	 0.000783	 0.003135	 0.00079	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9996	 9999	 0.002005	 0.007015	 0.00232	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9996	 78186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9996	 78186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9996	 78211	 0.001914	 0.010621	 0.00323	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	9997	 9998	 0.001161	 0.004225	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9998	 10010	 0.001455	 0.005825	 0.00147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9999	 10000	 0.000955	 0.003753	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	9999	 10009	 0.001443	 0.00673	 0.00167	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10001	 10006	 0.00054	 0.002519	 0.00062	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10001	 78187	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10001	 78187	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78187	 10002	 0.012986	 0.009387	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78187	 10003	 0.015289	 0.011727	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10004	 10005	 0.001905	 0.004898	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78187	 10004	 0.003884	 0.00964	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10005	 10008	 0.001658	 0.004262	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10006	 10015	 0.0006	 0.003015	 0.00078	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10007	 78190	 0.01096	 0.01107	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10007	 78191	 0.005011	 0.012743	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10008	 78188	 0.011164	 0.014673	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10009	 10014	 0.000809	 0.004822	 0.00127	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10009	 78188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10009	 78188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10010	 10011	 0.000994	 0.004208	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10011	 10020	 0.00122	 0.009975	 0.00271	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10011	 78189	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10011	 78189	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10012	 10014	 0.00041	 0.002813	 0.00082	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10012	 10019	 0.000984	 0.006431	 0.00164	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78189	 10013	 0.027703	 0.020382	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10014	 78190	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10014	 78190	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10015	 10016	 0.000594	 0.002983	 0.00078	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10015	 78191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10015	 78191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10016	 10017	 0.000343	 0.001723	 0.00045	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10017	 10018	 0.00059	 0.003017	 0.00082	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10018	 10025	 0.000345	 0.001672	 0.00038	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10018	 78192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10018	 78192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10019	 10021	 0.001257	 0.008095	 0.00212	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10019	 78193	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10019	 78193	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10020	 10201	 0.003563	 0.03056	 0.0087	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10020	 78194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10020	 78194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10021	 10022	 0.000951	 0.007643	 0.00215	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10021	 78195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10021	 78195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10022	 10066	 0.001804	 0.009178	 0.00333	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10022	 10185	 0.000763	 0.004577	 0.00139	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10023	 10024	 0.001301	 0.006314	 0.00144	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10023	 10028	 0.000571	 0.003025	 0.00077	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10023	 78196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10023	 78196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10024	 10026	 0.000739	 0.003392	 0.00087	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10025	 10026	 0.00117	 0.004832	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10025	 78197	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10025	 78197	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10027	 10029	 0.027507	 0.017808	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10028	 10177	 0.001929	 0.01	 0.00244	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10028	 78198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10028	 78198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10029	 10030	 0.003128	 0.0168	 0.0004	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78198	 10029	 0.003411	 0.015197	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10030	 78250	 0.004776	 0.031089	 0.00063	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78152	 10031	 0.007279	 0.022753	 0.00659	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10031	 78199	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10031	 78199	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10032	 10033	 0.006537	 0.022871	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10032	 10033	 0.006537	 0.022871	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78199	 10032	 0.003374	 0.031414	 0.00061	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10033	 10041	 0.005245	 0.020178	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10033	 10041	 0.005245	 0.020178	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10033	 78202	 0.007877	 0.054071	 0.00099	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10034	 10036	 0.006201	 0.022152	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10034	 10037	 0.014961	 0.034372	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78199	 10034	 0.014014	 0.054518	 0.00091	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78199	 10034	 0.014014	 0.054518	 0.00091	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10034	 78205	 0.005829	 0.044287	 0.00101	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10035	 10036	 0.005995	 0.02537	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10035	 10044	 0.003652	 0.014488	 0.00041	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10037	 10038	 0.026422	 0.044509	 0.00063	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10038	 78200	 0.016902	 0.03924	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10038	 78207	 0.017926	 0.062763	 0.00174	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10039	 10059	 0.002789	 0.013754	 0.00372	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10039	 78200	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10039	 78200	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10040	 10047	 0.001895	 0.007201	 0.00202	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10040	 78201	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10040	 78201	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10041	 10042	 0.005372	 0.019191	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10041	 10042	 0.005372	 0.019191	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78201	 10042	 0.002977	 0.014299	 0.00028	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10042	 78203	 0.008062	 0.045866	 0.00141	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10043	 78202	 0.005013	 0.01791	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10043	 78204	 0.005407	 0.024093	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10044	 78202	 0.003336	 0.022901	 0.00042	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10045	 10046	 0.002818	 0.012686	 0.00338	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10045	 78202	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10045	 78202	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10046	 10047	 0.001873	 0.01028	 0.00272	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10046	 10075	 0.001778	 0.014752	 0.00388	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10046	 78203	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10046	 78203	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10047	 78204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10047	 78204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10048	 10054	 0.014302	 0.018797	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78202	 10048	 0.015388	 0.027485	 0.00041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10049	 10050	 0.002302	 0.008054	 0.00267	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10049	 78205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10049	 78205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10050	 10064	 0.010651	 0.028149	 0.00659	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78165	 10050	 0.007057	 0.053675	 0.01687	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10050	 78206	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10050	 78206	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10051	 10052	 0.012743	 0.019883	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10051	 10053	 0.007846	 0.034766	 0.00104	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78206	 10051	 0.00861	 0.02941	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78203	 10052	 0.013321	 0.043958	 0.00071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10053	 78262	 0.007451	 0.054458	 0.001	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10054	 10055	 0.007052	 0.011003	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10055	 10056	 0.00581	 0.011504	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78206	 10055	 0.005335	 0.018665	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10056	 10057	 0.015501	 0.012267	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10058	 10061	 0.025529	 0.050545	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78206	 10058	 0.035787	 0.028321	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10059	 10068	 0.001988	 0.00912	 0.00234	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10059	 78207	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10059	 78207	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78207	 10060	 0.024852	 0.064408	 0.00122	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10060	 78210	 0.002485	 0.013682	 0.00031	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10061	 78208	 0.018342	 0.036315	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10061	 78261	 0.023128	 0.059454	 0.00092	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10062	 10063	 0.002766	 0.00718	 0.00174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10062	 10065	 0.001814	 0.005347	 0.00124	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10062	 78208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10062	 78208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10063	 78209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10063	 78209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10064	 10065	 0.001245	 0.003201	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10064	 78210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10064	 78210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10066	 10067	 0.002724	 0.012139	 0.0033	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10066	 10189	 0.000684	 0.005694	 0.00172	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10067	 10068	 0.002478	 0.009916	 0.00335	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10069	 10076	 0.003148	 0.02028	 0.00532	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78089	 10070	 0.055558	 0.043549	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10071	 78212	 0.040651	 0.15816	 0.00264	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10072	 10277	 0.003562	 0.036388	 0.11566	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77631	 10072	 0.003405	 0.026297	 0.05353	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10072	 78211	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78212	 10072	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78211	 10073	 0.000372	 0.005206	 0.00177	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10073	 78213	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10073	 78213	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78185	 10074	 0.025789	 0.018974	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10075	 10076	 0.001934	 0.012016	 0.00339	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10075	 10218	 0.005827	 0.023712	 0.00578	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10077	 78214	 0.043081	 0.03264	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10078	 10079	 0.000793	 0.01211	 0.0039	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77979	 10078	 0.000471	 0.006502	 0.00291	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10078	 78214	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10078	 78214	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10079	 10373	 0.000758	 0.005483	 0.00295	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10079	 78215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10079	 78215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10080	 10084	 0.016691	 0.042447	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78215	 10080	 0.008523	 0.019332	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10081	 10082	 0.007899	 0.020934	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10081	 10302	 0.013705	 0.045717	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10081	 78303	 0.012119	 0.031153	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10081	 78310	 0.016542	 0.086023	 0.00186	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10082	 10083	 0.008297	 0.012709	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10084	 10085	 0.063783	 0.050478	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10084	 10086	 0.012236	 0.040377	 0.00065	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10086	 78217	 0.008745	 0.03897	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10087	 10102	 0.000874	 0.006287	 0.00167	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77979	 10087	 0.001764	 0.009986	 0.00248	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10087	 78216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10087	 78216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10088	 10091	 0.014205	 0.023157	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10088	 78217	 0.014112	 0.024817	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10089	 10139	 0.005574	 0.035303	 0.00958	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77979	 10089	 0.002361	 0.009448	 0.00319	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10089	 78217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10089	 78217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10090	 10091	 0.020283	 0.03715	 0.00064	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10091	 10092	 0.020559	 0.01331	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10091	 10105	 0.006378	 0.024538	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10093	 78218	 0.014787	 0.02668	 0.00039	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10094	 10095	 0.001329	 0.007525	 0.00186	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10094	 10098	 0.002078	 0.010616	 0.00267	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10095	 10138	 0.00087	 0.005512	 0.0015	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10096	 10097	 0.000513	 0.005182	 0.00152	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10096	 10158	 0.000712	 0.007549	 0.00224	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10097	 10115	 0.000533	 0.005113	 0.00149	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10098	 10108	 0.002776	 0.015951	 0.00452	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10098	 78218	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10098	 78218	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10099	 10105	 0.006682	 0.020519	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10099	 10106	 0.003794	 0.016806	 0.00038	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10100	 10107	 0.009715	 0.019039	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78218	 10100	 0.002603	 0.014646	 0.00032	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10100	 78222	 0.004617	 0.026244	 0.00047	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10101	 10105	 0.001733	 0.008456	 0.00015	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10101	 78219	 0.002185	 0.009778	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10102	 10104	 0.000437	 0.0042	 0.00122	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10102	 78219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10102	 78219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10103	 10105	 0.014345	 0.033968	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77980	 10103	 0.019851	 0.047348	 0.00106	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78216	 10103	 0.005142	 0.017154	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10104	 10108	 0.000567	 0.005621	 0.00153	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10106	 78220	 0.006841	 0.034604	 0.0006	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10107	 78222	 0.012018	 0.030563	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10108	 10111	 0.000724	 0.007187	 0.00195	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10108	 10114	 0.001865	 0.020434	 0.00567	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10108	 10115	 0.001822	 0.017149	 0.00519	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77979	 10108	 0.001499	 0.018268	 0.00604	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77983	 10108	 0.001572	 0.017974	 0.00548	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10108	 78220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10108	 78220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10109	 10110	 0.001104	 0.007807	 0.00214	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77983	 10109	 0.00204	 0.012541	 0.00362	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10110	 10116	 0.000545	 0.007866	 0.0025	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77979	 10110	 0.004265	 0.024982	 0.00681	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10111	 10112	 0.000574	 0.005805	 0.00171	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10112	 10113	 0.00105	 0.008044	 0.00215	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10112	 78223	 0.001441	 0.009422	 0.0024	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10113	 10114	 0.000773	 0.006498	 0.00192	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10114	 10127	 0.000487	 0.004957	 0.00128	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10114	 10175	 0.002033	 0.019519	 0.00568	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10114	 78221	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10114	 78221	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10115	 78222	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10115	 78222	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10116	 78223	 0.000245	 0.003996	 0.00238	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10117	 10150	 0.001252	 0.011479	 0.04531	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78104	 10117	 0.002246	 0.022117	 0.04715	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10117	 78223	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78224	 10117	 0.000318	 0.023855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10118	 10119	 0.002395	 0.012864	 0.00031	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10118	 10121	 0.002856	 0.020878	 0.00038	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10119	 10133	 0.025729	 0.020361	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10119	 78378	 0.004053	 0.016219	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78224	 10120	 0.011559	 0.009147	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10121	 10122	 0.020379	 0.016127	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78224	 10121	 0.002273	 0.021165	 0.00041	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78224	 10123	 0.00373	 0.014929	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10124	 10129	 0.012931	 0.021784	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10124	 78225	 0.008638	 0.021143	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10125	 10126	 0.000801	 0.006502	 0.00207	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10125	 10130	 0.001084	 0.004879	 0.0013	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78223	 10125	 0.000698	 0.006697	 0.00195	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10125	 78225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10125	 78225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10126	 10137	 0.000991	 0.009834	 0.00267	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10126	 78226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10126	 78226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10127	 10161	 0.000962	 0.0102	 0.00303	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10127	 78227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10127	 78227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10128	 10130	 0.000877	 0.009502	 0.00297	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10128	 10163	 0.000694	 0.010017	 0.00318	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10128	 78228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10128	 78228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10129	 10132	 0.005039	 0.008861	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78221	 10129	 0.011648	 0.027042	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78223	 10130	 0.001431	 0.0115	 0.00323	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10130	 78229	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10130	 78229	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78226	 10131	 0.002566	 0.014586	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78229	 10131	 0.001795	 0.010088	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78229	 10132	 0.005644	 0.01496	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10134	 78379	 0.018647	 0.032794	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10135	 10136	 0.000625	 0.006396	 0.0038	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10135	 10459	 0.00027	 0.002448	 0.00185	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10135	 78230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10135	 78230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10136	 10624	 0.000547	 0.005758	 0.00323	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10137	 10457	 0.001187	 0.012735	 0.00332	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10138	 10148	 0.000938	 0.007536	 0.00212	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10138	 78231	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10138	 78231	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10139	 10145	 0.001183	 0.017389	 0.00532	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77979	 10139	 0.009288	 0.046669	 0.01215	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78231	 10140	 0.015172	 0.035224	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78231	 10141	 0.029525	 0.020914	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78231	 10142	 0.007198	 0.032072	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10142	 78236	 0.003803	 0.018256	 0.00055	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10143	 78234	 0.007142	 0.0114	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10144	 78232	 0.028844	 0.043746	 0.00063	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10145	 10517	 0.000651	 0.00994	 0.0032	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10145	 78232	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10145	 78232	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10146	 10518	 0.001403	 0.008421	 0.00255	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10146	 10530	 0.001233	 0.008274	 0.002	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10146	 78233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10146	 78233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78233	 10147	 0.009327	 0.033318	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10147	 78238	 0.024711	 0.072668	 0.00149	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10148	 78234	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10148	 78234	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10148	 78235	 0.0008	 0.003483	 0.00099	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10148	 78237	 0.000751	 0.008053	 0.0021	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10149	 78248	 0.012401	 0.022375	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10150	 10151	 0.000178	 0.001567	 0.00327	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10150	 78235	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78236	 10150	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10151	 78237	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10151	 78237	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10152	 78238	 0.043067	 0.031133	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10153	 10155	 0.000366	 0.006117	 0.00347	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78237	 10153	 0.000378	 0.006317	 0.00358	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10153	 78238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10153	 78238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10154	 78239	 0.011798	 0.02647	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10154	 78351	 0.01177	 0.039263	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10155	 10533	 0.00048	 0.005375	 0.00171	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10155	 78239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10155	 78239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10155	 78244	 0.001154	 0.017956	 0.00557	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10156	 78240	 0.010489	 0.023988	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10156	 78243	 0.013952	 0.032385	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10157	 10175	 0.00105	 0.014246	 0.00824	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10157	 78240	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10157	 78240	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10157	 78244	 0.000884	 0.011987	 0.00693	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10158	 10159	 0.000398	 0.004214	 0.00125	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78237	 10158	 0.001335	 0.010388	 0.0027	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10158	 78241	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10158	 78241	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10159	 10175	 0.000263	 0.002736	 0.00085	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10160	 10161	 0.000935	 0.010528	 0.00304	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10160	 10167	 0.001462	 0.016713	 0.0051	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10161	 78242	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10161	 78242	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78242	 10162	 0.004481	 0.01793	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10162	 78248	 0.0064	 0.024898	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10163	 10176	 0.000509	 0.00711	 0.00241	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10164	 10165	 0.000343	 0.002586	 0.00072	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10164	 10174	 0.002227	 0.016274	 0.0048	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10165	 10461	 0.002551	 0.018353	 0.00486	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10166	 10531	 0.000323	 0.003977	 0.00128	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10166	 78244	 0.000888	 0.011169	 0.00346	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10167	 10168	 0.000552	 0.006238	 0.0024	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10167	 78243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10167	 78243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10168	 78396	 0.001411	 0.017754	 0.0055	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10169	 78244	 0.000379	 0.001736	 0.00044	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10169	 78396	 0.00314	 0.013665	 0.00389	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10170	 10653	 0.000425	 0.005172	 0.01929	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10170	 78244	 0.000105	 0.008384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78245	 10170	 0.000298	 0.020873	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10171	 10173	 0.002915	 0.013896	 0.00403	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10171	 78246	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10171	 78246	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10171	 78398	 0.001391	 0.008287	 0.00218	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78246	 10172	 0.048902	 0.0387	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10173	 10174	 0.001885	 0.014688	 0.00439	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10173	 10461	 0.004738	 0.043097	 0.01088	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77769	 10173	 0.002822	 0.040088	 0.02109	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10173	 78247	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10173	 78247	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10175	 78248	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10175	 78248	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10176	 10461	 0.001176	 0.018063	 0.00505	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10177	 10178	 0.000853	 0.003915	 0.001	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10177	 78249	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10177	 78249	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10178	 10180	 0.000722	 0.003311	 0.00085	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10179	 10183	 0.00721	 0.016738	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10179	 78250	 0.004999	 0.011605	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10180	 10181	 0.000382	 0.002703	 0.00074	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10180	 78250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10180	 78250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10181	 10193	 0.000543	 0.003638	 0.00111	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10181	 78251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10181	 78251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78251	 10182	 0.027091	 0.019932	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10183	 10184	 0.004393	 0.011384	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10184	 78252	 0.009258	 0.01418	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10184	 78253	 0.018094	 0.035462	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10185	 10187	 0.000983	 0.005756	 0.00157	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10186	 78252	 0.017873	 0.011571	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10187	 10188	 0.00068	 0.004669	 0.00136	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10187	 78252	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10187	 78252	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10188	 10190	 0.000913	 0.005482	 0.00166	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10189	 78253	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10189	 78253	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10190	 78254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10190	 78254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10191	 10192	 0.022376	 0.01585	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10191	 78255	 0.010338	 0.018653	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10193	 10194	 0.000401	 0.00293	 0.00075	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10194	 10198	 0.001234	 0.006796	 0.00245	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10195	 10198	 0.001204	 0.005523	 0.00141	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10195	 78255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10195	 78255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77644	 10196	 0.010702	 0.022492	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10196	 78256	 0.009037	 0.021399	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10196	 78257	 0.040736	 0.026373	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10197	 10198	 0.001049	 0.005272	 0.00137	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10197	 10238	 0.001542	 0.00958	 0.0027	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10197	 78256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10197	 78256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10198	 10199	 0.001134	 0.007179	 0.00195	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10198	 78257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10198	 78257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10199	 10200	 0.00064	 0.004056	 0.0011	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10200	 10241	 0.001006	 0.006249	 0.00176	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10201	 10202	 0.000985	 0.005769	 0.00157	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10202	 10203	 0.001262	 0.003388	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10202	 10204	 0.000436	 0.002919	 0.00089	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10203	 78258	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10203	 78258	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10204	 10206	 0.000369	 0.002723	 0.00079	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10205	 78259	 0.022862	 0.018817	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10206	 10207	 0.000452	 0.003628	 0.00102	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10207	 10209	 0.000716	 0.006342	 0.00169	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10207	 78259	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10207	 78259	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10208	 78260	 0.013315	 0.024387	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10209	 10210	 0.002753	 0.009277	 0.00231	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10209	 10222	 0.002244	 0.011275	 0.00293	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10209	 10234	 0.000911	 0.004635	 0.00168	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10209	 10235	 0.002109	 0.013359	 0.00363	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10210	 10235	 0.002309	 0.015491	 0.00374	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10210	 78260	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10210	 78260	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10211	 10212	 0.024602	 0.01947	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10212	 10236	 0.0064	 0.028521	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77644	 10212	 0.005976	 0.021348	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10213	 10237	 0.003907	 0.014969	 0.00042	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77644	 10213	 0.004091	 0.023253	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78209	 10214	 0.005429	 0.020885	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10214	 78261	 0.002148	 0.008523	 0.00024	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10215	 10221	 0.001596	 0.005476	 0.00131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10215	 78261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10215	 78261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10216	 10217	 0.039857	 0.028233	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78208	 10216	 0.007825	 0.027396	 0.00076	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10216	 78262	 0.008238	 0.05655	 0.00103	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10218	 10219	 0.003369	 0.016351	 0.00374	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10218	 78262	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10218	 78262	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10219	 10223	 0.003494	 0.019389	 0.00589	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10219	 78263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10219	 78263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78263	 10220	 0.01821	 0.065051	 0.00129	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10220	 78267	 0.031505	 0.090361	 0.00139	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10221	 10222	 0.002231	 0.006973	 0.00202	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10223	 78264	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10223	 78264	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10224	 78281	 0.13088	 0.10358	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10225	 10233	 0.002488	 0.010125	 0.00247	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10225	 10275	 0.009111	 0.036479	 0.00919	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10225	 78265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10225	 78265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10226	 10227	 0.024567	 0.018074	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10227	 10271	 0.026523	 0.034859	 0.00048	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78265	 10227	 0.021533	 0.046145	 0.00081	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10228	 10232	 0.002168	 0.007436	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10228	 10247	 0.002401	 0.012904	 0.00317	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10228	 78266	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10228	 78266	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78266	 10229	 0.022404	 0.017561	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78266	 10230	 0.029883	 0.022922	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10231	 10232	 0.001528	 0.005945	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10231	 10233	 0.0016	 0.00629	 0.00165	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10232	 10234	 0.001088	 0.00637	 0.00174	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10232	 78267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10232	 78267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10235	 10247	 0.001316	 0.010922	 0.00287	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10235	 78268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10235	 78268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78268	 10236	 0.003923	 0.020902	 0.00037	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10237	 78269	 0.004197	 0.022362	 0.00039	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10238	 10243	 0.001331	 0.005057	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10238	 10247	 0.002639	 0.013257	 0.00345	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10238	 78269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10238	 78269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10239	 10240	 0.002236	 0.010911	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78256	 10239	 0.003922	 0.015087	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10240	 10242	 0.003694	 0.022712	 0.00041	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10241	 10259	 0.001053	 0.00632	 0.00191	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10242	 78270	 0.002775	 0.01705	 0.00039	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10243	 10244	 0.000975	 0.003904	 0.00132	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10244	 10249	 0.000862	 0.00505	 0.00138	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10244	 78270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10244	 78270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10245	 78272	 0.012046	 0.020292	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10246	 78271	 0.019475	 0.020798	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10247	 10248	 0.002086	 0.01109	 0.00257	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10247	 10270	 0.00216	 0.009911	 0.00254	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77617	 10247	 0.002883	 0.041627	 0.01322	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10247	 78271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10247	 78271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10248	 10254	 0.001188	 0.006313	 0.00146	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10248	 78272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10248	 78272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10249	 10250	 0.00097	 0.006144	 0.00167	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10249	 78273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10249	 78273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10250	 10258	 0.000736	 0.004815	 0.00122	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10250	 78274	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10250	 78274	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78274	 10251	 0.02862	 0.022434	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10252	 78277	 0.023267	 0.015629	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78272	 10253	 0.024079	 0.019056	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10254	 10255	 0.00063	 0.003751	 0.00099	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10254	 78275	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10254	 78275	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10255	 10256	 0.000436	 0.002551	 0.00069	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10256	 10267	 0.001244	 0.007881	 0.00214	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10256	 78276	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10256	 78276	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78276	 10257	 0.026225	 0.017616	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10258	 10266	 0.000788	 0.005464	 0.00156	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10258	 78277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10258	 78277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10259	 10260	 0.000574	 0.004131	 0.00109	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10260	 10261	 0.000654	 0.004211	 0.0011	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10261	 10267	 0.002861	 0.020581	 0.00545	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10262	 10264	 0.017864	 0.014137	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10263	 78278	 0.014926	 0.011812	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10264	 78279	 0.035536	 0.039085	 0.00052	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10265	 10267	 0.000454	 0.00563	 0.00244	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10265	 78282	 0.000556	 0.007213	 0.00285	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10266	 10267	 0.00086	 0.006281	 0.00161	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10266	 78278	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10266	 78278	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10267	 10276	 0.000988	 0.014841	 0.00869	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10267	 78279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10267	 78279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78279	 10268	 0.03021	 0.021838	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10269	 78280	 0.018938	 0.01226	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10270	 10272	 0.002165	 0.010876	 0.00283	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10270	 78280	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10270	 78280	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78280	 10271	 0.020951	 0.02282	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10272	 10275	 0.003374	 0.019384	 0.00549	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78275	 10273	 0.030383	 0.021522	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78271	 10274	 0.023886	 0.01692	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77658	 10275	 0.002331	 0.022846	 0.00716	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10275	 78281	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10275	 78281	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77617	 10276	 0.00035	 0.003777	 0.00202	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77658	 10276	 0.000442	 0.004688	 0.00139	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10276	 78283	 0.001658	 0.007606	 0.00195	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10277	 10279	 0.000257	 0.002984	 0.01061	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10277	 78282	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10277	 78282	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10278	 78284	 0.031956	 0.02529	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10279	 78283	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78284	 10279	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10280	 10284	 0.013887	 0.059639	 0.00109	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77659	 10280	 0.009219	 0.044482	 0.00079	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77659	 10281	 0.025583	 0.11272	 0.00196	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10282	 10283	 0.018591	 0.027089	 0.00061	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10282	 10285	 0.021565	 0.084219	 0.00187	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77618	 10282	 0.009219	 0.056678	 0.00102	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10284	 10285	 0.00638	 0.024445	 0.00069	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10285	 10289	 0.018628	 0.072467	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10285	 10289	 0.018628	 0.072467	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10286	 10288	 0.011671	 0.052005	 0.00088	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10286	 10290	 0.008334	 0.042158	 0.00073	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10287	 10288	 0.004475	 0.032207	 0.00106	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10287	 10295	 0.007321	 0.064533	 0.0014	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10288	 10298	 0.10116	 0.080063	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77618	 10288	 0.012356	 0.10494	 0.00245	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10289	 10290	 0.010347	 0.041049	 0.00117	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10289	 78285	 0.018237	 0.07016	 0.0012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10289	 78285	 0.018237	 0.07016	 0.0012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10291	 78285	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10291	 78285	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10292	 10293	 0.060297	 0.043588	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10292	 10294	 0.005548	 0.024444	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10292	 10301	 0.013896	 0.042628	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10292	 10301	 0.013896	 0.042628	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78285	 10292	 0.006469	 0.028502	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10294	 10296	 0.008078	 0.061091	 0.00203	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78285	 10294	 0.008494	 0.037847	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10295	 10296	 0.004703	 0.046091	 0.0009	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10297	 10300	 0.048141	 0.038098	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78284	 10297	 0.10735	 0.08496	 0.00107	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77862	 10299	 0.048444	 0.12272	 0.00243	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78265	 10299	 0.006795	 0.066583	 0.0013	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10302	 10397	 0.0165	 0.058946	 0.00117	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10303	 10312	 0.000404	 0.002774	 0.00081	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10303	 78286	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10303	 78286	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10303	 78312	 0.000525	 0.004503	 0.00128	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10304	 10306	 0.000282	 0.002135	 0.00105	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10304	 10324	 0.000621	 0.004491	 0.00242	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10305	 10308	 0.002124	 0.011368	 0.00034	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77963	 10305	 0.002048	 0.015363	 0.00031	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10306	 78287	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10306	 78287	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10307	 10308	 0.000837	 0.007791	 0.00015	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10307	 10309	 0.00279	 0.010855	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10307	 10309	 0.00279	 0.010855	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78287	 10308	 0.001947	 0.01301	 0.00029	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10309	 10333	 0.001074	 0.007729	 0.00025	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10309	 78289	 0.005509	 0.02143	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10310	 10335	 0.000325	 0.003712	 0.00104	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10310	 78288	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10310	 78288	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10311	 10332	 0.000186	 0.002336	 0.00072	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10311	 78289	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10311	 78289	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10311	 78312	 0.002302	 0.011349	 0.00307	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10312	 10313	 0.000507	 0.002415	 0.0007	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10312	 78290	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10312	 78290	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10313	 10316	 0.00077	 0.003532	 0.0009	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10314	 10315	 0.00394	 0.010021	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10314	 10371	 0.006153	 0.015061	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10315	 78291	 0.003727	 0.008652	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10316	 10332	 0.00051	 0.002005	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10316	 78291	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10316	 78291	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78291	 10317	 0.002311	 0.010296	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10317	 78293	 0.003505	 0.009696	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10318	 78293	 0.008895	 0.007039	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10319	 10320	 0.000913	 0.005192	 0.00016	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10319	 10344	 0.001395	 0.006696	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10320	 78308	 0.002183	 0.018161	 0.00034	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77840	 10321	 0.032516	 0.025733	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10321	 78292	 0.012215	 0.024185	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10322	 78292	 0.008156	 0.016148	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10323	 10326	 0.000397	 0.004598	 0.00246	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77805	 10323	 0.000382	 0.00402	 0.00226	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10323	 78292	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10323	 78292	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10325	 78306	 0.014075	 0.027867	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10326	 10383	 0.001039	 0.007211	 0.00206	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10326	 10386	 0.000442	 0.005993	 0.00346	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10327	 78293	 0.007527	 0.006196	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10328	 78293	 0.008661	 0.005607	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10329	 10332	 0.000305	 0.003552	 0.00104	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77635	 10329	 0.001418	 0.019831	 0.00672	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77979	 10329	 0.00156	 0.026682	 0.01447	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10329	 78293	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10329	 78293	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78293	 10330	 0.0012	 0.007376	 0.00013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10330	 78294	 0.000886	 0.005366	 0.00017	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10331	 10336	 0.001764	 0.010026	 0.00018	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10331	 10338	 0.006043	 0.006171	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10331	 10339	 0.001141	 0.005807	 0.00013	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10331	 10340	 0.002785	 0.009291	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78293	 10331	 0.00138	 0.010752	 0.0002	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10332	 78294	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10332	 78294	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10333	 78295	 0.000749	 0.00623	 0.00012	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78293	 10334	 0.005321	 0.02371	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10334	 78295	 0.001977	 0.011236	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10335	 10337	 0.00065	 0.001717	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10336	 78295	 0.000925	 0.005811	 0.00013	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10337	 78295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10337	 78295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78289	 10339	 0.00367	 0.01311	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78289	 10339	 0.00367	 0.01311	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78294	 10339	 0.000691	 0.005678	 0.00011	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10341	 78298	 0.006294	 0.011895	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10342	 78296	 0.010434	 0.008588	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10343	 10357	 0.000762	 0.002655	 0.00062	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10343	 78296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10343	 78296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10344	 78301	 0.002712	 0.01372	 0.00024	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10345	 10401	 0.010508	 0.006803	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10346	 78297	 0.005167	 0.005436	 8e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10347	 10372	 0.000962	 0.00385	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10347	 78297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10347	 78297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10348	 10349	 0.002224	 0.00991	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78292	 10348	 0.003902	 0.015011	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78297	 10348	 0.00088	 0.00541	 0.0001	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10349	 10350	 0.001159	 0.007046	 0.00013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77806	 10349	 0.001569	 0.012226	 0.00023	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10350	 10351	 0.001004	 0.006171	 0.00011	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10351	 10352	 0.00061	 0.005077	 0.0001	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10352	 78300	 0.000707	 0.006581	 0.00013	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10353	 10354	 0.00626	 0.004802	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10354	 78301	 0.003926	 0.007191	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10355	 78301	 0.004756	 0.005079	 0.00011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78296	 10356	 0.00721	 0.009476	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10357	 10358	 0.000306	 0.002167	 0.00059	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10357	 78298	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10357	 78298	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10357	 78305	 0.000791	 0.008059	 0.00208	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10358	 10360	 0.000265	 0.001517	 0.0005	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10359	 10368	 0.00542	 0.003839	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10360	 10361	 0.000357	 0.001639	 0.00042	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10360	 78299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10360	 78299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10361	 10362	 0.000289	 0.001176	 0.00029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10362	 78300	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10362	 78300	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10363	 10365	 0.002022	 0.012431	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78300	 10363	 0.000958	 0.005802	 0.00018	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10364	 10366	 0.007819	 0.018152	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10365	 10370	 0.001128	 0.008242	 0.00015	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10366	 10368	 0.002709	 0.01307	 0.00023	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10366	 10371	 0.003523	 0.008959	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10367	 10368	 0.00634	 0.005681	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78299	 10368	 0.001588	 0.006492	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10368	 78313	 0.004474	 0.02403	 0.00057	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10369	 10371	 0.003296	 0.007295	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78290	 10369	 0.001388	 0.00789	 0.00014	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10370	 10371	 0.000827	 0.005888	 0.00013	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78286	 10371	 0.002345	 0.021829	 0.00042	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10372	 78301	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10372	 78301	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10372	 78305	 0.000878	 0.011046	 0.00342	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10373	 10374	 0.000552	 0.003992	 0.00215	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10373	 78302	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10373	 78302	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10374	 78303	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10374	 78303	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78297	 10375	 0.008989	 0.009599	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10376	 10382	 0.03364	 0.086475	 0.00134	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10377	 10395	 0.001033	 0.01491	 0.00473	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10378	 10399	 0.00105	 0.007553	 0.00025	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10378	 78306	 0.00171	 0.014062	 0.00027	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77978	 10379	 0.000221	 0.002174	 0.03774	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77978	 10379	 0.000221	 0.002174	 0.03774	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10379	 78304	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78306	 10380	 0.007289	 0.005591	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78303	 10381	 0.011694	 0.022918	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78303	 10382	 0.010883	 0.033385	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10382	 78311	 0.017938	 0.096341	 0.00229	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78305	 10383	 0.002268	 0.016579	 0.00489	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10383	 78307	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10383	 78307	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78302	 10384	 0.032954	 0.023822	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10385	 10390	 0.011854	 0.020847	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10386	 10388	 0.000199	 0.003326	 0.00189	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10386	 78308	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10386	 78308	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78308	 10387	 0.028409	 0.022483	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10388	 10391	 0.000166	 0.002842	 0.00154	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78306	 10389	 0.026975	 0.020437	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78215	 10390	 0.003662	 0.020818	 0.00038	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10390	 78309	 0.005968	 0.019694	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10391	 10392	 0.000212	 0.003466	 0.00207	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10391	 78309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10391	 78309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10392	 10393	 0.000148	 0.002417	 0.00144	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77979	 10393	 0.000461	 0.007716	 0.00437	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10393	 78310	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10393	 78310	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10394	 10395	 0.000753	 0.010463	 0.00575	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10394	 10499	 0.001298	 0.013001	 0.00433	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10394	 10500	 0.001017	 0.009767	 0.00284	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10395	 10396	 0.001035	 0.007485	 0.00403	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10396	 10510	 0.003124	 0.033677	 0.018	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10396	 78311	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10396	 78311	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78311	 10397	 0.008306	 0.047215	 0.00085	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78311	 10398	 0.036272	 0.066437	 0.00115	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78298	 10399	 0.002021	 0.011357	 0.00021	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10399	 78313	 0.001727	 0.009824	 0.0003	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78304	 10400	 0.000244	 0.002631	 0.00522	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78304	 10400	 0.000244	 0.002631	 0.00522	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10400	 78312	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78313	 10400	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78296	 10401	 0.001683	 0.009569	 0.00017	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78301	 10401	 0.001752	 0.006574	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77643	 10402	 0.001421	 0.007529	 0.00251	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10403	 10404	 0.012479	 0.009781	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10404	 10405	 0.023152	 0.017034	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10404	 10406	 0.024207	 0.019157	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77623	 10404	 0.008115	 0.032473	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10404	 78713	 0.09691	 0.22952	 0.0042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77623	 10407	 0.021218	 0.035437	 0.0006	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10408	 10409	 0.000755	 0.007846	 0.00243	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10408	 78314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10408	 78314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10409	 10416	 0.001843	 0.019144	 0.00592	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10410	 10411	 0.002418	 0.009681	 0.00244	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10410	 78315	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10410	 78315	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10411	 10412	 0.002156	 0.008633	 0.00217	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77918	 10413	 0.047587	 0.048064	 0.00064	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10414	 10415	 0.00428	 0.017136	 0.00432	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10414	 10416	 0.010228	 0.027033	 0.00633	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77616	 10415	 0.006733	 0.035031	 0.01032	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10415	 78316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10415	 78316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10416	 10419	 0.005278	 0.024211	 0.0062	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10416	 10421	 0.00369	 0.01693	 0.00434	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10417	 10418	 0.001434	 0.006071	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10417	 10420	 0.002747	 0.010997	 0.00277	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10419	 10420	 0.001789	 0.007033	 0.00184	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10419	 78317	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10419	 78317	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10421	 10422	 0.00067	 0.003076	 0.00079	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10421	 78318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10421	 78318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10422	 10425	 0.002299	 0.010351	 0.00275	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78318	 10423	 0.003039	 0.014084	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10423	 78319	 0.007675	 0.040431	 0.00073	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77616	 10424	 0.004846	 0.01972	 0.0048	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77613	 10425	 0.00395	 0.021775	 0.00509	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10425	 78319	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10425	 78319	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10426	 10430	 0.000336	 0.003227	 0.00094	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10426	 78320	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10426	 78320	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78320	 10427	 0.008429	 0.005662	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78320	 10428	 0.00371	 0.013919	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78320	 10428	 0.00371	 0.013919	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10428	 78323	 0.006355	 0.022237	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10428	 78323	 0.006355	 0.022237	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78320	 10429	 0.004577	 0.009809	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10430	 10431	 0.00032	 0.003238	 0.00095	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10431	 10434	 0.000398	 0.005328	 0.00146	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10431	 78321	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10431	 78321	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78321	 10432	 0.005284	 0.023282	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10432	 78332	 0.007892	 0.029604	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78320	 10433	 0.007549	 0.014947	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10434	 10476	 0.001162	 0.005329	 0.00137	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10435	 10436	 0.000243	 0.002839	 0.00222	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10435	 10477	 0.000392	 0.005722	 0.00355	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10436	 10458	 0.000877	 0.010587	 0.006	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10436	 78322	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10436	 78322	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78322	 10437	 0.032411	 0.025649	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10438	 78324	 0.041695	 0.032997	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10439	 78323	 0.051918	 0.0508	 0.00072	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10440	 10446	 0.000342	 0.00447	 0.00178	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10440	 78323	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10440	 78323	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10441	 10443	 0.014332	 0.011342	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10441	 10465	 0.012725	 0.01386	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10441	 78324	 0.002706	 0.010526	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10442	 10474	 0.000647	 0.009662	 0.00286	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10442	 78324	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10442	 78324	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10444	 10445	 0.00011	 0.001712	 0.0006	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10444	 10446	 0.000181	 0.002911	 0.00095	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10445	 10485	 0.00071	 0.007039	 0.00216	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10445	 10486	 0.000738	 0.006282	 0.00157	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10447	 10450	 0.004159	 0.01193	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10447	 10451	 0.003033	 0.011799	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10448	 10451	 0.003145	 0.008314	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10448	 10637	 0.004674	 0.012389	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10449	 10637	 0.014013	 0.01013	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10450	 10632	 0.003308	 0.008505	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10451	 10456	 0.004646	 0.020703	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10451	 78388	 0.007949	 0.024412	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78105	 10452	 0.004045	 0.016459	 0.00401	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10452	 78325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10452	 78325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78230	 10453	 0.00473	 0.026909	 0.00083	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78325	 10453	 0.007248	 0.039916	 0.0009	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78325	 10454	 0.040726	 0.041135	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78325	 10455	 0.024592	 0.058234	 0.00106	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78325	 10456	 0.012518	 0.05578	 0.00095	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10456	 78381	 0.008078	 0.032327	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10457	 10490	 0.000982	 0.010199	 0.00315	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10458	 10463	 0.000579	 0.008654	 0.00256	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10458	 10490	 0.000307	 0.005451	 0.00274	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10458	 78326	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10458	 78326	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10459	 10490	 0.000363	 0.003716	 0.00221	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10460	 78327	 0.005194	 0.050292	 0.00101	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10460	 78336	 0.007918	 0.061712	 0.00115	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10461	 78327	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10461	 78327	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78326	 10462	 0.005543	 0.040046	 0.00076	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78327	 10462	 0.005076	 0.035176	 0.00072	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10463	 10464	 0.000705	 0.009965	 0.0033	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10466	 10469	 0.003469	 0.013346	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78167	 10466	 0.008149	 0.027185	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10467	 10468	 0.00459	 0.019427	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10467	 78328	 0.003038	 0.017268	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10468	 10493	 0.007833	 0.018548	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10469	 78328	 0.002444	 0.009987	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10470	 78328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10470	 78328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78159	 10471	 0.019419	 0.026471	 0.00059	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78143	 10473	 0.022143	 0.057389	 0.00109	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10473	 78333	 0.013581	 0.055504	 0.00112	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10474	 10483	 0.000683	 0.009854	 0.00313	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10474	 78329	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10474	 78329	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10475	 10476	 0.002202	 0.012126	 0.00438	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10475	 10480	 0.00162	 0.016667	 0.00473	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10475	 78330	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10475	 78330	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10476	 10477	 0.001892	 0.008681	 0.00222	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10478	 10479	 0.009058	 0.046093	 0.00104	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10478	 78337	 0.009098	 0.055291	 0.00102	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10479	 78331	 0.00248	 0.012548	 0.00022	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10480	 10481	 0.000767	 0.008634	 0.00227	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10480	 78331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10480	 78331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10481	 10485	 0.00042	 0.004797	 0.00146	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10481	 78332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10481	 78332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78330	 10482	 0.050161	 0.039697	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10483	 10484	 0.000487	 0.007161	 0.00219	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10484	 10486	 0.001137	 0.010585	 0.00328	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10484	 10489	 0.000363	 0.005163	 0.00272	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10484	 78333	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10484	 78333	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10485	 78334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10485	 78334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10486	 78335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10486	 78335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10487	 10488	 0.000879	 0.009316	 0.00277	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10488	 10489	 0.000539	 0.005717	 0.0017	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10489	 10492	 0.00143	 0.014707	 0.00417	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10490	 78336	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10490	 78336	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78093	 10491	 0.020753	 0.092477	 0.00157	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10491	 78337	 0.006591	 0.031639	 0.00095	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10492	 78337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10492	 78337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78107	 10493	 0.02222	 0.042553	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10494	 10495	 0.00248	 0.026755	 0.00766	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10494	 13466	 0.002418	 0.026082	 0.00747	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10495	 10498	 0.002586	 0.025339	 0.00794	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10495	 78338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10495	 78338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10496	 10502	 0.001401	 0.015116	 0.00433	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10496	 10503	 0.00081	 0.008586	 0.00255	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78338	 10497	 0.092726	 0.062288	 0.0011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10498	 10500	 0.001358	 0.011762	 0.00422	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10499	 10501	 0.000975	 0.010563	 0.0033	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10501	 10502	 0.000846	 0.008793	 0.00272	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10501	 78339	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10501	 78339	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10503	 10508	 0.002066	 0.020183	 0.00566	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10503	 10510	 0.001513	 0.021837	 0.00693	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10503	 78340	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10503	 78340	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10503	 78956	 0.017936	 0.18001	 0.06008	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10504	 10508	 0.002368	 0.025098	 0.00745	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10504	 13470	 0.002249	 0.020426	 0.00666	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10504	 78341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10504	 78341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10505	 10506	 0.012972	 0.050467	 0.00084	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10505	 10506	 0.012972	 0.050467	 0.00084	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10505	 10507	 0.013192	 0.045061	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10505	 10524	 0.006919	 0.055984	 0.00144	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10506	 78343	 0.033215	 0.12922	 0.00216	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10506	 78343	 0.033215	 0.12922	 0.00216	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10506	 78346	 0.004008	 0.024266	 0.00076	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78341	 10507	 0.014691	 0.051403	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10508	 78342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10508	 78342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10509	 10516	 0.017183	 0.05172	 0.00101	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78342	 10509	 0.01188	 0.062582	 0.00112	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10510	 78343	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10510	 78343	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10511	 10512	 0.0652	 0.051599	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78343	 10512	 0.013022	 0.029539	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10513	 10514	 0.018775	 0.014717	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10513	 10515	 0.00755	 0.030215	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78343	 10513	 0.006805	 0.038684	 0.0007	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10515	 78344	 0.00872	 0.038855	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78245	 10516	 0.081266	 0.21065	 0.00398	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10516	 78345	 0.019386	 0.055013	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10517	 10518	 0.000693	 0.011551	 0.00351	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10517	 78344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10517	 78344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10518	 10519	 0.000431	 0.003921	 0.00099	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10519	 10520	 0.001839	 0.014777	 0.00415	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10519	 78345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10519	 78345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10520	 10523	 0.001562	 0.012549	 0.00353	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10521	 78347	 0.034054	 0.02695	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10522	 10523	 0.000377	 0.003234	 0.00092	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10522	 10647	 0.005177	 0.045231	 0.01792	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10522	 78346	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10522	 78346	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10523	 78347	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10523	 78347	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10524	 79125	 0.014271	 0.12751	 0.00301	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10525	 10526	 0.045711	 0.069329	 0.00099	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78346	 10525	 0.030082	 0.055098	 0.00095	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10526	 78395	 0.036481	 0.072229	 0.00106	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10527	 10528	 0.001826	 0.008705	 0.00252	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10527	 10651	 0.002855	 0.016232	 0.0047	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10527	 78348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10527	 78348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10528	 10534	 0.001727	 0.009923	 0.00281	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10528	 78349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10528	 78349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78348	 10529	 0.011929	 0.073341	 0.00132	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10529	 78350	 0.005034	 0.028615	 0.00052	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10530	 10532	 0.00129	 0.006932	 0.00171	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10530	 78350	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10530	 78350	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10531	 10533	 0.00043	 0.005749	 0.00157	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10532	 10534	 0.000635	 0.003719	 0.00101	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10532	 78351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10532	 78351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10535	 10543	 5.4e-05	 0.000928	 0.0005	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10535	 10641	 0.00022	 0.003494	 0.00221	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10536	 78352	 0.011915	 0.007713	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10537	 10545	 0.00192	 0.004826	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10537	 10549	 0.003622	 0.009573	 0.00224	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77640	 10537	 0.000526	 0.00592	 0.00155	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10537	 78352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10537	 78352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10538	 10541	 0.000827	 0.003793	 0.00097	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10538	 10542	 9.7e-05	 0.001506	 0.00098	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77628	 10538	 0.000237	 0.00421	 0.00212	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77640	 10538	 0.000261	 0.003286	 0.00102	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10539	 78353	 0.003473	 0.006564	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10539	 78368	 0.00336	 0.006247	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10540	 10554	 0.000724	 0.002621	 0.00056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10540	 10556	 0.001473	 0.004011	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10540	 10590	 0.001052	 0.003165	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10540	 78353	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10540	 78353	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10541	 10544	 0.000431	 0.001695	 0.00044	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10541	 78354	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10541	 78354	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10542	 10543	 6.9e-05	 0.001087	 0.00069	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10544	 10545	 0.000382	 0.001577	 0.00037	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10545	 10546	 0.001122	 0.002965	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10545	 10549	 0.001714	 0.003979	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10546	 10548	 0.000955	 0.002478	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10547	 10642	 0.00155	 0.007568	 0.00016	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10547	 78355	 0.002378	 0.006821	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10548	 10550	 0.000815	 0.002116	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10549	 10550	 0.000725	 0.002626	 0.00056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10549	 10562	 0.001061	 0.00364	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10549	 78355	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10549	 78355	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10551	 10553	 0.001893	 0.007364	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78355	 10551	 0.001931	 0.00438	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10552	 10553	 0.001138	 0.004444	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10552	 78356	 0.0013	 0.006238	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10554	 10562	 0.001104	 0.006995	 0.0019	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10554	 10590	 0.001572	 0.005129	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77640	 10554	 0.002179	 0.008566	 0.00224	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10554	 78356	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10554	 78356	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10555	 10642	 0.001315	 0.004696	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78356	 10555	 0.000955	 0.004253	 7e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10556	 10558	 0.000985	 0.002557	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10557	 10583	 0.00154	 0.00967	 0.00021	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78356	 10557	 0.001124	 0.006907	 0.00012	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10558	 10573	 0.000589	 0.002786	 0.00067	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10558	 78357	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10558	 78357	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10559	 78358	 0.001623	 0.007367	 0.00016	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10560	 10561	 0.000314	 0.002055	 0.00052	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10560	 10573	 0.001611	 0.007251	 0.00193	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10560	 78358	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10560	 78358	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10561	 10562	 0.000845	 0.004318	 0.00109	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10563	 10564	 0.000654	 0.00421	 0.0011	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10563	 10570	 0.001427	 0.004438	 0.00093	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10563	 78359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10563	 78359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10564	 10565	 0.000842	 0.003428	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10564	 78360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10564	 78360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10565	 78361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10565	 78361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10566	 10567	 0.003213	 0.012499	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10566	 10567	 0.003213	 0.012499	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78361	 10566	 0.002335	 0.008632	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78361	 10566	 0.002335	 0.008632	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10567	 78362	 0.003362	 0.010314	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10567	 78362	 0.003362	 0.010314	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10568	 10574	 0.000461	 0.00363	 0.00106	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10568	 10615	 0.000606	 0.008573	 0.00284	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10568	 78362	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10568	 78362	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77661	 10569	 0.003677	 0.021443	 0.00043	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77948	 10569	 0.01	 0.025707	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78359	 10569	 0.005435	 0.013971	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10570	 10573	 0.00165	 0.004361	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77661	 10571	 0.010722	 0.010829	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10572	 78363	 0.014214	 0.010458	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77640	 10573	 0.004338	 0.014617	 0.00363	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10573	 78363	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10573	 78363	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10574	 10609	 0.000327	 0.003617	 0.00108	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10574	 78364	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10574	 78364	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78357	 10575	 0.001227	 0.011426	 0.00022	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10575	 78365	 0.001148	 0.011247	 0.00022	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10576	 10577	 0.007024	 0.007094	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10577	 78365	 0.002121	 0.005452	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10578	 10580	 0.000356	 0.00145	 0.00035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10578	 78365	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10578	 78365	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10579	 10582	 0.003852	 0.009795	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10579	 10583	 0.004167	 0.008897	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10580	 10581	 0.000553	 0.00225	 0.00055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10581	 10586	 0.000373	 0.002184	 0.00059	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10581	 78366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10581	 78366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10582	 10589	 0.006494	 0.016693	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10583	 10584	 0.002131	 0.01211	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10583	 78368	 0.002129	 0.010771	 0.00019	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10584	 10585	 0.001249	 0.006876	 0.00016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10584	 10589	 0.003576	 0.008302	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78366	 10585	 0.002782	 0.013577	 0.00023	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10585	 78369	 0.003768	 0.016792	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10586	 10587	 0.000638	 0.002423	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10586	 78367	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10586	 78367	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10587	 10588	 0.000331	 0.002418	 0.00071	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10587	 10593	 0.00034	 0.003556	 0.0012	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10588	 10593	 0.000225	 0.003247	 0.00103	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10588	 78370	 0.000434	 0.005034	 0.00269	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77641	 10589	 0.004621	 0.023515	 0.00053	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10589	 78369	 0.001353	 0.010054	 0.00024	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77640	 10590	 0.000987	 0.004017	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10590	 78368	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10590	 78368	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10591	 10598	 0.001216	 0.00581	 0.00203	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10591	 78369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10591	 78369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77627	 10592	 0.000183	 0.002052	 0.00375	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77627	 10592	 0.000183	 0.002052	 0.00375	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77637	 10592	 0.000611	 0.006733	 0.01279	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77637	 10592	 0.000611	 0.006733	 0.01279	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10592	 78370	 0.000105	 0.008384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78371	 10592	 0.000298	 0.020873	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10593	 10597	 0.000175	 0.002313	 0.00142	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10593	 78372	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10593	 78372	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10594	 10595	 0.00205	 0.007974	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10594	 10595	 0.00205	 0.007974	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10595	 78373	 0.001332	 0.012399	 0.00024	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10595	 78374	 0.000785	 0.007308	 0.00014	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10596	 10597	 0.000109	 0.001479	 0.00086	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10596	 78373	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10596	 78373	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10597	 78374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10597	 78374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10599	 10601	 0.005846	 0.022741	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10599	 10601	 0.005846	 0.022741	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78367	 10599	 0.003307	 0.012724	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78367	 10599	 0.003307	 0.012724	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10600	 10601	 0.003904	 0.011975	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10600	 10601	 0.003904	 0.011975	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78372	 10600	 0.001589	 0.014231	 0.0003	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10601	 10607	 0.004509	 0.015778	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10601	 10607	 0.004509	 0.015778	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10601	 10613	 0.002291	 0.017023	 0.00041	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78125	 10601	 0.015089	 0.079483	 0.00143	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10601	 78385	 0.008465	 0.029621	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10601	 78385	 0.008465	 0.029621	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10603	 78375	 0.003308	 0.020336	 0.00037	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10603	 78376	 0.002878	 0.015334	 0.00027	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10604	 10625	 0.000368	 0.005211	 0.00173	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10604	 10627	 0.000354	 0.002562	 0.00138	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10605	 10610	 0.000596	 0.007265	 0.0024	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10605	 78375	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10605	 78375	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10605	 78389	 0.001003	 0.015008	 0.00505	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10606	 10607	 0.002895	 0.012898	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78375	 10606	 0.002878	 0.009602	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10607	 78385	 0.005315	 0.016304	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10607	 78385	 0.005315	 0.016304	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10608	 10613	 0.002803	 0.01249	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78375	 10608	 0.002727	 0.021251	 0.0004	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10608	 78376	 0.005148	 0.016577	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10609	 10610	 0.000344	 0.003929	 0.0011	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10610	 78376	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10610	 78376	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10611	 10612	 0.001187	 0.009858	 0.00024	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78362	 10611	 0.018505	 0.042961	 0.00064	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78365	 10611	 0.00386	 0.026495	 0.00048	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10612	 10613	 0.003709	 0.013713	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10612	 10613	 0.003709	 0.013713	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10614	 78377	 0.003438	 0.017286	 0.00047	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10615	 10625	 0.000438	 0.005749	 0.00253	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10615	 78377	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10615	 78377	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78362	 10616	 0.003144	 0.021329	 0.0004	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78376	 10616	 0.00319	 0.024867	 0.00046	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78377	 10616	 0.003169	 0.018014	 0.00033	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10617	 10618	 0.000314	 0.002664	 0.0016	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10618	 10622	 0.00104	 0.008093	 0.0021	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10618	 10623	 0.001425	 0.012942	 0.00422	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10618	 78378	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10618	 78378	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78378	 10619	 0.004127	 0.016865	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10619	 78382	 0.005214	 0.022844	 0.00049	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78377	 10620	 0.001831	 0.012388	 0.00036	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78378	 10620	 0.005853	 0.022769	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78378	 10620	 0.005853	 0.022769	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10621	 78379	 0.01899	 0.015029	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78105	 10622	 0.004941	 0.042376	 0.01206	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10622	 78379	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10622	 78379	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10623	 10624	 0.000525	 0.00581	 0.00174	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10623	 78380	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10623	 78380	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10624	 10626	 0.000989	 0.008215	 0.00321	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10624	 78381	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10624	 78381	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10625	 78382	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10625	 78382	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10626	 10630	 0.001468	 0.005877	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10626	 78383	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10626	 78383	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10627	 10630	 0.000279	 0.002854	 0.0017	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10627	 78384	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10627	 78384	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10628	 10629	 0.000688	 0.005232	 0.00164	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10628	 78385	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10628	 78385	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10629	 78389	 0.000778	 0.006457	 0.0017	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10630	 10631	 0.000633	 0.004137	 0.00105	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10630	 78389	 0.001284	 0.009764	 0.00307	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10631	 10633	 0.000609	 0.003784	 0.00107	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10632	 78386	 0.002498	 0.00642	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10633	 10635	 0.000253	 0.001737	 0.00051	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10633	 78386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10633	 78386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10634	 78387	 0.019582	 0.012678	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10635	 78387	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10635	 78387	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10635	 78389	 0.000485	 0.003073	 0.00083	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10636	 10639	 0.001995	 0.012265	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78386	 10636	 0.002826	 0.010827	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10636	 78390	 0.005289	 0.014018	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10637	 78388	 0.000787	 0.004422	 8e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10638	 78388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10638	 78388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78388	 10639	 0.002061	 0.014147	 0.00026	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78104	 10640	 0.000539	 0.005131	 0.01874	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10640	 78389	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78390	 10640	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10641	 78391	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10641	 78391	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78354	 10642	 0.003027	 0.011775	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10643	 10644	 0.00018	 0.002267	 0.0007	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10643	 10663	 0.000523	 0.006215	 0.00216	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10643	 78392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10643	 78392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10644	 12989	 0.000325	 0.002978	 0.00119	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10644	 78393	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10644	 78393	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10645	 10646	 0.002985	 0.011944	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10645	 10665	 0.007092	 0.02838	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10645	 78405	 0.003317	 0.020085	 0.00063	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78393	 10646	 0.002927	 0.014285	 0.00025	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10647	 12739	 0.001971	 0.022182	 0.00641	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10647	 78394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10647	 78394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78394	 10648	 0.12765	 0.082645	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10649	 10650	 0.001627	 0.021341	 0.01024	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77694	 10649	 0.000706	 0.009314	 0.0057	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10650	 10651	 0.002079	 0.015186	 0.0039	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10650	 78396	 0.000854	 0.013108	 0.00367	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10651	 78395	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10651	 78395	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10652	 10653	 0.000211	 0.002219	 0.00464	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10652	 10653	 0.000211	 0.002219	 0.00464	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10652	 78396	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78397	 10652	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10653	 10654	 0.000631	 0.006807	 0.01351	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10653	 10654	 0.000631	 0.006807	 0.01351	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10653	 78398	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10653	 78398	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10654	 10656	 0.000593	 0.006665	 0.0122	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10654	 10656	 0.000593	 0.006665	 0.0122	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10654	 78399	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10654	 78399	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10655	 10656	 0.000208	 0.002655	 0.01037	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77768	 10655	 0.000498	 0.005371	 0.01066	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77768	 10655	 0.000498	 0.005371	 0.01066	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10655	 78400	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10655	 78400	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10656	 10660	 0.000254	 0.003833	 0.01376	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10657	 13038	 0.002519	 0.014472	 0.0041	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77698	 10657	 0.000626	 0.009365	 0.00315	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78400	 10657	 0.001283	 0.007265	 0.0018	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77767	 10658	 0.000161	 0.001625	 0.02675	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77767	 10658	 0.000161	 0.001625	 0.02675	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10658	 78401	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10658	 78401	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10658	 79131	 0.001656	 0.017536	 0.26252	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10658	 79131	 0.001656	 0.017536	 0.26252	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10659	 78402	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10659	 78402	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10659	 78403	 0.001913	 0.006382	 0.00162	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77649	 10660	 0.00222	 0.023018	 0.04958	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77649	 10660	 0.00222	 0.023018	 0.04958	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77768	 10660	 0.000968	 0.007002	 0.02906	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10660	 78403	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10660	 78403	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10661	 10662	 0.000992	 0.011502	 0.00615	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10661	 78404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10661	 78404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10662	 10663	 0.001047	 0.011578	 0.00347	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10662	 13037	 0.002334	 0.022274	 0.00903	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78401	 10663	 0.000769	 0.012816	 0.0039	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10663	 78405	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10663	 78405	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10664	 13037	 0.001676	 0.013206	 0.00386	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10664	 78406	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10664	 78406	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78406	 10665	 0.004903	 0.021846	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10666	 10668	 0.006391	 0.018842	 0.00438	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10666	 78407	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10666	 78407	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10667	 78408	 0.080345	 0.080366	 0.00109	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10668	 13821	 0.006324	 0.044728	 0.01228	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77707	 10668	 0.002391	 0.026477	 0.00861	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10669	 10671	 0.002312	 0.017908	 0.00627	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10669	 11822	 0.004858	 0.040344	 0.01578	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10670	 12157	 0.005537	 0.032431	 0.00883	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10671	 10672	 0.002569	 0.01935	 0.00537	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77707	 10672	 0.000126	 0.001071	 0.00027	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10673	 10675	 0.002464	 0.014127	 0.0047	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10674	 13824	 0.001519	 0.016299	 0.00424	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77707	 10674	 0.003371	 0.032363	 0.00941	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10674	 78408	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10674	 78408	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10675	 10676	 0.002161	 0.010489	 0.0024	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10675	 78409	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10675	 78409	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10676	 13853	 0.001399	 0.006788	 0.00155	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10677	 10678	 0.001224	 0.005708	 0.00141	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10677	 13853	 0.001025	 0.003729	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10678	 10682	 0.003894	 0.018899	 0.00432	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10679	 10680	 0.003047	 0.016236	 0.00456	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10679	 10682	 0.003069	 0.018871	 0.00544	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10679	 10684	 0.002567	 0.015927	 0.00386	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10679	 14823	 0.008282	 0.029275	 0.0066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77707	 10679	 0.007743	 0.031509	 0.00768	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10679	 78410	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10679	 78410	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10680	 10682	 0.000833	 0.004571	 0.00121	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10680	 14840	 0.015344	 0.042791	 0.00898	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10681	 78411	 0.055819	 0.042817	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10682	 78411	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10682	 78411	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10683	 10685	 0.000904	 0.005782	 0.00195	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10684	 10687	 0.003239	 0.017166	 0.00573	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10685	 10686	 0.000366	 0.002536	 0.00072	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10686	 14824	 0.015754	 0.048996	 0.01022	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77707	 10686	 0.002959	 0.019849	 0.00479	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10686	 78412	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10686	 78412	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10687	 10688	 0.003758	 0.018337	 0.00506	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10687	 14971	 0.003264	 0.021343	 0.00543	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10688	 12173	 0.004875	 0.027048	 0.00822	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10688	 78413	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10688	 78413	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10689	 10836	 0.000899	 0.007608	 0.01482	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10689	 10965	 0.001338	 0.009031	 0.01663	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10689	 78414	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78415	 10689	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10689	 78416	 0.000105	 0.001291	 0.0024	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10690	 10828	 0.000481	 0.008727	 0.08725	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10690	 11076	 0.000739	 0.008369	 0.0762	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10690	 13644	 0.000671	 0.010205	 0.18293	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10690	 78416	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78417	 10690	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10691	 10701	 0.00161	 0.004489	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10691	 10770	 0.000684	 0.002283	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10691	 78418	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10691	 78418	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10692	 10702	 0.001603	 0.005726	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78415	 10692	 0.001726	 0.006043	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 0	 -30.0	 30.0;
	10693	 78419	 0.00169	 0.00855	 0.00015	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10693	 78421	 0.001234	 0.004802	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10693	 78431	 0.007776	 0.019775	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10694	 11089	 0.002518	 0.004878	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10694	 78423	 0.005312	 0.008949	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10695	 10709	 0.001388	 0.004762	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10695	 10728	 0.002786	 0.009386	 0.00233	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78414	 10695	 0.00062	 0.00584	 0.00177	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10695	 78419	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10695	 78419	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10696	 10697	 0.000393	 0.00143	 0.00044	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10696	 11081	 0.000682	 0.002378	 0.00055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10696	 78420	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10696	 78420	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10697	 11084	 0.000295	 0.001354	 0.00035	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10698	 10700	 0.001774	 0.003802	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10698	 10702	 0.001877	 0.005759	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10698	 78421	 0.00265	 0.006153	 9e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10699	 10700	 0.003201	 0.012451	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10699	 10704	 0.005313	 0.008139	 0.00011	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10699	 11058	 0.001324	 0.00473	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78418	 10700	 0.003813	 0.006086	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10701	 78421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10701	 78421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10703	 10715	 0.001145	 0.002878	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10703	 10717	 0.000927	 0.002882	 0.0006	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10703	 10728	 0.001882	 0.008905	 0.00214	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10703	 10770	 0.000731	 0.004031	 0.00094	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78417	 10703	 0.000997	 0.009056	 0.00295	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10703	 78422	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10703	 78422	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78422	 10704	 0.004642	 0.007409	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10705	 10706	 0.004285	 0.007849	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10705	 10739	 0.011951	 0.009368	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10705	 78423	 0.001793	 0.005981	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10706	 10707	 0.006169	 0.004539	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10706	 78427	 0.008729	 0.008817	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10708	 10741	 0.004735	 0.009376	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10708	 78427	 0.002308	 0.007698	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10709	 78423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10709	 78423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10710	 10711	 0.002445	 0.00522	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10710	 78424	 0.001824	 0.005231	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10711	 11058	 0.003807	 0.008542	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78423	 10711	 0.001486	 0.005782	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10712	 10714	 0.007218	 0.005712	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10713	 10714	 0.003452	 0.008873	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10713	 10727	 0.002813	 0.006382	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10714	 10722	 0.007403	 0.005803	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10714	 78424	 0.002703	 0.007752	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10715	 10717	 0.001434	 0.003455	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10715	 10842	 0.000665	 0.002661	 0.0009	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10715	 78455	 0.002956	 0.009958	 0.00247	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10716	 11086	 0.004597	 0.009102	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78422	 10716	 0.002376	 0.007297	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10717	 78424	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10717	 78424	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10718	 10721	 0.011294	 0.008938	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10718	 10723	 0.008037	 0.00806	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10718	 11086	 0.006011	 0.011009	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10719	 10723	 0.015772	 0.011401	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10719	 10837	 0.013053	 0.016402	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10719	 10844	 0.006356	 0.014537	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78422	 10719	 0.009746	 0.023078	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10720	 10723	 0.005183	 0.009048	 0.00014	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10720	 11078	 0.016639	 0.013043	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10720	 78456	 0.008301	 0.01091	 0.00015	 45.0	 45.0	 45.0	 0.0	 0.0	 0	 -30.0	 30.0;
	10721	 10722	 0.006038	 0.004277	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10724	 10726	 0.000738	 0.001981	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10724	 78425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10724	 78425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10724	 78455	 0.001789	 0.005182	 0.00125	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78425	 10725	 0.010368	 0.008205	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10726	 10728	 0.000751	 0.001743	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10726	 78426	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10726	 78426	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78426	 10727	 0.002632	 0.006694	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10728	 10742	 0.001227	 0.005954	 0.00136	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10728	 78427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10728	 78427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10729	 11057	 0.011543	 0.008344	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10730	 10732	 0.008668	 0.005612	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10731	 10732	 0.004279	 0.008472	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10731	 10734	 0.012908	 0.009331	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10732	 11057	 0.00797	 0.020487	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 0	 -30.0	 30.0;
	78427	 10732	 0.003039	 0.010138	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10733	 10734	 0.005977	 0.004585	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10735	 78428	 0.008076	 0.006391	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10736	 11047	 0.011737	 0.007598	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10736	 11052	 0.001744	 0.007126	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10736	 78428	 0.00162	 0.011117	 0.0002	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10737	 11051	 0.003215	 0.008265	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10737	 11053	 0.004702	 0.009622	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78423	 10738	 0.012354	 0.012478	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10740	 10741	 0.006738	 0.010322	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10740	 10747	 0.012941	 0.011675	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10742	 78428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10742	 78428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10743	 11087	 0.008717	 0.006898	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78428	 10743	 0.009352	 0.007173	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10744	 11079	 0.002026	 0.008925	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78423	 10744	 0.004996	 0.02542	 0.00058	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10744	 78429	 0.005357	 0.013771	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10745	 11002	 0.004803	 0.009199	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10745	 11003	 0.005166	 0.008616	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10745	 11048	 0.00275	 0.006966	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10745	 11079	 0.001506	 0.006026	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10746	 11001	 0.002256	 0.010886	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10746	 78429	 0.002338	 0.011281	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10747	 78430	 0.00617	 0.012092	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10748	 10750	 0.001126	 0.003319	 0.00077	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10748	 78429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10748	 78429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10749	 10750	 0.000866	 0.002507	 0.0006	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10749	 11081	 0.000808	 0.002524	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10750	 78430	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10750	 78430	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10751	 10752	 0.007652	 0.007814	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10751	 11055	 0.011471	 0.008799	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10752	 78518	 0.002835	 0.00813	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78414	 10753	 0.000274	 0.001635	 0.00043	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10753	 78431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10753	 78431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10754	 10755	 0.011151	 0.00874	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78431	 10754	 0.008081	 0.008887	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10756	 10759	 0.012799	 0.010129	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10757	 10760	 0.001088	 0.003791	 0.00088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78417	 10757	 0.000955	 0.003823	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10757	 78432	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10757	 78432	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10758	 78514	 0.019486	 0.014763	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78432	 10759	 0.010119	 0.008008	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10760	 78433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10760	 78433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10761	 11060	 0.007323	 0.018824	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78433	 10761	 0.003385	 0.011293	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10762	 10763	 0.006733	 0.017307	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10762	 10765	 0.013868	 0.014007	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78433	 10762	 0.004076	 0.018164	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10763	 10764	 0.013785	 0.010909	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10763	 10796	 0.009737	 0.012671	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10763	 10944	 0.01441	 0.011403	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78431	 10763	 0.076521	 0.055318	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10765	 10912	 0.008098	 0.008648	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10766	 10898	 0.000995	 0.003022	 0.00066	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10766	 11061	 0.001038	 0.002825	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10766	 11066	 0.001121	 0.003964	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10767	 10912	 0.003878	 0.012936	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10767	 78481	 0.002464	 0.010918	 0.00033	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10768	 11062	 0.001295	 0.004441	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10768	 11063	 0.001026	 0.003714	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77729	 10768	 0.000347	 0.004511	 0.0013	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10768	 78434	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10768	 78434	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10769	 10772	 0.004381	 0.003467	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10769	 78515	 0.006689	 0.005068	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10770	 10771	 0.000401	 0.001523	 0.00043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10770	 78435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10770	 78435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10771	 10781	 0.000405	 0.001998	 0.00054	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10771	 78436	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10771	 78436	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78434	 10773	 0.001021	 0.00524	 0.0001	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10773	 78437	 0.002086	 0.01018	 0.00018	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10774	 78437	 0.010619	 0.008404	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10775	 10778	 0.000665	 0.002282	 0.00055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10775	 10785	 0.001004	 0.003446	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10776	 10777	 0.010038	 0.010139	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10776	 11080	 0.005072	 0.00777	 0.00011	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10777	 78438	 0.020202	 0.013079	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10778	 10846	 0.001209	 0.003639	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10779	 10780	 0.000349	 0.001722	 0.00047	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10779	 10781	 0.000557	 0.003423	 0.00099	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10779	 78437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10779	 78437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10780	 10786	 0.000513	 0.002575	 0.00067	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10780	 78438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10780	 78438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10781	 78439	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10781	 78439	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10782	 10783	 0.000254	 0.002073	 0.00056	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10782	 10857	 0.000269	 0.00224	 0.00068	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10783	 10785	 0.000615	 0.002416	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10783	 10786	 0.000893	 0.002294	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10784	 78440	 0.012346	 0.009771	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10786	 11085	 0.00047	 0.003434	 0.00088	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10786	 78440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10786	 78440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10787	 10788	 0.011054	 0.008748	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10787	 78513	 0.01739	 0.012794	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10789	 10790	 0.011527	 0.008333	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10789	 10796	 0.016281	 0.01054	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10790	 10791	 0.018993	 0.013974	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10790	 10948	 0.024267	 0.019205	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10790	 10950	 0.019369	 0.015328	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78431	 10790	 0.018471	 0.033199	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10791	 10795	 0.00898	 0.009876	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10791	 10942	 0.016761	 0.018256	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10792	 10950	 0.003674	 0.007274	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10792	 11060	 0.003202	 0.00823	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10793	 10794	 0.001967	 0.005199	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10793	 10954	 0.000611	 0.003582	 0.00098	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10793	 78493	 0.000756	 0.005344	 0.00147	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10794	 78441	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10794	 78441	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10795	 10797	 0.004022	 0.007883	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10797	 10944	 0.006638	 0.013142	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10798	 10799	 0.002349	 0.009557	 0.00233	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10798	 11108	 0.003555	 0.012194	 0.00292	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10798	 78442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10798	 78442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10799	 10801	 0.001174	 0.004027	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10799	 78443	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10799	 78443	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10800	 10805	 0.057733	 0.04569	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10800	 78444	 0.008298	 0.016262	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10801	 10802	 0.001057	 0.004233	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10801	 78444	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10801	 78444	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10802	 13687	 0.000986	 0.004014	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10802	 78445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10802	 78445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10803	 10804	 0.035846	 0.025392	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77705	 10803	 0.006722	 0.035968	 0.00109	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78445	 10803	 0.009782	 0.024878	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10806	 78450	 0.04059	 0.080365	 0.00118	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10807	 78450	 0.019121	 0.03052	 0.0007	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10808	 10810	 0.003927	 0.015721	 0.00396	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10808	 78446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10808	 78446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10809	 10821	 0.007586	 0.033803	 0.00057	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78446	 10809	 0.004982	 0.030275	 0.00056	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10810	 10811	 0.002695	 0.010593	 0.00277	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10810	 10812	 0.004217	 0.016575	 0.00434	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10810	 11486	 0.003986	 0.021949	 0.00792	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10810	 78478	 0.012745	 0.046153	 0.0099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10810	 79423	 0.015331	 0.10289	 0.02485	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10811	 10812	 0.001673	 0.007079	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10812	 10813	 0.004927	 0.013022	 0.00305	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10812	 78447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10812	 78447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10812	 78537	 0.00291	 0.033866	 0.00996	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10813	 10814	 0.003728	 0.010008	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10814	 10864	 0.003217	 0.008501	 0.00199	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10815	 10820	 0.002711	 0.008232	 0.0018	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10815	 10852	 0.004638	 0.019629	 0.00442	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10816	 10817	 0.022675	 0.017944	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10816	 78448	 0.007659	 0.017781	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10818	 10864	 0.002959	 0.01204	 0.00293	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10818	 78448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10818	 78448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10819	 10838	 0.007049	 0.03141	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78448	 10819	 0.004955	 0.030116	 0.00056	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10820	 78449	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10820	 78449	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10821	 10823	 0.016695	 0.031042	 0.00073	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10822	 10823	 0.010892	 0.036333	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78449	 10822	 0.005736	 0.02983	 0.00065	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10823	 78450	 0.01827	 0.065266	 0.0013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10824	 10830	 0.003844	 0.011512	 0.00259	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10824	 78450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10824	 78450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10825	 10834	 0.013326	 0.034256	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10825	 10841	 0.01733	 0.041038	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77684	 10826	 0.00552	 0.016952	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10827	 10830	 0.002924	 0.011897	 0.0029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77683	 10827	 0.000195	 0.001969	 0.00058	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77704	 10827	 0.000322	 0.002329	 0.00125	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10828	 78451	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78452	 10828	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 0	 -30.0	 30.0;
	77684	 10829	 0.014937	 0.00967	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10830	 11031	 0.001559	 0.006345	 0.00155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77683	 10830	 0.002658	 0.010642	 0.00268	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10830	 78455	 0.003602	 0.023202	 0.00608	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10831	 11018	 0.012693	 0.020261	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10831	 11027	 0.025858	 0.019025	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10831	 78454	 0.012687	 0.016511	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10832	 10836	 0.000391	 0.004251	 0.00924	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10832	 78453	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78454	 10832	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10833	 78456	 0.007221	 0.023251	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10833	 78458	 0.003418	 0.014611	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78454	 10834	 0.009045	 0.030174	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10835	 11077	 0.0021	 0.010625	 0.00018	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10835	 78456	 0.002497	 0.013753	 0.00031	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10836	 11158	 0.002124	 0.019471	 0.07688	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10836	 78455	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78456	 10836	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 10841	 0.008321	 0.020367	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10839	 10840	 0.001376	 0.004279	 0.00089	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10839	 10843	 0.001396	 0.004117	 0.00096	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10839	 78457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10839	 78457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10840	 78458	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10840	 78458	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10842	 10846	 0.000994	 0.003978	 0.001	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10842	 78459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10842	 78459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10843	 10849	 0.001351	 0.004506	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78459	 10844	 0.00319	 0.014783	 0.00028	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78436	 10845	 0.002956	 0.007661	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78459	 10845	 0.004798	 0.011139	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10846	 78460	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10846	 78460	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10847	 78461	 0.012395	 0.024541	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10848	 78463	 0.01676	 0.016928	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10849	 10852	 0.001513	 0.005504	 0.00169	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10849	 78461	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10849	 78461	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10850	 78462	 0.022405	 0.02241	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10851	 10852	 0.000589	 0.002141	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10851	 10856	 0.001055	 0.004226	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10851	 78462	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10851	 78462	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10852	 10853	 0.001532	 0.009867	 0.00259	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10852	 78463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10852	 78463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10852	 78478	 0.002409	 0.021911	 0.00553	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10852	 79423	 0.015018	 0.096775	 0.02538	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10853	 10856	 0.000792	 0.003633	 0.00093	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10853	 10858	 0.000481	 0.002556	 0.00059	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10853	 10859	 0.002026	 0.005259	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10853	 10895	 0.002652	 0.009241	 0.00214	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10854	 78465	 0.031193	 0.024685	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10855	 78464	 0.01779	 0.014079	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10856	 78464	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10856	 78464	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10857	 10859	 0.000196	 0.001679	 0.00048	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10858	 10860	 0.00054	 0.0028	 0.00068	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10859	 10895	 0.000506	 0.003934	 0.00102	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10859	 78465	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10859	 78465	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10860	 10862	 0.000579	 0.003002	 0.00073	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10860	 78466	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10860	 78466	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78466	 10861	 0.011175	 0.008844	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10862	 10863	 0.000896	 0.003793	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10862	 78478	 0.000985	 0.00565	 0.00188	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10863	 78467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10863	 78467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10863	 78478	 0.000686	 0.003269	 0.00095	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10864	 78478	 0.001679	 0.010812	 0.00283	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10865	 11139	 0.058998	 0.046246	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10866	 10867	 0.000359	 0.004518	 0.0014	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10866	 10872	 0.000546	 0.005786	 0.00172	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10867	 10869	 0.000534	 0.003757	 0.00214	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10867	 78468	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10867	 78468	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10868	 10869	 0.00064	 0.003319	 0.00081	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10868	 11142	 0.001712	 0.005352	 0.00155	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10868	 11147	 0.0017	 0.010279	 0.00262	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10868	 78552	 0.0026	 0.014269	 0.00377	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10868	 79423	 0.02087	 0.13229	 0.03594	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10869	 78469	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10869	 78469	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10869	 78471	 0.003146	 0.008315	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10869	 78552	 0.001958	 0.014749	 0.00409	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78469	 10870	 0.023226	 0.01679	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10871	 78470	 0.017735	 0.013604	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10872	 78470	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10872	 78470	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10872	 78478	 0.001392	 0.011937	 0.0034	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10873	 10874	 0.000235	 0.002094	 0.00424	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10873	 11158	 0.000896	 0.008292	 0.0156	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10873	 78471	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10873	 78471	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10874	 78472	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78473	 10874	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10875	 11149	 0.003111	 0.01048	 0.0026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78471	 10875	 0.002293	 0.007865	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78473	 10876	 0.012907	 0.033179	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10877	 10878	 0.001284	 0.017953	 0.00609	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10877	 10880	 0.002557	 0.012101	 0.00291	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10877	 78478	 0.004197	 0.016497	 0.00432	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10878	 11150	 0.002503	 0.019039	 0.00598	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10878	 78474	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10878	 78474	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10879	 10880	 0.002069	 0.007493	 0.00161	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10879	 78475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10879	 78475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78475	 10881	 0.041824	 0.032784	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10882	 10883	 0.009866	 0.02509	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10882	 78476	 0.014998	 0.030693	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77691	 10883	 0.33351	 0.26404	 0.00332	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10883	 78476	 0.024304	 0.057552	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10883	 79402	 0.009871	 0.034562	 0.00096	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10884	 13622	 0.014655	 0.034018	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10884	 78476	 0.11586	 0.075015	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10884	 78483	 0.008441	 0.02421	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10885	 10886	 0.016845	 0.01333	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10886	 10907	 0.004757	 0.016644	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10886	 10926	 0.00491	 0.014083	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10886	 78476	 0.022002	 0.045025	 0.00111	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10887	 78476	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10887	 78476	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10887	 78478	 0.009147	 0.032333	 0.00729	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10888	 78479	 0.03308	 0.021416	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10889	 10893	 0.001384	 0.007371	 0.00207	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10889	 78478	 0.001731	 0.01096	 0.00297	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10890	 78478	 0.005586	 0.019164	 0.00459	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10891	 11073	 0.017789	 0.013944	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10892	 78479	 0.021226	 0.023346	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10893	 11066	 0.001427	 0.005806	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10894	 78477	 0.000131	 0.010475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10894	 78477	 0.000131	 0.010475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10895	 10896	 0.000929	 0.002795	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78478	 10895	 0.000967	 0.006473	 0.00407	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10896	 10897	 0.000675	 0.002352	 0.00055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10897	 10899	 0.001203	 0.003547	 0.00083	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10898	 10900	 0.00063	 0.001807	 0.00044	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77729	 10899	 0.001321	 0.003545	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10900	 78480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10900	 78480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10901	 11073	 0.01808	 0.014172	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78480	 10901	 0.009651	 0.008648	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10902	 10903	 0.01375	 0.010882	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10902	 11064	 0.025848	 0.020261	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10903	 10910	 0.0056	 0.014396	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78475	 10903	 0.033989	 0.0771	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10904	 10910	 0.013605	 0.013741	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10904	 10911	 0.026663	 0.021101	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78480	 10904	 0.009975	 0.031988	 0.00079	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10905	 11067	 0.001362	 0.004813	 0.00108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10905	 78481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10905	 78481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10906	 10907	 0.012817	 0.015625	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10906	 10910	 0.017653	 0.01783	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10907	 10923	 0.006311	 0.014315	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10907	 10924	 0.024918	 0.016132	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10908	 10909	 0.008247	 0.006787	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10908	 10910	 0.009313	 0.021617	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10908	 10916	 0.003718	 0.009557	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78481	 10908	 0.012023	 0.022724	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10912	 10913	 0.010062	 0.007963	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10912	 10914	 0.011266	 0.008288	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10914	 10915	 0.00982	 0.00744	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10915	 10917	 0.016302	 0.011548	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10915	 78482	 0.012202	 0.010044	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10916	 10917	 0.013024	 0.014325	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10918	 10937	 0.001513	 0.00422	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10918	 78482	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10918	 78482	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78482	 10919	 0.020167	 0.015959	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10920	 10921	 0.019034	 0.015063	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10920	 78485	 0.019755	 0.015485	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10921	 10923	 0.011804	 0.012605	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10921	 78489	 0.03903	 0.030887	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10922	 10923	 0.016176	 0.014495	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78481	 10922	 0.037856	 0.038654	 0.0006	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10924	 10925	 0.02759	 0.017862	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10925	 78487	 0.011168	 0.022111	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10926	 78483	 0.00773	 0.021936	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10927	 10928	 0.001877	 0.005112	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10927	 78483	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10927	 78483	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10928	 13633	 0.004611	 0.015816	 0.00379	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10928	 78484	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10928	 78484	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10929	 10930	 0.001162	 0.003164	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10929	 78485	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10929	 78485	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10930	 10932	 0.000914	 0.003718	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10930	 10937	 0.00357	 0.009956	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10930	 78486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10930	 78486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10931	 10932	 0.001859	 0.004672	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10931	 78487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10931	 78487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10932	 10936	 0.00085	 0.004127	 0.00094	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10933	 10934	 0.014512	 0.010677	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10934	 13630	 0.013246	 0.030747	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10934	 78488	 0.006807	 0.023251	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78486	 10935	 0.007382	 0.018977	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10935	 78491	 0.014449	 0.028607	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10936	 10971	 0.003072	 0.012299	 0.0031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10936	 78488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10936	 78488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10937	 10938	 0.000705	 0.002077	 0.00048	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77729	 10937	 0.006968	 0.027385	 0.00716	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10937	 78489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10937	 78489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10938	 78490	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10938	 78490	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10939	 10946	 0.013934	 0.018314	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78490	 10939	 0.005807	 0.009269	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10940	 10941	 0.009125	 0.017883	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78490	 10940	 0.007176	 0.018447	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10941	 10942	 0.010048	 0.018405	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10941	 10947	 0.018684	 0.013506	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10941	 78491	 0.009783	 0.017584	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10942	 10943	 0.003533	 0.006569	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10943	 10949	 0.026487	 0.020961	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10943	 78494	 0.016384	 0.035111	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78490	 10944	 0.005218	 0.015704	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10945	 78491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10945	 78491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10945	 78517	 0.009142	 0.02298	 0.00595	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78491	 10946	 0.011913	 0.015503	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10950	 11056	 0.014685	 0.011621	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10951	 11059	 0.005889	 0.013672	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10951	 11065	 0.013726	 0.021027	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78441	 10951	 0.004357	 0.012497	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10952	 10953	 0.004514	 0.011605	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10952	 11059	 0.007802	 0.015967	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10953	 10955	 0.003486	 0.015358	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10953	 10956	 0.002673	 0.009353	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10953	 11001	 0.005327	 0.013692	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78419	 10953	 0.019109	 0.057515	 0.00112	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10954	 78492	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10954	 78492	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78492	 10955	 0.001936	 0.010067	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10956	 10997	 0.003789	 0.014578	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10957	 10959	 0.025589	 0.019387	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10958	 10989	 0.006203	 0.020693	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10958	 11041	 0.003999	 0.015385	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10959	 11041	 0.014629	 0.011467	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10960	 10963	 0.007795	 0.022119	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10960	 11041	 0.013806	 0.032692	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10960	 11044	 0.005214	 0.012106	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10960	 78502	 0.005721	 0.032518	 0.00059	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10961	 10962	 0.002869	 0.010045	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78492	 10961	 0.003261	 0.013329	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78492	 10963	 0.004924	 0.019154	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10964	 11041	 0.017036	 0.018737	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10965	 78493	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78494	 10965	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10965	 78516	 0.001338	 0.009124	 0.01643	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10966	 78495	 0.005999	 0.026429	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10966	 78502	 0.019263	 0.037752	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10967	 10972	 0.002868	 0.008044	 0.00207	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78493	 10967	 0.003555	 0.009394	 0.0022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10967	 78495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10967	 78495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78491	 10968	 0.006862	 0.017452	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78495	 10968	 0.016164	 0.017778	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78488	 10969	 0.012709	 0.02293	 0.00033	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10969	 78496	 0.010555	 0.030272	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78488	 10970	 0.010526	 0.027058	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10970	 78497	 0.020696	 0.036397	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10971	 78496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10971	 78496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10972	 78497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10972	 78497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10972	 78517	 0.003029	 0.010392	 0.00249	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10973	 78498	 0.042778	 0.033854	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10974	 10975	 0.000356	 0.002648	 0.00101	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10974	 10985	 0.001434	 0.00492	 0.00118	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10974	 78498	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10974	 78498	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10974	 78517	 0.001169	 0.011225	 0.00327	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10975	 10976	 0.000288	 0.002516	 0.00069	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10976	 10977	 0.000477	 0.004732	 0.00129	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77722	 10977	 0.000839	 0.008057	 0.00234	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77687	 10978	 0.001543	 0.017483	 0.15927	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10978	 78499	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10978	 78499	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10979	 10980	 0.001632	 0.0082	 0.00213	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10979	 10981	 0.001739	 0.00798	 0.00204	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10979	 78500	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10979	 78500	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10980	 79412	 0.003401	 0.017385	 0.00474	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10981	 13725	 0.001858	 0.009181	 0.00268	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10981	 78501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10981	 78501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78498	 10982	 0.034943	 0.027653	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10983	 10986	 0.00549	 0.018313	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10983	 10987	 0.036239	 0.027797	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77773	 10983	 0.00424	 0.024105	 0.00044	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10984	 78502	 0.018617	 0.014593	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10985	 78502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10985	 78502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10986	 11043	 0.00411	 0.011788	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10986	 11044	 0.006399	 0.014702	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10988	 11074	 0.035861	 0.025402	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10988	 13724	 0.017696	 0.041076	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10988	 78512	 0.005891	 0.028746	 0.0005	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10989	 10991	 0.008088	 0.016552	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10990	 10991	 0.004241	 0.010526	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10990	 11075	 0.006586	 0.01693	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10991	 10992	 0.0159	 0.020236	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10992	 10994	 0.006246	 0.020836	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10992	 11009	 0.016245	 0.017868	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10992	 78505	 0.012374	 0.031469	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10993	 10994	 0.002688	 0.010457	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10996	 10997	 0.004201	 0.008829	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10996	 11005	 0.00514	 0.010176	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10998	 10999	 0.007099	 0.008654	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10999	 11000	 0.004064	 0.007964	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10999	 11001	 0.002525	 0.011253	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10999	 11005	 0.003368	 0.013103	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11000	 11004	 0.002983	 0.007668	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11001	 11002	 0.011401	 0.011156	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11002	 11003	 0.007115	 0.005631	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11004	 11050	 0.002587	 0.00658	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11005	 11006	 0.002566	 0.010487	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11006	 11007	 0.004183	 0.014646	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11007	 11009	 0.008241	 0.023635	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11007	 11021	 0.008172	 0.016723	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11007	 78503	 0.004634	 0.017756	 0.0005	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11008	 11024	 0.002228	 0.005887	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11008	 78503	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11008	 78503	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11009	 11071	 0.013124	 0.010386	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11010	 11035	 0.040793	 0.031975	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78503	 11011	 0.004484	 0.017445	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11011	 78505	 0.005855	 0.014889	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11012	 11013	 0.00122	 0.004963	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11012	 11016	 0.003893	 0.010288	 0.00241	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11012	 13705	 0.00814	 0.051562	 0.014	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11012	 78504	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11012	 78504	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77683	 11013	 0.00473	 0.034545	 0.00888	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11013	 78505	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11013	 78505	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11014	 11015	 0.010595	 0.025088	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11014	 13710	 0.011002	 0.03375	 0.00091	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11014	 78506	 0.007556	 0.02167	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11015	 11017	 0.011317	 0.026273	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11015	 13711	 0.010063	 0.02068	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11016	 11037	 0.002161	 0.00728	 0.00181	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11016	 78506	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11016	 78506	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78505	 11017	 0.004649	 0.009514	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11018	 11088	 0.007339	 0.018866	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11019	 11053	 0.012902	 0.016957	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11019	 78507	 0.020125	 0.021921	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78453	 11020	 0.004473	 0.011497	 0.00285	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11020	 78507	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11020	 78507	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78454	 11021	 0.009429	 0.057971	 0.00104	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11022	 11024	 0.002375	 0.006376	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11022	 11026	 0.002277	 0.006112	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11022	 78508	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11022	 78508	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78508	 11023	 0.028255	 0.020788	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11025	 11028	 0.029203	 0.023111	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11026	 11032	 0.003474	 0.011331	 0.00301	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11026	 78509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11026	 78509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11028	 78510	 0.012556	 0.02486	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11029	 78510	 0.014875	 0.01166	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11030	 11031	 0.000816	 0.003266	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78453	 11030	 0.00144	 0.00586	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11031	 78510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11031	 78510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11032	 11034	 0.002167	 0.010106	 0.0025	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78452	 11032	 0.000612	 0.004917	 0.00138	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11033	 78511	 0.049376	 0.039076	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11034	 11036	 0.002301	 0.008953	 0.00239	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11034	 78511	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11034	 78511	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78509	 11035	 0.024946	 0.047148	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78511	 11035	 0.026198	 0.026204	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11036	 13708	 0.000959	 0.003961	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11037	 13708	 0.001406	 0.004232	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11038	 11041	 0.001467	 0.006498	 0.00015	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11038	 11043	 0.003252	 0.010732	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11038	 11045	 0.002272	 0.006681	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11039	 11042	 0.016452	 0.010651	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11040	 78512	 0.020947	 0.016577	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11042	 11045	 0.002253	 0.006911	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11042	 78512	 0.001554	 0.008345	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11046	 78512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11046	 78512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11048	 11049	 0.002776	 0.007136	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11049	 11050	 0.003246	 0.007688	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11049	 11052	 0.002609	 0.006707	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11050	 11053	 0.028354	 0.020085	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11050	 11054	 0.010858	 0.007849	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11051	 11052	 0.00223	 0.00528	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11057	 11088	 0.006003	 0.011764	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78419	 11058	 0.009861	 0.012241	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78429	 11059	 0.013247	 0.018805	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78430	 11059	 0.006127	 0.015878	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78431	 11060	 0.035002	 0.0277	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77729	 11061	 0.000813	 0.002789	 0.00067	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11061	 78513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11061	 78513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11062	 11067	 0.001129	 0.0034	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11062	 78514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11062	 78514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11063	 11068	 0.000915	 0.002844	 0.00059	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11063	 78515	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11063	 78515	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78480	 11064	 0.009705	 0.015491	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11065	 78518	 0.011679	 0.038962	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78417	 11068	 0.00137	 0.003523	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78468	 11069	 0.057471	 0.041545	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78479	 11070	 0.033722	 0.026687	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11072	 13615	 0.037019	 0.061739	 0.0009	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11072	 13616	 0.017572	 0.040187	 0.00098	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78475	 11072	 0.023664	 0.039307	 0.00083	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78505	 11075	 0.023678	 0.042559	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11076	 78516	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78517	 11076	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11077	 11088	 0.004138	 0.009506	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78454	 11077	 0.006172	 0.021609	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78440	 11080	 0.008737	 0.012176	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78434	 11082	 0.004763	 0.005188	 7e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78432	 11083	 0.008443	 0.006104	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78414	 11084	 0.000708	 0.004401	 0.00124	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11084	 78518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11084	 78518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77729	 11085	 7.3e-05	 0.000586	 0.00016	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78419	 11089	 0.002197	 0.005647	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11090	 12235	 0.010152	 0.041918	 0.00992	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11091	 11706	 0.008277	 0.028847	 0.00669	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11091	 78519	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11091	 78519	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78519	 11092	 0.19722	 0.1513	 0.00203	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11092	 78651	 0.17879	 0.1415	 0.00178	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11093	 11094	 0.007917	 0.021255	 0.00482	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11093	 11476	 0.008361	 0.022098	 0.00517	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11094	 11100	 0.002584	 0.010346	 0.00261	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11095	 11100	 0.00661	 0.022272	 0.00554	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11096	 78527	 0.14128	 0.12661	 0.00259	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11097	 11102	 0.004253	 0.03008	 0.00825	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11097	 78526	 0.003819	 0.022923	 0.00694	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11098	 78521	 0.011226	 0.022226	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11099	 11133	 0.004384	 0.043124	 0.14811	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11099	 78520	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78521	 11099	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11099	 78525	 0.002119	 0.015789	 0.03007	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11099	 78739	 0.00523	 0.051462	 0.17686	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78520	 11100	 0.002671	 0.015647	 0.00426	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11101	 11478	 0.00736	 0.043108	 0.01174	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78520	 11101	 0.00496	 0.019859	 0.005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11101	 78522	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11101	 78522	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11102	 11108	 0.002819	 0.016514	 0.0045	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11102	 13697	 0.004199	 0.011098	 0.0026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11102	 78523	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11102	 78523	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11103	 79424	 0.049858	 0.054306	 0.00074	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11104	 79424	 0.015926	 0.011513	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11105	 11106	 0.000344	 0.006028	 0.06449	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11105	 13699	 0.000257	 0.00297	 0.02603	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11105	 78524	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11105	 78524	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77673	 11106	 0.000118	 0.001377	 0.0131	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77679	 11106	 0.00089	 0.010122	 0.09143	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11106	 78525	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11107	 13697	 0.002703	 0.007256	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11107	 13698	 0.00401	 0.009665	 0.00273	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11108	 78528	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11108	 78528	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11109	 11110	 0.004599	 0.019466	 0.00438	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11109	 12425	 0.003992	 0.025285	 0.00686	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11109	 25198	 0.001429	 0.015142	 0.00449	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11109	 78529	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11109	 78529	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11110	 11127	 0.005202	 0.021477	 0.00508	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11111	 11113	 0.002016	 0.012007	 0.00316	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11111	 78534	 0.004527	 0.029604	 0.00753	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11112	 11114	 0.00041	 0.003231	 0.00094	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11112	 11125	 0.001256	 0.010088	 0.00284	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11113	 11114	 0.000717	 0.006026	 0.00178	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11113	 11154	 0.003873	 0.015223	 0.00398	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11113	 11159	 0.001867	 0.012527	 0.00302	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11113	 78530	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11113	 78530	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11114	 11117	 0.00282	 0.008768	 0.00183	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11114	 78531	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11114	 78531	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78531	 11115	 0.01138	 0.008373	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11116	 78532	 0.019727	 0.015463	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11117	 11155	 0.001443	 0.0051	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11117	 78532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11117	 78532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78532	 11118	 0.039247	 0.031059	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11119	 11157	 0.003992	 0.015529	 0.00415	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11119	 11485	 0.004024	 0.015296	 0.00428	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11120	 11121	 0.000775	 0.004326	 0.00111	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11120	 11157	 0.000724	 0.003533	 0.00098	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11120	 78533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11120	 78533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11121	 11122	 0.000422	 0.002425	 0.00069	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11122	 11123	 0.000738	 0.004176	 0.00104	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11123	 11125	 0.001503	 0.006361	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11123	 11155	 0.002672	 0.010395	 0.00278	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11124	 11125	 0.000576	 0.007841	 0.0028	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11124	 78534	 0.000834	 0.01145	 0.00413	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11125	 78537	 0.001452	 0.013183	 0.0043	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77678	 11126	 0.000241	 0.002704	 0.00495	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77678	 11126	 0.000241	 0.002704	 0.00495	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11126	 78534	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11126	 78534	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11126	 78549	 0.000262	 0.004538	 0.01541	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11127	 11128	 0.003709	 0.014431	 0.00385	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77675	 11128	 0.00164	 0.006771	 0.0016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11129	 11151	 0.13439	 0.10636	 0.00134	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77676	 11129	 0.020347	 0.040286	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11130	 11131	 0.000578	 0.005503	 0.0201	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77678	 11130	 0.000285	 0.004552	 0.00935	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11130	 78535	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11130	 78535	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11131	 11145	 0.000318	 0.003224	 0.00649	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11131	 78536	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11131	 78536	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11132	 78538	 0.009531	 0.009559	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11133	 78537	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78538	 11133	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11133	 78549	 0.000438	 0.004365	 0.01457	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11134	 11135	 0.011973	 0.023706	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78538	 11134	 0.006216	 0.015978	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11135	 78540	 0.019421	 0.029455	 0.00042	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11136	 11137	 0.001291	 0.006098	 0.00195	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78536	 11136	 0.002331	 0.012835	 0.00463	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11136	 78539	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11136	 78539	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11137	 11138	 0.001786	 0.010112	 0.00251	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11137	 78540	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11137	 78540	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11138	 11486	 0.001716	 0.01005	 0.00274	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78539	 11139	 0.039438	 0.043377	 0.00058	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11140	 11142	 0.002241	 0.007551	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11140	 78541	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11140	 78541	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11140	 78552	 0.00098	 0.005628	 0.00159	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11141	 11143	 0.00958	 0.007509	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11142	 78542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11142	 78542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78541	 11143	 0.009083	 0.017983	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78536	 11144	 0.001611	 0.010201	 0.00277	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11144	 78543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11144	 78543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11144	 78552	 0.000703	 0.002672	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11145	 11158	 0.000183	 0.001615	 0.00684	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11145	 78544	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78545	 11145	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78545	 11146	 0.011599	 0.009092	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11147	 11149	 0.002055	 0.005516	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78544	 11147	 0.001516	 0.009097	 0.00275	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78545	 11148	 0.023596	 0.017057	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11149	 11150	 0.002454	 0.016465	 0.00397	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11149	 78546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11149	 78546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78535	 11150	 0.001043	 0.017101	 0.00538	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11152	 11482	 0.001712	 0.018353	 0.00587	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11152	 12429	 0.004682	 0.021477	 0.0055	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11152	 78547	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11152	 78547	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11152	 78550	 0.003267	 0.047166	 0.01498	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78530	 11153	 0.015133	 0.011976	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11154	 12425	 0.003841	 0.015379	 0.00387	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11155	 78548	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11155	 78548	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77677	 11156	 0.000227	 0.002346	 0.03686	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77677	 11156	 0.000227	 0.002346	 0.03686	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78477	 11156	 0.000499	 0.007729	 0.13308	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11156	 78549	 0.000119	 0.009523	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11156	 78549	 0.000119	 0.009523	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78550	 11156	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11157	 78551	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11157	 78551	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78549	 11158	 0.000762	 0.005923	 0.02123	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11158	 78552	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11158	 78552	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11159	 12429	 0.002222	 0.014072	 0.00382	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11160	 11163	 0.004095	 0.022012	 0.00541	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11160	 11164	 0.00697	 0.038383	 0.01386	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11160	 78553	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11160	 78553	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11161	 11163	 0.006728	 0.042615	 0.01157	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11162	 11167	 0.009021	 0.038182	 0.00859	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11162	 78554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11162	 78554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11164	 12181	 0.005465	 0.031401	 0.0089	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11165	 11167	 0.003428	 0.028469	 0.01114	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11165	 12181	 0.005275	 0.052347	 0.01424	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11166	 11167	 0.00218	 0.008873	 0.00216	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11166	 11168	 0.008764	 0.035666	 0.00869	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11167	 11169	 0.01898	 0.055964	 0.01302	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11167	 11500	 0.020273	 0.11781	 0.02776	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11169	 11170	 0.008453	 0.048572	 0.01376	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11169	 12182	 0.009209	 0.061784	 0.01492	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11170	 13541	 0.006401	 0.036781	 0.01042	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11170	 79803	 0.01956	 0.069149	 0.01558	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11171	 11175	 0.00065	 0.006201	 0.00251	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11171	 11194	 0.000213	 0.001538	 0.00083	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11171	 78555	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11171	 78555	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11172	 11173	 0.001658	 0.01041	 0.00023	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11172	 11181	 0.006081	 0.010695	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11172	 11215	 0.002065	 0.017179	 0.00033	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11173	 11174	 0.002523	 0.005769	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11173	 11241	 0.007304	 0.020948	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11174	 11179	 0.002916	 0.011343	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11174	 78556	 0.002236	 0.006859	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11174	 78578	 0.011588	 0.034877	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11175	 11243	 0.000717	 0.007242	 0.00213	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11175	 78556	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11175	 78556	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78556	 11176	 0.015495	 0.012262	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11177	 11178	 0.008936	 0.006575	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11177	 11185	 0.002178	 0.006555	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78556	 11177	 0.003742	 0.013367	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11179	 11180	 0.001481	 0.005185	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11179	 11183	 0.002767	 0.006423	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11180	 11181	 0.001579	 0.006453	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11181	 11217	 0.002887	 0.010108	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11182	 78557	 0.01275	 0.009994	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78555	 11183	 0.003465	 0.007426	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11184	 11185	 0.00199	 0.005061	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78555	 11184	 0.005198	 0.012309	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11185	 11186	 0.002201	 0.005211	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11186	 11187	 0.002379	 0.006114	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78555	 11187	 0.003029	 0.007172	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11188	 11190	 0.018372	 0.014401	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11189	 11191	 0.003085	 0.007931	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78555	 11189	 0.002957	 0.00605	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11190	 11191	 0.000762	 0.005483	 0.00018	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11190	 11237	 0.002917	 0.010208	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11190	 11237	 0.002917	 0.010208	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77750	 11190	 0.003553	 0.017054	 0.00051	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11190	 78559	 0.0023	 0.019535	 0.00046	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11192	 11193	 0.000671	 0.00397	 8e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11193	 78557	 0.001122	 0.00864	 0.00017	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11194	 11195	 0.000251	 0.002222	 0.00122	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11194	 78557	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11194	 78557	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11195	 11196	 0.000203	 0.001888	 0.00058	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11195	 78558	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11195	 78558	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11195	 78565	 0.001528	 0.016901	 0.00507	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11196	 11216	 0.000394	 0.003416	 0.00123	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11197	 11218	 0.00032	 0.003539	 0.00106	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11197	 78559	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11197	 78559	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11198	 78564	 0.017769	 0.080662	 0.00175	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11198	 79020	 0.020126	 0.13816	 0.00252	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11199	 11200	 0.004838	 0.019975	 0.00473	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11199	 11202	 0.003832	 0.013144	 0.00315	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11199	 78560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11199	 78560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11200	 11256	 0.003545	 0.018845	 0.00437	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11200	 78561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11200	 78561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11201	 11203	 0.002024	 0.019048	 0.00577	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11201	 11204	 0.002278	 0.02269	 0.00843	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11201	 78562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11201	 78562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77695	 11202	 0.002462	 0.010019	 0.00244	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11203	 11213	 0.003502	 0.021757	 0.00614	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11203	 78563	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11203	 78563	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11203	 78583	 0.001437	 0.020321	 0.00673	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11204	 12446	 0.001641	 0.023206	 0.00769	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11204	 78564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11204	 78564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11205	 11207	 0.007266	 0.05399	 0.00129	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11205	 12317	 0.14803	 0.11715	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11205	 12447	 0.01178	 0.054693	 0.00149	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11205	 79024	 0.022351	 0.13584	 0.00251	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11206	 78567	 0.022697	 0.044938	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11207	 78566	 0.008744	 0.054909	 0.0012	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11208	 12362	 0.001779	 0.011918	 0.00365	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11208	 78565	 0.001366	 0.008391	 0.00307	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11209	 12348	 0.001655	 0.023749	 0.09452	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11209	 78565	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78566	 11209	 0.000262	 0.019645	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78565	 11210	 0.001178	 0.006107	 0.00149	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11210	 78567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11210	 78567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11211	 11212	 0.002017	 0.007845	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78567	 11211	 0.00718	 0.035036	 0.0006	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11212	 11215	 0.00657	 0.020861	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11213	 11216	 0.000493	 0.004091	 0.0016	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78565	 11213	 0.000482	 0.005455	 0.00306	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11213	 78568	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11213	 78568	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11214	 11215	 0.003307	 0.014654	 0.00044	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78568	 11214	 0.002375	 0.012707	 0.00039	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78558	 11215	 0.013793	 0.032023	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78558	 11217	 0.002412	 0.012199	 0.00021	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11218	 11221	 0.000274	 0.003026	 0.00091	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11219	 11221	 0.000228	 0.002449	 0.00078	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78565	 11219	 0.000963	 0.010784	 0.00343	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11219	 78569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11219	 78569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11220	 11222	 0.01908	 0.014037	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11222	 11225	 0.021403	 0.054431	 0.00086	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78569	 11222	 0.01386	 0.028363	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11223	 78570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11223	 78570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78570	 11224	 0.021105	 0.055939	 0.00142	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11225	 12364	 0.020067	 0.052007	 0.00098	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11226	 11695	 0.002878	 0.017271	 0.00523	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11226	 12365	 0.001654	 0.015018	 0.00489	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11226	 78571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11226	 78571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11227	 11228	 0.010084	 0.044934	 0.00076	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11227	 78574	 0.003938	 0.018904	 0.00056	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11228	 11606	 0.013127	 0.068262	 0.00148	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11228	 11608	 0.013495	 0.054003	 0.00114	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11229	 11234	 0.002556	 0.013545	 0.00452	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11229	 11245	 0.002479	 0.011371	 0.00291	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11229	 78572	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11229	 78572	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11230	 11231	 0.001093	 0.013753	 0.00426	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11230	 12951	 0.004391	 0.027811	 0.00755	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11230	 12959	 0.003561	 0.01661	 0.00411	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11230	 78573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11230	 78573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11231	 11232	 0.001863	 0.011184	 0.00339	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11231	 78574	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11231	 78574	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11232	 11233	 0.001455	 0.006887	 0.00166	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11232	 78575	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11232	 78575	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11233	 11235	 0.001013	 0.005249	 0.00128	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11233	 78576	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11233	 78576	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11234	 11235	 0.001745	 0.010219	 0.00278	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11235	 78577	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11235	 78577	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78575	 11236	 0.014813	 0.026624	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78576	 11237	 0.002212	 0.021678	 0.00042	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78556	 11238	 0.004901	 0.033254	 0.00062	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78577	 11238	 0.005231	 0.026461	 0.00046	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11239	 11240	 0.000864	 0.004795	 0.00146	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11239	 11243	 0.000582	 0.003246	 0.00083	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11239	 11244	 0.00381	 0.023644	 0.00573	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77695	 11240	 0.000799	 0.005838	 0.0015	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11241	 78578	 0.005571	 0.018585	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77696	 11242	 0.010751	 0.028496	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78556	 11242	 0.018817	 0.034987	 0.00082	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78563	 11242	 0.007984	 0.034288	 0.00063	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77695	 11243	 0.002218	 0.010173	 0.00261	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11243	 78578	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11243	 78578	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11244	 11251	 0.004382	 0.029399	 0.0071	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11244	 78579	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11244	 78579	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11245	 11247	 0.002772	 0.012717	 0.00326	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11246	 11247	 0.001598	 0.0043	 0.00121	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11246	 78580	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11246	 78580	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11247	 12938	 0.001797	 0.007195	 0.00181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11247	 78581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11247	 78581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11248	 11249	 0.015697	 0.061064	 0.00102	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11248	 12936	 0.009501	 0.057523	 0.0018	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11248	 78587	 0.033293	 0.08467	 0.00134	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78580	 11249	 0.024424	 0.062115	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11249	 78582	 0.016559	 0.064418	 0.00108	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11250	 11253	 0.022482	 0.044062	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11251	 11260	 0.004224	 0.021224	 0.00552	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11251	 78582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11251	 78582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11252	 12633	 0.007706	 0.054081	 0.09218	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11252	 78583	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11252	 78583	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11252	 79045	 0.001598	 0.020376	 0.06938	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11253	 78584	 0.009762	 0.037978	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11254	 11258	 0.002801	 0.014072	 0.00366	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11254	 11260	 0.005936	 0.035363	 0.0093	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11254	 12508	 0.004841	 0.040711	 0.01206	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77695	 11254	 0.001646	 0.020366	 0.01099	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78583	 11254	 0.000976	 0.012219	 0.0083	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11254	 78584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11254	 78584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11254	 79046	 0.008401	 0.052209	 0.01474	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11255	 11256	 0.006347	 0.016477	 0.004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78583	 11255	 0.00422	 0.016895	 0.00426	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11255	 78585	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11255	 78585	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11256	 12488	 0.007977	 0.04393	 0.01586	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11256	 78586	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11256	 78586	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78585	 11257	 0.025733	 0.10011	 0.00167	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11257	 79036	 0.035909	 0.11979	 0.0019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11258	 11259	 0.001529	 0.006121	 0.00207	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11259	 12490	 0.005939	 0.024519	 0.0058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11260	 12511	 0.001348	 0.014284	 0.00424	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11260	 78587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11260	 78587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11261	 78588	 0.006064	 0.009462	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11262	 11263	 0.00051	 0.00423	 0.00111	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11262	 11265	 0.002469	 0.024119	 0.00677	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11262	 78588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11262	 78588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11263	 11268	 0.004344	 0.040892	 0.01239	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11263	 12193	 0.004592	 0.03666	 0.00904	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11263	 12194	 0.006725	 0.05066	 0.01406	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77718	 11263	 0.01836	 0.10759	 0.02933	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11263	 78589	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11263	 78589	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11264	 11265	 0.000744	 0.006753	 0.0022	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11264	 11286	 0.001836	 0.017936	 0.00503	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11266	 11286	 0.001667	 0.016537	 0.0045	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11266	 11528	 0.003463	 0.033251	 0.00967	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11266	 78590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11266	 78590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11267	 78597	 0.030618	 0.022527	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11268	 11286	 0.000745	 0.010538	 0.00349	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11268	 78591	 0.003244	 0.027281	 0.00808	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11269	 11270	 0.000583	 0.009089	 0.01953	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11269	 78591	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11269	 78591	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11269	 78916	 0.005193	 0.047668	 0.18856	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11270	 11516	 0.00305	 0.031147	 0.09897	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11270	 78592	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11270	 78592	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11271	 11272	 0.001714	 0.018387	 0.00479	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11271	 11528	 0.002018	 0.016208	 0.00456	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11272	 11287	 0.000727	 0.006604	 0.00215	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78592	 11272	 0.001447	 0.022436	 0.00633	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11272	 78593	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11272	 78593	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11273	 11274	 0.013288	 0.036301	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11273	 78594	 0.029337	 0.062867	 0.0011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78593	 11274	 0.008903	 0.031804	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11275	 11276	 0.003704	 0.023458	 0.00637	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11275	 12203	 0.006322	 0.041339	 0.01051	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11276	 11277	 0.001326	 0.005474	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11277	 11278	 0.004545	 0.020463	 0.00544	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11277	 78594	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11277	 78594	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11279	 11289	 0.001079	 0.005266	 0.00145	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11279	 78595	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11279	 78595	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11280	 11281	 0.012482	 0.009878	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11280	 78598	 0.004218	 0.006732	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11282	 11294	 0.013932	 0.01025	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11283	 11284	 0.012766	 0.009672	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11284	 11285	 0.021272	 0.016317	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11284	 11293	 0.005785	 0.017766	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78595	 11284	 0.008384	 0.047656	 0.00086	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11286	 11292	 0.00052	 0.006538	 0.00203	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11287	 11288	 0.000497	 0.003915	 0.00115	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11287	 78596	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11287	 78596	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11288	 11289	 0.00059	 0.004652	 0.00136	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11288	 78597	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11288	 78597	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11289	 11291	 0.000267	 0.003361	 0.00104	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11289	 78598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11289	 78598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78598	 11290	 0.018973	 0.012283	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11291	 11292	 0.000202	 0.002583	 0.00077	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11291	 78599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11291	 78599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11292	 78600	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11292	 78600	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78600	 11293	 0.004377	 0.010057	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78599	 11294	 0.005325	 0.008075	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11295	 11296	 0.094984	 0.1714	 0.00248	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11295	 13551	 0.21348	 0.15124	 0.00239	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11296	 11298	 0.016634	 0.10227	 0.00184	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11296	 78606	 0.034105	 0.16644	 0.00287	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11297	 78601	 0.015091	 0.046343	 0.00087	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11298	 78601	 0.004818	 0.036133	 0.00073	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11299	 11302	 0.004476	 0.031658	 0.00869	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11299	 78601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11299	 78601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11300	 78602	 0.25845	 0.20458	 0.00258	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11301	 11302	 0.005629	 0.042181	 0.01029	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11301	 78602	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11301	 78602	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11303	 78603	 7.2e-05	 0.005789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11304	 11307	 0.018564	 0.17284	 0.00335	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78606	 11304	 0.004963	 0.040805	 0.00079	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11305	 13557	 0.004998	 0.069887	 0.0237	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11305	 13558	 0.009551	 0.036307	 0.01016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11305	 13784	 0.004304	 0.030439	 0.00835	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78605	 11305	 0.002087	 0.027527	 0.01685	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78606	 11306	 0.01442	 0.12248	 0.00286	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11306	 79382	 0.047713	 0.18358	 0.00313	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11306	 79382	 0.047713	 0.18358	 0.00313	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11307	 11308	 0.015155	 0.14851	 0.00291	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77721	 11308	 0.032256	 0.1241	 0.00212	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77721	 11308	 0.032256	 0.1241	 0.00212	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11309	 11312	 0.008726	 0.011469	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11309	 78607	 0.012592	 0.02893	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11309	 79354	 0.01391	 0.054113	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11309	 79354	 0.01391	 0.054113	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11310	 13405	 0.005668	 0.020247	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11310	 13405	 0.005668	 0.020247	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11310	 79339	 0.002122	 0.008163	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11310	 79339	 0.002122	 0.008163	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11311	 11317	 0.000616	 0.005732	 0.00178	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11311	 13420	 0.000205	 0.001967	 0.00057	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11313	 78618	 0.007674	 0.018783	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11313	 79338	 0.021462	 0.049827	 0.00074	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11314	 11316	 0.006246	 0.021868	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11314	 11319	 0.004576	 0.015266	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11315	 11316	 0.00175	 0.013642	 0.00025	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11315	 11318	 0.003871	 0.02178	 0.00047	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11316	 13422	 0.002254	 0.012811	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11316	 79354	 0.004988	 0.046441	 0.0009	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11317	 78607	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11317	 78607	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11317	 78608	 0.000972	 0.007807	 0.00219	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78607	 11318	 0.008095	 0.02297	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11318	 78610	 0.002439	 0.017367	 0.00039	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11319	 11344	 0.007714	 0.01983	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11320	 11443	 0.008896	 0.017613	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11320	 78610	 0.021579	 0.023044	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11321	 11328	 0.000507	 0.005119	 0.01161	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11321	 11328	 0.000507	 0.005119	 0.01161	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11321	 13450	 0.000823	 0.009078	 0.01725	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11321	 13450	 0.000823	 0.009078	 0.01725	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11321	 78608	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11321	 78608	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11322	 11335	 0.000943	 0.003705	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11322	 78609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11322	 78609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11323	 11324	 0.001183	 0.003986	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11323	 11326	 0.001974	 0.006878	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11323	 78610	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11323	 78610	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11324	 11325	 0.00103	 0.003534	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78608	 11325	 0.000882	 0.003073	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11326	 11338	 0.001543	 0.004685	 0.00103	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11327	 78612	 0.002203	 0.014337	 0.00029	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11327	 78617	 0.002257	 0.018775	 0.00036	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11328	 11329	 0.000142	 0.001544	 0.00303	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11328	 11329	 0.000142	 0.001544	 0.00303	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11328	 78611	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78612	 11328	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11329	 11451	 0.000552	 0.00558	 0.01266	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11329	 11451	 0.000552	 0.00558	 0.01266	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11329	 78613	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78614	 11329	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11330	 11332	 0.00049	 0.003466	 0.00095	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11330	 11417	 0.002939	 0.02148	 0.00634	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11330	 78615	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11330	 78615	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11331	 78642	 0.014775	 0.010871	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78611	 11332	 0.000357	 0.004837	 0.0028	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78613	 11332	 0.000162	 0.002879	 0.00145	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11332	 78616	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11332	 78616	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11333	 11334	 0.000213	 0.002041	 0.00059	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78611	 11333	 0.000495	 0.004752	 0.00138	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11334	 11335	 0.000361	 0.003394	 0.00103	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78608	 11335	 0.000457	 0.005855	 0.00175	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11336	 11337	 0.002574	 0.014635	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11336	 11339	 0.002214	 0.014797	 0.00033	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11336	 11436	 0.004651	 0.018094	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11336	 11436	 0.004651	 0.018094	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11337	 78617	 0.001316	 0.008569	 0.00017	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11338	 78617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11338	 78617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11339	 11341	 0.006202	 0.027324	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11339	 11343	 0.01022	 0.038339	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11339	 11343	 0.01022	 0.038339	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11340	 11341	 0.004147	 0.025494	 0.00046	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11340	 11444	 0.008026	 0.035763	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11340	 78636	 0.005466	 0.021263	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11341	 11429	 0.003966	 0.01543	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11341	 11429	 0.003966	 0.01543	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11342	 11443	 0.001682	 0.008114	 0.00014	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78617	 11342	 0.003987	 0.017566	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11343	 11346	 0.005415	 0.021065	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11343	 11346	 0.005415	 0.021065	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11343	 11409	 0.003809	 0.023058	 0.00072	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11343	 11444	 0.00481	 0.015423	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11343	 11444	 0.00481	 0.015423	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11343	 78619	 0.010012	 0.071302	 0.0016	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11344	 11443	 0.001804	 0.012381	 0.00023	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11344	 11444	 0.003978	 0.016258	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11345	 13424	 0.0042	 0.016338	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11345	 78618	 0.004428	 0.01973	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11345	 78619	 0.004382	 0.024566	 0.00068	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11346	 78618	 0.005805	 0.017808	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11346	 78618	 0.005805	 0.017808	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11347	 11348	 0.001024	 0.0041	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11347	 11351	 0.001077	 0.00485	 0.00129	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11348	 78618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11348	 78618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11349	 78619	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11349	 78619	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11349	 78621	 0.00204	 0.01855	 0.00468	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11350	 11355	 0.003939	 0.013781	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78619	 11350	 0.006832	 0.022791	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11351	 11352	 0.001241	 0.005586	 0.00149	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11352	 11445	 0.000732	 0.005669	 0.00199	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11352	 78620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11352	 78620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11353	 12770	 0.010962	 0.014146	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11353	 78622	 0.007215	 0.020693	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11354	 11355	 0.003109	 0.013353	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11354	 12770	 0.002987	 0.015109	 0.00026	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11356	 12861	 0.000492	 0.009097	 0.08741	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11356	 78621	 0.000103	 0.008222	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11356	 79131	 0.000723	 0.008221	 0.07425	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78622	 11357	 0.013533	 0.022569	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78622	 11358	 0.026163	 0.028776	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11358	 78624	 0.019606	 0.025768	 0.00035	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11358	 79128	 0.010411	 0.018309	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11359	 11360	 0.003366	 0.008651	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11359	 12780	 0.001797	 0.007196	 0.00181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11359	 78623	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11359	 78623	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11360	 11363	 0.002593	 0.006854	 0.0016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11361	 11405	 0.027334	 0.019362	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11362	 78624	 0.024798	 0.016054	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11363	 78624	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11363	 78624	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11364	 11366	 0.000479	 0.005292	 0.00159	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11364	 11400	 0.002256	 0.013646	 0.00348	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11364	 11401	 0.003423	 0.018871	 0.00441	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11364	 78625	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11364	 78625	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11365	 11404	 0.048323	 0.038242	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11366	 79132	 0.000872	 0.010745	 0.00347	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78625	 11367	 0.024117	 0.019086	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11368	 11386	 0.009505	 0.024434	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11368	 78643	 0.013161	 0.031391	 0.0007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11369	 11373	 0.00277	 0.012708	 0.00326	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11369	 11446	 0.002485	 0.008999	 0.00193	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11369	 79132	 0.000894	 0.007798	 0.00214	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11370	 11371	 0.002245	 0.008734	 0.00233	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11370	 11380	 0.005213	 0.022065	 0.00496	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11371	 11372	 0.000852	 0.003468	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11372	 11373	 0.00097	 0.004223	 0.0012	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11373	 11374	 0.00129	 0.008952	 0.00255	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11373	 11380	 0.005423	 0.035461	 0.00902	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11374	 12925	 0.000577	 0.006325	 0.00175	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11374	 12928	 0.001103	 0.004668	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11374	 78626	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11374	 78626	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11375	 11447	 0.003743	 0.014984	 0.00377	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11375	 79132	 0.005451	 0.025423	 0.0063	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11376	 11448	 0.001971	 0.010862	 0.00254	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11376	 12932	 0.003354	 0.014695	 0.00505	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11376	 78627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11376	 78627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11377	 11380	 0.003013	 0.019086	 0.00518	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11377	 11447	 0.001609	 0.006322	 0.00165	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11377	 78628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11377	 78628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78628	 11378	 0.00528	 0.00967	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11379	 78644	 0.012516	 0.035515	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77650	 11380	 0.002242	 0.028206	 0.00874	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11380	 78629	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11380	 78629	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11381	 13034	 0.034488	 0.06759	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78629	 11381	 0.013309	 0.05831	 0.00125	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11381	 79052	 0.015115	 0.062754	 0.00163	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11382	 11384	 0.10364	 0.079501	 0.00107	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77651	 11382	 0.005822	 0.035248	 0.0011	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78629	 11382	 0.011495	 0.07218	 0.00158	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77651	 11383	 0.05808	 0.045526	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11384	 11387	 0.072054	 0.079949	 0.00156	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11385	 11386	 0.011827	 0.046189	 0.00102	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11385	 11388	 0.019365	 0.075335	 0.00126	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11385	 11389	 0.025013	 0.066122	 0.0012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11385	 13035	 0.23964	 0.22479	 0.00347	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78629	 11385	 0.057944	 0.087884	 0.00126	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11386	 78643	 0.02337	 0.060075	 0.00093	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11387	 11388	 0.010537	 0.046954	 0.0008	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11387	 11390	 0.007729	 0.053056	 0.00097	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11388	 11389	 0.010968	 0.027892	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11388	 78631	 0.036556	 0.072378	 0.00106	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11388	 78632	 0.040418	 0.068087	 0.00097	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11389	 78631	 0.057563	 0.058141	 0.00077	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11390	 78630	 0.006383	 0.031671	 0.00076	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11391	 11401	 0.005161	 0.032071	 0.00905	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11391	 78630	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11391	 78630	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11392	 11423	 0.022122	 0.060436	 0.00103	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78630	 11392	 0.012147	 0.040522	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78076	 11393	 0.021515	 0.017026	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78630	 11394	 0.021334	 0.07465	 0.00155	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11394	 78632	 0.012712	 0.078156	 0.00141	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11395	 11396	 0.014101	 0.025442	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11395	 78632	 0.009913	 0.033069	 0.00052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11396	 11397	 0.030863	 0.024192	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11398	 11405	 0.015405	 0.037708	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11398	 78631	 0.020489	 0.052669	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11399	 78631	 0.03828	 0.042103	 0.00056	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11400	 11401	 0.000787	 0.004888	 0.00138	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11400	 78631	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11400	 78631	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11401	 78632	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11401	 78632	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11402	 11403	 0.00681	 0.010626	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78631	 11402	 0.01351	 0.026748	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78632	 11403	 0.019972	 0.015806	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78625	 11404	 0.017175	 0.028932	 0.00041	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11405	 11406	 0.018357	 0.030614	 0.00045	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78622	 11405	 0.012497	 0.048616	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11407	 11415	 0.000804	 0.008628	 0.00225	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11407	 11418	 0.00073	 0.007006	 0.00204	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11407	 78633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11407	 78633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11408	 11409	 0.003389	 0.026102	 0.0005	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11408	 11414	 0.002383	 0.017417	 0.00032	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11408	 78635	 0.013174	 0.031196	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11409	 11411	 0.004771	 0.021259	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11410	 11415	 0.000488	 0.005395	 0.00162	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78621	 11410	 0.000906	 0.010543	 0.0031	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11410	 78634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11410	 78634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11411	 11412	 0.002781	 0.01239	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11412	 11413	 0.035119	 0.027528	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78633	 11412	 0.005018	 0.024101	 0.00047	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11412	 78637	 0.006856	 0.030552	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78620	 11414	 0.00237	 0.019717	 0.00037	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11415	 78635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11415	 78635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78634	 11416	 0.084656	 0.062285	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11417	 11418	 0.000872	 0.008376	 0.00244	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11417	 78636	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11417	 78636	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11418	 78637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11418	 78637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11419	 11422	 0.005515	 0.021456	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11419	 11422	 0.005515	 0.021456	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11419	 11427	 0.003039	 0.028289	 0.00055	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11420	 11421	 0.020744	 0.015716	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78637	 11420	 0.015557	 0.020446	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78636	 11422	 0.002315	 0.009004	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78636	 11422	 0.002315	 0.009004	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78636	 11423	 0.035898	 0.066748	 0.00156	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11424	 11426	 0.001079	 0.00481	 0.00131	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11425	 11428	 0.009163	 0.023303	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11425	 11430	 0.002175	 0.020005	 0.0004	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11425	 11431	 0.031284	 0.024758	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11425	 78638	 0.006619	 0.025751	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11425	 78638	 0.006619	 0.025751	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11426	 11434	 0.00143	 0.005725	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11426	 78638	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11426	 78638	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11427	 11428	 0.008837	 0.022475	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11429	 11430	 0.001474	 0.013166	 0.00031	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78081	 11432	 0.002508	 0.009755	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11432	 78639	 0.003025	 0.013326	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11433	 11435	 0.000932	 0.007568	 0.00241	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11433	 78639	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11433	 78639	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11434	 11439	 0.001505	 0.006126	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11434	 78640	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11434	 78640	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11435	 11439	 0.000824	 0.005826	 0.0016	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11435	 78641	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11435	 78641	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11435	 78645	 0.001647	 0.009645	 0.00263	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11436	 11437	 0.002116	 0.017601	 0.00033	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78615	 11436	 0.00306	 0.011772	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11437	 11438	 0.002576	 0.00991	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78097	 11437	 0.015417	 0.087638	 0.00159	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78615	 11438	 0.002302	 0.018926	 0.00037	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78641	 11438	 0.009368	 0.036444	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78641	 11438	 0.009368	 0.036444	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11439	 11440	 0.000251	 0.002874	 0.00081	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11440	 11441	 0.000246	 0.002818	 0.00079	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11440	 78642	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11440	 78642	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78613	 11441	 0.000355	 0.003925	 0.00118	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78614	 11442	 0.003019	 0.016521	 0.00032	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11442	 78646	 0.00756	 0.046478	 0.00084	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11445	 12771	 0.002554	 0.014956	 0.00407	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78621	 11445	 0.00087	 0.005348	 0.00196	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11446	 78643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11446	 78643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11448	 11449	 0.003416	 0.016166	 0.00389	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77715	 11449	 0.006532	 0.041373	 0.01123	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11449	 78644	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11449	 78644	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11449	 79132	 0.019989	 0.055747	 0.0117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77651	 11450	 0.064844	 0.04974	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77699	 11451	 0.000173	 0.001938	 0.00358	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77699	 11451	 0.000173	 0.001938	 0.00358	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11451	 78645	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78646	 11451	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11452	 78648	 0.012163	 0.008948	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11453	 11460	 0.004339	 0.014473	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11453	 78647	 0.0038	 0.012678	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11454	 11455	 0.00092	 0.003685	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11454	 11459	 0.00172	 0.006886	 0.00173	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11454	 11462	 0.003226	 0.009661	 0.00218	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11454	 78647	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11454	 78647	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11455	 11475	 0.002157	 0.012847	 0.00338	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11455	 78648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11455	 78648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11456	 11457	 0.008706	 0.010613	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78648	 11456	 0.003666	 0.009423	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78648	 11457	 0.004419	 0.011359	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11457	 78657	 0.012719	 0.042431	 0.00067	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78647	 11458	 0.006232	 0.017026	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11458	 78650	 0.007401	 0.024689	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11459	 11461	 0.001976	 0.008043	 0.00196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11459	 78649	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11459	 78649	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11460	 11472	 0.005124	 0.031141	 0.00057	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78649	 11460	 0.005658	 0.022013	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11461	 11482	 0.006768	 0.033029	 0.00912	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11461	 78650	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11461	 78650	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11462	 11480	 0.004792	 0.01435	 0.00323	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11463	 11465	 0.008991	 0.056955	 0.01546	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11463	 11704	 0.005795	 0.035628	 0.01027	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11463	 78651	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11463	 78651	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11464	 13596	 0.098434	 0.19491	 0.00286	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78651	 11464	 0.051122	 0.13002	 0.00206	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11464	 78652	 0.023591	 0.099844	 0.00188	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11465	 11467	 0.00303	 0.011023	 0.00337	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11465	 12708	 0.006425	 0.038564	 0.01168	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11465	 78652	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11465	 78652	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11466	 11468	 0.012011	 0.063995	 0.00112	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11466	 12420	 0.041489	 0.12488	 0.00244	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11466	 78656	 0.13843	 0.10186	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11467	 11473	 0.010311	 0.043643	 0.00982	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11467	 78653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11467	 78653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78653	 11468	 0.002887	 0.014089	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11469	 11471	 0.00707	 0.020846	 0.00485	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11469	 78654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11469	 78654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11470	 78655	 0.076132	 0.06025	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11471	 78655	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11471	 78655	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78655	 11472	 0.005171	 0.022783	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11473	 11482	 0.004806	 0.030444	 0.00826	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11473	 78656	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11473	 78656	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78650	 11474	 0.010075	 0.050954	 0.00099	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11474	 78659	 0.011756	 0.080698	 0.00147	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11475	 11476	 0.00861	 0.022353	 0.00543	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11475	 78657	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11475	 78657	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78522	 11477	 0.03038	 0.089338	 0.00183	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11477	 78658	 0.039291	 0.10734	 0.00182	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11478	 11479	 0.005034	 0.020484	 0.00499	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11478	 11480	 0.006933	 0.020439	 0.00475	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11479	 11495	 0.003684	 0.016724	 0.0058	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77704	 11479	 0.014466	 0.048263	 0.01224	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11479	 78658	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11479	 78658	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11481	 11482	 0.008821	 0.023314	 0.00546	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11481	 11493	 0.004839	 0.019372	 0.00488	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11482	 12429	 0.006175	 0.037964	 0.01095	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11482	 78659	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11482	 78659	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78547	 11483	 0.024486	 0.056838	 0.00108	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11484	 11492	 0.004362	 0.020644	 0.00496	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78537	 11484	 0.006546	 0.032278	 0.00873	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11484	 78660	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11484	 78660	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11485	 11486	 0.001211	 0.004926	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11485	 11487	 0.000553	 0.003769	 0.00128	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11485	 78661	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11485	 78661	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11487	 11491	 0.001034	 0.008254	 0.00203	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78661	 11488	 0.020725	 0.028883	 0.00049	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78660	 11489	 0.020262	 0.032342	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11490	 78662	 0.021924	 0.017185	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11491	 11492	 0.001659	 0.009718	 0.00265	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11491	 78662	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11491	 78662	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11492	 11493	 0.000827	 0.008762	 0.0026	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11493	 11495	 0.002399	 0.015198	 0.00412	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78528	 11494	 0.01619	 0.05401	 0.00086	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78658	 11494	 0.030945	 0.063326	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11495	 78663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11495	 78663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11496	 11497	 0.000206	 0.001283	 0.00036	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11496	 11498	 0.000579	 0.004436	 0.00119	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11496	 78677	 0.001093	 0.003681	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11497	 11512	 0.000513	 0.003629	 0.001	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11498	 11501	 0.000492	 0.003477	 0.00095	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11498	 78664	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11498	 78664	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11499	 78665	 0.012341	 0.00908	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11500	 11501	 0.000404	 0.002318	 0.00066	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11500	 11508	 0.002209	 0.017187	 0.00446	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11500	 11509	 0.002898	 0.011015	 0.00308	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77686	 11500	 0.002528	 0.034436	 0.01231	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11500	 78665	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11500	 78665	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11502	 11514	 0.01269	 0.026078	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11502	 78678	 0.004554	 0.010785	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11503	 78670	 0.069793	 0.076765	 0.00102	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11503	 78678	 0.013372	 0.044609	 0.00071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11504	 11505	 0.000212	 0.002407	 0.00528	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11504	 11534	 0.000198	 0.002244	 0.00493	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11505	 78666	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11505	 78666	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11506	 11507	 0.02601	 0.016839	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78665	 11506	 0.017902	 0.017954	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11508	 11533	 0.00165	 0.01575	 0.00638	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78666	 11508	 0.001451	 0.010721	 0.00309	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11508	 78667	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11508	 78667	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11509	 11537	 0.003227	 0.009345	 0.00225	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11509	 78668	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11509	 78668	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78665	 11510	 0.012767	 0.008265	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11511	 11513	 0.001268	 0.009555	 0.00265	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11511	 13534	 0.008141	 0.036277	 0.00986	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77671	 11511	 0.001654	 0.023828	 0.00865	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11511	 78669	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11511	 78669	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11512	 11513	 0.000665	 0.004786	 0.00127	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78669	 11514	 0.023404	 0.054336	 0.00081	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11515	 11516	 0.000243	 0.00367	 0.01318	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11515	 11536	 0.000863	 0.009517	 0.01808	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11515	 12226	 0.000665	 0.007533	 0.02811	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11515	 78670	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11515	 78670	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11516	 78671	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78672	 11516	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11517	 12218	 0.003506	 0.019456	 0.00591	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11517	 78673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11517	 78673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11518	 11519	 0.000813	 0.004084	 0.00106	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11518	 11524	 0.005006	 0.022965	 0.00588	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11519	 78934	 0.015237	 0.079388	 0.02083	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11520	 11727	 0.004264	 0.036571	 0.01041	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11520	 78674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11520	 78674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11521	 78743	 0.13123	 0.092961	 0.00147	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78590	 11522	 0.01517	 0.05308	 0.0011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78674	 11522	 0.023824	 0.1223	 0.00231	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11523	 11524	 0.005068	 0.022059	 0.00628	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11523	 11528	 0.005476	 0.025121	 0.00644	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11525	 11526	 0.001268	 0.004484	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11525	 11528	 0.006522	 0.035116	 0.00965	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78671	 11525	 0.001678	 0.018891	 0.00546	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11527	 11528	 0.001044	 0.010195	 0.00286	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11527	 11530	 0.003265	 0.017995	 0.00421	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11529	 11530	 0.001145	 0.00704	 0.00203	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11530	 11532	 0.001369	 0.017812	 0.00515	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11530	 78675	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11530	 78675	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78675	 11531	 0.057344	 0.045382	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78666	 11532	 0.001845	 0.019902	 0.0057	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11532	 78676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11532	 78676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11534	 11536	 0.000169	 0.002658	 0.00564	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11534	 78677	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11534	 78677	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78664	 11535	 0.014747	 0.01085	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77685	 11536	 0.000538	 0.008574	 0.0176	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11536	 78678	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11536	 78678	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11537	 78679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11537	 78679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11538	 11729	 0.024605	 0.096746	 0.02532	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11538	 12041	 0.014209	 0.055855	 0.01461	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11538	 78680	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11538	 78680	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78680	 11539	 0.073199	 0.09198	 0.00138	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11540	 78681	 0.073263	 0.05798	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11541	 11542	 0.001586	 0.020644	 0.00597	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11541	 12626	 0.002774	 0.036105	 0.01043	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11542	 12753	 0.001514	 0.016393	 0.0069	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11543	 12626	 0.003543	 0.036094	 0.0093	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11543	 12735	 0.002672	 0.025151	 0.00762	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77724	 11544	 0.01621	 0.082002	 0.00143	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11544	 79081	 0.012064	 0.07888	 0.00183	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11545	 11547	 0.002458	 0.023602	 0.00687	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11546	 13508	 0.001261	 0.007385	 0.00201	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11547	 11548	 0.001164	 0.010959	 0.00332	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11548	 11549	 0.001482	 0.011905	 0.00335	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11548	 78681	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11548	 78681	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11549	 11550	 0.002372	 0.018485	 0.00553	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11550	 12754	 0.003077	 0.026209	 0.00654	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11550	 78682	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11550	 78682	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77753	 11551	 0.003219	 0.034338	 0.06986	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77753	 11551	 0.003219	 0.034338	 0.06986	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77768	 11551	 0.003628	 0.039183	 0.07782	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77768	 11551	 0.003628	 0.039183	 0.07782	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11551	 78683	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78684	 11551	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11552	 11553	 0.007713	 0.046294	 0.01402	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11552	 11730	 0.004265	 0.025407	 0.00668	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11553	 11716	 0.008186	 0.051854	 0.01408	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11554	 11555	 0.001884	 0.013325	 0.00366	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11554	 11717	 0.002636	 0.018959	 0.00502	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11555	 11556	 0.002092	 0.030199	 0.00959	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11555	 11717	 0.003853	 0.029518	 0.00791	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11556	 11565	 0.001259	 0.016321	 0.00646	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11557	 11562	 0.057757	 0.094162	 0.00144	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11558	 11559	 0.008388	 0.049133	 0.01338	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11558	 78686	 0.004607	 0.029179	 0.00792	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11559	 13573	 0.009056	 0.047964	 0.01216	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11560	 13524	 0.015062	 0.074286	 0.02009	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11560	 78685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11560	 78685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11560	 78686	 0.004105	 0.029033	 0.00797	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77717	 11561	 0.002514	 0.037966	 0.13651	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77753	 11561	 0.009828	 0.095656	 0.34105	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11561	 78686	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78687	 11561	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78687	 11562	 0.009316	 0.035839	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11563	 11564	 0.005375	 0.020432	 0.00572	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11563	 78688	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11563	 78688	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11564	 11565	 0.00315	 0.012611	 0.00318	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11565	 11567	 0.00155	 0.013201	 0.00329	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11565	 78689	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11565	 78689	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11566	 11572	 0.002392	 0.017928	 0.00437	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11566	 11581	 0.000586	 0.003367	 0.00095	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11566	 78690	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11566	 78690	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11567	 11569	 0.004709	 0.018852	 0.00475	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11567	 11576	 0.000886	 0.003604	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11567	 78691	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11567	 78691	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11568	 11569	 0.002225	 0.009417	 0.00212	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11568	 11575	 0.001537	 0.010314	 0.00249	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11568	 11578	 0.002067	 0.008998	 0.00256	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78686	 11568	 0.002926	 0.02754	 0.00834	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11569	 11570	 0.002395	 0.012696	 0.00424	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11569	 78692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11569	 78692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11570	 12713	 0.00602	 0.035261	 0.00961	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78689	 11571	 0.10659	 0.084357	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11572	 12193	 0.004827	 0.037552	 0.00976	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11573	 11580	 0.017458	 0.013816	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11573	 78694	 0.00491	 0.009623	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11574	 78694	 0.00806	 0.008865	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11575	 11576	 0.000447	 0.001755	 0.00046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11575	 78693	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11575	 78693	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11577	 11578	 0.000494	 0.002872	 0.00068	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11577	 11581	 0.000433	 0.002539	 0.00069	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11578	 78694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11578	 78694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78694	 11579	 0.009755	 0.00772	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78688	 11582	 0.051351	 0.037781	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11583	 79169	 0.036239	 0.023461	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11584	 11591	 0.001716	 0.010662	 0.00301	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11584	 11594	 0.000476	 0.003305	 0.00094	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11585	 11586	 0.011341	 0.026328	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11585	 11590	 0.002072	 0.014355	 0.0003	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11585	 78695	 0.015557	 0.036119	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11585	 78703	 0.013304	 0.080853	 0.00149	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11586	 11587	 0.010794	 0.022685	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11587	 78696	 0.004127	 0.031789	 0.00061	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11587	 78697	 0.006145	 0.037782	 0.00068	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11588	 11589	 0.002584	 0.019201	 0.00046	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11588	 11590	 0.007376	 0.025195	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11588	 11590	 0.007376	 0.025195	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11589	 12017	 0.004392	 0.016826	 0.00048	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11589	 12893	 0.002789	 0.010214	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11590	 78695	 0.003057	 0.020985	 0.00038	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11591	 12021	 0.001965	 0.008114	 0.00192	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11591	 78695	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11591	 78695	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11592	 12022	 0.017394	 0.044235	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11592	 78711	 0.016034	 0.041218	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11593	 11595	 0.000656	 0.004154	 0.00113	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11593	 11629	 0.001529	 0.009999	 0.00254	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11594	 11595	 0.000688	 0.003913	 0.00113	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11594	 78696	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11594	 78696	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11594	 78702	 0.002132	 0.012486	 0.0034	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11596	 11601	 0.002707	 0.007014	 0.00212	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11596	 78697	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11596	 78697	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11597	 11600	 0.019536	 0.019594	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11598	 12901	 0.002261	 0.00905	 0.00228	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11599	 11601	 0.000936	 0.002912	 0.00061	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11599	 78698	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11599	 78698	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78698	 11600	 0.002707	 0.011859	 0.00025	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11600	 78699	 0.004241	 0.022051	 0.00048	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11602	 11688	 0.004784	 0.013026	 0.00287	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11602	 78699	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11602	 78699	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11603	 12906	 0.000594	 0.002149	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11603	 78700	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11603	 78700	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11604	 11688	 0.004091	 0.010984	 0.00249	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77667	 11604	 0.00122	 0.008631	 0.00237	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11604	 78701	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11604	 78701	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11605	 12950	 0.015383	 0.012058	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11605	 79201	 0.029026	 0.022971	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11606	 11607	 0.06079	 0.039356	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77772	 11606	 0.0136	 0.054423	 0.00115	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11608	 11609	 0.009494	 0.04248	 0.00087	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11609	 78720	 0.0114	 0.052858	 0.0011	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11610	 11611	 0.009301	 0.04374	 0.00081	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78701	 11610	 0.016946	 0.084757	 0.00151	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11611	 11650	 0.00801	 0.032055	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11612	 78703	 0.020134	 0.039459	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11613	 12887	 7.9e-05	 0.001596	 0.19045	 3627.0	 3808.3	 3989.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11613	 78702	 0.00018	 0.014416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11614	 11628	 0.000962	 0.007033	 0.00207	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78702	 11614	 0.000789	 0.005582	 0.00153	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11615	 11616	 0.001901	 0.00761	 0.00192	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11615	 11651	 0.000598	 0.005451	 0.00198	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78702	 11615	 0.001224	 0.015398	 0.00477	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11616	 11623	 0.002178	 0.008721	 0.0022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11617	 11623	 0.003274	 0.009653	 0.00225	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11617	 78704	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11617	 78704	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11618	 11621	 0.000549	 0.003106	 0.00077	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11618	 11623	 0.000884	 0.004606	 0.00121	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11619	 78705	 0.023267	 0.017119	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11620	 11643	 0.000667	 0.007071	 0.0021	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11620	 11687	 0.000138	 0.001553	 0.00041	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11621	 11687	 0.000332	 0.002061	 0.0005	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11621	 78705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11621	 78705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11621	 78709	 0.000907	 0.00316	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11622	 11627	 0.001087	 0.008735	 0.00246	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11622	 78706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11622	 78706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11622	 78709	 0.000594	 0.00559	 0.00169	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11623	 78707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11623	 78707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78707	 11624	 0.024473	 0.019183	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11625	 11630	 0.000633	 0.004624	 0.00119	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11625	 78708	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11625	 78708	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11625	 78709	 0.000573	 0.005503	 0.0016	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11626	 11963	 0.001433	 0.013271	 0.0513	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11626	 78709	 0.000105	 0.008384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78710	 11626	 0.000298	 0.020873	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11627	 11628	 0.000543	 0.004014	 0.00116	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11629	 11630	 0.000697	 0.005014	 0.00133	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11629	 78711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11629	 78711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11630	 78712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11630	 78712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11631	 12022	 0.014946	 0.053392	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78708	 11631	 0.006088	 0.02713	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11632	 11633	 0.00413	 0.01724	 0.0005	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11632	 11634	 0.022226	 0.044006	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78710	 11632	 0.003609	 0.022189	 0.0004	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11633	 12023	 0.007305	 0.031371	 0.00057	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11634	 12024	 0.017591	 0.04522	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11635	 11637	 0.000933	 0.004528	 0.00104	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11635	 11670	 0.001952	 0.008955	 0.00229	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11636	 11689	 0.003881	 0.037574	 0.00075	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11636	 78714	 0.011074	 0.043083	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11636	 78714	 0.011074	 0.043083	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11637	 78713	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11637	 78713	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78713	 11638	 0.012488	 0.009188	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11639	 11691	 0.000933	 0.010315	 0.00309	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11639	 11697	 0.002059	 0.025904	 0.00802	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11639	 78714	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11639	 78714	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11640	 11690	 0.056738	 0.044902	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78714	 11640	 0.058615	 0.045946	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11641	 11642	 0.006705	 0.035724	 0.00063	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11641	 11644	 0.008908	 0.039859	 0.00082	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11642	 78717	 0.005159	 0.029029	 0.00063	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11643	 11691	 0.0009	 0.009013	 0.003	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78705	 11644	 0.012675	 0.043296	 0.00094	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11645	 11646	 0.000883	 0.003029	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11645	 78715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11645	 78715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11646	 11648	 0.000616	 0.009453	 0.00264	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78709	 11646	 0.002514	 0.023008	 0.00921	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11646	 78716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11646	 78716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78716	 11647	 0.026101	 0.019204	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11648	 11692	 0.000632	 0.005742	 0.00435	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11648	 78717	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11648	 78717	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78717	 11649	 0.011145	 0.037179	 0.00059	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11649	 78731	 0.013923	 0.054165	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78703	 11650	 0.012432	 0.066238	 0.00116	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11650	 78719	 0.016735	 0.065104	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11650	 78719	 0.016735	 0.065104	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11651	 11653	 0.0006	 0.006236	 0.00193	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78715	 11652	 0.004261	 0.026758	 0.00058	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11652	 78718	 0.003656	 0.020544	 0.00038	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11653	 11655	 0.000869	 0.008626	 0.00235	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11653	 78718	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11653	 78718	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11654	 11655	 0.002026	 0.008112	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11654	 78719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11654	 78719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11655	 11656	 0.000811	 0.011929	 0.00365	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11656	 11694	 0.002108	 0.01211	 0.00343	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11656	 11695	 0.002302	 0.01458	 0.00396	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11656	 78720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11656	 78720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11657	 11694	 0.003022	 0.019138	 0.00519	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11657	 12392	 0.002962	 0.021306	 0.00565	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11657	 78721	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11657	 78721	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78721	 11658	 0.028403	 0.022263	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11659	 11660	 0.001474	 0.00847	 0.0024	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11659	 11693	 0.001999	 0.011707	 0.00319	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11659	 78722	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11659	 78722	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11660	 12393	 0.003937	 0.02306	 0.00628	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11661	 11662	 0.00053	 0.003639	 0.00106	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11661	 11678	 0.001613	 0.012152	 0.00337	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11661	 78723	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11661	 78723	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11662	 11692	 0.001035	 0.01111	 0.00289	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11662	 11698	 0.003468	 0.026573	 0.00712	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11662	 78724	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11662	 78724	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11663	 11664	 0.011982	 0.009078	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11663	 11665	 0.01657	 0.01113	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78724	 11663	 0.006655	 0.012373	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11666	 11696	 0.012895	 0.021722	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11667	 11675	 0.001098	 0.009415	 0.00268	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11667	 11697	 0.000496	 0.004029	 0.00128	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11668	 11671	 0.011125	 0.049573	 0.00084	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11668	 78725	 0.013601	 0.030852	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11669	 78725	 0.041006	 0.029047	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11670	 11697	 0.002966	 0.014901	 0.00388	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11670	 78725	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11670	 78725	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11671	 11672	 0.004306	 0.033558	 0.00063	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78317	 11671	 0.069071	 0.25544	 0.00473	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11672	 78726	 0.00542	 0.045092	 0.00085	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11673	 78730	 0.072149	 0.057098	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11674	 11684	 0.002802	 0.011214	 0.00379	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11674	 78726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11674	 78726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11675	 11683	 0.002985	 0.022699	 0.00713	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11675	 78727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11675	 78727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11676	 11677	 0.041311	 0.056362	 0.00101	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11676	 78732	 0.060795	 0.067456	 0.00132	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11677	 11679	 0.031514	 0.047797	 0.00069	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11678	 11698	 0.001398	 0.011162	 0.00275	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11678	 78728	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11678	 78728	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11679	 11696	 0.017414	 0.088093	 0.00153	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78728	 11679	 0.015152	 0.020654	 0.00046	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11679	 78733	 0.004386	 0.027845	 0.00079	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11680	 11698	 0.003361	 0.02002	 0.00527	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11680	 12400	 0.005358	 0.03394	 0.00921	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11681	 11682	 0.074518	 0.048244	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11682	 78729	 0.012589	 0.024925	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11683	 11684	 0.002066	 0.009303	 0.00248	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11683	 11685	 0.001748	 0.008634	 0.00252	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77713	 11683	 0.009463	 0.066941	 0.01837	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11683	 78729	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11683	 78729	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11684	 78730	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11684	 78730	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11685	 11686	 0.002468	 0.014332	 0.00337	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11686	 12398	 0.006032	 0.035331	 0.00962	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78709	 11687	 0.000513	 0.003151	 0.00091	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11689	 12024	 0.004576	 0.03886	 0.00091	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11692	 11693	 0.001425	 0.008099	 0.00234	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11694	 78731	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11694	 78731	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78710	 11696	 0.049771	 0.1915	 0.00327	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78710	 11696	 0.049771	 0.1915	 0.00327	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78724	 11696	 0.003022	 0.021262	 0.00042	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77713	 11697	 0.010261	 0.095568	 0.02962	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11697	 78732	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11697	 78732	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11698	 12394	 0.00326	 0.021316	 0.00542	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11698	 78733	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11698	 78733	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11699	 11705	 0.010898	 0.052896	 0.01209	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11699	 12150	 0.013346	 0.053438	 0.01347	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11699	 78734	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11699	 78734	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11700	 78736	 0.073358	 0.078342	 0.00166	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11701	 78736	 0.070082	 0.12837	 0.00222	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77759	 11702	 0.044415	 0.082586	 0.00193	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11702	 78735	 0.017947	 0.068765	 0.00194	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11703	 11704	 0.005867	 0.02349	 0.00592	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11703	 13594	 0.01244	 0.04981	 0.01255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11703	 78735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11703	 78735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11704	 11706	 0.008311	 0.027727	 0.00703	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11705	 78736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11705	 78736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11707	 78737	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11707	 78737	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78737	 11708	 0.14479	 0.10971	 0.00151	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11709	 11710	 6.1e-05	 0.000691	 0.00629	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11709	 12234	 0.00025	 0.002786	 0.02627	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11709	 78738	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11709	 78738	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11710	 78739	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11710	 78739	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78739	 11711	 0.000128	 0.001532	 0.00302	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11711	 78740	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11711	 78740	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11712	 11713	 0.002299	 0.015403	 0.00472	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78740	 11712	 0.002012	 0.014229	 0.0039	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11713	 11723	 0.003797	 0.027727	 0.00713	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77718	 11714	 0.007041	 0.022964	 0.0061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11714	 78741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11714	 78741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77719	 11715	 0.078511	 0.13528	 0.00215	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77718	 11716	 0.006133	 0.043378	 0.0119	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11717	 11726	 0.001694	 0.026023	 0.00728	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77718	 11717	 0.007293	 0.054655	 0.01333	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77719	 11718	 0.097016	 0.10671	 0.00142	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11719	 11721	 0.002733	 0.011566	 0.0026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11719	 11723	 0.00403	 0.024005	 0.00632	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77718	 11719	 0.001425	 0.017927	 0.00555	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11719	 78742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11719	 78742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78742	 11720	 0.014363	 0.010383	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11721	 11722	 0.006013	 0.030714	 0.00773	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11722	 11724	 0.005042	 0.027668	 0.00731	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11724	 11728	 0.005766	 0.032778	 0.00949	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11725	 11726	 0.003559	 0.025989	 0.00668	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11725	 11728	 0.00604	 0.04822	 0.01189	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11726	 11727	 0.002922	 0.028547	 0.00801	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11727	 78743	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11727	 78743	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11728	 12206	 0.002594	 0.039108	 0.01166	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11729	 11730	 0.019019	 0.067238	 0.01515	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11729	 78744	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11729	 78744	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11730	 11735	 0.002793	 0.030756	 0.01574	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77718	 11730	 0.014679	 0.12727	 0.04575	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11730	 78745	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11730	 78745	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11731	 12651	 0.27138	 0.21482	 0.0027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78745	 11731	 0.11348	 0.16613	 0.00257	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11732	 78746	 0.035492	 0.069558	 0.00104	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11733	 11735	 0.003446	 0.021826	 0.00592	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11733	 12669	 0.00512	 0.025245	 0.00683	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11733	 78746	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11733	 78746	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11734	 78747	 0.016354	 0.025052	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11735	 12669	 0.006762	 0.042019	 0.01186	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11735	 78747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11735	 78747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78747	 11736	 0.056341	 0.0941	 0.0016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78746	 11737	 0.15745	 0.12461	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11738	 78748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11738	 78748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11738	 79076	 0.01224	 0.049007	 0.01235	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11739	 12968	 0.017343	 0.13517	 0.00253	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78748	 11739	 0.020413	 0.12543	 0.00287	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11740	 11749	 0.016934	 0.043066	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11740	 12968	 0.052068	 0.17184	 0.00278	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11740	 78752	 0.016319	 0.041951	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11741	 11746	 0.074063	 0.052464	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11742	 78749	 0.025074	 0.045242	 0.00065	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11743	 11744	 0.000739	 0.005396	 0.00139	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11743	 78749	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11743	 78749	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11743	 79076	 0.002843	 0.015774	 0.00479	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11744	 11751	 0.001766	 0.012599	 0.0039	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11745	 11751	 0.002102	 0.016383	 0.0049	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11745	 78750	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11745	 78750	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78750	 11746	 0.005286	 0.020565	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78750	 11746	 0.005286	 0.020565	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11746	 78752	 0.013627	 0.053013	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11746	 78752	 0.013627	 0.053013	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11747	 11748	 0.001851	 0.005542	 0.00125	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11747	 12969	 0.006489	 0.030927	 0.00896	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11747	 78751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11747	 78751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11748	 12656	 0.015096	 0.09728	 0.02552	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11748	 78752	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11748	 78752	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78751	 11749	 0.002813	 0.012533	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78752	 11749	 0.002173	 0.009685	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11750	 11752	 0.14107	 0.11165	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78750	 11750	 0.013144	 0.051135	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78750	 11750	 0.013144	 0.051135	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78751	 11750	 0.00732	 0.028163	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78751	 11750	 0.00732	 0.028163	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77742	 11752	 0.086976	 0.13325	 0.00187	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11753	 11764	 0.081174	 0.16073	 0.00236	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11754	 78899	 0.1241	 0.097279	 0.00125	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11755	 11762	 0.00654	 0.038963	 0.01025	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11755	 12110	 0.009018	 0.036696	 0.00894	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11756	 11757	 0.003534	 0.02662	 0.00739	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11756	 12113	 0.003569	 0.024763	 0.00707	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11757	 11775	 0.003838	 0.02663	 0.0076	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11757	 78753	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11757	 78753	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11758	 78754	 0.071854	 0.051944	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11759	 11772	 0.003539	 0.016505	 0.00409	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11759	 11773	 0.00616	 0.026987	 0.00928	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11759	 78754	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11759	 78754	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11760	 11771	 0.071248	 0.072752	 0.00113	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11761	 11768	 0.003203	 0.025736	 0.00723	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11761	 12094	 0.019786	 0.090802	 0.02327	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11762	 13584	 0.010924	 0.069204	 0.01879	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11763	 13583	 0.25953	 0.19668	 0.00271	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11764	 78755	 0.008497	 0.034728	 0.0007	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11765	 13588	 0.013378	 0.061381	 0.01573	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11765	 78755	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11765	 78755	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78755	 11766	 0.009205	 0.018225	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11767	 11768	 0.009988	 0.026398	 0.00618	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11767	 13588	 0.017695	 0.064082	 0.01375	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11768	 11769	 0.001467	 0.005765	 0.00151	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11769	 11770	 0.000945	 0.003783	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11770	 11772	 0.002714	 0.013244	 0.00366	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11770	 78756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11770	 78756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78756	 11771	 0.008756	 0.028194	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11772	 78757	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11772	 78757	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11773	 12693	 0.006463	 0.032694	 0.0091	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11774	 11775	 0.002734	 0.020486	 0.005	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11774	 12694	 0.004041	 0.027736	 0.00809	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11776	 11777	 0.007107	 0.01683	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11776	 78784	 0.025305	 0.03876	 0.00067	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11777	 11832	 0.026925	 0.044905	 0.00065	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11777	 79239	 0.12524	 0.35935	 0.00553	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11778	 11780	 0.000457	 0.001987	 0.00057	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11778	 11793	 0.001755	 0.008563	 0.00236	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11779	 78763	 0.028931	 0.021286	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11780	 11828	 0.001031	 0.004639	 0.00123	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77732	 11781	 0.022719	 0.064471	 0.00101	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11781	 78765	 0.006485	 0.024947	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11782	 11783	 0.000769	 0.005336	 0.00152	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11782	 78758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11782	 78758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11782	 78764	 0.000769	 0.006599	 0.00188	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11783	 11825	 0.000895	 0.005668	 0.00154	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11784	 78759	 0.016166	 0.011451	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11785	 11786	 0.001064	 0.004791	 0.00127	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11785	 13816	 0.001209	 0.005869	 0.00134	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11786	 11823	 0.001325	 0.006656	 0.00173	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11786	 78759	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11786	 78759	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78758	 11787	 0.0072	 0.014797	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11787	 78781	 0.005634	 0.01308	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11788	 13818	 0.001839	 0.01335	 0.00461	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11788	 78760	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11788	 78760	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11789	 11798	 0.001903	 0.006923	 0.00212	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11789	 78761	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11789	 78761	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11789	 78768	 0.001046	 0.007399	 0.00203	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78761	 11790	 0.000905	 0.00637	 0.00013	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11790	 78765	 0.001712	 0.012514	 0.00023	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11791	 78762	 0.047729	 0.037772	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11792	 11793	 0.001236	 0.006438	 0.00169	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11792	 78762	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11792	 78762	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11792	 78768	 0.0012	 0.007256	 0.00185	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11793	 78763	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11793	 78763	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11794	 78764	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11794	 78766	 7.5e-05	 0.000795	 0.01188	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11795	 12156	 0.000343	 0.00847	 0.70404	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11795	 12620	 0.000904	 0.016744	 1.3506	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11795	 78766	 8.6e-05	 0.006874	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11795	 78766	 8.6e-05	 0.006874	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11795	 78766	 8.6e-05	 0.006874	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11796	 11797	 0.012739	 0.016743	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11796	 11813	 0.035746	 0.11925	 0.00189	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78769	 11796	 0.01037	 0.030494	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11798	 78770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11798	 78770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11798	 78771	 0.003209	 0.020671	 0.00542	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78770	 11799	 0.041955	 0.027161	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11800	 11824	 0.031477	 0.024673	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77749	 11800	 0.027568	 0.027649	 0.00045	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78770	 11800	 0.010576	 0.026788	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11801	 78772	 0.036829	 0.072919	 0.00107	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11802	 13070	 0.005893	 0.032335	 0.00855	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78768	 11802	 0.004342	 0.018377	 0.00414	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78767	 11803	 0.000592	 0.006435	 0.01399	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11803	 78771	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78772	 11803	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11804	 11806	 0.001514	 0.013209	 0.00363	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78771	 11804	 0.001793	 0.014553	 0.00463	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11805	 78773	 0.040488	 0.037294	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11806	 11807	 0.000458	 0.004379	 0.00144	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11806	 78773	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11806	 78773	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11807	 78774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11807	 78774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11807	 78775	 0.000565	 0.004272	 0.0021	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11808	 11809	 0.002003	 0.007793	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11808	 11813	 0.018681	 0.048023	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78773	 11808	 0.014537	 0.033748	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11809	 11810	 0.002114	 0.009421	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78774	 11810	 0.003604	 0.008279	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11810	 78776	 0.002158	 0.012867	 0.00036	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11811	 11817	 0.000794	 0.009837	 0.03551	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11811	 11819	 0.001205	 0.012004	 0.04006	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78767	 11811	 0.001158	 0.013541	 0.0474	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11811	 78775	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78776	 11811	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 11813	 0.020157	 0.051263	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11812	 11815	 0.017874	 0.079649	 0.00135	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77763	 11812	 0.023219	 0.049758	 0.00087	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78776	 11812	 0.015761	 0.036211	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11815	 11816	 0.017339	 0.077584	 0.0016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11816	 78780	 0.019406	 0.11924	 0.00273	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11817	 12155	 0.001129	 0.013755	 0.05131	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11817	 78777	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78778	 11817	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78778	 11818	 0.026786	 0.020996	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11819	 78779	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11819	 78779	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11819	 79240	 0.000673	 0.008128	 0.03557	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11820	 11821	 0.001629	 0.006894	 0.00155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78777	 11820	 0.002085	 0.030105	 0.00956	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11820	 78914	 0.002161	 0.016059	 0.00612	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11821	 11822	 0.000717	 0.003718	 0.00091	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11821	 78780	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11821	 78780	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11822	 78914	 0.000591	 0.008431	 0.00282	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78764	 11823	 0.001875	 0.009419	 0.00245	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11823	 78781	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11823	 78781	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11825	 11835	 0.000506	 0.003257	 0.00085	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11826	 11834	 0.001854	 0.012848	 0.00026	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11826	 78782	 0.000749	 0.005334	 0.00012	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11827	 78782	 0.007682	 0.004973	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11828	 11829	 0.000419	 0.001411	 0.00035	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11828	 78782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11828	 78782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11829	 11830	 0.000693	 0.002334	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11830	 11831	 0.000476	 0.001327	 0.00028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11831	 78783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11831	 78783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78783	 11832	 0.001864	 0.011463	 0.00021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11832	 78784	 0.003107	 0.013611	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11833	 11847	 0.00365	 0.014612	 0.00368	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78764	 11833	 0.002771	 0.022991	 0.00605	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11833	 78784	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11833	 78784	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11834	 78785	 0.001143	 0.007847	 0.00014	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11835	 11839	 0.000648	 0.003984	 0.00115	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11835	 78785	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11835	 78785	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11836	 11859	 0.001534	 0.007577	 0.00221	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78764	 11836	 0.002498	 0.020066	 0.00564	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11836	 78786	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11836	 78786	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77732	 11837	 0.001875	 0.004019	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78785	 11837	 0.001906	 0.007416	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78785	 11838	 0.019732	 0.015616	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11839	 11846	 0.000672	 0.003498	 0.00092	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11839	 78787	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11839	 78787	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78784	 11840	 0.038339	 0.030341	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78784	 11841	 0.065667	 0.051968	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11842	 11843	 0.033044	 0.02615	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11842	 11844	 0.006123	 0.0145	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78784	 11842	 0.00452	 0.01941	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11844	 78788	 0.007732	 0.011842	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11845	 11846	 0.000683	 0.002993	 0.00103	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11845	 11855	 0.00122	 0.005312	 0.00151	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11846	 78788	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11846	 78788	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11847	 11858	 0.002145	 0.013587	 0.00369	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11847	 78789	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11847	 78789	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11848	 11849	 0.010376	 0.020544	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11848	 11850	 0.018742	 0.031573	 0.00045	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78789	 11849	 0.003692	 0.020987	 0.00038	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11850	 11851	 0.037398	 0.031963	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11851	 78790	 0.012721	 0.026736	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11852	 11854	 0.001739	 0.006963	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11852	 11880	 0.003345	 0.016808	 0.00437	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11852	 78790	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11852	 78790	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11853	 78791	 0.032575	 0.025779	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11854	 11855	 0.001112	 0.005398	 0.00123	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11854	 78791	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11854	 78791	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11855	 78792	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11855	 78792	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78792	 11856	 0.021217	 0.013736	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11857	 78793	 0.028671	 0.020309	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11858	 11865	 0.000872	 0.00552	 0.0015	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78764	 11858	 0.003837	 0.035724	 0.01107	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11858	 78793	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11858	 78793	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11859	 11863	 0.001056	 0.005592	 0.00142	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11859	 78794	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11859	 78794	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11860	 11861	 0.016247	 0.011509	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78787	 11861	 0.011904	 0.013093	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78794	 11862	 0.002149	 0.012218	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11863	 11864	 0.001574	 0.008042	 0.00202	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11864	 11866	 0.001306	 0.005437	 0.0017	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11865	 11866	 0.001422	 0.007271	 0.00198	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11865	 11875	 0.001219	 0.017594	 0.00559	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11865	 78795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11865	 78795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11866	 11868	 0.00282	 0.008314	 0.00193	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77668	 11866	 0.002471	 0.016964	 0.00495	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11866	 78796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11866	 78796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11867	 78797	 0.017482	 0.011318	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11868	 11870	 0.003317	 0.008766	 0.00205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11868	 78797	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11868	 78797	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78795	 11869	 0.06205	 0.047011	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78797	 11869	 0.017735	 0.013048	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11870	 11871	 0.004317	 0.016968	 0.00444	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77668	 11870	 0.002119	 0.012817	 0.00327	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11871	 12326	 0.004037	 0.016667	 0.00394	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11872	 11880	 0.002178	 0.011123	 0.0028	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11872	 12457	 0.003542	 0.014993	 0.00337	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11872	 78798	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11872	 78798	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11873	 11875	 0.000655	 0.008189	 0.00358	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11873	 78799	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11873	 78799	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11873	 79021	 0.002864	 0.036682	 0.01095	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11874	 11878	 0.010204	 0.023146	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78795	 11874	 0.016038	 0.044424	 0.00073	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11875	 78800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11875	 78800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78798	 11876	 0.02775	 0.028029	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78798	 11877	 0.030869	 0.024429	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11878	 78801	 0.015334	 0.033938	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11879	 11881	 0.006038	 0.05621	 0.00109	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11879	 79022	 0.008968	 0.069081	 0.00132	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11880	 78801	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11880	 78801	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11881	 11882	 0.089412	 0.089677	 0.00145	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11881	 11883	 0.039686	 0.1544	 0.00258	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78793	 11881	 0.016162	 0.10303	 0.00251	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11883	 78802	 0.012355	 0.066601	 0.00134	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11884	 11885	 0.088397	 0.069291	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11885	 11886	 0.009761	 0.066226	 0.00124	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11885	 79019	 0.026627	 0.14962	 0.00277	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11886	 13062	 0.015994	 0.072604	 0.00157	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11886	 78802	 0.017886	 0.068811	 0.00117	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11887	 11888	 0.005902	 0.023629	 0.00595	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11887	 13057	 0.025797	 0.07195	 0.0151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11887	 78802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11887	 78802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11888	 11889	 0.002514	 0.010067	 0.00254	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11888	 78803	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11888	 78803	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11889	 13065	 0.0054	 0.024774	 0.00635	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11890	 78804	 0.003153	 0.010519	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11890	 78805	 0.002527	 0.006497	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11890	 78807	 0.006162	 0.016288	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11891	 11912	 0.000141	 0.001882	 0.00051	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11891	 11916	 0.000242	 0.001624	 0.00102	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11891	 13153	 8.2e-05	 0.001459	 0.00073	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11891	 78804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11891	 78804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11892	 11893	 8.5e-05	 0.000989	 0.00029	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11892	 12028	 0.000175	 0.001971	 0.00057	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11892	 78805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11892	 78805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11893	 11896	 0.000161	 0.001907	 0.00054	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11894	 13454	 0.002564	 0.009976	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11894	 78807	 0.001715	 0.009748	 0.00018	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11895	 11896	 0.000949	 0.00295	 0.00062	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11895	 78806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11895	 78806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11896	 11901	 0.000326	 0.003196	 0.001	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11896	 13174	 0.001351	 0.007911	 0.00216	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11896	 78807	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11896	 78807	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11896	 78832	 0.002446	 0.026249	 0.00683	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78807	 11897	 0.001475	 0.006571	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11897	 78812	 0.001449	 0.007375	 0.00017	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11898	 11899	 0.001578	 0.004183	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11898	 78813	 0.003686	 0.007746	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11899	 78808	 0.001952	 0.005173	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11900	 11903	 0.000415	 0.002278	 0.0006	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11900	 11906	 0.000424	 0.002564	 0.00065	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11900	 78808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11900	 78808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11901	 11903	 0.000164	 0.001626	 0.0005	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11902	 11903	 0.000691	 0.002767	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11902	 11904	 0.000297	 0.002546	 0.00072	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11902	 12009	 0.001213	 0.005566	 0.00143	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11902	 78809	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11902	 78809	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11903	 12011	 0.001765	 0.006419	 0.00197	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11904	 11905	 0.000543	 0.002133	 0.00056	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11904	 11987	 0.00066	 0.004668	 0.00128	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11904	 78810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11904	 78810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11905	 11906	 0.000342	 0.002124	 0.0006	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11905	 11989	 0.000423	 0.002628	 0.00064	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11906	 78811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11906	 78811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11907	 11908	 0.009875	 0.006995	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78811	 11908	 0.005139	 0.01321	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11908	 78820	 0.001838	 0.007366	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11909	 78820	 0.014321	 0.011333	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11910	 11931	 0.000448	 0.003482	 0.0009	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11910	 11943	 0.00032	 0.002615	 0.00071	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11911	 78819	 0.017009	 0.012514	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11912	 11913	 0.000161	 0.00198	 0.00064	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11913	 11914	 0.000225	 0.001581	 0.0009	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11913	 78812	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11913	 78812	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11914	 11915	 0.000343	 0.002134	 0.0006	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11914	 11931	 0.000249	 0.003922	 0.00134	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11914	 78813	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11914	 78813	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11915	 11917	 0.000329	 0.002149	 0.00055	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11916	 11917	 0.000208	 0.002998	 0.00095	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11916	 78814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11916	 78814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11917	 11920	 0.000277	 0.003549	 0.00106	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11918	 13136	 0.001608	 0.005745	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78814	 11918	 0.002325	 0.009302	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11919	 78815	 0.001376	 0.005353	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11919	 79260	 0.002629	 0.011716	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11920	 11921	 0.000115	 0.001675	 0.00054	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11920	 78815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11920	 78815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11920	 79357	 0.001172	 0.010051	 0.00286	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11921	 11928	 0.000167	 0.002297	 0.00083	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11922	 79260	 0.010529	 0.008333	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11923	 11929	 0.003052	 0.006246	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11923	 78817	 0.002433	 0.009942	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11924	 78816	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11924	 78821	 5.2e-05	 0.000527	 0.00867	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11924	 78821	 5.2e-05	 0.000527	 0.00867	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11924	 79259	 5.5e-05	 0.000564	 0.00886	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11924	 79259	 5.5e-05	 0.000564	 0.00886	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11925	 11926	 0.01093	 0.007076	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11925	 11935	 0.005455	 0.008356	 0.00015	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11925	 78828	 0.003509	 0.007958	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11927	 11928	 0.000226	 0.001333	 0.00109	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11927	 11934	 0.000259	 0.00324	 0.00142	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11927	 78818	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11927	 78818	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11928	 78819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11928	 78819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78819	 11929	 0.00317	 0.00506	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78818	 11930	 0.017268	 0.013245	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11931	 78820	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11931	 78820	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11931	 78832	 0.002401	 0.017536	 0.00451	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11932	 78823	 0.009943	 0.007869	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11933	 11938	 9e-06	 0.000194	 0.01971	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11933	 13130	 1.8e-05	 0.00051	 0.03547	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11933	 78821	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11933	 78821	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78822	 11933	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78822	 11933	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11934	 11940	 0.00033	 0.004846	 0.00148	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11934	 78823	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11934	 78823	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78823	 11935	 0.011903	 0.008432	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11936	 78825	 0.013315	 0.010538	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11937	 78824	 0.024562	 0.019438	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11938	 11939	 1.2e-05	 0.000287	 0.02378	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11939	 11947	 7e-06	 0.000163	 0.01626	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11939	 78824	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11939	 78824	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11940	 78825	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11940	 78825	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11940	 78832	 0.000479	 0.003753	 0.00172	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11941	 11942	 1.4e-05	 0.000194	 0.00296	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11941	 78826	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11941	 78826	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11941	 78831	 1.8e-05	 0.000247	 0.0037	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11942	 11946	 3.1e-05	 0.000464	 0.00831	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11942	 78827	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11942	 78827	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11943	 11944	 0.000256	 0.002198	 0.00063	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11943	 11990	 0.000674	 0.002696	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11943	 78828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11943	 78828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11944	 12029	 0.000394	 0.003782	 0.0011	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78826	 11945	 0.011437	 0.020557	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11945	 78830	 0.00426	 0.013081	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11945	 78861	 0.0183	 0.017682	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77702	 11946	 2.7e-05	 0.000407	 0.0073	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11946	 78829	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11947	 78831	 7.6e-05	 0.006111	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11947	 78831	 7.6e-05	 0.006111	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11948	 11953	 6e-06	 0.00014	 0.01648	 3786.0	 3975.3	 4164.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11948	 78834	 0.000131	 0.010475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11948	 78834	 0.000131	 0.010475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78835	 11948	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11949	 11950	 0.00019	 0.001982	 0.00067	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11949	 11952	 0.000254	 0.001808	 0.00056	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78829	 11949	 0.000199	 0.003132	 0.00107	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11950	 11951	 0.000215	 0.001901	 0.00051	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11950	 78836	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11950	 78836	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11951	 78845	 0.000253	 0.002379	 0.00072	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78835	 11952	 0.000333	 0.003762	 0.00145	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11952	 78837	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11952	 78837	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11952	 78840	 7.7e-05	 0.000992	 0.00079	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11953	 11954	 3e-06	 7.7e-05	 0.00744	 3786.0	 3975.3	 4164.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11953	 78838	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11953	 78838	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11954	 11957	 1.4e-05	 0.000336	 0.03397	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11954	 11957	 1.4e-05	 0.000336	 0.03397	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 0	 -30.0	 30.0;
	11954	 78839	 9.5e-05	 0.007586	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11954	 78839	 9.5e-05	 0.007586	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11954	 78839	 9.5e-05	 0.007586	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78840	 11954	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78840	 11954	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11955	 11956	 3e-05	 0.000301	 0.00515	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11955	 11956	 3e-05	 0.000301	 0.00515	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78839	 11955	 2.9e-05	 0.000287	 0.00491	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78839	 11955	 2.9e-05	 0.000287	 0.00491	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11955	 78841	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11955	 78841	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11956	 78842	 2.7e-05	 0.000265	 0.00454	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11956	 78842	 2.7e-05	 0.000265	 0.00454	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11957	 11958	 5e-06	 0.00013	 0.01318	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11957	 11958	 5e-06	 0.00013	 0.01318	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 0	 -30.0	 30.0;
	11957	 78842	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11957	 78842	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78843	 11957	 0.00012	 0.00961	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11958	 11966	 8e-06	 0.000215	 0.018	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11958	 11966	 8e-06	 0.000215	 0.018	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 0	 -30.0	 30.0;
	11958	 78844	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11958	 78844	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78844	 11959	 0.008056	 0.005927	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11960	 11961	 0.010443	 0.008264	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11961	 11962	 0.016794	 0.013291	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11961	 78846	 0.005135	 0.013059	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11962	 78858	 0.035129	 0.027801	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77726	 11963	 0.000262	 0.003191	 0.0119	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11963	 78845	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78846	 11963	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11963	 78847	 0.000139	 0.001362	 0.00467	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11964	 78849	 0.013534	 0.010711	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78842	 11965	 5.7e-05	 0.000586	 0.00921	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78842	 11965	 5.7e-05	 0.000586	 0.00921	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11965	 78847	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11965	 78850	 7.7e-05	 0.000791	 0.01243	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11965	 78850	 7.7e-05	 0.000791	 0.01243	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11966	 11967	 1e-05	 0.000245	 0.02481	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11966	 11967	 1e-05	 0.000245	 0.02481	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 0	 -30.0	 30.0;
	11966	 78850	 0.000131	 0.010475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11966	 78850	 0.000131	 0.010475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11967	 13882	 5.6e-05	 0.001367	 0.13827	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11967	 13882	 5.6e-05	 0.001367	 0.13827	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11967	 78853	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11967	 78853	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11968	 11970	 0.000151	 0.00215	 0.00113	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11968	 12027	 0.001318	 0.008824	 0.00555	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77624	 11968	 0.002987	 0.010245	 0.00245	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78853	 11968	 0.000591	 0.002758	 0.00068	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11969	 11970	 0.000405	 0.004384	 0.00137	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11969	 11974	 0.000886	 0.008506	 0.00247	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11969	 78854	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11969	 78854	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78851	 11970	 0.00044	 0.004863	 0.00146	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	11970	 78855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11970	 78855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78855	 11971	 0.010005	 0.025718	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11971	 78876	 0.024461	 0.055485	 0.00111	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11972	 11976	 0.001395	 0.005584	 0.00189	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78848	 11972	 0.001029	 0.005204	 0.00145	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11972	 78856	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11972	 78856	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78854	 11973	 0.013551	 0.016222	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11974	 11979	 0.001053	 0.007445	 0.00204	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11974	 78857	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11974	 78857	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11975	 12025	 0.018978	 0.03197	 0.00046	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78857	 11975	 0.017367	 0.024204	 0.00041	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11976	 11977	 0.001136	 0.004549	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11976	 78858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11976	 78858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11977	 12032	 0.001416	 0.005668	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11978	 11979	 0.000583	 0.005085	 0.0014	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11978	 11992	 0.001362	 0.010257	 0.00285	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11978	 78859	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11978	 78859	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11979	 78860	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11979	 78860	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11980	 11983	 0.003458	 0.015235	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11980	 11986	 0.029069	 0.023004	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11980	 78862	 0.009097	 0.023384	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11981	 11984	 0.000421	 0.004039	 0.00117	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11981	 12032	 0.000335	 0.003271	 0.00092	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11981	 78861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11981	 78861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11982	 11983	 0.0044	 0.006412	 0.00014	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11982	 11994	 0.016895	 0.010938	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11983	 11993	 0.004433	 0.011274	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78849	 11983	 0.010437	 0.07164	 0.00131	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11984	 11987	 0.001674	 0.010603	 0.00288	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11984	 11991	 0.000495	 0.003431	 0.00098	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77703	 11984	 0.001791	 0.011345	 0.00308	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11984	 78862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11984	 78862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11985	 11990	 0.000366	 0.00245	 0.00075	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11985	 11991	 0.000275	 0.00169	 0.00062	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11985	 78863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11985	 78863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11987	 11995	 0.005048	 0.013742	 0.00303	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11987	 12020	 0.007208	 0.018713	 0.00454	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11987	 78864	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11987	 78864	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11988	 11989	 0.000585	 0.003487	 0.00092	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11988	 11990	 0.000401	 0.002281	 0.00066	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11988	 78865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11988	 78865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11992	 11996	 0.001041	 0.007145	 0.00208	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78859	 11993	 0.014513	 0.033687	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11995	 11996	 0.001816	 0.005675	 0.00164	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11995	 12021	 0.002239	 0.010207	 0.00324	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11995	 78866	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11995	 78866	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11996	 11999	 0.001184	 0.005947	 0.00155	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	11997	 12001	 0.000739	 0.004591	 0.0013	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11997	 12020	 0.001107	 0.006877	 0.00194	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	11997	 78867	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11997	 78867	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78867	 11998	 0.022674	 0.014679	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11998	 78873	 0.021789	 0.017934	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11999	 12011	 0.000813	 0.004234	 0.00111	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11999	 78868	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11999	 78868	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12000	 12001	 0.001066	 0.005037	 0.00161	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12000	 12005	 0.001296	 0.00504	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12000	 78869	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12000	 78869	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12001	 78870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12001	 78870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12002	 12003	 0.000525	 0.002638	 0.00069	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12002	 12011	 0.000564	 0.002586	 0.00066	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12002	 78871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12002	 78871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12003	 12004	 0.000671	 0.003079	 0.00079	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12004	 12005	 0.000241	 0.002313	 0.00067	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12004	 12009	 0.001169	 0.004549	 0.00122	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12004	 78872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12004	 78872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12005	 12882	 0.000205	 0.002265	 0.00068	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12006	 12007	 0.016014	 0.010367	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12007	 12008	 0.004001	 0.010175	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78806	 12007	 0.007287	 0.014428	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78872	 12008	 0.005071	 0.010378	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78809	 12010	 0.017796	 0.013949	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12011	 78873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12011	 78873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78810	 12012	 0.002487	 0.012136	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78871	 12012	 0.009855	 0.022641	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78873	 12012	 0.017523	 0.013867	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12013	 12015	 0.004581	 0.021544	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12013	 12016	 0.003421	 0.019446	 0.00035	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78869	 12013	 0.01024	 0.024247	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78870	 12013	 0.006398	 0.021343	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12014	 12016	 0.004415	 0.011348	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12014	 12877	 0.011342	 0.018943	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12015	 78874	 0.006132	 0.027172	 0.00082	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12016	 12017	 0.009267	 0.028458	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12016	 12876	 0.012805	 0.018178	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12017	 12018	 0.016195	 0.029221	 0.00042	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12017	 12894	 0.005782	 0.022494	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12018	 79169	 0.018648	 0.056128	 0.0011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78866	 12019	 0.021158	 0.027535	 0.00039	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12019	 78875	 0.011774	 0.030266	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12020	 12021	 0.000879	 0.006095	 0.00174	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12020	 78874	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12020	 78874	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78709	 12021	 0.004314	 0.037644	 0.01034	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12021	 78875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12021	 78875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78859	 12022	 0.008013	 0.029348	 0.00074	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12023	 12025	 0.0081	 0.036095	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78708	 12023	 0.024784	 0.06371	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78710	 12024	 0.10808	 0.088963	 0.0018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12024	 78876	 0.006087	 0.037422	 0.00067	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78854	 12025	 0.038529	 0.061501	 0.00142	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78859	 12025	 0.025622	 0.060674	 0.00111	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12026	 12027	 0.003477	 0.009696	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12026	 78876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12026	 78876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12027	 14134	 0.000593	 0.009713	 0.00305	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12028	 13170	 0.000234	 0.002477	 0.00074	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78827	 12029	 0.000295	 0.002985	 0.00088	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12029	 78877	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12029	 78877	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78863	 12030	 0.003791	 0.014018	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78877	 12030	 0.001761	 0.009382	 0.00016	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78838	 12031	 0.000419	 0.001437	 0.00034	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12031	 78878	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12031	 78878	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78845	 12032	 0.001231	 0.009225	 0.00225	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12033	 13129	 0.002099	 0.006188	 0.00144	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77660	 12033	 0.003186	 0.008419	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12033	 78879	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12033	 78879	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12034	 12678	 0.057451	 0.16479	 0.00253	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77735	 12034	 0.030153	 0.099509	 0.00161	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12035	 12037	 0.004334	 0.037171	 0.01058	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12035	 12150	 0.013194	 0.052829	 0.01331	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12035	 12228	 0.009529	 0.048677	 0.01225	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12035	 78880	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12035	 78880	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12036	 78881	 0.013858	 0.06141	 0.00184	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12036	 78882	 0.018159	 0.13273	 0.00245	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12037	 12040	 0.001615	 0.017504	 0.00547	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12037	 78881	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12037	 78881	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12038	 12042	 0.02739	 0.13366	 0.00231	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78741	 12038	 0.030217	 0.20744	 0.00378	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12039	 12227	 0.008201	 0.031173	 0.00873	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12039	 78882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12039	 78882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12040	 12041	 0.002267	 0.021102	 0.00654	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12041	 12677	 0.014126	 0.074828	 0.01897	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77718	 12041	 0.014256	 0.1215	 0.03034	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12041	 78883	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12041	 78883	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78883	 12042	 0.031705	 0.058953	 0.00138	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 78888	 0.020465	 0.014497	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12044	 78887	 0.009821	 0.013387	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12045	 78885	 0.012302	 0.013531	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12046	 12054	 0.002046	 0.00713	 0.00165	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12046	 78884	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12046	 78884	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78884	 12047	 0.023967	 0.018967	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12048	 78889	 0.004495	 0.012754	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12049	 12050	 0.01238	 0.009797	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78884	 12050	 0.006279	 0.009192	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12051	 78885	 0.009503	 0.007521	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12052	 78885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12052	 78885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12052	 78886	 0.001412	 0.004842	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12053	 78886	 0.00012	 0.00961	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12054	 12057	 0.0014	 0.01144	 0.0031	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12054	 12061	 0.000261	 0.001751	 0.0011	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12054	 12100	 0.006714	 0.057587	 0.01639	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78886	 12054	 0.000336	 0.005022	 0.00169	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12054	 78888	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12054	 78888	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12055	 12056	 0.011049	 0.008744	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12055	 12060	 0.008717	 0.006175	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12055	 12067	 0.018437	 0.014591	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12055	 12068	 0.011101	 0.014325	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78888	 12055	 0.003307	 0.018799	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12057	 12058	 0.000916	 0.003665	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12057	 12096	 0.001871	 0.006304	 0.00157	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12057	 78889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12057	 78889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12058	 78890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12058	 78890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12059	 12068	 0.008394	 0.006642	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12061	 12066	 0.00022	 0.001724	 0.00079	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78888	 12062	 0.011423	 0.008954	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78887	 12063	 0.019797	 0.015667	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12064	 12065	 0.000195	 0.001372	 0.00078	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78886	 12064	 0.000412	 0.003232	 0.00148	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12065	 12066	 0.000218	 0.001579	 0.00085	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12069	 12091	 0.029615	 0.020978	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78890	 12069	 0.002864	 0.012761	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12070	 12092	 0.011967	 0.023693	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12071	 12072	 0.024948	 0.025021	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12072	 12089	 0.017326	 0.021122	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78887	 12072	 0.005148	 0.022939	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12073	 78891	 0.15378	 0.12171	 0.00153	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12074	 12076	 0.08104	 0.052467	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12075	 78900	 0.08748	 0.069232	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12076	 78900	 0.022811	 0.018053	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12077	 12078	 0.001458	 0.008001	 0.00211	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12077	 12080	 0.00456	 0.020318	 0.00552	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12078	 12113	 0.004713	 0.030819	 0.00784	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12078	 78891	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12078	 78891	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12079	 12087	 0.085135	 0.085158	 0.00115	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78886	 12080	 0.008761	 0.03708	 0.00834	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12081	 78893	 0.086612	 0.058181	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12082	 78893	 0.010864	 0.019602	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12083	 78892	 0.014067	 0.027851	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78886	 12084	 0.00136	 0.005345	 0.0014	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12084	 78892	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12084	 78892	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12085	 12086	 0.002089	 0.007166	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78886	 12085	 0.002448	 0.008907	 0.00273	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12086	 78893	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12086	 78893	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78892	 12087	 0.012095	 0.031091	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78893	 12088	 0.03536	 0.027984	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78892	 12090	 0.014888	 0.029477	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78888	 12092	 0.010368	 0.041491	 0.00088	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12093	 12103	 0.14697	 0.11632	 0.00146	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12093	 78894	 0.044392	 0.078071	 0.00147	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12094	 12104	 0.012557	 0.075388	 0.02284	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12094	 12110	 0.014454	 0.049586	 0.01188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78886	 12094	 0.001833	 0.018843	 0.00713	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12094	 78894	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12094	 78894	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12095	 78895	 0.024435	 0.019337	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12096	 78895	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12096	 78895	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12097	 12098	 0.077204	 0.061099	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78895	 12097	 0.013357	 0.021321	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12099	 12111	 0.044762	 0.04011	 0.00082	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12100	 13605	 0.062315	 0.18688	 0.04217	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12100	 78896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12100	 78896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76676	 12101	 0.086308	 0.33215	 0.00567	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76676	 12101	 0.086308	 0.33215	 0.00567	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78896	 12101	 0.00385	 0.014976	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78896	 12101	 0.00385	 0.014976	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78896	 12102	 0.079226	 0.080022	 0.00106	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12104	 12105	 0.00449	 0.012054	 0.00273	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12104	 13600	 0.015243	 0.053129	 0.01232	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12104	 78897	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12104	 78897	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12105	 13600	 0.011837	 0.03861	 0.01025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12105	 78898	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12105	 78898	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12106	 12107	 0.011167	 0.03361	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78897	 12106	 0.060262	 0.11932	 0.00175	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12107	 12108	 0.04383	 0.11267	 0.00174	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78894	 12107	 0.059029	 0.18111	 0.00491	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78894	 12108	 0.042786	 0.1314	 0.00247	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12109	 78899	 0.023218	 0.037061	 0.00085	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12110	 78899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12110	 78899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78890	 12111	 0.009309	 0.024672	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78885	 12112	 0.015281	 0.031272	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12113	 78900	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12113	 78900	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12114	 12115	 0.095477	 0.061814	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12114	 12125	 0.015671	 0.060291	 0.00103	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12114	 13754	 0.033484	 0.051294	 0.00072	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12116	 12149	 0.002664	 0.010128	 0.00283	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12116	 13759	 0.003784	 0.012979	 0.00311	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12117	 79435	 0.059318	 0.046944	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12118	 79435	 0.11962	 0.090636	 0.00125	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12119	 12120	 0.00673	 0.030303	 0.00806	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12119	 13535	 0.012145	 0.054125	 0.01471	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12119	 78901	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12119	 78901	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12120	 12121	 0.001356	 0.006581	 0.0015	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12120	 78902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12120	 78902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12121	 12123	 0.00252	 0.013394	 0.00311	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12121	 78903	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12121	 78903	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78903	 12122	 0.012371	 0.012632	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12123	 12131	 0.001926	 0.017933	 0.00556	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12123	 12149	 0.002484	 0.012055	 0.00276	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12124	 78908	 0.11749	 0.092097	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12125	 78906	 0.037397	 0.12476	 0.00198	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12125	 78907	 0.035266	 0.066652	 0.00108	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12126	 13665	 0.003009	 0.010894	 0.00234	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12126	 78904	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12126	 78904	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12126	 78905	 0.003894	 0.015589	 0.00393	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12127	 13656	 0.00337	 0.021877	 0.04358	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12127	 78905	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78906	 12127	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12127	 78924	 0.00145	 0.010164	 0.0173	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12128	 12129	 0.004846	 0.012806	 0.003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12128	 12130	 0.003602	 0.014658	 0.00357	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12128	 12145	 0.004759	 0.018706	 0.00489	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78905	 12128	 0.002932	 0.016846	 0.00477	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12129	 78907	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12129	 78907	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12130	 12132	 0.003829	 0.01393	 0.00426	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12131	 12132	 0.000815	 0.007675	 0.00232	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12131	 78908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12131	 78908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12132	 12145	 0.003744	 0.030602	 0.0083	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12132	 78909	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12132	 78909	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12132	 81803	 0.034161	 0.21684	 0.05903	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12133	 12140	 0.020123	 0.037416	 0.00088	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78909	 12133	 0.010155	 0.033512	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12134	 12137	 0.005103	 0.013118	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12134	 12138	 0.018228	 0.013982	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78909	 12134	 0.007221	 0.013427	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12135	 12136	 0.014273	 0.011188	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12135	 12137	 0.006222	 0.020756	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77690	 12135	 0.018254	 0.11052	 0.00346	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12135	 78911	 0.011654	 0.066249	 0.0012	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12139	 78911	 0.087709	 0.068752	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12140	 12141	 0.11624	 0.075258	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12140	 78911	 0.12454	 0.12718	 0.00198	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12142	 12144	 0.008635	 0.03394	 0.00888	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12142	 13548	 0.017388	 0.069629	 0.01755	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12142	 78910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12142	 78910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78910	 12143	 0.19056	 0.15083	 0.0019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12144	 78911	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12144	 78911	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77709	 12145	 0.001285	 0.010078	 0.00461	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12146	 12147	 0.006283	 0.024441	 0.00653	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77689	 12146	 0.000759	 0.003862	 0.0014	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77709	 12146	 0.000601	 0.00306	 0.00111	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77745	 12148	 0.092644	 0.073319	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12150	 78912	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12150	 78912	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78734	 12151	 0.17059	 0.12333	 0.00187	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12152	 13593	 0.011063	 0.054555	 0.01475	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12152	 13605	 0.013987	 0.086942	 0.02455	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12152	 78913	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12152	 78913	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12153	 12154	 0.003214	 0.020572	 0.00692	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12153	 12201	 0.002863	 0.022273	 0.00579	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12154	 78917	 0.003854	 0.028882	 0.00704	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12155	 78914	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12155	 78914	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12155	 78916	 0.000652	 0.007325	 0.0134	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12155	 78916	 0.000652	 0.007325	 0.0134	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12155	 79998	 0.009678	 0.064632	 0.12205	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12156	 15599	 0.000245	 0.006267	 0.42921	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12156	 78915	 9.5e-05	 0.007586	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12156	 78915	 9.5e-05	 0.007586	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12157	 12158	 0.00161	 0.015727	 0.00441	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78914	 12157	 0.005632	 0.024515	 0.00698	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12158	 15583	 0.01159	 0.073426	 0.01994	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78917	 12158	 0.004312	 0.019216	 0.00522	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12158	 78919	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12158	 78919	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12159	 12173	 0.003096	 0.019234	 0.00543	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12159	 12174	 0.005864	 0.037141	 0.01008	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78914	 12159	 0.006738	 0.044059	 0.0112	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12159	 78920	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12159	 78920	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12160	 12161	 0.021512	 0.02366	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12161	 12162	 0.038905	 0.030789	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12161	 12163	 0.006835	 0.016186	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12161	 12164	 0.029345	 0.02159	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78918	 12161	 0.00904	 0.055575	 0.001	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77746	 12165	 0.006117	 0.039817	 0.00081	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12167	 12168	 0.0044	 0.022106	 0.00575	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12168	 12180	 0.004632	 0.027128	 0.00739	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12168	 15598	 0.016928	 0.05648	 0.01433	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12169	 12170	 0.004779	 0.036618	 0.00981	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12169	 12182	 0.006471	 0.045086	 0.01695	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12170	 12172	 0.003632	 0.016939	 0.0042	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12170	 78921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12170	 78921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78921	 12171	 0.016342	 0.032356	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12172	 12174	 0.005254	 0.022238	 0.005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12174	 12177	 0.001759	 0.007044	 0.00177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12174	 15596	 0.002133	 0.011307	 0.00377	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12175	 78923	 0.023584	 0.01809	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12176	 12177	 0.00163	 0.005069	 0.00106	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12176	 78922	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12176	 78922	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12177	 78923	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12177	 78923	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12178	 12179	 0.072689	 0.047059	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78922	 12178	 0.010538	 0.034775	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12180	 12181	 0.001936	 0.031159	 0.01018	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78917	 12180	 0.010022	 0.078138	 0.02337	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12182	 81814	 0.009772	 0.050905	 0.01335	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12183	 12184	 0.000157	 0.002463	 0.02567	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77687	 12183	 0.000215	 0.002761	 0.02597	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12183	 78924	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12183	 78924	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12184	 13647	 0.000319	 0.00501	 0.05221	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12185	 13645	 0.048893	 0.12569	 0.00195	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12185	 78925	 0.033891	 0.097205	 0.00149	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12186	 13669	 0.065625	 0.21895	 0.00347	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12186	 20173	 0.045755	 0.14037	 0.0038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12186	 20173	 0.045755	 0.14037	 0.0038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12186	 78925	 0.02514	 0.16222	 0.00516	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77689	 12187	 0.012106	 0.049267	 0.01201	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12187	 78925	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12187	 78925	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12187	 81809	 0.025157	 0.070165	 0.01473	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12188	 12189	 0.043396	 0.06927	 0.0016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12188	 12190	 0.055127	 0.10915	 0.0016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77690	 12188	 0.094135	 0.17244	 0.00298	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78925	 12188	 0.027113	 0.064204	 0.00117	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78925	 12189	 0.014789	 0.03433	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77690	 12191	 0.13994	 0.1097	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12192	 79108	 0.14584	 0.11542	 0.00145	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12194	 12714	 0.010527	 0.067817	 0.01778	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12195	 12196	 0.012183	 0.069254	 0.00125	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77770	 12195	 0.013564	 0.069626	 0.00132	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78589	 12195	 0.047337	 0.26914	 0.00487	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12196	 79109	 0.032538	 0.12659	 0.00211	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78591	 12197	 0.001857	 0.026257	 0.0087	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12197	 78926	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12197	 78926	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12198	 12202	 0.004685	 0.034243	 0.0101	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12198	 12203	 0.004204	 0.033775	 0.00949	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12198	 78927	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12198	 78927	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12199	 12715	 0.000987	 0.014597	 0.00502	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12199	 78928	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12199	 78928	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77770	 12200	 0.043555	 0.16945	 0.00283	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78928	 12200	 0.030161	 0.064634	 0.00113	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12200	 79109	 0.026331	 0.10244	 0.00171	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12201	 12202	 0.003729	 0.028091	 0.00779	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12203	 78929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12203	 78929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12204	 12212	 0.006795	 0.068696	 0.02021	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12204	 12237	 0.002238	 0.022177	 0.00679	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12204	 78930	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12204	 78930	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12205	 78932	 0.1386	 0.21024	 0.00301	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12206	 12207	 0.001398	 0.021462	 0.006	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12206	 78931	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12206	 78931	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12207	 12211	 0.005804	 0.054041	 0.01674	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12207	 12217	 0.0042	 0.026605	 0.00722	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12208	 78932	 0.1154	 0.091331	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12209	 12210	 0.001713	 0.016122	 0.00488	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77674	 12209	 0.002083	 0.020349	 0.00571	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12210	 12211	 0.002113	 0.013383	 0.00363	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12210	 12213	 0.001634	 0.006651	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12211	 12217	 0.002618	 0.028255	 0.00968	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12211	 78935	 0.000909	 0.013606	 0.00457	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12212	 12214	 0.000814	 0.009004	 0.0027	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12212	 78932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12212	 78932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12213	 12214	 0.000469	 0.001908	 0.00046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12214	 12215	 0.000193	 0.00063	 0.00017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12215	 78933	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12215	 78933	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78933	 12216	 0.02143	 0.01696	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12217	 12218	 0.004478	 0.024845	 0.00755	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77669	 12219	 0.000427	 0.004966	 0.04293	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77679	 12219	 0.000181	 0.003271	 0.05161	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12219	 78934	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12219	 78934	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77680	 12220	 0.000197	 0.003149	 0.00646	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77685	 12220	 0.001718	 0.014317	 0.04466	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77708	 12220	 0.001566	 0.015856	 0.03192	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12220	 78935	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78936	 12220	 0.000321	 0.02569	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78936	 12221	 0.011792	 0.018823	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12222	 12223	 0.10047	 0.078754	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12223	 13704	 0.047063	 0.12198	 0.00231	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77682	 12223	 0.075091	 0.1265	 0.0018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12223	 79439	 0.13501	 0.13637	 0.00181	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77672	 12224	 0.030945	 0.12086	 0.00268	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77682	 12224	 0.01174	 0.064251	 0.00126	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12225	 13778	 0.01152	 0.030447	 0.00713	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77681	 12225	 0.010414	 0.029041	 0.0061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77670	 12226	 0.000993	 0.007641	 0.01362	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77680	 12226	 0.001231	 0.011283	 0.04454	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12226	 78937	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12226	 78937	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12227	 12229	 0.006922	 0.039774	 0.01127	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78738	 12227	 0.008058	 0.032791	 0.00799	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12227	 78938	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12227	 78938	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12228	 12229	 0.002727	 0.022629	 0.00595	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12228	 78939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12228	 78939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12229	 12230	 0.006282	 0.022855	 0.007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12230	 12231	 0.000915	 0.003872	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12231	 12232	 0.001394	 0.005422	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12232	 12235	 0.010137	 0.040587	 0.01023	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12232	 78940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12232	 78940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12233	 12234	 0.000159	 0.001765	 0.01665	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12233	 12236	 0.000422	 0.004868	 0.04268	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12236	 78941	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12236	 78941	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12236	 79077	 0.005053	 0.074209	 1.165	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 0	 -30.0	 30.0;
	12236	 95336	 0.002589	 0.035133	 0.62225	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78941	 12237	 0.001175	 0.013437	 0.00376	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12237	 78942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12237	 78942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77674	 12238	 0.00702	 0.10325	 0.0316	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78941	 12238	 0.001568	 0.020088	 0.006	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12238	 78943	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12238	 78943	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78942	 12239	 0.013799	 0.043815	 0.00077	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78943	 12239	 0.002232	 0.010897	 0.00023	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12240	 12243	 0.002779	 0.02053	 0.00593	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12240	 12722	 0.006098	 0.040862	 0.01252	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12240	 78944	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12240	 78944	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12241	 13073	 0.000212	 0.00359	 0.07799	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12241	 78945	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12241	 78945	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12242	 79110	 0.075755	 0.14847	 0.00223	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12243	 13064	 0.00449	 0.030119	 0.00727	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12244	 13525	 0.074692	 0.17161	 0.00261	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12244	 79237	 0.050032	 0.11225	 0.00179	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12244	 79376	 0.026129	 0.12751	 0.0022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12245	 78946	 0.004722	 0.009255	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12246	 12265	 0.000302	 0.00275	 0.00069	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12246	 12292	 0.003824	 0.026533	 0.00757	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12246	 78946	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12246	 78946	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12247	 12248	 0.013305	 0.009789	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78946	 12247	 0.008372	 0.009208	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12249	 12296	 0.002714	 0.012092	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78946	 12249	 0.00164	 0.010085	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12249	 78948	 0.003065	 0.013503	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12250	 12295	 0.002991	 0.009977	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12250	 78947	 0.002492	 0.008313	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12251	 12256	 0.000869	 0.003678	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12251	 12276	 0.007992	 0.021122	 0.00494	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12251	 78947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12251	 78947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12252	 12253	 0.015423	 0.012205	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12252	 12293	 0.002158	 0.018326	 0.00043	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78947	 12252	 0.004327	 0.016835	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78947	 12252	 0.004327	 0.016835	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12254	 12259	 0.005027	 0.030553	 0.00056	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12254	 12290	 0.004363	 0.02085	 0.00046	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12255	 12278	 0.059668	 0.060267	 0.0008	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78947	 12255	 0.008484	 0.010156	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12256	 12258	 0.00056	 0.002569	 0.00066	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12256	 78948	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12256	 78948	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12257	 12258	 0.000391	 0.001967	 0.00051	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12257	 12261	 0.000268	 0.001441	 0.00035	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12258	 78949	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12258	 78949	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78949	 12259	 0.00719	 0.016694	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12259	 78962	 0.006501	 0.040822	 0.00089	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12260	 12261	 0.000353	 0.001946	 0.00045	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12260	 12297	 0.0027	 0.015813	 0.00431	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12260	 78950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12260	 78950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12261	 78951	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12261	 78951	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12262	 12263	 0.001968	 0.007656	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78950	 12262	 0.002123	 0.007435	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12263	 12264	 0.005515	 0.011819	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12263	 78952	 0.004231	 0.012978	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78951	 12264	 0.005008	 0.009312	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12265	 12266	 0.000181	 0.001557	 0.00044	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12266	 12270	 0.000361	 0.003464	 0.00101	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78946	 12267	 0.018925	 0.014977	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12268	 12269	 0.019949	 0.015787	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12269	 78952	 0.002147	 0.009566	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12269	 78953	 0.002876	 0.014632	 0.00033	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12270	 12271	 0.000347	 0.003628	 0.001	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12270	 78952	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12270	 78952	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12271	 12301	 0.000465	 0.005844	 0.00181	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12271	 78953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12271	 78953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12272	 12282	 0.007652	 0.029316	 0.00083	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12272	 13561	 0.011673	 0.046715	 0.00099	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12273	 78960	 0.086422	 0.24791	 0.00381	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12273	 79441	 0.039769	 0.13267	 0.0021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12274	 78957	 0.079183	 0.10407	 0.00143	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12275	 12277	 0.002054	 0.008223	 0.00207	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12275	 13786	 0.006081	 0.024345	 0.00613	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12276	 12277	 0.001975	 0.007907	 0.00199	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12276	 78954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12276	 78954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12278	 12279	 0.016886	 0.018573	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78954	 12279	 0.007443	 0.022833	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78603	 12280	 0.001231	 0.021468	 0.44328	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12280	 78955	 9.6e-05	 0.007692	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12281	 13560	 0.039104	 0.15214	 0.00254	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78957	 12281	 0.004388	 0.018571	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12282	 12283	 0.002961	 0.015197	 0.00029	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78957	 12283	 0.00211	 0.011994	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78957	 12284	 0.011115	 0.04324	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78957	 12284	 0.011115	 0.04324	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12284	 78959	 0.005834	 0.02084	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12284	 78959	 0.005834	 0.02084	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12285	 13785	 0.003947	 0.041259	 0.08755	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12285	 13785	 0.003947	 0.041259	 0.08755	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78955	 12285	 0.000504	 0.005664	 0.01036	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78955	 12285	 0.000504	 0.005664	 0.01036	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12285	 78958	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78959	 12285	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12286	 12290	 0.008521	 0.036064	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78959	 12286	 0.016031	 0.050902	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12287	 12292	 0.003062	 0.013787	 0.00367	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12288	 12291	 0.00799	 0.019557	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77766	 12288	 0.019122	 0.039132	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12289	 12290	 0.024164	 0.019123	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12291	 12293	 0.006522	 0.018042	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12292	 78960	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12292	 78960	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12293	 12294	 0.014491	 0.028691	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77766	 12293	 0.03517	 0.079777	 0.00159	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12295	 12296	 0.002268	 0.008725	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12297	 13788	 0.004076	 0.019256	 0.00616	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12297	 78961	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12297	 78961	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12298	 12300	 0.001001	 0.009094	 0.00296	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12298	 12576	 0.002392	 0.031998	 0.00875	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78956	 12298	 0.004498	 0.053423	 0.01861	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12298	 78962	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12298	 78962	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12299	 78963	 0.010029	 0.01635	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12300	 12301	 0.000656	 0.004618	 0.00263	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12300	 12557	 0.000439	 0.005792	 0.00355	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12300	 78963	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12300	 78963	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12301	 78964	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12301	 78964	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77765	 12302	 0.18376	 0.11899	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12303	 13682	 0.035998	 0.089351	 0.00148	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12303	 13683	 0.019189	 0.085508	 0.00145	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78960	 12303	 0.016379	 0.10285	 0.00225	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12304	 12310	 0.000248	 0.002056	 0.0008	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12304	 12313	 0.000473	 0.002414	 0.00061	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12304	 12379	 0.001056	 0.008997	 0.00224	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12304	 78965	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12304	 78965	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12305	 12307	 0.003286	 0.013431	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12305	 12311	 0.006205	 0.015951	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12305	 78967	 0.003128	 0.007261	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12305	 78979	 0.003549	 0.012417	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12305	 78994	 0.005959	 0.030145	 0.00052	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12306	 12307	 0.008847	 0.008149	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78965	 12307	 0.002152	 0.007688	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12307	 78982	 0.00438	 0.018284	 0.00053	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12308	 12309	 0.000578	 0.001705	 0.0004	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12308	 12381	 0.000993	 0.00346	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12309	 12313	 0.000299	 0.001472	 0.0004	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12309	 12380	 0.00075	 0.005305	 0.00146	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12309	 78966	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12309	 78966	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12310	 12378	 0.000381	 0.002949	 0.00103	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12310	 78967	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12310	 78967	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12311	 12401	 0.002033	 0.005623	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12311	 78995	 0.005401	 0.017822	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12311	 78997	 0.00305	 0.008085	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12312	 12401	 0.002228	 0.006836	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78965	 12312	 0.001389	 0.006119	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12313	 78968	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12313	 78968	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78966	 12314	 0.009556	 0.007562	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78968	 12315	 0.003309	 0.011039	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12315	 78999	 0.006822	 0.019566	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12315	 79004	 0.030117	 0.061892	 0.00118	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78968	 12316	 0.009427	 0.009521	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12317	 12318	 0.027419	 0.046189	 0.00066	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12318	 78989	 0.016019	 0.036803	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12319	 12320	 0.012699	 0.044435	 0.00092	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12319	 12460	 0.043637	 0.10333	 0.00189	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12319	 79025	 0.067987	 0.069423	 0.00108	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12320	 78987	 0.013027	 0.042989	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12321	 12322	 0.001579	 0.008225	 0.00216	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12321	 12352	 0.002985	 0.016456	 0.00385	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12321	 78969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12321	 78969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12322	 12323	 0.002766	 0.015891	 0.0045	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12323	 12325	 0.002636	 0.017233	 0.00438	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12324	 78971	 0.023251	 0.047581	 0.00117	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12325	 12327	 0.001784	 0.0113	 0.00307	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12326	 12327	 0.000859	 0.003494	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12327	 12328	 0.001169	 0.007184	 0.00207	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77668	 12328	 0.002077	 0.021365	 0.00606	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12328	 78970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12328	 78970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12329	 13831	 0.004171	 0.016973	 0.00414	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12330	 12338	 0.003005	 0.018646	 0.00452	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77668	 12330	 0.003472	 0.043673	 0.01353	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12330	 78971	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12330	 78971	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12331	 12332	 0.001935	 0.009887	 0.00249	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12331	 12336	 0.002254	 0.010936	 0.0025	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12332	 78972	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12332	 78972	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12333	 12335	 0.000727	 0.003583	 0.00097	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12333	 13868	 0.002773	 0.01411	 0.00512	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12334	 78973	 0.003273	 0.014422	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12334	 78974	 0.003389	 0.013184	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12335	 12385	 0.003285	 0.018673	 0.00541	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12335	 78973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12335	 78973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12336	 12338	 0.002166	 0.011227	 0.00274	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12336	 78974	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12336	 78974	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12337	 12338	 0.001613	 0.007401	 0.0019	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12337	 12342	 0.002188	 0.008762	 0.00221	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12338	 12341	 0.00168	 0.008197	 0.00226	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12339	 12341	 0.002155	 0.008628	 0.00217	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12339	 78975	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12339	 78975	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12340	 12342	 0.001322	 0.004535	 0.00109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12340	 12381	 0.001165	 0.006942	 0.00183	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77668	 12340	 0.007196	 0.081002	 0.02128	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12340	 78976	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12340	 78976	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12341	 78977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12341	 78977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12342	 78978	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12342	 78978	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78978	 12343	 0.031189	 0.022546	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12344	 78979	 0.029442	 0.022584	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12345	 78979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12345	 78979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12345	 78981	 0.002383	 0.007448	 0.00216	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12346	 78980	 0.013975	 0.027389	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12347	 78980	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12347	 78980	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12347	 78981	 0.001573	 0.007215	 0.00185	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12348	 12382	 0.000475	 0.004351	 0.01717	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12348	 14997	 0.006056	 0.049314	 0.16189	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12348	 78981	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78982	 12348	 0.000318	 0.023855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78980	 12349	 0.023395	 0.03469	 0.00052	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12350	 12353	 0.008271	 0.031819	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78980	 12350	 0.009838	 0.039435	 0.00102	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12351	 12352	 0.000487	 0.002995	 0.00086	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12351	 12355	 0.001229	 0.007784	 0.00211	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12351	 78983	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12351	 78983	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12352	 78984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12352	 78984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78983	 12353	 0.007166	 0.022006	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78984	 12354	 0.021496	 0.028252	 0.00039	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12355	 12360	 0.001717	 0.010382	 0.00265	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12356	 12361	 0.003463	 0.013267	 0.00037	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12356	 78985	 0.002335	 0.015842	 0.0003	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12357	 12358	 0.000848	 0.0035	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12357	 78985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12357	 78985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12358	 12360	 0.00119	 0.005549	 0.00137	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12358	 78986	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12358	 78986	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78986	 12359	 0.038237	 0.029972	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12360	 78987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12360	 78987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12361	 12369	 0.023866	 0.060696	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12361	 78989	 0.006205	 0.035272	 0.00064	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12362	 12363	 0.001161	 0.011732	 0.00345	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12362	 78988	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12362	 78988	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77692	 12363	 0.0065	 0.066242	 0.01708	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12363	 78989	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12363	 78989	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78988	 12364	 0.011732	 0.05199	 0.00156	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12365	 12366	 0.001824	 0.01656	 0.0054	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12366	 12367	 0.00212	 0.013032	 0.00376	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12366	 12368	 0.001631	 0.013102	 0.00368	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12367	 12371	 0.000908	 0.014081	 0.00397	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12367	 12392	 0.003039	 0.02311	 0.00726	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12367	 78990	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12367	 78990	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78981	 12368	 0.00375	 0.042414	 0.01633	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12368	 78991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12368	 78991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12369	 78992	 0.011472	 0.05026	 0.00108	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12370	 12371	 0.001351	 0.009413	 0.00354	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12370	 12372	 0.001366	 0.014479	 0.0043	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12370	 78992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12370	 78992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78981	 12371	 0.003691	 0.034363	 0.01065	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12371	 78993	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12371	 78993	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12372	 12374	 0.00183	 0.012946	 0.00355	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12372	 12375	 0.00081	 0.007181	 0.00191	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12372	 12378	 0.000515	 0.005034	 0.00141	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77713	 12372	 0.007261	 0.064347	 0.01713	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12372	 78994	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12372	 78994	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78994	 12373	 0.004926	 0.026957	 0.00053	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12374	 12391	 0.00336	 0.021968	 0.00559	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12375	 12387	 0.001744	 0.014953	 0.00426	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12375	 78995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12375	 78995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12376	 12387	 0.001709	 0.010619	 0.003	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12376	 12395	 0.004779	 0.018785	 0.00491	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12376	 78996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12376	 78996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78994	 12377	 0.02459	 0.043921	 0.00065	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78996	 12377	 0.010503	 0.030124	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12378	 78997	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12378	 78997	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12379	 78998	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12379	 78998	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12379	 79000	 0.000794	 0.005321	 0.00163	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12380	 12381	 0.000797	 0.00458	 0.0013	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12380	 12384	 0.000351	 0.004145	 0.00118	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12380	 78999	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12380	 78999	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12380	 79000	 0.001119	 0.007207	 0.00189	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78981	 12381	 0.000448	 0.004487	 0.00149	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12382	 12383	 7.6e-05	 0.000828	 0.00334	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12382	 79000	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12382	 79000	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12383	 14842	 0.004838	 0.048253	 0.16132	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12383	 79001	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12383	 79001	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77757	 12384	 0.002077	 0.025602	 0.00827	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12384	 79002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12384	 79002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79001	 12385	 0.001917	 0.009469	 0.00277	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12386	 13870	 0.002268	 0.019072	 0.00565	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77757	 12386	 0.00244	 0.015452	 0.00419	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12386	 79003	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12386	 79003	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77757	 12387	 0.00125	 0.015812	 0.00817	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12387	 79004	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12387	 79004	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77758	 12388	 0.004871	 0.033437	 0.00061	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78998	 12388	 0.01358	 0.083489	 0.0015	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78733	 12389	 0.043112	 0.19212	 0.00326	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78996	 12389	 0.007576	 0.052003	 0.00095	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12389	 79005	 0.014116	 0.054083	 0.00153	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78993	 12390	 0.064511	 0.065159	 0.00086	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12391	 12393	 0.00327	 0.020709	 0.00562	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12394	 12395	 0.005683	 0.041503	 0.01067	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12395	 79005	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12395	 79005	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79005	 12396	 0.053249	 0.089704	 0.00128	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77720	 12397	 0.058176	 0.063988	 0.00085	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77713	 12398	 0.003051	 0.019649	 0.00515	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12398	 79006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12398	 79006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79006	 12399	 0.057082	 0.07366	 0.00148	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77713	 12400	 0.007102	 0.047648	 0.0115	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12402	 12404	 0.000602	 0.003638	 0.00093	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12402	 12419	 0.001034	 0.005673	 0.0015	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12403	 79007	 0.026916	 0.021301	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12404	 12409	 0.001536	 0.006038	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12404	 79007	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12404	 79007	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12404	 79012	 0.004922	 0.027007	 0.00714	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12405	 12418	 0.019559	 0.015003	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79007	 12405	 0.006342	 0.011398	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12406	 12407	 0.011909	 0.008609	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12407	 79008	 0.01447	 0.009368	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12408	 79008	 0.02378	 0.018819	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12409	 12419	 0.003537	 0.014162	 0.00357	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12409	 12422	 0.001307	 0.012774	 0.00358	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12409	 79008	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12409	 79008	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12409	 79012	 0.006451	 0.026635	 0.0063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12410	 12417	 0.038458	 0.04107	 0.00087	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79008	 12410	 0.028691	 0.024521	 0.00046	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12410	 79013	 0.023834	 0.070087	 0.00144	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12411	 79009	 0.052236	 0.10238	 0.00153	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12412	 12414	 0.089739	 0.066025	 0.00097	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12412	 79010	 0.016841	 0.026881	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12413	 12419	 0.001666	 0.013126	 0.00384	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12413	 12708	 0.003849	 0.026424	 0.00771	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12413	 79009	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12413	 79009	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12415	 12416	 0.004561	 0.017925	 0.00469	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12415	 12703	 0.005445	 0.018347	 0.00456	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12415	 12708	 0.008354	 0.054632	 0.0139	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12416	 79012	 0.003799	 0.014441	 0.00404	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12419	 79010	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12419	 79010	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12420	 12421	 0.014942	 0.052281	 0.00108	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12420	 12426	 0.043482	 0.085219	 0.00128	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12421	 79011	 0.01163	 0.035679	 0.00097	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12422	 12425	 0.001159	 0.016876	 0.0054	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12422	 79011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12422	 79011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77678	 12423	 0.002671	 0.024491	 0.09672	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78739	 12423	 0.009895	 0.097767	 0.33802	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12423	 79012	 9.1e-05	 0.007266	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79013	 12423	 0.000262	 0.019645	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79013	 12424	 0.10624	 0.078167	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12426	 79014	 0.017348	 0.039674	 0.00097	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12427	 79014	 0.01154	 0.009045	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12428	 12429	 0.000828	 0.00248	 0.00056	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12428	 79014	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12428	 79014	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79012	 12429	 0.012679	 0.052356	 0.01239	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12430	 79015	 0.013382	 0.014718	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12431	 12432	 0.001368	 0.004694	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12431	 12451	 0.002376	 0.006883	 0.00166	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12431	 79015	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12431	 79015	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12432	 12434	 0.001888	 0.005141	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12432	 12450	 0.004676	 0.01273	 0.0028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12432	 12453	 0.000745	 0.002981	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12432	 79016	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12432	 79016	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12432	 79021	 0.005919	 0.036778	 0.01038	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79016	 12433	 0.009966	 0.010066	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12433	 79017	 0.017211	 0.013491	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12434	 12435	 0.001238	 0.003182	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12434	 79017	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12434	 79017	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77692	 12435	 0.00259	 0.009154	 0.00206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12435	 79018	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12435	 79018	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12436	 79019	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12436	 79019	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12436	 79021	 0.006464	 0.022173	 0.00531	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12437	 12438	 0.001962	 0.012829	 0.00326	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12437	 13519	 0.0043	 0.025186	 0.00686	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77692	 12437	 0.00749	 0.029986	 0.00755	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12437	 79020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12437	 79020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12438	 79021	 0.00374	 0.025947	 0.00741	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78766	 12439	 0.001171	 0.011515	 0.2	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78766	 12439	 0.001171	 0.011515	 0.2	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12439	 79021	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12439	 79197	 0.00144	 0.025845	 0.50475	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12440	 12441	 0.002582	 0.010337	 0.0026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79021	 12440	 0.004506	 0.018337	 0.00447	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12441	 12442	 0.001471	 0.006747	 0.00173	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12441	 79023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12441	 79023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12442	 12453	 0.001426	 0.006748	 0.00162	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79016	 12443	 0.01889	 0.028937	 0.00041	 36.0	 36.0	 36.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79019	 12443	 0.08488	 0.1355	 0.00312	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77693	 12444	 0.016978	 0.028601	 0.00041	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12445	 12446	 0.000148	 0.002067	 0.0007	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77692	 12445	 0.000851	 0.009174	 0.0049	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12445	 79024	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12445	 79024	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12447	 79025	 0.010031	 0.068858	 0.00126	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12448	 12449	 0.004722	 0.016199	 0.00388	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12448	 79025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12448	 79025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12449	 12451	 0.002006	 0.008729	 0.00249	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12449	 79026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12449	 79026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12450	 12451	 0.002767	 0.007761	 0.002	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77692	 12450	 0.000814	 0.003566	 0.00123	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12450	 79027	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12450	 79027	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12452	 12460	 0.03485	 0.057887	 0.00123	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79016	 12452	 0.017728	 0.040729	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79023	 12454	 0.005266	 0.043809	 0.00083	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12454	 79028	 0.006638	 0.053712	 0.00138	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12455	 79028	 0.010897	 0.021575	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12456	 79028	 0.007212	 0.011048	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12457	 79028	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12457	 79028	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12458	 12459	 0.020544	 0.073392	 0.00146	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78799	 12458	 0.010103	 0.054063	 0.00164	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12459	 12460	 0.011728	 0.038703	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12461	 12532	 0.004326	 0.016642	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12461	 12532	 0.004326	 0.016642	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77731	 12461	 0.005727	 0.030513	 0.00054	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12461	 79029	 0.003617	 0.011598	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12461	 79029	 0.003617	 0.011598	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12462	 12497	 0.001947	 0.007795	 0.00196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12462	 79029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12462	 79029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12463	 12535	 0.006173	 0.020592	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12463	 79030	 0.001578	 0.009587	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12463	 79038	 0.015893	 0.028677	 0.00041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12464	 12465	 0.007356	 0.013677	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12464	 12468	 0.002083	 0.007441	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12464	 12470	 0.0037	 0.007777	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77731	 12464	 0.002082	 0.003323	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12465	 12535	 0.005554	 0.021368	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12465	 79031	 0.005318	 0.020461	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12466	 12498	 0.012432	 0.009838	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12466	 79030	 0.004214	 0.006575	 0.00011	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12467	 12475	 0.000287	 0.001465	 0.00037	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12467	 79030	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12467	 79030	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12468	 12469	 0.006084	 0.004815	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12468	 12536	 0.016929	 0.013398	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79030	 12468	 0.001014	 0.005204	 0.0001	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12470	 12536	 0.002969	 0.007632	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12471	 12473	 0.001015	 0.004063	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12471	 79031	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12471	 79031	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12472	 12473	 0.000844	 0.005435	 0.00142	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12472	 12523	 0.000358	 0.002879	 0.00081	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12473	 12526	 0.004076	 0.018698	 0.00479	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12473	 12984	 0.002771	 0.026081	 0.0079	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12473	 79032	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12473	 79032	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12473	 79046	 0.001873	 0.027987	 0.00828	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12474	 12522	 0.010268	 0.018057	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79032	 12474	 0.00369	 0.010584	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12475	 12476	 0.000204	 0.001065	 0.00028	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12476	 12478	 0.000346	 0.002026	 0.00055	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12477	 12479	 0.001595	 0.007696	 0.00014	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79030	 12477	 0.002389	 0.010647	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12478	 12482	 0.000639	 0.003252	 0.00118	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12478	 79033	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12478	 79033	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12479	 12480	 0.001441	 0.008193	 0.00015	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12480	 79035	 0.002493	 0.013976	 0.00039	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12481	 79034	 0.011095	 0.010324	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12482	 12484	 0.000412	 0.003201	 0.00083	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12482	 79034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12482	 79034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12483	 79035	 0.015226	 0.013644	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12484	 12506	 0.00057	 0.006421	 0.00186	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12484	 79035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12484	 79035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12485	 79215	 0.019791	 0.015181	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12486	 12487	 0.001448	 0.010473	 0.00563	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12486	 13004	 0.000941	 0.00738	 0.00337	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12487	 12488	 0.0014	 0.020211	 0.00642	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12488	 13509	 0.006012	 0.027583	 0.00707	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12488	 79036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12488	 79036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12489	 12490	 0.003795	 0.014763	 0.00394	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12489	 79037	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12489	 79037	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12489	 79046	 0.007438	 0.020743	 0.00435	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12491	 12492	 0.003177	 0.02123	 0.00047	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79037	 12491	 0.009484	 0.072053	 0.00164	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12492	 12495	 0.004221	 0.03006	 0.00068	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78684	 12492	 0.032558	 0.12526	 0.00214	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12493	 12494	 0.054	 0.040912	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79037	 12494	 0.011165	 0.034252	 0.00093	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12494	 79040	 0.01626	 0.046637	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77712	 12495	 0.007682	 0.030479	 0.00087	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12496	 12501	 0.00242	 0.014112	 0.00028	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12496	 79038	 0.009345	 0.024219	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12496	 79039	 0.006171	 0.022046	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12496	 79039	 0.006171	 0.022046	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12497	 12500	 0.000483	 0.0034	 0.00193	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12497	 12503	 0.000776	 0.007581	 0.00213	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12497	 12976	 0.003186	 0.026439	 0.00696	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12497	 79038	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12497	 79038	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12497	 79043	 0.002678	 0.025211	 0.00764	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79033	 12499	 0.011546	 0.011662	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12499	 79039	 0.032728	 0.0259	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12500	 12504	 0.000349	 0.003566	 0.00212	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12500	 79039	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12500	 79039	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12501	 79216	 0.002324	 0.015768	 0.00029	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12502	 13007	 0.002917	 0.012781	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79038	 12502	 0.005069	 0.01972	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12503	 13029	 0.000877	 0.007648	 0.0021	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12504	 12505	 0.000624	 0.00629	 0.00386	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12505	 12508	 0.003711	 0.024268	 0.00617	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12505	 79040	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12505	 79040	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12505	 79043	 0.000843	 0.010393	 0.00336	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12505	 79046	 0.000499	 0.007916	 0.00501	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12506	 79041	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12506	 79041	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12506	 79043	 0.000592	 0.007213	 0.00238	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79041	 12507	 0.022744	 0.024773	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12508	 12515	 0.005133	 0.020176	 0.00528	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12508	 79042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12508	 79042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12509	 79043	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12509	 79043	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12509	 79045	 0.000199	 0.00219	 0.00416	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12509	 79045	 0.000199	 0.00219	 0.00416	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12510	 79044	 7.2e-05	 0.005789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12510	 79044	 7.2e-05	 0.005789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12511	 12516	 0.000662	 0.007103	 0.00185	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12512	 12518	 0.007762	 0.036191	 0.00083	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79042	 12512	 0.022621	 0.087029	 0.00149	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12512	 79050	 0.004064	 0.022238	 0.00043	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12513	 12514	 0.000667	 0.0064	 0.00186	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12513	 12523	 0.000684	 0.00597	 0.00164	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12514	 12516	 0.000766	 0.006364	 0.00249	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79043	 12514	 0.001148	 0.007503	 0.00191	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12514	 79048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12514	 79048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12515	 12519	 0.003736	 0.013021	 0.00302	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12515	 79049	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12515	 79049	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12516	 79050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12516	 79050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12517	 79051	 0.021064	 0.016511	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12518	 12529	 0.009857	 0.048098	 0.00083	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12519	 79051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12519	 79051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79051	 12520	 0.014973	 0.015123	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12521	 12524	 0.002662	 0.020508	 0.00039	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12521	 12535	 0.002076	 0.015034	 0.00038	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12522	 12528	 0.024667	 0.037412	 0.00054	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12524	 12981	 0.006214	 0.014715	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12524	 79209	 0.01683	 0.038491	 0.00094	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12525	 12527	 0.004629	 0.020503	 0.00047	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78644	 12525	 0.013192	 0.059027	 0.00122	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12525	 79052	 0.04209	 0.041347	 0.0007	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12526	 12935	 0.007506	 0.047547	 0.01291	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12526	 79052	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12526	 79052	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12527	 12528	 0.032755	 0.036027	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79051	 12527	 0.011278	 0.06411	 0.00116	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78627	 12529	 0.024843	 0.063862	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12530	 12531	 0.010482	 0.008216	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12530	 12532	 0.003085	 0.015055	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12530	 13030	 0.004228	 0.015105	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79032	 12530	 0.01368	 0.084105	 0.00152	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12530	 79227	 0.014266	 0.040917	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12532	 12533	 0.004235	 0.010885	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12532	 12978	 0.004155	 0.024595	 0.00048	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12533	 12534	 0.005943	 0.013794	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12534	 12980	 0.005599	 0.013258	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79031	 12536	 0.002888	 0.011235	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12537	 12541	 0.000205	 0.002563	 0.00112	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12537	 12548	 0.000229	 0.002965	 0.00117	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12538	 12539	 0.000127	 0.001822	 0.00117	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12538	 12589	 0.000202	 0.00304	 0.00178	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12539	 12540	 0.00022	 0.002376	 0.00068	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12539	 12592	 0.000437	 0.004917	 0.00129	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12540	 12541	 0.00039	 0.003036	 0.00079	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12540	 12602	 0.00053	 0.005091	 0.00148	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12541	 12543	 0.00013	 0.001989	 0.00064	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12542	 12543	 8.9e-05	 0.001323	 0.00046	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12542	 12605	 0.000219	 0.003449	 0.00118	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12543	 79053	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12543	 79053	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12544	 12545	 0.002342	 0.006207	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79053	 12544	 0.002033	 0.006237	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12545	 12546	 0.00098	 0.006724	 0.00012	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79053	 12545	 0.006214	 0.015975	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12546	 12550	 0.001478	 0.009085	 0.00016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12547	 12548	 0.000182	 0.001573	 0.00056	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12547	 12606	 0.000484	 0.004728	 0.00133	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12547	 79054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12547	 79054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12548	 12549	 0.000131	 0.001822	 0.001	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12548	 79055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12548	 79055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12549	 12551	 0.000367	 0.002863	 0.00086	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12549	 12580	 0.000226	 0.002928	 0.00116	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77765	 12550	 0.011062	 0.078782	 0.00177	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79054	 12550	 0.003459	 0.00803	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12551	 12578	 0.001639	 0.0096	 0.00261	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12551	 79056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12551	 79056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77756	 12552	 0.007136	 0.027759	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79056	 12552	 0.001664	 0.010448	 0.00023	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12553	 12554	 0.035152	 0.025862	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12553	 79057	 0.030654	 0.070425	 0.00107	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12553	 79061	 0.007865	 0.039784	 0.00069	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12555	 79057	 0.0478	 0.035168	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12556	 12559	 0.002189	 0.015026	 0.00027	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12556	 12560	 0.001748	 0.012776	 0.00024	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12557	 12563	 0.000712	 0.007677	 0.0041	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12557	 79057	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12557	 79057	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12557	 79440	 0.009269	 0.08215	 0.02188	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12558	 12560	 0.001528	 0.011913	 0.00022	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12558	 12561	 0.008584	 0.005766	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12558	 79060	 0.004714	 0.036742	 0.00069	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79057	 12559	 0.003153	 0.017741	 0.00038	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12560	 12562	 0.00434	 0.014478	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12562	 79058	 0.005711	 0.019052	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12563	 12575	 0.000532	 0.006306	 0.00323	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12563	 79058	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12563	 79058	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12564	 12566	 0.009753	 0.04759	 0.00082	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79057	 12564	 0.013335	 0.05942	 0.00101	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12565	 79059	 0.052318	 0.033871	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12566	 79059	 0.008712	 0.047676	 0.00093	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12567	 12573	 0.003304	 0.012985	 0.0034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12567	 79059	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12567	 79059	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12567	 79440	 0.013955	 0.055877	 0.01408	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12568	 12571	 0.006492	 0.025256	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12568	 12571	 0.006492	 0.025256	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12568	 13790	 0.006705	 0.050705	 0.00169	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79059	 12568	 0.015268	 0.038828	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12569	 12570	 0.013815	 0.053746	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12569	 12595	 0.010836	 0.037941	 0.00105	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79059	 12569	 0.011129	 0.086741	 0.00162	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12569	 79069	 0.042782	 0.056229	 0.00077	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12570	 12572	 0.016287	 0.068928	 0.0013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12571	 12572	 0.017525	 0.067424	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12571	 12572	 0.017525	 0.067424	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12572	 12616	 0.020413	 0.079413	 0.00133	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12572	 12616	 0.020413	 0.079413	 0.00133	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12573	 12582	 0.002394	 0.009743	 0.00237	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12574	 79060	 0.032427	 0.025662	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12575	 12581	 0.000408	 0.004762	 0.00373	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12575	 12582	 0.001658	 0.007903	 0.00229	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12575	 79060	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12575	 79060	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12576	 12577	 0.000627	 0.007883	 0.00244	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12576	 79061	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12576	 79061	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12578	 79062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12578	 79062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12579	 12580	 0.000343	 0.005234	 0.00169	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12579	 79063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12579	 79063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12581	 12584	 0.000334	 0.0044	 0.00269	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12581	 79064	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12581	 79064	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12582	 79065	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12582	 79065	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12583	 12590	 0.002052	 0.010673	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79065	 12583	 0.003343	 0.015976	 0.00035	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12584	 12589	 0.000173	 0.002283	 0.0014	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12584	 79066	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12584	 79066	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79066	 12585	 0.018384	 0.013526	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12586	 12587	 0.001446	 0.005624	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12586	 12588	 0.001945	 0.007565	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12587	 79067	 0.002268	 0.009271	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79055	 12588	 0.002886	 0.009626	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12589	 79067	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12589	 79067	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79066	 12590	 0.002931	 0.017094	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79067	 12591	 0.031191	 0.022948	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12592	 12593	 0.000244	 0.002546	 0.0007	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12592	 79068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12592	 79068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12593	 12594	 0.000183	 0.001944	 0.00058	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12593	 79069	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12593	 79069	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12594	 12598	 0.000981	 0.010255	 0.00345	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12595	 79070	 0.00914	 0.032002	 0.00089	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12596	 12597	 0.016489	 0.01168	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12597	 79071	 0.01497	 0.011483	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12598	 12600	 0.000378	 0.002529	 0.00159	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12598	 79070	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12598	 79070	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12599	 79071	 0.01827	 0.014459	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12600	 12613	 0.00089	 0.009435	 0.0028	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12600	 12639	 0.00096	 0.010355	 0.00296	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12600	 79071	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12600	 79071	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79068	 12601	 0.002531	 0.01013	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12601	 79087	 0.005562	 0.029634	 0.00052	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12602	 12639	 0.000789	 0.006835	 0.00245	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12602	 79072	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12602	 79072	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12603	 12605	 0.000424	 0.006267	 0.00216	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12603	 12611	 0.000635	 0.008755	 0.00392	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12603	 79073	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12603	 79073	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79073	 12604	 0.009352	 0.021711	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12604	 79087	 0.01081	 0.025096	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12605	 79074	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12605	 79074	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12606	 12609	 0.002087	 0.019641	 0.00595	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12607	 12735	 0.005	 0.035367	 0.00971	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12608	 12610	 0.001479	 0.015677	 0.00465	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12608	 12626	 0.001866	 0.020228	 0.00632	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12609	 12610	 0.00133	 0.013549	 0.00349	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12610	 12611	 0.001719	 0.010887	 0.00295	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77666	 12610	 0.003034	 0.047217	 0.01465	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12611	 79075	 0.001037	 0.016157	 0.00564	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12612	 79075	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12612	 79075	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12612	 79078	 0.000736	 0.006748	 0.02664	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79075	 12613	 0.001665	 0.019557	 0.00519	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12614	 12615	 0.000936	 0.013514	 0.00429	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12615	 12618	 0.000814	 0.01109	 0.00396	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12616	 12617	 0.023331	 0.090765	 0.00152	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12616	 12617	 0.023331	 0.090765	 0.00152	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78748	 12617	 0.026173	 0.0935	 0.00186	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78748	 12617	 0.026173	 0.0935	 0.00186	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12618	 79076	 0.001403	 0.010151	 0.00546	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77665	 12619	 0.000111	 0.001428	 0.01343	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12619	 79076	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12619	 79076	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12619	 79077	 0.000217	 0.00241	 0.02294	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12620	 79077	 6.9e-05	 0.0055	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12620	 79077	 6.9e-05	 0.0055	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79078	 12620	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79078	 12620	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12621	 13480	 0.040762	 0.10479	 0.00162	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78750	 12621	 0.022528	 0.1756	 0.00328	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12621	 79080	 0.015817	 0.070479	 0.0012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12622	 12623	 3e-05	 0.000353	 0.02649	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12622	 12640	 4.3e-05	 0.000511	 0.03835	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12623	 79079	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12624	 12626	 0.003089	 0.030176	 0.00847	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12624	 79089	 0.001925	 0.017919	 0.00555	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12625	 12626	 0.001238	 0.012513	 0.00368	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12625	 12627	 0.001339	 0.014187	 0.00421	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12627	 12631	 0.000609	 0.007658	 0.00237	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12627	 79081	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12627	 79081	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12628	 79082	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79083	 12628	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12629	 12636	 0.000942	 0.005228	 0.00159	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12629	 79089	 0.000929	 0.005886	 0.0016	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12630	 12635	 0.00258	 0.010035	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12630	 12635	 0.00258	 0.010035	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12630	 79084	 0.003488	 0.013571	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12630	 79084	 0.003488	 0.013571	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12631	 12632	 0.000876	 0.004658	 0.00108	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12631	 79084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12631	 79084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12631	 79085	 0.000181	 0.001848	 0.0011	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12633	 12634	 0.000172	 0.00109	 0.00228	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12634	 79085	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79086	 12634	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79086	 12635	 0.001632	 0.00628	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79086	 12635	 0.001632	 0.00628	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79085	 12636	 0.00062	 0.003301	 0.00093	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12637	 12638	 0.000398	 0.003941	 0.00121	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79085	 12637	 0.000274	 0.002491	 0.00081	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12638	 79089	 0.00042	 0.004166	 0.00128	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12639	 79087	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12639	 79087	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12640	 79088	 0.000115	 0.009166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12640	 79088	 0.000115	 0.009166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79089	 12640	 0.000149	 0.01193	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12641	 79090	 0.013937	 0.018998	 0.00042	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12642	 79090	 0.017524	 0.013736	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12643	 79091	 0.003231	 0.012432	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12644	 12647	 0.000136	 0.002212	 0.00132	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12644	 12661	 0.000451	 0.006779	 0.00477	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12644	 79090	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12644	 79090	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12645	 12646	 0.010972	 0.00737	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79090	 12645	 0.002959	 0.011511	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79090	 12645	 0.002959	 0.011511	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12647	 12660	 0.001092	 0.013987	 0.00418	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12647	 79091	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12647	 79091	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12647	 79092	 0.000354	 0.005329	 0.00375	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12648	 79092	 0.00014	 0.01116	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12649	 12662	 0.003909	 0.014858	 0.00416	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12649	 12669	 0.006667	 0.044731	 0.0108	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79092	 12649	 0.000249	 0.003066	 0.00099	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12649	 79094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12649	 79094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12650	 12653	 0.015945	 0.12428	 0.00232	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12650	 13571	 0.019614	 0.13464	 0.00245	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12652	 12662	 0.003973	 0.018229	 0.00467	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12652	 12669	 0.005499	 0.025229	 0.00646	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12653	 12663	 0.013132	 0.084725	 0.0027	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12654	 12661	 0.001545	 0.024499	 0.0155	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12654	 13550	 0.002475	 0.040372	 0.02409	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78748	 12655	 0.023918	 0.19666	 0.00381	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12655	 79095	 0.011398	 0.10486	 0.00208	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12656	 12658	 0.002593	 0.026423	 0.00681	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12656	 79095	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12656	 79095	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78748	 12657	 0.038217	 0.29043	 0.00662	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79095	 12657	 0.012841	 0.068416	 0.0012	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12657	 79097	 0.047122	 0.16489	 0.00342	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12657	 79097	 0.047122	 0.16489	 0.00342	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12658	 12659	 0.000915	 0.009252	 0.00272	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12659	 12660	 0.000726	 0.007698	 0.00228	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12662	 79096	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12662	 79096	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79094	 12663	 0.002627	 0.025743	 0.0005	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79093	 12664	 0.052283	 0.038466	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79093	 12665	 0.005551	 0.021596	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79093	 12665	 0.005551	 0.021596	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79094	 12665	 0.006558	 0.029046	 0.00066	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12666	 79097	 0.023112	 0.070903	 0.00192	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12666	 79097	 0.023112	 0.070903	 0.00192	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12667	 13041	 0.003431	 0.030402	 0.00809	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79092	 12667	 0.001567	 0.018408	 0.01105	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12667	 79097	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12667	 79097	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79096	 12668	 0.13304	 0.086136	 0.00164	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12670	 12672	 0.002336	 0.020383	 0.0056	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12670	 12679	 0.002487	 0.023879	 0.00695	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12671	 12672	 0.000325	 0.002784	 0.00079	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12671	 12673	 0.000612	 0.005081	 0.00134	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12673	 13475	 0.029464	 0.17576	 0.04633	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12673	 79098	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12673	 79098	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79098	 12674	 0.095681	 0.070397	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79098	 12675	 0.17729	 0.21228	 0.00353	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12676	 12677	 0.007973	 0.033744	 0.00759	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12676	 79099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12676	 79099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12678	 79100	 0.099554	 0.23116	 0.00344	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12679	 79100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12679	 79100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12680	 12681	 0.072445	 0.12204	 0.00174	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77762	 12681	 0.028951	 0.21164	 0.0039	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78881	 12681	 0.11391	 0.21185	 0.00496	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12682	 79106	 0.01197	 0.009473	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12683	 12684	 0.015963	 0.012512	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12683	 79106	 0.006187	 0.01225	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12685	 12686	 0.021611	 0.016939	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12686	 79107	 0.011616	 0.017794	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12687	 79107	 0.002285	 0.011148	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12688	 12703	 0.001644	 0.014239	 0.00511	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12688	 12704	 0.001584	 0.014749	 0.00457	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12688	 79101	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12688	 79101	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79101	 12689	 0.063808	 0.050016	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12690	 12691	 0.021003	 0.016622	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12690	 79107	 0.027864	 0.044476	 0.00102	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12692	 12699	 0.042805	 0.11004	 0.0017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12692	 79103	 0.025406	 0.17441	 0.00318	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12693	 12694	 0.00322	 0.020395	 0.00554	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12693	 12698	 0.004221	 0.026196	 0.00635	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12693	 79102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12693	 79102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12694	 12698	 0.010297	 0.035323	 0.00846	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12694	 27633	 0.007345	 0.072797	 0.0223	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12695	 12696	 0.013474	 0.013759	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79102	 12696	 0.014115	 0.027947	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12697	 12710	 0.081686	 0.059052	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12698	 12701	 0.002113	 0.02658	 0.00823	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12698	 12711	 0.011659	 0.049349	 0.01111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12698	 79103	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12698	 79103	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12700	 79104	 0.14571	 0.11422	 0.00147	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12701	 12702	 0.005902	 0.02296	 0.00613	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12701	 12704	 0.002318	 0.019878	 0.00566	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12701	 12705	 0.009444	 0.046573	 0.01259	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12702	 12708	 0.003204	 0.020635	 0.00541	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12702	 79104	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12702	 79104	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12703	 27617	 0.002631	 0.022569	 0.00642	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79012	 12703	 0.012848	 0.04496	 0.0149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12705	 79105	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12705	 79105	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12706	 12707	 0.012536	 0.01747	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79105	 12706	 0.040573	 0.02874	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78653	 12707	 0.037873	 0.09736	 0.00151	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12709	 12711	 0.001616	 0.007538	 0.00187	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12709	 79106	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12709	 79106	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79106	 12710	 0.009539	 0.03148	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79012	 12711	 0.003581	 0.055791	 0.01949	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12711	 79107	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12711	 79107	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12712	 12723	 0.029426	 0.098166	 0.00156	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78685	 12712	 0.025092	 0.1337	 0.00235	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12713	 12721	 0.003601	 0.019756	 0.00522	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12714	 12716	 0.005975	 0.028996	 0.00663	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12714	 79108	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12714	 79108	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78945	 12715	 0.002295	 0.035077	 0.0113	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12715	 79109	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12715	 79109	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78945	 12716	 0.00837	 0.035427	 0.00797	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12717	 12721	 0.002783	 0.020017	 0.0053	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78686	 12717	 0.033408	 0.093752	 0.02414	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78945	 12717	 0.003184	 0.045035	 0.01492	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12717	 79110	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12717	 79110	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12718	 12720	 0.022755	 0.016742	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12719	 12720	 0.018458	 0.01654	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79110	 12720	 0.011337	 0.044106	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12721	 12722	 0.000871	 0.005697	 0.00145	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12722	 79111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12722	 79111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78944	 12723	 0.043426	 0.099771	 0.00152	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12724	 12725	 0.002574	 0.013407	 0.00352	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12724	 12726	 0.003709	 0.020692	 0.00529	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12725	 12755	 0.006078	 0.023102	 0.00647	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12725	 79112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12725	 79112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12726	 12731	 0.00341	 0.024922	 0.00735	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12726	 79113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12726	 79113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12727	 12736	 0.034765	 0.062727	 0.00091	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12728	 12732	 0.001442	 0.015451	 0.00494	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12728	 12733	 0.001798	 0.019888	 0.00596	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12729	 79116	 0.013896	 0.05138	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12729	 79116	 0.013896	 0.05138	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12729	 79123	 0.024181	 0.094073	 0.00157	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12729	 79123	 0.024181	 0.094073	 0.00157	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12730	 79114	 0.03442	 0.026077	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12731	 12732	 0.001097	 0.009227	 0.00273	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12731	 79114	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12731	 79114	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12732	 79115	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12732	 79115	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12733	 12735	 0.001322	 0.018	 0.00643	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12733	 79116	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12733	 79116	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79116	 12734	 0.051557	 0.040802	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79115	 12736	 0.015637	 0.12653	 0.00326	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12736	 79117	 0.011632	 0.046151	 0.00132	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12736	 79120	 0.010185	 0.082411	 0.00212	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12737	 12738	 0.001769	 0.019908	 0.00523	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12737	 12745	 0.001063	 0.010006	 0.00303	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12737	 79117	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12737	 79117	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12738	 12752	 0.001337	 0.01417	 0.00421	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12739	 12744	 0.001338	 0.016301	 0.00539	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12740	 12741	 0.055538	 0.043953	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12741	 12742	 0.006846	 0.017597	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12741	 79119	 0.010878	 0.027665	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12742	 79118	 0.007507	 0.019456	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12743	 12744	 0.001232	 0.006235	 0.00174	 211.0	 211.0	 211.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12743	 12746	 0.001019	 0.006265	 0.00181	 241.0	 241.0	 241.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12743	 79118	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12743	 79118	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12744	 12745	 0.000732	 0.007329	 0.00244	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78958	 12744	 0.018771	 0.15357	 0.04173	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12744	 79119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12744	 79119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12745	 79120	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12745	 79120	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12746	 13039	 0.002417	 0.013861	 0.00461	 241.0	 241.0	 241.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12746	 79121	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12746	 79121	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12747	 12748	 0.004456	 0.043147	 0.00087	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12747	 79123	 0.024381	 0.094852	 0.00158	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12747	 79123	 0.024381	 0.094852	 0.00158	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12748	 12996	 0.011711	 0.044871	 0.00127	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79121	 12748	 0.008229	 0.058606	 0.00132	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12749	 79122	 0.015373	 0.047162	 0.00128	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12749	 79123	 0.013147	 0.058584	 0.00099	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12750	 12754	 0.002337	 0.016967	 0.00586	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12750	 12997	 0.001641	 0.015751	 0.00458	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12750	 79122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12750	 79122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12751	 79123	 0.010467	 0.037392	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12751	 79123	 0.010467	 0.037392	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12751	 79124	 0.014237	 0.043676	 0.00118	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12751	 79124	 0.014237	 0.043676	 0.00118	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12752	 12753	 0.001981	 0.020989	 0.00623	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12752	 79123	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12752	 79123	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12753	 79124	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12753	 79124	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12755	 79125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12755	 79125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12756	 13473	 0.005125	 0.048287	 0.00102	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79112	 12756	 0.013802	 0.04234	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79112	 12756	 0.013802	 0.04234	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12757	 12761	 0.003258	 0.014517	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78619	 12757	 0.004979	 0.019154	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12758	 13413	 0.005401	 0.014315	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78619	 12758	 0.007178	 0.027925	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12759	 12760	 0.002887	 0.017737	 0.00041	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12759	 13409	 0.00439	 0.02668	 0.00049	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12760	 12761	 0.003911	 0.017425	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12760	 79144	 0.006436	 0.019743	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12760	 79144	 0.006436	 0.019743	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12762	 12766	 0.001251	 0.005296	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78621	 12762	 0.003713	 0.01511	 0.00368	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12762	 79126	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12762	 79126	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12763	 12764	 0.004457	 0.011457	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12763	 12770	 0.007251	 0.013281	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79126	 12764	 0.013008	 0.030804	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12765	 79127	 0.013348	 0.010564	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12766	 12811	 0.000663	 0.002654	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12766	 79127	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12766	 79127	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12767	 79142	 0.027526	 0.021784	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12768	 12769	 0.011417	 0.032746	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12768	 79144	 0.008996	 0.029687	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12769	 12770	 0.00284	 0.011366	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78622	 12770	 0.014058	 0.028769	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12771	 12774	 0.001883	 0.007662	 0.00187	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12771	 79128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12771	 79128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79126	 12772	 0.007301	 0.016947	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79128	 12772	 0.005798	 0.019342	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12773	 12774	 0.00176	 0.006918	 0.00181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12773	 12778	 0.001769	 0.0072	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12774	 79129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12774	 79129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12775	 12805	 0.005543	 0.017005	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79128	 12775	 0.012322	 0.031336	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12776	 12789	 0.005572	 0.013829	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12776	 79130	 0.009596	 0.024869	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12776	 79138	 0.011169	 0.028711	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12777	 12780	 0.00115	 0.006851	 0.0018	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12777	 12781	 0.00118	 0.005411	 0.00139	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12777	 79130	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12777	 79130	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12778	 12780	 0.001407	 0.005725	 0.00139	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12778	 79132	 0.005933	 0.025113	 0.00565	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79130	 12779	 0.024073	 0.019051	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12781	 79132	 0.001673	 0.007802	 0.00193	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12782	 12785	 0.001023	 0.00635	 0.00154	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12782	 12786	 0.000453	 0.002916	 0.00076	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12783	 13434	 0.00032	 0.005938	 0.39224	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12783	 79131	 7.4e-05	 0.005945	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12783	 79131	 7.4e-05	 0.005945	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79132	 12783	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79132	 12783	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12784	 12785	 0.001314	 0.003412	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79132	 12784	 0.002666	 0.007045	 0.00165	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12784	 79133	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12784	 79133	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79132	 12785	 0.001196	 0.004101	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12786	 12787	 0.000613	 0.00162	 0.00038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12786	 12791	 0.000494	 0.002483	 0.00065	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12786	 79134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12786	 79134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12787	 12788	 0.001151	 0.002671	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12788	 12792	 0.002017	 0.005237	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12788	 79135	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12788	 79135	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79135	 12789	 0.004985	 0.014299	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12790	 12793	 0.001143	 0.004138	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12790	 79136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12790	 79136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12791	 12917	 0.001305	 0.005076	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12791	 79137	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12791	 79137	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12792	 79138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12792	 79138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12794	 79139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12794	 79139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12795	 12796	 0.006297	 0.012887	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12795	 12842	 0.008587	 0.028645	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79138	 12796	 0.003351	 0.007778	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79138	 12797	 0.00805	 0.031318	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12797	 79140	 0.007625	 0.029663	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12798	 12806	 0.011169	 0.025926	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12798	 79140	 0.005586	 0.021733	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12799	 12802	 0.002983	 0.011942	 0.00301	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12799	 79140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12799	 79140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12799	 79157	 0.003563	 0.021903	 0.00632	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12800	 12807	 0.002993	 0.009984	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12800	 12843	 0.005106	 0.01994	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12801	 12808	 0.005128	 0.011632	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79140	 12801	 0.021629	 0.023558	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12802	 12811	 0.00233	 0.013197	 0.00327	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12802	 79141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12802	 79141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12803	 12804	 0.007372	 0.017116	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79141	 12803	 0.011011	 0.025563	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12804	 12818	 0.004933	 0.011682	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79141	 12805	 0.005418	 0.018968	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12806	 12807	 0.003377	 0.019992	 0.00039	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79129	 12806	 0.002789	 0.025961	 0.0005	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12807	 12808	 0.007499	 0.015345	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12808	 79150	 0.005914	 0.023096	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12809	 12822	 0.031407	 0.024855	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12810	 12822	 0.004207	 0.018534	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12810	 79144	 0.003907	 0.017412	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12811	 79142	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12811	 79142	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12812	 12813	 0.002983	 0.007586	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12812	 12814	 0.006607	 0.00938	 0.00015	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79142	 12812	 0.003617	 0.008564	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12813	 12817	 0.004627	 0.011767	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12814	 79143	 0.003585	 0.007026	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12815	 12816	 0.000834	 0.003445	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12815	 12820	 0.001034	 0.004745	 0.00122	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12815	 79143	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12815	 79143	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12816	 79144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12816	 79144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12817	 79146	 0.005516	 0.014178	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12818	 79145	 0.005657	 0.016226	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12819	 12820	 0.000481	 0.003049	 0.00083	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12819	 12823	 0.003662	 0.010797	 0.00251	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12819	 12834	 0.000674	 0.0027	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12819	 79145	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12819	 79145	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12819	 79157	 0.003189	 0.031601	 0.00968	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12820	 79146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12820	 79146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12821	 12825	 0.018613	 0.01473	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12822	 79147	 0.002927	 0.014059	 0.00027	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12822	 79148	 0.006078	 0.015625	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12823	 12824	 0.001241	 0.004323	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12823	 79147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12823	 79147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12824	 13392	 0.001013	 0.002676	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12824	 79148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12824	 79148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79145	 12825	 0.008075	 0.015015	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12826	 13357	 0.005875	 0.015101	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79147	 12826	 0.00836	 0.018964	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12827	 79327	 0.017878	 0.013154	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12828	 12829	 0.004205	 0.012061	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79147	 12828	 0.005398	 0.012531	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12829	 12831	 0.006332	 0.016103	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12829	 12833	 0.017332	 0.015964	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12830	 79316	 0.014144	 0.010716	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12831	 13320	 0.003998	 0.010279	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12831	 13322	 0.009304	 0.018422	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12832	 13309	 0.004688	 0.011102	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12832	 79149	 0.005789	 0.011846	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12833	 79149	 0.012629	 0.013891	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12834	 12835	 0.000649	 0.002892	 0.00079	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12834	 79149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12834	 79149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12835	 12962	 0.000899	 0.003533	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12836	 12961	 0.001929	 0.008995	 0.00223	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12836	 79150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12836	 79150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12836	 79157	 0.002592	 0.015558	 0.00471	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12837	 12838	 0.000751	 0.004618	 0.00133	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12837	 12862	 0.000583	 0.004261	 0.00109	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12838	 13443	 0.00126	 0.00782	 0.00189	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12838	 79151	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12838	 79151	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12839	 12840	 0.001171	 0.00469	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12839	 13282	 0.003878	 0.014042	 0.00301	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12839	 13285	 0.002395	 0.006157	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12839	 79152	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12839	 79152	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12839	 79157	 0.002685	 0.01209	 0.00322	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12840	 12866	 0.000629	 0.002201	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12840	 79153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12840	 79153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12841	 12847	 0.010654	 0.018735	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12842	 12847	 0.008735	 0.038488	 0.00067	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12843	 12844	 0.004376	 0.018267	 0.00053	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12844	 12845	 0.009589	 0.024649	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12844	 12847	 0.009573	 0.025374	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12845	 12864	 0.006866	 0.018199	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12846	 12855	 0.005063	 0.022563	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79139	 12846	 0.017723	 0.068183	 0.00116	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12847	 12865	 0.002982	 0.014914	 0.00027	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12847	 79158	 0.005832	 0.031323	 0.00074	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12848	 12854	 0.020671	 0.015209	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12848	 12855	 0.018423	 0.018026	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12849	 79154	 0.013041	 0.019978	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12850	 12851	 0.000873	 0.00446	 0.00112	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12850	 12899	 0.000884	 0.005026	 0.00145	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12851	 12858	 0.000652	 0.00382	 0.00104	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12851	 79154	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12851	 79154	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12852	 12854	 0.007657	 0.010671	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12852	 12860	 0.00497	 0.012775	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12853	 12859	 0.008668	 0.00614	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12855	 12856	 0.005825	 0.014972	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79154	 12855	 0.005555	 0.029264	 0.00053	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12856	 79155	 0.001698	 0.005467	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12857	 12858	 0.000166	 0.001334	 0.00037	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12857	 79155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12857	 79155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12857	 79157	 0.001279	 0.010898	 0.00272	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12858	 79156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12858	 79156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12859	 12860	 0.003162	 0.008042	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79155	 12859	 0.002048	 0.011644	 0.00021	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12860	 12886	 0.001001	 0.0085	 0.0002	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77754	 12860	 0.01814	 0.025713	 0.00053	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12860	 79158	 0.004149	 0.018383	 0.00055	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12861	 79157	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12861	 79167	 0.000104	 0.002458	 0.0445	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79157	 12862	 0.00069	 0.004735	 0.00138	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12863	 12866	 0.000625	 0.002786	 0.00076	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79151	 12864	 0.02361	 0.039431	 0.00067	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12864	 79203	 0.005333	 0.01905	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12865	 79203	 0.001912	 0.011152	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12866	 79159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12866	 79159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12867	 12868	 0.00106	 0.003124	 0.00073	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12867	 12896	 0.001969	 0.006962	 0.00157	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12867	 79160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12867	 79160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12868	 12896	 0.001782	 0.005162	 0.00125	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12869	 12870	 0.003641	 0.007802	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12869	 13196	 0.004114	 0.00955	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12870	 13275	 0.004147	 0.018271	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12870	 79162	 0.008377	 0.012206	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12870	 79163	 0.015095	 0.066507	 0.00116	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12871	 12885	 0.006841	 0.015882	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12871	 13189	 0.002879	 0.010645	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12871	 79166	 0.006899	 0.019085	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12872	 12874	 0.000748	 0.004379	 0.00119	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12872	 12881	 0.000544	 0.004823	 0.00128	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12872	 79161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12872	 79161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79161	 12873	 0.002973	 0.016707	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12873	 79308	 0.003349	 0.019039	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12874	 13279	 0.000626	 0.003452	 0.00081	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12874	 79162	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12874	 79162	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79152	 12875	 0.037	 0.037371	 0.00049	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12877	 79163	 0.003938	 0.006032	 8e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12878	 79163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12878	 79163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12878	 79168	 0.008422	 0.028891	 0.00692	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12879	 12880	 0.00625	 0.014511	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79163	 12879	 0.005166	 0.011993	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78869	 12880	 0.002467	 0.014022	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12880	 79165	 0.002658	 0.008154	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12881	 12882	 0.000313	 0.003162	 0.00093	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12881	 79164	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12881	 79164	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12882	 79165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12882	 79165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79165	 12883	 0.004663	 0.011859	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12883	 79166	 0.005342	 0.012117	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12884	 13171	 0.001003	 0.00265	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12884	 79166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12884	 79166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79164	 12885	 0.004702	 0.010077	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12886	 12889	 0.002699	 0.010502	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12886	 12889	 0.002699	 0.010502	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12887	 12945	 0.000243	 0.0029	 0.21757	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12887	 13134	 0.000297	 0.003546	 0.26606	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12887	 79167	 7.1e-05	 0.005641	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12888	 12891	 0.005923	 0.019758	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12888	 12892	 0.003405	 0.011359	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79163	 12888	 0.043276	 0.090957	 0.00166	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12888	 79170	 0.002823	 0.010084	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12889	 79170	 0.005291	 0.020583	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12889	 79170	 0.005291	 0.020583	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12890	 12895	 0.000218	 0.002495	 0.00076	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79168	 12890	 0.000438	 0.006117	 0.00207	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12890	 79170	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12890	 79170	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12891	 12892	 0.003972	 0.0177	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79169	 12891	 0.004761	 0.016658	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79169	 12891	 0.004761	 0.016658	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79170	 12891	 0.011735	 0.027245	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12891	 79176	 0.045291	 0.097058	 0.0017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79156	 12892	 0.001361	 0.012669	 0.00025	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79169	 12893	 0.007089	 0.021748	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12894	 79171	 0.006258	 0.016586	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12895	 12896	 0.000445	 0.005037	 0.00194	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12895	 79171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12895	 79171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12896	 79172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12896	 79172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12897	 12898	 0.01811	 0.018291	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12897	 12916	 0.034946	 0.038063	 0.00052	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12897	 79173	 0.012552	 0.029137	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12897	 79204	 0.012129	 0.027865	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12899	 12900	 0.001078	 0.004946	 0.00127	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12899	 79173	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12899	 79173	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12900	 12901	 0.001963	 0.008174	 0.00255	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12901	 79174	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12901	 79174	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12902	 12903	 0.000423	 0.002967	 0.00505	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12902	 13439	 0.004825	 0.033846	 0.05765	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12902	 79175	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79176	 12902	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12903	 12913	 0.000652	 0.006658	 0.02114	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12903	 79177	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12903	 79177	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12903	 79198	 0.000459	 0.004208	 0.01661	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12904	 79178	 0.022902	 0.014826	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12905	 12906	 0.000641	 0.002197	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12905	 79178	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12905	 79178	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12905	 79199	 0.001676	 0.00575	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12907	 12967	 0.002642	 0.007193	 0.00158	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79175	 12907	 0.001941	 0.006659	 0.0016	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12907	 79179	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12907	 79179	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12908	 79180	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12908	 79180	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79180	 12909	 0.004278	 0.021642	 0.00038	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12909	 79182	 0.006548	 0.026763	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12910	 12912	 0.001942	 0.006796	 0.00225	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12910	 79181	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12910	 79181	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12910	 79196	 0.002157	 0.012216	 0.00303	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79181	 12911	 0.02487	 0.019495	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12912	 79182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12912	 79182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12912	 79183	 0.000736	 0.004659	 0.00126	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12913	 12921	 0.000265	 0.002827	 0.00512	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12913	 79183	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79184	 12913	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79184	 12914	 0.013761	 0.031944	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12914	 79204	 0.013348	 0.036923	 0.00086	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12915	 79204	 0.018731	 0.083464	 0.00142	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12917	 12918	 0.00142	 0.005862	 0.00139	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79132	 12918	 0.001537	 0.012563	 0.00341	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12918	 79185	 0.000777	 0.01152	 0.00355	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12919	 12920	 0.003812	 0.023433	 0.00042	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12919	 79186	 0.006069	 0.026893	 0.00081	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79139	 12920	 0.004571	 0.018135	 0.00052	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12921	 79185	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79186	 12921	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12922	 12923	 0.000272	 0.003926	 0.00125	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12922	 79189	 0.000535	 0.006686	 0.00292	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12923	 12924	 0.000727	 0.005258	 0.00283	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12923	 79187	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12923	 79187	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79132	 12924	 0.001304	 0.015423	 0.00439	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12925	 12930	 0.000961	 0.010819	 0.00284	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12926	 12927	 0.014941	 0.010801	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12927	 79188	 0.004813	 0.007013	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79132	 12928	 0.00226	 0.007907	 0.00262	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12928	 79188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12928	 79188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78626	 12929	 0.012555	 0.009936	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12930	 12932	 0.002234	 0.011579	 0.00283	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12930	 79189	 0.001626	 0.013198	 0.0042	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12931	 12943	 0.000144	 0.001525	 0.0159	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12931	 12944	 0.00019	 0.00338	 0.03506	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	12931	 79189	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12931	 79189	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12932	 12934	 0.002305	 0.008386	 0.00257	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12932	 12941	 0.004213	 0.031731	 0.0088	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12933	 12935	 0.000636	 0.003195	 0.00083	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77667	 12933	 0.007861	 0.050637	 0.01328	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12933	 79190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12933	 79190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12934	 12935	 0.001357	 0.004749	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79190	 12936	 0.001647	 0.010128	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12937	 79191	 0.073336	 0.058038	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12938	 79191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12938	 79191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12939	 12958	 0.008726	 0.029108	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78581	 12939	 0.006838	 0.030128	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79191	 12939	 0.006963	 0.019261	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12940	 79192	 0.079504	 0.060236	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12941	 12949	 0.001791	 0.014113	 0.00413	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12941	 79192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12941	 79192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12942	 79194	 0.055233	 0.043711	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12943	 79193	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79044	 12944	 0.001437	 0.016595	 0.14556	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79131	 12944	 0.000617	 0.006528	 0.09763	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79131	 12944	 0.000617	 0.006528	 0.09763	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12944	 79195	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79196	 12944	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12944	 79197	 0.000141	 0.001423	 0.02341	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12944	 79197	 0.000141	 0.001423	 0.02341	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12945	 79197	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12945	 79197	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79198	 12945	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79198	 12945	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79195	 12946	 0.000203	 0.003058	 0.01098	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79198	 12946	 0.000129	 0.002118	 0.00794	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12946	 79199	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12946	 79199	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12947	 12955	 0.005998	 0.019046	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12947	 79200	 0.007319	 0.028157	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12948	 79200	 0.038596	 0.030545	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77667	 12949	 0.000303	 0.004367	 0.00159	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12949	 79200	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12949	 79200	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12950	 12954	 0.002698	 0.004307	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12951	 79201	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12951	 79201	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12952	 12954	 0.004909	 0.012619	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12952	 12956	 0.003417	 0.011399	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12952	 12957	 0.002075	 0.010556	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12953	 12956	 0.008736	 0.011908	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12953	 12958	 0.039936	 0.035785	 0.00073	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79200	 12953	 0.002346	 0.021843	 0.00042	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79201	 12953	 0.001408	 0.008336	 0.00016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12953	 79202	 0.011913	 0.046345	 0.00077	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12955	 12956	 0.004213	 0.009556	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12955	 12958	 0.009775	 0.022173	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12957	 79202	 0.001736	 0.01254	 0.00024	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12959	 79202	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12959	 79202	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79202	 12960	 0.010928	 0.007741	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12961	 12962	 0.000753	 0.003512	 0.00087	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12963	 12964	 0.017742	 0.019514	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12963	 12965	 0.015519	 0.02933	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79150	 12963	 0.018378	 0.036388	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12965	 79313	 0.005115	 0.010467	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79157	 12966	 0.001018	 0.004942	 0.00113	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12966	 79203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12966	 79203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12967	 79204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12967	 79204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12968	 13040	 0.011486	 0.075907	 0.00149	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12968	 79230	 0.016494	 0.12856	 0.0024	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	12969	 13046	 0.002319	 0.013916	 0.00421	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12969	 79205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12969	 79205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12970	 12971	 0.006776	 0.038518	 0.0007	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	12970	 13040	 0.079715	 0.20275	 0.00321	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12970	 13063	 0.043777	 0.16775	 0.00474	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12970	 13579	 0.0625	 0.2838	 0.00616	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79205	 12970	 0.001024	 0.009421	 0.00019	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12971	 13043	 0.023583	 0.145	 0.00261	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12972	 13025	 0.003608	 0.012891	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12972	 79206	 0.003379	 0.014886	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12973	 13030	 0.00392	 0.019128	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12973	 79206	 0.003824	 0.017038	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12974	 12978	 0.015331	 0.011083	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12975	 12976	 0.001764	 0.005284	 0.00119	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12975	 79206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12975	 79206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12976	 12977	 0.000795	 0.00223	 0.00057	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77715	 12976	 0.000827	 0.007779	 0.00236	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12976	 79207	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12976	 79207	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12977	 79208	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12977	 79208	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12978	 12979	 0.011458	 0.009067	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79208	 12978	 0.002904	 0.014172	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	12980	 12981	 0.003421	 0.006773	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12981	 12982	 0.002616	 0.006072	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12982	 12983	 0.004141	 0.009807	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12983	 79209	 0.007878	 0.022595	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12984	 13033	 0.001517	 0.005205	 0.00125	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77715	 12984	 0.000484	 0.006193	 0.00185	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12984	 79209	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12984	 79209	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12985	 13016	 0.007562	 0.029091	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78393	 12985	 0.004766	 0.018541	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12985	 79210	 0.006452	 0.021522	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12986	 13017	 0.001743	 0.014005	 0.00394	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12986	 13018	 0.000195	 0.002319	 0.00081	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12986	 79210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12986	 79210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12987	 12988	 0.001615	 0.00817	 0.00014	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79210	 12987	 0.001445	 0.008216	 0.00015	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78393	 12988	 0.002937	 0.012938	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12989	 12991	 0.000323	 0.003353	 0.00104	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12990	 12991	 0.00044	 0.005172	 0.00137	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12990	 13023	 0.000251	 0.003655	 0.00117	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	12990	 13037	 0.001256	 0.00871	 0.00249	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12990	 79211	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12990	 79211	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12992	 12994	 0.001325	 0.019087	 0.00693	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12992	 12997	 0.00089	 0.012073	 0.00698	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12992	 13039	 0.001147	 0.015345	 0.0042	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12992	 79212	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12992	 79212	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79212	 12993	 0.016052	 0.028851	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77698	 12994	 0.000895	 0.009657	 0.00276	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77769	 12994	 0.001051	 0.010425	 0.00283	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12995	 79213	 0.022981	 0.044011	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79212	 12996	 0.009215	 0.028268	 0.00077	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79212	 12996	 0.009215	 0.028268	 0.00077	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12996	 79213	 0.009798	 0.035	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12996	 79213	 0.009798	 0.035	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12997	 12998	 0.001882	 0.019329	 0.00611	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	12997	 79213	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12997	 79213	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12998	 13000	 0.001476	 0.013892	 0.00421	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	12998	 13012	 0.002529	 0.010123	 0.00255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12999	 13000	 0.004024	 0.01703	 0.00383	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	12999	 79214	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12999	 79214	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13000	 13001	 0.001025	 0.012114	 0.00345	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13000	 13009	 0.005502	 0.022718	 0.00538	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13001	 13002	 0.001115	 0.012346	 0.00402	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13002	 13003	 0.000836	 0.010521	 0.00326	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13003	 13004	 0.000495	 0.006233	 0.00193	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78683	 13004	 0.001773	 0.014247	 0.004	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13004	 79215	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13004	 79215	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77712	 13005	 0.009657	 0.019121	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13006	 79216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13006	 79216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79216	 13007	 0.003946	 0.015655	 0.00045	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77712	 13008	 0.012888	 0.021711	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13009	 79217	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13009	 79217	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13010	 13011	 0.008798	 0.046347	 0.00083	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79217	 13010	 0.005414	 0.033288	 0.0006	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79214	 13011	 0.041597	 0.077346	 0.00181	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13011	 79218	 0.003669	 0.018347	 0.00033	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13011	 79220	 0.030543	 0.040143	 0.00055	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13012	 13014	 0.001488	 0.008303	 0.00212	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13012	 79218	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13012	 79218	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13013	 13014	 0.001029	 0.00934	 0.00304	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13013	 13031	 0.00131	 0.00987	 0.00274	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13013	 79219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13013	 79219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77715	 13014	 0.002297	 0.023864	 0.00738	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13014	 79220	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13014	 79220	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79213	 13015	 0.045079	 0.10464	 0.00199	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79218	 13015	 0.00516	 0.042422	 0.00082	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79220	 13015	 0.007341	 0.051139	 0.0012	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13015	 79221	 0.01011	 0.03933	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13015	 79221	 0.01011	 0.03933	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13016	 13020	 0.00206	 0.020188	 0.0004	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13016	 79221	 0.002838	 0.026421	 0.00051	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78401	 13017	 0.000962	 0.010548	 0.00939	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 79221	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13017	 79221	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13018	 13023	 0.000742	 0.007865	 0.00233	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13018	 79222	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13018	 79222	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79211	 13019	 0.002167	 0.009604	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79222	 13019	 0.003093	 0.013782	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79220	 13020	 0.010334	 0.040204	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79220	 13020	 0.010334	 0.040204	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79222	 13020	 0.028931	 0.044319	 0.00062	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13021	 13022	 0.03006	 0.022116	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13022	 79223	 0.006759	 0.017374	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13023	 79223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13023	 79223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13023	 79225	 0.000343	 0.005434	 0.00344	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79206	 13024	 0.00302	 0.013381	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13024	 79224	 0.003305	 0.015325	 0.00032	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13025	 13026	 0.007745	 0.017978	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13025	 79224	 0.010753	 0.021291	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77716	 13026	 0.020607	 0.068742	 0.00109	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79220	 13026	 0.007218	 0.03522	 0.00061	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13026	 79224	 0.014401	 0.027217	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77715	 13027	 0.001024	 0.009832	 0.00286	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13027	 79224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13027	 79224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13027	 79225	 0.000456	 0.004738	 0.00147	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13028	 79225	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13028	 79225	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13029	 13031	 0.00061	 0.00446	 0.00132	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13029	 79226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13029	 79226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79226	 13030	 0.005195	 0.020212	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13031	 79227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13031	 79227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79207	 13032	 0.013875	 0.010876	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13033	 79228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13033	 79228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13034	 13036	 0.003044	 0.02199	 0.00042	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79228	 13034	 0.002088	 0.01269	 0.00023	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77716	 13035	 0.00385	 0.025443	 0.0005	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79211	 13035	 0.015239	 0.079247	 0.00172	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79052	 13036	 0.003824	 0.028414	 0.00068	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77715	 13037	 0.000833	 0.013108	 0.00698	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13037	 79229	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13037	 79229	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77694	 13038	 0.002053	 0.010384	 0.00289	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77694	 13039	 0.001019	 0.016395	 0.00536	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13040	 79230	 0.014974	 0.045937	 0.00124	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13040	 79230	 0.014974	 0.045937	 0.00124	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13041	 13042	 0.009237	 0.030814	 0.00782	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13041	 79230	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13041	 79230	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13042	 13578	 0.003788	 0.016032	 0.00361	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13042	 79231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13042	 79231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79231	 13043	 0.017095	 0.043944	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13043	 79390	 0.008455	 0.051384	 0.00095	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13044	 13045	 0.002825	 0.010738	 0.00301	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13045	 13059	 0.001909	 0.007766	 0.00189	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13046	 79232	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13046	 79232	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79232	 13047	 0.025312	 0.077735	 0.00146	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13047	 79233	 0.034785	 0.091955	 0.00167	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13048	 13049	 0.004306	 0.026474	 0.00048	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77742	 13048	 0.002491	 0.019412	 0.00036	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13049	 13050	 0.011192	 0.007928	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13049	 79369	 0.013141	 0.058234	 0.00175	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13051	 13054	 0.002083	 0.008339	 0.0021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13051	 79233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13051	 79233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13052	 13055	 0.000831	 0.004307	 0.00105	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13052	 13057	 0.003332	 0.017713	 0.00411	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13052	 79234	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13052	 79234	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13053	 13491	 0.012105	 0.078099	 0.00249	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79234	 13053	 0.000902	 0.007113	 0.00015	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13054	 13056	 0.00037	 0.001611	 0.00046	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13055	 13056	 0.000399	 0.001859	 0.00046	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13055	 79235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13055	 79235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13057	 13058	 0.007031	 0.032793	 0.00812	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13058	 13061	 0.001809	 0.009242	 0.00232	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13059	 13061	 0.001025	 0.003516	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13060	 79236	 0.013479	 0.008727	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13061	 79236	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13061	 79236	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13062	 79377	 0.025517	 0.13966	 0.00273	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13063	 13496	 0.031222	 0.21434	 0.00391	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77742	 13063	 0.005238	 0.022493	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79233	 13063	 0.00493	 0.036034	 0.00066	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13064	 13065	 0.002728	 0.021495	 0.00629	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13064	 79237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13064	 79237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13065	 79238	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13065	 79238	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13066	 13068	 0.051157	 0.11876	 0.00226	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79237	 13066	 0.054234	 0.090581	 0.00154	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13066	 79239	 0.031769	 0.16072	 0.0028	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13067	 13068	 0.033231	 0.065794	 0.00097	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78769	 13067	 0.072767	 0.15595	 0.00273	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79238	 13068	 0.033498	 0.07777	 0.00116	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78762	 13069	 0.11517	 0.091147	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13070	 13071	 0.002854	 0.0164	 0.00465	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13071	 13072	 0.003867	 0.023772	 0.00686	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78779	 13072	 0.007089	 0.044052	 0.01243	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13072	 79239	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13072	 79239	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78766	 13073	 0.000909	 0.013828	 0.24797	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13073	 79240	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13073	 79240	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13074	 13211	 0.000312	 0.003699	 0.00129	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13074	 79241	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13074	 79241	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13075	 13078	 0.000923	 0.002872	 0.0006	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13075	 13432	 0.000471	 0.001412	 0.00032	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13075	 79242	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13075	 79242	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13076	 13078	 0.00018	 0.00112	 0.00032	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13076	 13197	 0.000187	 0.001161	 0.00033	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13077	 79243	 0.006736	 0.004361	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13078	 13081	 0.000229	 0.00111	 0.00025	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13079	 13080	 0.000727	 0.00269	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79242	 13079	 0.001428	 0.004096	 6e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13080	 13085	 0.000629	 0.003535	 7e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13081	 13091	 0.000374	 0.001982	 0.0005	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13081	 79243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13081	 79243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13082	 79245	 0.004729	 0.003628	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79243	 13083	 0.003459	 0.002738	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13084	 79246	 0.005074	 0.003977	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13085	 79244	 0.000501	 0.002817	 6e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13086	 13090	 0.004678	 0.003666	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13087	 13088	 0.001682	 0.003127	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13087	 13090	 0.00209	 0.004851	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13088	 13096	 0.00165	 0.005067	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13088	 79249	 0.005535	 0.013739	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13089	 13092	 0.000489	 0.001771	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13089	 79244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13089	 79244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79244	 13090	 0.002279	 0.005235	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13091	 13092	 0.000885	 0.002339	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13091	 79245	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13091	 79245	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13092	 79246	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13092	 79246	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77711	 13093	 0.004464	 0.003533	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13094	 13099	 0.000831	 0.00255	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79246	 13094	 0.001095	 0.003613	 6e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13095	 13098	 0.003086	 0.002231	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13096	 13097	 0.001009	 0.002865	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13097	 79250	 0.001798	 0.004175	 6e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13098	 79249	 0.003699	 0.00371	 6e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13099	 79247	 0.001111	 0.004951	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13100	 13114	 0.007941	 0.005741	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77697	 13100	 0.002438	 0.004534	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13101	 13102	 0.000125	 0.001282	 0.00041	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13101	 79247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13101	 79247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13102	 13103	 0.000146	 0.001545	 0.00046	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13102	 79248	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13102	 79248	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13103	 13104	 5.1e-05	 0.000823	 0.00027	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13103	 13110	 5.1e-05	 0.00088	 0.00048	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13104	 13105	 0.00016	 0.002007	 0.00062	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13104	 79249	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13104	 79249	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13105	 13426	 8.5e-05	 0.001065	 0.00033	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13105	 79250	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13105	 79250	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13106	 13107	 0.005208	 0.003765	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13106	 13108	 0.00195	 0.002988	 4e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13108	 79251	 0.001559	 0.003966	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13109	 13110	 0.000412	 0.00109	 0.00026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13109	 79251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13109	 79251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13110	 13111	 5.8e-05	 0.000951	 0.00057	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13111	 13120	 6e-05	 0.001002	 0.00057	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13111	 79252	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13111	 79252	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79248	 13112	 0.000753	 0.003144	 9e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79252	 13112	 0.000641	 0.003941	 7e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13113	 13117	 0.001735	 0.005788	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79247	 13113	 0.00198	 0.004529	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13115	 79253	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13115	 79253	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13116	 13117	 0.003867	 0.009941	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79253	 13116	 0.006534	 0.011968	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13117	 13118	 0.000427	 0.003509	 7e-05	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13118	 79254	 0.00067	 0.006238	 0.00012	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13119	 13120	 0.000104	 0.001368	 0.00127	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13119	 79254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13119	 79254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13120	 79255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13120	 79255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79254	 13121	 0.011171	 0.008219	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79255	 13122	 0.008768	 0.006873	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13123	 13125	 0.00122	 0.005857	 0.00011	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79255	 13123	 0.002267	 0.006007	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13123	 79258	 0.003786	 0.024425	 0.00078	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13124	 13126	 0.000666	 0.001856	 0.00039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13124	 79256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13124	 79256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13125	 13429	 0.002	 0.005736	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79256	 13125	 0.000782	 0.00537	 0.0001	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13126	 79257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13126	 79257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79257	 13127	 0.008252	 0.00653	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13127	 79355	 0.011193	 0.008235	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13128	 79258	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13128	 79258	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13128	 79357	 0.000704	 0.005064	 0.00134	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78816	 13129	 0.001338	 0.003537	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78822	 13129	 0.00026	 0.003974	 0.00128	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13129	 79357	 0.000612	 0.009395	 0.00263	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13130	 13132	 7e-06	 0.000133	 0.01081	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13130	 79259	 7.2e-05	 0.005789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13130	 79259	 7.2e-05	 0.005789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79260	 13131	 0.013474	 0.010663	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13132	 13134	 7e-06	 0.00013	 0.01143	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13133	 79262	 0.00922	 0.006783	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13134	 13455	 1.3e-05	 0.000349	 0.02612	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13134	 79261	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79262	 13135	 0.008438	 0.006208	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79262	 13136	 0.002181	 0.009721	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13137	 79265	 0.007896	 0.005304	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13138	 13139	 0.000156	 0.001831	 0.00049	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13138	 13141	 0.000404	 0.002364	 0.00064	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13138	 79263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13138	 79263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79261	 13139	 0.000202	 0.002233	 0.00067	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13140	 79264	 0.010984	 0.00794	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13141	 79264	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13141	 79264	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79264	 13142	 0.000577	 0.004216	 8e-05	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13142	 79265	 0.000642	 0.003905	 7e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13143	 13144	 0.000125	 0.001357	 0.00042	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13143	 13145	 9.6e-05	 0.001336	 0.00045	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13143	 79265	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13143	 79265	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13144	 13151	 0.000102	 0.001161	 0.00033	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13145	 13148	 9.9e-05	 0.001518	 0.00042	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79264	 13146	 0.002314	 0.008902	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79264	 13146	 0.002314	 0.008902	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13146	 79266	 0.000722	 0.00601	 0.00011	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13147	 79272	 0.012148	 0.009522	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13148	 13161	 0.000168	 0.002566	 0.00083	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13148	 79266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13148	 79266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79266	 13149	 0.006927	 0.005482	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13150	 79271	 0.007107	 0.007817	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13151	 13153	 0.000161	 0.001956	 0.00053	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13151	 79267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13151	 79267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79267	 13152	 0.001786	 0.003654	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13152	 79269	 0.003071	 0.007809	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13153	 13155	 0.000144	 0.002164	 0.00065	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13153	 79268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13153	 79268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13154	 79269	 0.00659	 0.005055	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13155	 13156	 0.000127	 0.000879	 0.00052	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13155	 79269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13155	 79269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13156	 13157	 0.000185	 0.001449	 0.00066	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13156	 79270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13156	 79270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13157	 13159	 0.000132	 0.00185	 0.00063	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13157	 79271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13157	 79271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13158	 13159	 5.8e-05	 0.000565	 0.00037	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13158	 13160	 8.4e-05	 0.000883	 0.0005	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13159	 13177	 0.000617	 0.002471	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13160	 13161	 4.8e-05	 0.000515	 0.00028	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13161	 13163	 3.8e-05	 0.000617	 0.00037	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13161	 79272	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13161	 79272	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13162	 13163	 3.9e-05	 0.000665	 0.00036	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13162	 79273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13162	 79273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13162	 79341	 6.8e-05	 0.001078	 0.00068	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13164	 13165	 0.003648	 0.006582	 0.0001	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13164	 13182	 0.002436	 0.005962	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77711	 13164	 0.007725	 0.019646	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79273	 13165	 0.002776	 0.005948	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13166	 13179	 0.002258	 0.004374	 9e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13166	 13181	 0.003886	 0.009882	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79272	 13166	 0.001181	 0.006633	 0.00012	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79271	 13167	 0.009281	 0.007119	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79270	 13168	 0.001083	 0.006154	 0.00011	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13168	 79274	 0.001433	 0.005013	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13168	 79278	 0.002511	 0.011189	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13169	 13170	 0.000106	 0.001103	 0.00034	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13169	 13175	 0.000137	 0.001471	 0.00038	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13169	 79274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13169	 79274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13171	 79275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13171	 79275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13172	 13454	 0.001432	 0.005508	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79275	 13172	 0.00124	 0.003555	 5e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13173	 13188	 0.002834	 0.007206	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13173	 79276	 0.00442	 0.007445	 0.00011	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13174	 13185	 0.000386	 0.001904	 0.00051	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13174	 79276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13174	 79276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13175	 13176	 0.000132	 0.001341	 0.00035	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13175	 79277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13175	 79277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13176	 13177	 0.000148	 0.001421	 0.00041	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13177	 13183	 0.000711	 0.003781	 0.00088	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13177	 79278	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13177	 79278	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79278	 13178	 0.00633	 0.004576	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13179	 13180	 0.002105	 0.004723	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13180	 79279	 0.002222	 0.005712	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13181	 13182	 0.002505	 0.00644	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13183	 13447	 0.000653	 0.003399	 0.00089	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13183	 79279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13183	 79279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13184	 13191	 0.006168	 0.013838	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79279	 13184	 0.005238	 0.01216	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13184	 79280	 0.001256	 0.008947	 0.0002	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13184	 79342	 0.009542	 0.037119	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13185	 79280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13185	 79280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13186	 13190	 0.001618	 0.007212	 0.00012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79280	 13186	 0.000968	 0.004925	 0.00011	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13187	 13189	 0.003904	 0.012882	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79276	 13187	 0.00185	 0.009357	 0.00016	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13188	 13431	 0.003218	 0.008271	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13189	 13192	 0.001546	 0.009506	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13190	 13191	 0.002374	 0.006103	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13191	 13193	 0.003093	 0.012034	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13192	 13193	 0.001015	 0.005767	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13193	 13194	 0.003769	 0.013462	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13193	 13196	 0.002082	 0.00851	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13194	 13195	 0.000805	 0.003588	 6e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13194	 13196	 0.00214	 0.005443	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13195	 13274	 0.002599	 0.011583	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13197	 13208	 0.000968	 0.003875	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13197	 13215	 0.000351	 0.005239	 0.00155	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13197	 79281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13197	 79281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13197	 79341	 0.000647	 0.005648	 0.00155	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13198	 13210	 0.00059	 0.001767	 0.0004	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13198	 13432	 0.000624	 0.00184	 0.00043	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13199	 13200	 0.007229	 0.005226	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13199	 79343	 0.010474	 0.007572	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13200	 13202	 0.007805	 0.005053	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13201	 13204	 0.004506	 0.004955	 7e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79281	 13201	 0.003195	 0.005852	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13202	 13203	 0.006573	 0.004256	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79281	 13202	 0.002745	 0.005379	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13204	 13205	 0.004473	 0.00354	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13206	 13218	 0.002109	 0.006049	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13206	 13220	 0.004833	 0.011221	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13206	 79282	 0.005156	 0.011844	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13207	 79282	 0.007755	 0.005706	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13208	 13217	 0.000538	 0.001587	 0.00037	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13208	 79282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13208	 79282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13209	 13216	 0.002034	 0.004651	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79282	 13209	 0.001805	 0.007023	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13210	 79283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13210	 79283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13211	 13225	 0.000209	 0.002266	 0.00095	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13211	 79284	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13211	 79284	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13212	 13225	 0.000549	 0.001426	 0.00035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13213	 13214	 0.003306	 0.006765	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13213	 13224	 0.010974	 0.008685	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79284	 13213	 0.003464	 0.006789	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13214	 79285	 0.001932	 0.004419	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13215	 13433	 0.00018	 0.001361	 0.00067	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13215	 79285	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13215	 79285	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79285	 13216	 0.00302	 0.007012	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13217	 13221	 0.00053	 0.001486	 0.00038	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13218	 79286	 0.002277	 0.006036	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13219	 13237	 0.000516	 0.00196	 0.00055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13219	 13447	 0.000624	 0.003233	 0.00079	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13219	 79286	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13219	 79286	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13220	 13236	 0.003743	 0.008022	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13221	 13222	 0.000723	 0.002131	 0.0005	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13221	 13279	 0.004215	 0.017151	 0.00418	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13222	 79287	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13222	 79287	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13223	 13224	 0.008036	 0.006359	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13225	 13226	 0.00027	 0.001995	 0.00058	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13225	 13228	 0.000885	 0.003442	 0.00092	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13226	 13250	 0.000258	 0.002735	 0.00081	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13226	 79288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13226	 79288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79288	 13227	 0.003678	 0.007283	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13228	 13229	 0.0004	 0.001603	 0.0004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13229	 13230	 0.000111	 0.001826	 0.00057	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13229	 13244	 0.000623	 0.003128	 0.00081	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13229	 13245	 0.000274	 0.001502	 0.0004	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13229	 79289	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13229	 79289	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13230	 13433	 0.000162	 0.002265	 0.00077	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13230	 79290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13230	 79290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13231	 13232	 0.001508	 0.003835	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79290	 13231	 0.002059	 0.005293	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13232	 13234	 0.001403	 0.003833	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13233	 13234	 0.005211	 0.004124	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13234	 13243	 0.013154	 0.01041	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79287	 13234	 0.001218	 0.005847	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13235	 13242	 0.004289	 0.009622	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79287	 13235	 0.003241	 0.010813	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13236	 13241	 0.001627	 0.00633	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13236	 79291	 0.002287	 0.006558	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13237	 13239	 0.000723	 0.003058	 0.00069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13237	 79291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13237	 79291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13238	 13270	 0.001329	 0.004334	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13238	 13271	 0.00069	 0.003166	 0.00081	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13238	 79292	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13238	 79292	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13238	 79341	 0.00299	 0.016932	 0.0042	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13239	 79293	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13239	 79293	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13240	 13242	 0.001681	 0.006539	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79293	 13240	 0.001448	 0.005743	 0.00016	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79292	 13241	 0.004773	 0.012269	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79293	 13241	 0.001242	 0.004776	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13242	 13265	 0.001484	 0.00716	 0.00013	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13244	 13263	 0.000453	 0.001887	 0.00059	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13245	 13259	 0.000416	 0.001909	 0.00049	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13245	 79294	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13245	 79294	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13246	 13248	 0.006754	 0.006052	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79294	 13246	 0.0027	 0.004427	 8e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13247	 13258	 0.000936	 0.003712	 0.00011	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13247	 79295	 0.000783	 0.004389	 0.00012	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13248	 79295	 0.009365	 0.007411	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13248	 79300	 0.015961	 0.012511	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13249	 13250	 0.000504	 0.001459	 0.00035	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13249	 79295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13249	 79295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13250	 79296	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13250	 79296	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13250	 79345	 0.000486	 0.004165	 0.00119	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13251	 13252	 0.003847	 0.005244	 0.00012	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79288	 13251	 0.005434	 0.009075	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79296	 13252	 0.010502	 0.006799	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13252	 79346	 0.012451	 0.012576	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13253	 79298	 0.00516	 0.010113	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13254	 79297	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79298	 13254	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13254	 79344	 0.000132	 0.002019	 0.00705	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13255	 13258	 0.00346	 0.007849	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13255	 79348	 0.003885	 0.006202	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13256	 79299	 0.001809	 0.007037	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13256	 79322	 0.003042	 0.00782	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13257	 13345	 0.001411	 0.007582	 0.00187	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13257	 79299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13257	 79299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13257	 79345	 0.001023	 0.007234	 0.00198	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13259	 13260	 0.000196	 0.000897	 0.00023	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13260	 79300	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13260	 79300	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13260	 79349	 0.000597	 0.002321	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13261	 13262	 0.000356	 0.001562	 0.00054	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13261	 13336	 0.000914	 0.003135	 0.00075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13261	 13340	 0.000321	 0.002035	 0.00055	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13261	 79301	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13261	 79301	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13262	 13263	 0.000364	 0.001696	 0.00042	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13262	 79302	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13262	 79302	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13264	 13265	 0.005766	 0.004563	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13265	 13267	 0.001946	 0.00597	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13266	 13267	 0.001131	 0.006363	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13266	 13268	 0.000869	 0.003848	 9e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13267	 79303	 0.002242	 0.007846	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79302	 13268	 0.002036	 0.006791	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13269	 13333	 0.010515	 0.008321	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13270	 79303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13270	 79303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13271	 79304	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13271	 79304	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13272	 13273	 0.002893	 0.009652	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79292	 13272	 0.004713	 0.011986	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13273	 13276	 0.003784	 0.010029	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13274	 13275	 0.002107	 0.007526	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13275	 13276	 0.001922	 0.00721	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13275	 13277	 0.002392	 0.011672	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79292	 13275	 0.008558	 0.033292	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13275	 79305	 0.004941	 0.009783	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13277	 13278	 0.00122	 0.005437	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13278	 79306	 0.002383	 0.008512	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13279	 13280	 0.000529	 0.002116	 0.00053	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13279	 79305	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13279	 79305	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13280	 79306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13280	 79306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13281	 79307	 0.004087	 0.010832	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13281	 79308	 0.001987	 0.008805	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13282	 13448	 0.000522	 0.002776	 0.00064	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13282	 79307	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13282	 79307	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79307	 13283	 0.006233	 0.016024	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13283	 79309	 0.003882	 0.013262	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13284	 13285	 0.001063	 0.002733	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13284	 79308	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13284	 79308	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13285	 79309	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13285	 79309	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13286	 79313	 0.012868	 0.010086	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13287	 13288	 0.000347	 0.001644	 0.0004	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13287	 13290	 0.001176	 0.004034	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13287	 13448	 0.000696	 0.003195	 0.00082	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13288	 13290	 0.001102	 0.002769	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13288	 79310	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13288	 79310	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13289	 13302	 0.002537	 0.00976	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13289	 13303	 0.001364	 0.007752	 0.00014	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79307	 13289	 0.00507	 0.028488	 0.00053	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79310	 13289	 0.001171	 0.006267	 0.00019	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13290	 13336	 0.001634	 0.008129	 0.00262	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13290	 79311	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13290	 79311	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13291	 13292	 0.003749	 0.008004	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79311	 13291	 0.003068	 0.006575	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13292	 13293	 0.001989	 0.005986	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79304	 13292	 0.001616	 0.009934	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13293	 13298	 0.00244	 0.006998	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13294	 13296	 0.002909	 0.006114	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13294	 13297	 0.001167	 0.008013	 0.00015	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13294	 13298	 0.005779	 0.013417	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79304	 13294	 0.0021	 0.014415	 0.00026	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79303	 13295	 0.012389	 0.009711	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13296	 13333	 0.003194	 0.008123	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13297	 13332	 0.001245	 0.007259	 0.00015	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13298	 13300	 0.00167	 0.010149	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79311	 13298	 0.00305	 0.007006	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13299	 13300	 0.00094	 0.00505	 0.00012	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13299	 13302	 0.005509	 0.012791	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13299	 13332	 0.004487	 0.010308	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13299	 13445	 0.002877	 0.014037	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13299	 79317	 0.025418	 0.025492	 0.00041	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13301	 13316	 0.002456	 0.009554	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13301	 13331	 0.006405	 0.008048	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13301	 13445	 0.001215	 0.006836	 0.00015	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13303	 13304	 0.001344	 0.007217	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13303	 13444	 0.011039	 0.014366	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13304	 13305	 0.001835	 0.006268	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13304	 13445	 0.001581	 0.008885	 0.00016	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13305	 79312	 0.001719	 0.006615	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13306	 13307	 0.000401	 0.002088	 0.00055	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13306	 13312	 0.001312	 0.004638	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13306	 79312	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13306	 79312	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13307	 13443	 0.000937	 0.004879	 0.00128	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13307	 79313	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13307	 79313	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13308	 13311	 0.000965	 0.00541	 0.00015	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79312	 13308	 0.00135	 0.009269	 0.00017	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13309	 13310	 0.002129	 0.005643	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13309	 13311	 0.002307	 0.010281	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79145	 13309	 0.014571	 0.037457	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13310	 79315	 0.001555	 0.006051	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13312	 13313	 0.000537	 0.00215	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13312	 79314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13312	 79314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13313	 13314	 0.000547	 0.001824	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13313	 79315	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13313	 79315	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13314	 79316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13314	 79316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13315	 13316	 0.002301	 0.006364	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79316	 13315	 0.002886	 0.007629	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79316	 13317	 0.007369	 0.011289	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13318	 13319	 0.001744	 0.006786	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13318	 13329	 0.00109	 0.004371	 0.00011	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79316	 13318	 0.01051	 0.018964	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13319	 13320	 0.001956	 0.005751	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13320	 13321	 0.007196	 0.006696	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13321	 13322	 0.007567	 0.00697	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13322	 13323	 0.003101	 0.005766	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13322	 13324	 0.005438	 0.013829	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13323	 79327	 0.005144	 0.010571	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13324	 79320	 0.003003	 0.00904	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13325	 13326	 0.004413	 0.003492	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13326	 13327	 0.002794	 0.006486	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13326	 13339	 0.003622	 0.012081	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13327	 13328	 0.003067	 0.006573	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13328	 13330	 0.004845	 0.007422	 0.0001	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13329	 13330	 0.001734	 0.009238	 0.00016	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13330	 13331	 0.004364	 0.007288	 0.00012	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13330	 13335	 0.001426	 0.007629	 0.00023	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13332	 13335	 0.002682	 0.01195	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13333	 13334	 0.009775	 0.007736	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79303	 13333	 0.003581	 0.013932	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13335	 79317	 0.002248	 0.007869	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13336	 79317	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13336	 79317	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13336	 79349	 0.001486	 0.005839	 0.00153	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13337	 13338	 0.00196	 0.005622	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79317	 13337	 0.001265	 0.003882	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13337	 79318	 0.002714	 0.006976	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13338	 13339	 0.002071	 0.004905	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13339	 79319	 0.005066	 0.016901	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13340	 13341	 0.000263	 0.001543	 0.00042	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13340	 79318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13340	 79318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13341	 13344	 0.000453	 0.002812	 0.00068	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13342	 13343	 0.000397	 0.001561	 0.00041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13342	 79319	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13342	 79319	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13342	 79349	 0.000687	 0.002794	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13343	 13346	 0.000725	 0.002184	 0.00068	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13344	 13345	 0.000491	 0.00232	 0.00074	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13345	 13355	 0.000329	 0.002639	 0.00074	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13345	 79320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13345	 79320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13346	 79321	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13346	 79321	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13347	 13352	 0.000258	 0.001944	 0.00054	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13347	 13438	 0.000564	 0.004805	 0.0012	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13347	 79322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13347	 79322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13348	 13436	 0.001356	 0.006043	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79322	 13348	 0.00143	 0.006978	 0.00012	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13349	 13372	 0.000527	 0.002108	 0.00053	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79297	 13349	 0.000826	 0.003495	 0.00079	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13349	 79323	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13349	 79323	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79323	 13350	 0.009684	 0.007664	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79297	 13351	 0.000787	 0.004318	 0.00114	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13351	 79324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13351	 79324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13352	 13353	 0.000313	 0.001983	 0.00054	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13352	 79325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13352	 79325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13353	 13364	 0.001	 0.004663	 0.00115	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13353	 79326	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13353	 79326	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13354	 13359	 0.006637	 0.013007	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13354	 79327	 0.001678	 0.005599	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13355	 13360	 0.001013	 0.006415	 0.00174	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13355	 79327	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13355	 79327	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13356	 13357	 0.00181	 0.008833	 0.00015	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13356	 13446	 0.008954	 0.017728	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79327	 13356	 0.001589	 0.007627	 0.00023	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13357	 13358	 0.002855	 0.006407	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13358	 79328	 0.003836	 0.008906	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13359	 13361	 0.006061	 0.006601	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13360	 13365	 0.000513	 0.002052	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13360	 13385	 0.00038	 0.002408	 0.00065	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13360	 79328	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13360	 79328	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13361	 79329	 0.009084	 0.008367	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13362	 13363	 0.002927	 0.005795	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13362	 13446	 0.007707	 0.01003	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13363	 13371	 0.001923	 0.004107	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13364	 13365	 0.000485	 0.001844	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13364	 79329	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13364	 79329	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13365	 79330	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13365	 79330	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13366	 13368	 0.006589	 0.006473	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79330	 13366	 0.003904	 0.006511	 9e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13367	 13369	 0.008736	 0.01065	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13368	 13369	 0.001136	 0.006081	 0.00018	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13368	 13382	 0.001203	 0.009379	 0.00018	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13369	 13370	 0.001496	 0.006975	 0.00016	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13369	 79331	 0.00154	 0.006785	 0.00012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13369	 79332	 0.014718	 0.015718	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79326	 13370	 0.002005	 0.009622	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79326	 13371	 0.00185	 0.007198	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13372	 13373	 0.000616	 0.002467	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13373	 79331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13373	 79331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13374	 13376	 0.000472	 0.00372	 0.00109	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79297	 13374	 0.000471	 0.003922	 0.00119	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13374	 79332	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13374	 79332	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79331	 13375	 0.000981	 0.00616	 0.00013	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13375	 79333	 0.001228	 0.00755	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13376	 13377	 0.000143	 0.00154	 0.00044	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13376	 79333	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13376	 79333	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13377	 13379	 0.000295	 0.001491	 0.00042	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13377	 79334	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13377	 79334	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13378	 79347	 0.01538	 0.012055	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13379	 13380	 0.000411	 0.002027	 0.00055	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13380	 13381	 0.000577	 0.002511	 0.00072	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13381	 13399	 0.000729	 0.003282	 0.00087	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79334	 13382	 0.002189	 0.015022	 0.00027	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13383	 13384	 0.000934	 0.007278	 0.00014	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13383	 79337	 0.001877	 0.010044	 0.0003	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13384	 79335	 0.001011	 0.009298	 0.00018	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13385	 79335	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13385	 79335	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13386	 13387	 0.00287	 0.011164	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13386	 13387	 0.00287	 0.011164	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13386	 13388	 0.01509	 0.011942	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13386	 13389	 0.003137	 0.012204	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13386	 13389	 0.003137	 0.012204	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79335	 13386	 0.002444	 0.009167	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79335	 13386	 0.002444	 0.009167	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13387	 13395	 0.002935	 0.010026	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13387	 13395	 0.002935	 0.010026	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13387	 13449	 0.005372	 0.003952	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13389	 13391	 0.002881	 0.007635	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79328	 13389	 0.003938	 0.015318	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79328	 13389	 0.003938	 0.015318	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79328	 13390	 0.004717	 0.01891	 0.00049	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13390	 79336	 0.002631	 0.009398	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13391	 79336	 0.002164	 0.008419	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13392	 79336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13392	 79336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79148	 13393	 0.021834	 0.017279	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13394	 13408	 0.009269	 0.023572	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13395	 13396	 0.001134	 0.005699	 0.00015	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13395	 13408	 0.005122	 0.015714	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13395	 13408	 0.005122	 0.015714	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13396	 13398	 0.002577	 0.017691	 0.00032	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13397	 13401	 0.018855	 0.014921	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13398	 13401	 0.001838	 0.011857	 0.00038	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13398	 79337	 0.002872	 0.01105	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13398	 79337	 0.002872	 0.01105	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13399	 79337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13399	 79337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13400	 13403	 0.001597	 0.010961	 0.0002	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79337	 13400	 0.001237	 0.010295	 0.00019	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13401	 13402	 0.014276	 0.011298	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13401	 13406	 0.005441	 0.018585	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13401	 13406	 0.005441	 0.018585	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13401	 79347	 0.004633	 0.036517	 0.00077	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13403	 13404	 0.004736	 0.016573	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13403	 13404	 0.004736	 0.016573	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13403	 13456	 0.00588	 0.010503	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13403	 79347	 0.006236	 0.024259	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13403	 79347	 0.006236	 0.024259	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13404	 13405	 0.002026	 0.007881	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13404	 13405	 0.002026	 0.007881	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13406	 13407	 0.002293	 0.00892	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13406	 13407	 0.002293	 0.00892	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13407	 13417	 0.003346	 0.013019	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13407	 13417	 0.003346	 0.013019	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13408	 13409	 0.003228	 0.010652	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13408	 79354	 0.005311	 0.020659	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13408	 79354	 0.005311	 0.020659	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13409	 13410	 0.002599	 0.011449	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13410	 13412	 0.002702	 0.010396	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13411	 13412	 0.002207	 0.008588	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13411	 13414	 0.003082	 0.01028	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13413	 13414	 0.004479	 0.012847	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13414	 13424	 0.007041	 0.018613	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13414	 79338	 0.001793	 0.009555	 0.00017	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13415	 79338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13415	 79338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13415	 79353	 0.001559	 0.005348	 0.00128	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13416	 13421	 0.001492	 0.007593	 0.00017	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13416	 13422	 0.002907	 0.01787	 0.00032	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13416	 13423	 0.004825	 0.014817	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13416	 79354	 0.0048	 0.014724	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13416	 79354	 0.0048	 0.014724	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13417	 13418	 0.001703	 0.006388	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13417	 13418	 0.001703	 0.006388	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13418	 79339	 0.000917	 0.00854	 0.00017	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13419	 13420	 0.000458	 0.003925	 0.00112	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13419	 79339	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13419	 79339	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13420	 79340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13420	 79340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79340	 13421	 0.002923	 0.013551	 0.00028	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13423	 13425	 0.004047	 0.015742	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13424	 13425	 0.002936	 0.010279	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79241	 13427	 0.013904	 0.009849	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13428	 79341	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13428	 79356	 0.000169	 0.001787	 0.02672	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13428	 79356	 0.000169	 0.001787	 0.02672	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13429	 13452	 0.001832	 0.010309	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13429	 79355	 0.00286	 0.011127	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13429	 79355	 0.00286	 0.011127	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13430	 13452	 0.001574	 0.009884	 0.00022	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79258	 13430	 0.001875	 0.011519	 0.00026	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79263	 13430	 0.01879	 0.048301	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79275	 13431	 0.005145	 0.011942	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13432	 79343	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13432	 79343	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13434	 13455	 7e-05	 0.00173	 0.17494	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13434	 79344	 9.4e-05	 0.007487	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13434	 79344	 9.4e-05	 0.007487	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13435	 13438	 0.000228	 0.002078	 0.00052	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79345	 13435	 0.000168	 0.001585	 0.00048	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79298	 13436	 0.002376	 0.009242	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79297	 13437	 0.000724	 0.010445	 0.00332	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13437	 79347	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13437	 79347	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13438	 79348	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13438	 79348	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79344	 13439	 0.000546	 0.003546	 0.00706	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13439	 79349	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79350	 13439	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13440	 13442	 0.015991	 0.026938	 0.00038	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79151	 13440	 0.013719	 0.024126	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13441	 79351	 0.011973	 0.009475	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13442	 13444	 0.001783	 0.010961	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13442	 79352	 0.00376	 0.011316	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13443	 79351	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13443	 79351	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79313	 13444	 0.00654	 0.015181	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79314	 13445	 0.005403	 0.013889	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79324	 13446	 0.007098	 0.02368	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13448	 79352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13448	 79352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79344	 13450	 0.001143	 0.011854	 0.02553	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79344	 13450	 0.001143	 0.011854	 0.02553	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13450	 79353	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79354	 13450	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78879	 13451	 0.028971	 0.022927	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13453	 79355	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13453	 79355	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13453	 79357	 0.000898	 0.013205	 0.00404	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13455	 79356	 7.2e-05	 0.005789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13455	 79356	 7.2e-05	 0.005789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79357	 13455	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79357	 13455	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13457	 13460	 0.006038	 0.045246	 0.01104	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13457	 13466	 0.003247	 0.024334	 0.00594	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13458	 13459	 0.088266	 0.066875	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13459	 79361	 0.091953	 0.067655	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13460	 13675	 0.00226	 0.021701	 0.00631	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13460	 79358	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13460	 79358	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77178	 13461	 0.085367	 0.33221	 0.00555	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77178	 13461	 0.085367	 0.33221	 0.00555	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79358	 13461	 0.008034	 0.060753	 0.00202	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13461	 79360	 0.007268	 0.066857	 0.00133	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13462	 13463	 0.00097	 0.007645	 0.00224	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13462	 13464	 0.002064	 0.020676	 0.00688	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13462	 79359	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13462	 79359	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13463	 13680	 0.001426	 0.011459	 0.00322	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13464	 13468	 0.002893	 0.028345	 0.00888	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13464	 79360	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13464	 79360	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13465	 13474	 0.01763	 0.089184	 0.00155	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79360	 13465	 0.013449	 0.058922	 0.00127	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13466	 13469	 0.002279	 0.014903	 0.00379	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13466	 79361	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13466	 79361	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79361	 13467	 0.06476	 0.051251	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13468	 13469	 0.002324	 0.017418	 0.00425	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13468	 13470	 0.003894	 0.026733	 0.0078	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13468	 79362	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13468	 79362	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13469	 79363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13469	 79363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13470	 79364	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13470	 79364	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79364	 13471	 0.077022	 0.059081	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13472	 13473	 0.006955	 0.044872	 0.00143	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79364	 13472	 0.008396	 0.05979	 0.00134	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79125	 13473	 0.021491	 0.065929	 0.00179	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79113	 13474	 0.015001	 0.085274	 0.00154	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13475	 13564	 0.01548	 0.060851	 0.01592	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13475	 79365	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13475	 79365	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79099	 13476	 0.11275	 0.20655	 0.00357	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13477	 13478	 0.036539	 0.161	 0.0028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79099	 13477	 0.055549	 0.24757	 0.00421	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79365	 13477	 0.030447	 0.18506	 0.00341	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78680	 13478	 0.031472	 0.21356	 0.00399	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13479	 13570	 0.034295	 0.20845	 0.00385	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78744	 13479	 0.040191	 0.2434	 0.00762	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77733	 13481	 0.044565	 0.029936	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13482	 13506	 0.002573	 0.016573	 0.00434	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13482	 79366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13482	 79366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13483	 13484	 0.004221	 0.011188	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13484	 79367	 0.018238	 0.043187	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13485	 13486	 0.001534	 0.003981	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13485	 13487	 0.001133	 0.003339	 0.00078	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13486	 79367	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13486	 79367	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13487	 79368	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13487	 79368	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77725	 13488	 0.016453	 0.031096	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13489	 13490	 0.001862	 0.006386	 0.00153	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13489	 79369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13489	 79369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13491	 13492	 0.007833	 0.050538	 0.00161	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79235	 13491	 0.026601	 0.10234	 0.00175	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13492	 13517	 0.009829	 0.071839	 0.00132	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13493	 13496	 0.075958	 0.099834	 0.00137	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13493	 79375	 0.06475	 0.13877	 0.00243	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13494	 13495	 0.004138	 0.035144	 0.00082	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79369	 13494	 0.01719	 0.066873	 0.00112	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79369	 13494	 0.01719	 0.066873	 0.00112	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13495	 13496	 0.001853	 0.017047	 0.00034	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77748	 13496	 0.003303	 0.03237	 0.00063	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78563	 13496	 0.082643	 0.32288	 0.00716	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13497	 13499	 0.004606	 0.017918	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13497	 13499	 0.004606	 0.017918	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13497	 79370	 0.002202	 0.008566	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13497	 79370	 0.002202	 0.008566	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13498	 79370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13498	 79370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13499	 13500	 0.001763	 0.00686	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13499	 13500	 0.001763	 0.00686	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13500	 13501	 0.005599	 0.017176	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13500	 13503	 0.004361	 0.031874	 0.00059	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77725	 13500	 0.024128	 0.10752	 0.00183	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13501	 79373	 0.009921	 0.038167	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13502	 13503	 0.003594	 0.024668	 0.00045	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13502	 79371	 0.007121	 0.043778	 0.00079	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13504	 13505	 0.004634	 0.022086	 0.0064	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13504	 79371	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13504	 79371	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13505	 13509	 0.005249	 0.023928	 0.00759	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13505	 79372	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13505	 79372	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13506	 13507	 0.000993	 0.005696	 0.00189	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13507	 13508	 0.001017	 0.006055	 0.00159	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13510	 13511	 0.007135	 0.043868	 0.00079	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78586	 13510	 0.029017	 0.11289	 0.00188	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13511	 79373	 0.008434	 0.051853	 0.00093	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13512	 13513	 0.001706	 0.007042	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13512	 79373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13512	 79373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13513	 13515	 0.004419	 0.017192	 0.00459	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13513	 79374	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13513	 79374	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79374	 13514	 0.078884	 0.062428	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13515	 13516	 0.004479	 0.018227	 0.00444	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13516	 13518	 0.004213	 0.017142	 0.00418	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79019	 13517	 0.054083	 0.15513	 0.00239	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13517	 79375	 0.008942	 0.057694	 0.00184	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13518	 13519	 0.001817	 0.007395	 0.0018	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13519	 79375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13519	 79375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13520	 13577	 0.009709	 0.025659	 0.00601	 132.0	 132.0	 132.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13520	 13577	 0.009709	 0.025659	 0.00601	 132.0	 132.0	 132.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13521	 13522	 0.05151	 0.11959	 0.00178	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13521	 13575	 0.049207	 0.084784	 0.00135	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77738	 13521	 0.028991	 0.080199	 0.00186	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13521	 79376	 0.052122	 0.15991	 0.00433	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13522	 79376	 0.019642	 0.09585	 0.00165	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13523	 13524	 0.005682	 0.026068	 0.00668	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13523	 79376	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13523	 79376	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13525	 13527	 0.041205	 0.095666	 0.00142	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13526	 79377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13526	 79377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79377	 13527	 0.00893	 0.011737	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78669	 13528	 0.059304	 0.042871	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78669	 13529	 0.050754	 0.10049	 0.00148	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78679	 13530	 0.042571	 0.070712	 0.0015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78668	 13531	 0.033035	 0.059007	 0.00087	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13533	 13534	 0.007957	 0.025951	 0.00689	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13535	 13536	 0.004555	 0.020898	 0.00535	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13536	 13538	 0.001092	 0.004916	 0.00131	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13536	 79378	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13536	 79378	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77739	 13537	 0.037923	 0.13279	 0.00368	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13537	 79379	 0.006426	 0.041828	 0.00085	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13538	 13539	 0.001193	 0.005315	 0.00144	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13539	 79379	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13539	 79379	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77761	 13540	 0.020846	 0.081099	 0.00135	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13540	 79380	 0.035169	 0.13531	 0.00231	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13542	 79380	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13542	 79380	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13543	 13545	 0.006044	 0.024197	 0.0061	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13543	 79381	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13543	 79381	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77760	 13544	 0.048447	 0.035644	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13545	 13548	 0.008489	 0.034545	 0.00842	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79378	 13546	 0.027885	 0.097571	 0.00202	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78901	 13547	 0.20931	 0.14829	 0.00234	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13549	 13550	 0.001766	 0.029536	 0.01674	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13549	 79382	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13549	 79382	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13549	 79440	 0.002938	 0.038751	 0.02373	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13552	 79384	 0.17672	 0.13987	 0.00176	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13553	 79383	 0.20863	 0.16513	 0.00208	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13554	 79383	 0.27604	 0.21851	 0.00275	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13555	 13561	 0.086286	 0.19826	 0.00301	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13555	 13671	 0.053988	 0.12785	 0.00234	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13555	 79383	 0.039232	 0.11809	 0.00231	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13556	 13557	 0.009774	 0.03353	 0.00803	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13556	 79383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13556	 79383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13557	 79384	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13557	 79384	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13558	 13559	 0.009325	 0.039471	 0.00888	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13559	 13786	 0.008647	 0.036597	 0.00824	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79383	 13560	 0.053225	 0.17566	 0.00285	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13561	 13672	 0.012964	 0.04539	 0.00126	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77721	 13562	 0.11084	 0.22687	 0.00558	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13563	 79385	 0.057651	 0.10298	 0.00152	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13564	 13565	 0.010923	 0.044453	 0.01083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13565	 13569	 0.006913	 0.034735	 0.00904	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13565	 79385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13565	 79385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77721	 13566	 0.17348	 0.1373	 0.00173	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77721	 13567	 0.075689	 0.20011	 0.00363	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13567	 79386	 0.017142	 0.11159	 0.00227	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13568	 13569	 0.005075	 0.023283	 0.00596	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13568	 79386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13568	 79386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13569	 79387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13569	 79387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79387	 13570	 0.023267	 0.13074	 0.00242	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79386	 13571	 0.018936	 0.12999	 0.00237	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79097	 13572	 0.016127	 0.091676	 0.00166	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13572	 79389	 0.015802	 0.097151	 0.00175	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13573	 13574	 0.004968	 0.025131	 0.007	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13574	 13576	 0.004996	 0.023302	 0.00577	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13574	 79388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13574	 79388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79388	 13575	 0.023637	 0.060763	 0.00094	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13576	 13580	 0.002814	 0.011061	 0.00289	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13576	 79389	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13576	 79389	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13577	 13578	 0.004055	 0.010528	 0.00256	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13577	 13578	 0.004055	 0.010528	 0.00255	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13578	 13580	 0.001848	 0.0074	 0.00186	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13578	 79390	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13578	 79390	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79097	 13579	 0.008018	 0.040797	 0.00092	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79390	 13581	 0.012307	 0.016016	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78755	 13582	 0.094825	 0.067171	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13583	 79392	 0.055993	 0.10064	 0.00181	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13584	 13585	 0.003485	 0.014389	 0.0034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13585	 13588	 0.003349	 0.010923	 0.0029	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13585	 79391	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13585	 79391	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13586	 13587	 0.019504	 0.015288	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79391	 13587	 0.016516	 0.0327	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13588	 79392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13588	 79392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13589	 13590	 0.001219	 0.005488	 0.00146	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13589	 79393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13589	 79393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13590	 13595	 0.003076	 0.014112	 0.00362	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13590	 79394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13590	 79394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79394	 13591	 0.021222	 0.015613	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79393	 13592	 0.00372	 0.018929	 0.00043	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13592	 79395	 0.018513	 0.081567	 0.00142	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13593	 13594	 0.005687	 0.023142	 0.00564	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13593	 79395	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13593	 79395	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13594	 79396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13594	 79396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13595	 79397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13595	 79397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77723	 13596	 0.13066	 0.094456	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77723	 13597	 0.042067	 0.070866	 0.00101	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77762	 13598	 0.049231	 0.06407	 0.0009	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13599	 79399	 0.13525	 0.10704	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13600	 13602	 0.00712	 0.037045	 0.01091	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13601	 13610	 0.034054	 0.12166	 0.00242	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13601	 79398	 0.13071	 0.1718	 0.00235	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13602	 13606	 0.012093	 0.043791	 0.0094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13602	 79398	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13602	 79398	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13603	 13605	 0.0056	 0.015034	 0.00341	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13603	 79399	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13603	 79399	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13604	 79401	 0.032527	 0.025742	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13605	 79400	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13605	 79400	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13606	 79401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13606	 79401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77762	 13607	 0.093223	 0.07063	 0.00097	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77737	 13608	 0.042749	 0.11826	 0.00275	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78913	 13608	 0.05111	 0.15681	 0.00425	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77762	 13609	 0.065702	 0.18846	 0.0029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78912	 13609	 0.22609	 0.2083	 0.00334	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78913	 13609	 0.072526	 0.27908	 0.00477	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78913	 13610	 0.035452	 0.15621	 0.00271	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13611	 13638	 0.000987	 0.003325	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13611	 13640	 0.001267	 0.003258	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13612	 13614	 0.020722	 0.080614	 0.00135	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13612	 13614	 0.020722	 0.080614	 0.00135	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13612	 19947	 0.040088	 0.11376	 0.00179	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13612	 19949	 0.058495	 0.16778	 0.00258	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13612	 20017	 0.026206	 0.074365	 0.00117	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13612	 20020	 0.18794	 0.14734	 0.00189	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13612	 20021	 0.23293	 0.15084	 0.00287	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13612	 81719	 0.050254	 0.11987	 0.00269	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13612	 81736	 0.027645	 0.063223	 0.00154	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13612	 81737	 0.17124	 0.25977	 0.00372	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13613	 13614	 0.028742	 0.022746	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13614	 13618	 0.024357	 0.085226	 0.00177	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13614	 13618	 0.024357	 0.085226	 0.00177	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78474	 13614	 0.019165	 0.10745	 0.00296	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13616	 79402	 0.014795	 0.038343	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13617	 13634	 0.018277	 0.11237	 0.00203	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13617	 19950	 0.012879	 0.095128	 0.00198	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13618	 13624	 0.029857	 0.069317	 0.00103	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13618	 79402	 0.009627	 0.058284	 0.00182	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13619	 13669	 0.044979	 0.11891	 0.00216	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13619	 20266	 0.035287	 0.13728	 0.00229	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13619	 20266	 0.035287	 0.13728	 0.00229	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13619	 79405	 0.0111	 0.07988	 0.00262	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13620	 13636	 0.02652	 0.06157	 0.00092	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13620	 13645	 0.035214	 0.090522	 0.0014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13620	 13669	 0.034721	 0.09203	 0.00233	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13621	 13667	 0.004387	 0.012706	 0.00306	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13621	 79402	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13621	 79402	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13622	 13631	 0.020074	 0.039341	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79402	 13622	 0.024293	 0.068938	 0.00108	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13623	 13624	 0.006915	 0.025327	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13623	 13625	 0.02237	 0.017535	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77691	 13623	 0.037123	 0.20319	 0.00397	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13623	 79403	 0.010278	 0.045797	 0.00078	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13623	 79408	 0.008365	 0.047001	 0.00087	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13624	 13634	 0.014613	 0.05685	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13626	 13627	 0.000932	 0.003792	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13626	 13667	 0.002915	 0.008442	 0.00204	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13626	 79403	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13626	 79403	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13627	 13628	 0.001054	 0.004217	 0.00142	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13628	 13629	 0.001396	 0.010513	 0.00292	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13628	 13650	 0.005151	 0.033181	 0.0087	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 79404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13629	 79404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13629	 79409	 0.001256	 0.015485	 0.005	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13630	 13631	 0.008081	 0.026668	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13631	 13632	 0.004287	 0.024087	 0.00045	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79404	 13632	 0.00794	 0.049857	 0.00109	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13633	 13650	 0.003166	 0.012675	 0.00319	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13634	 79405	 0.017089	 0.041828	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13635	 13640	 0.002917	 0.007333	 0.0019	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13635	 79405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13635	 79405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79405	 13636	 0.028732	 0.042603	 0.00064	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13637	 13638	 0.000623	 0.002449	 0.00064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13637	 13643	 0.002578	 0.007721	 0.00174	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13637	 79406	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13637	 79406	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13638	 79409	 0.001489	 0.010886	 0.00321	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13639	 13641	 0.004556	 0.01154	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79406	 13639	 0.006276	 0.012425	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13639	 79408	 0.010848	 0.027885	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13640	 79407	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13640	 79407	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13641	 13642	 0.01399	 0.011072	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79405	 13641	 0.00696	 0.028444	 0.00058	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79407	 13641	 0.006416	 0.012703	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13643	 79408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13643	 79408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13644	 13647	 0.000425	 0.006745	 0.06886	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13644	 20536	 0.001274	 0.012859	 0.21177	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13644	 20536	 0.001274	 0.012859	 0.21177	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13644	 79409	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13644	 79409	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13646	 13658	 0.067136	 0.10476	 0.00175	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13648	 13649	 0.026565	 0.048657	 0.00084	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13648	 13668	 0.02268	 0.051446	 0.00103	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13649	 13658	 0.058257	 0.058841	 0.00078	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13650	 79410	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13650	 79410	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78496	 13651	 0.042354	 0.033519	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13652	 13655	 0.00184	 0.00858	 0.00213	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13653	 13654	 0.024142	 0.017101	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13653	 79411	 0.009651	 0.019109	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13655	 79411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13655	 79411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13655	 79412	 0.0037	 0.015275	 0.00361	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78516	 13656	 0.001553	 0.009837	 0.0206	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13656	 79412	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79413	 13656	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13657	 13753	 0.011574	 0.015212	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79413	 13657	 0.004281	 0.014281	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13658	 79414	 0.017965	 0.045687	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13659	 79414	 0.014058	 0.009443	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13660	 13661	 0.000911	 0.002541	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13660	 79414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13660	 79414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13661	 13662	 0.003394	 0.00897	 0.0021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13662	 13664	 0.003776	 0.011132	 0.00259	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13662	 79415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13662	 79415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79415	 13663	 0.026312	 0.020823	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13664	 13665	 0.00226	 0.008184	 0.00176	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78906	 13666	 0.10888	 0.077131	 0.00122	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78906	 13668	 0.016715	 0.061804	 0.00114	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13670	 13671	 0.053145	 0.13662	 0.00211	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13670	 13673	 0.09811	 0.19427	 0.00285	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13672	 79416	 0.035833	 0.13786	 0.00235	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13673	 13674	 0.1692	 0.11367	 0.00201	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13673	 79416	 0.1647	 0.12911	 0.00166	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13675	 13676	 0.001742	 0.01707	 0.00535	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78956	 13676	 0.005347	 0.051346	 0.01494	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13676	 79416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13676	 79416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13677	 13678	 0.004874	 0.024032	 0.0065	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13677	 79417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13677	 79417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13678	 13679	 0.003982	 0.02026	 0.00735	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78956	 13678	 0.001776	 0.022346	 0.00692	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13679	 13680	 0.004045	 0.023689	 0.00645	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13680	 79418	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13680	 79418	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13681	 13682	 0.037097	 0.075917	 0.00187	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78960	 13681	 0.01522	 0.11724	 0.00224	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79418	 13681	 0.02787	 0.097521	 0.00202	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79418	 13681	 0.02787	 0.097521	 0.00202	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79115	 13683	 0.012345	 0.049403	 0.00104	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13684	 13686	 0.000579	 0.002254	 0.0006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13684	 13690	 0.001171	 0.004097	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13685	 79419	 0.018516	 0.013385	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13685	 79420	 0.007747	 0.006989	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13686	 13687	 0.000684	 0.002489	 0.00076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13688	 13689	 0.001198	 0.003215	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13688	 79419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13688	 79419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13689	 13690	 0.000652	 0.002759	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13689	 79420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13689	 79420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13690	 79421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13690	 79421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13691	 13692	 0.019529	 0.015455	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79421	 13691	 0.013015	 0.014315	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79420	 13692	 0.024403	 0.019312	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13693	 13694	 0.014468	 0.024129	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13693	 13695	 0.003296	 0.018733	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79419	 13693	 0.003083	 0.018251	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79420	 13694	 0.017015	 0.04374	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13694	 79425	 0.014583	 0.041383	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78443	 13695	 0.007144	 0.019789	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13696	 79422	 0.012202	 0.040703	 0.00065	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13696	 79424	 0.037368	 0.059647	 0.00137	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13696	 79425	 0.010465	 0.057627	 0.0013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13697	 79422	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13697	 79422	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13698	 79423	 0.001096	 0.002941	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13699	 79423	 0.000123	 0.009866	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79424	 13700	 0.012724	 0.009362	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77704	 13701	 0.001797	 0.019386	 0.00555	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79423	 13701	 0.00263	 0.026799	 0.00691	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13701	 79425	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13701	 79425	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13702	 13703	 0.008796	 0.030047	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13702	 13706	 0.027589	 0.064052	 0.00095	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79425	 13702	 0.012143	 0.059255	 0.00102	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13703	 13704	 0.026662	 0.070668	 0.00179	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13705	 13707	 0.004892	 0.019584	 0.00493	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13705	 13731	 0.004317	 0.019806	 0.00507	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77681	 13705	 0.018763	 0.07514	 0.01894	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13706	 13709	 0.013184	 0.03389	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13706	 79426	 0.057919	 0.058501	 0.00077	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77704	 13707	 0.006523	 0.050745	 0.01318	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13707	 79426	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13707	 79426	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78506	 13709	 0.017141	 0.057182	 0.00091	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13710	 13714	 0.016383	 0.042115	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13711	 13723	 0.012075	 0.028593	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78504	 13711	 0.019515	 0.038637	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13712	 13714	 0.024916	 0.039771	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78504	 13712	 0.01912	 0.063782	 0.00101	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13713	 13714	 0.030156	 0.039245	 0.00055	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13713	 79427	 0.035978	 0.029613	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79426	 13714	 0.020501	 0.0527	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13715	 13716	 0.00797	 0.02445	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79426	 13715	 0.075839	 0.053721	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13715	 79428	 0.01972	 0.065784	 0.00104	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13716	 13717	 0.002233	 0.00818	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13716	 13730	 0.005353	 0.027077	 0.00047	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13717	 79427	 0.001727	 0.010494	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13718	 13744	 0.004078	 0.019675	 0.00035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13718	 79427	 0.002577	 0.015843	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13719	 13745	 0.00352	 0.012269	 0.00284	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13719	 79427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13719	 79427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13720	 13722	 0.001204	 0.005423	 0.00144	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13720	 79428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13720	 79428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13721	 13722	 0.000541	 0.002434	 0.00065	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13721	 13727	 0.001812	 0.00659	 0.00202	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13721	 79429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13721	 79429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13723	 13724	 0.010925	 0.031335	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13724	 79430	 0.01364	 0.025361	 0.00059	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13725	 13726	 0.001042	 0.004643	 0.00126	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13725	 79430	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13725	 79430	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13726	 13727	 0.001641	 0.006832	 0.00213	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13727	 79431	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13727	 79431	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79429	 13728	 0.002809	 0.015806	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79430	 13728	 0.006491	 0.039909	 0.00072	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79431	 13728	 0.010645	 0.019207	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79427	 13729	 0.003849	 0.017149	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79428	 13729	 0.004896	 0.029756	 0.00055	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13730	 13734	 0.011625	 0.026989	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13730	 79432	 0.019304	 0.050031	 0.00095	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13731	 13773	 0.0047	 0.029202	 0.00824	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13731	 79432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13731	 79432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13732	 13733	 0.005774	 0.01926	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79432	 13732	 0.009055	 0.023027	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13733	 13734	 0.003495	 0.015485	 0.00046	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13733	 13735	 0.019069	 0.013785	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13733	 13736	 0.00536	 0.020854	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13733	 13743	 0.021468	 0.042504	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13734	 13743	 0.016028	 0.027001	 0.00038	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13734	 13744	 0.006771	 0.020772	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13735	 13737	 0.005794	 0.010454	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13736	 13740	 0.005773	 0.019258	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13737	 13738	 0.00607	 0.012421	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13738	 13739	 0.022133	 0.029089	 0.0004	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13738	 13743	 0.006753	 0.01382	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13739	 13741	 0.012558	 0.034307	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13739	 13768	 0.024044	 0.068963	 0.00106	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13740	 13771	 0.028167	 0.066701	 0.00122	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13741	 79433	 0.008963	 0.032018	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13742	 79433	 0.063992	 0.050643	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13743	 79433	 0.018181	 0.064949	 0.00129	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13745	 13757	 0.007213	 0.029351	 0.00715	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13746	 13762	 0.006258	 0.016219	 0.00491	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13746	 79433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13746	 79433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13747	 79434	 0.071351	 0.055929	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78500	 13748	 0.012083	 0.043163	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79430	 13748	 0.015235	 0.050822	 0.00081	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13749	 13750	 0.023264	 0.01841	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13750	 13751	 0.011895	 0.015634	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79411	 13750	 0.012823	 0.037707	 0.00077	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79413	 13750	 0.016692	 0.031037	 0.00073	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79414	 13750	 0.00393	 0.018781	 0.00041	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13751	 13752	 0.038458	 0.027242	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13754	 13755	 0.073503	 0.05817	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13755	 13756	 0.00559	 0.030781	 0.00069	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79413	 13755	 0.008549	 0.051957	 0.00096	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79430	 13756	 0.072192	 0.1177	 0.0018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13756	 79434	 0.007801	 0.047958	 0.00086	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79412	 13757	 0.007061	 0.031793	 0.00846	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13757	 79434	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13757	 79434	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79434	 13758	 0.088039	 0.069674	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13759	 13765	 0.009124	 0.024115	 0.00564	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13759	 79435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13759	 79435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13760	 13761	 0.009401	 0.018613	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79435	 13760	 0.002517	 0.007723	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13761	 13763	 0.086934	 0.061581	 0.00097	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13762	 13765	 0.005021	 0.017223	 0.00413	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77709	 13762	 0.012213	 0.11114	 0.02808	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13762	 79436	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13762	 79436	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13763	 13764	 0.016095	 0.012194	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13763	 79437	 0.022753	 0.024783	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13765	 79437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13765	 79437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79437	 13766	 0.091011	 0.072026	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79437	 13767	 0.1002	 0.078545	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13768	 13771	 0.013764	 0.053545	 0.00089	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79437	 13768	 0.024093	 0.11757	 0.00203	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13769	 13771	 0.029664	 0.075441	 0.00119	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13769	 13783	 0.076312	 0.1511	 0.00222	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13769	 79438	 0.026099	 0.060592	 0.0009	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13770	 13772	 0.013139	 0.034823	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79432	 13770	 0.021359	 0.067821	 0.00119	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13771	 79439	 0.067716	 0.12403	 0.00214	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13772	 79438	 0.008996	 0.020885	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13773	 13775	 0.001948	 0.006059	 0.00126	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13773	 79438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13773	 79438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79438	 13774	 0.013096	 0.010364	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13775	 13778	 0.005172	 0.013669	 0.0032	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13776	 13778	 0.007943	 0.020991	 0.00491	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77681	 13776	 0.01852	 0.047613	 0.01179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13776	 79439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13776	 79439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13777	 13781	 0.051728	 0.11734	 0.00234	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79439	 13777	 0.018023	 0.080313	 0.00136	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13779	 13781	 0.16818	 0.12159	 0.00184	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77672	 13779	 0.095423	 0.072298	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13780	 13781	 0.097914	 0.063392	 0.00121	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13780	 14470	 0.92587	 0.73487	 0.00925	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77672	 13780	 0.36086	 0.24254	 0.00428	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13781	 13782	 0.05559	 0.035989	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77672	 13781	 0.26354	 0.2022	 0.00271	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77672	 13782	 0.31279	 0.22619	 0.00343	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77672	 13783	 0.50428	 0.38716	 0.0052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78605	 13784	 0.007906	 0.068994	 0.01895	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78604	 13785	 0.003011	 0.032874	 0.06378	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78604	 13785	 0.003011	 0.032874	 0.06378	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13785	 79440	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13785	 79440	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13786	 79441	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13786	 79441	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13787	 13788	 0.0039	 0.022844	 0.00622	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13787	 79442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13787	 79442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13789	 13790	 0.009164	 0.084302	 0.00167	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77736	 13789	 0.029206	 0.097431	 0.00154	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79442	 13789	 0.015516	 0.070437	 0.00153	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13791	 13792	 0.008291	 0.006499	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13791	 13800	 0.002358	 0.007865	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77714	 13791	 0.12304	 0.41066	 0.00651	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13792	 79443	 0.002773	 0.007052	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13792	 79444	 0.007051	 0.011877	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13793	 13795	 0.000344	 0.001792	 0.00047	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13793	 13812	 0.000233	 0.001406	 0.00036	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13793	 79443	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13793	 79443	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13794	 13795	 0.000183	 0.001596	 0.00044	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13794	 13810	 0.000574	 0.004519	 0.00132	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13795	 13798	 0.000803	 0.004615	 0.00131	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13795	 13808	 0.002249	 0.008183	 0.0025	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13795	 13859	 0.006745	 0.018808	 0.00395	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13795	 79444	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13795	 79444	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13796	 13797	 0.004318	 0.009794	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79444	 13796	 0.005199	 0.008522	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13797	 13800	 0.00821	 0.010008	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13797	 79445	 0.002382	 0.007944	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13798	 13858	 0.001308	 0.009801	 0.00239	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13798	 79445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13798	 79445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13799	 13800	 0.008919	 0.007058	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13800	 13801	 0.003732	 0.009593	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13800	 13806	 0.004579	 0.011771	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13801	 13802	 0.006938	 0.005439	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13801	 79446	 0.003262	 0.012691	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13803	 13804	 0.001557	 0.004464	 0.0011	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13803	 13812	 0.002278	 0.008248	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13803	 79446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13803	 79446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13804	 13840	 0.001204	 0.006483	 0.00178	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13804	 79447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13804	 79447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13804	 79454	 0.003437	 0.012445	 0.00267	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13805	 13806	 0.001464	 0.005232	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79447	 13805	 0.00337	 0.016444	 0.00028	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13807	 13808	 0.000793	 0.00746	 0.00226	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13807	 13868	 0.002124	 0.018218	 0.00518	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13807	 79448	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13807	 79448	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13808	 79454	 0.000829	 0.008099	 0.00227	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13809	 13865	 0.002397	 0.006724	 0.00173	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13810	 13811	 0.000972	 0.004376	 0.00116	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13810	 79449	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13810	 79449	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13811	 13865	 0.002831	 0.011334	 0.00286	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79444	 13813	 0.00581	 0.015399	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79449	 13813	 0.022233	 0.029221	 0.0004	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13814	 13843	 0.001408	 0.012074	 0.00344	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13814	 13858	 0.000842	 0.006345	 0.00176	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79445	 13815	 0.004553	 0.011579	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13815	 79461	 0.023573	 0.0462	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13816	 79450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13816	 79450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79450	 13817	 0.008188	 0.039508	 0.0007	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13817	 79453	 0.0126	 0.049018	 0.00082	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13818	 13832	 0.004922	 0.019705	 0.00496	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77668	 13818	 0.004827	 0.029997	 0.00847	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78764	 13818	 0.004871	 0.024471	 0.00637	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13819	 13833	 0.022908	 0.065007	 0.00102	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78760	 13819	 0.015286	 0.05652	 0.00105	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13820	 13823	 0.03221	 0.063773	 0.00094	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77749	 13820	 0.06757	 0.063366	 0.00098	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13821	 13827	 0.002706	 0.019468	 0.00516	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13822	 13823	 0.009988	 0.060701	 0.00112	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78407	 13822	 0.007818	 0.053048	 0.00099	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78770	 13823	 0.10736	 0.10844	 0.00144	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13824	 13826	 0.001066	 0.010448	 0.00327	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13825	 13826	 0.000916	 0.008947	 0.00251	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13825	 13843	 0.000685	 0.011419	 0.00347	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13827	 13828	 0.001432	 0.008385	 0.00228	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13828	 13829	 0.000913	 0.00535	 0.00146	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13829	 13840	 0.001354	 0.008724	 0.00229	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13829	 79451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13829	 79451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13830	 13833	 0.027572	 0.067489	 0.00115	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13830	 79455	 0.1122	 0.088796	 0.00112	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13831	 13832	 0.00273	 0.012526	 0.00321	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13831	 79452	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13831	 79452	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77668	 13832	 0.002577	 0.012574	 0.00347	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13832	 79453	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13832	 79453	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79453	 13833	 0.030937	 0.052117	 0.00074	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13834	 79454	 0.0028	 0.01156	 0.00273	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79452	 13835	 0.062807	 0.062823	 0.00085	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13835	 79455	 0.025129	 0.064597	 0.001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77706	 13836	 0.00072	 0.012676	 0.2106	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78766	 13836	 0.001158	 0.013533	 0.12876	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13836	 79454	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79447	 13837	 0.025463	 0.019959	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79455	 13837	 0.011955	 0.030732	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79455	 13838	 0.019196	 0.036279	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79446	 13839	 0.007984	 0.013087	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79451	 13841	 0.007267	 0.018834	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13841	 79456	 0.004304	 0.021001	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13842	 13843	 0.001738	 0.006323	 0.00194	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13842	 79456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13842	 79456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13843	 79457	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13843	 79457	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13844	 13848	 0.002281	 0.009132	 0.0023	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13845	 13856	 0.030174	 0.069008	 0.00168	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77728	 13845	 0.014552	 0.037408	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13846	 13856	 0.037686	 0.12437	 0.00201	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79456	 13846	 0.029257	 0.067925	 0.00101	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79457	 13846	 0.042117	 0.042127	 0.00057	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13847	 79458	 0.030573	 0.023964	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13847	 79459	 0.045098	 0.03569	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13848	 13851	 0.000466	 0.005965	 0.00178	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13848	 13857	 0.006396	 0.050399	 0.01474	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13849	 13851	 0.00094	 0.003696	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13849	 13853	 0.001766	 0.006942	 0.00182	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13849	 14837	 0.013274	 0.036142	 0.00796	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13849	 79458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13849	 79458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79458	 13850	 0.006723	 0.010299	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13850	 79459	 0.009093	 0.005887	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13851	 13853	 0.000423	 0.003126	 0.0009	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77707	 13851	 0.00436	 0.042598	 0.01196	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13851	 79459	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13851	 79459	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78407	 13852	 0.14662	 0.26461	 0.00383	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79458	 13852	 0.016348	 0.029943	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79459	 13852	 0.007246	 0.016436	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13854	 13855	 0.01578	 0.057797	 0.00146	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13854	 13856	 0.01152	 0.061382	 0.00108	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13854	 79934	 0.023075	 0.076976	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13855	 14826	 0.03163	 0.087498	 0.00203	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79458	 13855	 0.025985	 0.060328	 0.0009	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13856	 13874	 0.021242	 0.0701	 0.00114	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13857	 13861	 0.002958	 0.016415	 0.00499	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13857	 79460	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13857	 79460	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13859	 13862	 0.00369	 0.009486	 0.00235	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13859	 79461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13859	 79461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79461	 13860	 0.008392	 0.025744	 0.0007	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13861	 13862	 0.000913	 0.004758	 0.00125	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13862	 13863	 0.002117	 0.007261	 0.00174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13863	 79462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13863	 79462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13864	 13872	 0.020688	 0.063465	 0.00172	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79462	 13864	 0.005089	 0.027333	 0.00065	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13865	 13869	 0.001456	 0.012248	 0.00363	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13865	 79463	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13865	 79463	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79462	 13866	 0.010462	 0.032127	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79463	 13866	 0.029317	 0.03574	 0.00057	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78972	 13867	 0.039524	 0.072393	 0.00125	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79448	 13867	 0.022543	 0.057331	 0.00091	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13867	 79464	 0.015128	 0.042927	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13868	 79464	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13868	 79464	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13869	 13870	 0.001031	 0.008997	 0.00247	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13869	 79465	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13869	 79465	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13871	 13878	 0.030216	 0.077675	 0.0012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79460	 13871	 0.029806	 0.068167	 0.00166	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13872	 79466	 0.026467	 0.10183	 0.00174	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77713	 13873	 0.004862	 0.019466	 0.0049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13873	 79466	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13873	 79466	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13874	 13875	 0.016958	 0.040155	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79460	 13874	 0.037397	 0.085917	 0.00131	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13875	 13876	 0.011999	 0.030845	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13877	 13880	 0.033436	 0.11034	 0.00179	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13878	 13880	 0.032881	 0.076326	 0.00145	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77714	 13879	 0.026051	 0.059579	 0.00145	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13879	 80016	 0.050818	 0.16954	 0.00269	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13880	 15032	 0.051334	 0.13197	 0.00204	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79466	 13880	 0.015744	 0.088463	 0.00164	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13881	 13884	 0.022867	 0.17813	 0.04637	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13881	 13886	 0.001422	 0.007408	 0.00194	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13881	 13887	 0.001732	 0.008976	 0.00219	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13881	 13889	 0.033686	 0.1547	 0.03969	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13881	 13890	 0.03038	 0.15764	 0.03855	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13881	 14065	 0.000906	 0.006405	 0.00176	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13881	 79467	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13881	 79467	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13881	 79469	 0.031459	 0.1501	 0.04355	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13881	 79472	 0.02162	 0.15308	 0.04207	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13882	 14114	 2.1e-05	 0.000453	 0.04748	 3627.0	 3808.3	 3989.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13882	 79468	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13882	 79468	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79469	 13882	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79469	 13882	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13883	 14210	 0.001961	 0.012167	 0.00295	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13883	 14213	 0.000765	 0.003616	 0.00116	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13883	 14214	 0.009667	 0.038705	 0.00975	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13883	 79470	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13883	 79470	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13884	 14233	 0.010107	 0.083897	 0.02208	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13884	 14237	 0.007048	 0.051474	 0.01323	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13884	 14240	 0.006242	 0.016206	 0.00393	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13884	 14241	 0.001721	 0.01476	 0.0042	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13884	 14244	 0.007027	 0.024106	 0.00578	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13884	 14250	 0.021157	 0.05484	 0.01659	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13884	 14264	 0.008067	 0.021319	 0.00499	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13884	 15619	 0.014174	 0.085101	 0.02578	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13884	 79471	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13884	 79471	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13885	 14202	 0.000387	 0.004561	 0.00842	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79468	 13885	 2.4e-05	 0.000401	 0.00146	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13885	 79472	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13885	 79472	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13886	 14070	 0.007585	 0.021151	 0.00444	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13886	 14073	 0.000305	 0.000917	 0.00029	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13886	 79473	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13886	 79473	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13887	 14073	 0.000301	 0.001244	 0.00029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13887	 14074	 0.001048	 0.003982	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13887	 14076	 0.002795	 0.01119	 0.00282	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13887	 79474	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13887	 79474	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13888	 14062	 0.000731	 0.004202	 0.00119	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13888	 79475	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13888	 79475	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13889	 14106	 8.6e-05	 0.001299	 0.00076	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13889	 14115	 9.5e-05	 0.001046	 0.00093	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13889	 14222	 0.000317	 0.003761	 0.00131	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13890	 14230	 0.002792	 0.011529	 0.00273	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13890	 14231	 0.001213	 0.005566	 0.00143	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13891	 14141	 0.007065	 0.012424	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13891	 14145	 0.012882	 0.025506	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13891	 79700	 0.010079	 0.015726	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13891	 79701	 0.006393	 0.014842	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13892	 13893	 0.000468	 0.012744	 0.8811	 2893.0	 3037.6	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13892	 14482	 0.000612	 0.00764	 0.52396	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13892	 14913	 0.000305	 0.005655	 0.37353	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13892	 79476	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13892	 79476	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79477	 13892	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79477	 13892	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13893	 14502	 0.000178	 0.002791	 0.27124	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13893	 15776	 2.2e-05	 0.000586	 0.06224	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13893	 15777	 4.1e-05	 0.001084	 0.09055	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13893	 79478	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13893	 79478	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13894	 13895	 0.000173	 0.004794	 0.35935	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13894	 14454	 0.000393	 0.006748	 0.54654	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13894	 14482	 0.0002	 0.005739	 0.39942	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13894	 79479	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13894	 79479	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13895	 14903	 0.000168	 0.003005	 0.21332	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13895	 79482	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13895	 79482	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13896	 14467	 5.1e-05	 0.001333	 0.10981	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13896	 20201	 0.0001	 0.001702	 0.13247	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13896	 20242	 0.000236	 0.006219	 0.51275	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13896	 79485	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13896	 79485	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79486	 13896	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79486	 13896	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13897	 14958	 0.000127	 0.001512	 0.11341	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13897	 15120	 0.000101	 0.00126	 0.0863	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13897	 15144	 0.000116	 0.003219	 0.24123	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13897	 18810	 4.2e-05	 0.00121	 0.08414	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13897	 79487	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13897	 79487	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13898	 14870	 0.002006	 0.024375	 0.07897	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13898	 15001	 0.000213	 0.003168	 0.01174	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13898	 79490	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13898	 79490	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13899	 14746	 0.000386	 0.004065	 0.00849	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13899	 14746	 0.000386	 0.004065	 0.00849	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13899	 79491	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13899	 79491	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13899	 79910	 0.000142	 0.002476	 0.00831	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13900	 14878	 7e-05	 0.001163	 0.07595	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13900	 15000	 0.000304	 0.005187	 0.40389	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13900	 79492	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13900	 79492	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13901	 14910	 0.005236	 0.022161	 0.00499	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13901	 14912	 0.008615	 0.033859	 0.00886	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13901	 15631	 0.016827	 0.043687	 0.0106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13901	 79494	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13901	 79494	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13902	 14677	 0.000851	 0.008169	 0.00238	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13902	 14684	 0.001438	 0.004844	 0.0012	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13902	 14787	 0.000599	 0.004513	 0.00125	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13902	 79495	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13902	 79495	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13903	 14494	 0.001416	 0.013706	 0.04848	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79478	 13903	 5.4e-05	 0.00072	 0.00254	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13903	 79496	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13903	 79496	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79497	 13903	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79497	 13903	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13903	 79891	 0.000572	 0.005782	 0.01312	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13903	 79891	 0.000572	 0.005782	 0.01312	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13904	 14532	 0.007053	 0.038845	 0.01403	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13904	 14701	 0.002185	 0.008499	 0.00227	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13904	 14704	 0.001298	 0.005048	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13904	 14793	 0.00325	 0.008848	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13904	 79498	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13904	 79498	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13904	 79892	 0.000167	 0.001699	 0.00044	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13905	 15754	 0.000587	 0.002348	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13905	 15754	 0.000587	 0.002348	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13905	 15756	 0.000693	 0.003181	 0.00081	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13905	 15758	 0.000317	 0.001247	 0.00033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13905	 15759	 0.000768	 0.001993	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13905	 79499	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13905	 79499	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13906	 15759	 0.000577	 0.002443	 0.00055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13906	 15760	 0.000594	 0.002416	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13906	 15761	 0.000712	 0.002482	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13906	 79500	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13906	 79500	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13907	 14895	 2.5e-05	 0.000342	 0.02341	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13907	 15374	 0.000129	 0.002206	 0.17175	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13907	 79501	 0.000229	 0.017175	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13907	 79501	 0.000229	 0.017175	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13908	 14917	 0.014991	 0.051431	 0.01232	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13908	 15557	 0.005799	 0.030824	 0.00715	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79477	 13908	 0.00293	 0.015517	 0.00393	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13908	 79502	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13908	 79502	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13909	 79503	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13909	 79503	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13909	 80002	 0.001098	 0.012339	 0.02258	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13909	 81805	 0.000792	 0.009254	 0.03239	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13910	 18829	 0.002784	 0.019525	 0.03325	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79487	 13910	 0.000177	 0.001234	 0.00212	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13910	 79504	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13910	 79504	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13911	 15754	 0.001247	 0.003477	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13911	 79505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13911	 79505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13912	 15575	 0.001048	 0.006139	 0.00167	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13912	 15576	 0.000625	 0.003781	 0.00096	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13913	 15599	 9.1e-05	 0.001088	 0.08159	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13913	 15603	 2.9e-05	 0.000347	 0.02637	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13913	 79506	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13913	 79506	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13914	 15573	 0.003405	 0.012944	 0.00362	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13914	 15575	 0.000838	 0.002732	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13914	 79508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13914	 79508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13915	 14477	 0.002759	 0.014665	 0.0034	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13915	 79509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13915	 79509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13915	 81804	 0.00722	 0.029381	 0.00716	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13916	 79510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13916	 79510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13916	 80195	 0.000956	 0.003829	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13917	 15286	 0.000565	 0.003133	 0.00095	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13917	 15290	 0.001332	 0.005234	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13917	 80122	 0.000217	 0.000791	 0.00024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13918	 15785	 1.9e-05	 0.000251	 0.01602	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13918	 15792	 4e-05	 0.000591	 0.03801	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13918	 79511	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13918	 79511	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13919	 14981	 0.000248	 0.003686	 0.23711	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13919	 20282	 8.7e-05	 0.001576	 0.15403	 2840.0	 2982.0	 3124.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13919	 79513	 0.000281	 0.02246	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13919	 79513	 0.000281	 0.02246	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13920	 16507	 6.3e-05	 0.001015	 0.07126	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13920	 16739	 0.000135	 0.003866	 0.26899	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13920	 17442	 0.000793	 0.014727	 0.97575	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13920	 17567	 0.000179	 0.002319	 0.14801	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13920	 79514	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13920	 79514	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79515	 13920	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79515	 13920	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13921	 13933	 0.000104	 0.00124	 0.09303	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13921	 16151	 0.000339	 0.005712	 0.55584	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13921	 79516	 0.000111	 0.008848	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13921	 79516	 0.000111	 0.008848	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79517	 13921	 0.000216	 0.017299	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79517	 13921	 0.000216	 0.017299	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13922	 16244	 0.000779	 0.02068	 1.7188	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13922	 17310	 0.000137	 0.003617	 0.29806	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13922	 34575	 0.000698	 0.017224	 1.7548	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13922	 34575	 0.000698	 0.017224	 1.7548	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13922	 79518	 0.000281	 0.02246	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13922	 79518	 0.000281	 0.02246	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79519	 13922	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79519	 13922	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13923	 16303	 0.000449	 0.008331	 0.55067	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13923	 17835	 6.5e-05	 0.001713	 0.14114	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13923	 79520	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13923	 79520	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13924	 16642	 0.000416	 0.007443	 0.52878	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13924	 17442	 0.000175	 0.002188	 0.14989	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13924	 18660	 0.000123	 0.001575	 0.10304	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13924	 79523	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13924	 79523	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13925	 16443	 0.000629	 0.009705	 0.74791	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13925	 18660	 0.000191	 0.00247	 0.15762	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13925	 79524	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13925	 79524	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79525	 13925	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79525	 13925	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13926	 13944	 3e-06	 8.2e-05	 0.0057	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13926	 17636	 0.000389	 0.004641	 0.34825	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13926	 17717	 0.000669	 0.010801	 0.75966	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13926	 79526	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13926	 79526	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13927	 16872	 0.001515	 0.018728	 0.03757	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13927	 16894	 0.001448	 0.013791	 0.05039	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13927	 17592	 0.001041	 0.011239	 0.02231	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13927	 17592	 0.001041	 0.011239	 0.02231	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13927	 17606	 0.000494	 0.005608	 0.01231	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13927	 79527	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13927	 79527	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79528	 13927	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79528	 13927	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13928	 16723	 0.001847	 0.011988	 0.02388	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13928	 16743	 0.003807	 0.024118	 0.05052	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13928	 17574	 0.00071	 0.009978	 0.04138	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13928	 79529	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13928	 79529	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79530	 13928	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79530	 13928	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13929	 13936	 8.3e-05	 0.000913	 0.00192	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13929	 16923	 0.001166	 0.020298	 0.06817	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13929	 79531	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13929	 79531	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13930	 17117	 0.000105	 0.001872	 0.13288	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13930	 17217	 9.1e-05	 0.001248	 0.09442	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13930	 79532	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13930	 79532	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79533	 13930	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79533	 13930	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13931	 17310	 9.8e-05	 0.001755	 0.12458	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13931	 17317	 4.3e-05	 0.000713	 0.04657	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13931	 79534	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13931	 79534	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13932	 16178	 0.000626	 0.006494	 0.01399	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13932	 16957	 0.001032	 0.006879	 0.01297	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13932	 16958	 0.001531	 0.010545	 0.01861	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13932	 79537	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13932	 79537	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79538	 13932	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79538	 13932	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13933	 17227	 0.000108	 0.001293	 0.09699	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13933	 79539	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13933	 79539	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13934	 16164	 0.018273	 0.083852	 0.02149	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13934	 16987	 0.003022	 0.025075	 0.0066	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13934	 16988	 0.003402	 0.008991	 0.0021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13934	 16989	 0.002049	 0.010675	 0.0028	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13934	 17236	 0.000803	 0.008657	 0.00248	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79517	 13934	 0.000131	 0.002246	 0.00065	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13935	 17683	 0.000251	 0.007204	 0.5016	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13935	 39334	 0.000709	 0.012134	 0.94707	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13935	 79540	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13935	 79540	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13936	 17963	 0.00106	 0.010868	 0.02135	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13936	 79542	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13936	 79542	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79543	 13936	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79543	 13936	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13937	 16182	 0.004505	 0.019066	 0.00429	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13937	 16183	 0.005938	 0.046786	 0.01369	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13937	 79544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13937	 79544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13938	 79545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13938	 79545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13938	 80319	 0.000995	 0.003466	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13939	 17442	 9.4e-05	 0.001126	 0.08449	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13939	 79546	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13939	 79546	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79547	 13939	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79547	 13939	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13940	 16564	 0.001733	 0.00458	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13940	 16585	 0.005654	 0.014942	 0.0035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13940	 17224	 0.001162	 0.004519	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13940	 17242	 0.004304	 0.020073	 0.00497	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79539	 13940	 0.001982	 0.007788	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13941	 13957	 0.002086	 0.010288	 0.00278	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13941	 15923	 0.060448	 0.15994	 0.03749	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13941	 16771	 0.002342	 0.007812	 0.00198	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13941	 17348	 0.008059	 0.034108	 0.00768	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13941	 79548	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13941	 79548	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13942	 16452	 0.015643	 0.052713	 0.0131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13942	 17292	 0.00451	 0.013695	 0.003	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13942	 79549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13942	 79549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13943	 15894	 0.000765	 0.006144	 0.00173	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13943	 15896	 0.0188	 0.079588	 0.01791	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13943	 15897	 0.01512	 0.042165	 0.00885	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13943	 17261	 0.017063	 0.1144	 0.03508	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13943	 17517	 0.003819	 0.027013	 0.00741	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13943	 80905	 0.020324	 0.12638	 0.03571	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13944	 16303	 0.000372	 0.009628	 0.87848	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13944	 16303	 0.000372	 0.009628	 0.87848	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13944	 16360	 0.000579	 0.015662	 1.321	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13944	 16360	 0.000579	 0.015662	 1.321	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13944	 79550	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13944	 79550	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13944	 95340	 0.000367	 0.012758	 1.0946	 4217.0	 4427.8	 4638.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13945	 15911	 0.012542	 0.057543	 0.01474	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13945	 15918	 0.00656	 0.029538	 0.00786	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13945	 15919	 0.002563	 0.02198	 0.00625	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13945	 79553	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13945	 79553	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13946	 15997	 0.019338	 0.14505	 0.00293	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13946	 16812	 0.00841	 0.028053	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13946	 16813	 0.003409	 0.019155	 0.00035	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13946	 80601	 0.007218	 0.031983	 0.00096	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13947	 15943	 8.9e-05	 0.001541	 0.00518	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13947	 17343	 0.000313	 0.004702	 0.02125	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13947	 79554	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13947	 79554	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13948	 16231	 0.002668	 0.007263	 0.0016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13948	 16235	 0.003038	 0.011546	 0.00323	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13948	 16236	 0.006438	 0.019379	 0.00606	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13949	 17542	 0.002431	 0.012214	 0.00318	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13949	 17548	 0.004677	 0.018381	 0.00481	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13949	 79555	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13949	 79555	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13950	 16775	 0.00317	 0.023169	 0.00684	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13950	 16777	 0.004733	 0.01926	 0.00469	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13950	 17292	 0.042148	 0.13116	 0.02739	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13950	 17350	 0.001875	 0.007507	 0.00189	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13950	 18179	 0.011023	 0.066169	 0.02004	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13950	 79556	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13950	 79556	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13951	 16373	 0.011199	 0.029598	 0.00693	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13951	 16377	 0.003571	 0.023352	 0.00594	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13951	 16971	 0.007015	 0.035697	 0.01294	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13951	 79557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13951	 79557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13952	 16214	 0.005199	 0.014156	 0.00312	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13952	 17435	 0.010834	 0.027851	 0.0069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13952	 79558	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13952	 79558	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13953	 16632	 0.003067	 0.021877	 0.00678	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13953	 17003	 0.007875	 0.031531	 0.00794	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13953	 17005	 0.013283	 0.060947	 0.01562	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13953	 79559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13953	 79559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13954	 17640	 0.004552	 0.012029	 0.00282	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13954	 79560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13954	 79560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13955	 16360	 0.000122	 0.001578	 0.1007	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13955	 79561	 0.000229	 0.017175	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13955	 79561	 0.000229	 0.017175	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13956	 17217	 0.000614	 0.011242	 0.76276	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13956	 17612	 0.00027	 0.00367	 0.28153	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13956	 79564	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13956	 79564	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13957	 16771	 0.001107	 0.004433	 0.00112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13957	 79567	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13957	 79567	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13958	 15889	 0.006499	 0.036944	 0.00067	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13958	 15890	 0.045669	 0.10246	 0.00163	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13958	 16136	 0.066286	 0.086266	 0.00121	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13958	 16138	 0.009135	 0.031983	 0.00089	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79528	 13958	 0.19479	 0.55325	 0.0087	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13959	 16809	 0.003638	 0.014803	 0.00361	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13959	 17015	 0.017362	 0.10794	 0.03049	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13959	 79568	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13959	 79568	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13960	 80314	 0.030276	 0.14775	 0.00255	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13960	 80315	 0.020751	 0.053344	 0.00083	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13961	 17539	 0.03486	 0.062899	 0.00091	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13961	 17540	 0.012994	 0.008412	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13961	 17543	 0.007159	 0.016373	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13962	 16365	 0.007412	 0.029676	 0.00748	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13962	 17585	 0.011557	 0.031465	 0.00693	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13962	 79569	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13962	 79569	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13963	 80748	 0.007831	 0.051201	 0.00118	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13963	 80883	 0.017299	 0.083039	 0.00248	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13964	 17718	 0.009093	 0.033303	 0.00084	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13964	 80906	 0.012312	 0.020741	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13965	 16235	 0.004583	 0.017831	 0.00476	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13965	 79570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13965	 79570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13966	 16257	 0.00135	 0.01103	 0.00299	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13966	 16279	 0.003998	 0.020226	 0.00563	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13966	 16281	 0.0112	 0.037739	 0.00938	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13966	 16312	 0.00835	 0.035342	 0.00795	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13966	 16313	 0.004636	 0.01562	 0.00388	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13966	 17626	 0.019161	 0.086298	 0.02297	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13967	 15928	 0.003202	 0.010985	 0.00263	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13967	 17547	 0.005664	 0.023971	 0.00539	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13967	 79571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13967	 79571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13968	 16771	 0.001471	 0.005782	 0.00151	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13968	 16772	 0.000699	 0.005583	 0.00138	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13968	 17346	 0.011187	 0.076235	 0.02598	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13969	 17383	 0.008252	 0.020482	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13969	 17403	 0.001362	 0.006069	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13969	 17409	 0.031277	 0.031591	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79522	 13969	 0.097276	 0.32111	 0.0052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13970	 17572	 0.013481	 0.035629	 0.00834	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13970	 79572	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13970	 79572	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13971	 16022	 0.02485	 0.088774	 0.00176	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13971	 16992	 0.27048	 0.21411	 0.0027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13971	 16993	 0.037611	 0.085315	 0.0017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13971	 80332	 0.013468	 0.035695	 0.00091	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13972	 16136	 0.011383	 0.044282	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13972	 16883	 0.025429	 0.060216	 0.0011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13972	 16885	 0.024735	 0.063584	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13973	 16031	 0.002753	 0.010818	 0.00283	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13973	 16091	 0.00253	 0.012922	 0.00325	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13973	 79573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13973	 79573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13974	 16771	 0.003781	 0.009992	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13974	 16772	 0.001008	 0.004161	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13974	 17349	 0.001937	 0.010295	 0.00239	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13975	 15894	 0.001899	 0.014302	 0.00397	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13975	 17265	 0.006516	 0.069065	 0.02051	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13975	 17517	 0.004505	 0.018035	 0.00454	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13975	 79574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13975	 79574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13976	 16324	 0.003169	 0.016882	 0.0003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13976	 16326	 0.038929	 0.076295	 0.00114	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13976	 80429	 0.032928	 0.13065	 0.00373	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13977	 17263	 0.011075	 0.049349	 0.00084	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13977	 17648	 0.051812	 0.12027	 0.00229	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13977	 17649	 0.025179	 0.058457	 0.00087	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13978	 16914	 0.004773	 0.014918	 0.00432	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13978	 17006	 0.009634	 0.037867	 0.00991	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13978	 79575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13978	 79575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13979	 16182	 0.032554	 0.090808	 0.01907	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79540	 13979	 0.006027	 0.029719	 0.00804	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13979	 79576	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13979	 79576	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13980	 18305	 0.000529	 0.006598	 0.45241	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13980	 18982	 0.000412	 0.011404	 0.85653	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13980	 19166	 0.000248	 0.004593	 0.30332	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13980	 79577	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13980	 79577	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79578	 13980	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79578	 13980	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13981	 14882	 8.2e-05	 0.001447	 0.12693	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13981	 18992	 7.9e-05	 0.001341	 0.10436	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13981	 19413	 0.000175	 0.004375	 0.35706	 2893.0	 3037.6	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13981	 79579	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13981	 79579	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79580	 13981	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79580	 13981	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13982	 14004	 1.4e-05	 0.000171	 0.01282	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13982	 18785	 0.00029	 0.00346	 0.2596	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13982	 19432	 0.000388	 0.004625	 0.34706	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13982	 79581	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13982	 79581	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13983	 19317	 0.000528	 0.013977	 1.1561	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13983	 19776	 0.00037	 0.00914	 0.75998	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13983	 79582	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13983	 79582	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79583	 13983	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79583	 13983	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13984	 18221	 0.001347	 0.018085	 0.06385	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13984	 18661	 0.001977	 0.019142	 0.06772	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13984	 18886	 0.003594	 0.035332	 0.12128	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13984	 79584	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13984	 79584	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79585	 13984	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79585	 13984	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13985	 18204	 0.009198	 0.03798	 0.00899	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13985	 18790	 0.001384	 0.01352	 0.00379	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13985	 19159	 0.009646	 0.025492	 0.00597	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13985	 19204	 0.002662	 0.013375	 0.00348	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13985	 79586	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13985	 79586	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13986	 19237	 0.000404	 0.005037	 0.34528	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13986	 19250	 0.000425	 0.005067	 0.38031	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13986	 79587	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13986	 79587	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13987	 19273	 8e-05	 0.001051	 0.00231	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13987	 19535	 0.000796	 0.008377	 0.03631	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13987	 79590	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13987	 79590	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13988	 18188	 0.001778	 0.01747	 0.05992	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13988	 18603	 0.000441	 0.005508	 0.01082	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13988	 79591	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13988	 79591	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79592	 13988	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79592	 13988	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13988	 81495	 0.001721	 0.017847	 0.03844	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13988	 81495	 0.001721	 0.017847	 0.03844	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13989	 19166	 0.000122	 0.002365	 0.17045	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13989	 79593	 0.000324	 0.024331	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13989	 79593	 0.000324	 0.024331	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13990	 13991	 2.2e-05	 0.000285	 0.01817	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13990	 79596	 0.000278	 0.020855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13990	 79596	 0.000278	 0.020855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13991	 14002	 0.000318	 0.008403	 0.69323	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13991	 18305	 0.000258	 0.004414	 0.34368	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13991	 19036	 0.000175	 0.004331	 0.35965	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13991	 79599	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13991	 79599	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79600	 13991	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79600	 13991	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13992	 16642	 0.001871	 0.033911	 2.4578	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 0	 -30.0	 30.0;
	13992	 19346	 4.7e-05	 0.000879	 0.05805	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13992	 79601	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13992	 79601	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13992	 95345	 0.000946	 0.016215	 1.2685	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13993	 17574	 0.003582	 0.052446	 0.20147	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13993	 79604	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13993	 79604	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13993	 81198	 0.003596	 0.028899	 0.0627	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13993	 81488	 0.00147	 0.021845	 0.081	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13994	 19558	 0.00127	 0.012649	 0.04221	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79601	 13994	 4.2e-05	 0.000471	 0.00176	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13994	 79605	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13994	 79605	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79606	 13994	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79606	 13994	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13995	 18665	 0.000632	 0.009386	 0.03479	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13995	 18674	 0.000937	 0.009718	 0.02093	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13995	 18674	 0.000937	 0.009718	 0.02093	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13995	 19247	 0.004202	 0.040049	 0.14652	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13995	 79607	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13995	 79607	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13996	 13997	 8.1e-05	 0.001896	 0.15343	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13996	 18041	 0.001247	 0.017153	 1.3048	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13996	 18232	 3.6e-05	 0.000584	 0.041	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13996	 79608	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13996	 79608	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79609	 13996	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79609	 13996	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13997	 79610	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13997	 79610	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13998	 18796	 0.000766	 0.006783	 0.00181	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13998	 18918	 0.003815	 0.028734	 0.00797	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13998	 79613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13998	 79613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13999	 14016	 0.00057	 0.002764	 0.00063	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13999	 14019	 4e-05	 0.00014	 3e-05	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13999	 19208	 0.015568	 0.10032	 0.02631	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13999	 19464	 0.000392	 0.003035	 0.00106	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13999	 19467	 0.001664	 0.007492	 0.00199	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14000	 18630	 5.2e-05	 0.000645	 0.04421	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14000	 79614	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14000	 79614	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14001	 16630	 0.015727	 0.066574	 0.01498	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14001	 18774	 0.005506	 0.025261	 0.00647	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14001	 19409	 0.001821	 0.007156	 0.00187	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14001	 19410	 0.001372	 0.005336	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14001	 79616	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14001	 79616	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14002	 14005	 7e-06	 0.000136	 0.01597	 3450.0	 3622.5	 3795.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14002	 19151	 0.000535	 0.009581	 0.68109	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14002	 79617	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14002	 79617	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14002	 79617	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14003	 18743	 0.000306	 0.002289	 0.00886	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14003	 19727	 0.000836	 0.005578	 0.01051	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14003	 79618	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14003	 79618	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14004	 79619	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14004	 79619	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79620	 14004	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79620	 14004	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14005	 18039	 6.1e-05	 0.001495	 0.12412	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14005	 18934	 0.000101	 0.001255	 0.08598	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14005	 79621	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14005	 79621	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14006	 19676	 0.002488	 0.011777	 0.00283	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14006	 79622	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14006	 79622	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14007	 19464	 0.00074	 0.001919	 0.00058	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14007	 79623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14007	 79623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14008	 18201	 0.000508	 0.003152	 0.00076	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14008	 18202	 0.006803	 0.045639	 0.01102	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14008	 79624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14008	 79624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14009	 19146	 0.003027	 0.012319	 0.003	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14009	 19147	 0.007057	 0.030918	 0.01064	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14009	 19410	 0.004779	 0.016393	 0.00393	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14009	 79625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14009	 79625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14010	 17737	 0.016429	 0.042654	 0.01035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14010	 17743	 0.026876	 0.080922	 0.02533	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14010	 18892	 0.006111	 0.029655	 0.00678	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14010	 18928	 0.021293	 0.18162	 0.04541	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14010	 79626	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14010	 79626	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14011	 18189	 0.004955	 0.022733	 0.00582	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14011	 18190	 0.009856	 0.061249	 0.01729	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14011	 18602	 0.00338	 0.038039	 0.00999	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14011	 18928	 0.038539	 0.15446	 0.03897	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14011	 18965	 0.031056	 0.12214	 0.03198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14011	 81194	 0.002521	 0.031718	 0.00983	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14012	 18059	 0.001924	 0.019444	 0.00572	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14012	 19382	 0.002028	 0.009844	 0.00225	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14012	 20005	 0.011741	 0.057902	 0.01566	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14012	 79627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14012	 79627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14013	 18364	 0.000982	 0.0052	 0.00132	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14013	 18365	 0.000869	 0.0054	 0.00152	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14013	 18366	 9.6e-05	 0.000668	 0.00025	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14014	 15571	 0.007345	 0.055044	 0.01343	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14014	 15646	 0.003784	 0.017646	 0.00437	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14014	 18027	 0.004433	 0.01029	 0.00313	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14014	 18032	 0.029506	 0.1182	 0.0298	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14014	 18798	 0.051747	 0.21943	 0.0495	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14014	 79628	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14014	 79628	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14015	 19584	 0.004167	 0.011011	 0.00258	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14015	 19643	 0.002988	 0.007897	 0.00185	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14015	 19667	 0.001138	 0.00552	 0.00126	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14016	 19464	 0.000804	 0.004994	 0.00141	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14016	 79629	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14016	 79629	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14016	 81275	 0.043051	 0.12012	 0.02523	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14017	 18231	 0.000675	 0.002703	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14017	 18272	 0.005576	 0.035318	 0.00959	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14017	 19729	 0.000351	 0.002157	 0.00079	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14018	 19118	 0.002841	 0.025316	 0.04449	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14018	 19319	 0.001212	 0.008081	 0.01523	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14018	 79630	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14018	 79630	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79631	 14018	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79631	 14018	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14018	 81452	 0.00104	 0.016015	 0.03529	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14019	 18976	 0.014648	 0.0353	 0.00997	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14019	 79632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14019	 79632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14020	 17441	 0.003748	 0.037364	 0.12482	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14020	 18004	 0.015087	 0.098252	 0.19663	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14020	 79633	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14020	 79633	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79634	 14020	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79634	 14020	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14021	 14031	 0.004346	 0.027529	 0.00747	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14021	 18201	 0.000357	 0.004425	 0.00192	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14021	 18945	 0.001766	 0.01068	 0.00273	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14022	 19112	 0.010974	 0.033324	 0.0073	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14022	 79635	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14022	 79635	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14023	 18339	 0.015451	 0.010945	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14023	 81477	 0.00101	 0.004126	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14023	 81480	 0.002245	 0.006758	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14024	 18629	 0.002757	 0.030487	 0.00914	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14024	 79636	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14024	 79636	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14024	 81208	 0.001025	 0.013713	 0.00375	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14025	 18030	 0.005608	 0.022453	 0.00566	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14025	 18031	 0.005375	 0.017932	 0.00455	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14025	 18032	 0.006874	 0.030953	 0.00824	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14026	 18909	 0.003919	 0.010522	 0.00238	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14026	 79637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14026	 79637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14027	 19461	 0.005429	 0.007707	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14027	 81393	 0.024288	 0.056379	 0.00107	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14028	 18213	 0.003417	 0.015143	 0.00045	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14028	 18645	 0.023544	 0.096225	 0.00195	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14028	 19264	 0.073026	 0.1213	 0.00257	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14029	 18058	 0.0009	 0.011248	 0.0221	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14029	 18168	 0.001061	 0.012541	 0.02755	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14029	 79638	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14029	 79638	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79639	 14029	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79639	 14029	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14030	 19108	 0.001967	 0.009698	 0.00262	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14030	 19454	 0.000495	 0.002272	 0.00058	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14031	 18945	 0.003186	 0.019796	 0.00559	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14031	 18946	 0.005738	 0.03561	 0.00863	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14031	 18948	 0.018298	 0.074478	 0.01815	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14032	 19658	 0.003278	 0.009867	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14032	 19673	 0.000977	 0.006008	 0.00011	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14032	 81501	 0.006151	 0.018515	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14033	 14043	 1.9e-05	 0.000261	 0.01788	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14033	 20107	 0.001044	 0.013056	 0.89716	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14033	 79640	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14033	 79640	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14034	 20092	 6.3e-05	 0.001641	 0.1218	 2893.0	 3037.6	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14034	 20113	 0.000115	 0.002191	 0.19317	 2840.0	 2982.0	 3124.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14034	 79642	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14034	 79642	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79643	 14034	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79643	 14034	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14035	 14040	 2.3e-05	 0.000271	 0.02031	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14035	 14057	 0.00012	 0.001429	 0.10719	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14035	 20174	 4.4e-05	 0.000626	 0.04999	 2385.0	 2504.2	 2623.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14036	 14038	 0.000258	 0.00667	 0.60792	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14036	 14038	 0.000258	 0.00667	 0.60792	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14036	 20037	 7.5e-05	 0.002148	 0.14943	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14036	 20163	 9.6e-05	 0.00161	 0.15651	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14036	 79644	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14036	 79644	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14036	 79644	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14037	 20037	 0.000454	 0.01201	 0.99235	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14037	 20174	 0.000571	 0.010584	 0.70007	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14037	 79646	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14037	 79646	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79647	 14037	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79647	 14037	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14038	 20230	 1.4e-05	 0.000288	 0.03018	 3450.0	 3622.5	 3795.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14038	 20279	 0.000125	 0.003235	 0.29459	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14038	 20279	 0.000125	 0.003235	 0.29459	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 0	 -30.0	 30.0;
	14038	 79648	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14038	 79648	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79649	 14038	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79649	 14038	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14039	 14986	 0.000147	 0.002506	 0.19507	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14039	 19931	 0.000583	 0.016772	 1.1725	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14039	 20026	 0.000366	 0.00626	 0.48761	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14039	 79650	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14039	 79650	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79651	 14039	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79651	 14039	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14040	 20174	 6.7e-05	 0.000803	 0.0602	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14040	 79652	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14040	 79652	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79653	 14040	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79653	 14040	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14041	 19260	 0.001683	 0.021102	 1.457	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14041	 19768	 0.000831	 0.024008	 1.6872	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14041	 20107	 7.8e-05	 0.002149	 0.16103	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14041	 79654	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14041	 79654	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14042	 20054	 0.002496	 0.041801	 0.15214	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14042	 20274	 0.000448	 0.006763	 0.02428	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79646	 14042	 0.000599	 0.006605	 0.01255	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79646	 14042	 0.000599	 0.006605	 0.01255	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14042	 79656	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14042	 79656	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79657	 14042	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79657	 14042	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14043	 20045	 0.000684	 0.017924	 1.9214	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 0	 -30.0	 30.0;
	14043	 79658	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14043	 79658	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79659	 14043	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79659	 14043	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14043	 95335	 0.000345	 0.009404	 0.91713	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14043	 95338	 0.000448	 0.015595	 1.3404	 4217.0	 4427.8	 4638.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14044	 20005	 0.012789	 0.072715	 0.02106	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14044	 20008	 0.010649	 0.051686	 0.01182	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14044	 20250	 0.008344	 0.050081	 0.01517	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14044	 20278	 0.007052	 0.060487	 0.01722	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14044	 79660	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14044	 79660	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14045	 20002	 0.000708	 0.005687	 0.0016	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14045	 20004	 0.021796	 0.087294	 0.022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79651	 14045	 0.000701	 0.012019	 0.00345	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14046	 20165	 1.8e-05	 0.00022	 0.01647	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14046	 79661	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14046	 79661	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14047	 20352	 0.000167	 0.001272	 0.00473	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14047	 36684	 0.001088	 0.014463	 0.0309	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14047	 79664	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14047	 79664	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79665	 14047	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79665	 14047	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79650	 14048	 0.000912	 0.00868	 0.01542	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14048	 79666	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14048	 79666	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14049	 14985	 9.6e-05	 0.002746	 0.19102	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14049	 20201	 0.000365	 0.01047	 0.72971	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14049	 20280	 6.6e-05	 0.001523	 0.16033	 3786.0	 3975.3	 4164.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14049	 79667	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14049	 79667	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14050	 20215	 0.000189	 0.001716	 0.00043	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14050	 20225	 0.001162	 0.007145	 0.00206	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14050	 79668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14050	 79668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14051	 20336	 0.004155	 0.027874	 0.00673	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14051	 20337	 0.009034	 0.03617	 0.00911	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14051	 20338	 0.010982	 0.04469	 0.01089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79651	 14051	 0.007114	 0.057158	 0.01607	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14051	 79669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14051	 79669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14052	 19250	 0.001809	 0.021708	 1.6429	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14052	 36685	 3e-05	 0.000352	 0.02644	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14052	 79670	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14052	 79670	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14053	 20274	 0.000478	 0.003458	 0.01435	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14053	 20392	 0.001514	 0.02213	 0.08482	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79646	 14053	 1.9e-05	 0.000289	 0.00131	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14054	 20246	 0.005204	 0.023433	 0.00624	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14054	 20251	 0.003178	 0.023813	 0.00581	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14054	 79671	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14054	 79671	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14055	 20362	 0.000314	 0.002142	 0.00386	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14055	 79672	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14055	 79672	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14056	 20236	 0.000554	 0.007541	 0.02589	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14056	 79673	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14056	 79673	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14056	 81791	 0.000178	 0.00277	 0.01164	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14057	 20174	 0.000135	 0.001739	 0.11096	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14057	 79674	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14057	 79674	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14058	 19988	 0.001073	 0.011443	 0.02327	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14058	 19988	 0.001073	 0.011443	 0.02327	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14058	 19996	 0.000518	 0.005284	 0.01678	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14058	 19997	 0.000802	 0.008749	 0.01697	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14059	 20288	 0.001852	 0.018556	 0.00618	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14059	 79675	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14059	 79675	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14059	 81828	 0.00132	 0.012672	 0.00369	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14060	 20050	 0.003867	 0.038515	 0.0143	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14060	 20391	 0.001723	 0.016453	 0.00604	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14060	 26939	 0.001597	 0.016091	 0.00987	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14061	 79677	 0.044353	 0.071148	 0.00131	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14062	 14063	 0.002516	 0.009787	 0.00261	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14062	 14220	 0.002588	 0.012246	 0.00294	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14062	 79676	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14062	 79676	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14063	 14065	 0.003779	 0.022513	 0.00592	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14063	 79677	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14063	 79677	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79677	 14064	 0.034241	 0.060218	 0.00113	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14065	 79678	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14065	 79678	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79678	 14066	 0.032776	 0.025939	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79467	 14067	 0.008209	 0.013104	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79473	 14067	 0.005666	 0.030186	 0.00053	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79475	 14067	 0.038867	 0.11699	 0.00229	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14068	 14072	 0.004016	 0.016995	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79467	 14068	 0.007388	 0.019147	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14069	 79680	 0.023843	 0.061292	 0.00095	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14070	 79679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14070	 79679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14071	 14072	 0.007492	 0.023007	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79473	 14071	 0.033464	 0.04355	 0.00061	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79679	 14071	 0.011174	 0.037275	 0.00059	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14071	 79719	 0.027153	 0.23065	 0.00539	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14072	 79680	 0.006428	 0.018901	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14073	 79680	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14073	 79680	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14074	 14077	 0.001945	 0.008032	 0.0019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14074	 79681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14074	 79681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79681	 14075	 0.005512	 0.014169	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14075	 79682	 0.010771	 0.033076	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14076	 14083	 0.00304	 0.011946	 0.00313	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14076	 79682	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14076	 79682	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14077	 14083	 0.002026	 0.00811	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14078	 14080	 0.019618	 0.095732	 0.00165	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79467	 14078	 0.022771	 0.052865	 0.00079	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79677	 14078	 0.017799	 0.078424	 0.00136	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79474	 14079	 0.032754	 0.046497	 0.00077	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14080	 14081	 0.034099	 0.077986	 0.0019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14080	 15538	 0.02919	 0.08955	 0.00243	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14081	 14082	 0.017719	 0.068933	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14081	 14086	 0.017303	 0.08753	 0.00152	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14081	 14814	 0.030603	 0.093983	 0.00176	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79682	 14081	 0.024644	 0.10858	 0.00189	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79682	 14082	 0.012465	 0.044527	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14083	 14084	 0.001609	 0.010363	 0.00272	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14084	 14092	 0.003085	 0.021817	 0.00599	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14085	 14092	 0.002092	 0.015291	 0.00451	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14085	 14225	 0.001067	 0.008852	 0.00233	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14086	 14088	 0.013452	 0.082706	 0.00149	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14087	 14088	 0.021371	 0.049099	 0.00075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14087	 14223	 0.023247	 0.066675	 0.00103	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14088	 14089	 0.024747	 0.082556	 0.00131	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14088	 79722	 0.085544	 0.26276	 0.00493	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14089	 14228	 0.053492	 0.13751	 0.00213	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14089	 14818	 0.056318	 0.11151	 0.00164	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79679	 14090	 0.020221	 0.039629	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79467	 14091	 0.000797	 0.004842	 9e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79678	 14091	 0.004625	 0.020379	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14093	 14094	 0.00049	 0.002595	 0.00066	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14093	 14124	 0.000654	 0.003286	 0.00086	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14094	 14096	 0.000343	 0.001621	 0.00052	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14095	 14100	 0.001917	 0.008542	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14095	 79683	 0.001817	 0.007425	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14096	 14098	 0.000231	 0.001389	 0.00042	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14096	 14116	 0.001114	 0.003883	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14096	 79683	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14096	 79683	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79683	 14097	 0.001928	 0.008241	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14097	 79689	 0.003389	 0.008711	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14097	 79691	 0.001966	 0.015737	 0.00032	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14098	 79684	 0.000248	 0.001569	 0.00043	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79468	 14099	 0.000254	 0.002637	 0.00568	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79468	 14099	 0.000254	 0.002637	 0.00568	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14099	 79684	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14099	 79684	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14099	 79686	 5.4e-05	 0.000561	 0.00121	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14099	 79686	 5.4e-05	 0.000561	 0.00121	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14100	 14101	 0.008264	 0.00535	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14100	 79685	 0.002233	 0.008593	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14100	 79685	 0.002233	 0.008593	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14100	 79692	 0.010727	 0.034061	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14102	 79685	 0.00819	 0.013352	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14103	 14146	 0.00049	 0.006677	 0.00239	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14103	 79685	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14103	 79685	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14103	 79687	 0.000284	 0.003631	 0.00108	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79685	 14104	 0.008969	 0.006599	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14105	 14107	 0.00286	 0.005662	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14105	 79688	 0.003748	 0.004926	 7e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14106	 79698	 0.000375	 0.005638	 0.00397	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14107	 14113	 0.001931	 0.007891	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14107	 79688	 0.003492	 0.008022	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14108	 14109	 0.005213	 0.006111	 0.00011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14108	 14112	 0.003758	 0.00678	 0.0001	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14109	 14110	 0.005056	 0.009682	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14109	 14111	 0.008748	 0.00875	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79685	 14109	 0.001509	 0.004839	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14110	 14140	 0.057495	 0.045067	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14110	 14144	 0.003857	 0.013779	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79685	 14110	 0.004103	 0.011645	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14110	 79688	 0.009322	 0.02132	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14110	 79696	 0.004008	 0.014033	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14111	 14112	 0.006056	 0.007382	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14112	 14113	 0.001426	 0.005546	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14112	 14205	 0.084046	 0.066515	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14113	 79688	 0.004116	 0.015833	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14113	 79699	 0.005565	 0.021648	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14113	 79699	 0.005565	 0.021648	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14114	 14149	 2.1e-05	 0.000495	 0.04775	 3786.0	 3975.3	 4164.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14114	 79686	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14114	 79686	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14115	 14116	 0.000283	 0.002904	 0.00092	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79684	 14115	 0.000363	 0.002438	 0.00059	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79469	 14116	 0.000284	 0.004012	 0.00133	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14116	 79689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14116	 79689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14117	 14118	 0.00608	 0.01563	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14117	 14130	 0.040942	 0.032401	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14118	 14120	 0.012161	 0.012987	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14118	 79691	 0.01097	 0.067445	 0.00122	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14119	 14120	 0.010267	 0.007422	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14120	 14127	 0.010875	 0.019546	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14121	 14127	 0.004114	 0.014054	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14121	 79693	 0.003785	 0.016866	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14122	 14126	 0.000284	 0.004102	 0.0013	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14122	 79690	 0.00038	 0.004718	 0.00204	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77701	 14123	 0.000795	 0.008892	 0.01641	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77701	 14123	 0.000795	 0.008892	 0.01641	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79468	 14123	 0.000115	 0.001222	 0.00248	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79468	 14123	 0.000115	 0.001222	 0.00248	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14123	 79690	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79691	 14123	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79690	 14124	 0.001788	 0.00716	 0.0018	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14124	 79692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14124	 79692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14125	 79693	 0.019597	 0.014166	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14126	 14134	 0.000453	 0.006545	 0.00208	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14126	 79693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14126	 79693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14127	 14131	 0.005059	 0.013374	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14127	 79694	 0.006131	 0.0126	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14128	 14129	 0.009148	 0.021235	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14128	 14136	 0.007302	 0.018771	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14129	 14132	 0.003489	 0.011638	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14130	 14131	 0.005634	 0.009409	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14132	 14133	 0.004601	 0.0117	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14133	 79694	 0.008489	 0.018192	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14134	 79694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14134	 79694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79694	 14135	 0.018807	 0.017637	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14136	 14137	 0.003566	 0.013871	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79692	 14137	 0.002846	 0.017499	 0.00032	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79469	 14138	 0.007101	 0.021265	 0.00479	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14138	 79695	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14138	 79695	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14139	 14155	 0.020825	 0.053534	 0.00083	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79695	 14139	 0.020477	 0.04754	 0.00071	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14141	 14142	 0.010456	 0.017047	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14141	 14160	 0.044804	 0.068635	 0.00096	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14141	 79699	 0.011198	 0.043083	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14142	 79696	 0.012474	 0.015674	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14143	 79696	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14143	 79696	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14143	 79698	 0.001272	 0.00819	 0.00215	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79696	 14144	 0.001942	 0.006798	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79696	 14145	 0.020484	 0.016211	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14146	 14147	 0.00167	 0.004414	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14146	 79698	 0.000168	 0.002665	 0.0008	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14147	 14150	 0.003049	 0.008057	 0.00189	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14148	 14150	 0.000994	 0.003908	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14148	 79697	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14148	 79697	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14148	 79698	 0.00318	 0.010371	 0.00275	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14149	 15000	 0.000364	 0.008948	 0.90657	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14149	 15000	 0.000364	 0.008948	 0.90657	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 0	 -30.0	 30.0;
	14149	 79698	 0.000117	 0.009351	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14149	 79698	 0.000117	 0.009351	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14150	 14151	 0.000524	 0.002134	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14150	 79700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14150	 79700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14151	 14153	 0.001185	 0.003493	 0.00081	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14151	 79701	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14151	 79701	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14152	 14154	 0.016391	 0.011611	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79701	 14152	 0.00539	 0.010671	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14152	 79702	 0.017467	 0.01638	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14153	 79702	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14153	 79702	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14155	 14156	 0.007419	 0.023789	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14156	 14157	 0.022602	 0.027057	 0.00045	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14156	 14164	 0.009874	 0.025111	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79696	 14156	 0.027004	 0.071574	 0.00182	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14157	 14158	 0.013773	 0.027269	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14158	 14160	 0.014612	 0.037161	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14159	 14167	 0.021358	 0.023491	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14160	 14163	 0.002399	 0.013634	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14160	 14164	 0.009714	 0.019878	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14161	 14167	 0.022881	 0.016541	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14162	 14163	 0.003878	 0.02662	 0.00049	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14162	 14176	 0.007526	 0.023087	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14162	 14176	 0.007526	 0.023087	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14162	 79704	 0.01534	 0.040659	 0.00103	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14164	 14165	 0.013038	 0.021964	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79702	 14165	 0.00797	 0.026301	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14166	 14167	 0.005724	 0.014835	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79700	 14166	 0.006117	 0.0142	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14167	 14168	 0.006413	 0.024572	 0.00069	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79697	 14167	 0.031751	 0.04132	 0.00058	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14168	 14175	 0.004838	 0.02156	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14169	 14173	 0.001282	 0.007511	 0.00205	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79698	 14169	 0.005738	 0.019684	 0.00472	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14169	 79703	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14169	 79703	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14170	 14171	 0.010351	 0.034158	 0.00055	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14170	 79704	 0.006909	 0.01636	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14171	 14172	 0.006717	 0.022405	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14171	 14185	 0.009412	 0.021851	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14171	 14192	 0.003556	 0.013681	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14172	 14194	 0.008411	 0.019918	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79703	 14172	 0.011765	 0.039248	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14173	 79704	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14173	 79704	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14174	 14175	 0.005927	 0.012181	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14174	 14183	 0.004347	 0.01691	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79704	 14174	 0.005595	 0.015476	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14175	 14180	 0.002668	 0.019503	 0.00036	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79704	 14175	 0.010062	 0.021481	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14176	 14178	 0.010356	 0.029387	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14176	 79954	 0.003084	 0.029856	 0.0006	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14177	 14186	 0.007243	 0.020773	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14177	 79706	 0.0048	 0.016013	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14178	 14180	 0.002425	 0.018679	 0.00036	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14178	 79705	 0.003252	 0.012198	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14178	 79705	 0.003252	 0.012198	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14179	 14869	 0.000812	 0.005572	 0.00163	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14179	 79705	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14179	 79705	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14181	 14211	 0.007418	 0.02886	 0.00771	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14181	 79706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14181	 79706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14182	 14189	 0.020113	 0.03615	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79706	 14182	 0.023772	 0.024011	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14183	 14184	 0.015351	 0.01508	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79706	 14183	 0.002264	 0.013917	 0.00025	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14184	 14185	 0.006974	 0.017927	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14184	 14189	 0.013152	 0.043875	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79704	 14184	 0.006586	 0.031777	 0.00056	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14185	 14189	 0.006518	 0.019996	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14186	 79708	 0.00912	 0.030423	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14187	 14190	 0.002264	 0.013918	 0.00401	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14187	 14862	 0.003924	 0.022543	 0.00639	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14187	 79707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14187	 79707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14188	 14190	 0.00419	 0.015926	 0.00446	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14188	 14867	 0.00146	 0.008391	 0.00238	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14188	 79708	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14188	 79708	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79708	 14189	 0.005729	 0.032187	 0.0006	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14189	 79709	 0.012066	 0.036318	 0.00071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14190	 14209	 0.001433	 0.007467	 0.00196	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14190	 79709	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14190	 79709	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79709	 14191	 0.016372	 0.032087	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14192	 14194	 0.004616	 0.020569	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79709	 14192	 0.007907	 0.031696	 0.00082	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14192	 79713	 0.003272	 0.018598	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14193	 14195	 0.008082	 0.012378	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14193	 14196	 0.004828	 0.016107	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14193	 14197	 0.009277	 0.023594	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14193	 79714	 0.004045	 0.022726	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14194	 14195	 0.006323	 0.014343	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14196	 14197	 0.00372	 0.009105	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14196	 79715	 0.011645	 0.023056	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14197	 79710	 0.00326	 0.022374	 0.00041	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14198	 14200	 0.002148	 0.009571	 0.0026	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14198	 79710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14198	 79710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14199	 14206	 0.000722	 0.00289	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14199	 14208	 0.001457	 0.005728	 0.0015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14200	 14203	 0.001116	 0.004341	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79698	 14200	 0.00106	 0.004864	 0.00125	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14201	 14203	 0.001038	 0.004154	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14201	 79711	 0.000788	 0.003728	 0.0009	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77612	 14202	 0.00371	 0.024749	 0.04666	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77615	 14202	 0.003774	 0.02391	 0.05009	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14202	 79711	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14202	 79711	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14204	 14206	 0.001376	 0.005601	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79711	 14204	 0.001101	 0.00553	 0.00144	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14204	 79712	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14204	 79712	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14205	 14207	 0.028724	 0.020764	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79712	 14205	 0.007093	 0.014043	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14208	 14211	 0.00195	 0.009094	 0.00225	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14209	 14210	 0.001942	 0.007776	 0.00196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14209	 79713	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14209	 79713	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14210	 14211	 0.000554	 0.006729	 0.00181	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14210	 79714	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14210	 79714	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77613	 14211	 0.015282	 0.05534	 0.01187	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79698	 14211	 0.002799	 0.023283	 0.00705	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14211	 79715	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14211	 79715	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79470	 14212	 0.017472	 0.044912	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79475	 14212	 0.098637	 0.303	 0.00569	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79709	 14212	 0.020896	 0.037323	 0.00055	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79713	 14212	 0.020806	 0.049269	 0.0009	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14213	 14215	 0.006177	 0.026144	 0.00588	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14213	 79716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14213	 79716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14214	 79717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14214	 79717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14215	 14216	 0.003646	 0.015054	 0.00356	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14216	 14218	 0.006228	 0.025714	 0.00608	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14216	 79718	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14216	 79718	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79716	 14217	 0.048655	 0.081145	 0.00118	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14218	 14220	 0.003822	 0.017531	 0.00449	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14219	 14221	 0.023073	 0.07697	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79717	 14219	 0.060504	 0.1005	 0.00213	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79718	 14219	 0.029469	 0.052636	 0.00078	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79677	 14221	 0.032418	 0.11581	 0.0023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79472	 14222	 0.000238	 0.003	 0.00093	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14223	 79719	 0.005033	 0.046858	 0.00091	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14223	 79720	 0.017428	 0.053464	 0.00145	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14223	 79720	 0.017428	 0.053464	 0.00145	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14224	 79720	 0.011019	 0.056068	 0.00127	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14224	 79726	 0.025024	 0.15386	 0.00277	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14225	 14226	 0.001554	 0.012699	 0.00345	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14225	 79719	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14225	 79719	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14226	 14227	 0.002365	 0.018632	 0.00545	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14226	 79720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14226	 79720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14227	 14237	 0.00213	 0.017109	 0.00481	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14228	 79721	 0.029248	 0.11253	 0.00192	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14228	 79932	 0.036162	 0.11106	 0.00208	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14229	 79723	 0.10463	 0.14277	 0.00255	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14230	 14232	 0.00296	 0.011634	 0.00304	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14231	 14273	 0.003243	 0.016564	 0.00417	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14232	 14233	 0.001188	 0.004668	 0.00122	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14232	 79721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14232	 79721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14233	 14822	 0.013265	 0.038422	 0.00927	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14233	 79722	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14233	 79722	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14234	 14235	 0.031934	 0.063228	 0.00093	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14234	 14236	 0.042203	 0.078473	 0.00184	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79721	 14234	 0.097954	 0.063418	 0.00121	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79722	 14234	 0.026796	 0.052515	 0.00079	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14236	 79723	 0.028122	 0.064609	 0.00098	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14237	 14238	 0.003847	 0.017647	 0.00452	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14237	 79723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14237	 79723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14238	 14241	 0.004163	 0.020313	 0.00561	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14239	 14271	 0.12839	 0.083124	 0.00158	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14239	 79724	 0.051896	 0.0795	 0.00112	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14240	 14272	 0.015403	 0.039597	 0.00981	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14240	 79724	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14240	 79724	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14241	 14247	 0.005046	 0.023535	 0.00583	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79471	 14242	 0.023733	 0.018782	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14243	 79725	 0.023381	 0.035817	 0.0005	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14243	 79728	 0.035312	 0.056365	 0.0013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14244	 79725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14244	 79725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14245	 14258	 0.085095	 0.060278	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79725	 14245	 0.038791	 0.027477	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79723	 14246	 0.047953	 0.10079	 0.00184	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14246	 79726	 0.031471	 0.067442	 0.00118	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14247	 14248	 0.003901	 0.013787	 0.00311	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14248	 79726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14248	 79726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79726	 14249	 0.076925	 0.060298	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14250	 79727	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14250	 79727	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14251	 14252	 0.051609	 0.056213	 0.00077	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14251	 14255	 0.020773	 0.041128	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79727	 14251	 0.01335	 0.037885	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14253	 14254	 0.032126	 0.039879	 0.00087	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79723	 14253	 0.053173	 0.17739	 0.00281	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79725	 14253	 0.022279	 0.05727	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14254	 14255	 0.014818	 0.031755	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79725	 14254	 0.011495	 0.05122	 0.00087	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14255	 14256	 0.052009	 0.033671	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14256	 14257	 0.024907	 0.019711	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14258	 14259	 0.060243	 0.047222	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14260	 14261	 0.02418	 0.018953	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14261	 14262	 0.02223	 0.017052	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14261	 79729	 0.033837	 0.026778	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14262	 14263	 0.068896	 0.054524	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14263	 14267	 0.10863	 0.085154	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14264	 14266	 0.005728	 0.015596	 0.00344	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14264	 79728	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14264	 79728	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79728	 14265	 0.079038	 0.062551	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14265	 79729	 0.081786	 0.05295	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14266	 79729	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14266	 79729	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14267	 14268	 0.057049	 0.045148	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14267	 15629	 0.11345	 0.2886	 0.00457	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79729	 14267	 0.12063	 0.095471	 0.0012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79729	 14268	 0.08437	 0.054623	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14269	 14270	 0.039994	 0.065558	 0.00116	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79471	 14270	 0.017744	 0.069031	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14271	 79730	 0.061275	 0.089696	 0.00138	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14272	 79730	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14272	 79730	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14273	 14910	 0.009119	 0.037108	 0.00904	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14273	 79731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14273	 79731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79730	 14274	 0.018983	 0.10791	 0.00195	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79731	 14274	 0.015231	 0.052029	 0.00113	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79731	 14275	 0.023382	 0.078	 0.00124	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14275	 80224	 0.017604	 0.060133	 0.00131	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14276	 14278	 0.000702	 0.002111	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14276	 79754	 0.000454	 0.002444	 0.00067	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14277	 14278	 0.000494	 0.001346	 0.0003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14277	 14279	 0.000699	 0.002437	 0.00057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14277	 79732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14277	 79732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14279	 14285	 0.000677	 0.002027	 0.00046	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14280	 14281	 0.012961	 0.013234	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14281	 14282	 0.007905	 0.007907	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14281	 79745	 0.00309	 0.007175	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14281	 79755	 0.005391	 0.016538	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14283	 14291	 0.005985	 0.011311	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14283	 79737	 0.007546	 0.010296	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14284	 14291	 0.002558	 0.009953	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14284	 79733	 0.001175	 0.005448	 0.00011	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14285	 79733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14285	 79733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79733	 14286	 0.012647	 0.012773	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14286	 79734	 0.009435	 0.018681	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79732	 14287	 0.002837	 0.011037	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14287	 81015	 0.002915	 0.015531	 0.00027	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14288	 14289	 0.000814	 0.003261	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14288	 14290	 0.001014	 0.004059	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14288	 79734	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14288	 79734	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14289	 18080	 0.001163	 0.004525	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14290	 14292	 0.000834	 0.003392	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14290	 79735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14290	 79735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79735	 14291	 0.020836	 0.01533	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14292	 79736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14292	 79736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14292	 80122	 0.004645	 0.012645	 0.00279	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79736	 14293	 0.01536	 0.015514	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14293	 79737	 0.006186	 0.013001	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14294	 14297	 0.005735	 0.011354	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14294	 14305	 0.019327	 0.019331	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14295	 79737	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14295	 79737	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14295	 79798	 0.003289	 0.011464	 0.00266	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14296	 15299	 0.01331	 0.010533	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79736	 14296	 0.005914	 0.01171	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14297	 14298	 0.010602	 0.01786	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79736	 14297	 0.004014	 0.013247	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14298	 14299	 0.015723	 0.020664	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14298	 14301	 0.007781	 0.012925	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14298	 15298	 0.008213	 0.016261	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14299	 15242	 0.014807	 0.011718	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14299	 80100	 0.018424	 0.01458	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14300	 14304	 0.01256	 0.009845	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14300	 79794	 0.011038	 0.011613	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14301	 14302	 0.011687	 0.009249	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14302	 14305	 0.014305	 0.011321	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14302	 79738	 0.007232	 0.006782	 0.0001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14303	 14308	 0.000814	 0.00326	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14303	 14446	 0.001302	 0.003441	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14303	 79738	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14303	 79738	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79738	 14304	 0.003808	 0.006975	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14306	 14307	 0.002837	 0.007294	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14306	 14316	 0.00509	 0.012945	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14307	 14309	 0.011006	 0.008627	 0.00011	 33.0	 33.0	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79738	 14307	 0.006357	 0.010602	 0.00015	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14308	 14323	 0.00115	 0.006335	 0.00229	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14308	 79739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14308	 79739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14309	 14313	 0.004477	 0.008864	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14310	 14311	 0.008215	 0.008298	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79739	 14310	 0.011227	 0.008885	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14310	 79783	 0.01782	 0.012882	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14311	 14313	 0.002794	 0.004913	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14312	 14404	 0.00173	 0.005828	 0.00145	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14312	 14418	 0.000467	 0.00259	 0.00079	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14312	 79740	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14312	 79740	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14312	 79798	 0.001198	 0.008904	 0.0034	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14313	 14315	 0.001408	 0.007124	 0.00012	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14314	 14315	 0.005416	 0.007118	 0.0001	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14315	 14319	 0.000921	 0.005661	 0.0001	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14315	 14321	 0.001768	 0.0059	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79740	 14315	 0.01972	 0.016231	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79737	 14316	 0.003209	 0.012346	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14317	 14318	 0.001451	 0.003846	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14317	 14319	 0.002477	 0.006367	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14318	 79745	 0.001217	 0.005363	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14319	 14320	 0.001873	 0.006249	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14319	 79741	 0.004182	 0.008595	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14320	 14322	 0.005962	 0.004673	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14320	 14331	 0.001826	 0.008291	 0.00018	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14321	 79741	 0.001162	 0.004538	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14323	 14328	 0.000503	 0.002307	 0.00059	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14323	 79741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14323	 79741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79741	 14324	 0.005992	 0.004742	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14325	 14327	 0.001107	 0.0054	 9e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14325	 79778	 0.001377	 0.005357	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14326	 14343	 5.3e-05	 0.000487	 0.00192	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14326	 14417	 0.000285	 0.002526	 0.0107	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14326	 79742	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79743	 14326	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14327	 79744	 0.001054	 0.005146	 0.00011	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14328	 14339	 0.000329	 0.001653	 0.00043	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14328	 79744	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14328	 79744	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14329	 14330	 0.001886	 0.003507	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79744	 14329	 0.001463	 0.004882	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14329	 79748	 0.003038	 0.007053	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14330	 14331	 0.001763	 0.004484	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14331	 14336	 0.003293	 0.006453	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14331	 79746	 0.001968	 0.006493	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14331	 79747	 0.000864	 0.005115	 0.0001	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14332	 14333	 0.000437	 0.001522	 0.00035	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14332	 79745	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14332	 79745	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14333	 14334	 0.00029	 0.001012	 0.00023	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14333	 79746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14333	 79746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14334	 14337	 0.000204	 0.001334	 0.00034	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14334	 79747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14334	 79747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79746	 14335	 0.00295	 0.006038	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14335	 79755	 0.002027	 0.007097	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14336	 14338	 0.001047	 0.003871	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14337	 14350	 0.000178	 0.001146	 0.0003	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14338	 79753	 0.001316	 0.007395	 0.00014	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14339	 79748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14339	 79748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14339	 79798	 0.000797	 0.004579	 0.0013	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79743	 14340	 0.000598	 0.004658	 9e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14340	 79751	 0.0007	 0.005458	 0.0001	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14341	 14344	 0.002307	 0.005356	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14341	 79749	 0.001645	 0.003059	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14342	 79749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14342	 79749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14342	 79756	 0.00057	 0.002768	 0.00063	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14343	 79750	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79751	 14343	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14343	 79797	 0.000148	 0.001413	 0.00516	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14344	 14346	 0.001905	 0.004511	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14345	 14347	 0.000337	 0.001218	 0.00026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79750	 14345	 0.000274	 0.00113	 0.00027	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14346	 14348	 0.001384	 0.004617	 7e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14347	 14349	 0.000337	 0.001157	 0.00028	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14347	 79752	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14347	 79752	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79752	 14348	 0.00186	 0.005336	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14348	 79792	 0.001063	 0.005316	 9e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14349	 14350	 0.000323	 0.001124	 0.00026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14350	 79753	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14350	 79753	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14350	 79798	 0.000224	 0.001981	 0.00053	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14351	 79754	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79755	 14351	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14351	 79797	 0.000104	 0.000732	 0.00125	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14351	 80121	 0.001489	 0.010257	 0.01811	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79755	 14352	 0.009459	 0.009554	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14352	 79799	 0.002608	 0.006911	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14353	 14444	 1e-05	 0.000123	 0.0084	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14353	 14454	 4.6e-05	 0.000854	 0.05641	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14353	 15397	 0.000119	 0.002119	 0.15037	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14353	 79756	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14354	 14398	 0.00221	 0.012565	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79749	 14354	 0.000765	 0.004092	 0.00012	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79757	 14354	 0.002731	 0.00911	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14355	 14451	 0.001708	 0.007053	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14355	 18128	 0.001005	 0.00391	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14355	 79758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14355	 79758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14356	 14453	 0.011224	 0.012345	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14356	 79796	 0.014331	 0.018835	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14357	 14358	 0.00157	 0.006109	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14357	 14364	 0.007797	 0.006417	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14357	 79796	 0.001951	 0.008381	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14358	 14398	 0.002731	 0.005002	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14358	 79759	 0.010499	 0.008309	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14359	 14363	 0.000306	 0.001189	 0.00032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14359	 14396	 0.000484	 0.001841	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14359	 79759	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14359	 79759	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14360	 14361	 0.001711	 0.003502	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14360	 79760	 0.012714	 0.009966	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14360	 79772	 0.001924	 0.004946	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14361	 79761	 0.001021	 0.005167	 9e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14362	 14386	 0.00067	 0.003301	 0.00089	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14362	 14409	 0.000863	 0.003654	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14362	 79760	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14362	 79760	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14363	 14365	 0.000194	 0.00089	 0.00023	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14363	 79761	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14363	 79761	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14364	 79762	 0.002367	 0.006019	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14365	 14379	 0.000857	 0.003368	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79756	 14365	 0.001517	 0.008623	 0.0025	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14365	 79762	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14365	 79762	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79762	 14366	 0.003489	 0.011639	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14367	 14432	 0.001442	 0.003811	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14367	 18126	 0.002026	 0.008112	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14368	 14371	 0.000689	 0.002759	 0.00069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14368	 14429	 0.000465	 0.002255	 0.00052	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14368	 79763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14368	 79763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14369	 79766	 0.012383	 0.009799	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14370	 14374	 0.002237	 0.005752	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14370	 14375	 0.001412	 0.002889	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14371	 14373	 0.000533	 0.002094	 0.00055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14371	 79764	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14371	 79764	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14372	 79765	 0.00161	 0.004618	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14372	 79795	 0.003428	 0.009087	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14373	 14377	 0.000473	 0.001859	 0.00049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14373	 79765	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14373	 79765	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14374	 14376	 0.001845	 0.004742	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79763	 14375	 0.003234	 0.008571	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79764	 14375	 0.012649	 0.009915	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14376	 14378	 0.01428	 0.010323	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14376	 15415	 0.004457	 0.021748	 0.00038	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14376	 79768	 0.004643	 0.011366	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14377	 14379	 0.000637	 0.002593	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14377	 79766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14377	 79766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14378	 14382	 0.002398	 0.006878	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79765	 14378	 0.001916	 0.005077	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79766	 14378	 0.01068	 0.006914	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14379	 14381	 0.001499	 0.004025	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14379	 79767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14379	 79767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14380	 14381	 0.000348	 0.002243	 0.00059	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14380	 15414	 0.000913	 0.003587	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14380	 15438	 0.001241	 0.003223	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14381	 14386	 0.000648	 0.00309	 0.0009	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14381	 79768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14381	 79768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79767	 14382	 0.002493	 0.005701	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14383	 14427	 0.009118	 0.007216	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14384	 14443	 0.000257	 0.001424	 0.00043	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14384	 15439	 0.000296	 0.002199	 0.00084	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14384	 79769	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14384	 79769	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14385	 14428	 0.00367	 0.009433	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79760	 14385	 0.00954	 0.009542	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14385	 79770	 0.003197	 0.010665	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14386	 79770	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14386	 79770	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14387	 14442	 0.000645	 0.002663	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14387	 79771	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14387	 79771	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14387	 79801	 0.002382	 0.007946	 0.00202	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14388	 14391	 0.015571	 0.01103	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14388	 14392	 0.003733	 0.007392	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79771	 14388	 0.002657	 0.00877	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14389	 14392	 0.006596	 0.00427	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14389	 14425	 0.01654	 0.013089	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14390	 14391	 0.009599	 0.007524	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14391	 14439	 0.002078	 0.005086	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14391	 15441	 0.01554	 0.011433	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14393	 14396	 0.000449	 0.001588	 0.00036	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14393	 14409	 0.000527	 0.001775	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14394	 79772	 0.00362	 0.007409	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14394	 79777	 0.003664	 0.005613	 8e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14395	 14397	 0.002753	 0.00639	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14395	 79772	 0.001886	 0.006222	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14395	 79774	 0.006794	 0.004564	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14395	 79775	 0.010637	 0.01774	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14396	 79772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14396	 79772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14397	 79773	 0.002251	 0.004361	 9e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14398	 79773	 0.000939	 0.005042	 0.00012	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14399	 79773	 0.002651	 0.003694	 6e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14400	 14401	 0.000417	 0.001302	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14400	 79773	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14400	 79773	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14401	 14402	 0.00025	 0.000858	 0.00021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14401	 79774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14401	 79774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14402	 14405	 0.000358	 0.001167	 0.00031	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14403	 14404	 8.6e-05	 0.001001	 0.00029	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79742	 14403	 8.6e-05	 0.001017	 0.00029	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14404	 14406	 0.000282	 0.002459	 0.00068	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14405	 14407	 0.000841	 0.002224	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14406	 14407	 0.000873	 0.002344	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14406	 79775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14406	 79775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14406	 79801	 0.001709	 0.005958	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14407	 79776	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14407	 79776	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14407	 79801	 0.001093	 0.003683	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79776	 14408	 0.004067	 0.00797	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14408	 79777	 0.001551	 0.004296	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14409	 79777	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14409	 79777	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14409	 79801	 0.000832	 0.004481	 0.00123	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14410	 15487	 0.002846	 0.010523	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14410	 79802	 0.00335	 0.013032	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79775	 14411	 0.004284	 0.00961	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14411	 79780	 0.008136	 0.007494	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79740	 14412	 0.017142	 0.013566	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14412	 79779	 0.008668	 0.006859	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14413	 14414	 0.000463	 0.001394	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14413	 79778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14413	 79778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14414	 14416	 0.000542	 0.001859	 0.00045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14414	 79779	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14414	 79779	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14415	 79780	 0.002243	 0.005944	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14415	 79782	 0.003804	 0.012689	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14416	 79780	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14416	 79780	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14417	 79781	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79782	 14417	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14417	 79800	 0.000297	 0.002156	 0.00434	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14417	 80187	 0.000559	 0.003812	 0.00686	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14417	 80199	 0.000966	 0.009858	 0.0313	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14418	 14420	 0.000653	 0.002179	 0.00055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14418	 14422	 0.001449	 0.005051	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14418	 79783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14418	 79783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14419	 14424	 0.001106	 0.002968	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79781	 14419	 0.001155	 0.003101	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79781	 14420	 0.001692	 0.004543	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14420	 79784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14420	 79784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79739	 14421	 0.001709	 0.009213	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14421	 79785	 0.00225	 0.007507	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14422	 14423	 0.000515	 0.00136	 0.00032	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14422	 15230	 0.001182	 0.004732	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14422	 79785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14422	 79785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14423	 14424	 0.000604	 0.001553	 0.00038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14423	 79786	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14423	 79786	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14424	 79787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14424	 79787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14425	 14426	 0.00685	 0.011378	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14425	 79802	 0.029346	 0.023003	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14426	 14428	 0.003904	 0.010036	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79771	 14427	 0.002911	 0.007482	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14429	 14430	 0.000287	 0.001442	 0.00038	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14430	 14431	 0.000172	 0.000841	 0.00023	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14431	 14436	 0.000243	 0.001063	 0.00037	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14432	 14435	 0.000614	 0.002597	 0.00058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14432	 14447	 0.000964	 0.003859	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14432	 79788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14432	 79788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79788	 14433	 0.002739	 0.006357	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14433	 79795	 0.00321	 0.009857	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79788	 14434	 0.014454	 0.01133	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14434	 79789	 0.006426	 0.011769	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14435	 14436	 0.000334	 0.001338	 0.00034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14435	 14452	 0.000568	 0.004016	 0.0011	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14436	 14452	 0.000678	 0.005079	 0.00124	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14436	 15407	 0.001007	 0.004159	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14436	 79789	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14436	 79789	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79770	 14437	 0.015844	 0.010643	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79769	 14438	 0.00419	 0.010655	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14438	 80174	 0.002108	 0.009235	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14439	 14441	 0.001993	 0.005268	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14440	 79790	 0.007484	 0.005923	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14441	 79790	 0.003119	 0.010406	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14442	 14443	 0.000283	 0.001602	 0.0004	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14442	 79790	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14442	 79790	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14444	 14450	 9e-06	 0.000141	 0.00906	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14444	 79791	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14445	 14448	 0.000684	 0.002306	 0.00057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79756	 14445	 0.000944	 0.00458	 0.00105	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14445	 79793	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14445	 79793	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14446	 79794	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14446	 79794	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14446	 80099	 0.001783	 0.004628	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14447	 79795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14447	 79795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14448	 79796	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14448	 79796	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79757	 14449	 0.003058	 0.018588	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79773	 14449	 0.001619	 0.009201	 0.00017	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14450	 18540	 0.000193	 0.005341	 0.40037	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14450	 79797	 9.9e-05	 0.007891	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79798	 14450	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 0	 -30.0	 30.0;
	79754	 14451	 0.000924	 0.00322	 0.00075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79798	 14451	 0.000772	 0.001792	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14451	 79799	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14451	 79799	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14452	 15403	 0.000498	 0.002766	 0.00084	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14452	 19298	 0.001816	 0.011162	 0.00322	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14452	 19312	 0.001059	 0.00682	 0.00179	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79793	 14453	 0.003892	 0.010006	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14454	 15486	 3.5e-05	 0.000486	 0.03676	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14454	 15525	 5.2e-05	 0.001425	 0.10675	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14454	 79800	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14455	 14456	 0.000679	 0.010087	 0.03739	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14455	 15612	 0.005176	 0.048479	 0.18412	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14455	 79803	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14455	 79803	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14456	 14462	 0.000385	 0.004682	 0.01516	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14456	 79804	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14456	 79804	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14457	 14458	 0.033441	 0.024174	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14458	 79805	 0.01187	 0.027557	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14459	 14460	 0.00128	 0.006059	 0.00146	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79804	 14459	 0.003054	 0.012228	 0.00308	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14459	 79805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14459	 79805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14460	 14461	 0.000624	 0.002864	 0.00073	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14461	 79806	 0.000553	 0.002424	 0.00083	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14462	 14465	 0.000159	 0.002033	 0.00794	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79485	 14462	 0.000322	 0.003656	 0.00803	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14462	 79806	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79807	 14462	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14463	 14464	 0.001426	 0.006948	 0.00013	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14463	 14469	 0.006859	 0.039021	 0.0012	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79805	 14463	 0.007512	 0.026299	 0.00073	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79807	 14463	 0.013778	 0.031653	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14464	 79808	 0.009306	 0.0529	 0.00096	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14465	 79809	 8.6e-05	 0.001072	 0.00437	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14466	 14475	 0.006256	 0.025046	 0.00631	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14466	 20200	 0.001201	 0.004888	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14467	 14468	 3e-05	 0.000357	 0.02675	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14467	 14472	 2.3e-05	 0.0006	 0.04941	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14467	 79808	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14467	 79808	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14468	 79809	 0.000433	 0.032442	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14468	 79809	 0.000433	 0.032442	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14469	 14470	 0.00855	 0.066642	 0.00125	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14470	 79810	 0.005302	 0.035882	 0.00104	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14471	 14472	 2.6e-05	 0.000682	 0.05618	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14471	 14982	 7.9e-05	 0.00208	 0.17134	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14472	 79810	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14472	 79810	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14473	 14474	 0.07404	 0.047935	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79808	 14473	 0.050547	 0.096804	 0.00152	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14474	 14476	 0.043226	 0.084716	 0.00127	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14475	 14477	 0.008881	 0.028968	 0.00769	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14475	 81803	 0.003818	 0.015286	 0.00385	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14476	 79811	 0.026158	 0.069149	 0.00126	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14477	 79811	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14477	 79811	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14478	 79813	 0.007643	 0.025223	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14478	 79817	 0.016134	 0.053822	 0.00085	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14479	 14482	 4.3e-05	 0.001111	 0.07604	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14479	 14491	 3e-05	 0.000525	 0.04608	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14479	 79812	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14480	 14506	 0.055624	 0.18358	 0.00297	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79813	 14480	 0.019896	 0.04619	 0.00069	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14481	 15346	 0.003628	 0.015356	 0.00346	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14481	 79814	 0.004058	 0.016247	 0.00409	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14482	 15374	 0.000231	 0.004271	 0.28205	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14482	 79814	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14482	 79814	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14483	 14580	 0.00777	 0.043724	 0.00094	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14483	 79831	 0.006709	 0.041244	 0.00074	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14484	 14485	 0.000682	 0.00361	 0.00091	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14484	 15344	 0.001494	 0.008753	 0.00238	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14485	 14486	 0.001507	 0.004537	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14485	 79815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14485	 79815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14486	 79816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14486	 79816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14487	 14488	 0.027542	 0.018501	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79816	 14487	 0.033156	 0.024394	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79815	 14488	 0.008651	 0.016955	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14489	 80136	 0.062276	 0.068497	 0.00091	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14490	 14496	 0.004274	 0.014897	 0.00345	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14490	 15431	 0.007139	 0.066476	 0.0206	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14490	 79817	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14490	 79817	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14490	 79825	 0.002536	 0.009968	 0.00261	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14491	 14501	 1e-05	 0.000228	 0.02052	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14491	 15534	 0.000391	 0.004661	 0.34979	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14492	 14499	 0.000584	 0.004693	 0.00132	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79812	 14492	 0.001146	 0.011003	 0.0032	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14492	 79818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14492	 79818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14493	 14497	 0.013562	 0.026851	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79818	 14493	 0.011365	 0.026913	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14494	 79819	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79820	 14494	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14494	 79824	 0.000129	 0.001305	 0.00296	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14494	 79824	 0.000129	 0.001305	 0.00296	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14494	 80256	 0.002291	 0.022829	 0.07621	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14495	 14522	 0.001121	 0.008588	 0.0023	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79819	 14495	 0.000869	 0.007101	 0.00193	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14496	 14500	 0.000201	 0.002897	 0.00092	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14496	 14503	 0.000375	 0.002812	 0.00069	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14496	 14523	 0.001117	 0.008369	 0.00204	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14496	 79821	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14496	 79821	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14497	 14498	 0.011032	 0.011143	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14497	 79822	 0.021088	 0.02297	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14499	 14500	 0.000148	 0.002172	 0.00066	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14499	 79822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14499	 79822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14499	 79823	 0.000486	 0.004824	 0.00131	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14501	 14502	 7e-06	 0.000156	 0.01555	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14501	 79823	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14501	 79823	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14502	 79824	 9.9e-05	 0.007891	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79825	 14502	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14503	 14523	 0.000796	 0.006396	 0.0018	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79825	 14503	 0.00025	 0.003196	 0.00095	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14504	 14505	 0.003114	 0.008477	 0.00187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79814	 14504	 0.006094	 0.016104	 0.00377	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14505	 14800	 0.004392	 0.025232	 0.00715	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14505	 15580	 0.009985	 0.03998	 0.01007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14506	 14797	 0.015204	 0.050718	 0.0008	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14506	 79926	 0.024883	 0.063966	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14507	 14798	 0.006303	 0.031667	 0.00824	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14507	 15357	 0.0041	 0.016685	 0.00407	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14508	 15327	 0.00203	 0.019336	 0.07066	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79478	 14508	 0.000189	 0.001371	 0.00276	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14508	 79826	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79827	 14508	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14509	 14511	 0.004362	 0.011212	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14509	 79828	 0.003412	 0.013127	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14510	 14514	 0.002999	 0.007927	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14510	 14521	 0.006512	 0.023017	 0.00519	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79826	 14510	 0.003814	 0.01008	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14510	 79828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14510	 79828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14511	 14513	 0.01851	 0.014649	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14511	 79848	 0.007801	 0.015964	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14512	 14513	 0.006685	 0.017184	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14512	 14570	 0.019252	 0.04949	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14512	 79839	 0.005604	 0.016481	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14512	 79847	 0.005647	 0.011556	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14513	 79829	 0.003711	 0.016351	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14514	 14515	 0.000923	 0.003592	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14514	 14517	 0.001743	 0.004745	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14514	 79829	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14514	 79829	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14515	 14518	 0.001363	 0.006254	 0.0016	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14516	 14517	 0.000677	 0.002281	 0.00057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14516	 14548	 0.001796	 0.007189	 0.00181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14516	 79830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14516	 79830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14517	 14547	 0.001397	 0.00479	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14518	 14520	 0.003435	 0.007974	 0.00243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14518	 14561	 0.002182	 0.009236	 0.00208	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79829	 14519	 0.013387	 0.027395	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14519	 79831	 0.009	 0.023136	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14520	 14521	 0.002113	 0.00725	 0.00174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14520	 79831	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14520	 79831	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14521	 14532	 0.001525	 0.005232	 0.00125	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79819	 14521	 0.003347	 0.021197	 0.00575	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14522	 14530	 0.000852	 0.006293	 0.00182	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14523	 14524	 0.000698	 0.005471	 0.0025	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14524	 14525	 0.000676	 0.006704	 0.00182	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14524	 14526	 0.001075	 0.005962	 0.00181	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14524	 15544	 0.00808	 0.032882	 0.00801	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79819	 14524	 0.002735	 0.018348	 0.00443	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14524	 79832	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14524	 79832	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14525	 15103	 0.004985	 0.04693	 0.01422	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14526	 14536	 0.002739	 0.016841	 0.00486	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14526	 79833	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14526	 79833	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79832	 14527	 0.012763	 0.029321	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79833	 14527	 0.006833	 0.010907	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14527	 79834	 0.012292	 0.020707	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14528	 14529	 0.000926	 0.005756	 0.00162	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14528	 14530	 0.000679	 0.004887	 0.0013	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14528	 79834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14528	 79834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79819	 14529	 0.001704	 0.012771	 0.00311	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14530	 14531	 0.00052	 0.003893	 0.00095	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14530	 14532	 0.001249	 0.008571	 0.0025	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14531	 14532	 0.000825	 0.005123	 0.00145	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14532	 14534	 0.001175	 0.008454	 0.00224	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14533	 14538	 0.018177	 0.035988	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14533	 79835	 0.015667	 0.032062	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14534	 14535	 0.00101	 0.005917	 0.00161	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14535	 14542	 0.001113	 0.004374	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79496	 14536	 0.008035	 0.028403	 0.0064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14536	 79835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14536	 79835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79497	 14537	 0.029719	 0.047437	 0.00109	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79834	 14537	 0.031372	 0.10466	 0.00166	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14538	 79836	 0.031545	 0.038455	 0.00062	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79497	 14539	 0.033033	 0.024303	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14540	 14541	 0.022259	 0.016091	 0.00024	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79497	 14540	 0.023009	 0.034117	 0.00051	 45.0	 45.0	 45.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14541	 79836	 0.008141	 0.016119	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14542	 14574	 0.005824	 0.018996	 0.00504	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79496	 14542	 0.005035	 0.013307	 0.00311	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14542	 79836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14542	 79836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14543	 79837	 0.00456	 0.024398	 0.00074	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14543	 79842	 0.009323	 0.029602	 0.00052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14543	 80041	 0.006498	 0.039491	 0.00073	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14544	 14577	 0.002594	 0.008738	 0.00217	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14544	 79837	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14544	 79837	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14545	 14555	 0.002938	 0.017602	 0.00042	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79837	 14545	 0.005252	 0.01752	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14545	 79838	 0.023023	 0.01822	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14546	 14549	 0.000933	 0.002248	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14546	 79838	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14546	 79838	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14547	 14572	 0.001983	 0.008186	 0.00194	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14547	 14577	 0.00228	 0.007089	 0.00148	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14547	 79839	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14547	 79839	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14548	 14549	 0.001326	 0.005213	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14548	 79840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14548	 79840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14549	 14551	 0.001451	 0.005809	 0.00146	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14550	 14551	 0.001889	 0.006585	 0.00153	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14550	 14556	 0.003406	 0.015886	 0.00393	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14550	 14561	 0.002243	 0.008728	 0.00233	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14550	 79841	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14550	 79841	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14551	 14554	 0.002716	 0.010676	 0.00279	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14552	 80041	 0.014372	 0.028456	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14553	 14554	 0.002887	 0.011559	 0.00291	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14553	 14578	 0.001628	 0.005586	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14553	 15095	 0.001628	 0.006626	 0.00161	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14553	 80040	 0.001823	 0.011921	 0.00303	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14554	 79842	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14554	 79842	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79842	 14555	 0.003047	 0.018733	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14556	 79843	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14556	 79843	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14556	 80200	 0.005598	 0.028126	 0.00732	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14557	 14560	 0.004663	 0.01814	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14557	 15340	 0.015525	 0.059482	 0.00168	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79841	 14557	 0.008903	 0.028269	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79815	 14558	 0.008747	 0.034026	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79843	 14558	 0.024493	 0.057999	 0.00106	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79841	 14559	 0.01821	 0.04631	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79841	 14560	 0.010731	 0.021247	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14562	 14563	 0.00078	 0.003065	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14562	 14566	 0.000783	 0.003706	 0.00089	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14562	 79844	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14562	 79844	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14563	 14794	 0.000927	 0.002331	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14563	 15774	 0.001048	 0.00326	 0.00068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14564	 14568	 0.017948	 0.019741	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14564	 79845	 0.004779	 0.012284	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14565	 14572	 0.002783	 0.013724	 0.00371	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14565	 79845	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14565	 79845	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14565	 80263	 0.003298	 0.010757	 0.00286	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14566	 14574	 0.000774	 0.005064	 0.00129	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14566	 80263	 0.001745	 0.007205	 0.0017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14567	 14711	 0.013347	 0.016567	 0.00036	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79845	 14567	 0.008411	 0.028057	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14569	 14572	 0.002005	 0.005911	 0.00138	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14569	 14581	 0.002761	 0.007298	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14569	 79846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14569	 79846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14570	 14571	 0.008207	 0.016084	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79845	 14570	 0.006626	 0.022102	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14570	 79849	 0.033715	 0.026681	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79846	 14571	 0.00875	 0.016027	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14571	 79847	 0.005897	 0.019672	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14572	 14573	 0.001083	 0.003775	 0.00088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14572	 79847	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14572	 79847	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79826	 14573	 0.003852	 0.013214	 0.00317	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14573	 79848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14573	 79848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79826	 14574	 0.002235	 0.01188	 0.00276	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14574	 79849	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14574	 79849	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79848	 14575	 0.008357	 0.014078	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14576	 14581	 0.00267	 0.007444	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14576	 15049	 0.002773	 0.007198	 0.00175	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14576	 79850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14576	 79850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14578	 79851	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14578	 79851	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14579	 14580	 0.027841	 0.0469	 0.00067	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79817	 14579	 0.012942	 0.032123	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79816	 14580	 0.005405	 0.030725	 0.00056	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14582	 14583	 0.013325	 0.009633	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14582	 14791	 0.007659	 0.015164	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14582	 79897	 0.016574	 0.013117	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14583	 14586	 0.0065	 0.008543	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14583	 15764	 0.008163	 0.012381	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14584	 14585	 0.001506	 0.005167	 0.00124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14584	 15766	 0.004872	 0.012648	 0.00307	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14585	 14591	 0.001597	 0.005479	 0.00131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14585	 14597	 0.001244	 0.004839	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14585	 79852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14585	 79852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14586	 79853	 0.004336	 0.00891	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14587	 14589	 0.000722	 0.002434	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14587	 79853	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14587	 79853	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14588	 14596	 0.004013	 0.00735	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14588	 15845	 0.01196	 0.010717	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79853	 14588	 0.002882	 0.008851	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14589	 14591	 0.000846	 0.002547	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14590	 79854	 0.003298	 0.00675	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14590	 79855	 0.011503	 0.02465	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14591	 79854	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14591	 79854	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14592	 14593	 0.000933	 0.003948	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14592	 14600	 0.0008	 0.003201	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14592	 79855	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14592	 79855	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14593	 14606	 0.004352	 0.011502	 0.00269	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14593	 79856	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14593	 79856	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14593	 80257	 0.00863	 0.023169	 0.00525	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14593	 80257	 0.00863	 0.023169	 0.00525	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14594	 14611	 0.006367	 0.013594	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14594	 15841	 0.008933	 0.014259	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79856	 14594	 0.004055	 0.012204	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14595	 14596	 0.003004	 0.005947	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79853	 14595	 0.005257	 0.010757	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79855	 14595	 0.010971	 0.011949	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14596	 15843	 0.003651	 0.012179	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14597	 15061	 0.001279	 0.00587	 0.0015	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14597	 79857	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14597	 79857	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14598	 14599	 0.00147	 0.005586	 0.00156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14598	 15062	 0.002118	 0.008482	 0.00214	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14598	 79858	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14598	 79858	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14599	 14600	 0.001132	 0.004531	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14599	 79859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14599	 79859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14601	 14602	 0.007036	 0.020179	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14601	 14614	 0.005077	 0.016936	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14601	 15060	 0.010785	 0.035979	 0.00057	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79859	 14601	 0.019895	 0.017828	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14602	 14614	 0.028657	 0.021084	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79856	 14602	 0.008323	 0.021396	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79859	 14602	 0.004068	 0.01985	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14603	 14789	 0.000942	 0.008222	 0.00226	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14603	 14831	 0.003496	 0.01574	 0.00419	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14603	 14834	 0.001561	 0.012298	 0.0036	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14604	 14617	 0.006923	 0.032558	 0.00061	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14604	 80029	 0.006314	 0.028137	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14605	 14615	 0.020382	 0.020586	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14605	 79861	 0.012809	 0.023112	 0.00033	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14605	 79862	 0.007194	 0.021154	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14606	 14616	 0.003378	 0.011771	 0.00273	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14606	 79860	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14606	 79860	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14607	 14612	 0.016983	 0.012495	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14607	 14624	 0.007753	 0.01535	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79860	 14607	 0.002449	 0.013762	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14608	 14624	 0.005034	 0.012939	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14608	 14627	 0.018012	 0.014254	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14608	 79861	 0.002818	 0.006673	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14609	 79861	 0.018918	 0.014971	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14610	 14623	 0.001465	 0.004935	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14610	 14628	 0.002633	 0.006112	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14610	 79861	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14610	 79861	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14611	 14612	 0.003768	 0.010693	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14611	 14626	 0.005013	 0.012887	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14612	 14613	 0.01456	 0.011522	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79856	 14612	 0.005943	 0.022293	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14614	 14615	 0.004393	 0.010754	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79860	 14615	 0.009922	 0.014458	 0.00033	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14616	 14619	 0.001218	 0.004875	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14616	 14621	 0.001602	 0.005497	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14616	 79862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14616	 79862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79862	 14617	 0.003396	 0.019303	 0.00035	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14617	 79933	 0.01972	 0.060496	 0.00164	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14618	 14619	 0.000442	 0.003124	 0.00086	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14618	 14789	 0.000393	 0.002871	 0.00074	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14619	 14620	 0.001343	 0.004746	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14620	 14622	 0.001464	 0.004932	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14621	 14623	 0.000987	 0.003384	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14622	 79863	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14622	 79863	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14624	 14625	 0.004126	 0.0101	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14625	 15837	 0.006472	 0.016637	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14626	 15838	 0.007983	 0.018533	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14626	 15839	 0.008173	 0.014372	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14627	 79864	 0.015301	 0.011061	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14628	 79864	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14628	 79864	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14628	 79865	 0.001109	 0.00288	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14629	 14857	 0.002378	 0.02337	 0.08017	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14629	 15694	 0.000858	 0.006883	 0.02317	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14629	 79865	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79866	 14629	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14629	 80256	 0.001777	 0.011854	 0.02234	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14630	 14637	 0.000886	 0.004066	 0.00104	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79865	 14630	 0.000759	 0.004809	 0.00131	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14630	 79867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14630	 79867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14631	 14637	 0.00096	 0.004542	 0.00109	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14631	 14762	 0.001131	 0.004526	 0.00153	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14631	 79868	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14631	 79868	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14632	 15826	 0.00577	 0.011807	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79868	 14632	 0.00637	 0.012612	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14633	 14634	 0.012212	 0.023933	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79866	 14633	 0.039025	 0.050787	 0.00071	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14633	 79869	 0.026123	 0.040018	 0.00056	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79863	 14634	 0.003133	 0.015295	 0.00032	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14635	 14636	 0.00736	 0.024553	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14635	 14656	 0.010243	 0.026547	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79867	 14636	 0.007519	 0.026862	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14638	 14639	 0.001345	 0.005553	 0.00131	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14638	 14790	 0.001382	 0.005376	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14639	 14641	 0.001212	 0.005131	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14640	 14641	 0.001892	 0.005308	 0.00137	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14640	 14646	 0.000791	 0.002666	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79865	 14641	 0.008018	 0.02119	 0.00496	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14641	 79869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14641	 79869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14642	 14645	 0.001489	 0.005851	 0.00153	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14642	 14647	 0.001431	 0.010207	 0.00316	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14642	 14649	 0.002137	 0.010536	 0.00285	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14643	 79870	 0.008203	 0.016241	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14644	 14645	 0.000584	 0.003736	 0.00126	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14644	 14648	 0.000911	 0.007758	 0.00194	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14644	 14850	 0.014203	 0.035704	 0.00925	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14645	 14646	 0.000998	 0.003527	 0.00079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14645	 79870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14645	 79870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14647	 14827	 0.002283	 0.018947	 0.00498	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14648	 14831	 0.002022	 0.015382	 0.00483	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14649	 14657	 0.001657	 0.008776	 0.00222	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14649	 79871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14649	 79871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14650	 14652	 0.003363	 0.020674	 0.00596	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14650	 14849	 0.002268	 0.013006	 0.00432	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14651	 14653	 0.003623	 0.022947	 0.00623	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14651	 14839	 0.004069	 0.02577	 0.00699	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14652	 14653	 0.005986	 0.025335	 0.0057	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14652	 14654	 0.004591	 0.018954	 0.00448	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14653	 15033	 0.00298	 0.025554	 0.00727	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14653	 79872	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14653	 79872	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14654	 14659	 0.004186	 0.014648	 0.00485	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14654	 14672	 0.002632	 0.012979	 0.00351	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14655	 79873	 0.083945	 0.05639	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14656	 14669	 0.007352	 0.028603	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14656	 79873	 0.017995	 0.041777	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14657	 14658	 0.001445	 0.007259	 0.00189	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14658	 14659	 0.001309	 0.006578	 0.00171	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14658	 79873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14658	 79873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14659	 14661	 0.001305	 0.006085	 0.00151	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79511	 14659	 0.011837	 0.053301	 0.01419	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14659	 79874	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14659	 79874	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14660	 14663	 0.000737	 0.002897	 0.00076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14660	 14665	 0.001702	 0.005954	 0.00197	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14660	 14673	 0.003677	 0.016005	 0.00456	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14661	 14664	 0.000793	 0.003174	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14662	 14666	 0.008536	 0.02817	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79874	 14662	 0.042865	 0.043769	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14662	 79875	 0.009702	 0.016343	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14663	 14664	 0.000686	 0.002745	 0.00069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14665	 79875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14665	 79875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79875	 14666	 0.002923	 0.013025	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14666	 79914	 0.002507	 0.014264	 0.00044	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14667	 14669	 0.004509	 0.015042	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14667	 14768	 0.011481	 0.022501	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14667	 79915	 0.004228	 0.016201	 0.00046	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14668	 14669	 0.007652	 0.019669	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14668	 14670	 0.038324	 0.030329	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79874	 14668	 0.021532	 0.042632	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14669	 14670	 0.003184	 0.017534	 0.0004	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79875	 14670	 0.002693	 0.014832	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14670	 79914	 0.008501	 0.024381	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79874	 14671	 0.012445	 0.024639	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14672	 14673	 0.007327	 0.018834	 0.00466	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14672	 15034	 0.00445	 0.018835	 0.00424	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14673	 15019	 0.004219	 0.025322	 0.00767	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14674	 14675	 0.000989	 0.008639	 0.00342	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14674	 14685	 0.00079	 0.008521	 0.00244	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14675	 14996	 0.001254	 0.012671	 0.00373	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14676	 14677	 0.001305	 0.012287	 0.00372	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14676	 15019	 0.001616	 0.013118	 0.00418	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14678	 14683	 0.000599	 0.007673	 0.00229	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14678	 14998	 0.000726	 0.010736	 0.0037	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14678	 79876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14678	 79876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14679	 14680	 0.000416	 0.004599	 0.00138	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14679	 14682	 0.000363	 0.004091	 0.00118	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14679	 79877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14679	 79877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14680	 14722	 0.000293	 0.003247	 0.00106	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14681	 14724	 0.001779	 0.013449	 0.00045	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14681	 79878	 0.001946	 0.01336	 0.00024	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14681	 79879	 0.011281	 0.034643	 0.00065	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14682	 14683	 0.00051	 0.005294	 0.00164	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14682	 79878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14682	 79878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14683	 79879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14683	 79879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14684	 14686	 0.001469	 0.005039	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14685	 14688	 0.000584	 0.005955	 0.00153	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14685	 79880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14685	 79880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14686	 14687	 0.00055	 0.003953	 0.00105	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14686	 14717	 0.000498	 0.00427	 0.00122	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14686	 79881	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14686	 79881	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14687	 14689	 0.000487	 0.003652	 0.00089	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14688	 14689	 0.000406	 0.0032	 0.00094	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14688	 79882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14688	 79882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14689	 79883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14689	 79883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14690	 14692	 0.000765	 0.002783	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14690	 14698	 0.001037	 0.00363	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14690	 79884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14690	 79884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14691	 14695	 6.7e-05	 0.000726	 0.00141	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14691	 14695	 6.7e-05	 0.000726	 0.00141	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14691	 79890	 6.5e-05	 0.000822	 0.00155	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14691	 79891	 0.000109	 0.001462	 0.00516	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14692	 14693	 0.00035	 0.001403	 0.00035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14693	 14694	 0.000285	 0.001141	 0.00029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14694	 79886	 0.000486	 0.00191	 0.0005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14695	 14696	 4.3e-05	 0.000484	 0.00089	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14695	 14696	 4.3e-05	 0.000484	 0.00089	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14695	 79885	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14695	 79885	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14696	 14757	 0.000105	 0.001175	 0.00215	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14696	 14757	 0.000105	 0.001175	 0.00215	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14696	 79886	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14696	 79886	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14697	 14698	 0.00065	 0.002601	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14697	 15790	 0.000872	 0.003491	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14698	 14699	 0.000468	 0.002649	 0.00066	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14698	 14755	 0.000368	 0.003595	 0.00101	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14699	 14701	 0.000477	 0.002567	 0.00071	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14699	 79887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14699	 79887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14700	 15791	 0.003648	 0.012168	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79887	 14700	 0.004017	 0.009325	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14700	 79888	 0.018544	 0.014676	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14701	 14702	 0.000522	 0.001899	 0.00058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14701	 79888	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14701	 79888	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14702	 14703	 0.000328	 0.001388	 0.00031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14703	 14704	 0.000736	 0.002862	 0.00076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14703	 80272	 0.000638	 0.004515	 0.00124	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14704	 79889	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14704	 79889	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79498	 14705	 0.016654	 0.016821	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79889	 14705	 0.011793	 0.009333	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14706	 14707	 1.6e-05	 0.00019	 0.01424	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14706	 14749	 9.8e-05	 0.002008	 0.23566	 3627.0	 3808.3	 3989.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14706	 15792	 2.2e-05	 0.000539	 0.05449	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14706	 79890	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14706	 79890	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14707	 79891	 0.000104	 0.008342	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79892	 14707	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14708	 14709	 0.000681	 0.001899	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14708	 14795	 0.003183	 0.008413	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14708	 79893	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14708	 79893	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14709	 14794	 0.000837	 0.002279	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14709	 79894	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14709	 79894	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14710	 14711	 0.010697	 0.01406	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14710	 79895	 0.028229	 0.02234	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79893	 14711	 0.008086	 0.011478	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14712	 14713	 0.001982	 0.008181	 0.00194	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14712	 79895	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14712	 79895	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14712	 80257	 0.004616	 0.012871	 0.0027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14713	 14795	 0.001958	 0.005863	 0.00132	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14713	 15049	 0.00101	 0.006276	 0.00177	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14713	 79896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14713	 79896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14714	 14715	 0.002373	 0.011585	 0.00024	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79896	 14714	 0.002068	 0.012982	 0.00028	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14715	 14791	 0.015388	 0.01443	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79895	 14715	 0.010642	 0.019008	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14715	 79897	 0.004533	 0.011654	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14715	 80260	 0.036944	 0.02799	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14716	 15766	 0.001597	 0.004147	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14716	 79897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14716	 79897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14717	 14785	 0.000238	 0.002429	 0.00063	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14718	 14719	 0.002103	 0.011835	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14718	 79900	 0.023873	 0.024112	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14718	 80277	 0.002094	 0.012873	 0.00023	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79881	 14719	 0.00182	 0.010241	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14720	 14721	 0.000289	 0.003117	 0.00089	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14720	 15778	 0.000258	 0.002948	 0.0009	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14721	 14725	 0.000265	 0.002858	 0.00082	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14722	 14725	 0.000395	 0.004102	 0.00127	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14722	 79898	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14722	 79898	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14723	 14726	 0.000648	 0.00434	 0.00133	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14723	 14741	 0.000683	 0.004584	 0.00111	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14723	 79899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14723	 79899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14724	 14742	 0.006238	 0.024266	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14724	 14742	 0.006238	 0.024266	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14725	 79900	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14725	 79900	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14726	 14727	 0.00133	 0.005629	 0.00127	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14726	 14728	 0.000565	 0.002669	 0.00085	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14727	 15779	 0.000927	 0.00371	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14728	 14730	 0.000801	 0.004168	 0.00123	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14729	 15788	 0.005048	 0.015192	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14729	 79901	 0.007087	 0.018217	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14730	 14731	 0.000999	 0.004449	 0.00121	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14730	 14755	 0.000522	 0.005097	 0.00143	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14730	 15789	 0.003024	 0.012484	 0.00295	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14730	 79901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14730	 79901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14731	 14732	 0.000674	 0.003035	 0.00081	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14732	 14734	 0.000789	 0.002999	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14733	 79902	 0.019734	 0.015468	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14734	 79902	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14734	 79902	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14734	 79904	 0.000973	 0.004119	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79902	 14735	 0.003432	 0.011449	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14735	 79903	 0.003342	 0.006551	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14736	 14737	 0.000178	 0.001372	 0.00279	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14736	 14740	 0.000106	 0.001146	 0.00227	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14736	 14740	 0.000106	 0.001146	 0.00227	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14736	 14746	 0.000146	 0.00207	 0.0106	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14736	 79903	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14736	 79903	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14737	 15699	 0.00108	 0.010285	 0.03758	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14737	 79904	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79905	 14737	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14738	 14739	 0.043847	 0.0347	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79903	 14738	 0.009634	 0.020645	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14740	 14756	 0.000232	 0.002532	 0.00491	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14740	 14756	 0.000232	 0.002532	 0.00491	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14741	 79906	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14741	 79906	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14741	 79907	 0.003373	 0.011001	 0.00292	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14742	 14743	 0.002376	 0.008488	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79899	 14742	 0.00735	 0.022572	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79906	 14742	 0.001807	 0.008672	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14743	 14744	 0.004721	 0.012136	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14744	 79908	 0.004979	 0.018679	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14744	 79909	 0.009508	 0.019458	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79904	 14745	 0.000651	 0.002608	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14745	 79907	 0.001004	 0.00402	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14746	 79907	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79908	 14746	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14746	 80010	 0.001141	 0.012173	 0.02475	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14746	 80010	 0.001141	 0.012173	 0.02475	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14747	 14748	 0.001102	 0.007097	 0.00186	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79907	 14747	 0.0018	 0.007833	 0.00223	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14747	 79909	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14747	 79909	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14748	 79911	 0.00133	 0.008425	 0.00229	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14749	 15000	 4.1e-05	 0.001114	 0.09346	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14749	 15000	 4.1e-05	 0.001114	 0.09346	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 0	 -30.0	 30.0;
	14749	 15792	 9.7e-05	 0.002621	 0.21993	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14749	 79910	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14749	 79910	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79911	 14749	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79491	 14750	 0.011015	 0.020175	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79491	 14751	 0.0203	 0.013142	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79908	 14751	 0.028441	 0.034046	 0.00057	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14752	 14754	 0.025181	 0.027696	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14753	 14754	 0.022499	 0.016553	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14754	 79924	 0.006491	 0.021652	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14755	 79912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14755	 79912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14756	 14757	 8.9e-05	 0.000979	 0.00186	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14756	 14757	 8.9e-05	 0.000979	 0.00186	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14756	 79913	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14756	 79913	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14758	 14761	 0.007191	 0.023731	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14758	 79921	 0.011245	 0.026104	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14758	 80023	 0.051378	 0.16956	 0.00275	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14759	 79914	 0.009749	 0.010619	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14760	 14769	 0.000949	 0.002661	 0.00068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14760	 79914	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14760	 79914	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14760	 80239	 0.003977	 0.025189	 0.00684	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14761	 79920	 0.00189	 0.009619	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14761	 79921	 0.017152	 0.015475	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14762	 14763	 0.001104	 0.003861	 0.00128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14762	 79915	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14762	 79915	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14763	 14767	 0.001126	 0.004509	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14763	 79916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14763	 79916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14764	 15814	 0.007897	 0.012097	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14764	 79917	 0.00379	 0.006941	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14765	 14770	 0.001007	 0.004262	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14765	 15823	 0.001342	 0.005102	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14765	 79917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14765	 79917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79917	 14766	 0.014873	 0.009629	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14767	 14769	 0.000679	 0.002472	 0.00076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14767	 79918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14767	 79918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79914	 14768	 0.017756	 0.014052	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14769	 14771	 0.001024	 0.0041	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14770	 79919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14770	 79919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14771	 14774	 0.001093	 0.004375	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14771	 79920	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14771	 79920	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14772	 14773	 0.002506	 0.005818	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14772	 14776	 0.00349	 0.011516	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79919	 14772	 0.012031	 0.011283	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14773	 15814	 0.011879	 0.009401	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14773	 80278	 0.003875	 0.014538	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14774	 14780	 0.000794	 0.003177	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14774	 79921	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14774	 79921	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79921	 14775	 0.006426	 0.006863	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14776	 79922	 0.006225	 0.0122	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14777	 14779	 0.000669	 0.003245	 0.00074	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14777	 15813	 0.000846	 0.004172	 0.00113	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14777	 79922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14777	 79922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79922	 14778	 0.001567	 0.008806	 0.00016	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14778	 79923	 0.001528	 0.007093	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14779	 14783	 0.000614	 0.002978	 0.00068	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14780	 14781	 0.00102	 0.004082	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14780	 14783	 0.000593	 0.002148	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14781	 14792	 0.001113	 0.004711	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14782	 14785	 0.000757	 0.003031	 0.00076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14782	 14787	 0.001267	 0.004816	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14783	 14784	 0.000499	 0.001959	 0.00051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14784	 14785	 0.000392	 0.001933	 0.00052	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14784	 14786	 0.000836	 0.003403	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14785	 15805	 0.000599	 0.004858	 0.00155	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14786	 79923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14786	 79923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14787	 14792	 0.000929	 0.00378	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79899	 14788	 0.013036	 0.036992	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79902	 14788	 0.006253	 0.018822	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79905	 14788	 0.007314	 0.014481	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14789	 14790	 0.000866	 0.003467	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79852	 14791	 0.010116	 0.026812	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14793	 79924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14793	 79924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14796	 14797	 0.052671	 0.038752	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14796	 15368	 0.086447	 0.068414	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14797	 79925	 0.026117	 0.053446	 0.00132	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14798	 79925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14798	 79925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14798	 79927	 0.00224	 0.017458	 0.00522	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14799	 14801	 0.001725	 0.00678	 0.00177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14799	 79927	 0.003713	 0.01831	 0.00495	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14800	 14801	 0.002449	 0.009804	 0.00247	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14800	 14806	 0.012199	 0.04185	 0.01003	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14800	 79926	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14800	 79926	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14802	 14803	 0.06283	 0.049723	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79925	 14802	 0.12578	 0.10353	 0.0021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14802	 79928	 0.029649	 0.052959	 0.00078	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14803	 79928	 0.051971	 0.052493	 0.0007	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79479	 14804	 0.0004	 0.005941	 0.02202	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14804	 79927	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14804	 79927	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14804	 80199	 0.004453	 0.033372	 0.12927	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14805	 14807	 0.000463	 0.003766	 0.01234	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79479	 14805	 0.000442	 0.003547	 0.01194	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79482	 14805	 0.002559	 0.02394	 0.09077	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79824	 14805	 0.003504	 0.033391	 0.1221	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14806	 14809	 0.00667	 0.021756	 0.00578	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79480	 14806	 0.003403	 0.024071	 0.00661	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14806	 79928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14806	 79928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14807	 14808	 0.000427	 0.006734	 0.01412	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79476	 14808	 0.0004	 0.005737	 0.02282	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14808	 79929	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79930	 14808	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79929	 14809	 0.003881	 0.013314	 0.00319	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79502	 14810	 0.017506	 0.04452	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14810	 79931	 0.025946	 0.043708	 0.00062	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79477	 14811	 0.002133	 0.008538	 0.00215	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14811	 79931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14811	 79931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14812	 15558	 0.016894	 0.075282	 0.00128	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79502	 14812	 0.012728	 0.040985	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79502	 14813	 0.016483	 0.02525	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14814	 14815	 0.02622	 0.093671	 0.00186	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14814	 15538	 0.075783	 0.11494	 0.00165	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14815	 14816	 0.01413	 0.068954	 0.00119	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14816	 14817	 0.025682	 0.085675	 0.00136	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14816	 14819	 0.037892	 0.10753	 0.00169	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14816	 15541	 0.086821	 0.092721	 0.00196	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14817	 14819	 0.028051	 0.065124	 0.00097	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14817	 15572	 0.020067	 0.096824	 0.00171	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14818	 14819	 0.018444	 0.047413	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14819	 14820	 0.031656	 0.10052	 0.00176	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14819	 15541	 0.070669	 0.20271	 0.00312	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14819	 79932	 0.026127	 0.17936	 0.00327	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14820	 79932	 0.035353	 0.09088	 0.00141	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14821	 79972	 0.15724	 0.11368	 0.00172	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14822	 14911	 0.006003	 0.027029	 0.00719	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14822	 79932	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14822	 79932	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14823	 14824	 0.002776	 0.01091	 0.00285	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14823	 14825	 0.007286	 0.017557	 0.00496	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14824	 14840	 0.006029	 0.03819	 0.01037	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14824	 14852	 0.021	 0.070769	 0.01759	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14824	 14972	 0.004041	 0.027074	 0.00829	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14825	 14840	 0.003274	 0.016735	 0.00456	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14825	 14855	 0.003907	 0.018493	 0.00445	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14826	 79935	 0.031456	 0.079999	 0.00127	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14827	 14828	 0.002421	 0.009514	 0.00249	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14827	 79937	 0.005733	 0.019125	 0.00485	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14828	 14829	 0.002433	 0.00974	 0.00245	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14829	 14851	 0.005802	 0.023608	 0.00575	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14830	 14831	 0.001683	 0.007006	 0.00218	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14830	 14835	 0.001648	 0.008125	 0.0022	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14831	 14859	 0.003833	 0.027996	 0.0072	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14832	 14833	 0.000519	 0.003832	 0.00111	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14832	 14835	 0.000539	 0.004701	 0.00129	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14833	 14834	 0.000768	 0.005524	 0.00146	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14834	 79933	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14834	 79933	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14835	 14836	 0.001199	 0.007025	 0.00191	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14835	 14860	 0.000817	 0.007006	 0.00199	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14836	 14859	 0.004041	 0.016683	 0.00395	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14836	 15065	 0.002672	 0.014906	 0.00381	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14837	 14839	 0.002891	 0.016611	 0.00471	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14837	 14841	 0.003809	 0.01729	 0.006	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14838	 14848	 0.02225	 0.058973	 0.0015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14838	 79936	 0.01325	 0.047334	 0.00094	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14838	 79942	 0.032868	 0.059305	 0.00086	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14839	 79934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14839	 79934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14840	 14841	 0.00124	 0.008848	 0.00274	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14840	 79935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14840	 79935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14840	 79937	 0.004267	 0.017084	 0.0043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14841	 79936	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14841	 79936	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14842	 79937	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79938	 14842	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14842	 79998	 0.003401	 0.035278	 0.07602	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14842	 79998	 0.003401	 0.035278	 0.07602	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14843	 14846	 0.0013	 0.006307	 0.00144	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14843	 14854	 0.002965	 0.016343	 0.00382	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14843	 79939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14843	 79939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14844	 14845	 0.008277	 0.02026	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79939	 14844	 0.010003	 0.023687	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79935	 14845	 0.017999	 0.035636	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79936	 14845	 0.017368	 0.046034	 0.00117	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79938	 14845	 0.068061	 0.066594	 0.00094	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79937	 14846	 0.002247	 0.010116	 0.00269	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14846	 79940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14846	 79940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14847	 14858	 0.027304	 0.090106	 0.00146	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79939	 14847	 0.048531	 0.036769	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79940	 14847	 0.012087	 0.027418	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14848	 79941	 0.018598	 0.047809	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14849	 14850	 0.001407	 0.010275	 0.00264	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14849	 79941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14849	 79941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79937	 14850	 0.001855	 0.015602	 0.00462	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14850	 79942	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14850	 79942	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14851	 14854	 0.00526	 0.017155	 0.00455	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14851	 79944	 0.004317	 0.025908	 0.00785	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14852	 14859	 0.002354	 0.014908	 0.00405	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14852	 15067	 0.008796	 0.030655	 0.00711	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14852	 79944	 0.001437	 0.014036	 0.00394	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14853	 14855	 0.003204	 0.018405	 0.00521	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14853	 14972	 0.003184	 0.016876	 0.00563	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14854	 14855	 0.004756	 0.019636	 0.00465	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14855	 14919	 0.010846	 0.049761	 0.01275	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14855	 79943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14855	 79943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14856	 14857	 0.000111	 0.001762	 0.0071	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14856	 14948	 0.001186	 0.011568	 0.04028	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14856	 79944	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14856	 79944	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14857	 79945	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14857	 79945	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14858	 79946	 0.028319	 0.064236	 0.00128	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14859	 14860	 0.001095	 0.009213	 0.00273	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79945	 14859	 0.002415	 0.015298	 0.00415	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14859	 79946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14859	 79946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14859	 79999	 0.008166	 0.070047	 0.01994	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14861	 14862	 0.003421	 0.029136	 0.00727	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14861	 15100	 0.005145	 0.040542	 0.01186	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14862	 79947	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14862	 79947	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14863	 14865	 0.000138	 0.00156	 0.00676	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77612	 14863	 0.002099	 0.019992	 0.07306	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14863	 79948	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79949	 14863	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14864	 14865	 0.000249	 0.002947	 0.01003	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14864	 14870	 0.00073	 0.007925	 0.01555	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14864	 14870	 0.00073	 0.007925	 0.01555	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79686	 14864	 0.001329	 0.020337	 0.07104	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14864	 79950	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79951	 14864	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14865	 79952	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79953	 14865	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79707	 14866	 0.01376	 0.03647	 0.00092	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79949	 14866	 0.00317	 0.028317	 0.00067	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79953	 14866	 0.014559	 0.054614	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79953	 14866	 0.014559	 0.054614	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79948	 14867	 0.00111	 0.007028	 0.00191	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79951	 14868	 0.023324	 0.037229	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79950	 14869	 0.00136	 0.01676	 0.00541	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14869	 79954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14869	 79954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14870	 79957	 0.00075	 0.008093	 0.01606	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14870	 79957	 0.00075	 0.008093	 0.01606	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14871	 14872	 0.011687	 0.066434	 0.0012	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79951	 14871	 0.019908	 0.061072	 0.00165	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79953	 14871	 0.009227	 0.052451	 0.00095	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79947	 14872	 0.030973	 0.095121	 0.00178	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14872	 79956	 0.011018	 0.10136	 0.00201	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14873	 79955	 0.024908	 0.045622	 0.00079	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14874	 14876	 0.001721	 0.012116	 0.00689	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79952	 14874	 0.001495	 0.025618	 0.00736	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14874	 79955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14874	 79955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14875	 15042	 0.004581	 0.016666	 0.0051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14875	 79958	 0.004626	 0.020614	 0.0056	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14876	 15039	 0.000677	 0.010666	 0.00364	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14876	 79956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14876	 79956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14877	 79959	 0.028116	 0.04387	 0.00073	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14878	 79957	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79493	 14879	 0.002343	 0.020463	 0.00051	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79959	 14879	 0.019937	 0.061162	 0.00166	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79959	 14879	 0.019937	 0.061162	 0.00166	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14879	 80025	 0.035959	 0.083485	 0.00124	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14880	 14883	 4.9e-05	 0.001156	 0.09357	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14880	 15386	 2.8e-05	 0.000661	 0.05352	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14881	 14887	 0.002889	 0.013255	 0.0034	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14881	 14893	 0.002319	 0.010637	 0.00272	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14881	 79961	 0.00165	 0.012996	 0.0038	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14881	 80152	 0.00549	 0.034114	 0.00963	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14882	 14883	 2.2e-05	 0.000369	 0.03591	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14882	 79960	 0.00209	 0.091976	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14882	 79960	 0.00209	 0.091976	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14883	 79961	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14883	 79961	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79960	 14884	 0.065137	 0.047924	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14885	 14886	 0.003879	 0.02136	 0.00771	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14885	 18790	 0.006854	 0.042143	 0.01216	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14886	 14887	 0.003282	 0.016699	 0.00605	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14887	 14893	 0.003167	 0.021243	 0.00513	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14887	 79962	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14887	 79962	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14888	 14889	 0.004874	 0.01253	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14888	 79971	 0.016698	 0.042923	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14889	 14890	 0.043415	 0.028107	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14889	 80151	 0.064317	 0.10267	 0.00236	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14890	 79964	 0.019231	 0.038075	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14891	 14892	 0.024423	 0.019328	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14891	 79971	 0.014028	 0.025214	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14892	 79965	 0.053535	 0.042367	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14893	 14894	 0.002384	 0.011756	 0.00318	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14893	 14902	 0.007957	 0.020454	 0.00507	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14894	 14909	 0.003035	 0.010412	 0.00249	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14894	 15391	 0.001587	 0.010053	 0.00273	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14895	 14896	 4.2e-05	 0.000498	 0.03737	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14895	 14903	 0.000126	 0.002339	 0.15445	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14895	 15386	 0.000195	 0.002437	 0.16701	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14896	 79963	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14896	 79963	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14897	 14901	 0.001344	 0.004383	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79963	 14897	 0.004243	 0.011551	 0.00254	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14897	 79964	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14897	 79964	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14898	 14901	 0.001002	 0.005498	 0.00145	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14898	 79965	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14898	 79965	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14898	 79967	 0.002898	 0.015358	 0.00513	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14899	 14907	 0.094855	 0.068572	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79965	 14899	 0.064555	 0.041794	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14899	 79968	 0.021818	 0.053404	 0.00091	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79964	 14900	 0.030906	 0.024459	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14900	 79966	 0.015315	 0.015045	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79963	 14901	 0.004429	 0.011132	 0.00288	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14901	 79966	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14901	 79966	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14901	 79967	 0.003433	 0.020107	 0.00548	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14901	 80155	 0.010519	 0.052854	 0.01376	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14902	 14904	 0.006234	 0.020332	 0.0054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14902	 79967	 0.002945	 0.010408	 0.00235	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14903	 79967	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79483	 14904	 0.008684	 0.02979	 0.00714	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79483	 14905	 0.005512	 0.014797	 0.00335	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14905	 79969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14905	 79969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14906	 14907	 0.025275	 0.077618	 0.00146	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79484	 14906	 0.071879	 0.1292	 0.00232	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79969	 14906	 0.045737	 0.093601	 0.0023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14907	 79970	 0.034501	 0.088689	 0.00137	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79480	 14908	 0.004941	 0.017977	 0.0055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79963	 14908	 0.006022	 0.024112	 0.00607	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14908	 79970	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14908	 79970	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14909	 15391	 0.006262	 0.018463	 0.00429	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79967	 14909	 0.004739	 0.018625	 0.00487	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14909	 79971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14909	 79971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14910	 14912	 0.007799	 0.033011	 0.00743	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14911	 79972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14911	 79972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14911	 79973	 0.007585	 0.047135	 0.0133	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14912	 79973	 0.003187	 0.026046	 0.00707	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14913	 14915	 4.4e-05	 0.000554	 0.03793	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14913	 79973	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14913	 79973	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14914	 79975	 0.033255	 0.021529	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14915	 79974	 0.000111	 0.008848	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14916	 15580	 0.011608	 0.046458	 0.0157	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79477	 14916	 0.008	 0.050674	 0.01376	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79973	 14916	 0.012211	 0.049696	 0.01211	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14916	 79976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14916	 79976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14917	 14918	 0.017166	 0.043154	 0.01118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14917	 79977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14917	 79977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14918	 15632	 0.022118	 0.053308	 0.01505	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14919	 79978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14919	 79978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14919	 79999	 0.004382	 0.019074	 0.00543	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14920	 14921	 0.005997	 0.005374	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14920	 14927	 0.00635	 0.012572	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14921	 14922	 0.008101	 0.008823	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14921	 80000	 0.011883	 0.023527	 0.00035	 44.0	 44.0	 44.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14922	 14927	 0.006144	 0.012165	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14922	 14970	 0.015181	 0.010974	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14923	 14926	 0.014987	 0.015137	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14923	 79979	 0.008659	 0.02202	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14924	 14927	 0.015916	 0.017505	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14924	 79979	 0.01273	 0.016567	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14924	 79980	 0.005812	 0.019388	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14924	 79983	 0.023907	 0.049131	 0.00094	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14925	 79979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14925	 79979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14925	 79982	 0.004436	 0.01191	 0.0027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14927	 79980	 0.002826	 0.014296	 0.00025	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14928	 14941	 0.11195	 0.092147	 0.00187	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14928	 79981	 0.010965	 0.027886	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14929	 14937	 0.00142	 0.005582	 0.00146	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14929	 79980	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14929	 79980	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79980	 14930	 0.002189	 0.011071	 0.00019	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14930	 79981	 0.005205	 0.017362	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14931	 14976	 0.007937	 0.038296	 0.00068	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14931	 79981	 0.003336	 0.020508	 0.00037	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14932	 79981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14932	 79981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14932	 79999	 0.001936	 0.006749	 0.00156	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14933	 14934	 0.014674	 0.011502	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14934	 79983	 0.020164	 0.026241	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14935	 14950	 4e-05	 0.000714	 0.05067	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14935	 14958	 8.8e-05	 0.001504	 0.11708	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14935	 14975	 2.6e-05	 0.000471	 0.03925	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14935	 19931	 0.000278	 0.007682	 0.57623	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14935	 79982	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79979	 14936	 0.034664	 0.033493	 0.00049	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14936	 79993	 0.045368	 0.097224	 0.0017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14937	 14938	 0.001063	 0.004498	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14938	 14939	 0.001565	 0.006265	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14939	 14962	 0.003497	 0.014439	 0.00342	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14939	 14964	 0.002548	 0.008741	 0.00209	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14939	 79984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14939	 79984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79984	 14940	 0.080567	 0.06376	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14942	 14944	 0.024004	 0.068847	 0.00106	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79943	 14942	 0.019712	 0.056537	 0.00087	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14943	 14976	 0.01273	 0.029554	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14943	 14979	 0.022451	 0.044451	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14943	 79985	 0.025386	 0.072812	 0.00112	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14944	 79985	 0.026977	 0.085659	 0.0015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14945	 14946	 0.001771	 0.014229	 0.004	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14945	 79985	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14945	 79985	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14945	 79986	 0.001879	 0.017095	 0.00432	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79944	 14946	 0.001769	 0.012514	 0.00343	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79985	 14947	 0.010774	 0.033086	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14947	 79987	 0.013209	 0.029962	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14947	 80000	 0.011266	 0.054076	 0.00162	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14948	 79986	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79987	 14948	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14948	 79998	 0.0002	 0.002681	 0.00946	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14949	 14951	 0.001645	 0.011463	 0.00431	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14949	 14952	 0.002486	 0.016252	 0.00413	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14949	 79988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14949	 79988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14949	 79989	 0.003386	 0.023951	 0.00657	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14950	 79989	 0.000154	 0.012356	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79944	 14951	 0.001167	 0.009686	 0.00255	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14952	 14953	 0.001397	 0.006288	 0.00167	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14952	 15108	 0.002151	 0.011936	 0.00363	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79989	 14952	 0.006069	 0.023611	 0.00631	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14952	 80049	 0.009198	 0.036829	 0.00928	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14953	 14956	 0.002349	 0.013758	 0.00375	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14954	 79993	 0.07922	 0.062694	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79990	 14955	 0.068763	 0.054419	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14955	 79991	 0.01573	 0.011573	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79989	 14956	 0.000924	 0.00979	 0.00291	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14956	 79991	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14956	 79991	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14956	 79992	 0.001551	 0.021926	 0.00726	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79982	 14957	 0.003316	 0.008902	 0.00202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14957	 79992	 0.00471	 0.019934	 0.00449	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14957	 79999	 0.003634	 0.016669	 0.00427	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14958	 79992	 0.000154	 0.012356	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14959	 14961	 0.001716	 0.011512	 0.00278	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79992	 14959	 0.001492	 0.009756	 0.00248	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14960	 14963	 0.004269	 0.014645	 0.00351	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14960	 79994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14960	 79994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14960	 80001	 0.004635	 0.019135	 0.00453	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14961	 14978	 0.002269	 0.014098	 0.00398	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14962	 14974	 0.002213	 0.008859	 0.00223	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14962	 79995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14962	 79995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14963	 14964	 0.002207	 0.007436	 0.00185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	14965	 14968	 0.026984	 0.10382	 0.00177	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14965	 79996	 0.015925	 0.061952	 0.00103	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14965	 80219	 0.086608	 0.088438	 0.00138	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14966	 14974	 0.004619	 0.018492	 0.00466	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14966	 15596	 0.017409	 0.043765	 0.01134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14966	 15611	 0.003668	 0.01843	 0.0048	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14966	 79996	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14966	 79996	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14967	 14969	 0.00163	 0.013976	 0.00398	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14967	 15609	 0.003097	 0.023329	 0.00647	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79978	 14968	 0.061928	 0.14378	 0.00214	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14968	 79997	 0.007155	 0.031526	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14969	 14972	 0.001915	 0.015652	 0.00425	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14969	 79997	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14969	 79997	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79979	 14970	 0.011118	 0.017029	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	14971	 14972	 0.003345	 0.015833	 0.00381	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14971	 15609	 0.006721	 0.04835	 0.01281	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79978	 14973	 0.084454	 0.084704	 0.00137	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14975	 79998	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14975	 79998	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79978	 14976	 0.008445	 0.026816	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14977	 15612	 0.000544	 0.006844	 0.02395	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79487	 14977	 0.001417	 0.01412	 0.04712	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14977	 80001	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14977	 80001	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80001	 14978	 0.001495	 0.008296	 0.00252	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14978	 81286	 0.003386	 0.013557	 0.00342	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79987	 14979	 0.008354	 0.021246	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14980	 14981	 0.000131	 0.002417	 0.15962	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14980	 14984	 0.000146	 0.002348	 0.16483	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14980	 20279	 0.000124	 0.003265	 0.269	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14981	 14982	 6.6e-05	 0.00188	 0.13077	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14981	 14984	 0.000215	 0.002571	 0.19286	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14983	 14984	 0.000103	 0.001752	 0.13639	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14983	 14985	 0.00016	 0.002965	 0.19581	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	14983	 20206	 4.9e-05	 0.001396	 0.09711	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14984	 80002	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14984	 80002	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14985	 14986	 8.2e-05	 0.002221	 0.15313	 2893.0	 3037.6	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14985	 20282	 0.000174	 0.002332	 0.15975	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	14985	 80003	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80004	 14985	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14986	 80005	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14986	 80005	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14987	 14991	 0.001517	 0.007232	 0.00209	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14987	 15002	 0.002413	 0.008778	 0.00269	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14987	 15027	 0.001408	 0.00996	 0.00273	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14988	 14991	 0.000529	 0.002813	 0.00065	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14988	 14995	 0.00071	 0.003567	 0.00093	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14989	 80006	 0.029028	 0.021357	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14989	 80008	 0.047764	 0.03744	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	14990	 80007	 0.010314	 0.02042	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14990	 80008	 0.020193	 0.014304	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79878	 14992	 0.01335	 0.10405	 0.00194	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14992	 80007	 0.007249	 0.022236	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14992	 80008	 0.011336	 0.03741	 0.00061	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14993	 14995	 0.001365	 0.005635	 0.00133	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14993	 15021	 0.001863	 0.007884	 0.00177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	14993	 80006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14993	 80006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14994	 14995	 0.000354	 0.002504	 0.00069	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14994	 80007	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14994	 80007	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14994	 80009	 0.001278	 0.009441	 0.00272	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14995	 80008	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14995	 80008	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14996	 14998	 0.001438	 0.007225	 0.00188	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79490	 14996	 0.003268	 0.025425	 0.0066	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14996	 80009	 0.000561	 0.004141	 0.0012	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	14997	 80009	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14997	 80009	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14997	 80010	 0.000111	 0.001414	 0.00267	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	14998	 14999	 0.00095	 0.005565	 0.00152	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	14999	 80011	 0.002447	 0.014797	 0.00378	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15000	 80010	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15000	 80010	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15000	 80010	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80010	 15001	 0.000285	 0.002956	 0.00637	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80010	 15001	 0.000285	 0.002956	 0.00637	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15001	 80011	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15001	 80011	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15002	 15004	 0.000281	 0.001645	 0.00045	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79490	 15002	 0.001944	 0.010331	 0.0024	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15003	 15004	 0.001258	 0.007492	 0.00197	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80011	 15003	 0.001217	 0.007708	 0.00209	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15003	 80012	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15003	 80012	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15005	 15038	 0.021021	 0.049778	 0.00091	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15005	 80013	 0.02556	 0.050094	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15006	 15008	 0.001245	 0.007884	 0.00214	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15006	 15027	 0.002233	 0.013729	 0.00396	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15006	 80013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15006	 80013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15007	 15011	 0.00076	 0.009893	 0.00286	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79490	 15007	 0.000863	 0.006765	 0.00309	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15008	 15041	 0.001142	 0.007663	 0.00185	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80013	 15009	 0.02023	 0.046966	 0.0007	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15009	 80014	 0.00357	 0.015728	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15009	 80020	 0.010867	 0.053921	 0.00129	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15009	 80026	 0.0208	 0.071051	 0.00155	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15009	 80026	 0.0208	 0.071051	 0.00155	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15010	 15011	 0.000636	 0.006312	 0.00172	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15010	 15041	 0.00064	 0.006249	 0.00175	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15011	 80014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15011	 80014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15012	 15024	 0.001641	 0.010393	 0.00282	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15012	 15037	 0.006235	 0.025372	 0.00618	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15012	 80015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15012	 80015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80015	 15013	 0.045768	 0.049851	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15014	 15034	 0.00756	 0.030268	 0.00763	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15014	 15036	 0.004992	 0.022245	 0.00604	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15014	 80016	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15014	 80016	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15015	 15016	 0.009335	 0.016674	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80016	 15015	 0.011698	 0.031005	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15015	 80019	 0.004775	 0.023275	 0.00044	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15016	 15018	 0.006355	 0.01736	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15017	 15018	 0.036754	 0.029087	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15018	 80018	 0.004097	 0.018996	 0.00039	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15019	 15020	 0.002291	 0.011511	 0.003	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15019	 15022	 0.001056	 0.009604	 0.00242	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15019	 15035	 0.008956	 0.024974	 0.00524	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15020	 15021	 0.002136	 0.009959	 0.00247	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15021	 15028	 0.002729	 0.00761	 0.0016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79492	 15021	 0.021399	 0.06981	 0.01854	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15021	 80017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15021	 80017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15022	 15028	 0.000474	 0.003786	 0.00093	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15022	 80018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15022	 80018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15023	 15026	 0.02911	 0.023038	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80017	 15023	 0.015352	 0.023518	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15024	 15030	 0.000966	 0.004573	 0.0011	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15024	 80019	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15024	 80019	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15025	 80020	 0.01639	 0.050333	 0.00094	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15025	 80022	 0.006375	 0.021777	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15027	 80020	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15027	 80020	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15028	 15030	 0.000985	 0.004519	 0.00116	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15028	 80021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15028	 80021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80015	 15029	 0.019101	 0.057491	 0.00112	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80021	 15029	 0.007062	 0.015078	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15029	 80022	 0.024908	 0.018325	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15030	 80022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15030	 80022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80019	 15031	 0.030217	 0.033234	 0.00044	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80022	 15031	 0.00756	 0.012557	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15032	 80024	 0.022853	 0.058746	 0.00091	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15033	 15036	 0.003773	 0.031729	 0.0094	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15034	 15035	 0.003258	 0.012806	 0.00335	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15034	 80023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15034	 80023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15035	 80024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15035	 80024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77713	 15036	 0.00571	 0.038304	 0.00925	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79492	 15036	 0.008886	 0.039598	 0.01076	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79492	 15037	 0.009802	 0.025197	 0.00624	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15037	 80025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15037	 80025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80025	 15038	 0.012962	 0.043241	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15039	 15041	 0.000537	 0.00591	 0.00302	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15039	 15042	 0.001347	 0.005393	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15039	 80026	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15039	 80026	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79956	 15040	 0.014282	 0.049971	 0.00103	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79956	 15040	 0.014282	 0.049971	 0.00103	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80026	 15040	 0.002761	 0.01074	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80026	 15040	 0.002761	 0.01074	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79490	 15043	 0.003357	 0.009139	 0.00201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15043	 80027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15043	 80027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15044	 15045	 0.005574	 0.020415	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15044	 15048	 0.002573	 0.01382	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15044	 80028	 0.016445	 0.025189	 0.00044	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79852	 15045	 0.006706	 0.029883	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15046	 15083	 0.003814	 0.016995	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15046	 80032	 0.006892	 0.030368	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15047	 15088	 0.020571	 0.016279	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15048	 15088	 0.002762	 0.015703	 0.00028	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15049	 15051	 0.001048	 0.006501	 0.00157	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15050	 15051	 0.001106	 0.007121	 0.00187	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15050	 80040	 0.001224	 0.00938	 0.00251	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15051	 80028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15051	 80028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15052	 15054	 0.001465	 0.005867	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15052	 80029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15052	 80029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15053	 15054	 0.00103	 0.006526	 0.00177	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15053	 15064	 0.001881	 0.011018	 0.003	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15053	 15077	 0.003944	 0.024982	 0.00678	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15054	 15059	 0.001854	 0.007424	 0.00187	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15055	 15059	 0.001829	 0.00719	 0.00188	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15055	 15061	 0.001749	 0.007001	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15055	 15062	 0.001748	 0.007112	 0.00173	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15055	 80030	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15055	 80030	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15055	 80038	 0.003288	 0.017671	 0.00435	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15056	 15057	 0.00492	 0.01914	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15056	 80036	 0.008136	 0.036255	 0.00062	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15057	 15058	 0.003685	 0.012586	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15058	 80031	 0.00332	 0.010692	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15059	 80031	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15059	 80031	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15060	 15063	 0.007715	 0.015121	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80029	 15060	 0.004783	 0.027188	 0.00049	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15060	 80033	 0.024274	 0.03383	 0.00058	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15061	 80032	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15061	 80032	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15062	 80033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15062	 80033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79858	 15063	 0.005626	 0.017863	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80033	 15063	 0.00771	 0.02448	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15064	 15065	 0.00175	 0.014301	 0.00388	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15064	 80034	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15064	 80034	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15065	 15067	 0.003865	 0.029117	 0.00808	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15065	 15068	 0.005245	 0.021	 0.00529	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80030	 15066	 0.041383	 0.10638	 0.00165	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80034	 15066	 0.009596	 0.053995	 0.00117	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15067	 15112	 0.003124	 0.023411	 0.00571	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79945	 15067	 0.003203	 0.014691	 0.00376	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15068	 15105	 0.005877	 0.0231	 0.00604	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15069	 15077	 0.002617	 0.012698	 0.0029	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15069	 15208	 0.003423	 0.015411	 0.0041	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15069	 80035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15069	 80035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15070	 15076	 0.002915	 0.011457	 0.003	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15070	 15205	 0.00365	 0.015072	 0.00357	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15071	 15206	 0.025188	 0.079978	 0.0014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15071	 80037	 0.023258	 0.047595	 0.00117	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15072	 15073	 0.024717	 0.018185	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15073	 15081	 0.00503	 0.019569	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15073	 80036	 0.002403	 0.016495	 0.0003	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15074	 15075	 0.001261	 0.004792	 0.00134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15074	 15077	 0.001279	 0.005279	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15075	 80036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15075	 80036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15076	 15077	 0.000963	 0.004074	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15077	 80037	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15077	 80037	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15078	 15079	 0.001994	 0.011947	 0.00029	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80035	 15078	 0.015817	 0.052763	 0.00084	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80037	 15078	 0.003069	 0.021068	 0.00038	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15079	 15081	 0.004843	 0.02753	 0.0005	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15080	 15081	 0.003076	 0.018912	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15080	 15084	 0.002266	 0.010879	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15081	 80039	 0.0188	 0.04161	 0.00068	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15082	 15083	 0.008945	 0.01573	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15082	 15084	 0.011479	 0.022497	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15082	 15086	 0.007017	 0.016287	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15083	 15084	 0.02066	 0.014634	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15083	 15088	 0.008149	 0.015153	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15083	 80039	 0.008047	 0.035858	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80030	 15084	 0.00283	 0.016954	 0.00041	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80032	 15084	 0.012425	 0.041447	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15085	 15086	 0.00436	 0.016774	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15085	 15090	 0.005408	 0.02104	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15086	 80039	 0.004695	 0.022651	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15087	 15091	 0.0146	 0.022362	 0.00039	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15087	 80039	 0.014853	 0.016336	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15088	 80039	 0.003815	 0.018309	 0.00055	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15089	 15094	 0.000183	 0.002852	 0.00613	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15089	 80038	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80039	 15089	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15090	 15091	 0.011787	 0.020729	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15090	 15093	 0.004996	 0.021455	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15092	 80042	 0.030236	 0.023928	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15093	 80130	 0.009019	 0.055447	 0.001	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15094	 80040	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80041	 15094	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15094	 80199	 0.001228	 0.013796	 0.02524	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15094	 80199	 0.001228	 0.013796	 0.02524	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15094	 80256	 0.001356	 0.012912	 0.04718	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15095	 15098	 0.000587	 0.002695	 0.00069	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80041	 15096	 0.005506	 0.026566	 0.00047	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15096	 80043	 0.005352	 0.023849	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15097	 15098	 0.000588	 0.002869	 0.00079	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15097	 15319	 0.000462	 0.002708	 0.00074	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15097	 80042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15097	 80042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15098	 80043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15098	 80043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79676	 15099	 0.067418	 0.17147	 0.00271	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15099	 80044	 0.05226	 0.17247	 0.00279	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15100	 15102	 0.004393	 0.03893	 0.01036	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15100	 80044	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15100	 80044	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15101	 15540	 0.010842	 0.041215	 0.01154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15101	 80045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15101	 80045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15102	 15103	 0.002522	 0.024217	 0.00704	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15104	 15109	 0.071184	 0.056335	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15105	 15107	 0.004247	 0.017003	 0.00428	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15106	 15148	 0.005415	 0.016628	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15106	 80046	 0.006787	 0.015521	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15107	 15137	 0.000724	 0.004585	 0.00124	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15107	 80046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15107	 80046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15108	 15112	 0.001494	 0.008677	 0.00204	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15109	 15110	 0.012926	 0.042655	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15109	 15167	 0.04046	 0.04047	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15109	 80051	 0.01214	 0.028746	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15110	 15111	 0.049537	 0.03883	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15110	 80047	 0.011122	 0.029479	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15111	 80047	 0.010817	 0.023093	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15111	 80051	 0.016777	 0.049334	 0.00101	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15112	 15166	 0.004534	 0.024969	 0.00901	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15112	 80047	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15112	 80047	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15113	 80048	 0.01158	 0.022927	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15113	 80051	 0.02004	 0.039275	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15113	 80070	 0.051868	 0.038161	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15114	 15154	 0.000594	 0.004386	 0.00127	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15114	 80049	 0.000328	 0.002437	 0.00093	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15115	 80048	 0.0078	 0.01245	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15115	 80050	 0.004233	 0.016468	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15116	 15154	 0.001509	 0.003792	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15116	 15163	 0.000486	 0.004089	 0.00121	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15116	 80048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15116	 80048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15116	 80049	 0.000245	 0.003496	 0.00117	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15117	 80049	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80050	 15117	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15117	 80052	 0.000658	 0.007259	 0.01379	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15117	 80052	 0.000658	 0.007259	 0.01379	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15117	 80066	 0.000694	 0.005397	 0.01934	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15118	 15119	 0.002024	 0.008103	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15118	 80051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15118	 80051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79504	 15119	 0.007081	 0.038064	 0.00936	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15120	 80052	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80053	 15120	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15121	 15122	 0.007386	 0.028075	 0.00786	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79504	 15121	 0.00307	 0.019447	 0.00528	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15122	 15128	 0.004902	 0.012726	 0.00309	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15122	 15130	 0.001676	 0.009736	 0.00229	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15122	 80054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15122	 80054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15123	 15124	 0.000854	 0.00392	 0.001	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15123	 15130	 0.001186	 0.004068	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15123	 80055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15123	 80055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15124	 15195	 0.001768	 0.004748	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15124	 80056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15124	 80056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15125	 18491	 0.012952	 0.057713	 0.00098	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80054	 15125	 0.078828	 0.062385	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80055	 15125	 0.014536	 0.037367	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15126	 15129	 0.000724	 0.00431	 0.00113	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15126	 15158	 0.00073	 0.003933	 0.00108	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15127	 15128	 0.001068	 0.006879	 0.0018	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80053	 15127	 0.002167	 0.017409	 0.00489	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15128	 15129	 0.001519	 0.00661	 0.00188	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15129	 15151	 0.00127	 0.003297	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15130	 80057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15130	 80057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80055	 15131	 0.020629	 0.020634	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80057	 15131	 0.004462	 0.014885	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15131	 80071	 0.006127	 0.017574	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15132	 15139	 1.6e-05	 0.000196	 0.01472	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15132	 15141	 1.2e-05	 0.000281	 0.02275	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15132	 15186	 1.9e-05	 0.000491	 0.03648	 2893.0	 3037.6	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15132	 80058	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15133	 15157	 0.001222	 0.004191	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15133	 80060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15133	 80060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15133	 80064	 0.00091	 0.00346	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15134	 15135	 0.006272	 0.016122	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15134	 15198	 0.015836	 0.052258	 0.00085	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80059	 15135	 0.003477	 0.013526	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15136	 15143	 0.000443	 0.001772	 0.00045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15136	 80067	 0.000635	 0.002497	 0.00065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15137	 15149	 0.000703	 0.002815	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15137	 15150	 0.001566	 0.006373	 0.00155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15137	 80061	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15137	 80061	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80046	 15138	 0.006468	 0.019864	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15138	 80063	 0.007186	 0.014706	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15139	 80062	 0.000281	 0.02246	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15139	 80062	 0.000281	 0.02246	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15140	 15175	 0.008807	 0.023282	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80059	 15140	 0.006139	 0.015782	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15140	 80069	 0.009418	 0.018646	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15141	 15145	 8e-06	 0.000188	 0.01531	 2893.0	 3037.6	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15141	 80063	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15141	 80063	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80059	 15142	 0.009956	 0.023113	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80063	 15142	 0.003742	 0.008687	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15143	 80064	 0.000718	 0.002876	 0.00072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15144	 15145	 1e-05	 0.000274	 0.0226	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15144	 80064	 0.000149	 0.01193	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15145	 80066	 0.000118	 0.009419	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80067	 15145	 0.000243	 0.018209	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15146	 15162	 0.001051	 0.004207	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80067	 15146	 0.000599	 0.002353	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15147	 15148	 0.004833	 0.013862	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15147	 15167	 0.013712	 0.023099	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15147	 80068	 0.007233	 0.016406	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80061	 15148	 0.009294	 0.014237	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80064	 15149	 0.001339	 0.00536	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15150	 15166	 0.001494	 0.005812	 0.00155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15150	 80068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15150	 80068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15151	 15154	 0.001211	 0.003113	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15152	 15153	 0.00072	 0.002735	 0.00077	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15152	 15161	 0.000883	 0.003739	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15153	 80069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15153	 80069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15153	 80081	 0.003098	 0.010436	 0.00259	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15154	 15155	 0.000795	 0.004226	 0.00098	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80064	 15154	 0.003303	 0.011329	 0.00271	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15154	 80070	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15154	 80070	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15155	 15164	 0.000624	 0.002642	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80060	 15156	 0.01413	 0.010839	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80065	 15156	 0.018632	 0.024247	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15156	 80071	 0.02057	 0.028668	 0.00049	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15157	 15158	 0.000992	 0.0027	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15157	 15162	 0.001007	 0.003646	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15158	 15159	 0.001257	 0.00431	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15159	 15160	 0.000731	 0.002547	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15160	 15161	 0.000796	 0.003287	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15160	 15162	 0.001519	 0.004478	 0.00104	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15160	 80071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15160	 80071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80058	 15162	 0.002676	 0.009325	 0.00216	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15163	 15166	 0.000407	 0.003164	 0.00082	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15164	 15166	 0.001311	 0.0051	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80064	 15164	 0.002057	 0.005288	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15164	 80072	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15164	 80072	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80072	 15165	 0.006177	 0.01223	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15165	 80073	 0.01706	 0.012552	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15166	 80073	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15166	 80073	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80073	 15167	 0.005513	 0.014171	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15168	 80074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15168	 80074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15168	 80081	 0.001533	 0.006026	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15169	 15196	 0.012295	 0.041015	 0.00065	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80074	 15169	 0.00277	 0.007859	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15170	 15179	 1.4e-05	 0.000253	 0.01792	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15170	 15186	 2.3e-05	 0.000387	 0.03008	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15171	 15172	 1.1e-05	 0.000178	 0.01161	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15171	 15180	 6e-06	 0.000114	 0.00756	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15171	 80075	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15172	 15192	 9e-06	 0.000152	 0.01063	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80074	 15173	 0.016165	 0.024517	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80076	 15173	 0.012423	 0.015144	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15174	 15176	 0.012062	 0.02168	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15174	 15185	 0.022519	 0.017821	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15174	 80079	 0.006709	 0.015573	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80074	 15175	 0.005392	 0.016558	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15175	 80082	 0.007486	 0.01738	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80074	 15176	 0.015508	 0.01121	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80074	 15177	 0.014764	 0.029232	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80069	 15178	 0.011099	 0.015129	 0.00034	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15179	 15180	 8e-06	 0.000139	 0.01084	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15181	 15182	 0.000622	 0.003126	 0.00081	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15181	 15271	 0.000471	 0.002197	 0.00054	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15182	 80077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15182	 80077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15182	 80083	 0.000718	 0.004064	 0.00101	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15183	 80078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15183	 80078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15183	 80084	 0.002084	 0.005811	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15184	 15194	 0.00197	 0.01081	 0.00286	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15184	 15311	 0.002925	 0.009541	 0.00253	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15184	 80079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15184	 80079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15184	 80083	 0.003186	 0.013155	 0.00311	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15186	 80080	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15187	 15199	 0.002002	 0.009338	 0.00231	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80081	 15187	 0.001366	 0.00663	 0.00152	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15188	 15190	 1.1e-05	 0.000149	 0.0095	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15188	 15191	 1.7e-05	 0.000197	 0.01481	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15189	 15283	 0.015183	 0.012015	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15190	 15296	 4.2e-05	 0.000621	 0.03997	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15190	 80083	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15190	 80083	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15191	 15192	 1.1e-05	 0.000129	 0.00923	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15191	 80084	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15191	 80084	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15192	 15534	 0.000173	 0.002949	 0.22952	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80075	 15193	 0.001892	 0.005001	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80084	 15193	 0.00149	 0.003939	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15194	 15195	 0.001877	 0.004872	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15194	 15312	 0.00212	 0.007495	 0.00169	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15196	 15250	 0.012298	 0.012334	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15196	 15261	 0.013865	 0.02492	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15197	 15206	 0.010722	 0.035381	 0.00057	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15197	 80086	 0.005571	 0.01903	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15198	 15202	 0.008654	 0.01261	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15198	 80086	 0.007592	 0.019515	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15199	 15201	 0.001831	 0.007449	 0.00181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15200	 15203	 0.002118	 0.005323	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15200	 15263	 0.003107	 0.008066	 0.00196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15200	 80085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15200	 80085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15201	 15203	 0.001818	 0.004805	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15201	 15204	 0.000955	 0.005297	 0.00161	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80081	 15201	 0.00382	 0.020229	 0.00513	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15201	 80086	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15201	 80086	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80085	 15202	 0.028108	 0.022244	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15204	 15205	 0.001718	 0.009252	 0.00254	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15205	 15208	 0.002971	 0.011676	 0.00305	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15207	 15222	 0.004945	 0.022917	 0.00044	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15207	 80087	 0.016106	 0.041403	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15208	 15211	 0.002127	 0.013217	 0.00373	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15208	 80087	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15208	 80087	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15209	 15212	 0.007111	 0.031685	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15209	 80090	 0.004247	 0.01486	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15210	 15218	 0.001555	 0.006419	 0.00152	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15210	 15325	 0.001187	 0.004754	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15211	 80088	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15211	 80088	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15211	 80103	 0.002896	 0.015889	 0.0042	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15212	 80091	 0.003681	 0.023115	 0.00051	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15213	 15214	 0.000627	 0.002382	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15213	 15217	 0.000518	 0.002075	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15213	 80089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15213	 80089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15214	 15215	 0.00074	 0.002962	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15215	 15216	 0.001135	 0.004686	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15216	 15224	 0.001028	 0.00525	 0.00132	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15217	 15218	 0.000565	 0.002199	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15218	 80090	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15218	 80090	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15219	 15221	 0.000981	 0.003815	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15219	 80091	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15219	 80091	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15220	 15224	 0.000527	 0.003396	 0.00089	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15220	 15235	 0.00044	 0.002701	 0.00099	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15221	 80103	 0.0017	 0.006804	 0.00171	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15222	 15256	 0.002712	 0.018615	 0.00034	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80087	 15222	 0.017183	 0.051719	 0.00101	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15223	 15536	 0.008352	 0.027863	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15223	 80092	 0.004032	 0.013449	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15224	 15529	 0.001332	 0.004568	 0.00109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15224	 80092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15224	 80092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15225	 15226	 0.001054	 0.006618	 0.00014	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15225	 80198	 0.002533	 0.017384	 0.00032	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15226	 15234	 0.001583	 0.008892	 0.00016	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15226	 15504	 0.007071	 0.011793	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15226	 80096	 0.002901	 0.018881	 0.00038	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15226	 80198	 0.007816	 0.024818	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15227	 80094	 0.011548	 0.009139	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15227	 80095	 0.012414	 0.008794	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15228	 15232	 0.000249	 0.00114	 0.00029	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15228	 15240	 0.000753	 0.003389	 0.0009	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15228	 80093	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15228	 80093	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15229	 15497	 0.003876	 0.009963	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80093	 15229	 0.002884	 0.011219	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15229	 80096	 0.013486	 0.013621	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15230	 15231	 0.001526	 0.004032	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15230	 80094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15230	 80094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15231	 15240	 0.001193	 0.003096	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15231	 80095	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15231	 80095	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15232	 15233	 0.000342	 0.001617	 0.00039	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15233	 15240	 0.000829	 0.005338	 0.0014	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15233	 15498	 0.000505	 0.002355	 0.00058	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15233	 80096	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15233	 80096	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15234	 15236	 0.001668	 0.010139	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15235	 15238	 0.000661	 0.004755	 0.00126	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15236	 15237	 0.003214	 0.009871	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15236	 80097	 0.001747	 0.00889	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15237	 80098	 0.005598	 0.011457	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15238	 15246	 0.000275	 0.002245	 0.00061	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15238	 80097	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15238	 80097	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80093	 15239	 0.001411	 0.005488	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15239	 80098	 0.001397	 0.008588	 0.00015	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15240	 80098	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15240	 80098	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15240	 80099	 0.00018	 0.00191	 0.00057	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15241	 15296	 4.3e-05	 0.000796	 0.063	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15241	 15486	 0.000137	 0.001774	 0.11324	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15241	 80099	 0.00014	 0.01116	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15242	 15243	 0.003957	 0.006666	 9e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80100	 15242	 0.002059	 0.005338	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15244	 15245	 0.000614	 0.003086	 0.0008	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15244	 15280	 0.00186	 0.006267	 0.00156	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80099	 15244	 0.002528	 0.006681	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15244	 80122	 0.000882	 0.007819	 0.00208	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15245	 15246	 0.000729	 0.003399	 0.00084	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15245	 80101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15245	 80101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80099	 15246	 0.000584	 0.003699	 0.001	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15247	 15255	 0.023855	 0.018298	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80097	 15247	 0.003565	 0.010226	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80101	 15247	 0.007109	 0.023715	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15248	 15255	 0.010117	 0.010219	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15248	 15278	 0.01312	 0.015994	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15248	 80113	 0.011987	 0.018181	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15249	 15260	 0.001989	 0.006702	 0.00167	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15249	 15265	 0.001255	 0.003699	 0.00086	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15249	 80102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15249	 80102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80102	 15250	 0.016647	 0.015334	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15251	 15256	 0.006802	 0.016649	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15251	 15259	 0.008116	 0.013554	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15251	 80109	 0.003926	 0.011817	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15251	 80110	 0.00275	 0.010536	 0.0003	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15252	 80103	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80104	 15252	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15252	 80121	 0.000554	 0.005078	 0.02004	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80104	 15253	 0.01167	 0.01966	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80104	 15254	 0.012411	 0.016311	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15254	 80113	 0.004444	 0.010316	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80104	 15256	 0.007725	 0.025769	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15256	 80107	 0.015278	 0.030248	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15257	 15260	 0.00098	 0.002544	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15257	 80105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15257	 80105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15258	 15259	 0.015844	 0.012539	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80105	 15258	 0.010495	 0.010601	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15260	 15263	 0.000968	 0.00323	 0.00082	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15260	 80106	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15260	 80106	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15261	 15262	 0.006701	 0.00737	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80106	 15261	 0.01605	 0.012702	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80106	 15262	 0.016023	 0.01268	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15262	 80107	 0.017621	 0.013945	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15263	 80107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15263	 80107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80107	 15264	 0.021358	 0.016741	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15265	 80108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15265	 80108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15265	 80122	 0.006143	 0.020698	 0.00514	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80108	 15266	 0.004905	 0.010511	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15266	 80109	 0.008303	 0.010306	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15267	 15268	 0.000808	 0.003175	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15267	 15271	 0.000746	 0.002904	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15268	 15269	 0.001048	 0.002527	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15268	 80109	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15268	 80109	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15269	 80110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15269	 80110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15270	 15275	 0.00999	 0.006468	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15271	 80111	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15271	 80111	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15272	 15273	 0.010096	 0.010125	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80077	 15272	 0.009075	 0.017786	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15273	 80112	 0.006389	 0.014678	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15273	 80115	 0.009354	 0.01852	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15274	 15277	 0.000783	 0.002767	 0.00062	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15274	 15282	 0.000807	 0.002923	 0.00063	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15275	 15276	 0.002947	 0.007577	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80110	 15275	 0.010342	 0.010344	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15276	 80112	 0.005169	 0.013288	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15277	 80112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15277	 80112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15278	 80114	 0.004807	 0.012357	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15279	 15280	 0.00122	 0.004068	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15279	 80113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15279	 80113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15280	 80114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15280	 80114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80114	 15281	 0.006152	 0.020301	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15281	 80115	 0.012375	 0.013611	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15281	 80124	 0.003543	 0.015701	 0.00047	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15282	 80115	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15282	 80115	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15282	 80122	 0.002696	 0.009529	 0.00215	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80115	 15283	 0.008753	 0.015793	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15283	 80116	 0.006926	 0.017805	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15284	 15285	 0.000788	 0.002656	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80083	 15284	 0.000442	 0.00168	 0.00047	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15285	 15286	 0.000559	 0.001916	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15286	 80116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15286	 80116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15287	 15288	 0.011116	 0.011227	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15287	 15289	 0.007169	 0.018231	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15287	 15317	 0.009902	 0.019406	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80078	 15287	 0.036632	 0.028714	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15288	 15308	 0.008541	 0.01691	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80116	 15289	 0.008429	 0.015931	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15289	 80117	 0.004247	 0.010917	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15290	 15307	 0.001692	 0.010719	 0.00291	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15290	 80117	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15290	 80117	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15291	 80120	 0.014423	 0.011414	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15291	 80125	 0.024555	 0.019433	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15292	 15302	 0.000953	 0.002475	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15292	 80118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15292	 80118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15293	 15294	 0.000344	 0.00091	 0.00021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15293	 80119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15293	 80119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15294	 15295	 0.000599	 0.001672	 0.00035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15295	 80120	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15295	 80120	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15295	 80122	 0.000777	 0.002708	 0.00063	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15296	 18540	 0.000182	 0.004791	 0.39488	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15296	 80121	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15296	 80121	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80122	 15297	 0.001131	 0.004444	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15297	 80124	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15297	 80124	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15298	 15300	 0.018992	 0.018996	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80124	 15298	 0.008216	 0.014768	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15299	 15300	 0.015375	 0.011312	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80119	 15300	 0.006059	 0.010932	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15301	 15304	 0.005716	 0.004524	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15302	 80125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15302	 80125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15303	 15304	 0.013979	 0.00905	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15303	 15306	 0.010267	 0.011392	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79735	 15303	 0.004865	 0.013954	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80125	 15303	 0.016922	 0.016557	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79736	 15304	 0.00709	 0.012793	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80118	 15305	 0.008553	 0.021985	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80125	 15305	 0.003974	 0.013258	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15305	 80126	 0.004149	 0.023315	 0.00043	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15307	 18579	 0.000784	 0.00319	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15307	 80126	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15307	 80126	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15308	 15318	 0.031878	 0.020638	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80117	 15308	 0.008193	 0.018585	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15309	 15310	 0.005338	 0.014148	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80126	 15309	 0.00342	 0.014622	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80117	 15310	 0.006952	 0.014226	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15311	 15314	 0.001905	 0.006639	 0.00154	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15312	 15313	 0.003645	 0.014324	 0.00375	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15313	 15314	 0.001463	 0.005859	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15313	 18454	 0.003202	 0.021482	 0.00519	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15313	 80127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15313	 80127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15315	 15316	 0.011789	 0.015213	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15315	 15318	 0.028095	 0.018188	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80079	 15316	 0.005565	 0.011882	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80078	 15317	 0.025904	 0.020305	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15319	 15324	 0.000697	 0.002739	 0.00072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15319	 15332	 0.001392	 0.005891	 0.00133	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15320	 15328	 0.000895	 0.003517	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15320	 80128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15320	 80128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15321	 15322	 0.00535	 0.010947	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80042	 15321	 0.004961	 0.016948	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15321	 80129	 0.00428	 0.012275	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15322	 80129	 0.014435	 0.011881	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15322	 80130	 0.003784	 0.018465	 0.00032	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15323	 80129	 0.006515	 0.006295	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15324	 15325	 0.001153	 0.007423	 0.00195	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15324	 80129	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15324	 80129	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15325	 80130	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15325	 80130	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15326	 80132	 0.027638	 0.027915	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15327	 80131	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80132	 15327	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15327	 80199	 0.000183	 0.002164	 0.00737	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15328	 15330	 0.000762	 0.0031	 0.00076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15329	 15332	 0.000771	 0.003139	 0.00076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15329	 15333	 0.000535	 0.002143	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80131	 15330	 0.001707	 0.006833	 0.00172	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15331	 15533	 0.007308	 0.038937	 0.00068	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15331	 80133	 0.003036	 0.013453	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15332	 80133	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15332	 80133	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80131	 15333	 0.000903	 0.00355	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15333	 80134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15333	 80134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80132	 15334	 0.004194	 0.01399	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80134	 15334	 0.00435	 0.008902	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79815	 15335	 0.010047	 0.030239	 0.00059	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15335	 80135	 0.007899	 0.016164	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15336	 15344	 0.002641	 0.007365	 0.00155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15336	 80135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15336	 80135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15337	 15339	 0.010186	 0.026184	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15337	 15340	 0.005862	 0.022804	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80135	 15337	 0.004359	 0.016959	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15338	 15339	 0.005052	 0.030704	 0.00057	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15338	 15343	 0.008589	 0.021842	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15338	 15350	 0.032965	 0.033296	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15338	 80183	 0.007364	 0.037249	 0.00065	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15339	 15349	 0.031625	 0.033695	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15340	 15341	 0.014388	 0.041267	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15341	 80194	 0.010333	 0.052579	 0.00119	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15342	 15343	 0.005068	 0.012889	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15342	 80182	 0.005643	 0.01561	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15344	 15345	 0.000881	 0.004504	 0.00123	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15344	 80136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15344	 80136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15345	 15352	 0.000663	 0.003009	 0.00104	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15346	 15348	 0.000686	 0.005983	 0.00164	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15346	 15358	 0.002114	 0.013615	 0.00357	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15347	 15353	 0.001431	 0.006443	 0.00171	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15347	 15361	 0.001951	 0.0093	 0.00269	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15348	 15355	 0.000528	 0.004312	 0.00117	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80136	 15349	 0.019209	 0.038033	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15349	 80138	 0.005514	 0.026905	 0.00046	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15351	 15354	 0.001522	 0.005786	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15351	 80137	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15351	 80137	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15352	 15355	 0.00065	 0.005225	 0.00147	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15352	 80138	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15352	 80138	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15353	 15354	 0.001432	 0.005628	 0.00147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15353	 15462	 0.002986	 0.008377	 0.00216	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80138	 15356	 0.013992	 0.009058	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15357	 15358	 0.001447	 0.007271	 0.00189	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15357	 80139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15357	 80139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15359	 15360	 0.001726	 0.008421	 0.00233	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79480	 15359	 0.011213	 0.067314	 0.02039	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15359	 80140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15359	 80140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15360	 15362	 0.001943	 0.00778	 0.00196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15361	 15362	 0.002001	 0.007072	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15361	 15431	 0.004878	 0.020645	 0.00465	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15363	 15367	 0.059131	 0.046796	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15363	 15429	 0.017803	 0.034093	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15364	 15365	 0.00892	 0.022929	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15364	 15367	 0.045978	 0.034835	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79928	 15364	 0.44267	 0.35055	 0.00441	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80140	 15364	 0.006393	 0.039303	 0.00071	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15364	 80141	 0.005279	 0.032454	 0.00058	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15365	 15368	 0.040213	 0.067743	 0.00096	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15366	 15373	 0.002184	 0.00736	 0.00183	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15366	 80141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15366	 80141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79481	 15369	 0.092508	 0.083465	 0.0014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79970	 15369	 0.04405	 0.054681	 0.00119	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79501	 15370	 0.00012	 0.000931	 0.00334	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15370	 80142	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15370	 80142	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15371	 15372	 0.003319	 0.010824	 0.00287	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80142	 15371	 0.002538	 0.012012	 0.00289	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15371	 80143	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15371	 80143	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15372	 15373	 0.000708	 0.00243	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15374	 15397	 0.000116	 0.001387	 0.10406	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15374	 15426	 4.1e-05	 0.000528	 0.03956	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15374	 80144	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15375	 15385	 0.001285	 0.006662	 0.00163	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80142	 15375	 0.00313	 0.021001	 0.00507	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15375	 80146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15375	 80146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80146	 15376	 0.007822	 0.019892	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15376	 80147	 0.004905	 0.016362	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15377	 15384	 0.001039	 0.004767	 0.00122	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15377	 15392	 0.002265	 0.01158	 0.00316	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15377	 80147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15377	 80147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15378	 80149	 0.022757	 0.024787	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15379	 15380	 0.001091	 0.003803	 0.00088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15379	 15385	 0.001266	 0.005808	 0.00149	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15379	 80148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15379	 80148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15380	 15417	 0.00152	 0.004956	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15381	 15384	 0.002274	 0.00939	 0.00222	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15381	 15398	 0.001188	 0.004669	 0.00122	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15382	 15383	 0.008305	 0.023819	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80145	 15382	 0.024991	 0.027221	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80141	 15383	 0.012743	 0.032407	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80146	 15383	 0.006854	 0.018165	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15384	 80149	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15384	 80149	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15386	 15390	 2.5e-05	 0.000589	 0.04764	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15387	 15394	 1.7e-05	 0.000309	 0.0219	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15387	 15397	 1.6e-05	 0.000277	 0.02156	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15387	 80150	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15387	 80150	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15388	 15402	 0.000846	 0.008394	 0.00228	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15388	 80151	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15388	 80151	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15388	 80152	 0.00069	 0.007214	 0.00243	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15389	 15390	 1.3e-05	 0.000239	 0.01888	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15389	 15393	 1.3e-05	 0.00027	 0.01811	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15390	 80152	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15390	 80152	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15391	 15392	 0.002315	 0.017343	 0.00423	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15392	 80153	 0.002557	 0.007951	 0.00166	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15393	 15394	 2.5e-05	 0.00043	 0.03347	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15393	 80153	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15393	 80153	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15395	 15402	 0.000737	 0.004667	 0.00127	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15395	 15403	 0.000978	 0.006296	 0.00165	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15396	 15400	 0.000348	 0.002825	 0.0009	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15396	 15409	 0.000545	 0.004451	 0.00121	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15396	 80154	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15396	 80154	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15397	 80155	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15397	 80155	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15398	 15406	 0.001554	 0.006578	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15398	 80156	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15398	 80156	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15399	 15406	 0.000481	 0.003048	 0.00083	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80155	 15399	 0.00096	 0.006905	 0.00183	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15399	 80157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15399	 80157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80155	 15400	 0.000337	 0.002894	 0.00082	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80151	 15401	 0.004686	 0.012047	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15401	 80158	 0.008087	 0.026976	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80155	 15402	 0.001082	 0.006712	 0.00163	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15402	 80158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15402	 80158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79789	 15404	 0.003974	 0.007868	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15404	 80159	 0.02037	 0.013683	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80157	 15405	 0.006716	 0.017011	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15405	 80164	 0.021318	 0.016871	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15406	 15409	 0.002287	 0.00575	 0.00149	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15406	 15410	 0.000405	 0.002101	 0.00051	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15406	 15419	 0.002919	 0.01062	 0.00325	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15407	 15409	 0.000389	 0.003103	 0.00076	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15407	 15416	 0.000652	 0.004613	 0.00127	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15407	 80159	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15407	 80159	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15408	 15410	 0.000489	 0.001957	 0.00066	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15408	 15411	 0.000693	 0.003181	 0.00081	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15410	 80160	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15410	 80160	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15411	 15412	 0.000427	 0.001711	 0.00043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15411	 80161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15411	 80161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15412	 15422	 0.000928	 0.003183	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15412	 80162	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15412	 80162	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15413	 15414	 0.000407	 0.001682	 0.0004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15413	 15416	 0.000627	 0.002511	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80159	 15415	 0.005064	 0.016712	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15415	 80163	 0.010191	 0.010293	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15416	 80163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15416	 80163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15417	 15419	 0.002208	 0.006612	 0.00149	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15417	 80164	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15417	 80164	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80145	 15418	 0.00858	 0.028623	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15418	 80165	 0.012897	 0.016784	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15419	 15423	 0.000999	 0.004346	 0.00124	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80144	 15419	 0.002076	 0.010073	 0.0023	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15419	 80165	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15419	 80165	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15419	 80168	 0.001864	 0.007464	 0.00188	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15420	 80169	 0.012622	 0.012625	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79771	 15421	 0.026845	 0.069575	 0.00132	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80161	 15421	 0.001742	 0.010161	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15422	 15423	 0.00196	 0.005871	 0.00132	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15422	 80166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15422	 80166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15423	 15424	 0.000519	 0.002258	 0.00064	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15424	 15428	 0.000366	 0.002851	 0.00085	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15424	 15435	 0.000235	 0.001575	 0.00099	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15424	 80167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15424	 80167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15425	 15427	 0.000593	 0.002411	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15425	 15432	 0.00062	 0.00241	 0.00064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15426	 80168	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15427	 15428	 0.000221	 0.001898	 0.00054	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80168	 15427	 0.00021	 0.002859	 0.00102	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80169	 15429	 0.007243	 0.022997	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15429	 80170	 0.00723	 0.018585	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15430	 15431	 0.000526	 0.005576	 0.00166	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80168	 15430	 0.0004	 0.004379	 0.00121	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15430	 80170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15430	 80170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15431	 15443	 0.001155	 0.00477	 0.00113	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79801	 15431	 0.009315	 0.026131	 0.00673	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15431	 80171	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15431	 80171	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15432	 15433	 0.000493	 0.001973	 0.0005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15433	 80172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15433	 80172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15434	 15435	 0.001339	 0.003442	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15434	 15438	 0.000574	 0.002583	 0.00069	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15434	 80173	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15434	 80173	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15435	 15439	 0.000602	 0.004179	 0.00119	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15436	 15437	 0.016317	 0.011795	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80172	 15436	 0.005016	 0.016553	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15437	 80175	 0.014829	 0.011624	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15438	 80174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15438	 80174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15439	 80175	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15439	 80175	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15440	 15442	 0.006487	 0.015361	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79769	 15440	 0.01462	 0.010756	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80172	 15442	 0.005077	 0.013456	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15443	 15444	 0.001053	 0.004002	 0.00112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15444	 80176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15444	 80176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15445	 15447	 0.018369	 0.013279	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15445	 15448	 0.007761	 0.020114	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80176	 15445	 0.006139	 0.014252	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15446	 15448	 0.014112	 0.009136	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79771	 15448	 0.004136	 0.025426	 0.00046	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15449	 15483	 0.003123	 0.008862	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15449	 80177	 0.002431	 0.007466	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15450	 15452	 0.001573	 0.004157	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15450	 80177	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15450	 80177	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15451	 80178	 0.009706	 0.007141	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15452	 80178	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15452	 80178	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15453	 15461	 0.015103	 0.023136	 0.00032	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15453	 15468	 0.006094	 0.020331	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80178	 15453	 0.003791	 0.01295	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80177	 15454	 0.005686	 0.018967	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15454	 80181	 0.006655	 0.017108	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15455	 15456	 0.004516	 0.010482	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80171	 15455	 0.006977	 0.026842	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15456	 15467	 0.004164	 0.009665	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15457	 15467	 0.020929	 0.02099	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15458	 15460	 0.025161	 0.019722	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15458	 80183	 0.015299	 0.030291	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80176	 15459	 0.031989	 0.025074	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15461	 15463	 0.014923	 0.024888	 0.00036	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15462	 80179	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15462	 80179	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80179	 15463	 0.006436	 0.012614	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80176	 15464	 0.002028	 0.013199	 0.00027	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80178	 15464	 0.002088	 0.010022	 0.0003	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80178	 15465	 0.015289	 0.012099	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15466	 15467	 0.014527	 0.014569	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80171	 15467	 0.013249	 0.043722	 0.00071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80179	 15467	 0.00503	 0.014274	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15468	 80181	 0.014828	 0.019488	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15468	 80183	 0.005519	 0.014629	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15469	 80180	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80181	 15469	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15469	 80187	 0.000321	 0.004942	 0.01089	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15469	 80199	 0.000765	 0.007015	 0.02769	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15470	 15476	 0.00492	 0.012512	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15470	 15516	 0.007628	 0.017303	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80180	 15471	 0.002208	 0.008592	 0.00229	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15471	 80182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15471	 80182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15472	 80183	 0.008399	 0.015384	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15473	 15517	 0.005748	 0.015432	 0.0035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80180	 15473	 0.00098	 0.00563	 0.00159	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15473	 80183	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15473	 80183	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15474	 15476	 0.010276	 0.007561	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15475	 15476	 0.004723	 0.012142	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80181	 15475	 0.005619	 0.012605	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80183	 15475	 0.007878	 0.023167	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15476	 15479	 0.004426	 0.011378	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15476	 80186	 0.004836	 0.023608	 0.00049	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15477	 80186	 0.018655	 0.014623	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15478	 15481	 0.000733	 0.001996	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15478	 80184	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15478	 80184	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80184	 15479	 0.002358	 0.010333	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15480	 80185	 0.00867	 0.008757	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15480	 80193	 0.006979	 0.012544	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15481	 15482	 0.000851	 0.004056	 0.00117	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15481	 80185	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15481	 80185	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15482	 80188	 0.000839	 0.004215	 0.0011	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15483	 15485	 0.002841	 0.011052	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15483	 80186	 0.006895	 0.013651	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15484	 80186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15484	 80186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15484	 80188	 0.00217	 0.007562	 0.00175	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15485	 80189	 0.001359	 0.009327	 0.00017	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15486	 80187	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80189	 15487	 0.004777	 0.012662	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15488	 15489	 0.005497	 0.00842	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79782	 15489	 0.002327	 0.008147	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15489	 80190	 0.002417	 0.008062	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79781	 15490	 0.000329	 0.002204	 0.00068	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15490	 80190	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15490	 80190	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15491	 15509	 0.004202	 0.008599	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80190	 15491	 0.001667	 0.008136	 0.00014	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15492	 15494	 0.003052	 0.010679	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79787	 15492	 0.004668	 0.015571	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80190	 15492	 0.003538	 0.008961	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15493	 15494	 0.004765	 0.008565	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79784	 15493	 0.008434	 0.020116	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15494	 15508	 0.004092	 0.010518	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79785	 15495	 0.002781	 0.009179	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80094	 15495	 0.005468	 0.010826	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15496	 15497	 0.004231	 0.009033	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80094	 15496	 0.002277	 0.008859	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15497	 15499	 0.003308	 0.011036	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15497	 15502	 0.006342	 0.009716	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15497	 80191	 0.006677	 0.013085	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15498	 15500	 0.000312	 0.001475	 0.00035	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15498	 80191	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15498	 80191	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80191	 15499	 0.001388	 0.003567	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15499	 80192	 0.001218	 0.004063	 6e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15500	 15503	 0.000516	 0.002369	 0.00061	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15500	 80192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15500	 80192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15501	 15502	 0.010942	 0.00805	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15501	 15507	 0.005391	 0.00632	 0.00011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15501	 15508	 0.006671	 0.015256	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15503	 15527	 0.001107	 0.00508	 0.0013	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15504	 15505	 0.000732	 0.003855	 7e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15504	 15530	 0.001945	 0.010114	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80192	 15505	 0.002148	 0.012719	 0.00025	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15506	 15508	 0.001814	 0.009435	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15506	 15512	 0.001542	 0.006833	 0.00021	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15508	 15509	 0.002793	 0.008407	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80190	 15508	 0.002943	 0.019966	 0.00037	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15509	 15510	 0.002409	 0.006909	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15510	 80193	 0.004605	 0.010691	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80188	 15511	 0.001797	 0.007194	 0.00181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15511	 80193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15511	 80193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79510	 15512	 0.002329	 0.014321	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15513	 15515	 0.007167	 0.020338	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15513	 15526	 0.005859	 0.01506	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80193	 15513	 0.001571	 0.009657	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15514	 15515	 0.004356	 0.010316	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80185	 15514	 0.003537	 0.010401	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15515	 15523	 0.007858	 0.026215	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15515	 15526	 0.008315	 0.015924	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15516	 15521	 0.009395	 0.020793	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15517	 80194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15517	 80194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15517	 80195	 0.002609	 0.010771	 0.00255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15518	 15519	 0.01939	 0.015345	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80194	 15518	 0.017949	 0.014773	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15519	 15520	 0.028076	 0.022219	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80182	 15519	 0.005269	 0.013543	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80194	 15520	 0.019678	 0.019736	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15521	 15522	 0.008016	 0.008817	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15521	 15523	 0.008907	 0.016009	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15521	 80196	 0.018468	 0.022513	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15522	 15524	 0.016865	 0.012778	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15523	 80196	 0.012712	 0.015973	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15524	 80196	 0.020233	 0.020436	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15525	 15534	 3.4e-05	 0.000879	 0.06526	 2893.0	 3037.6	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15525	 80195	 0.000216	 0.017299	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79510	 15526	 0.007874	 0.018281	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80196	 15526	 0.008887	 0.029648	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80195	 15527	 0.000923	 0.004154	 0.00111	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15527	 80197	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15527	 80197	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80196	 15528	 0.029809	 0.02359	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15529	 15535	 0.001144	 0.004579	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15529	 80198	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15529	 80198	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80198	 15530	 0.003162	 0.013579	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15531	 15532	 0.001133	 0.004306	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15531	 80200	 0.002097	 0.005629	 0.00128	 132.0	 132.0	 132.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15531	 80200	 0.002097	 0.005629	 0.00128	 132.0	 132.0	 132.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15532	 15535	 0.000998	 0.004061	 0.00099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15533	 15536	 0.006528	 0.022856	 0.00063	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80088	 15533	 0.005166	 0.035461	 0.00065	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80089	 15533	 0.005172	 0.014307	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15534	 15755	 0.000202	 0.004765	 0.38583	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15534	 80199	 9.1e-05	 0.007299	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15534	 80199	 9.1e-05	 0.007299	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15535	 80202	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15535	 80202	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80202	 15536	 0.003785	 0.009729	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15537	 15538	 0.025827	 0.09037	 0.00187	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15537	 15539	 0.021363	 0.094128	 0.00163	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80045	 15537	 0.056598	 0.10524	 0.00246	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15539	 15541	 0.044974	 0.11921	 0.00302	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15539	 80203	 0.03357	 0.11199	 0.00178	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15540	 15542	 0.006623	 0.03651	 0.00853	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15540	 80203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15540	 80203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80203	 15541	 0.065747	 0.11863	 0.00172	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15542	 15543	 0.003544	 0.013787	 0.00368	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15542	 15576	 0.011916	 0.049202	 0.01164	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15543	 15547	 0.00431	 0.017793	 0.00421	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15544	 15545	 0.004337	 0.017363	 0.00437	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15544	 15547	 0.003428	 0.013473	 0.00352	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15545	 15546	 0.004627	 0.018526	 0.00467	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15546	 15580	 0.009002	 0.035022	 0.00935	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15548	 15549	 0.057933	 0.06372	 0.00085	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79481	 15549	 0.044146	 0.090344	 0.00222	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15550	 15551	 0.065971	 0.066634	 0.00088	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15551	 15552	 0.039915	 0.091287	 0.00223	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79969	 15551	 0.016493	 0.092672	 0.00172	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15552	 15553	 0.030734	 0.088151	 0.00136	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15553	 15554	 0.041594	 0.063085	 0.0009	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15554	 15555	 0.015205	 0.045765	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15554	 15562	 0.022919	 0.10213	 0.00173	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79484	 15554	 0.055596	 0.28126	 0.00549	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15555	 15556	 0.007779	 0.037533	 0.00066	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79930	 15556	 0.049945	 0.098888	 0.00145	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15557	 19244	 0.011043	 0.078128	 0.02145	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15557	 80204	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15557	 80204	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15558	 15561	 0.008782	 0.042855	 0.00074	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80204	 15559	 0.024874	 0.039703	 0.00091	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15560	 15564	 0.067467	 0.13358	 0.00196	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80204	 15560	 0.023337	 0.066933	 0.00103	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80204	 15561	 0.008371	 0.04353	 0.00094	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15562	 15563	 0.030009	 0.086072	 0.00132	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80204	 15562	 0.04065	 0.075585	 0.00177	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80204	 15563	 0.03149	 0.1125	 0.00223	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15563	 81453	 0.049911	 0.19419	 0.00324	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15563	 81453	 0.049911	 0.19419	 0.00324	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15565	 15571	 0.005038	 0.02245	 0.0061	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15565	 15623	 0.005186	 0.029797	 0.00844	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15565	 80205	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15565	 80205	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15566	 15567	 0.17502	 0.13721	 0.00176	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15566	 15568	 0.201	 0.15909	 0.002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15566	 80206	 0.16036	 0.12692	 0.0016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80205	 15568	 0.01804	 0.11091	 0.002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15568	 80206	 0.004805	 0.021293	 0.00064	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15568	 80226	 0.030466	 0.10884	 0.00216	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15568	 80226	 0.030466	 0.10884	 0.00216	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15569	 80226	 0.099682	 0.15271	 0.00214	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15570	 80226	 0.13889	 0.22176	 0.00511	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15571	 80206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15571	 80206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15572	 80207	 0.013249	 0.065738	 0.00157	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15573	 15579	 0.004874	 0.017053	 0.00565	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79508	 15574	 0.003139	 0.006451	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15574	 80208	 0.015495	 0.051691	 0.00082	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15575	 15577	 0.001496	 0.009573	 0.00322	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15576	 80207	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15576	 80207	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15577	 15581	 0.003507	 0.022932	 0.00583	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15577	 80208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15577	 80208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80208	 15578	 0.13118	 0.13396	 0.00209	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15578	 80209	 0.030093	 0.054298	 0.00078	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15579	 15580	 0.00877	 0.03447	 0.00902	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15579	 80209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15579	 80209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79973	 15581	 0.00368	 0.026026	 0.00714	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15582	 80210	 0.004306	 0.011068	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15582	 80214	 0.021472	 0.046013	 0.00081	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15583	 15584	 0.001065	 0.004187	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15583	 15586	 0.000639	 0.003836	 0.00116	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15583	 15587	 0.001326	 0.005308	 0.00134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15584	 15585	 0.000708	 0.002836	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15584	 15592	 0.000517	 0.0054	 0.00182	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15585	 15586	 0.000431	 0.00178	 0.00042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15586	 15590	 0.000764	 0.004264	 0.00109	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15587	 80210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15587	 80210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80210	 15588	 0.000969	 0.009023	 0.00017	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15588	 80218	 0.002708	 0.02521	 0.00049	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15589	 15590	 0.000559	 0.003473	 0.00098	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15589	 15607	 0.001214	 0.01059	 0.00291	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15589	 80211	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15589	 80211	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15589	 80216	 0.002376	 0.018718	 0.00547	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15590	 15593	 0.00077	 0.005901	 0.00158	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15590	 80212	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15590	 80212	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80211	 15591	 0.004575	 0.014035	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80212	 15591	 0.003628	 0.00579	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15591	 80213	 0.004912	 0.019107	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15592	 15593	 0.001317	 0.005574	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15592	 15602	 0.001418	 0.015682	 0.0047	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15593	 80213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15593	 80213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15593	 80216	 0.002277	 0.013057	 0.00434	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80213	 15594	 0.003559	 0.017659	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15594	 80217	 0.005456	 0.029193	 0.00089	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15595	 80219	 0.10584	 0.083765	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15596	 15597	 0.002185	 0.022702	 0.00702	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15596	 15609	 0.0013	 0.011897	 0.00476	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15597	 15598	 0.001395	 0.008223	 0.0067	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15597	 80214	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15597	 80214	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15598	 80215	 0.001033	 0.014913	 0.00473	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15599	 15600	 6e-05	 0.001591	 0.13108	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15599	 80215	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15599	 80215	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15600	 19925	 0.000177	 0.002724	 0.20959	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15600	 20241	 7.7e-05	 0.002039	 0.16799	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15601	 81816	 0.026764	 0.056251	 0.00102	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79506	 15602	 0.000489	 0.005595	 0.00171	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15603	 19925	 0.000129	 0.002206	 0.17167	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15603	 80216	 0.000135	 0.010812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15604	 15611	 0.005368	 0.027963	 0.00733	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80216	 15604	 0.002222	 0.013016	 0.00355	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15605	 15606	 0.022995	 0.042118	 0.00073	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15606	 15610	 0.024707	 0.063511	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80211	 15606	 0.005589	 0.029438	 0.00053	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15607	 15609	 0.002343	 0.022499	 0.00654	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15607	 80218	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15607	 80218	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80218	 15608	 0.022943	 0.026894	 0.00047	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15609	 80219	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15609	 80219	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79996	 15610	 0.019169	 0.058868	 0.0011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15611	 80220	 0.007415	 0.026976	 0.00826	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15612	 20061	 0.001307	 0.012744	 0.04438	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79998	 15612	 0.001844	 0.018123	 0.06216	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15612	 80220	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15612	 80220	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15613	 20056	 0.003143	 0.017322	 0.00405	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80220	 15613	 0.002495	 0.0155	 0.00437	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15614	 15615	 0.004171	 0.011964	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15614	 15618	 0.004754	 0.018492	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15614	 15620	 0.008716	 0.029076	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15614	 80222	 0.002826	 0.019399	 0.00035	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15615	 15616	 0.002271	 0.011083	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15615	 15621	 0.008896	 0.034609	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15616	 80221	 0.002731	 0.014385	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15617	 15623	 0.002053	 0.010314	 0.00268	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15617	 80221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15617	 80221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80221	 15618	 0.003134	 0.013966	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15619	 80222	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15619	 80222	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15620	 15625	 0.006599	 0.023574	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15621	 80224	 0.012061	 0.03704	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80222	 15622	 0.029296	 0.066454	 0.00133	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15622	 80224	 0.055988	 0.059791	 0.00126	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15623	 80223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15623	 80223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15624	 15628	 0.080713	 0.052255	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80223	 15624	 0.015293	 0.030279	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80205	 15625	 0.038736	 0.1507	 0.00252	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80205	 15625	 0.038736	 0.1507	 0.00252	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80221	 15625	 0.005527	 0.027958	 0.00049	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15626	 15629	 0.071019	 0.10349	 0.00234	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80222	 15626	 0.03729	 0.065097	 0.00101	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15627	 15629	 0.032741	 0.084165	 0.0013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79730	 15627	 0.039902	 0.081658	 0.00201	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15629	 15643	 0.031676	 0.16025	 0.00279	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79494	 15630	 0.009457	 0.057477	 0.00106	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15630	 80225	 0.023792	 0.11421	 0.00341	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15631	 80224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15631	 80224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15632	 80225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15632	 80225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15633	 15634	 0.073218	 0.056164	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15633	 15636	 0.05275	 0.041745	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15634	 15635	 0.028857	 0.057135	 0.00084	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15634	 15642	 0.039942	 0.063755	 0.00147	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79729	 15635	 0.066723	 0.1204	 0.00174	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15636	 15642	 0.020721	 0.041027	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15637	 15638	 0.038883	 0.028108	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15637	 15642	 0.029376	 0.019733	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15639	 15641	 0.043729	 0.069801	 0.00161	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15640	 15641	 0.008863	 0.034478	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15640	 15643	 0.044866	 0.1899	 0.00358	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15641	 15642	 0.01707	 0.075212	 0.00131	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15641	 15643	 0.036417	 0.17572	 0.0031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15641	 15647	 0.071194	 0.0586	 0.00119	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79471	 15641	 0.07464	 0.2667	 0.0053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79471	 15641	 0.07464	 0.2667	 0.0053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15643	 15644	 0.013141	 0.057897	 0.00101	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15643	 15645	 0.025642	 0.13663	 0.0024	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79628	 15643	 0.044837	 0.27572	 0.00497	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15644	 15645	 0.015478	 0.081535	 0.00146	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15645	 80226	 0.027932	 0.12238	 0.00263	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15645	 80998	 0.032211	 0.15463	 0.00462	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15646	 80226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15646	 80226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15648	 15651	 0.002453	 0.007532	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15648	 15797	 0.001497	 0.003849	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15649	 15650	 0.007946	 0.005629	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15649	 80275	 0.006861	 0.007546	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15650	 15652	 0.003197	 0.005332	 8e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15651	 15655	 0.002206	 0.007105	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15652	 15653	 0.001354	 0.002434	 4e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15653	 15654	 0.001271	 0.002364	 6e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15654	 15655	 0.00223	 0.005733	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15655	 15656	 0.004848	 0.008747	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15655	 80259	 0.002606	 0.014642	 0.00027	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15656	 15657	 0.000944	 0.004776	 8e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15656	 15663	 0.002018	 0.007763	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15657	 80283	 0.001026	 0.00583	 0.00011	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15658	 15659	 0.000473	 0.002172	 0.00056	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15658	 15756	 0.000449	 0.002181	 0.0005	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15658	 15847	 0.00058	 0.003009	 0.00073	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15659	 15739	 0.000328	 0.001313	 0.00033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15660	 15664	 0.004895	 0.005228	 0.00011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15660	 80275	 0.002109	 0.004133	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15661	 15662	 0.002301	 0.004555	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15661	 15665	 0.002326	 0.005508	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15661	 80275	 0.005083	 0.009171	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15662	 15663	 0.001897	 0.004876	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15663	 80227	 0.006071	 0.006677	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79512	 15664	 0.008723	 0.011465	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15665	 15666	 0.006165	 0.004879	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15665	 80230	 0.009844	 0.007458	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15667	 15673	 0.000458	 0.002064	 0.00055	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15667	 15688	 0.000445	 0.002001	 0.00053	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15667	 80227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15667	 80227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15668	 15679	 0.001063	 0.003705	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15668	 80228	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15668	 80228	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15668	 80268	 0.001597	 0.005567	 0.00129	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15669	 15670	 0.00041	 0.001881	 0.00048	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15669	 15783	 0.000534	 0.002325	 0.00066	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15670	 15671	 0.000349	 0.001719	 0.00046	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15670	 80229	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15670	 80229	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15671	 15673	 0.000195	 0.000909	 0.00023	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79511	 15671	 0.001127	 0.004585	 0.00112	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15671	 80230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15671	 80230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80229	 15672	 0.005814	 0.008621	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80230	 15672	 0.00263	 0.005208	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15674	 15675	 0.001504	 0.003809	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15674	 15684	 0.003465	 0.007284	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80229	 15674	 0.011096	 0.01133	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15675	 15676	 0.001505	 0.003868	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15676	 15677	 0.001482	 0.00381	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80227	 15677	 0.001553	 0.003678	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15678	 15680	 0.002332	 0.006617	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15678	 15819	 0.001062	 0.005099	 0.00015	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15678	 80231	 0.004135	 0.013794	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15679	 15818	 0.00071	 0.002392	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15680	 80231	 0.00155	 0.006053	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15681	 15695	 0.001537	 0.005915	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15681	 80231	 0.002054	 0.005224	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15682	 15685	 0.000585	 0.002771	 0.00067	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15682	 80231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15682	 80231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15683	 15684	 0.003128	 0.007262	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80228	 15683	 0.005251	 0.009474	 0.00014	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80231	 15684	 0.004278	 0.007206	 0.0001	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15685	 15698	 0.0012	 0.003347	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79511	 15685	 0.002999	 0.010452	 0.00242	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15685	 80232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15685	 80232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15686	 15687	 0.002344	 0.005551	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80232	 15686	 0.003153	 0.007151	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15687	 80233	 0.001115	 0.004272	 0.00012	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15688	 15847	 0.00029	 0.001329	 0.00034	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15689	 15690	 0.000256	 0.000905	 0.0002	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15689	 15847	 0.000721	 0.001872	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15689	 80233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15689	 80233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15690	 15691	 0.000267	 0.00107	 0.00027	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15691	 15736	 0.000425	 0.001754	 0.00041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15691	 80234	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15691	 80234	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15692	 15818	 0.002369	 0.006262	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15692	 15823	 0.001351	 0.006458	 0.00226	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15692	 80235	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15692	 80235	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15692	 80236	 0.000273	 0.002262	 0.0006	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80235	 15693	 0.00226	 0.01007	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15693	 80237	 0.001436	 0.005027	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15694	 15699	 0.000133	 0.001143	 0.00217	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15694	 80236	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80237	 15694	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80237	 15695	 0.011727	 0.012898	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15695	 80238	 0.001029	 0.004082	 0.00012	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80232	 15696	 0.003483	 0.007157	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15696	 80238	 0.003105	 0.005581	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80232	 15697	 0.002965	 0.011406	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80234	 15697	 0.001694	 0.00649	 0.00018	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15698	 80238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15698	 80238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15698	 80239	 0.000273	 0.001369	 0.00036	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15699	 80239	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80240	 15699	 0.000321	 0.02569	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15699	 80256	 0.000416	 0.004378	 0.00915	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15699	 80256	 0.000416	 0.004378	 0.00915	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15700	 15701	 0.006739	 0.004363	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15700	 15702	 0.002265	 0.006497	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15700	 15712	 0.003353	 0.00862	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80237	 15700	 0.006021	 0.019869	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80240	 15700	 0.003493	 0.009676	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15702	 15713	 0.001769	 0.006541	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15703	 15705	 0.0059	 0.01947	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15703	 80242	 0.005243	 0.010729	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15703	 80243	 0.006762	 0.01295	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15704	 15707	 0.000907	 0.002434	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80239	 15704	 0.001069	 0.002869	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15705	 15709	 0.008765	 0.016053	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15705	 15825	 0.006904	 0.012457	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80237	 15705	 0.006223	 0.014297	 0.00022	 69.0	 69.0	 69.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15705	 80241	 0.003333	 0.008568	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15706	 15708	 0.007832	 0.015506	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15706	 80241	 0.003311	 0.011046	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15707	 80241	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15707	 80241	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15708	 15827	 0.001842	 0.007086	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15708	 15829	 0.002616	 0.013231	 0.00023	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15709	 15828	 0.005429	 0.013752	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15710	 15711	 0.002858	 0.006768	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80240	 15710	 0.004654	 0.009936	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15711	 15712	 0.00227	 0.005774	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15711	 15727	 0.001123	 0.006906	 0.00012	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15713	 15714	 0.002164	 0.005504	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15713	 15728	 0.002997	 0.008595	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15714	 15715	 0.008837	 0.005721	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15714	 80248	 0.002572	 0.009896	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15716	 15717	 0.000676	 0.002655	 0.00069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15716	 15731	 0.000937	 0.003279	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15716	 80242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15716	 80242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15717	 15725	 0.000727	 0.002764	 0.00077	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15717	 80243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15717	 80243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15718	 15724	 0.001822	 0.006079	 0.00154	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15718	 15733	 0.000357	 0.001826	 0.0005	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15718	 80244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15718	 80244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15719	 15720	 0.002465	 0.006268	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80243	 15719	 0.004796	 0.007656	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80244	 15720	 0.001688	 0.004339	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15721	 15722	 0.011165	 0.008214	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80244	 15721	 0.005374	 0.013666	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15721	 80245	 0.009249	 0.018126	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15722	 15842	 0.013666	 0.008847	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15723	 15724	 0.001085	 0.002614	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79865	 15723	 0.004096	 0.01336	 0.00355	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15723	 80245	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15723	 80245	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15724	 80246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15724	 80246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15725	 15726	 0.000711	 0.002318	 0.00062	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15726	 80247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15726	 80247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15727	 15728	 0.002383	 0.003979	 7e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15727	 15742	 0.001972	 0.008786	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15727	 80250	 0.002724	 0.005339	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15728	 15729	 0.004453	 0.003219	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15728	 15730	 0.001931	 0.005929	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15730	 15745	 0.002437	 0.008041	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15731	 80248	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15731	 80248	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15731	 80257	 0.001566	 0.006265	 0.00212	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15732	 15733	 0.000301	 0.00182	 0.00046	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15732	 15746	 0.00033	 0.001894	 0.00054	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15734	 15735	 0.006513	 0.005105	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15734	 15844	 0.008118	 0.006424	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15734	 80255	 0.013709	 0.00991	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15735	 80255	 0.016553	 0.010716	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15736	 15738	 0.000427	 0.001494	 0.0005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15736	 80249	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15736	 80249	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80234	 15737	 0.003853	 0.007629	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80249	 15737	 0.001128	 0.005025	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15738	 15739	 0.000246	 0.001559	 0.00042	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15738	 80250	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15738	 80250	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15739	 15741	 0.000158	 0.001292	 0.00035	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15740	 80251	 0.007783	 0.005726	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15741	 80251	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15741	 80251	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15741	 80257	 0.000341	 0.003213	 0.00097	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15742	 15745	 0.002053	 0.005276	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80251	 15742	 0.001924	 0.008476	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15743	 15744	 0.005564	 0.004403	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15744	 80253	 0.001965	 0.002864	 6e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15745	 80253	 0.001187	 0.007299	 0.00013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15746	 15748	 0.000319	 0.001628	 0.00041	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15746	 80252	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15746	 80252	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15747	 15748	 0.000338	 0.001701	 0.00044	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15747	 80253	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15747	 80253	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15747	 80257	 0.000416	 0.002632	 0.00071	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15747	 80257	 0.000416	 0.002632	 0.00071	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80252	 15749	 0.0027	 0.009452	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15749	 80258	 0.001893	 0.009087	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15750	 15751	 0.001434	 0.003723	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15750	 80254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15750	 80254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15750	 80257	 0.000757	 0.00604	 0.00149	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15751	 80255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15751	 80255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15752	 15753	 0.002405	 0.005456	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80254	 15752	 0.003221	 0.006591	 0.00016	 69.0	 69.0	 69.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80255	 15752	 0.003995	 0.00791	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15753	 15765	 0.011015	 0.011017	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15753	 80260	 0.003267	 0.011671	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15754	 80257	 0.000752	 0.003185	 0.00072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15754	 80257	 0.000752	 0.003185	 0.00072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15755	 15777	 6.1e-05	 0.000847	 0.0732	 2385.0	 2504.2	 2623.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15755	 15792	 3.8e-05	 0.000944	 0.11233	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15755	 80256	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15755	 80256	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79499	 15757	 0.001814	 0.004664	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79505	 15757	 0.004684	 0.015624	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15758	 15762	 0.000248	 0.000878	 0.0002	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15759	 15771	 0.001088	 0.004427	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15760	 15796	 0.001297	 0.007975	 0.0023	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15760	 80259	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15760	 80259	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15761	 15762	 0.000521	 0.001786	 0.00043	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79500	 15763	 0.00041	 0.001538	 3e-05	 86.0	 86.0	 86.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80259	 15763	 0.002725	 0.009089	 0.00014	 78.0	 78.0	 78.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15764	 15765	 0.012741	 0.008248	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79897	 15765	 0.011228	 0.017519	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15766	 15770	 0.001473	 0.003894	 0.00091	 132.0	 132.0	 132.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15766	 15770	 0.001473	 0.003894	 0.00091	 132.0	 132.0	 132.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15766	 80260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15766	 80260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15767	 80261	 0.010783	 0.008533	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15768	 15771	 0.000533	 0.002135	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15768	 15774	 0.001311	 0.00525	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15768	 80261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15768	 80261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79505	 15769	 0.027916	 0.022093	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80261	 15769	 0.004977	 0.012657	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15769	 80262	 0.015592	 0.011271	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80257	 15770	 0.001551	 0.00506	 0.00134	 157.0	 157.0	 157.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80257	 15770	 0.001551	 0.00506	 0.00134	 157.0	 157.0	 157.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15771	 80262	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15771	 80262	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79505	 15772	 0.003543	 0.006943	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79895	 15773	 0.050682	 0.032812	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80258	 15773	 0.017277	 0.012489	 0.00019	 49.0	 49.0	 49.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15774	 80264	 0.000413	 0.003948	 0.0013	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79844	 15775	 0.003636	 0.00744	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80259	 15775	 0.013444	 0.04329	 0.00074	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15776	 15792	 2.9e-05	 0.000751	 0.07983	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15776	 80263	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15776	 80263	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15777	 80264	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15777	 80264	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15778	 15779	 0.000171	 0.00239	 0.00081	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15778	 15805	 0.000592	 0.005683	 0.00165	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15778	 80268	 0.001231	 0.009893	 0.00278	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15779	 15780	 0.000245	 0.001773	 0.00095	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15780	 15781	 0.000209	 0.001901	 0.00062	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15780	 15782	 0.00033	 0.002469	 0.0006	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15780	 15804	 0.00121	 0.005765	 0.00167	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15780	 80265	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15780	 80265	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15781	 15783	 0.000525	 0.001837	 0.00061	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15781	 80266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15781	 80266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15781	 80268	 0.000756	 0.003404	 0.00091	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15782	 15787	 0.000219	 0.001678	 0.00045	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15783	 80267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15783	 80267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80266	 15784	 0.003167	 0.008395	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80267	 15784	 0.00214	 0.006071	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15784	 80269	 0.001008	 0.005731	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15785	 80268	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15786	 15787	 0.000463	 0.003722	 0.00105	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15786	 15789	 0.000436	 0.001775	 0.00043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79511	 15786	 0.000489	 0.003094	 0.00084	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15787	 80270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15787	 80270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80270	 15788	 0.002322	 0.00539	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79511	 15789	 0.000325	 0.002253	 0.00064	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15790	 15793	 0.00079	 0.003836	 0.00088	 195.0	 195.0	 195.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15790	 80271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15790	 80271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15790	 80272	 0.000555	 0.005495	 0.00168	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80271	 15791	 0.006212	 0.012175	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15791	 80273	 0.0022	 0.012378	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15792	 80272	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15793	 15796	 0.001006	 0.00345	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79511	 15793	 0.000901	 0.003541	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15793	 80274	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15793	 80274	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15794	 80275	 0.008273	 0.005356	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15795	 15797	 0.002481	 0.00372	 7e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80274	 15795	 0.007158	 0.007796	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79511	 15796	 0.000533	 0.002257	 0.00051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15796	 80275	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15796	 80275	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80266	 15798	 0.018771	 0.013569	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15799	 15801	 0.011409	 0.017477	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15799	 15802	 0.002044	 0.007953	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80265	 15799	 0.002133	 0.009903	 0.00027	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15800	 15801	 0.013466	 0.008718	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15801	 15807	 0.001643	 0.011275	 0.00021	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15801	 15817	 0.001648	 0.010131	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15802	 80276	 0.003359	 0.008903	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15803	 80276	 0.004567	 0.008951	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15804	 80276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15804	 80276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15805	 80277	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15805	 80277	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80276	 15806	 0.001654	 0.010053	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80277	 15806	 0.001726	 0.00765	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15807	 15809	 0.001009	 0.006338	 0.00014	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15807	 80279	 0.007728	 0.013944	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15808	 15809	 0.01006	 0.007886	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15809	 15810	 0.001212	 0.008318	 0.00015	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80276	 15809	 0.002992	 0.015359	 0.00029	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79923	 15810	 0.000905	 0.006212	 0.00011	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15811	 80278	 0.01272	 0.009358	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15812	 15813	 0.00072	 0.002832	 0.00074	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15812	 15815	 0.000588	 0.002236	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15812	 80278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15812	 80278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80268	 15813	 0.001881	 0.013748	 0.00406	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15813	 80279	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15813	 80279	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15815	 15820	 0.000654	 0.002767	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15816	 15817	 0.00418	 0.009705	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15816	 80281	 0.003669	 0.007863	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15817	 80280	 0.001745	 0.008877	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15818	 80280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15818	 80280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15819	 80281	 0.001578	 0.007981	 0.00014	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15820	 80281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15820	 80281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15821	 15822	 0.001546	 0.006012	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80281	 15821	 0.00225	 0.010025	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80235	 15822	 0.002526	 0.007749	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15823	 80282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15823	 80282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15824	 15827	 0.003234	 0.012582	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80282	 15824	 0.003434	 0.015301	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15826	 15829	 0.004985	 0.013213	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80247	 15828	 0.001309	 0.005769	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15829	 15832	 0.00185	 0.011375	 0.00021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80240	 15829	 0.04589	 0.059721	 0.00084	 40.0	 40.0	 40.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80245	 15829	 0.006111	 0.018746	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15830	 15831	 0.001976	 0.006593	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15830	 15832	 0.005327	 0.009516	 0.00014	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80247	 15831	 0.002311	 0.010493	 0.00023	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15832	 15833	 0.004919	 0.009739	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15832	 15836	 0.004471	 0.012823	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15833	 15834	 0.002024	 0.006091	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15834	 15835	 0.002249	 0.010023	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79867	 15834	 0.010619	 0.012711	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15835	 15837	 0.001854	 0.005689	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15836	 15838	 0.002501	 0.006429	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79866	 15837	 0.002588	 0.013456	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79867	 15837	 0.005229	 0.017442	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15838	 15839	 0.016872	 0.013352	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79866	 15838	 0.005332	 0.028409	 0.0005	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80245	 15839	 0.006415	 0.016314	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15840	 15842	 0.004996	 0.01183	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80245	 15840	 0.023593	 0.018671	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15841	 15842	 0.003371	 0.010352	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80255	 15841	 0.007347	 0.022537	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15843	 15844	 0.011724	 0.011841	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15843	 15846	 0.019833	 0.015546	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80260	 15845	 0.042583	 0.028604	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80255	 15846	 0.014275	 0.010111	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15847	 80283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15847	 80283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15848	 15849	 0.001786	 0.006313	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15848	 15853	 0.002568	 0.007162	 0.0015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15848	 15876	 0.005882	 0.02079	 0.00468	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15848	 80284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15848	 80284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15849	 79521	 0.065849	 0.17426	 0.04085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15849	 80285	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15849	 80285	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15850	 15853	 0.003373	 0.014277	 0.00321	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15850	 15865	 0.002548	 0.010202	 0.00257	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15850	 80286	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15850	 80286	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15851	 15853	 0.001526	 0.005091	 0.00129	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15851	 15871	 0.005867	 0.021245	 0.00456	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15852	 15853	 0.001014	 0.005655	 0.00144	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15852	 15873	 0.001396	 0.008579	 0.00314	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15852	 80287	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15852	 80287	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15854	 15855	 0.028394	 0.02247	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15854	 15856	 0.01243	 0.02461	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15854	 15875	 0.012224	 0.021971	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80287	 15854	 0.005715	 0.027887	 0.00048	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15854	 80295	 0.013106	 0.050985	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80284	 15855	 0.023268	 0.018414	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15857	 15858	 0.027478	 0.021538	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80284	 15857	 0.025496	 0.038669	 0.00055	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15858	 80288	 0.012101	 0.025835	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15858	 80295	 0.015243	 0.05636	 0.00104	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80285	 15859	 0.004357	 0.013365	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15859	 80288	 0.009839	 0.0225	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15860	 15864	 0.002761	 0.008309	 0.0026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15860	 80288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15860	 80288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80288	 15861	 0.021521	 0.028285	 0.00039	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15861	 80289	 0.019981	 0.033659	 0.00048	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15862	 15863	 0.017817	 0.023187	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80286	 15862	 0.017117	 0.023856	 0.00041	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15863	 80289	 0.023834	 0.029585	 0.00064	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15863	 80290	 0.039069	 0.051349	 0.0007	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15864	 80289	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15864	 80289	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15865	 15868	 0.003699	 0.011133	 0.00348	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15865	 80290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15865	 80290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15865	 80809	 0.046711	 0.11264	 0.03183	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15866	 80291	 0.017623	 0.045301	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15866	 80296	 0.082075	 0.059333	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15867	 80291	 0.01017	 0.026142	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15867	 80793	 0.12905	 0.10213	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15868	 17392	 0.010383	 0.026957	 0.00654	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15868	 80291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15868	 80291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80291	 15869	 0.018353	 0.025578	 0.00044	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80290	 15870	 0.037359	 0.096037	 0.00149	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15870	 80292	 0.017207	 0.068862	 0.00145	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15871	 16134	 0.007308	 0.032907	 0.00876	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15871	 80292	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15871	 80292	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15872	 15873	 0.0031	 0.017812	 0.00505	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15872	 80293	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15872	 80293	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15872	 80850	 0.004989	 0.038811	 0.01008	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15873	 80294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15873	 80294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15874	 80295	 0.065614	 0.051432	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15876	 80295	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15876	 80295	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15876	 80852	 0.009704	 0.070474	 0.02436	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15877	 15878	 0.10087	 0.077373	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80295	 15877	 0.050099	 0.084397	 0.0012	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15878	 15879	 0.028602	 0.082037	 0.00126	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15878	 15880	 0.026124	 0.066439	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15879	 80826	 0.044055	 0.11204	 0.00177	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80289	 15880	 0.050681	 0.076868	 0.0011	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15880	 80296	 0.009247	 0.046248	 0.00082	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15881	 80297	 0.10618	 0.11679	 0.00156	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15882	 15883	 0.003796	 0.013229	 0.00307	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15882	 80296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15882	 80296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15883	 17395	 0.007076	 0.022006	 0.00459	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15883	 80297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15883	 80297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15884	 16879	 0.072193	 0.13223	 0.00228	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15884	 17992	 0.11769	 0.15469	 0.00212	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15885	 17991	 0.007849	 0.027356	 0.00634	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15885	 80298	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15885	 80298	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15886	 15890	 0.010142	 0.061636	 0.00114	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80298	 15886	 0.016343	 0.10048	 0.00181	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15887	 15888	 0.038143	 0.094675	 0.00157	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80298	 15887	 0.062885	 0.093248	 0.0014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15888	 15889	 0.022191	 0.085375	 0.00146	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15888	 80612	 0.10794	 0.19283	 0.00285	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15890	 16141	 0.006861	 0.053477	 0.001	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15891	 17984	 0.014552	 0.055319	 0.01549	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15891	 18646	 0.008792	 0.035202	 0.00887	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15892	 17984	 0.014334	 0.060675	 0.01366	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15892	 18647	 0.010207	 0.041538	 0.01012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15892	 80299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15892	 80299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15893	 15905	 0.040788	 0.12526	 0.00235	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80299	 15893	 0.040602	 0.10326	 0.00163	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15893	 81413	 0.519	 0.4111	 0.00518	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15895	 17649	 0.034264	 0.13183	 0.00225	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15895	 17695	 0.072579	 0.24216	 0.00384	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15895	 80301	 0.036158	 0.10371	 0.00159	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15896	 17698	 0.026726	 0.070648	 0.01654	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15896	 17721	 0.008368	 0.034553	 0.00818	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15896	 80300	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15896	 80300	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15897	 80301	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15897	 80301	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15898	 15899	 0.13522	 0.097755	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80301	 15898	 0.055202	 0.076934	 0.00132	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15898	 80907	 0.071576	 0.23881	 0.00379	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15900	 15902	 0.006918	 0.036775	 0.00853	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15900	 18649	 0.006603	 0.033727	 0.00848	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15900	 80302	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15900	 80302	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15901	 17942	 0.057055	 0.19035	 0.00302	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80302	 15901	 0.047	 0.11953	 0.00189	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15902	 15904	 0.004966	 0.02236	 0.00595	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15902	 80303	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15902	 80303	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15903	 15905	 0.029731	 0.085273	 0.00131	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80303	 15903	 0.0067	 0.043805	 0.00101	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15903	 81413	 0.12009	 0.4008	 0.00636	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15904	 17984	 0.012293	 0.067712	 0.02446	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15904	 80304	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15904	 80304	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15904	 80976	 0.005975	 0.062077	 0.0192	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15905	 80988	 0.52519	 0.41602	 0.00524	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15906	 15908	 0.000123	 0.001465	 0.1099	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15906	 16151	 0.000938	 0.011212	 0.84304	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15906	 19243	 0.000414	 0.007023	 0.55477	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15906	 80305	 0.000127	 0.010176	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15907	 16083	 0.016966	 0.044842	 0.0105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15907	 17259	 0.02964	 0.078354	 0.01835	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80305	 15907	 0.006637	 0.04204	 0.01141	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15907	 80307	 0.002831	 0.027663	 0.00776	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15908	 39658	 0.000609	 0.010909	 0.77583	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	15908	 80307	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15909	 17257	 0.20575	 0.15591	 0.00215	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80308	 15909	 0.096593	 0.062537	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15910	 17258	 0.00947	 0.025028	 0.00586	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80307	 15910	 0.010877	 0.036649	 0.00911	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15910	 80309	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15910	 80309	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15911	 15918	 0.006321	 0.028166	 0.00765	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15911	 17941	 0.012648	 0.078611	 0.0222	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15912	 15913	 0.004951	 0.025292	 0.00636	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15912	 15921	 0.007651	 0.04846	 0.01315	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15912	 17017	 0.009867	 0.0578	 0.01575	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15913	 15921	 0.006912	 0.028127	 0.00685	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15913	 17017	 0.012122	 0.08134	 0.01964	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15913	 80310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15913	 80310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15913	 80394	 0.01114	 0.072856	 0.01853	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15914	 15916	 0.032066	 0.07097	 0.00116	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80310	 15914	 0.007804	 0.022145	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15915	 15916	 0.019227	 0.048897	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15915	 15920	 0.042469	 0.12489	 0.00256	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15916	 15917	 0.079269	 0.094895	 0.00158	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79553	 15917	 0.034414	 0.1741	 0.00303	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15917	 80382	 0.19783	 0.65368	 0.01061	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15919	 17411	 0.003121	 0.029971	 0.00872	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79553	 15920	 0.068401	 0.17585	 0.00272	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15921	 80311	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15921	 80311	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15921	 80394	 0.005099	 0.043734	 0.01245	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15922	 15923	 0.0118	 0.047245	 0.0119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15922	 16189	 0.01199	 0.047128	 0.01233	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15922	 16629	 0.01485	 0.095691	 0.0251	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15922	 17017	 0.014272	 0.088713	 0.02505	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15923	 15924	 0.010614	 0.036413	 0.00872	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15923	 16854	 0.003499	 0.033598	 0.00977	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15923	 17017	 0.019141	 0.091265	 0.02645	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15923	 17462	 0.022621	 0.1519	 0.03672	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15923	 80312	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15923	 80312	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15924	 17020	 0.010188	 0.043122	 0.0097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15924	 80313	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15924	 80313	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15925	 16188	 0.2001	 0.34491	 0.00549	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15925	 17019	 0.043724	 0.21099	 0.00373	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80312	 15925	 0.11725	 0.27227	 0.00405	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15926	 17631	 0.052944	 0.20371	 0.00348	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15926	 80316	 0.049	 0.18853	 0.00322	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15927	 16282	 0.038934	 0.15147	 0.00253	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79571	 15927	 0.036601	 0.097014	 0.00246	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15927	 80315	 0.067648	 0.19404	 0.00298	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15928	 80314	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15928	 80314	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15929	 15930	 0.010033	 0.040831	 0.00995	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15929	 15931	 0.015863	 0.045949	 0.01108	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15929	 80315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15929	 80315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15930	 17548	 0.007344	 0.029405	 0.00741	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15931	 80316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15931	 80316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15932	 17435	 0.008834	 0.023348	 0.00546	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79535	 15932	 0.00743	 0.026905	 0.00577	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15932	 80317	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15932	 80317	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15933	 15935	 0.047986	 0.095009	 0.00139	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80317	 15933	 0.055519	 0.040847	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15934	 15962	 0.006579	 0.027846	 0.00627	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79535	 15934	 0.006122	 0.02451	 0.00617	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15935	 15936	 0.020885	 0.04135	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79536	 15935	 0.026524	 0.046302	 0.00072	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15936	 80769	 0.012795	 0.049776	 0.00083	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15937	 17337	 0.022702	 0.088318	 0.00147	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15937	 80318	 0.018301	 0.10078	 0.00227	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15937	 80780	 0.041668	 0.082499	 0.00121	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15938	 15939	 0.005617	 0.03134	 0.00801	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15938	 15962	 0.005205	 0.026589	 0.00669	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15939	 15951	 0.01301	 0.045989	 0.01036	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79519	 15939	 0.002277	 0.025626	 0.00673	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15939	 80318	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15939	 80318	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15940	 15945	 0.019675	 0.050577	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15940	 15963	 0.094436	 0.063437	 0.00112	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15940	 80321	 0.028321	 0.065066	 0.00099	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15941	 15946	 0.010094	 0.03927	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79545	 15941	 0.014359	 0.080683	 0.00149	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15942	 15947	 0.042723	 0.03381	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79545	 15942	 0.013192	 0.026997	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79554	 15942	 0.022791	 0.052912	 0.00079	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79518	 15943	 2.9e-05	 0.00048	 0.0018	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15943	 80319	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15943	 80319	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79554	 15944	 0.097356	 0.07038	 0.00107	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15945	 15946	 0.016901	 0.048475	 0.00075	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15948	 15950	 0.073484	 0.054065	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15949	 15951	 0.00591	 0.0214	 0.00459	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15949	 80320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15949	 80320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80320	 15950	 0.018531	 0.041574	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15950	 80321	 0.009737	 0.031222	 0.00077	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15950	 80390	 0.22116	 0.43369	 0.0065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15951	 80321	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15951	 80321	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15952	 80322	 0.047238	 0.030582	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15953	 15956	 0.082663	 0.068041	 0.00138	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15953	 80322	 0.11615	 0.075196	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15954	 15958	 0.022211	 0.086407	 0.00144	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15954	 15959	 0.045923	 0.036343	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80320	 15954	 0.008587	 0.053923	 0.00118	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15955	 15957	 0.007244	 0.019144	 0.00448	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15955	 80322	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15955	 80322	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15956	 15958	 0.038753	 0.041384	 0.00088	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15957	 80323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15957	 80323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15958	 15960	 0.022271	 0.014418	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80323	 15958	 0.025921	 0.023227	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80320	 15961	 0.050627	 0.09135	 0.00132	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80318	 15963	 0.062638	 0.09774	 0.00163	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15964	 15969	 0.004671	 0.012006	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15964	 15970	 0.003443	 0.007045	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15965	 15966	 0.01247	 0.011694	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15965	 15977	 0.015753	 0.03119	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15966	 15967	 0.012421	 0.013529	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15966	 15969	 0.011741	 0.023246	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15968	 15969	 0.003326	 0.02045	 0.00037	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15968	 15980	 0.010725	 0.028425	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15968	 80325	 0.02029	 0.040173	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15969	 15981	 0.00493	 0.017263	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15969	 80324	 0.004691	 0.022518	 0.00067	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15970	 15971	 0.004758	 0.013645	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15971	 80324	 0.005129	 0.019954	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15972	 15992	 0.003468	 0.019098	 0.0069	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15972	 80324	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15972	 80324	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15972	 80868	 0.016324	 0.14013	 0.03993	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15973	 15974	 0.02219	 0.01756	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80324	 15973	 0.021782	 0.014631	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15974	 15975	 0.008819	 0.017283	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15974	 15998	 0.01885	 0.047939	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80324	 15974	 0.043969	 0.033727	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15975	 15976	 0.004158	 0.016176	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15975	 15977	 0.012197	 0.036711	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15976	 15997	 0.013215	 0.040583	 0.00076	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15976	 15998	 0.006703	 0.019225	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15977	 15978	 0.011891	 0.027602	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15977	 16003	 0.021426	 0.042421	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79568	 15977	 0.070427	 0.37984	 0.00766	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15977	 80329	 0.051897	 0.10908	 0.00199	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	15978	 80325	 0.012946	 0.032924	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15979	 16005	 0.006287	 0.017533	 0.00368	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15979	 80325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15979	 80325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15980	 16006	 0.021961	 0.062987	 0.00097	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15981	 15982	 0.005245	 0.020405	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15982	 16010	 0.014985	 0.049987	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15982	 16011	 0.035337	 0.087709	 0.00146	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80324	 15982	 0.013762	 0.059104	 0.00108	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15983	 15984	 0.023887	 0.031395	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80324	 15984	 0.007361	 0.035515	 0.00063	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15984	 80326	 0.008703	 0.024961	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80324	 15985	 0.014536	 0.042745	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15985	 80328	 0.015985	 0.061498	 0.00105	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15986	 16017	 0.007095	 0.018751	 0.00439	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	15986	 80326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15986	 80326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15987	 15989	 0.013689	 0.035188	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15987	 16832	 0.021578	 0.033055	 0.00046	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15987	 80327	 0.022179	 0.063614	 0.00098	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15988	 15990	 0.051241	 0.040552	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80324	 15988	 0.03709	 0.079189	 0.00179	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	15989	 15990	 0.029511	 0.045208	 0.00063	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15990	 16016	 0.059253	 0.038361	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15990	 16832	 0.023769	 0.079293	 0.00126	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80326	 15990	 0.011498	 0.044235	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15991	 15992	 0.004886	 0.01727	 0.00389	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	15991	 80327	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15991	 80327	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15992	 16811	 0.008063	 0.050038	 0.01212	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15992	 80328	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15992	 80328	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15993	 15994	 0.008471	 0.04815	 0.00087	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	15993	 16812	 0.024581	 0.070503	 0.00108	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15993	 16823	 0.024722	 0.086505	 0.00179	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80328	 15994	 0.014344	 0.07256	 0.00126	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15995	 15996	 0.039726	 0.031439	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	15995	 15997	 0.029513	 0.054055	 0.00093	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15997	 15998	 0.006895	 0.02211	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15997	 16001	 0.065022	 0.065675	 0.00087	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80328	 15997	 0.017282	 0.053015	 0.00144	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15999	 16000	 0.021558	 0.099963	 0.00208	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	15999	 80601	 0.014873	 0.065908	 0.00198	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16000	 80330	 0.014053	 0.071088	 0.00124	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16002	 16003	 0.055549	 0.043961	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80325	 16004	 0.040568	 0.040975	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16004	 80329	 0.064384	 0.049387	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16005	 16008	 0.006095	 0.016108	 0.00377	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16005	 80329	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16005	 80329	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16006	 16009	 0.020105	 0.089961	 0.00185	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80329	 16006	 0.045484	 0.087107	 0.00137	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16007	 17015	 0.008794	 0.028682	 0.00761	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16007	 80330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16007	 80330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16008	 17015	 0.010427	 0.027558	 0.00645	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16009	 17016	 0.063692	 0.12611	 0.00185	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16009	 18024	 0.024063	 0.10658	 0.00243	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16010	 16014	 0.02405	 0.092525	 0.00158	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16011	 16013	 0.025458	 0.064744	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16012	 16017	 0.007058	 0.044704	 0.01213	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16012	 16998	 0.007337	 0.030292	 0.00717	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16012	 80331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16012	 80331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80331	 16013	 0.088888	 0.090767	 0.00141	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80331	 16014	 0.045759	 0.05033	 0.00067	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16014	 80654	 0.063767	 0.16393	 0.00254	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80326	 16015	 0.039976	 0.026853	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16016	 16831	 0.039497	 0.078202	 0.00115	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16017	 16018	 0.003884	 0.016038	 0.00379	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16018	 16019	 0.005879	 0.024882	 0.0056	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16019	 17610	 0.007141	 0.028067	 0.00734	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16020	 16022	 0.08531	 0.080004	 0.00124	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16020	 80353	 0.076119	 0.15072	 0.00221	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16021	 16022	 0.097872	 0.14994	 0.00211	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16021	 16992	 0.24552	 0.15899	 0.00303	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80309	 16021	 0.11441	 0.20646	 0.00298	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16022	 80335	 0.011999	 0.053465	 0.00091	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16023	 16037	 0.005302	 0.023628	 0.00642	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16023	 16997	 0.008789	 0.054617	 0.01542	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16023	 80332	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16023	 80332	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16024	 16035	 0.036433	 0.092655	 0.00147	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80332	 16024	 0.018631	 0.053436	 0.00082	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16025	 80335	 0.041584	 0.032909	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16026	 16028	 0.025165	 0.045407	 0.00066	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16026	 16082	 0.036733	 0.12254	 0.00194	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16026	 80335	 0.007682	 0.043166	 0.0008	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16027	 16028	 0.01571	 0.036092	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16027	 80333	 0.028601	 0.053181	 0.00124	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16029	 80333	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16029	 80333	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16029	 80369	 0.00826	 0.03937	 0.01141	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79573	 16030	 0.018925	 0.035189	 0.00082	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80333	 16030	 0.030702	 0.057087	 0.00134	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16031	 80334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16031	 80334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16031	 80369	 0.00225	 0.011306	 0.00294	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80333	 16032	 0.073033	 0.074575	 0.00116	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16033	 16165	 0.062973	 0.085843	 0.0019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80333	 16033	 0.068192	 0.072825	 0.00154	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80334	 16033	 0.075909	 0.082682	 0.00113	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16034	 16166	 0.044469	 0.11432	 0.00177	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16034	 16192	 0.046609	 0.15549	 0.00246	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16035	 16036	 0.10524	 0.083291	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80332	 16035	 0.037907	 0.12646	 0.002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80333	 16035	 0.028694	 0.10994	 0.00311	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16037	 80335	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16037	 80335	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16037	 80372	 0.037777	 0.099881	 0.02339	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16038	 16055	 0.079418	 0.074477	 0.00115	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16038	 80345	 0.028576	 0.058479	 0.00144	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16039	 16056	 0.064947	 0.12729	 0.00191	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16039	 17590	 0.030492	 0.10172	 0.00161	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16039	 80346	 0.015574	 0.068617	 0.00119	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16040	 80336	 0.002681	 0.018406	 0.00034	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16040	 80864	 0.0039	 0.026772	 0.00049	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16041	 16042	 0.001466	 0.006102	 0.0019	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16041	 16043	 0.000719	 0.005419	 0.0015	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16041	 80336	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16041	 80336	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16041	 80863	 0.000732	 0.009569	 0.00382	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16042	 16065	 0.001149	 0.005664	 0.00153	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16042	 80337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16042	 80337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16043	 16045	 0.000556	 0.004382	 0.00128	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80336	 16044	 0.025332	 0.030881	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80337	 16044	 0.007736	 0.011272	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16045	 16047	 0.001154	 0.010743	 0.00333	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16045	 80338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16045	 80338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80337	 16046	 0.004759	 0.029255	 0.00053	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16046	 80347	 0.006946	 0.039481	 0.00071	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16047	 16048	 0.002225	 0.013677	 0.00394	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16047	 16049	 0.003049	 0.016208	 0.00376	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16047	 80339	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16047	 80339	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16048	 17249	 0.001837	 0.012322	 0.00297	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16049	 16050	 0.001465	 0.008326	 0.00241	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16050	 16071	 0.001045	 0.011073	 0.00329	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16050	 17143	 0.000509	 0.006519	 0.00195	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16050	 80340	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16050	 80340	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16051	 17697	 0.016947	 0.046144	 0.01017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79517	 16051	 0.004939	 0.069068	 0.02343	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16051	 80341	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16051	 80341	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16052	 17167	 0.018936	 0.046999	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80341	 16052	 0.022771	 0.041708	 0.00072	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16053	 16055	 0.016823	 0.10224	 0.00189	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80341	 16053	 0.007284	 0.050002	 0.00091	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16054	 17175	 0.018886	 0.073756	 0.00164	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80300	 16054	 0.36921	 0.40636	 0.00543	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16055	 16056	 0.020694	 0.079615	 0.00136	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16055	 17645	 0.062754	 0.089087	 0.00147	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16056	 17588	 0.045352	 0.1513	 0.0024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16056	 80884	 0.059643	 0.15109	 0.00299	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16057	 17588	 0.11503	 0.077275	 0.00136	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16058	 16068	 0.002042	 0.011615	 0.00036	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16058	 80342	 0.001649	 0.008822	 0.00027	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16058	 80345	 0.008306	 0.025508	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16059	 16061	 0.002057	 0.006063	 0.00141	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16059	 16064	 0.000748	 0.003897	 0.00102	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16059	 80342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16059	 80342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16060	 16073	 0.00274	 0.010768	 0.00282	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16060	 80343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16060	 80343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16061	 80344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16061	 80344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80343	 16062	 0.003679	 0.022361	 0.00041	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80344	 16062	 0.003441	 0.023348	 0.00044	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16063	 80345	 0.019209	 0.038033	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16064	 16065	 0.002089	 0.006968	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16064	 80345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16064	 80345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16065	 16067	 0.002306	 0.015076	 0.00383	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16065	 80346	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16065	 80346	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16065	 80860	 0.008439	 0.052375	 0.01269	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80346	 16066	 0.017039	 0.028302	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16067	 16071	 0.001249	 0.010901	 0.00299	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16067	 80347	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16067	 80347	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16068	 16069	 0.005734	 0.027979	 0.00048	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80343	 16068	 0.005195	 0.028609	 0.00065	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16069	 16070	 0.02449	 0.018018	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80347	 16069	 0.007246	 0.019155	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16069	 80348	 0.003104	 0.025824	 0.00049	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16071	 80348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16071	 80348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80348	 16072	 0.008801	 0.027945	 0.00049	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16072	 80349	 0.010335	 0.03976	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16073	 80349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16073	 80349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80341	 16074	 0.003414	 0.019419	 0.0006	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80349	 16074	 0.003951	 0.024288	 0.00044	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16075	 16077	 0.004449	 0.011759	 0.00275	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16075	 16079	 0.00197	 0.008017	 0.00195	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16075	 80350	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16075	 80350	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16075	 80372	 0.01998	 0.07855	 0.02056	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80350	 16076	 0.00633	 0.034643	 0.00068	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16076	 80353	 0.010592	 0.098608	 0.00191	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16077	 16080	 0.005669	 0.019446	 0.00466	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16077	 80351	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16077	 80351	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16078	 16081	 0.017457	 0.044876	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80350	 16078	 0.059621	 0.062728	 0.00092	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80351	 16078	 0.041103	 0.041516	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16078	 80352	 0.00682	 0.035924	 0.00064	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16079	 16085	 0.0053	 0.025721	 0.00588	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16080	 16091	 0.003031	 0.012135	 0.00306	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16080	 80352	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16080	 80352	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16081	 16089	 0.017466	 0.038658	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80333	 16081	 0.015565	 0.088478	 0.0016	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80352	 16081	 0.0147	 0.033618	 0.00082	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80351	 16082	 0.02383	 0.05643	 0.00103	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80305	 16083	 0.033054	 0.092203	 0.01936	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16083	 80353	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16083	 80353	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16083	 80868	 0.026665	 0.16911	 0.04598	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16084	 16085	 0.012723	 0.037512	 0.00873	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16084	 17952	 0.008985	 0.029975	 0.0076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16085	 17989	 0.010081	 0.060516	 0.01833	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16085	 80354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16085	 80354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16086	 17991	 0.011479	 0.048587	 0.01093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16086	 80355	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16086	 80355	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80352	 16087	 0.005746	 0.032662	 0.00059	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80355	 16087	 0.016878	 0.081433	 0.00144	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16088	 16147	 0.017694	 0.046897	 0.00119	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80355	 16088	 0.02143	 0.12182	 0.0022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16088	 80367	 0.020938	 0.085573	 0.00173	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16089	 80356	 0.013864	 0.039765	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79573	 16090	 0.018925	 0.020815	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16091	 80356	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16091	 80356	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16092	 16320	 0.007176	 0.02963	 0.00701	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16092	 17418	 0.003197	 0.013531	 0.00304	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16093	 16320	 0.01172	 0.040207	 0.00963	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16093	 16322	 0.013654	 0.054672	 0.01378	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16093	 80799	 0.008479	 0.034504	 0.00841	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16094	 16095	 0.18592	 0.1368	 0.002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16095	 16098	 0.12075	 0.185	 0.0026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16096	 16101	 0.1295	 0.10249	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16097	 16101	 0.092378	 0.066781	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16098	 80357	 0.038005	 0.12679	 0.00201	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16099	 16100	 0.028855	 0.022835	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16100	 80357	 0.024581	 0.039235	 0.0009	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16101	 80357	 0.029708	 0.076367	 0.00118	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16102	 16104	 0.024776	 0.01604	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16102	 16107	 0.006868	 0.007334	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16102	 16128	 0.043867	 0.034716	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16102	 80358	 0.029174	 0.057763	 0.00085	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16103	 16105	 0.008475	 0.023634	 0.00496	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16103	 80357	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16103	 80357	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16103	 80400	 0.011677	 0.065161	 0.01665	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80357	 16104	 0.017485	 0.015667	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16105	 80358	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16105	 80358	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16105	 80400	 0.01241	 0.04969	 0.01252	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16106	 16107	 0.021883	 0.014167	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16106	 16108	 0.034965	 0.027407	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80357	 16107	 0.043858	 0.031705	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80358	 16107	 0.029859	 0.059119	 0.00087	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16108	 16117	 0.04906	 0.097137	 0.00143	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80357	 16108	 0.033079	 0.023432	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16109	 16114	 0.018745	 0.033822	 0.00049	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16109	 16120	 0.09103	 0.13807	 0.00198	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16110	 16111	 0.001644	 0.004761	 0.00115	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16110	 16126	 0.00448	 0.013604	 0.00298	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16111	 16116	 0.003721	 0.012136	 0.00322	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16112	 16127	 0.062384	 0.04937	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80358	 16112	 0.032363	 0.025612	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80358	 16113	 0.035411	 0.026053	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16114	 80359	 0.033812	 0.061931	 0.00107	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16115	 16122	 0.041883	 0.085714	 0.00211	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16115	 80359	 0.015985	 0.03626	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16116	 16246	 0.003646	 0.020004	 0.00529	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16116	 80359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16116	 80359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16117	 80402	 0.032692	 0.084038	 0.0013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16118	 16122	 0.13619	 0.10779	 0.00136	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16118	 80783	 0.090521	 0.066601	 0.00097	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16119	 16124	 0.004897	 0.012943	 0.00303	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16119	 17351	 0.008318	 0.021982	 0.00515	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16119	 80360	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16119	 80360	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80360	 16120	 0.035062	 0.027483	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16121	 16122	 0.083963	 0.060698	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80360	 16121	 0.10761	 0.082547	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80360	 16123	 0.061109	 0.04496	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16124	 16125	 0.004154	 0.010785	 0.00262	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16125	 16126	 0.009287	 0.02738	 0.00637	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80357	 16129	 0.045378	 0.035912	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16130	 19395	 0.004313	 0.034652	 0.00974	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79525	 16130	 0.003961	 0.028758	 0.00994	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16130	 80361	 0.006519	 0.033301	 0.00838	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16130	 81220	 0.024977	 0.067068	 0.0152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16131	 17573	 0.003572	 0.023191	 0.0462	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16131	 18758	 0.007047	 0.048097	 0.08669	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79524	 16131	 0.003367	 0.021858	 0.04355	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16131	 80361	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80362	 16131	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16132	 16133	 0.005528	 0.025361	 0.0065	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16132	 19391	 0.00338	 0.014711	 0.00419	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16132	 80363	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16132	 80363	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16133	 17558	 0.009543	 0.024775	 0.00601	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80361	 16133	 0.010666	 0.031941	 0.0072	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16133	 80850	 0.006183	 0.039165	 0.01063	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80361	 16134	 0.01686	 0.043774	 0.01063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16134	 80364	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16134	 80364	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16134	 80850	 0.007666	 0.030129	 0.00788	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80362	 16135	 0.19257	 0.15242	 0.00192	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16136	 16138	 0.018557	 0.055855	 0.00109	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16137	 80365	 0.011252	 0.054906	 0.00095	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16137	 80375	 0.009366	 0.041736	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16138	 80365	 0.005808	 0.054069	 0.00105	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16139	 16143	 0.001586	 0.010215	 0.00268	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79517	 16139	 0.016424	 0.10408	 0.02827	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16139	 80365	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16139	 80365	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16140	 16141	 0.011617	 0.035674	 0.00067	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80365	 16140	 0.018457	 0.04892	 0.00124	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16141	 16144	 0.002743	 0.023298	 0.00054	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16141	 16147	 0.010324	 0.029612	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16142	 80366	 0.031278	 0.02025	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16143	 80366	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16143	 80366	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16143	 80372	 0.001031	 0.006398	 0.00155	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80366	 16144	 0.012105	 0.040383	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16144	 80367	 0.002415	 0.016574	 0.0003	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16145	 16146	 0.001815	 0.004711	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16145	 80367	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16145	 80367	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16145	 80372	 0.001247	 0.01002	 0.00282	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16146	 80368	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16146	 80368	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16148	 16209	 0.004136	 0.057775	 0.11193	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16148	 17943	 0.010299	 0.072325	 0.1234	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16148	 80369	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80370	 16148	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16148	 80371	 0.001004	 0.006774	 0.01247	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16149	 16152	 0.013814	 0.035511	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80370	 16149	 0.006866	 0.022904	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80334	 16150	 0.030962	 0.079592	 0.00123	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16150	 80373	 0.012944	 0.037126	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16151	 80371	 9.6e-05	 0.007684	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16152	 16165	 0.048413	 0.048555	 0.00079	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16153	 16165	 0.043337	 0.078197	 0.00113	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80373	 16153	 0.01401	 0.046235	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16154	 16155	 0.001726	 0.007918	 0.00203	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16154	 16163	 0.002374	 0.008305	 0.00275	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16155	 16157	 0.005019	 0.017217	 0.00412	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16155	 80374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16155	 80374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16156	 80375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16156	 80375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16156	 80614	 0.018035	 0.07222	 0.0182	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16157	 16162	 0.004597	 0.02109	 0.0054	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16157	 80376	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16157	 80376	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16158	 16159	 0.009911	 0.056337	 0.00102	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80376	 16158	 0.008334	 0.054248	 0.0011	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16159	 16891	 0.022845	 0.064827	 0.00102	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16159	 80617	 0.044414	 0.10075	 0.00201	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16160	 80377	 0.050244	 0.076959	 0.00134	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16160	 80652	 0.025945	 0.066696	 0.00103	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80376	 16161	 0.018275	 0.060965	 0.00097	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16161	 80378	 0.031352	 0.089922	 0.00138	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16162	 16164	 0.012547	 0.032255	 0.00799	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16162	 16984	 0.003699	 0.021665	 0.0059	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16162	 16987	 0.006669	 0.027765	 0.00866	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16162	 80377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16162	 80377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80372	 16163	 0.004028	 0.016128	 0.00406	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80372	 16164	 0.008744	 0.033238	 0.0093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16164	 80378	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16164	 80378	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16166	 16980	 0.10455	 0.067689	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80378	 16166	 0.070738	 0.13864	 0.00208	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16167	 16168	 0.016161	 0.062174	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16167	 16169	 0.018972	 0.048771	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16167	 16430	 0.032091	 0.065672	 0.00162	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16168	 17827	 0.15972	 0.16134	 0.00214	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16168	 80380	 0.017904	 0.10178	 0.00184	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16169	 16170	 0.02965	 0.058705	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16170	 17384	 0.080636	 0.08484	 0.00124	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16171	 16173	 0.056357	 0.13085	 0.00195	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16171	 80380	 0.057114	 0.15139	 0.00384	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16172	 16173	 0.030701	 0.031349	 0.00049	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16173	 16174	 0.014039	 0.036087	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16174	 80825	 0.020281	 0.12326	 0.00227	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16175	 16176	 0.011078	 0.043545	 0.01139	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16175	 17500	 0.00846	 0.033872	 0.00853	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16176	 80638	 0.009332	 0.038532	 0.00912	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16177	 16430	 0.044795	 0.080515	 0.00145	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16177	 17825	 0.011448	 0.027304	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16177	 17857	 0.063707	 0.050417	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16178	 80379	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16178	 80379	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80379	 16179	 0.009391	 0.038215	 0.00931	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16179	 80380	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16179	 80380	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16180	 16181	 0.047259	 0.10858	 0.00165	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79559	 16180	 0.12545	 0.13799	 0.00184	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16180	 80540	 0.054974	 0.11251	 0.00277	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16180	 80656	 0.16714	 0.21971	 0.00301	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16181	 16633	 0.037862	 0.11628	 0.00218	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16181	 80381	 0.043652	 0.10029	 0.00152	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16183	 17010	 0.022085	 0.11511	 0.03021	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16183	 80381	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16183	 80381	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16184	 16185	 0.030558	 0.10699	 0.00296	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80381	 16184	 0.027311	 0.10508	 0.00179	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79544	 16185	 0.013177	 0.057573	 0.00151	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79544	 16186	 0.11079	 0.14101	 0.00207	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16187	 17439	 0.00559	 0.036011	 0.00944	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16187	 17939	 0.008722	 0.038214	 0.01315	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16187	 17941	 0.00898	 0.056886	 0.01544	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16187	 80382	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16187	 80382	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16187	 80799	 0.026915	 0.094224	 0.03125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16188	 17440	 0.019686	 0.09179	 0.00211	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80382	 16188	 0.017194	 0.076615	 0.0013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16188	 80805	 0.097717	 0.22689	 0.00337	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16189	 17439	 0.008562	 0.025244	 0.00587	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16189	 19799	 0.022002	 0.144	 0.03666	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16189	 80383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16189	 80383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16190	 16191	 0.11035	 0.16904	 0.00294	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16190	 27954	 0.17348	 0.39704	 0.0097	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79559	 16190	 0.14771	 0.24638	 0.00358	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80381	 16191	 0.068912	 0.13645	 0.002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16192	 16194	 0.055556	 0.12764	 0.00194	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16192	 17608	 0.061373	 0.1885	 0.00354	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16193	 80387	 0.15911	 0.12593	 0.00159	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16194	 16202	 0.028132	 0.072911	 0.00138	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16195	 16202	 0.010898	 0.061949	 0.00112	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16195	 16576	 0.012312	 0.053942	 0.00116	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16196	 16199	 0.025041	 0.059297	 0.00108	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16196	 16573	 0.043896	 0.072913	 0.00154	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16196	 80384	 0.098644	 0.078068	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16197	 16198	 0.002044	 0.005306	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16197	 80384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16197	 80384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16198	 16626	 0.013487	 0.035645	 0.00834	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16198	 80385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16198	 80385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16199	 16201	 0.019678	 0.075708	 0.00129	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80384	 16199	 0.014853	 0.049014	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16200	 16212	 0.043137	 0.14236	 0.00231	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16200	 16213	 0.021382	 0.085569	 0.00181	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80385	 16200	 0.011096	 0.053263	 0.00159	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16201	 80386	 0.00925	 0.040988	 0.00123	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16202	 80386	 0.008532	 0.042674	 0.00076	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16202	 80387	 0.029765	 0.12165	 0.00246	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16203	 16206	 0.001391	 0.012325	 0.00328	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16203	 16207	 0.001983	 0.011065	 0.00283	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16203	 80386	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16203	 80386	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16203	 80530	 0.009587	 0.072232	 0.02005	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80386	 16204	 0.012772	 0.025031	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80386	 16205	 0.011937	 0.021864	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16206	 16211	 0.001789	 0.015341	 0.00437	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16207	 16208	 0.002681	 0.016982	 0.00461	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79565	 16208	 0.00474	 0.035708	 0.00991	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16208	 80387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16208	 80387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79564	 16209	 0.000549	 0.00419	 0.01557	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16209	 80388	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16209	 80388	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16210	 28009	 0.010066	 0.040965	 0.00998	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79565	 16210	 0.003	 0.015626	 0.0041	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16210	 80389	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16210	 80389	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80388	 16211	 0.002006	 0.01825	 0.00461	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16212	 16213	 0.019183	 0.050844	 0.00129	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80389	 16212	 0.015096	 0.11035	 0.00203	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16214	 16222	 0.027778	 0.09725	 0.03225	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79535	 16214	 0.019819	 0.064654	 0.01717	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16214	 80390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16214	 80390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16215	 16216	 0.07879	 0.12577	 0.0029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79558	 16215	 0.15826	 0.15986	 0.00212	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80390	 16215	 0.077745	 0.093071	 0.00155	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16216	 16217	 0.15574	 0.11459	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80316	 16216	 0.07781	 0.12421	 0.00286	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16217	 16221	 0.063139	 0.10637	 0.00152	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16218	 16220	 0.002265	 0.021612	 0.00876	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16218	 17550	 0.003593	 0.041086	 0.01151	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16219	 80391	 0.048603	 0.12494	 0.00193	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16220	 16222	 0.003857	 0.020768	 0.00571	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16220	 80391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16220	 80391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16221	 80392	 0.027016	 0.069447	 0.00107	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16222	 80392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16222	 80392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16223	 16225	 0.23998	 0.1766	 0.00258	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80392	 16223	 0.009482	 0.053898	 0.00098	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16224	 16225	 0.031968	 0.074219	 0.0011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16224	 16226	 0.077345	 0.13603	 0.00256	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80391	 16224	 0.061907	 0.14371	 0.00274	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80322	 16226	 0.12503	 0.22336	 0.0033	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16227	 16239	 0.004161	 0.015814	 0.00443	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16227	 16241	 0.003474	 0.015936	 0.00408	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16227	 80393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16227	 80393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79553	 16228	 0.038176	 0.2621	 0.00478	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79570	 16228	 0.045795	 0.10632	 0.00158	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80393	 16228	 0.027265	 0.1171	 0.00214	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16229	 17421	 0.009358	 0.086215	 0.34279	 731.0	 767.5	 804.1	 0.0	 0.0	 0	 -30.0	 30.0;
	16229	 17963	 0.010301	 0.068799	 0.12995	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16229	 80394	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80395	 16229	 0.000321	 0.02569	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16229	 80399	 0.004221	 0.045591	 0.09057	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16229	 80399	 0.004221	 0.045591	 0.09057	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16229	 95337	 0.004726	 0.0483	 0.15365	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80395	 16230	 0.066595	 0.1712	 0.00265	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16231	 16234	 0.002953	 0.010128	 0.00243	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16232	 16233	 0.018447	 0.013335	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16232	 80396	 0.042147	 0.046763	 0.00091	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16232	 80397	 0.019929	 0.039457	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16234	 16943	 0.011478	 0.039377	 0.00943	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16234	 80396	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16234	 80396	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16236	 16239	 0.001972	 0.007752	 0.00203	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16236	 80397	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16236	 80397	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16237	 16238	 0.010714	 0.021212	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80397	 16237	 0.007892	 0.015625	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80393	 16238	 0.029621	 0.076146	 0.00118	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16238	 80398	 0.017594	 0.012719	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80394	 16239	 0.00443	 0.055737	 0.01727	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16239	 80398	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16239	 80398	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16239	 80400	 0.006457	 0.060123	 0.01863	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16240	 16241	 0.003599	 0.017466	 0.00399	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16240	 80400	 0.009183	 0.048819	 0.01133	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16242	 80401	 0.05383	 0.11063	 0.00211	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16243	 80401	 0.053051	 0.041984	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16244	 17317	 0.000996	 0.018522	 1.2298	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16244	 80399	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80401	 16245	 0.10853	 0.085891	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80400	 16246	 0.003353	 0.018024	 0.00443	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16246	 80402	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16246	 80402	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80401	 16247	 0.024526	 0.063046	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80402	 16247	 0.020291	 0.041523	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16248	 80403	 0.021176	 0.035672	 0.00051	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16248	 80426	 0.036002	 0.027615	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16249	 16262	 0.013605	 0.035261	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16249	 80403	 0.017754	 0.041219	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16250	 16252	 0.001131	 0.004528	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16250	 16264	 0.001377	 0.005602	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16251	 80404	 0.014046	 0.02242	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16251	 80407	 0.009315	 0.023689	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16252	 16253	 0.001165	 0.004577	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16253	 16254	 0.002169	 0.005824	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16253	 16313	 0.001151	 0.004607	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16253	 80403	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16253	 80403	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16254	 16255	 0.001455	 0.003778	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16254	 80404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16254	 80404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16255	 16256	 0.00117	 0.002819	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16256	 16257	 0.001805	 0.004687	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16257	 80410	 0.00147	 0.011018	 0.00269	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16258	 80412	 0.04671	 0.15583	 0.00247	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16258	 80426	 0.010968	 0.052646	 0.00157	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16259	 16283	 0.028973	 0.085199	 0.00175	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16259	 16284	 0.124	 0.091234	 0.00133	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16259	 80426	 0.037306	 0.08571	 0.0013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16260	 16263	 0.001197	 0.010446	 0.00287	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16260	 16287	 0.000887	 0.008516	 0.00248	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16261	 16262	 0.007207	 0.018525	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16261	 80405	 0.004057	 0.018077	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16263	 16266	 0.000801	 0.005371	 0.0013	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16263	 80405	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16263	 80405	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16264	 16266	 0.000746	 0.004476	 0.00136	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16264	 16269	 0.002339	 0.007101	 0.00156	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16264	 80406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16264	 80406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16265	 16286	 0.013298	 0.043883	 0.00071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80405	 16265	 0.010278	 0.021033	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16266	 16267	 0.000783	 0.002687	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16267	 16289	 0.000811	 0.002782	 0.00067	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16268	 16269	 0.001806	 0.005407	 0.00122	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16268	 16270	 0.001952	 0.006695	 0.0016	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16268	 16293	 0.002256	 0.007974	 0.0018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16270	 16272	 0.002652	 0.007008	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16270	 80407	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16270	 80407	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16271	 16272	 0.001943	 0.005044	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16271	 16308	 0.002976	 0.008774	 0.00204	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16271	 80408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16271	 80408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16272	 80409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16272	 80409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16273	 80411	 0.019581	 0.014406	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79534	 16274	 0.015483	 0.11584	 0.22202	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16274	 80410	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80411	 16274	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16274	 80419	 0.001436	 0.011397	 0.02193	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16275	 16276	 0.018309	 0.036251	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16275	 16277	 0.011888	 0.023537	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80411	 16275	 0.004682	 0.018213	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16277	 16278	 0.015091	 0.02764	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16278	 16315	 0.017302	 0.03217	 0.00075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16279	 16280	 0.003371	 0.017473	 0.00427	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16280	 17623	 0.011247	 0.045033	 0.01135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16280	 80412	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16280	 80412	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16281	 17625	 0.008987	 0.038038	 0.00856	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16281	 80413	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16281	 80413	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80413	 16282	 0.03834	 0.10606	 0.00246	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79571	 16283	 0.031671	 0.14036	 0.00421	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16283	 80414	 0.044399	 0.080111	 0.00116	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16285	 16286	 0.015916	 0.025405	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16285	 80415	 0.020309	 0.041736	 0.0008	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16286	 80414	 0.010498	 0.035021	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16287	 17528	 0.002013	 0.021338	 0.00633	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16287	 80414	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16287	 80414	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16288	 16290	 0.002264	 0.008899	 0.00233	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16288	 80415	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16288	 80415	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16289	 16290	 0.000917	 0.003672	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16291	 16295	 0.011661	 0.021682	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80415	 16291	 0.012738	 0.029572	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16292	 16296	 0.023227	 0.028315	 0.00045	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16293	 16294	 0.001162	 0.005638	 0.00129	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16293	 80416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16293	 80416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16294	 16301	 0.002306	 0.014758	 0.00497	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16294	 80417	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16294	 80417	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16294	 80420	 0.004475	 0.02087	 0.00517	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16295	 16298	 0.005439	 0.021159	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16295	 80418	 0.008729	 0.022624	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16296	 16297	 0.003382	 0.011283	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80416	 16296	 0.011195	 0.025116	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80417	 16296	 0.011846	 0.023454	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16297	 16298	 0.001694	 0.006592	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16299	 80418	 0.014949	 0.025183	 0.00036	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16300	 16301	 0.000591	 0.005678	 0.00165	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16300	 16857	 0.001588	 0.015759	 0.00429	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16301	 80418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16301	 80418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16302	 16310	 0.001188	 0.007383	 0.00208	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16302	 80420	 0.000937	 0.007057	 0.00196	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16303	 80419	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16303	 80419	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16304	 16306	 0.00103	 0.003533	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80420	 16304	 0.001846	 0.007018	 0.00196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16304	 80422	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16304	 80422	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16305	 80423	 0.014101	 0.011053	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16306	 16308	 0.001968	 0.006419	 0.0017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16306	 80423	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16306	 80423	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80422	 16307	 0.013465	 0.024202	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80423	 16307	 0.034768	 0.027515	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16307	 80424	 0.019682	 0.033155	 0.00047	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16308	 80424	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16308	 80424	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80424	 16309	 0.0069	 0.023017	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16309	 80425	 0.015818	 0.045369	 0.0007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16310	 16311	 0.00121	 0.007089	 0.00193	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16310	 80425	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16310	 80425	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16311	 16801	 0.002504	 0.014388	 0.00408	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16312	 16788	 0.005891	 0.022919	 0.00612	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80410	 16313	 0.004369	 0.01804	 0.00427	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16313	 80426	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16313	 80426	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80421	 16314	 0.061281	 0.047007	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80422	 16314	 0.065488	 0.051827	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80425	 16315	 0.018669	 0.043342	 0.00064	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16316	 16317	 0.16422	 0.18064	 0.00241	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16316	 16321	 0.18182	 0.19807	 0.0027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16317	 16319	 0.16407	 0.12985	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16317	 19903	 0.11549	 0.1518	 0.00208	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16318	 16320	 0.005169	 0.028679	 0.00872	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16318	 19363	 0.023154	 0.060119	 0.01459	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16318	 80427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16318	 80427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16318	 81503	 0.029522	 0.076662	 0.01861	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16319	 19859	 0.086748	 0.26646	 0.005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80427	 16319	 0.026527	 0.07031	 0.00178	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16319	 80428	 0.25428	 0.4286	 0.00611	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16321	 80428	 0.05238	 0.10371	 0.00152	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16322	 80428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16322	 80428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80428	 16323	 0.15066	 0.11924	 0.0015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16324	 16325	 0.058298	 0.064121	 0.00086	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80428	 16324	 0.024788	 0.11899	 0.00356	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16327	 16331	 0.080471	 0.063078	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16327	 80429	 0.057827	 0.087707	 0.00126	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16328	 80429	 0.23079	 0.21264	 0.00341	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16329	 16330	 0.05105	 0.13503	 0.03164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16330	 80429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16330	 80429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16332	 16518	 0.003736	 0.012817	 0.00307	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16332	 16708	 0.001515	 0.005105	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16333	 16343	 0.040473	 0.064604	 0.00149	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16333	 80506	 0.05397	 0.102	 0.00165	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16334	 16335	 0.017949	 0.047574	 0.00121	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16334	 80430	 0.008546	 0.043231	 0.00075	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16335	 80509	 0.022155	 0.056953	 0.00088	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16336	 16341	 0.001196	 0.014573	 0.00482	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16336	 16524	 0.002389	 0.02294	 0.00667	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16336	 80430	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16336	 80430	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80430	 16337	 0.051019	 0.051531	 0.00068	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16338	 16339	 0.003383	 0.013536	 0.00457	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16338	 16528	 0.002207	 0.009188	 0.00286	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16339	 16368	 0.00427	 0.027504	 0.00721	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16339	 80431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16339	 80431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16340	 16351	 0.0086	 0.052845	 0.00121	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80431	 16340	 0.008138	 0.042316	 0.00092	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16341	 16342	 0.002623	 0.018871	 0.005	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16341	 16350	 0.000616	 0.007999	 0.00506	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16342	 16346	 0.001422	 0.009537	 0.0023	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16343	 16344	 0.009367	 0.031248	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16343	 16345	 0.031685	 0.041644	 0.00057	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16343	 80432	 0.011255	 0.050154	 0.00085	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16344	 16709	 0.006644	 0.015194	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16345	 80434	 0.008321	 0.017027	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16346	 80432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16346	 80432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16346	 80433	 0.00132	 0.009418	 0.00292	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80432	 16347	 0.002211	 0.020584	 0.0004	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16347	 80435	 0.009833	 0.030165	 0.00082	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16347	 80435	 0.009833	 0.030165	 0.00082	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16348	 17513	 0.00038	 0.003601	 0.00645	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16348	 80433	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80434	 16348	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80433	 16349	 0.000605	 0.009093	 0.00533	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16349	 80435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16349	 80435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16349	 80444	 0.000796	 0.011912	 0.004	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16349	 80445	 0.001724	 0.024377	 0.00807	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16350	 16352	 0.000759	 0.005605	 0.00162	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16350	 16353	 0.000712	 0.005151	 0.00277	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16351	 80439	 0.007449	 0.051132	 0.00093	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16352	 16355	 0.001081	 0.007072	 0.0018	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16352	 80436	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16352	 80436	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16353	 16354	 0.001445	 0.007928	 0.0021	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16353	 80437	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16353	 80437	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16353	 80442	 0.003211	 0.019125	 0.00503	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16354	 80438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16354	 80438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16354	 80442	 0.001764	 0.010959	 0.00309	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16355	 16356	 0.00118	 0.009645	 0.00262	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16355	 80439	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16355	 80439	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16356	 16358	 0.001374	 0.012792	 0.00396	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16356	 80440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16356	 80440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16357	 16369	 0.02943	 0.09818	 0.00156	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79563	 16357	 0.025	 0.11015	 0.00191	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16357	 80441	 0.021042	 0.048852	 0.00073	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79562	 16358	 0.001524	 0.016515	 0.00516	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16358	 80441	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16358	 80441	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16359	 16361	 0.002486	 0.018628	 0.00454	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16359	 80442	 0.004727	 0.019236	 0.00469	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16359	 80445	 0.002905	 0.018027	 0.00437	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16360	 16473	 0.000359	 0.00609	 0.48089	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16360	 80442	 0.000144	 0.011532	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79562	 16361	 0.002855	 0.021096	 0.00609	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16362	 16363	 0.00052	 0.005679	 0.01101	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16362	 80444	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16362	 80444	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79561	 16363	 0.001465	 0.01843	 0.04406	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16363	 80445	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80446	 16363	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79569	 16364	 0.019384	 0.03799	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16365	 80447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16365	 80447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16366	 16371	 0.02323	 0.066627	 0.00102	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16366	 80866	 0.045572	 0.17097	 0.00307	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16367	 16540	 0.016596	 0.076909	 0.00148	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16367	 80448	 0.01609	 0.071699	 0.00122	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16368	 16370	 0.001279	 0.021314	 0.00648	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16368	 16539	 0.001799	 0.017273	 0.00502	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16368	 80448	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16368	 80448	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80448	 16369	 0.020259	 0.072371	 0.00144	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80448	 16369	 0.020259	 0.072371	 0.00144	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16369	 80449	 0.021961	 0.081201	 0.0015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16369	 80449	 0.021961	 0.081201	 0.0015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16370	 16372	 0.002145	 0.020595	 0.00599	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16370	 80449	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16370	 80449	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16370	 80865	 0.00501	 0.04025	 0.01132	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80449	 16371	 0.019597	 0.050377	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79527	 16372	 0.003177	 0.032366	 0.00834	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16373	 17965	 0.010223	 0.033343	 0.00885	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16373	 17966	 0.012099	 0.036418	 0.01139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16374	 16375	 0.008532	 0.029267	 0.00701	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16374	 16383	 0.016733	 0.084671	 0.02358	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16374	 17966	 0.007231	 0.028422	 0.00744	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16375	 16383	 0.013019	 0.058628	 0.0156	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16375	 80450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16375	 80450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16376	 16380	 0.031932	 0.14289	 0.00294	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79557	 16376	 0.016869	 0.094924	 0.00205	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80450	 16376	 0.080571	 0.15954	 0.00234	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16377	 16378	 0.004071	 0.025031	 0.00722	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16378	 16379	 0.004695	 0.03024	 0.00793	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16379	 17433	 0.010329	 0.066545	 0.01745	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16379	 80451	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16379	 80451	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16380	 16381	 0.015	 0.08056	 0.00191	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80451	 16380	 0.05753	 0.13357	 0.00199	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16381	 17430	 0.016596	 0.10203	 0.00184	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16381	 80452	 0.037889	 0.087965	 0.00131	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16382	 80452	 0.14861	 0.11761	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16383	 80452	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16383	 80452	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16383	 80774	 0.015076	 0.13724	 0.03468	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16384	 16386	 0.001295	 0.004364	 0.00108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16384	 16412	 0.002583	 0.006707	 0.00163	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16384	 80453	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16384	 80453	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16385	 16387	 0.017891	 0.014726	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80453	 16385	 0.009312	 0.014863	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16385	 80466	 0.037707	 0.029841	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16386	 16394	 0.000762	 0.002614	 0.00063	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16386	 80454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16386	 80454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16387	 16388	 0.014052	 0.009439	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16387	 80455	 0.017158	 0.016578	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16388	 16404	 0.016074	 0.01272	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16388	 16441	 0.007228	 0.012992	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16389	 16390	 0.001115	 0.003109	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16389	 16408	 0.001613	 0.004189	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16390	 16403	 0.001791	 0.004501	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16390	 80455	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16390	 80455	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16391	 16393	 0.011039	 0.019717	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16391	 16441	 0.025639	 0.020291	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16391	 80460	 0.01286	 0.019701	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16392	 16426	 0.01002	 0.023264	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16392	 80460	 0.018884	 0.018245	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16392	 80461	 0.040005	 0.026873	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16393	 16399	 0.006456	 0.013783	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16394	 16397	 0.000876	 0.002951	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16395	 80456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16395	 80456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16395	 80458	 0.00095	 0.003259	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16396	 16416	 0.027245	 0.020045	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80454	 16396	 0.014672	 0.021756	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80456	 16396	 0.002693	 0.010317	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16396	 80468	 0.064133	 0.050271	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16397	 80457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16397	 80457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16397	 80458	 0.000705	 0.003868	 0.00102	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16398	 16399	 0.009352	 0.008614	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16398	 16442	 0.006879	 0.008644	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16399	 16400	 0.015103	 0.011953	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16399	 80459	 0.00367	 0.014277	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16401	 16645	 0.002509	 0.016932	 0.03118	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16401	 17445	 0.004974	 0.033572	 0.06185	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16401	 80458	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80459	 16401	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16401	 80476	 0.000704	 0.005862	 0.01829	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16402	 16403	 0.00086	 0.003113	 0.00067	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80458	 16402	 0.0031	 0.013812	 0.00375	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16402	 80460	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16402	 80460	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16403	 80461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16403	 80461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16405	 16411	 0.002747	 0.009422	 0.00226	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16405	 16440	 0.006404	 0.021364	 0.00542	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16405	 80462	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16405	 80462	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80462	 16406	 0.033873	 0.037256	 0.0005	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16406	 80463	 0.05464	 0.035374	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16407	 16410	 0.005118	 0.013525	 0.00317	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16407	 17389	 0.005153	 0.017676	 0.00423	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16407	 80463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16407	 80463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16408	 16410	 0.003036	 0.007804	 0.00193	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16408	 80464	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16408	 80464	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16409	 17390	 0.061522	 0.048688	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80461	 16409	 0.013305	 0.02076	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16410	 80465	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16410	 80465	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16411	 16412	 0.002251	 0.00595	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16411	 16413	 0.00262	 0.007134	 0.00157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16412	 80466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16412	 80466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16412	 80547	 0.011959	 0.030063	 0.00779	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16413	 80467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16413	 80467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80463	 16414	 0.049716	 0.050215	 0.00067	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80464	 16414	 0.036125	 0.028588	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80467	 16414	 0.012935	 0.016833	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16415	 16417	 0.004998	 0.013937	 0.00293	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16415	 80547	 0.008498	 0.022814	 0.00517	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80459	 16416	 0.018304	 0.032898	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16416	 80468	 0.037612	 0.02435	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16417	 16418	 0.00448	 0.01184	 0.00277	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16418	 16419	 0.002193	 0.007643	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16418	 80468	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16418	 80468	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16419	 16420	 0.002438	 0.008364	 0.002	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16419	 80469	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16419	 80469	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16420	 80477	 0.00267	 0.012021	 0.0032	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16421	 17877	 0.071117	 0.056282	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80469	 16421	 0.080251	 0.063511	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16422	 16423	 0.028156	 0.022282	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16422	 16426	 0.0051	 0.015646	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16422	 80471	 0.008215	 0.030088	 0.00076	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16424	 16437	 0.00922	 0.018254	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80459	 16424	 0.01136	 0.021754	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16425	 16431	 0.011193	 0.028772	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16425	 80473	 0.027701	 0.036407	 0.0005	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16425	 80478	 0.018037	 0.041439	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16426	 80470	 0.016698	 0.021946	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16427	 16429	 0.003613	 0.009548	 0.00223	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16427	 17407	 0.005767	 0.014971	 0.00363	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16427	 80470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16427	 80470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16427	 80472	 0.003515	 0.020589	 0.00561	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80470	 16428	 0.016603	 0.032873	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16429	 17397	 0.006276	 0.016587	 0.00388	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16430	 17402	 0.015729	 0.048303	 0.00091	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16430	 80473	 0.053103	 0.10514	 0.00154	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16431	 16432	 0.012642	 0.025029	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16432	 16433	 0.033402	 0.021624	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16432	 16434	 0.021717	 0.014059	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16433	 16434	 0.023079	 0.01809	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16433	 16435	 0.020183	 0.020609	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16433	 80471	 0.007369	 0.021136	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16436	 80471	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16436	 80471	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16436	 80472	 0.000904	 0.005383	 0.00142	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80471	 16437	 0.004145	 0.018263	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16438	 80472	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80473	 16438	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16438	 80474	 0.000714	 0.004634	 0.00923	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16438	 80476	 0.000186	 0.002012	 0.00399	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16439	 16443	 3.7e-05	 0.000456	 0.03124	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16439	 17875	 8.4e-05	 0.001081	 0.06901	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16439	 80474	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80475	 16439	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16440	 80809	 0.005287	 0.035469	 0.00856	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80459	 16441	 0.007411	 0.028833	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80457	 16442	 0.005802	 0.011372	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16443	 80476	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16443	 80476	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16444	 16455	 0.006121	 0.020419	 0.00518	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16444	 17286	 0.004825	 0.012752	 0.00298	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16444	 80479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16444	 80479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16445	 16446	 0.035842	 0.024076	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16445	 17291	 0.10291	 0.08067	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80479	 16445	 0.013649	 0.039146	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16446	 80756	 0.025404	 0.049788	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16447	 16448	 0.13817	 0.10599	 0.00142	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79549	 16447	 0.027324	 0.06198	 0.00124	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16447	 80480	 0.19894	 0.15746	 0.00198	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16449	 16451	 0.034773	 0.055505	 0.00128	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16449	 80819	 0.084691	 0.19459	 0.00296	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16450	 16451	 0.04988	 0.035333	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16451	 80480	 0.03168	 0.043184	 0.00096	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16452	 80480	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16452	 80480	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16453	 16454	 0.02366	 0.054929	 0.00082	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80480	 16453	 0.034921	 0.045896	 0.00063	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79549	 16454	 0.14838	 0.18422	 0.00402	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16454	 80481	 0.028089	 0.093704	 0.00149	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16455	 16456	 0.006728	 0.023449	 0.00544	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16455	 80481	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16455	 80481	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16456	 16457	 0.005112	 0.01851	 0.00397	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16456	 80482	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16456	 80482	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16457	 17477	 0.006413	 0.022001	 0.00527	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16458	 16459	 0.000264	 0.002082	 0.00061	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16458	 16468	 0.000827	 0.003601	 0.00103	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16458	 16470	 0.001401	 0.003703	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16459	 80489	 0.00116	 0.010119	 0.00278	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16460	 16461	 0.005324	 0.010433	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16460	 16471	 0.0063	 0.014627	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16461	 16462	 0.01346	 0.014804	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16462	 80483	 0.005111	 0.012102	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16462	 80484	 0.00702	 0.018046	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16462	 80488	 0.00712	 0.027806	 0.00062	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16463	 16464	 0.000805	 0.00276	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16463	 16476	 0.000545	 0.001907	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16463	 80483	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16463	 80483	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16464	 16465	 0.000838	 0.002876	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16464	 80484	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16464	 80484	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16465	 16466	 0.001082	 0.003382	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16466	 16467	 0.000822	 0.002744	 0.0007	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16466	 16468	 0.001221	 0.004443	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16466	 80485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16466	 80485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16466	 80505	 0.003181	 0.017748	 0.00453	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16467	 16479	 0.001031	 0.003644	 0.00082	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16467	 80486	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16467	 80486	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16468	 80487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16468	 80487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80487	 16469	 0.017445	 0.017449	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16469	 80494	 0.010239	 0.020272	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16469	 80495	 0.010645	 0.021077	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16470	 16484	 0.002293	 0.006394	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16471	 16485	 0.015866	 0.01356	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16471	 80488	 0.004705	 0.021051	 0.00043	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16472	 80488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16472	 80488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16472	 80489	 0.001283	 0.005888	 0.00151	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16473	 16474	 2.1e-05	 0.000278	 0.01771	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16473	 16500	 4.8e-05	 0.000851	 0.06038	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16473	 80489	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16473	 80489	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16474	 80490	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16475	 16476	 0.000643	 0.005013	 0.0015	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16475	 80492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16475	 80492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16475	 80500	 0.00215	 0.008877	 0.0021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16476	 16477	 0.00082	 0.005093	 0.00144	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16477	 16514	 0.00153	 0.007816	 0.00197	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16478	 16523	 0.005911	 0.016351	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80485	 16478	 0.00775	 0.019923	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16479	 16481	 0.000931	 0.003371	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80486	 16480	 0.021653	 0.014018	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80487	 16480	 0.009683	 0.015582	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16481	 16525	 0.002703	 0.010822	 0.00273	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16481	 80493	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16481	 80493	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16482	 16526	 0.008764	 0.016053	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80493	 16482	 0.016994	 0.016998	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16483	 16484	 0.001224	 0.003334	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16483	 80494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16483	 80494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16484	 16531	 0.002635	 0.010552	 0.00266	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16484	 80495	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16484	 80495	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16484	 80496	 0.01122	 0.030122	 0.00683	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80495	 16485	 0.023595	 0.023601	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16486	 16487	 0.035059	 0.027745	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16486	 16536	 0.031863	 0.025216	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80488	 16487	 0.011257	 0.022062	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16488	 16489	 0.035353	 0.022887	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16488	 16492	 0.018179	 0.035993	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16488	 16537	 0.041817	 0.030229	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16488	 16538	 0.055789	 0.054587	 0.00077	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16489	 16549	 0.019753	 0.039109	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16490	 16491	 0.024716	 0.03013	 0.00048	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16491	 16492	 0.011051	 0.019292	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80491	 16491	 0.010749	 0.033011	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16491	 80497	 0.014785	 0.0236	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80488	 16492	 0.002794	 0.014952	 0.00045	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16492	 80497	 0.032292	 0.044056	 0.00079	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16493	 80498	 0.070254	 0.077272	 0.00103	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16494	 16550	 0.004397	 0.013233	 0.00414	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16494	 80496	 0.002476	 0.008751	 0.00197	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79514	 16495	 0.003077	 0.020523	 0.03869	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16495	 80496	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80497	 16495	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16495	 80499	 0.000952	 0.00635	 0.01197	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80497	 16496	 0.016055	 0.053558	 0.00085	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16496	 80498	 0.015688	 0.039736	 0.00079	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80496	 16497	 0.005345	 0.01801	 0.00448	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16497	 80498	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16497	 80498	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80498	 16498	 0.03956	 0.031307	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16499	 16501	 0.022854	 0.044789	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80497	 16499	 0.023704	 0.054459	 0.00083	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16500	 16506	 6.6e-05	 0.000945	 0.06525	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16500	 80499	 9.6e-05	 0.007684	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80500	 16500	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16501	 80503	 0.024918	 0.049336	 0.00072	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16502	 16503	 0.008356	 0.026532	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80491	 16502	 0.012909	 0.057521	 0.00098	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16503	 80501	 0.009643	 0.025492	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16504	 16510	 0.002847	 0.00738	 0.00223	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16504	 16512	 0.003011	 0.007959	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16504	 80501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16504	 80501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16505	 16508	 0.002993	 0.010083	 0.00251	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16505	 16509	 0.001645	 0.010111	 0.00292	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79515	 16505	 0.007031	 0.029761	 0.0067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16505	 80502	 0.001739	 0.013972	 0.00393	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16506	 16507	 5.1e-05	 0.000828	 0.05809	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16506	 80502	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16508	 16510	 0.002681	 0.007085	 0.00166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16509	 16511	 0.001551	 0.008243	 0.00191	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16511	 80507	 0.001954	 0.007821	 0.00197	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16512	 16513	 0.001281	 0.006673	 0.00175	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16512	 80507	 0.001621	 0.007992	 0.00216	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16513	 80505	 0.001108	 0.006363	 0.0018	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16514	 80504	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16514	 80504	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16514	 80505	 0.002379	 0.008162	 0.00196	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16515	 16520	 0.00068	 0.005526	 0.01811	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80499	 16515	 0.000795	 0.007696	 0.02722	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16515	 80505	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80506	 16515	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16516	 16517	 0.011114	 0.037075	 0.00059	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80506	 16516	 0.006678	 0.025692	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16517	 16747	 0.021386	 0.071343	 0.00113	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16517	 80508	 0.027757	 0.040447	 0.00091	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16518	 80507	 0.005838	 0.021141	 0.00454	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16519	 16744	 0.000855	 0.006868	 0.00193	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16519	 80507	 0.000957	 0.008707	 0.0022	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16520	 16743	 0.000274	 0.004825	 0.01583	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16520	 80507	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80508	 16520	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80506	 16521	 0.062295	 0.049299	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16521	 80509	 0.043722	 0.04809	 0.00064	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16522	 16524	 0.002179	 0.007626	 0.00253	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80505	 16522	 0.002332	 0.009336	 0.00235	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16522	 80509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16522	 80509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80504	 16523	 0.04364	 0.028253	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80509	 16523	 0.016305	 0.01529	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80505	 16524	 0.004502	 0.016377	 0.00501	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16525	 16528	 0.002177	 0.008274	 0.00232	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16526	 16527	 0.003413	 0.020982	 0.00038	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80494	 16526	 0.017784	 0.024263	 0.00043	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16527	 80510	 0.004426	 0.021244	 0.00063	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16528	 80510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16528	 80510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16529	 80511	 0.029843	 0.021957	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16530	 16531	 0.000991	 0.006876	 0.00196	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16530	 16539	 0.00279	 0.019733	 0.00541	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80505	 16530	 0.010116	 0.042817	 0.00964	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16530	 80511	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16530	 80511	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16531	 16533	 0.001235	 0.004162	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16531	 80512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16531	 80512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80511	 16532	 0.034569	 0.02238	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16533	 80513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16533	 80513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16534	 16540	 0.017093	 0.086469	 0.0015	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16534	 16544	 0.033644	 0.033981	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80512	 16534	 0.025088	 0.026792	 0.00057	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16535	 16536	 0.018152	 0.014365	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16535	 16538	 0.011709	 0.022424	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80513	 16535	 0.003056	 0.010917	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16538	 16542	 0.036148	 0.029753	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16539	 80514	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16539	 80514	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16541	 16542	 0.086034	 0.0557	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16542	 16543	 0.021829	 0.02869	 0.00039	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16543	 16544	 0.013388	 0.034047	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16544	 16545	 0.008962	 0.029897	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16545	 16546	 0.009262	 0.023555	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16546	 16547	 0.005809	 0.03095	 0.00054	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80511	 16546	 0.026129	 0.051734	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80514	 16547	 0.006665	 0.029698	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16548	 16550	 0.002502	 0.01018	 0.00248	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16548	 18020	 0.010807	 0.044621	 0.01056	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16548	 80515	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16548	 80515	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16549	 80516	 0.014889	 0.038273	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16550	 80516	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16550	 80516	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16551	 17744	 0.066576	 0.11967	 0.00215	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16551	 80518	 0.038498	 0.098966	 0.00153	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16551	 80975	 0.042173	 0.12694	 0.00248	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16552	 16553	 0.008633	 0.034564	 0.00871	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16552	 80517	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16552	 80517	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16553	 16554	 0.004222	 0.017181	 0.00419	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16553	 16560	 0.009861	 0.03383	 0.0081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16553	 17743	 0.023477	 0.062057	 0.01453	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16553	 80518	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16553	 80518	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16554	 16559	 0.005743	 0.02371	 0.00561	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16554	 80519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16554	 80519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16555	 16556	 0.004828	 0.018782	 0.00502	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16555	 16641	 0.007012	 0.028073	 0.00707	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16556	 16558	 0.009358	 0.024296	 0.0059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16556	 17745	 0.010178	 0.034295	 0.00852	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16556	 80520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16556	 80520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16557	 16558	 0.002886	 0.017907	 0.00434	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16557	 17916	 0.004791	 0.01442	 0.00451	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16557	 80521	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16557	 80521	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16557	 80545	 0.005263	 0.045923	 0.01261	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16558	 16559	 0.004023	 0.024328	 0.00621	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16559	 16561	 0.009871	 0.024814	 0.00643	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16560	 17295	 0.009855	 0.029056	 0.00676	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16561	 16562	 0.006214	 0.017328	 0.00364	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16562	 17301	 0.010503	 0.027759	 0.0065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16562	 80522	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16562	 80522	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79539	 16563	 0.002358	 0.008537	 0.00183	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16563	 80523	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16563	 80523	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16564	 80524	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16564	 80524	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16565	 16567	 0.00443	 0.011708	 0.00274	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16565	 16988	 0.008694	 0.022978	 0.00538	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16565	 80525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16565	 80525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16566	 16584	 0.023619	 0.034416	 0.00078	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80525	 16566	 0.066026	 0.052252	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16567	 16569	 0.002891	 0.015368	 0.00357	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16567	 16985	 0.002743	 0.017046	 0.00481	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16568	 16570	 0.034503	 0.052855	 0.00074	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16568	 16572	 0.073897	 0.10082	 0.0018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80523	 16568	 0.050892	 0.16978	 0.00269	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16568	 80651	 0.10867	 0.070355	 0.00134	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16569	 16580	 0.001805	 0.008127	 0.00216	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16570	 80650	 0.12625	 0.092888	 0.00136	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16571	 80526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16571	 80526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16571	 80530	 0.003857	 0.013231	 0.00317	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16572	 16574	 0.025595	 0.065092	 0.00103	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16572	 16978	 0.039691	 0.055316	 0.00095	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16573	 16578	 0.056752	 0.074589	 0.00102	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16574	 16576	 0.017157	 0.043633	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16575	 16576	 0.072301	 0.052267	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16576	 16593	 0.061584	 0.11933	 0.00257	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16576	 16979	 0.045398	 0.1167	 0.00181	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16577	 16593	 0.055344	 0.043799	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80526	 16578	 0.020489	 0.036826	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16579	 80527	 0.029516	 0.023136	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16579	 80529	 0.020313	 0.036651	 0.00053	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16580	 80527	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16580	 80527	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16580	 80530	 0.002176	 0.014015	 0.00367	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16581	 16582	 0.010627	 0.025348	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16581	 16588	 0.013237	 0.034028	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16581	 16589	 0.04841	 0.036677	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16582	 16583	 0.03447	 0.026441	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16582	 16584	 0.013246	 0.023809	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16582	 16627	 0.083652	 0.065572	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16583	 80528	 0.047783	 0.036202	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80524	 16584	 0.032704	 0.033032	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16585	 80528	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16585	 80528	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16586	 16587	 0.02711	 0.020539	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16586	 16603	 0.016351	 0.02939	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80528	 16586	 0.01052	 0.018908	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16587	 16602	 0.008261	 0.018892	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80528	 16587	 0.038324	 0.038709	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16588	 16589	 0.016995	 0.030664	 0.00044	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16588	 16591	 0.00777	 0.025641	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16589	 16601	 0.033568	 0.028689	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16589	 16611	 0.01595	 0.031579	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80528	 16589	 0.12088	 0.087385	 0.00133	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16590	 16599	 0.000983	 0.004	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16590	 80529	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16590	 80529	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80527	 16591	 0.018649	 0.020512	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80529	 16591	 0.003385	 0.016796	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16592	 28000	 0.001585	 0.021063	 0.04501	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79532	 16592	 0.002943	 0.019104	 0.03806	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16592	 80530	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80531	 16592	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80531	 16593	 0.015064	 0.067124	 0.00114	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16594	 16596	 0.053651	 0.040648	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80385	 16594	 0.039178	 0.076783	 0.00115	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16594	 80538	 0.076252	 0.076272	 0.00103	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16595	 16597	 0.017763	 0.028352	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16595	 16617	 0.035816	 0.033587	 0.00052	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80384	 16595	 0.14114	 0.1117	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16597	 16617	 0.007293	 0.014924	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80531	 16597	 0.006019	 0.024086	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16598	 16599	 0.000872	 0.003393	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80530	 16598	 0.001632	 0.006534	 0.00165	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16598	 80532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16598	 80532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16600	 16611	 0.008855	 0.025398	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16600	 16614	 0.040548	 0.032089	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80528	 16600	 0.078212	 0.13176	 0.00188	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80529	 16600	 0.004106	 0.020892	 0.00047	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16601	 80533	 0.029776	 0.045613	 0.00064	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16601	 80537	 0.032352	 0.031654	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16602	 80533	 0.010772	 0.022043	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16603	 80533	 0.007629	 0.023404	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16603	 80724	 0.012743	 0.045521	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16603	 80729	 0.015845	 0.036237	 0.00088	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16604	 16610	 0.002971	 0.007851	 0.00184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16604	 17222	 0.004704	 0.019911	 0.00448	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16604	 80533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16604	 80533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16604	 80534	 0.001402	 0.011189	 0.00276	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79532	 16605	 0.000105	 0.001195	 0.00281	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16605	 80534	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80535	 16605	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16606	 16625	 0.028938	 0.031828	 0.00042	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80535	 16606	 0.020914	 0.040988	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16607	 16612	 0.031616	 0.024782	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16607	 16615	 0.014147	 0.036365	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16607	 80536	 0.005722	 0.018884	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16608	 16609	 0.001399	 0.003697	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16608	 80536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16608	 80536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16609	 16610	 0.002696	 0.00734	 0.00162	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16609	 80537	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16609	 80537	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80536	 16611	 0.028171	 0.025948	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16612	 16614	 0.014611	 0.022383	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16612	 16615	 0.005345	 0.020793	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16613	 16614	 0.018523	 0.011991	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16615	 16616	 0.006476	 0.02137	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80531	 16615	 0.017642	 0.053099	 0.00104	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16616	 16617	 0.028711	 0.023632	 0.00048	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16616	 16619	 0.022419	 0.017742	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80532	 16616	 0.005162	 0.020079	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16617	 16619	 0.020542	 0.022593	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16617	 16620	 0.01148	 0.023593	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16618	 16620	 0.010063	 0.02667	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16618	 16622	 0.022426	 0.041075	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16618	 80538	 0.040547	 0.039177	 0.00057	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16619	 16620	 0.009032	 0.015883	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80536	 16621	 0.025065	 0.019836	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80536	 16622	 0.050467	 0.032672	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16623	 16624	 0.053089	 0.042014	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16623	 80538	 0.044121	 0.034916	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16624	 16625	 0.063044	 0.045575	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79533	 16626	 0.017796	 0.049631	 0.01042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16626	 80538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16626	 80538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80525	 16627	 0.021432	 0.06147	 0.00095	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80527	 16627	 0.017723	 0.059122	 0.00094	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16628	 80539	 0.14179	 0.095252	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16629	 16630	 0.012141	 0.03121	 0.00773	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16629	 19802	 0.011095	 0.044423	 0.01119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16629	 80539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16629	 80539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16630	 16851	 0.016824	 0.044467	 0.01041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16630	 16852	 0.006493	 0.036026	 0.01095	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16630	 19410	 0.01485	 0.057781	 0.01544	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79541	 16631	 0.010461	 0.052919	 0.00092	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79559	 16631	 0.036985	 0.14172	 0.00401	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79540	 16632	 0.004029	 0.034555	 0.00983	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16632	 80540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16632	 80540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79576	 16633	 0.026643	 0.16381	 0.00295	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16634	 16635	 0.041296	 0.12144	 0.00249	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79626	 16634	 0.029299	 0.15612	 0.00274	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16634	 80541	 0.20118	 0.15923	 0.002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16635	 80806	 0.052732	 0.13556	 0.0021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16636	 16637	 0.00632	 0.025302	 0.00637	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16636	 17738	 0.006152	 0.025036	 0.0061	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16636	 80541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16636	 80541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16637	 16643	 0.006705	 0.028378	 0.00639	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16637	 80542	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16637	 80542	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80541	 16638	 0.032296	 0.063945	 0.00094	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80542	 16638	 0.013612	 0.052957	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80542	 16639	 0.031919	 0.081176	 0.00128	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16639	 80908	 0.074179	 0.14688	 0.00216	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16640	 80543	 0.062742	 0.089069	 0.00147	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16641	 80543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16641	 80543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16641	 80545	 0.00638	 0.024822	 0.00663	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16642	 17875	 0.000191	 0.00327	 0.25453	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16642	 80544	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80545	 16642	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95345	 16642	 0.000965	 0.016533	 1.2936	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16643	 16644	 0.010875	 0.027955	 0.00692	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16643	 80809	 0.009136	 0.03658	 0.00922	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80545	 16644	 0.0038	 0.013036	 0.00312	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16644	 80546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16644	 80546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16645	 17441	 0.004233	 0.034722	 0.06258	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80544	 16645	 0.000782	 0.00596	 0.01084	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16645	 80547	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16645	 80547	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80546	 16646	 0.063751	 0.050452	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16647	 16649	 0.006922	 0.032285	 0.008	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16647	 17476	 0.00647	 0.027383	 0.00616	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16647	 80548	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16647	 80548	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16648	 16650	 0.016368	 0.10063	 0.00181	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16648	 17474	 0.018995	 0.092694	 0.0016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16649	 17959	 0.004972	 0.025397	 0.00639	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80548	 16650	 0.064912	 0.14725	 0.00294	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16650	 80646	 0.024474	 0.085637	 0.00177	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16650	 80648	 0.027308	 0.14667	 0.00348	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16651	 16653	 0.012603	 0.013862	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16651	 16664	 0.015687	 0.020414	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16652	 16662	 0.00265	 0.009089	 0.00218	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16652	 16692	 0.001602	 0.004235	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16652	 80549	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16652	 80549	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80549	 16653	 0.005097	 0.013209	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16654	 16656	 0.002427	 0.011415	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16654	 80555	 0.003844	 0.016938	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16655	 16675	 0.001064	 0.002812	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16655	 16678	 0.001331	 0.003456	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16655	 80550	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16655	 80550	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80550	 16656	 0.002795	 0.011667	 0.00034	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16656	 80561	 0.009768	 0.021915	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16657	 16678	 0.001982	 0.007007	 0.00158	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16657	 80551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16657	 80551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16658	 16659	 0.00109	 0.003674	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16658	 16676	 0.001252	 0.004758	 0.00133	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16658	 80552	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16658	 80552	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16659	 80553	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16659	 80553	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16659	 80558	 0.001915	 0.006934	 0.00149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16660	 80554	 0.003595	 0.008514	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16660	 80555	 0.003375	 0.011258	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16661	 80554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16661	 80554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16661	 80556	 0.002727	 0.008166	 0.00184	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16662	 80555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16662	 80555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16663	 16664	 0.002419	 0.011803	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80555	 16663	 0.001784	 0.009278	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16664	 16665	 0.002858	 0.014863	 0.00032	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16664	 16695	 0.003464	 0.019692	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16664	 80557	 0.005196	 0.024943	 0.00075	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16665	 80566	 0.005952	 0.026521	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16666	 80557	 0.032692	 0.021165	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16667	 80557	 0.012124	 0.016897	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16668	 16672	 0.000401	 0.004964	 0.00996	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16668	 17574	 0.003767	 0.030257	 0.05689	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16668	 80556	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80557	 16668	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16669	 16670	 0.001178	 0.009796	 0.00019	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80557	 16669	 0.001932	 0.013954	 0.00026	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16670	 16671	 0.001306	 0.009402	 0.00031	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16671	 80559	 0.001695	 0.016413	 0.00033	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16672	 80558	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80559	 16672	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16672	 80578	 0.000361	 0.005278	 0.02022	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16673	 16692	 0.001826	 0.004903	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16673	 16722	 0.004077	 0.010585	 0.00257	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16673	 80560	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16673	 80560	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80560	 16674	 0.025081	 0.018453	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16675	 16691	 0.002083	 0.005809	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16675	 80561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16675	 80561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16676	 16677	 0.000655	 0.002548	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16676	 16742	 0.000748	 0.004648	 0.00131	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16676	 80562	 0.001129	 0.004595	 0.00112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16677	 16681	 0.001039	 0.00429	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16678	 16679	 0.000612	 0.002407	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16679	 16681	 0.001017	 0.003997	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16680	 16726	 0.00124	 0.004963	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16680	 16735	 0.001084	 0.004586	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16682	 80562	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80563	 16682	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16682	 80578	 0.000249	 0.003506	 0.01454	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16683	 16687	 0.007028	 0.018214	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80557	 16683	 0.013206	 0.024556	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16684	 16690	 0.000847	 0.003448	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16684	 16758	 0.00105	 0.004818	 0.00123	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80559	 16685	 0.00572	 0.013279	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16685	 80565	 0.00414	 0.010972	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16686	 16690	 0.001114	 0.005408	 0.00124	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16686	 80564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16686	 80564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16687	 16688	 0.002457	 0.009747	 0.00028	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80564	 16687	 0.002168	 0.015598	 0.00051	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16688	 16689	 0.002496	 0.010563	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16689	 80567	 0.008462	 0.024014	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16690	 80565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16690	 80565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16691	 16727	 0.004476	 0.011829	 0.00277	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16693	 16694	 0.009654	 0.012688	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16693	 16695	 0.014493	 0.024415	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16693	 80573	 0.016462	 0.047214	 0.00073	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16694	 16695	 0.008072	 0.013598	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80556	 16696	 0.002978	 0.01296	 0.00369	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16696	 80566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16696	 80566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16697	 16764	 0.002205	 0.011154	 0.00311	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80556	 16697	 0.001152	 0.007295	 0.00198	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16697	 80567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16697	 80567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16698	 16767	 0.029058	 0.066759	 0.00101	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80557	 16698	 0.009171	 0.026303	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16699	 16702	 0.001354	 0.006608	 0.00014	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16699	 16712	 0.006379	 0.011861	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16700	 16701	 0.001264	 0.004405	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16700	 16711	 0.00194	 0.005127	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16701	 16704	 0.00165	 0.005832	 0.00131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16702	 80568	 0.002129	 0.009872	 0.00021	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16703	 16705	 0.000895	 0.003483	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16703	 80568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16703	 80568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16704	 16706	 0.000794	 0.003645	 0.00093	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16704	 16708	 0.003499	 0.009757	 0.00205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16705	 16706	 0.001296	 0.005486	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16705	 80569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16705	 80569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16706	 80571	 0.000431	 0.004135	 0.0012	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16707	 16713	 0.021088	 0.023194	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16707	 80584	 0.030936	 0.023438	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16709	 80572	 0.011889	 0.030561	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16710	 16747	 0.011702	 0.021432	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16710	 80570	 0.009854	 0.015096	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16711	 80570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16711	 80570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16711	 80582	 0.008059	 0.020258	 0.00525	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16712	 16713	 0.006621	 0.015019	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80570	 16712	 0.005824	 0.019427	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16713	 16750	 0.012061	 0.021762	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16714	 17513	 0.000278	 0.003069	 0.00647	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16714	 80571	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80572	 16714	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16714	 80578	 0.002606	 0.018272	 0.03111	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16715	 17511	 0.016637	 0.042768	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16715	 80584	 0.011669	 0.051413	 0.00089	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80569	 16716	 0.011182	 0.025956	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16716	 80584	 0.009858	 0.028273	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16717	 16720	 0.027312	 0.07021	 0.00109	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16717	 80851	 0.076305	 0.12855	 0.00183	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16718	 16719	 0.022148	 0.073883	 0.00117	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80293	 16718	 0.16952	 0.13417	 0.00169	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80294	 16718	 0.01618	 0.049687	 0.00093	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16719	 80573	 0.014225	 0.063385	 0.00108	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16720	 80573	 0.019698	 0.055898	 0.00088	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16721	 16722	 0.002264	 0.01434	 0.00389	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16721	 80573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16721	 80573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16722	 16727	 0.003183	 0.013472	 0.00303	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79529	 16722	 0.008961	 0.050749	 0.01258	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16723	 80574	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16723	 80574	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80561	 16724	 0.007557	 0.017284	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16724	 80576	 0.007052	 0.027433	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16725	 16726	 0.003088	 0.00829	 0.00188	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80574	 16725	 0.010065	 0.02613	 0.00634	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16725	 80575	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16725	 80575	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16726	 80576	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16726	 80576	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80574	 16727	 0.002431	 0.017194	 0.00472	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80575	 16728	 0.042431	 0.030673	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80576	 16728	 0.026888	 0.026894	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16729	 16730	 0.003133	 0.017807	 0.00515	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16729	 16733	 0.002578	 0.01122	 0.0032	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16730	 17569	 0.008127	 0.024338	 0.00548	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79515	 16730	 0.001741	 0.021453	 0.00693	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16730	 80577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16730	 80577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80577	 16731	 0.089114	 0.065565	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16732	 16736	 0.002374	 0.008595	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16732	 80581	 0.004601	 0.015503	 0.00385	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16733	 16734	 0.001589	 0.007412	 0.00184	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16734	 16735	 0.000446	 0.003313	 0.00126	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16734	 16737	 0.001805	 0.006536	 0.0014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16735	 16740	 0.002464	 0.007264	 0.00169	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16736	 16737	 0.001799	 0.006171	 0.00148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16737	 16769	 0.003675	 0.008857	 0.0025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80575	 16738	 0.048536	 0.074353	 0.00104	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16738	 80580	 0.008401	 0.013409	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16739	 16752	 4.9e-05	 0.00058	 0.04349	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16739	 80578	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16739	 80578	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80579	 16739	 0.000131	 0.010484	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16740	 16741	 0.002098	 0.005447	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16740	 80580	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16740	 80580	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16741	 16742	 0.000773	 0.004898	 0.00133	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80579	 16741	 0.00071	 0.005703	 0.0016	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80578	 16743	 0.000739	 0.00788	 0.01428	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16743	 80581	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16743	 80581	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16744	 16745	 0.001065	 0.0076	 0.00236	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80581	 16745	 0.006996	 0.018781	 0.00426	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16745	 80582	 0.001122	 0.009171	 0.00249	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16746	 16749	 0.030376	 0.024039	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16746	 80583	 0.034353	 0.027187	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16747	 16748	 0.008512	 0.01976	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16748	 16749	 0.011082	 0.019795	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16750	 16755	 0.044382	 0.032653	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16751	 16758	 0.001563	 0.007982	 0.00201	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80579	 16751	 0.000831	 0.004864	 0.00132	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16752	 80582	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16753	 16754	 0.003731	 0.012446	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80583	 16753	 0.005712	 0.017523	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16754	 16755	 0.008784	 0.016333	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16754	 16759	 0.006487	 0.016497	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80564	 16754	 0.020916	 0.055438	 0.00141	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80583	 16755	 0.020194	 0.041326	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80582	 16756	 0.007524	 0.022183	 0.00516	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16756	 80584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16756	 80584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80563	 16757	 0.011559	 0.051222	 0.00154	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80564	 16757	 0.018873	 0.043358	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16758	 80585	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16758	 80585	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16759	 16760	 0.009055	 0.012619	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80585	 16760	 0.030197	 0.0305	 0.0004	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16761	 16763	 0.033197	 0.065727	 0.00096	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80584	 16761	 0.018379	 0.047244	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16762	 16763	 0.05184	 0.042669	 0.00086	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80564	 16762	 0.051388	 0.042297	 0.00086	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16764	 16765	 0.003425	 0.015713	 0.00403	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16764	 80586	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16764	 80586	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16765	 17507	 0.007871	 0.023901	 0.00523	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16765	 80587	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16765	 80587	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16766	 16768	 0.099181	 0.099208	 0.00134	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80586	 16767	 0.051511	 0.061664	 0.00103	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80295	 16768	 0.018719	 0.091347	 0.00158	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80566	 16768	 0.020247	 0.10242	 0.00178	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80579	 16769	 0.002769	 0.007721	 0.00162	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79548	 16770	 0.019142	 0.040867	 0.00092	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16770	 80782	 0.033104	 0.11044	 0.00175	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16771	 16772	 0.00228	 0.006025	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16771	 16780	 0.014705	 0.058883	 0.01484	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16771	 80588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16771	 80588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16772	 16774	 0.000556	 0.006529	 0.00173	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16772	 80589	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16772	 80589	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79548	 16773	 0.008243	 0.027203	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79567	 16773	 0.008231	 0.01911	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80588	 16773	 0.022219	 0.020046	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16773	 80590	 0.007426	 0.030351	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16774	 16775	 0.000716	 0.009007	 0.00279	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16774	 80590	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16774	 80590	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16775	 80591	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16775	 80591	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80590	 16776	 0.1309	 0.14398	 0.00192	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16777	 17934	 0.007442	 0.030286	 0.00738	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16778	 17294	 0.066167	 0.21012	 0.00368	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16778	 17935	 0.049166	 0.16226	 0.00263	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80591	 16778	 0.034772	 0.23597	 0.0044	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16779	 16780	 0.008926	 0.036324	 0.00885	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16779	 17292	 0.010314	 0.041297	 0.01041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80313	 16781	 0.080649	 0.23135	 0.00356	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16781	 80782	 0.49813	 0.39455	 0.00497	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16782	 16784	 0.006255	 0.018731	 0.00422	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16782	 17623	 0.004992	 0.019986	 0.00503	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16782	 80592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16782	 80592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80592	 16783	 0.049011	 0.069576	 0.00114	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16783	 80593	 0.05608	 0.043017	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16784	 16786	 0.005083	 0.019977	 0.00523	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16784	 16789	 0.010995	 0.046537	 0.01047	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16784	 16939	 0.006332	 0.021721	 0.0052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16784	 80593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16784	 80593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16785	 16791	 0.009612	 0.054639	 0.00099	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16785	 80594	 0.009575	 0.053801	 0.001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16786	 16942	 0.005305	 0.022451	 0.00505	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16786	 80594	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16786	 80594	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80592	 16787	 0.019105	 0.04742	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80594	 16787	 0.18319	 0.14361	 0.00184	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16788	 16789	 0.005306	 0.022457	 0.00505	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16789	 16800	 0.004952	 0.0319	 0.00836	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16789	 17820	 0.013776	 0.069229	 0.01802	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79537	 16789	 0.034051	 0.090022	 0.02108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16789	 80595	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16789	 80595	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16790	 16791	 0.023987	 0.043114	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16790	 16794	 0.034069	 0.040784	 0.00068	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80595	 16791	 0.009261	 0.052646	 0.00095	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16792	 16793	 0.054287	 0.035146	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16792	 80596	 0.024545	 0.048105	 0.00072	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16792	 80930	 0.062193	 0.044959	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16794	 80596	 0.033164	 0.043587	 0.0006	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16795	 16796	 0.005092	 0.01182	 0.0036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16795	 80596	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16795	 80596	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16796	 80597	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16796	 80597	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16797	 16798	 0.011383	 0.078137	 0.00142	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79538	 16797	 0.027007	 0.11968	 0.00359	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80597	 16797	 0.009218	 0.063273	 0.00115	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16798	 80598	 0.01011	 0.069396	 0.00126	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16799	 16800	 0.012463	 0.033461	 0.00758	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16799	 80598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16799	 80598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16800	 16801	 0.002871	 0.017838	 0.00503	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16801	 80599	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16801	 80599	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16802	 16806	 0.01813	 0.05983	 0.00097	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80421	 16802	 0.019522	 0.077452	 0.00221	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80599	 16802	 0.009365	 0.024821	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16803	 16806	 0.027167	 0.068815	 0.00136	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80595	 16803	 0.047767	 0.15936	 0.00253	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16804	 16805	 0.054796	 0.055346	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16804	 16807	 0.027145	 0.083364	 0.00156	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16804	 16952	 0.079628	 0.10466	 0.00143	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80598	 16804	 0.028218	 0.094134	 0.00149	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16805	 16806	 0.023483	 0.044971	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16806	 16808	 0.0364	 0.092572	 0.00146	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16807	 16808	 0.035481	 0.082375	 0.00123	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16807	 80637	 0.01751	 0.084485	 0.00149	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80421	 16808	 0.01591	 0.085135	 0.00258	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16809	 16821	 0.009533	 0.063961	 0.01544	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16809	 80600	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16809	 80600	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16810	 17012	 0.060321	 0.19908	 0.00323	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79568	 16810	 0.021772	 0.080502	 0.00149	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16811	 80601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16811	 80601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16811	 80892	 0.009371	 0.10272	 0.0285	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16813	 16814	 0.008105	 0.049827	 0.0009	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16814	 16815	 0.008559	 0.048692	 0.0015	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16815	 16819	 0.00501	 0.041676	 0.00079	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80600	 16815	 0.050888	 0.13082	 0.00202	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16816	 16817	 0.097578	 0.076488	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16817	 16818	 0.006466	 0.04726	 0.00087	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16817	 16910	 0.01027	 0.076315	 0.00182	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16818	 16819	 0.003455	 0.032161	 0.00062	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16818	 16820	 0.047398	 0.034264	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16818	 80602	 0.019824	 0.0733	 0.00136	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16821	 80602	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16821	 80602	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16821	 80892	 0.008217	 0.068203	 0.01795	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80602	 16822	 0.12409	 0.097276	 0.00125	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16823	 17687	 0.032443	 0.14295	 0.00248	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80602	 16823	 0.019854	 0.15475	 0.00289	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79568	 16824	 0.12436	 0.098424	 0.00124	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16825	 16826	 0.15966	 0.11748	 0.00172	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16826	 80606	 0.035998	 0.085244	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16827	 16838	 0.024513	 0.043784	 0.00065	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16828	 16829	 0.054026	 0.036291	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16828	 16838	 0.042009	 0.051212	 0.00082	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16830	 16832	 0.01486	 0.042619	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16830	 16836	 0.011264	 0.028956	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16831	 16836	 0.029901	 0.070806	 0.00129	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16832	 16836	 0.026309	 0.0653	 0.00109	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16833	 16834	 0.02079	 0.053444	 0.00083	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80327	 16833	 0.075821	 0.060005	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16834	 16835	 0.021202	 0.054503	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16835	 16836	 0.040813	 0.10492	 0.00162	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16835	 17687	 0.022027	 0.090025	 0.00182	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16836	 16846	 0.007973	 0.023997	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16836	 80603	 0.007064	 0.035736	 0.00062	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16836	 80605	 0.028482	 0.075492	 0.00191	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16837	 16839	 0.002657	 0.006897	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16837	 80603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16837	 80603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16838	 80605	 0.008196	 0.028697	 0.00079	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16839	 16841	 0.002282	 0.007826	 0.00187	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16839	 80604	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16839	 80604	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16840	 16844	 0.013667	 0.034756	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80603	 16840	 0.041413	 0.041828	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80604	 16840	 0.016878	 0.013357	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16840	 80605	 0.011828	 0.01888	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16841	 16842	 0.001406	 0.011491	 0.00312	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16841	 80605	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16841	 80605	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16842	 17486	 0.011187	 0.038378	 0.00919	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16842	 80606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16842	 80606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16842	 80868	 0.011619	 0.10143	 0.02787	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16843	 16844	 0.011296	 0.039524	 0.00082	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80606	 16843	 0.009367	 0.033461	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16844	 16845	 0.040856	 0.030059	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16844	 16849	 0.025279	 0.072504	 0.00111	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80605	 16844	 0.017782	 0.041282	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16846	 16847	 0.008609	 0.02213	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16847	 16848	 0.024077	 0.049272	 0.00121	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80603	 16847	 0.05875	 0.04247	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16848	 17690	 0.031392	 0.083206	 0.00211	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16849	 17690	 0.031328	 0.10088	 0.00172	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80606	 16850	 0.13788	 0.099677	 0.00151	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16851	 17346	 0.014728	 0.051332	 0.0119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16852	 16855	 0.002283	 0.01958	 0.00557	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16852	 80607	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16852	 80607	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16853	 17347	 0.087609	 0.17347	 0.00255	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16853	 80608	 0.024197	 0.074232	 0.00201	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16854	 16855	 0.001887	 0.017165	 0.00433	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16854	 80608	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16854	 80608	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16856	 80609	 0.030357	 0.059495	 0.00089	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16857	 16861	 0.001671	 0.021021	 0.00651	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16857	 80609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16857	 80609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16858	 16862	 0.008336	 0.06935	 0.00131	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80415	 16858	 0.009422	 0.06887	 0.00127	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16859	 80610	 0.05683	 0.13194	 0.00196	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16859	 80755	 0.050141	 0.11641	 0.00173	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16860	 16861	 0.001471	 0.020795	 0.00689	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16860	 17638	 0.002293	 0.033103	 0.01051	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16860	 80610	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16860	 80610	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16862	 16863	 0.008575	 0.079835	 0.00155	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80610	 16863	 0.021675	 0.080142	 0.00148	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16863	 80836	 0.019722	 0.10509	 0.00184	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16863	 80837	 0.022274	 0.12516	 0.00232	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16864	 17694	 0.17643	 0.58915	 0.00935	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79553	 16864	 0.13949	 0.39601	 0.00623	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16865	 16869	 0.002653	 0.020674	 0.00039	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16865	 80611	 0.005491	 0.027938	 0.00063	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16865	 80613	 0.006367	 0.023541	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16865	 80613	 0.006367	 0.023541	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16865	 80615	 0.00718	 0.052477	 0.00097	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16866	 16888	 0.005137	 0.020566	 0.00518	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16866	 80611	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16866	 80611	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16866	 80614	 0.004018	 0.010787	 0.00244	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16867	 16887	 0.012153	 0.033201	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80611	 16867	 0.023345	 0.023351	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16868	 80612	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16868	 80612	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16868	 80614	 0.005671	 0.022289	 0.00583	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16869	 16882	 0.00934	 0.036334	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16869	 16882	 0.00934	 0.036334	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80612	 16869	 0.004149	 0.025218	 0.00047	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16870	 16875	 0.00234	 0.017931	 0.0048	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16870	 80613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16870	 80613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16870	 80614	 0.001243	 0.009986	 0.00281	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16871	 16874	 0.014937	 0.065814	 0.00114	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80613	 16871	 0.006246	 0.027831	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80371	 16872	 0.002765	 0.037231	 0.07764	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16872	 80614	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80615	 16872	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80615	 16873	 0.022072	 0.052267	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16874	 80866	 0.034095	 0.13264	 0.00221	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16875	 16877	 0.003292	 0.020853	 0.00566	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16875	 80616	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16875	 80616	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16876	 16877	 0.003658	 0.022729	 0.00641	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16876	 18018	 0.004503	 0.029446	 0.00749	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16878	 16879	 0.035301	 0.093321	 0.00169	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16878	 17994	 0.035387	 0.13615	 0.00232	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16879	 16880	 0.016339	 0.075763	 0.00157	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16880	 16882	 0.010971	 0.042679	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16880	 16882	 0.010971	 0.042679	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80616	 16880	 0.008667	 0.049267	 0.00089	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80612	 16881	 0.049141	 0.086423	 0.00162	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16883	 16884	 0.018263	 0.046447	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16884	 16886	 0.019567	 0.0503	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16885	 16886	 0.023013	 0.054496	 0.001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80612	 16886	 0.010197	 0.045439	 0.00077	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16887	 16891	 0.01759	 0.052943	 0.00104	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16888	 80617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16888	 80617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16889	 16890	 0.003756	 0.027027	 0.00089	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16889	 16895	 0.010717	 0.032257	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80617	 16889	 0.011699	 0.064025	 0.00125	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16890	 80620	 0.002397	 0.018125	 0.0006	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16892	 16893	 0.001957	 0.0128	 0.00325	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80614	 16892	 0.001961	 0.012418	 0.00337	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16893	 80618	 0.001987	 0.013331	 0.00322	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16894	 17136	 0.002036	 0.02741	 0.05714	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16894	 80618	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80619	 16894	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80619	 16895	 0.016344	 0.046877	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16896	 16897	 0.001735	 0.009029	 0.00266	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16896	 16901	 0.001608	 0.00892	 0.00271	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16897	 80620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16897	 80620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80620	 16898	 0.004697	 0.033446	 0.00075	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16898	 80622	 0.004755	 0.025447	 0.00077	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16899	 80621	 0.00615	 0.031983	 0.00069	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16899	 80622	 0.010162	 0.054143	 0.00095	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80620	 16900	 0.032024	 0.02315	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16901	 16990	 0.002076	 0.012368	 0.00325	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16902	 17248	 0.000742	 0.007246	 0.00203	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80618	 16902	 0.004727	 0.030449	 0.00798	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16902	 80621	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16902	 80621	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16903	 16905	 0.075097	 0.059432	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16904	 16905	 0.011667	 0.02967	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80619	 16904	 0.009651	 0.032194	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16905	 16906	 0.040389	 0.028609	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80618	 16907	 0.003291	 0.013177	 0.00332	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16907	 80622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16907	 80622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80622	 16908	 0.013305	 0.033838	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16909	 16911	 0.003741	 0.017449	 0.00432	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16909	 80892	 0.003306	 0.017221	 0.00452	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16910	 80623	 0.010779	 0.069544	 0.00221	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16911	 16912	 0.003818	 0.015285	 0.00385	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16912	 16914	 0.011255	 0.028293	 0.00733	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16912	 80623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16912	 80623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16913	 17685	 0.081292	 0.24473	 0.00479	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80623	 16913	 0.034214	 0.088673	 0.00168	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16913	 80624	 0.061505	 0.10216	 0.00216	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16913	 80657	 0.13725	 0.17864	 0.0025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16914	 80624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16914	 80624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79575	 16915	 0.015809	 0.070056	 0.0021	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80602	 16915	 0.03147	 0.15741	 0.0028	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79575	 16916	 0.075945	 0.049168	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16917	 17693	 0.007952	 0.031838	 0.00802	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16917	 80625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16917	 80625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16918	 16922	 0.007957	 0.023827	 0.00537	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16918	 17955	 0.010938	 0.032249	 0.0075	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16919	 16920	 0.024107	 0.069142	 0.00106	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16919	 18011	 0.046904	 0.12433	 0.00315	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16920	 16921	 0.019156	 0.068433	 0.00136	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16920	 80627	 0.022086	 0.11173	 0.00194	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16921	 17909	 0.05458	 0.10807	 0.00159	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16921	 80629	 0.028365	 0.072137	 0.00114	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16922	 16924	 0.003573	 0.014305	 0.0036	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16922	 80626	 0.00182	 0.011187	 0.00323	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16923	 17907	 0.004495	 0.030969	 0.05469	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	16923	 18004	 0.003325	 0.024907	 0.09643	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16923	 80626	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80627	 16923	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16924	 16925	 0.005751	 0.022373	 0.00598	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16925	 16926	 0.006684	 0.023389	 0.00775	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16925	 16938	 0.015147	 0.051964	 0.01245	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16925	 17971	 0.001878	 0.021132	 0.00555	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16926	 16927	 0.004568	 0.019332	 0.00435	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16927	 16928	 0.003053	 0.011875	 0.00317	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80626	 16927	 0.004548	 0.017287	 0.00484	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16928	 16936	 0.004021	 0.016362	 0.00399	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16929	 16931	 0.004844	 0.022591	 0.0056	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80626	 16929	 0.003136	 0.016017	 0.00403	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16929	 80628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16929	 80628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80628	 16930	 0.025666	 0.055001	 0.00096	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16930	 80629	 0.04386	 0.10077	 0.00153	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16931	 16932	 0.002253	 0.012365	 0.00327	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16931	 80629	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16931	 80629	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16931	 80966	 0.019007	 0.050238	 0.01176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16932	 17796	 0.003215	 0.016748	 0.00439	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16932	 80630	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16932	 80630	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16933	 16935	 0.026799	 0.05306	 0.00078	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16934	 80925	 0.026917	 0.055084	 0.00136	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16935	 80632	 0.030973	 0.088836	 0.00137	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16935	 80925	 0.087385	 0.13636	 0.00228	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16936	 16938	 0.010888	 0.043595	 0.01098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16936	 16940	 0.004835	 0.020461	 0.0046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16936	 80631	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16936	 80631	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16937	 16938	 0.008321	 0.021391	 0.0053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16937	 16939	 0.008409	 0.028847	 0.00691	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16938	 17622	 0.006445	 0.036961	 0.01229	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16940	 16942	 0.005164	 0.01963	 0.0055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16940	 80632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16940	 80632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16941	 80633	 0.032403	 0.066591	 0.00127	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	16941	 80926	 0.048209	 0.094484	 0.00142	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16942	 17800	 0.010174	 0.039988	 0.01046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16942	 80633	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16942	 80633	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16943	 17352	 0.012357	 0.041226	 0.01046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16944	 80634	 0.064073	 0.16472	 0.00255	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16944	 80784	 0.078569	 0.20199	 0.00313	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16945	 16973	 0.008016	 0.031505	 0.00824	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16945	 17353	 0.013034	 0.052189	 0.01315	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16945	 80634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16945	 80634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16946	 16947	 0.014988	 0.016006	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16946	 16949	 0.011483	 0.022504	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16947	 16955	 0.020295	 0.058208	 0.0009	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16947	 16956	 0.01508	 0.072757	 0.00128	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16948	 16949	 0.007237	 0.020758	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16948	 80635	 0.01899	 0.037598	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16949	 80636	 0.005753	 0.025633	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16950	 16951	 0.001569	 0.012602	 0.00354	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16950	 80635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16950	 80635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16950	 80638	 0.003969	 0.023646	 0.00622	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16950	 80640	 0.004698	 0.019885	 0.00447	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16951	 16954	 0.004912	 0.02138	 0.00609	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16951	 17271	 0.007861	 0.050637	 0.01328	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16951	 80636	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16951	 80636	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80636	 16952	 0.030544	 0.060475	 0.00089	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80636	 16953	 0.042027	 0.033259	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16954	 17272	 0.004331	 0.025996	 0.00787	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16954	 80637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16954	 80637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16955	 80639	 0.10349	 0.13172	 0.00193	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16956	 80752	 0.023532	 0.11484	 0.00198	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16957	 80638	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80639	 16957	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79520	 16958	 0.000986	 0.014974	 0.03395	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80419	 16958	 0.002615	 0.024912	 0.09105	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16958	 80640	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80641	 16958	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16959	 16967	 0.006698	 0.023344	 0.00541	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16959	 80642	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16959	 80642	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80642	 16960	 0.031151	 0.098914	 0.00173	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16960	 80643	 0.00709	 0.024822	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16960	 80644	 0.040325	 0.052999	 0.00073	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16961	 16962	 0.000884	 0.003359	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16961	 16973	 0.003472	 0.015927	 0.00408	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16961	 80643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16961	 80643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16962	 16964	 0.001636	 0.006549	 0.00165	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16963	 80644	 0.006365	 0.021234	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16963	 80646	 0.021122	 0.07046	 0.00112	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16964	 16966	 0.001166	 0.005953	 0.0015	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16964	 16968	 0.003878	 0.020879	 0.00574	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16964	 80644	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16964	 80644	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80644	 16965	 0.006314	 0.01623	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16965	 80645	 0.028359	 0.031465	 0.00061	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	16966	 16967	 0.002618	 0.012934	 0.00378	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16966	 80645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16966	 80645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16967	 80646	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16967	 80646	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16968	 16970	 0.010046	 0.025253	 0.00654	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16968	 16972	 0.003684	 0.014749	 0.00372	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16969	 16970	 0.007475	 0.017351	 0.00529	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16969	 80647	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16969	 80647	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16970	 80648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16970	 80648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16970	 80982	 0.004852	 0.040807	 0.01209	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16971	 16972	 0.007585	 0.029814	 0.0078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16971	 80649	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16971	 80649	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16974	 16975	 0.008651	 0.02654	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16974	 16978	 0.0172	 0.0421	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16974	 80650	 0.02126	 0.041666	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16975	 16976	 0.014814	 0.033602	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16975	 16982	 0.01699	 0.043674	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80378	 16975	 0.17686	 0.13998	 0.00176	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16975	 80650	 0.014851	 0.04954	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16976	 16983	 0.079186	 0.062668	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16977	 16985	 0.004471	 0.014915	 0.00378	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16977	 80650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16977	 80650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80526	 16978	 0.047492	 0.13622	 0.00209	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16979	 16981	 0.038651	 0.087674	 0.00175	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80378	 16981	 0.043055	 0.088112	 0.00217	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80377	 16983	 0.067745	 0.048973	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16984	 16985	 0.004907	 0.019648	 0.00495	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16984	 16987	 0.006676	 0.018617	 0.00391	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16985	 80651	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16985	 80651	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80525	 16986	 0.06934	 0.054875	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16987	 16991	 0.003167	 0.010329	 0.00274	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16987	 80652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16987	 80652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79517	 16988	 0.004275	 0.011298	 0.00264	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16989	 16990	 0.002468	 0.012398	 0.00323	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	16990	 16991	 0.001516	 0.005107	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16992	 80746	 0.026007	 0.10118	 0.00169	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16993	 16994	 0.027075	 0.068857	 0.00109	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16994	 16995	 0.009812	 0.023403	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	16995	 80653	 0.009446	 0.029993	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	16996	 16997	 0.004693	 0.014251	 0.00312	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	16996	 80653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16996	 80653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16997	 17001	 0.003603	 0.023208	 0.00608	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	16998	 18021	 0.011292	 0.038739	 0.00928	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	16998	 80654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16998	 80654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16999	 80655	 0.17656	 0.13974	 0.00176	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80332	 17000	 0.075515	 0.14952	 0.00219	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17001	 17609	 0.003605	 0.033937	 0.01028	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17001	 80655	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17001	 80655	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17002	 17003	 0.011935	 0.050518	 0.01137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17002	 17686	 0.00648	 0.025944	 0.00654	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17003	 80656	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17003	 80656	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17004	 17005	 0.003011	 0.012254	 0.00299	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17004	 17006	 0.005458	 0.022209	 0.00541	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17004	 80657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17004	 80657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17006	 17009	 0.012671	 0.032897	 0.00798	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17007	 80658	 0.02381	 0.078575	 0.00127	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17007	 80659	 0.022249	 0.099143	 0.00168	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17008	 17009	 0.008304	 0.034288	 0.00811	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17008	 80658	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17008	 80658	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17009	 17010	 0.006432	 0.02951	 0.00756	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17009	 80659	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17009	 80659	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17010	 80660	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17010	 80660	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17011	 80661	 0.21664	 0.14555	 0.00257	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17012	 17013	 0.031804	 0.075859	 0.0017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17013	 17014	 0.023542	 0.067523	 0.00104	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80330	 17014	 0.035601	 0.080756	 0.00161	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17015	 19318	 0.027484	 0.22514	 0.06129	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80305	 17015	 0.033153	 0.18219	 0.04826	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17015	 80661	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17015	 80661	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80661	 17016	 0.037727	 0.096982	 0.0015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17017	 17940	 0.01112	 0.044525	 0.01122	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17018	 17019	 0.026631	 0.061184	 0.00093	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17018	 17021	 0.011955	 0.041856	 0.00116	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17019	 17021	 0.031749	 0.097502	 0.00183	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17020	 17022	 0.008813	 0.030837	 0.01022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17021	 80814	 0.031448	 0.17878	 0.00323	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17022	 17479	 0.008186	 0.033311	 0.00812	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17023	 17072	 0.000815	 0.005466	 0.00132	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17023	 80662	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17023	 80662	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17023	 80687	 0.000696	 0.005854	 0.00173	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17024	 17102	 0.011389	 0.008927	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17024	 17255	 0.007802	 0.006174	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17025	 80682	 0.024259	 0.026682	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17025	 80688	 0.007007	 0.018012	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17026	 17124	 0.005416	 0.01007	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80662	 17026	 0.001069	 0.008331	 0.00016	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17026	 80688	 0.003897	 0.017691	 0.00038	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17027	 17029	 0.002206	 0.009209	 0.00027	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80662	 17027	 0.001502	 0.008038	 0.00024	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17028	 17029	 0.004622	 0.01073	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17028	 80663	 0.002434	 0.007475	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17028	 80699	 0.010599	 0.010705	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17029	 17031	 0.00174	 0.008852	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17030	 17127	 0.001221	 0.004115	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17030	 80663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17030	 80663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17031	 80664	 0.002271	 0.011963	 0.00021	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17032	 17050	 0.000966	 0.003932	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17032	 17071	 0.000783	 0.003234	 0.00077	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17032	 80664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17032	 80664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17033	 17034	 0.000791	 0.003627	 0.00093	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17033	 17043	 0.000769	 0.00373	 0.00085	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17033	 80665	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17033	 80665	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17034	 80666	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17034	 80666	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17034	 80700	 0.001901	 0.007736	 0.00188	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80663	 17035	 0.002686	 0.0119	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80666	 17035	 0.001987	 0.010051	 0.00017	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17036	 17038	 0.016563	 0.018217	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17036	 17040	 0.003054	 0.014908	 0.00031	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17036	 17042	 0.02334	 0.018471	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17036	 17046	 0.011709	 0.008981	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17037	 17130	 0.006334	 0.028223	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17037	 80710	 0.00639	 0.024858	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17039	 17040	 0.01848	 0.036588	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17039	 17163	 0.027661	 0.021682	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17040	 17041	 0.019146	 0.013562	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17040	 17130	 0.014226	 0.019408	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17040	 80701	 0.008178	 0.039907	 0.00069	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17042	 17044	 0.005103	 0.011724	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17042	 17046	 0.011635	 0.007533	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17043	 17049	 0.000994	 0.004206	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17044	 17045	 0.003243	 0.014451	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17044	 80667	 0.001745	 0.012154	 0.00029	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17045	 17047	 0.002745	 0.012232	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17047	 17054	 0.002916	 0.010205	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80665	 17048	 0.023269	 0.016483	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17048	 80667	 0.005689	 0.015736	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17048	 80668	 0.002163	 0.010437	 0.00018	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17048	 80669	 0.015696	 0.024044	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17049	 17059	 0.000619	 0.003808	 0.0011	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17049	 80667	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17049	 80667	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17050	 17051	 0.001201	 0.004719	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17050	 80668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17050	 80668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17051	 80669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17051	 80669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17052	 17053	 0.00472	 0.01251	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17052	 80671	 0.00662	 0.01643	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17053	 17057	 0.004383	 0.01953	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17053	 80672	 0.007342	 0.024229	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17054	 17063	 0.009729	 0.022585	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17054	 17064	 0.013746	 0.013786	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17054	 17168	 0.015468	 0.068925	 0.00117	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17054	 80701	 0.011779	 0.080852	 0.00147	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17055	 17068	 0.004587	 0.016058	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17055	 80672	 0.004916	 0.017562	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17056	 17061	 0.0016	 0.004635	 0.00112	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17056	 80670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17056	 80670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17056	 80713	 0.002114	 0.0092	 0.00262	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17057	 17058	 0.004234	 0.016288	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17057	 17063	 0.006255	 0.015845	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17057	 17064	 0.012616	 0.016581	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17058	 17170	 0.009856	 0.025064	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17059	 17060	 0.000295	 0.002393	 0.00076	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17060	 17061	 0.00092	 0.003683	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17060	 80671	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17060	 80671	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17061	 80672	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17061	 80672	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17062	 17176	 0.00361	 0.011912	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80672	 17062	 0.002367	 0.010743	 0.00023	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17063	 17166	 0.005068	 0.025638	 0.00045	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17065	 17066	 0.01055	 0.02159	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80669	 17065	 0.007331	 0.028518	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80670	 17066	 0.006186	 0.017741	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17066	 80712	 0.010141	 0.019649	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17067	 17078	 0.00105	 0.004204	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17067	 17178	 0.001781	 0.007536	 0.0017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17068	 17069	 0.004546	 0.017685	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80669	 17068	 0.004713	 0.011986	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17069	 80673	 0.00489	 0.021668	 0.00065	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17070	 17079	 0.010219	 0.032907	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80664	 17070	 0.01245	 0.022465	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80668	 17070	 0.003315	 0.01094	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17071	 17072	 0.000699	 0.002797	 0.00094	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17071	 80673	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17071	 80673	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17072	 80674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17072	 80674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17073	 17255	 0.014522	 0.011139	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17074	 17076	 0.003786	 0.01263	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17074	 17102	 0.003945	 0.015348	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17075	 17079	 0.003065	 0.018842	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17075	 17099	 0.003688	 0.012598	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17075	 17101	 0.012563	 0.024873	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80673	 17076	 0.006045	 0.013824	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17077	 17078	 0.001091	 0.005654	 0.00138	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17077	 17080	 0.001298	 0.004934	 0.00138	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17077	 80675	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17077	 80675	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17078	 80676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17078	 80676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80675	 17079	 0.009633	 0.019073	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17080	 17092	 0.001497	 0.005995	 0.00151	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17081	 17082	 0.013121	 0.022103	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17081	 17084	 0.00271	 0.011469	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80675	 17081	 0.008339	 0.027818	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17082	 17086	 0.002733	 0.016804	 0.0003	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17082	 80677	 0.007256	 0.025405	 0.0007	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17083	 17085	 0.000555	 0.003727	 0.0009	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17083	 17180	 0.001489	 0.009734	 0.00248	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17083	 80677	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17083	 80677	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17084	 80680	 0.004046	 0.022734	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17085	 17188	 0.00065	 0.003902	 0.00118	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17086	 17089	 0.002163	 0.011522	 0.0002	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17087	 80712	 0.026985	 0.021152	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17088	 17090	 0.002994	 0.01359	 0.00029	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17088	 17192	 0.006137	 0.014247	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17088	 80712	 0.012991	 0.030762	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17089	 17090	 0.002691	 0.0153	 0.00028	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17089	 80715	 0.004487	 0.014809	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17091	 80678	 0.002892	 0.014114	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17091	 80679	 0.002089	 0.011502	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17092	 17098	 0.000722	 0.002625	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17092	 80678	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17092	 80678	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17093	 80679	 0.024998	 0.019783	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17093	 80680	 0.011201	 0.011437	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17094	 17095	 0.001185	 0.004129	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17094	 17109	 0.001033	 0.003741	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17094	 80679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17094	 80679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17095	 17109	 0.002094	 0.005621	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17095	 17187	 0.000865	 0.005478	 0.00149	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17095	 80680	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17095	 80680	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80680	 17096	 0.015189	 0.01202	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17097	 17098	 0.000705	 0.002824	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17097	 17105	 0.000895	 0.004108	 0.00105	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17097	 80681	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17097	 80681	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80681	 17099	 0.003328	 0.012749	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17100	 17101	 0.003094	 0.01032	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17100	 80682	 0.003426	 0.014714	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17101	 17102	 0.008711	 0.010211	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17102	 17255	 0.019187	 0.01504	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17102	 80682	 0.006614	 0.021208	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17103	 80682	 0.004059	 0.011935	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17103	 80686	 0.038194	 0.030226	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17103	 80688	 0.006624	 0.015685	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17104	 80682	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17104	 80682	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17104	 80687	 0.001901	 0.007848	 0.00186	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17105	 17110	 0.001597	 0.006276	 0.00164	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17105	 80683	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17105	 80683	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80683	 17106	 0.00456	 0.024295	 0.00043	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17106	 80684	 0.005641	 0.025136	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17106	 80724	 0.027125	 0.076972	 0.00121	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17107	 17108	 0.000945	 0.003844	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17107	 17216	 0.002436	 0.011611	 0.00336	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17107	 80684	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17107	 80684	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17108	 17109	 0.000579	 0.002318	 0.00058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17108	 80685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17108	 80685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17110	 17111	 0.000555	 0.004374	 0.00128	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17110	 17112	 0.00265	 0.00688	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17110	 80686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17110	 80686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17111	 17253	 0.000798	 0.006411	 0.0018	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17112	 80692	 0.002476	 0.010222	 0.00242	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17113	 80687	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80688	 17113	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17113	 80689	 0.000265	 0.001745	 0.00338	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17113	 80691	 0.000793	 0.005148	 0.01025	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17113	 80743	 0.000932	 0.012038	 0.02728	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17114	 17117	 4.7e-05	 0.000585	 0.04008	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17114	 17217	 0.000133	 0.002376	 0.16861	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17114	 17717	 0.000376	 0.006961	 0.45995	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17114	 80689	 9.6e-05	 0.007684	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17115	 17120	 0.001321	 0.005377	 0.00131	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17115	 80692	 0.001129	 0.005344	 0.00128	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17116	 17223	 0.009227	 0.021421	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17116	 80693	 0.0137	 0.020984	 0.00036	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17116	 80742	 0.027595	 0.044047	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17117	 17227	 3.5e-05	 0.000446	 0.02849	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17117	 80691	 9.1e-05	 0.007299	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80693	 17118	 0.010853	 0.019879	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17119	 17128	 0.000416	 0.004537	 0.0183	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17119	 17136	 0.000506	 0.006311	 0.02242	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80689	 17119	 0.000231	 0.002655	 0.00959	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80691	 17119	 0.000285	 0.003035	 0.00617	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80691	 17119	 0.000285	 0.003035	 0.00617	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17119	 80694	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80695	 17119	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17120	 17121	 0.001068	 0.003482	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80687	 17120	 0.00188	 0.006334	 0.00157	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17120	 80696	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17120	 80696	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17121	 80697	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17121	 80697	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17122	 17124	 0.005534	 0.014225	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80696	 17122	 0.003572	 0.014598	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17123	 17125	 0.001581	 0.009719	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80697	 17123	 0.001614	 0.010951	 0.0002	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17125	 80698	 0.00267	 0.014394	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17125	 80699	 0.004775	 0.014663	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17126	 17127	 0.002098	 0.005544	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17126	 17135	 0.001298	 0.007156	 0.00167	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80694	 17126	 0.003188	 0.012118	 0.00339	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17126	 80698	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17126	 80698	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17127	 80699	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17127	 80699	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17128	 80700	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80701	 17128	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17129	 17130	 0.007089	 0.012984	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17129	 17131	 0.013105	 0.014414	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80701	 17130	 0.002936	 0.020154	 0.00037	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17131	 17132	 0.013214	 0.010457	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17131	 80708	 0.021039	 0.021044	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80695	 17133	 0.007956	 0.026541	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17133	 80702	 0.014291	 0.036737	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17134	 17135	 0.001421	 0.004876	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17134	 17234	 0.002454	 0.008418	 0.00202	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17135	 80702	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17135	 80702	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17136	 17598	 0.001669	 0.027137	 0.05359	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79516	 17136	 0.000582	 0.009433	 0.03659	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17136	 80703	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80704	 17136	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17137	 17141	 0.025955	 0.020541	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80704	 17137	 0.006144	 0.020988	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80704	 17137	 0.006144	 0.020988	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17137	 80707	 0.00304	 0.025245	 0.00062	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17138	 17140	 0.002114	 0.006332	 0.00143	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17138	 17234	 0.0012	 0.006031	 0.00157	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80703	 17138	 0.001399	 0.007287	 0.00191	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80704	 17139	 0.009228	 0.023721	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17139	 80705	 0.006084	 0.023668	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17140	 17152	 0.002956	 0.007811	 0.00183	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17140	 80705	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17140	 80705	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17142	 17146	 0.003796	 0.029242	 0.00056	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17142	 17150	 0.003431	 0.016741	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80704	 17142	 0.006244	 0.029972	 0.0009	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17143	 17145	 0.000426	 0.004089	 0.00119	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17143	 80706	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17143	 80706	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80706	 17144	 0.001795	 0.006279	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80706	 17144	 0.001795	 0.006279	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17144	 80707	 0.002594	 0.01009	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17144	 80707	 0.002594	 0.01009	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17145	 17245	 0.001006	 0.009154	 0.00231	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17145	 80707	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17145	 80707	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17146	 17147	 0.004002	 0.024606	 0.00044	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17146	 17148	 0.009527	 0.021609	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80707	 17146	 0.003744	 0.021039	 0.00039	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80340	 17147	 0.004935	 0.021868	 0.00066	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17148	 17149	 0.011113	 0.0258	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17149	 17156	 0.008385	 0.027973	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17149	 17157	 0.007885	 0.026303	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80340	 17149	 0.012529	 0.055829	 0.00095	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80705	 17150	 0.00472	 0.014479	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17150	 80708	 0.007973	 0.026597	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17151	 17153	 0.0017	 0.00702	 0.00166	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80703	 17151	 0.004322	 0.016427	 0.0046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80700	 17152	 0.002876	 0.01119	 0.00299	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17152	 80708	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17152	 80708	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17153	 17154	 0.000908	 0.003569	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17153	 80709	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17153	 80709	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17154	 17158	 0.001262	 0.004797	 0.00134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17154	 80710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17154	 80710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17155	 17156	 0.002807	 0.012368	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80709	 17155	 0.005552	 0.02474	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17156	 17157	 0.003233	 0.009919	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17156	 80711	 0.006356	 0.019498	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17158	 17160	 0.001261	 0.005335	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17159	 17162	 0.028212	 0.022327	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80710	 17159	 0.027694	 0.017929	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17160	 80711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17160	 80711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17161	 17164	 0.00637	 0.021022	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80711	 17161	 0.004839	 0.014843	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17164	 17165	 0.008374	 0.019829	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17165	 17166	 0.005112	 0.021337	 0.00062	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17165	 17167	 0.008788	 0.034186	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17167	 17175	 0.019344	 0.04424	 0.00108	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17168	 17174	 0.007931	 0.027767	 0.00077	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17169	 17172	 0.005033	 0.022426	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17169	 80714	 0.00482	 0.02012	 0.00058	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17170	 17171	 0.019417	 0.029744	 0.00042	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17171	 17173	 0.005679	 0.027139	 0.00059	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17171	 80714	 0.013211	 0.042362	 0.00105	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17172	 80900	 0.01011	 0.034536	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17173	 80900	 0.005959	 0.026406	 0.00079	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17174	 17175	 0.025586	 0.045701	 0.00067	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17174	 80896	 0.00877	 0.042793	 0.00074	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17176	 17177	 0.009207	 0.016863	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17177	 80714	 0.012209	 0.028345	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17178	 80712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17178	 80712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17178	 80713	 0.001458	 0.005542	 0.00155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17179	 17701	 0.001999	 0.012978	 0.02585	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17179	 80713	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80714	 17179	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17180	 17182	 0.000884	 0.004934	 0.00126	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17180	 80715	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17180	 80715	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17181	 17202	 0.00886	 0.020355	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80715	 17181	 0.009987	 0.01935	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17182	 17207	 0.000868	 0.004786	 0.00112	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17183	 17207	 0.001119	 0.005715	 0.00144	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17183	 80716	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17183	 80716	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17183	 80898	 0.003023	 0.027493	 0.00694	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17184	 80717	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80718	 17184	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17184	 80743	 0.000267	 0.002911	 0.00565	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17184	 80743	 0.000267	 0.002911	 0.00565	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17185	 17186	 0.026539	 0.021003	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17186	 17190	 0.004621	 0.012782	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17186	 80720	 0.003033	 0.015342	 0.00027	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17187	 17188	 0.00039	 0.002675	 0.00078	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80717	 17187	 0.000722	 0.004483	 0.00127	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17188	 80719	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17188	 80719	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17189	 17197	 0.002702	 0.012394	 0.00317	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80717	 17189	 0.001195	 0.007226	 0.00184	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17189	 80720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17189	 80720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17190	 17191	 0.007745	 0.019696	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17191	 17199	 0.002916	 0.012995	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80677	 17191	 0.009075	 0.019446	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17192	 17208	 0.012807	 0.025356	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17193	 17208	 0.006511	 0.02172	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80714	 17193	 0.008763	 0.029233	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17194	 17195	 0.004047	 0.01416	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80714	 17194	 0.006599	 0.029076	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17195	 17708	 0.013738	 0.027199	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17196	 80721	 0.02469	 0.018706	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17197	 17198	 0.001664	 0.007761	 0.00192	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17197	 80721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17197	 80721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17198	 80722	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17198	 80722	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17198	 84827	 0.017624	 0.16961	 0.07926	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17199	 17200	 0.002269	 0.009999	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17200	 17201	 0.002723	 0.009532	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17201	 17202	 0.004139	 0.022227	 0.00053	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17201	 17203	 0.008485	 0.019699	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80721	 17201	 0.003748	 0.018297	 0.00038	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80722	 17201	 0.00488	 0.027457	 0.00059	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17202	 17205	 0.002668	 0.014695	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17203	 17204	 0.006903	 0.014187	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17204	 17727	 0.009636	 0.029003	 0.00057	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80722	 17204	 0.007101	 0.022548	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17205	 17206	 0.022837	 0.018073	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80716	 17205	 0.009471	 0.038707	 0.00078	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17206	 17726	 0.028216	 0.022329	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80716	 17208	 0.006524	 0.024121	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79532	 17209	 0.000317	 0.003594	 0.0072	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80691	 17209	 0.000613	 0.007805	 0.01476	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17209	 80723	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80724	 17209	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17210	 17216	 0.003664	 0.008829	 0.00249	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79533	 17210	 0.003806	 0.008834	 0.00269	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17211	 17213	 0.034196	 0.026805	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79533	 17212	 0.006128	 0.01591	 0.00386	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17212	 80725	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17212	 80725	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17213	 17214	 0.062994	 0.040783	 0.00078	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17213	 17221	 0.014849	 0.0291	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80725	 17213	 0.026761	 0.029692	 0.00058	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80535	 17215	 0.11803	 0.093411	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17215	 80726	 0.016843	 0.026885	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17216	 80726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17216	 80726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17216	 80727	 0.00075	 0.005703	 0.00179	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17217	 17254	 4.2e-05	 0.000499	 0.03745	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17217	 27980	 0.000102	 0.00183	 0.12985	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17217	 80727	 0.000243	 0.018209	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17218	 17219	 0.01287	 0.019295	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80726	 17218	 0.011869	 0.023499	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80684	 17219	 0.008424	 0.028103	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80718	 17219	 0.006149	 0.02356	 0.00067	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17219	 80744	 0.003831	 0.026298	 0.00048	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17220	 17221	 0.006555	 0.021865	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80728	 17220	 0.005648	 0.018841	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17222	 17226	 0.002125	 0.008507	 0.00214	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17222	 80729	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17222	 80729	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80729	 17223	 0.05072	 0.04014	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17223	 80730	 0.023634	 0.036205	 0.00051	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17224	 17225	 0.001038	 0.004286	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17225	 17226	 0.001231	 0.004477	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17226	 80730	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17226	 80730	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17226	 80731	 0.00175	 0.007408	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17227	 80731	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17227	 80731	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17228	 17229	 0.00251	 0.010216	 0.00249	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79539	 17228	 0.00326	 0.011361	 0.00263	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80731	 17229	 0.001121	 0.006568	 0.00179	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17229	 80732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17229	 80732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17230	 17233	 0.001777	 0.007113	 0.00179	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17230	 17242	 0.004169	 0.016693	 0.00421	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17231	 80733	 0.026291	 0.020806	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17232	 17234	 0.002257	 0.005966	 0.0014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17232	 17244	 0.003544	 0.012158	 0.00291	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17232	 80733	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17232	 80733	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17233	 17234	 0.001499	 0.006002	 0.00151	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17233	 80734	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17233	 80734	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17235	 80741	 0.031953	 0.034803	 0.00047	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17236	 17251	 0.000999	 0.01534	 0.00429	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79517	 17236	 0.000443	 0.007268	 0.00229	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17237	 80741	 0.025661	 0.020308	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17238	 17250	 0.008962	 0.031376	 0.00087	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17238	 80736	 0.007569	 0.026482	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17238	 80736	 0.007569	 0.026482	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17238	 80741	 0.004849	 0.023664	 0.00041	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17239	 80736	 0.020238	 0.018641	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79516	 17240	 0.000428	 0.005533	 0.01254	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17240	 80735	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80736	 17240	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17241	 17243	 0.006276	 0.027968	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80736	 17241	 0.006519	 0.016578	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17241	 80739	 0.005076	 0.019748	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79517	 17242	 0.001876	 0.011885	 0.00323	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17242	 80737	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17242	 80737	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80737	 17243	 0.005608	 0.038495	 0.0007	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17243	 80738	 0.004622	 0.024625	 0.00043	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17244	 17245	 0.002745	 0.016078	 0.00438	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79517	 17244	 0.003465	 0.021531	 0.00608	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17244	 80738	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17244	 80738	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17245	 17247	 0.002593	 0.010974	 0.00247	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17246	 17247	 0.002217	 0.00988	 0.00268	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80735	 17246	 0.000775	 0.005319	 0.00155	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17246	 80739	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17246	 80739	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17247	 80740	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17247	 80740	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17248	 17251	 0.00114	 0.008982	 0.00263	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17249	 17251	 0.001998	 0.01413	 0.00388	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80621	 17250	 0.005123	 0.047512	 0.00104	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17250	 80741	 0.003715	 0.018129	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17251	 80741	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17251	 80741	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80741	 17252	 0.032486	 0.025709	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80723	 17253	 0.000861	 0.007386	 0.0021	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17253	 80742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17253	 80742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17254	 80743	 0.000104	 0.008342	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80662	 17255	 0.009346	 0.012163	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17256	 17257	 0.17817	 0.13967	 0.00179	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17257	 18022	 0.062619	 0.10444	 0.00152	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80309	 17257	 0.20757	 0.15274	 0.00223	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17257	 80745	 0.14578	 0.11538	 0.00145	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17258	 17259	 0.006949	 0.017863	 0.00442	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17258	 80745	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17258	 80745	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17259	 18021	 0.010048	 0.035518	 0.008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17259	 80746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17259	 80746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17260	 17267	 0.038982	 0.10784	 0.00251	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17260	 80747	 0.018391	 0.093032	 0.00162	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17260	 80749	 0.050032	 0.16512	 0.00268	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17261	 17262	 0.008055	 0.031658	 0.00828	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17261	 17499	 0.009022	 0.051291	 0.01485	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17261	 80747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17261	 80747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17262	 80748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17262	 80748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17263	 17264	 0.01107	 0.075987	 0.00139	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17263	 17516	 0.108	 0.2117	 0.00317	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17264	 80749	 0.029485	 0.16762	 0.00303	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17265	 17269	 0.008243	 0.041416	 0.01078	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17265	 17500	 0.017335	 0.11636	 0.02811	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17265	 80749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17265	 80749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17266	 17267	 0.053809	 0.14263	 0.00362	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17266	 80751	 0.069914	 0.16063	 0.00244	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17266	 80752	 0.03324	 0.11631	 0.00241	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17268	 80750	 0.020455	 0.10775	 0.00193	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17268	 80751	 0.039616	 0.11363	 0.00175	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17269	 17270	 0.00649	 0.039905	 0.01151	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17269	 80750	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17269	 80750	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17270	 17271	 0.005617	 0.029862	 0.00693	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17270	 80751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17270	 80751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17271	 80752	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17271	 80752	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17272	 17273	 0.002925	 0.021363	 0.00549	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17273	 17279	 0.002528	 0.016961	 0.00409	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17273	 80753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17273	 80753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17274	 17276	 0.014183	 0.026371	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80750	 17274	 0.04435	 0.10297	 0.00153	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80751	 17275	 0.038098	 0.10071	 0.00183	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80753	 17275	 0.032019	 0.098228	 0.00266	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17275	 80755	 0.014559	 0.11348	 0.00212	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17276	 17278	 0.04132	 0.069608	 0.00099	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17277	 17278	 0.052605	 0.041631	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17278	 80754	 0.007787	 0.023437	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17279	 17280	 0.001618	 0.011639	 0.00308	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17280	 17282	 0.001758	 0.015076	 0.00429	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17280	 80754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17280	 80754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80754	 17281	 0.038994	 0.042473	 0.00058	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79551	 17282	 0.009914	 0.098273	 0.03012	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17282	 80755	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17282	 80755	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17283	 17515	 0.020056	 0.10812	 0.00218	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80755	 17283	 0.014344	 0.075562	 0.00136	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17284	 17285	 0.014625	 0.026286	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80479	 17284	 0.050674	 0.040102	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17285	 17289	 0.012263	 0.035172	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17286	 17287	 0.002327	 0.008428	 0.00181	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17286	 17292	 0.013133	 0.038041	 0.00918	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17286	 80756	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17286	 80756	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17287	 17292	 0.009941	 0.033497	 0.00833	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17287	 17296	 0.005129	 0.020161	 0.00527	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17287	 80757	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17287	 80757	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80757	 17288	 0.048992	 0.032909	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17289	 17298	 0.019102	 0.082036	 0.0015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80757	 17289	 0.027617	 0.054679	 0.0008	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17290	 17291	 0.007786	 0.0198	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80757	 17290	 0.009599	 0.030479	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79549	 17291	 0.061301	 0.061481	 0.00099	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80757	 17291	 0.012941	 0.042706	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17291	 80758	 0.098146	 0.10795	 0.00144	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17292	 80758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17292	 80758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17293	 17294	 0.023276	 0.11231	 0.00198	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80758	 17293	 0.03752	 0.09645	 0.00149	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80517	 17294	 0.016983	 0.11658	 0.00213	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17295	 17297	 0.00466	 0.024679	 0.00626	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17295	 17301	 0.008974	 0.037052	 0.00877	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17296	 17297	 0.004832	 0.018992	 0.00497	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17297	 80759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17297	 80759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17298	 80760	 0.017786	 0.10111	 0.00183	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17299	 17301	 0.009417	 0.037705	 0.0095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17299	 80760	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17299	 80760	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17300	 18011	 0.070237	 0.084082	 0.0014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17300	 80761	 0.063855	 0.083926	 0.00115	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17301	 17926	 0.007147	 0.025009	 0.00829	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17301	 17955	 0.014242	 0.095575	 0.02308	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17301	 80761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17301	 80761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17302	 17314	 0.017183	 0.013598	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17303	 17305	 0.014045	 0.014186	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17303	 80772	 0.00954	 0.022145	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17304	 17319	 0.001796	 0.00731	 0.00178	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17304	 80762	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17304	 80762	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17304	 80773	 0.001438	 0.006526	 0.00227	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17305	 80763	 0.021886	 0.014169	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17306	 17307	 0.001089	 0.004139	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17306	 17319	 0.001826	 0.006453	 0.00145	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17307	 80763	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17307	 80763	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17307	 80764	 0.002759	 0.010844	 0.00284	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17308	 80765	 0.01121	 0.020533	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17309	 17316	 0.000878	 0.005857	 0.01104	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17309	 80764	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80765	 17309	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17309	 80766	 0.000117	 0.001331	 0.00496	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17310	 80766	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17310	 80766	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17311	 17312	 0.001844	 0.005142	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80764	 17311	 0.001731	 0.005384	 0.00112	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80767	 17311	 0.000606	 0.005372	 0.00143	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17311	 80769	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17311	 80769	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17312	 80770	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17312	 80770	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17312	 80771	 0.001993	 0.005426	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80770	 17313	 0.005622	 0.010144	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17313	 80772	 0.019686	 0.015579	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17314	 80772	 0.011613	 0.012773	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79534	 17315	 0.000973	 0.006704	 0.01183	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80766	 17315	 0.000415	 0.00346	 0.01079	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17315	 80771	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80772	 17315	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79534	 17316	 0.000729	 0.004861	 0.00916	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17316	 80773	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17316	 80773	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17317	 80774	 0.000111	 0.008871	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17318	 17345	 0.011338	 0.036357	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17318	 17345	 0.011338	 0.036357	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80775	 17318	 0.015455	 0.054077	 0.00112	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80775	 17318	 0.015455	 0.054077	 0.00112	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17319	 17320	 0.001019	 0.0053	 0.00156	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17320	 17321	 0.002328	 0.0113	 0.00258	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17320	 80776	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17320	 80776	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17321	 17325	 0.001663	 0.007872	 0.00189	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17322	 17427	 0.004429	 0.028052	 0.00761	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80774	 17322	 0.005327	 0.027749	 0.00728	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17323	 17324	 0.001162	 0.006052	 0.00159	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17323	 17328	 0.001247	 0.006645	 0.00186	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17323	 80777	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17323	 80777	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17324	 17325	 0.001538	 0.00778	 0.00217	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17325	 17344	 0.000677	 0.008668	 0.00259	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17326	 17331	 0.04517	 0.035747	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17327	 17328	 0.001055	 0.004224	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17327	 17330	 0.000955	 0.003885	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80764	 17328	 0.003337	 0.017056	 0.00465	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17328	 80778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17328	 80778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80777	 17329	 0.007629	 0.018066	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80778	 17329	 0.007907	 0.018354	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17330	 17335	 0.001795	 0.007056	 0.00185	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17331	 80779	 0.016825	 0.022113	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17332	 17333	 0.020316	 0.019051	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80765	 17332	 0.03911	 0.030951	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80768	 17333	 0.015044	 0.029785	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17334	 17336	 0.006261	 0.019227	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17334	 17337	 0.015962	 0.02662	 0.00039	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17334	 17338	 0.009548	 0.023698	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80767	 17335	 0.003028	 0.015213	 0.00396	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17335	 80779	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17335	 80779	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80779	 17336	 0.008693	 0.020584	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80768	 17337	 0.019926	 0.046261	 0.00069	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17338	 17339	 0.011458	 0.037811	 0.00061	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17339	 80780	 0.007665	 0.02982	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17340	 17341	 0.000212	 0.003306	 0.01389	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80766	 17340	 0.000425	 0.007112	 0.02585	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17340	 80780	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17340	 80780	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17341	 17342	 8.1e-05	 0.001267	 0.00532	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17342	 17343	 0.000262	 0.004437	 0.01568	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17344	 17423	 0.001242	 0.016616	 0.00454	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80762	 17345	 0.006031	 0.018501	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80762	 17345	 0.006031	 0.018501	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17346	 19147	 0.010122	 0.045106	 0.01226	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17346	 80781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17346	 80781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80781	 17347	 0.26938	 0.2112	 0.00271	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17348	 18655	 0.014317	 0.055705	 0.01488	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17348	 80782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17348	 80782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17349	 18655	 0.008371	 0.037694	 0.01003	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17350	 18180	 0.009372	 0.036838	 0.00964	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17351	 80783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17351	 80783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17351	 80786	 0.017749	 0.046083	 0.01119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17352	 17369	 0.004713	 0.02162	 0.00554	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17352	 80784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17352	 80784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17353	 17354	 0.007003	 0.028039	 0.00706	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17354	 17368	 0.003472	 0.01593	 0.00408	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17354	 80785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17354	 80785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17355	 17356	 0.17592	 0.13923	 0.00175	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17355	 17366	 0.097799	 0.12728	 0.00178	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80451	 17355	 0.053862	 0.14239	 0.00259	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17356	 80787	 0.10128	 0.20055	 0.00294	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17357	 17361	 0.01417	 0.057667	 0.01405	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17357	 17425	 0.00775	 0.032	 0.00757	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17358	 17359	 0.00438	 0.017825	 0.00434	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17358	 17361	 0.009474	 0.040099	 0.00902	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17359	 17424	 0.008045	 0.03274	 0.00798	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17360	 80787	 0.14584	 0.10544	 0.0016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17361	 80786	 0.00213	 0.013925	 0.00354	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17362	 17963	 0.007705	 0.058425	 0.2221	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80399	 17362	 0.006138	 0.046794	 0.0852	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80766	 17362	 0.006632	 0.072509	 0.14096	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80766	 17362	 0.006632	 0.072509	 0.14096	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17362	 80786	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80787	 17362	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17363	 17379	 0.10441	 0.081847	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80787	 17363	 0.006323	 0.025841	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17363	 80789	 0.00828	 0.030616	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17364	 80789	 0.012371	 0.026511	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17364	 80790	 0.014272	 0.025752	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17365	 17367	 0.046473	 0.034192	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17365	 17373	 0.043834	 0.044759	 0.0007	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17366	 17367	 0.036026	 0.036388	 0.00048	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17367	 80790	 0.027295	 0.077456	 0.00122	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17368	 17369	 0.0031	 0.013958	 0.00371	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17369	 17374	 0.002761	 0.011687	 0.00263	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80786	 17369	 0.003076	 0.027975	 0.00706	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17369	 80788	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17369	 80788	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17370	 17371	 0.007092	 0.014042	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17370	 17373	 0.042649	 0.033752	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17371	 17372	 0.003691	 0.00874	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17372	 80790	 0.007508	 0.021305	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17373	 80789	 0.029653	 0.058711	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17374	 17376	 0.002096	 0.009775	 0.00242	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80784	 17375	 0.033798	 0.11275	 0.00179	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80788	 17375	 0.016739	 0.05584	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17375	 80789	 0.003961	 0.014151	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80786	 17376	 0.001725	 0.010702	 0.00259	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17376	 80789	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17376	 80789	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17377	 17378	 0.037837	 0.029658	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17378	 17379	 0.073084	 0.052833	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80787	 17378	 0.02998	 0.058755	 0.00088	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80360	 17379	 0.23992	 0.17655	 0.00258	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80783	 17379	 0.12444	 0.091562	 0.00134	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80786	 17380	 0.004026	 0.01704	 0.00383	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17380	 80790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17380	 80790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80783	 17381	 0.033561	 0.060323	 0.00108	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80787	 17381	 0.16959	 0.15303	 0.00256	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17382	 17385	 0.051318	 0.040613	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17382	 80794	 0.086771	 0.095441	 0.00127	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17383	 17384	 0.056512	 0.044723	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17383	 17385	 0.004133	 0.009595	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17385	 80795	 0.035347	 0.033148	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17386	 80796	 0.027266	 0.019314	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17387	 17447	 0.22018	 0.16202	 0.00237	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17387	 80793	 0.13796	 0.089324	 0.0017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17388	 17389	 0.007616	 0.027577	 0.00592	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17388	 17446	 0.013715	 0.049665	 0.01066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17389	 80791	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17389	 80791	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80465	 17390	 0.074949	 0.059314	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17391	 17392	 0.006984	 0.021831	 0.00632	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17391	 17396	 0.008586	 0.028928	 0.00719	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17391	 80792	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17391	 80792	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79525	 17392	 0.023839	 0.11288	 0.02716	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17392	 80793	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17392	 80793	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80297	 17393	 0.17647	 0.13967	 0.00176	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80792	 17393	 0.12645	 0.10008	 0.00126	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80793	 17393	 0.034572	 0.063321	 0.00109	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80460	 17394	 0.10462	 0.1745	 0.00254	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17394	 80794	 0.01508	 0.07842	 0.0017	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17395	 80794	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17395	 80794	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17396	 17397	 0.003267	 0.00877	 0.00199	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17397	 17405	 0.001588	 0.004198	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17398	 17401	 0.01749	 0.011323	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17398	 80795	 0.022124	 0.017509	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17398	 80796	 0.029745	 0.023316	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17399	 17404	 0.002018	 0.005493	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17399	 17407	 0.002808	 0.00783	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17399	 80795	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17399	 80795	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17400	 17402	 0.023188	 0.016763	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17400	 17406	 0.050708	 0.039748	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17401	 17402	 0.006143	 0.010348	 0.00015	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80795	 17401	 0.02286	 0.017919	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17402	 17403	 0.004456	 0.011454	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17402	 17408	 0.038185	 0.024721	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17404	 17405	 0.002285	 0.006373	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17404	 80796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17404	 80796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17405	 80797	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17405	 80797	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80797	 17406	 0.023524	 0.018616	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80393	 17410	 0.11532	 0.091267	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17411	 17413	 0.006841	 0.0332	 0.00759	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80400	 17411	 0.019698	 0.10215	 0.02496	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17412	 17413	 0.007679	 0.035228	 0.00902	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80400	 17412	 0.009781	 0.043587	 0.01185	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17414	 17416	 0.003167	 0.015201	 0.00045	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17414	 17417	 0.004237	 0.016484	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17415	 17416	 0.003867	 0.020373	 0.00037	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17415	 80800	 0.007315	 0.041581	 0.00075	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17416	 80798	 0.016649	 0.055539	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17416	 80800	 0.018259	 0.060911	 0.00097	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17417	 80798	 0.020265	 0.032347	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17418	 17419	 0.001907	 0.007635	 0.00192	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17419	 80798	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17419	 80798	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17419	 80799	 0.007271	 0.028577	 0.00748	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17420	 17438	 0.009867	 0.028302	 0.00696	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17420	 80799	 0.009328	 0.023978	 0.00594	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79601	 17421	 0.005102	 0.040365	 0.14029	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17421	 80799	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80800	 17421	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95337	 17421	 0.004705	 0.0456	 0.16156	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17422	 17694	 0.11165	 0.27336	 0.00468	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80800	 17422	 0.041987	 0.067019	 0.00154	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17423	 17427	 0.000676	 0.008663	 0.00259	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17424	 17425	 0.002379	 0.009523	 0.0024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17425	 17426	 0.002119	 0.017025	 0.00479	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17426	 17427	 0.002518	 0.021597	 0.00615	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17427	 80801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17427	 80801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80801	 17428	 0.015968	 0.086081	 0.00173	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17428	 80803	 0.035006	 0.16891	 0.00298	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17429	 80803	 0.19093	 0.14049	 0.00205	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17430	 17432	 0.031344	 0.10456	 0.00166	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17430	 80803	 0.02914	 0.16375	 0.00303	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17431	 17433	 0.004611	 0.021823	 0.00525	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17431	 17436	 0.002304	 0.014295	 0.00346	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17431	 80802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17431	 80802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80802	 17432	 0.030667	 0.075066	 0.00128	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17432	 80804	 0.038757	 0.12307	 0.00216	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17433	 17437	 0.00704	 0.041239	 0.01123	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17433	 80803	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17433	 80803	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17434	 80804	 0.28209	 0.21378	 0.00294	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17436	 17437	 0.002928	 0.016643	 0.00482	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17436	 80804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17436	 80804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80774	 17437	 0.002644	 0.024884	 0.00754	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17438	 17439	 0.007932	 0.031759	 0.008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17438	 80805	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17438	 80805	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80805	 17440	 0.17301	 0.13693	 0.00172	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79523	 17441	 0.001173	 0.010448	 0.01836	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79546	 17441	 0.000387	 0.005438	 0.02255	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17441	 80806	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17441	 80806	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17442	 18612	 0.000904	 0.014604	 1.0289	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17442	 80807	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17442	 80807	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17443	 17446	 0.005204	 0.030484	 0.0083	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79525	 17443	 0.004518	 0.030311	 0.00732	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79547	 17443	 0.000626	 0.004998	 0.00123	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17443	 80808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17443	 80808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17443	 80809	 0.00984	 0.038674	 0.01012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80808	 17444	 0.029739	 0.0356	 0.00059	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79523	 17445	 0.003585	 0.023609	 0.04569	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79546	 17445	 0.001338	 0.01515	 0.03034	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17445	 80809	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17445	 80809	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17446	 80810	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17446	 80810	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80810	 17447	 0.044826	 0.087852	 0.00132	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17448	 17459	 0.001394	 0.004698	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17448	 80811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17448	 80811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17449	 17450	 0.00825	 0.011246	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17449	 80813	 0.018705	 0.043426	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17450	 17452	 0.006468	 0.01855	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17450	 17453	 0.007491	 0.017391	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17450	 17464	 0.032253	 0.07487	 0.00143	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17451	 17455	 0.020629	 0.015178	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17452	 17455	 0.015943	 0.033508	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80811	 17453	 0.006732	 0.012892	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17454	 17455	 0.006808	 0.0175	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17454	 80812	 0.007366	 0.040561	 0.00092	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17456	 17459	 0.000902	 0.005712	 0.00155	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17456	 17475	 0.005442	 0.018336	 0.00456	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17456	 80812	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17456	 80812	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17456	 80993	 0.016874	 0.10693	 0.02904	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17457	 17460	 0.005261	 0.023443	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80812	 17457	 0.010431	 0.026814	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17457	 80816	 0.018668	 0.072626	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17458	 17468	 0.011509	 0.035343	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80812	 17458	 0.019328	 0.049685	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17459	 17479	 0.006007	 0.038697	 0.01015	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17459	 80813	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17459	 80813	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80813	 17460	 0.004519	 0.017578	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17461	 17478	 0.090688	 0.074646	 0.00151	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80811	 17461	 0.005599	 0.032652	 0.00066	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17461	 80814	 0.098636	 0.10534	 0.00223	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17462	 17479	 0.014812	 0.044359	 0.00999	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80394	 17462	 0.015988	 0.084774	 0.02831	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17462	 80814	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17462	 80814	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17463	 17464	 0.045267	 0.035824	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17464	 17465	 0.020396	 0.052429	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17464	 17466	 0.01552	 0.063429	 0.00128	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80814	 17464	 0.022572	 0.08684	 0.00148	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17465	 80816	 0.019719	 0.056557	 0.00087	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80311	 17466	 0.021343	 0.10298	 0.00182	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17467	 17470	 0.007504	 0.030044	 0.00757	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80394	 17467	 0.009714	 0.04881	 0.0127	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17467	 80815	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17467	 80815	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17468	 17469	 0.011646	 0.026756	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17468	 17471	 0.015802	 0.069622	 0.00121	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17469	 80816	 0.008055	 0.026581	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17470	 80816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17470	 80816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17471	 17472	 0.061954	 0.068143	 0.00091	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80642	 17471	 0.026271	 0.11926	 0.00259	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80815	 17472	 0.051954	 0.079578	 0.00138	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80642	 17473	 0.13861	 0.10866	 0.00139	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80812	 17474	 0.041489	 0.10552	 0.00167	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17475	 17476	 0.006589	 0.026379	 0.00665	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17475	 17477	 0.007561	 0.025939	 0.00621	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17475	 80817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17475	 80817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17476	 80818	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17476	 80818	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80817	 17478	 0.015021	 0.052593	 0.00146	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17478	 80819	 0.030898	 0.081895	 0.00208	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17479	 80819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17479	 80819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17480	 80867	 0.121	 0.078339	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17481	 17482	 0.003722	 0.014148	 0.00396	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17481	 17611	 0.009951	 0.039844	 0.01004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17482	 17484	 0.002641	 0.010748	 0.00262	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17483	 80820	 0.077943	 0.15276	 0.00229	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17483	 80867	 0.083362	 0.21432	 0.00332	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17484	 17486	 0.003284	 0.013365	 0.00326	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80606	 17485	 0.056381	 0.099156	 0.00186	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17485	 80820	 0.017806	 0.045773	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17486	 80820	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17486	 80820	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17487	 17488	 0.002229	 0.008924	 0.00225	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17487	 17489	 0.001523	 0.006097	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17487	 80821	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17487	 80821	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17488	 17498	 0.00749	 0.020393	 0.00449	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17488	 80822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17488	 80822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17489	 17492	 0.003593	 0.022755	 0.00618	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17489	 17499	 0.005001	 0.027441	 0.00725	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17490	 17491	 0.01101	 0.022531	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17490	 80823	 0.002511	 0.020887	 0.0004	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17490	 80828	 0.006979	 0.050222	 0.00165	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17491	 80824	 0.028022	 0.072033	 0.00111	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17492	 17508	 0.002193	 0.018678	 0.00466	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17492	 80823	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17492	 80823	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80823	 17493	 0.053819	 0.042592	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17494	 17495	 0.014498	 0.085833	 0.00167	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80823	 17494	 0.012187	 0.067111	 0.00151	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80446	 17495	 0.019298	 0.11865	 0.00214	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17496	 17497	 0.02039	 0.10315	 0.00179	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80821	 17496	 0.010237	 0.045363	 0.00136	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80447	 17497	 0.018944	 0.10137	 0.00307	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17498	 17500	 0.011391	 0.030642	 0.00859	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17498	 80824	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17498	 80824	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17501	 17503	 0.011539	 0.029663	 0.00735	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17501	 80825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17501	 80825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80825	 17502	 0.032755	 0.1081	 0.00175	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17502	 80828	 0.016623	 0.066522	 0.0014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17503	 17507	 0.006413	 0.025675	 0.00647	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17503	 80826	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17503	 80826	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17504	 17512	 0.060211	 0.04765	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17505	 17511	 0.038729	 0.076681	 0.00113	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80587	 17506	 0.12446	 0.083608	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17507	 80827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17507	 80827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80558	 17508	 0.024858	 0.071314	 0.01755	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17508	 80828	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17508	 80828	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17509	 80829	 0.032051	 0.058705	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17510	 17511	 0.003215	 0.016357	 0.00037	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17510	 80830	 0.002358	 0.016187	 0.0003	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17511	 17512	 0.024518	 0.048544	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17513	 80829	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17513	 80829	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80571	 17514	 0.001953	 0.006904	 0.00156	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17514	 80830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17514	 80830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17515	 80833	 0.019349	 0.092881	 0.00278	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79574	 17516	 0.056876	 0.13469	 0.00246	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17517	 17519	 0.001762	 0.011523	 0.00293	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17518	 80831	 0.037544	 0.038336	 0.0006	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17519	 17521	 0.001156	 0.007322	 0.00199	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17520	 17521	 0.001819	 0.008345	 0.00214	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17520	 17524	 0.004086	 0.016625	 0.00405	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17520	 80831	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17520	 80831	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17521	 80832	 0.002773	 0.01293	 0.0032	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79526	 17522	 0.007984	 0.073448	 0.00146	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79552	 17522	 0.01009	 0.077724	 0.00149	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79550	 17523	 0.000571	 0.003891	 0.00701	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17523	 80832	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17523	 80832	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17524	 17525	 0.006595	 0.019751	 0.00445	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17524	 80833	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17524	 80833	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17525	 17637	 0.009111	 0.032206	 0.00726	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80832	 17525	 0.004477	 0.018219	 0.00444	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17526	 80834	 0.024779	 0.063697	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17527	 17529	 0.008918	 0.023943	 0.00543	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17527	 80834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17527	 80834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17528	 17529	 0.002166	 0.016043	 0.00822	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17528	 80835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17528	 80835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17529	 17530	 0.001326	 0.016349	 0.00528	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17530	 17531	 0.002139	 0.024895	 0.00732	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17530	 80836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17530	 80836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17531	 80837	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17531	 80837	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17531	 80878	 0.002097	 0.032037	 0.01032	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80836	 17532	 0.01362	 0.066463	 0.00115	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17532	 80838	 0.014473	 0.064135	 0.00193	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17533	 17534	 0.001266	 0.005994	 0.00144	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17533	 17555	 0.006215	 0.027985	 0.00745	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17534	 17536	 0.008562	 0.019874	 0.00605	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17534	 80838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17534	 80838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17535	 17539	 0.018108	 0.0916	 0.00159	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80838	 17535	 0.012028	 0.047721	 0.00136	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17536	 80839	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17536	 80839	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17536	 80841	 0.019169	 0.058217	 0.01275	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17536	 80843	 0.0054	 0.034782	 0.00912	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17537	 17538	 0.03064	 0.071136	 0.00106	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80834	 17537	 0.015716	 0.096626	 0.00174	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80839	 17537	 0.017002	 0.074487	 0.0016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17538	 17541	 0.007078	 0.043518	 0.00078	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80839	 17538	 0.006172	 0.043955	 0.00099	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17539	 17553	 0.059142	 0.10631	 0.00191	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17541	 80840	 0.002547	 0.011286	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17542	 17546	 0.001462	 0.006707	 0.00172	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17542	 80840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17542	 80840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79555	 17543	 0.005794	 0.013311	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80840	 17544	 0.019338	 0.012519	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17545	 17546	 0.00262	 0.011795	 0.00314	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17545	 17547	 0.004251	 0.019502	 0.005	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79555	 17549	 0.037318	 0.067075	 0.0012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80391	 17549	 0.22964	 0.30191	 0.00414	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17550	 80841	 0.001935	 0.022733	 0.00603	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17551	 17552	 0.002743	 0.01851	 0.03409	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17551	 80841	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80842	 17551	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17552	 17635	 0.003229	 0.02179	 0.04013	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17552	 34921	 0.00308	 0.039794	 0.09024	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17552	 80843	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17552	 80843	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80842	 17554	 0.10575	 0.087044	 0.00176	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17555	 80878	 0.004899	 0.022472	 0.00576	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17556	 80879	 0.16097	 0.1274	 0.0016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17557	 17559	 0.035808	 0.082267	 0.00125	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17557	 80844	 0.024368	 0.056565	 0.00108	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17558	 17562	 0.02374	 0.064643	 0.01424	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17558	 80844	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17558	 80844	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17559	 18956	 0.016425	 0.080153	 0.00138	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79572	 17559	 0.006916	 0.04622	 0.00102	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17560	 17561	 0.01234	 0.032706	 0.00083	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17560	 17563	 0.032425	 0.04596	 0.00094	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79572	 17560	 0.002648	 0.018174	 0.00033	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17561	 80845	 0.0134	 0.039405	 0.00081	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17562	 80845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17562	 80845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17562	 81266	 0.005794	 0.022771	 0.00596	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17563	 17565	 0.028189	 0.093027	 0.00151	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80845	 17563	 0.008536	 0.041653	 0.00072	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17564	 17568	 0.000945	 0.010078	 0.02049	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17564	 17568	 0.000945	 0.010078	 0.02049	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17564	 18758	 0.000907	 0.009669	 0.01966	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17564	 18758	 0.000907	 0.009669	 0.01966	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17565	 17566	 0.013105	 0.10214	 0.00191	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17565	 81267	 0.053743	 0.1793	 0.00284	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17566	 17652	 0.022876	 0.081721	 0.00162	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17566	 80848	 0.014899	 0.045707	 0.00124	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17566	 80848	 0.014899	 0.045707	 0.00124	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17567	 19417	 0.000841	 0.012988	 1.0024	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17567	 80846	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80847	 17567	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79514	 17568	 0.000981	 0.015386	 0.03266	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80846	 17568	 0.000117	 0.001819	 0.00764	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17568	 80848	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17568	 80848	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17569	 17570	 0.009139	 0.025485	 0.00535	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79529	 17570	 0.000694	 0.010761	 0.00303	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80847	 17570	 0.002313	 0.02534	 0.00703	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17571	 17576	 0.017152	 0.083741	 0.00175	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79572	 17571	 0.018129	 0.060477	 0.00096	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17571	 80849	 0.06383	 0.096812	 0.00139	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17572	 80849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17572	 80849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17572	 80852	 0.003682	 0.01474	 0.00371	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17573	 17574	 0.000355	 0.005666	 0.01163	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17573	 80850	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80851	 17573	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17574	 80852	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80853	 17574	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80849	 17575	 0.042476	 0.054812	 0.0011	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80853	 17575	 0.010896	 0.02824	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79530	 17576	 0.007765	 0.059815	 0.00114	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79530	 17577	 0.059773	 0.091567	 0.00129	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80575	 17577	 0.23645	 0.18716	 0.00236	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17578	 17579	 0.00027	 0.002976	 0.00565	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17578	 17579	 0.00027	 0.002976	 0.00565	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17578	 17584	 0.000146	 0.002276	 0.00956	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17578	 80854	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17578	 80854	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17579	 17591	 0.00036	 0.004208	 0.01472	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17579	 17592	 0.000703	 0.005557	 0.01929	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17579	 80855	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17579	 80855	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17580	 17607	 0.026636	 0.027198	 0.00042	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17581	 17582	 0.000618	 0.004657	 0.00129	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17581	 17594	 0.001335	 0.010909	 0.00296	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17582	 17597	 0.000909	 0.008558	 0.00259	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79562	 17582	 0.001023	 0.014184	 0.00978	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80855	 17582	 0.001487	 0.011307	 0.00355	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17582	 80856	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17582	 80856	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17583	 17596	 0.011691	 0.052095	 0.00088	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79563	 17583	 0.012084	 0.043167	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79563	 17583	 0.012084	 0.043167	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80854	 17583	 0.015918	 0.051045	 0.00126	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80854	 17583	 0.015918	 0.051045	 0.00126	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17583	 80857	 0.009213	 0.027731	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79561	 17584	 0.000219	 0.003629	 0.0134	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17584	 80857	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17584	 80857	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79562	 17585	 0.007023	 0.018559	 0.00434	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17586	 17587	 0.071927	 0.11224	 0.00188	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80854	 17586	 0.031306	 0.07267	 0.00138	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79560	 17587	 0.022562	 0.10886	 0.00192	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79569	 17587	 0.013138	 0.059642	 0.00129	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17588	 17590	 0.02406	 0.080263	 0.00127	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79563	 17588	 0.033936	 0.1504	 0.00452	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80854	 17589	 0.056818	 0.062493	 0.00083	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17590	 80859	 0.027542	 0.063943	 0.00095	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17591	 17598	 0.000565	 0.006557	 0.02331	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17591	 80858	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80859	 17591	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17592	 80860	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80861	 17592	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79528	 17593	 0.016137	 0.065951	 0.00133	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80861	 17593	 0.044013	 0.067424	 0.00095	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17593	 80862	 0.013747	 0.045858	 0.00073	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80860	 17594	 0.001161	 0.008995	 0.00315	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17595	 17597	 0.001378	 0.011001	 0.00271	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79527	 17595	 0.001517	 0.013012	 0.0037	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80856	 17596	 0.011228	 0.04589	 0.00093	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17597	 80862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17597	 80862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17598	 80863	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80864	 17598	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17599	 17600	 0.007828	 0.024015	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17599	 17601	 0.012263	 0.036062	 0.00074	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17600	 17603	 0.018598	 0.044041	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80339	 17600	 0.007573	 0.045847	 0.00144	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17601	 17602	 0.008546	 0.048582	 0.00088	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80338	 17601	 0.017669	 0.067978	 0.00116	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80861	 17602	 0.008776	 0.053952	 0.00097	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17603	 17604	 0.031528	 0.081048	 0.00125	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17604	 17605	 0.032353	 0.083168	 0.00129	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79528	 17605	 0.062096	 0.084648	 0.00188	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17606	 80865	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80866	 17606	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80856	 17607	 0.006902	 0.017741	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17608	 17614	 0.036601	 0.11229	 0.00304	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17609	 17610	 0.008471	 0.034471	 0.0084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17609	 80868	 0.001737	 0.024288	 0.00824	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17611	 17620	 0.004219	 0.02471	 0.00673	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17611	 80867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17611	 80867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17611	 80868	 0.001757	 0.015215	 0.00546	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17612	 17683	 0.001015	 0.018875	 1.2535	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17612	 34668	 0.000737	 0.011895	 0.83696	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17612	 80868	 0.000144	 0.011532	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17612	 80868	 0.000144	 0.011532	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17613	 17615	 0.015813	 0.054017	 0.00117	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17613	 17615	 0.015813	 0.054017	 0.00117	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80869	 17613	 0.010604	 0.041253	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80869	 17613	 0.010604	 0.041253	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17614	 17615	 0.007835	 0.027431	 0.00076	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17615	 80870	 0.005158	 0.031346	 0.00058	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79565	 17616	 0.013016	 0.0344	 0.00805	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17616	 80870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17616	 80870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17616	 80871	 0.007851	 0.021376	 0.00471	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80387	 17617	 0.029573	 0.098654	 0.00156	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17617	 80872	 0.023231	 0.074495	 0.00184	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79564	 17618	 0.0009	 0.006004	 0.01132	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17618	 80871	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80872	 17618	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79566	 17619	 0.033016	 0.055062	 0.0008	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80870	 17619	 0.11195	 0.11198	 0.00151	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80871	 17620	 0.005879	 0.032408	 0.00758	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17621	 17628	 0.003696	 0.020622	 0.00527	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17621	 17967	 0.010835	 0.041187	 0.01153	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17622	 17623	 0.011936	 0.040948	 0.00981	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17622	 17628	 0.009622	 0.055889	 0.01316	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17622	 17970	 0.015904	 0.057594	 0.01236	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17622	 80873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17622	 80873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80412	 17624	 0.016385	 0.11247	 0.00205	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80873	 17624	 0.040596	 0.18091	 0.00307	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17625	 17626	 0.006746	 0.025644	 0.00718	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17626	 17627	 0.004403	 0.023709	 0.00651	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17627	 17628	 0.004004	 0.016292	 0.00397	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80774	 17628	 0.032594	 0.20293	 0.05743	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17628	 80874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17628	 80874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80452	 17629	 0.06864	 0.21061	 0.00571	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80874	 17629	 0.13911	 0.11009	 0.00139	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17630	 17631	 0.24363	 0.19285	 0.00243	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80452	 17631	 0.0408	 0.14576	 0.00289	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17632	 80875	 0.014984	 0.038518	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17632	 80879	 0.028802	 0.058941	 0.00145	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17633	 17634	 0.001625	 0.01149	 0.00315	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17633	 17637	 0.005773	 0.019803	 0.00474	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17633	 17638	 0.004037	 0.030546	 0.015	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79551	 17633	 0.012618	 0.058854	 0.01458	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17633	 80875	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17633	 80875	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17634	 80876	 0.001239	 0.010981	 0.00292	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79550	 17635	 0.003951	 0.026355	 0.04969	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17635	 80876	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17635	 80876	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17635	 80877	 0.000281	 0.003052	 0.00663	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17636	 80877	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17639	 80880	 0.10229	 0.10332	 0.00137	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17639	 80881	 0.11853	 0.093809	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80863	 17640	 0.016411	 0.090084	 0.02382	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17640	 80880	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17640	 80880	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17641	 17642	 0.01123	 0.049761	 0.00149	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80748	 17641	 0.017443	 0.077299	 0.00232	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80880	 17642	 0.026066	 0.053342	 0.00131	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17642	 80881	 0.014238	 0.047496	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17642	 80883	 0.01072	 0.035761	 0.00057	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17643	 17650	 0.003843	 0.013182	 0.00316	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17643	 17651	 0.002934	 0.012419	 0.00279	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17643	 80881	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17643	 80881	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17644	 17647	 0.006834	 0.028217	 0.00668	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17644	 17651	 0.004481	 0.018503	 0.00438	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17645	 80882	 0.074811	 0.097361	 0.00136	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17646	 17647	 0.006427	 0.025262	 0.00661	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17646	 17698	 0.005691	 0.022366	 0.00585	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17647	 80882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17647	 80882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17648	 17649	 0.01927	 0.059116	 0.0016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17648	 80884	 0.14194	 0.11234	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17649	 80884	 0.18616	 0.15325	 0.00311	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17650	 80883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17650	 80883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17651	 80884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17651	 80884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17652	 17653	 0.069837	 0.12792	 0.00221	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17653	 17654	 0.12923	 0.1212	 0.00187	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17654	 81341	 0.15014	 0.19735	 0.00271	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17655	 17657	 0.006747	 0.017831	 0.00417	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17655	 17682	 0.008383	 0.021764	 0.00528	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17656	 17681	 0.044437	 0.10209	 0.00155	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17656	 18014	 0.054457	 0.13999	 0.00217	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80498	 17656	 0.015315	 0.068528	 0.00141	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17656	 80885	 0.006297	 0.038715	 0.0007	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17657	 80885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17657	 80885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17658	 17659	 0.030637	 0.079404	 0.0015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80885	 17658	 0.013313	 0.040885	 0.00077	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17659	 18942	 0.071189	 0.21844	 0.00592	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17659	 80886	 0.022597	 0.087909	 0.00147	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79515	 17660	 0.003976	 0.015627	 0.00409	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17660	 80886	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17660	 80886	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17661	 17663	 0.004069	 0.014239	 0.00472	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17661	 18941	 0.00859	 0.034955	 0.00852	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17662	 17664	 0.006604	 0.017455	 0.00409	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17662	 17682	 0.008149	 0.021537	 0.00504	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17663	 17666	 0.003328	 0.013325	 0.00336	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17664	 17666	 0.005727	 0.015136	 0.00354	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17665	 80887	 0.047219	 0.034135	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17666	 17669	 0.001855	 0.007548	 0.00184	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17666	 17670	 0.006287	 0.017118	 0.00377	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17666	 18941	 0.007974	 0.050513	 0.01371	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17666	 80887	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17666	 80887	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17666	 81535	 0.010337	 0.077883	 0.02162	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80887	 17667	 0.036503	 0.026856	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17667	 80888	 0.018218	 0.032039	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17668	 18217	 0.035817	 0.082287	 0.00125	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17668	 80888	 0.016506	 0.041977	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17668	 80889	 0.12571	 0.08139	 0.00155	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17669	 17671	 0.004175	 0.017238	 0.00408	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17669	 80888	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17669	 80888	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17670	 80889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17670	 80889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17671	 18216	 0.008624	 0.034527	 0.0087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17672	 17673	 0.01207	 0.032404	 0.00734	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17672	 18646	 0.017231	 0.044737	 0.01086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17673	 17982	 0.013386	 0.035939	 0.00815	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17674	 17983	 0.011468	 0.051106	 0.01389	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17674	 18017	 0.005147	 0.020608	 0.00519	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17674	 80890	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17674	 80890	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17674	 81535	 0.039054	 0.1152	 0.02682	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17675	 17678	 0.010811	 0.066467	 0.0012	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80890	 17675	 0.004551	 0.037859	 0.00072	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17676	 17677	 0.021108	 0.054261	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80889	 17676	 0.026183	 0.053581	 0.00132	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17677	 17678	 0.01706	 0.081935	 0.00158	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80889	 17677	 0.045627	 0.11729	 0.00182	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80889	 17679	 0.11532	 0.091263	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17680	 80891	 0.18786	 0.13582	 0.00206	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17681	 80891	 0.035693	 0.076489	 0.00134	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17682	 80891	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17682	 80891	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17683	 39427	 0.000196	 0.003512	 0.24929	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17683	 80892	 0.000124	 0.009885	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17684	 17686	 0.006016	 0.021886	 0.0067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80892	 17684	 0.009686	 0.038782	 0.00977	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79559	 17685	 0.034008	 0.13231	 0.00221	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17687	 17688	 0.030394	 0.1014	 0.00161	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17688	 80894	 0.016956	 0.051036	 0.001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17688	 80895	 0.011921	 0.06379	 0.00193	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80868	 17689	 0.071359	 0.19188	 0.04357	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17689	 80894	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17689	 80894	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17690	 17691	 0.038234	 0.090541	 0.00166	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80894	 17690	 0.01623	 0.064951	 0.00137	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80894	 17691	 0.033684	 0.085666	 0.00135	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17692	 17693	 0.009003	 0.032754	 0.01003	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17692	 80895	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17692	 80895	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17695	 17696	 0.046365	 0.15468	 0.00245	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80300	 17695	 0.2011	 0.15917	 0.002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17696	 80897	 0.023087	 0.077016	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17696	 80906	 0.041292	 0.088488	 0.00155	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17697	 17698	 0.00475	 0.018667	 0.00488	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17697	 17703	 0.003514	 0.014301	 0.00348	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17697	 80896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17697	 80896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17699	 80897	 0.057424	 0.045012	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17700	 17706	 0.004776	 0.012399	 0.00301	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17700	 80897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17700	 80897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17700	 80898	 0.002218	 0.009884	 0.00269	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17700	 80905	 0.008113	 0.033016	 0.00804	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17701	 80898	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80899	 17701	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17701	 80904	 0.000642	 0.008493	 0.03093	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17701	 87065	 0.002146	 0.029219	 0.05948	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17702	 17724	 0.033115	 0.065565	 0.00096	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80899	 17702	 0.017181	 0.038971	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17703	 17704	 0.001036	 0.004073	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17704	 80900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17704	 80900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80900	 17705	 0.005914	 0.026352	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17705	 80901	 0.00481	 0.021433	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17706	 17710	 0.002184	 0.010599	 0.00242	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17706	 80901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17706	 80901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80901	 17707	 0.01585	 0.020172	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17708	 17709	 0.012708	 0.022348	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17709	 80902	 0.011367	 0.02639	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80898	 17710	 0.003261	 0.011526	 0.0026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17710	 80902	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17710	 80902	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17711	 17731	 0.011339	 0.039701	 0.0011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80899	 17711	 0.016712	 0.033088	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80902	 17711	 0.007088	 0.018221	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17712	 80903	 0.009837	 0.025288	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17713	 80903	 0.018329	 0.029882	 0.00046	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17714	 80903	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17714	 80903	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17714	 80905	 0.006429	 0.016992	 0.00398	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17715	 17716	 0.045906	 0.033775	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80903	 17715	 0.021742	 0.039078	 0.0007	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17716	 17718	 0.049082	 0.038843	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17716	 17725	 0.055102	 0.084413	 0.00119	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17717	 80904	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17718	 17720	 0.019552	 0.076065	 0.00127	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17718	 17723	 0.052664	 0.13394	 0.00212	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17719	 17721	 0.004992	 0.022244	 0.00604	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80905	 17719	 0.002425	 0.011056	 0.00351	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17720	 17722	 0.045097	 0.08929	 0.00131	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17720	 80907	 0.034589	 0.088917	 0.00138	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17721	 80907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17721	 80907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80907	 17722	 0.2025	 0.14901	 0.00218	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17723	 17725	 0.031129	 0.079167	 0.00125	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17723	 84869	 0.10829	 0.42149	 0.00704	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17724	 17732	 0.048207	 0.03815	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17726	 17727	 0.01068	 0.027161	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17726	 17730	 0.017077	 0.043898	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17727	 17728	 0.026956	 0.037567	 0.00064	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17728	 17729	 0.006945	 0.033508	 0.00059	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80722	 17728	 0.014186	 0.061982	 0.00163	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17728	 84871	 0.10738	 0.39722	 0.00736	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17729	 17731	 0.012129	 0.042468	 0.00118	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80716	 17730	 0.028637	 0.051671	 0.00075	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17731	 17733	 0.035663	 0.091676	 0.00142	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17733	 17734	 0.044605	 0.034964	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17733	 17735	 0.08623	 0.087097	 0.00115	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17736	 17741	 0.005515	 0.02277	 0.00539	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17736	 17936	 0.010198	 0.03402	 0.00863	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17737	 17738	 0.014609	 0.033913	 0.01033	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17737	 18891	 0.007891	 0.03258	 0.00771	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79633	 17737	 0.019204	 0.052289	 0.01152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80545	 17737	 0.029532	 0.11496	 0.03073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17738	 80908	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17738	 80908	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17739	 80910	 0.051937	 0.041103	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17740	 80909	 0.020697	 0.037344	 0.00054	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17740	 80910	 0.011512	 0.038404	 0.00061	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17741	 17742	 0.002338	 0.008019	 0.00192	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17741	 80909	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17741	 80909	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17742	 17743	 0.001674	 0.006704	 0.00169	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17743	 17745	 0.006299	 0.021954	 0.00509	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17743	 80910	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17743	 80910	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79634	 17744	 0.11898	 0.30847	 0.00583	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80909	 17744	 0.037491	 0.066965	 0.00099	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17746	 17747	 0.001359	 0.003591	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17746	 17791	 0.004108	 0.020984	 0.00528	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17746	 80911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17746	 80911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17747	 17757	 0.000954	 0.00266	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17748	 17749	 0.005477	 0.014078	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17748	 17763	 0.010766	 0.013892	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80911	 17748	 0.002393	 0.015024	 0.00033	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17748	 80915	 0.049255	 0.049749	 0.00066	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17750	 17751	 0.003756	 0.009956	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17750	 17764	 0.007076	 0.017321	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17751	 17752	 0.002534	 0.010882	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17752	 80912	 0.002019	 0.011477	 0.00021	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17753	 17930	 0.001822	 0.007295	 0.00184	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17753	 80912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17753	 80912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17754	 17756	 0.007236	 0.016015	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80911	 17754	 0.009448	 0.010391	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80912	 17754	 0.003436	 0.015312	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17755	 17775	 0.005389	 0.010671	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17755	 17776	 0.0173	 0.012506	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17755	 80914	 0.018206	 0.01677	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17755	 80920	 0.05678	 0.03676	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17756	 17770	 0.014231	 0.023327	 0.00041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17756	 80913	 0.015794	 0.012499	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17756	 80914	 0.018958	 0.017778	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17757	 17758	 0.001467	 0.004091	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17757	 80913	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17757	 80913	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17758	 17760	 0.001675	 0.004036	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17758	 80914	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17758	 80914	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17759	 80920	 0.025124	 0.018485	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17760	 17778	 0.00185	 0.004889	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80914	 17761	 0.02536	 0.02007	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17762	 17763	 0.027842	 0.026109	 0.0004	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17762	 17782	 0.013203	 0.023219	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17762	 17784	 0.017948	 0.014204	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17764	 17788	 0.011363	 0.018137	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17765	 17785	 0.006484	 0.016668	 0.00413	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17765	 17792	 0.004034	 0.016414	 0.004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17765	 80915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17765	 80915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17765	 80966	 0.002664	 0.007854	 0.00183	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17766	 17768	 0.008794	 0.016107	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80915	 17766	 0.017104	 0.016039	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17767	 17768	 0.004205	 0.02127	 0.00037	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17767	 80923	 0.044009	 0.028492	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17767	 80973	 0.003424	 0.020514	 0.00049	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17769	 17772	 0.001518	 0.004011	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17769	 80916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17769	 80916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17770	 17776	 0.027709	 0.020031	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80916	 17770	 0.011853	 0.027517	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17770	 80929	 0.010312	 0.070782	 0.00129	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17771	 17778	 0.002959	 0.00886	 0.002	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17771	 17852	 0.002013	 0.008058	 0.00203	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17771	 80917	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17771	 80917	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17772	 17773	 0.002063	 0.007077	 0.0017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17772	 80918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17772	 80918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17773	 17848	 0.002051	 0.006688	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17773	 80919	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17773	 80919	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80917	 17774	 0.034634	 0.02624	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80918	 17774	 0.009598	 0.013083	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80919	 17774	 0.010304	 0.023671	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17775	 17776	 0.006899	 0.008411	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80918	 17775	 0.003432	 0.015292	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17777	 17781	 0.011877	 0.023516	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17777	 80920	 0.020366	 0.02057	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17778	 80920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17778	 80920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17778	 80953	 0.008891	 0.0305	 0.00731	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17779	 17782	 0.006988	 0.017964	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17779	 17873	 0.010758	 0.0213	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80920	 17779	 0.034657	 0.038119	 0.00051	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17780	 17781	 0.018629	 0.014743	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17781	 80957	 0.003613	 0.019031	 0.00034	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17783	 17785	 0.001888	 0.004988	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17783	 17892	 0.001868	 0.004937	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17785	 80921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17785	 80921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17786	 17904	 0.008245	 0.021194	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17787	 17789	 0.025724	 0.025982	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80921	 17787	 0.004764	 0.014614	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17788	 17789	 0.011146	 0.020415	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17788	 80967	 0.023306	 0.041889	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17790	 17799	 0.015125	 0.035816	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17790	 80922	 0.018921	 0.023774	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17791	 17792	 0.002793	 0.010867	 0.0029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17791	 80922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17791	 80922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17791	 80924	 0.006397	 0.017415	 0.00384	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17791	 80928	 0.001721	 0.007897	 0.00202	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17792	 80923	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17792	 80923	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17793	 17794	 0.067587	 0.053488	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17793	 80967	 0.012026	 0.03693	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80630	 17794	 0.041565	 0.064856	 0.00108	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17795	 80924	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80925	 17795	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17795	 80927	 0.000885	 0.007744	 0.01412	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80924	 17796	 0.001633	 0.009566	 0.00261	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17797	 80926	 0.011212	 0.049959	 0.00085	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17797	 80930	 0.013551	 0.066124	 0.00114	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17798	 80926	 0.048831	 0.047181	 0.00069	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80925	 17799	 0.024377	 0.040491	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17799	 80926	 0.011079	 0.049368	 0.00084	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17800	 17813	 0.002969	 0.009683	 0.00257	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17800	 80926	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17800	 80926	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17800	 80928	 0.005799	 0.024544	 0.00552	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17801	 17802	 0.007089	 0.018789	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17801	 17842	 0.031367	 0.034499	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80916	 17801	 0.012009	 0.03183	 0.00081	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17802	 17803	 0.00552	 0.022091	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17802	 17842	 0.015381	 0.030453	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17803	 17804	 0.05076	 0.040171	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17803	 17805	 0.016369	 0.030435	 0.00071	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17803	 17822	 0.012973	 0.025685	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17803	 17836	 0.005101	 0.028703	 0.00062	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17805	 17806	 0.014319	 0.025837	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17806	 80929	 0.049611	 0.050109	 0.00066	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17807	 17835	 0.00016	 0.002192	 0.16584	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17807	 17882	 0.000281	 0.00363	 0.23168	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17807	 80927	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17808	 17809	 0.017318	 0.040206	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17808	 80932	 0.01562	 0.060766	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17808	 80934	 0.006604	 0.029428	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17809	 17810	 0.041577	 0.032903	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17809	 80935	 0.0084	 0.03268	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17810	 17812	 0.009323	 0.063993	 0.00117	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79522	 17810	 0.034357	 0.1531	 0.0026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80597	 17810	 0.018556	 0.072188	 0.0012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79521	 17811	 0.016442	 0.054855	 0.01391	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17811	 80930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17811	 80930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80926	 17812	 0.03848	 0.075415	 0.00113	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17812	 80931	 0.027654	 0.047647	 0.00076	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17813	 17815	 0.00544	 0.018661	 0.00447	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17813	 80931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17813	 80931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80931	 17814	 0.043519	 0.040086	 0.00064	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17814	 80932	 0.020706	 0.04058	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17815	 80932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17815	 80932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17815	 80940	 0.005698	 0.019857	 0.0046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17816	 17817	 0.000732	 0.006891	 0.00209	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17816	 17819	 0.00056	 0.005378	 0.00156	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17817	 17829	 0.00833	 0.020939	 0.00542	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17817	 80933	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17817	 80933	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17817	 80940	 0.000799	 0.007809	 0.00219	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80933	 17818	 0.036421	 0.028823	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17819	 17820	 0.000608	 0.005811	 0.00192	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17819	 80934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17819	 80934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17820	 17821	 0.001781	 0.015271	 0.00435	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17820	 80935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17820	 80935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79521	 17821	 0.00138	 0.011603	 0.00344	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17822	 80939	 0.00557	 0.017861	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17823	 17824	 0.005857	 0.016799	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17823	 17840	 0.004704	 0.013012	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17824	 80938	 0.006739	 0.022481	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17825	 17826	 0.007955	 0.020231	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17826	 17827	 0.01698	 0.048185	 0.00076	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17826	 17858	 0.031552	 0.06247	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17827	 80936	 0.013663	 0.045579	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17827	 80937	 0.012346	 0.027325	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17828	 17829	 0.001118	 0.014065	 0.00436	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79521	 17828	 0.001309	 0.017039	 0.00492	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17829	 17866	 0.008082	 0.05022	 0.01417	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79537	 17829	 0.007374	 0.052164	 0.01432	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17829	 80936	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17829	 80936	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17829	 80940	 0.001138	 0.012058	 0.00358	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17830	 17831	 0.001502	 0.005904	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17830	 80937	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17830	 80937	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17831	 80938	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17831	 80938	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17832	 80941	 0.045372	 0.030478	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17833	 80939	 0.009635	 0.018452	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17834	 17853	 0.003389	 0.021462	 0.00582	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17834	 80939	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17834	 80939	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17834	 80940	 0.002891	 0.013481	 0.00334	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17835	 17882	 0.000204	 0.00378	 0.24964	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17835	 80940	 0.000124	 0.009885	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80933	 17836	 0.005554	 0.030394	 0.00059	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80941	 17836	 0.010678	 0.032756	 0.00089	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17837	 17840	 0.017583	 0.017759	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17837	 17856	 0.017396	 0.013767	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17838	 17839	 0.025233	 0.019969	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17838	 17856	 0.018	 0.014245	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17838	 80943	 0.010423	 0.026795	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17840	 17854	 0.024889	 0.02711	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17840	 17861	 0.006832	 0.01398	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17841	 17842	 0.003705	 0.014414	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17841	 17847	 0.00671	 0.015889	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17842	 80943	 0.003804	 0.026113	 0.00048	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17843	 17848	 0.001563	 0.006256	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17843	 17850	 0.001065	 0.003873	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17843	 80942	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17843	 80942	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17844	 17850	 0.00127	 0.004826	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80940	 17844	 0.002049	 0.017569	 0.005	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17844	 80943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17844	 80943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17845	 17852	 0.002419	 0.008759	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17845	 80948	 0.002566	 0.010084	 0.00264	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17846	 17851	 0.003797	 0.012666	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17846	 17855	 0.026284	 0.020603	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17846	 80946	 0.005732	 0.022298	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80919	 17847	 0.010009	 0.019167	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17847	 80944	 0.010916	 0.019696	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17848	 17852	 0.003124	 0.00811	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17848	 80944	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17848	 80944	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80943	 17849	 0.023744	 0.018791	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17851	 80945	 0.012044	 0.022059	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17852	 80945	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17852	 80945	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17853	 80946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17853	 80946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17853	 80948	 0.003308	 0.011529	 0.00267	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17854	 17862	 0.026068	 0.01975	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80946	 17854	 0.021682	 0.021899	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80942	 17855	 0.007124	 0.013049	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17857	 17858	 0.033581	 0.026575	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17858	 17859	 0.061195	 0.048429	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17858	 80947	 0.020822	 0.019375	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17859	 17860	 0.00518	 0.009487	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17859	 17863	 0.047911	 0.036751	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17860	 17861	 0.003948	 0.010042	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17861	 17862	 0.011685	 0.008447	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17863	 80949	 0.030929	 0.034018	 0.00045	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80477	 17864	 0.005705	 0.014666	 0.00363	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17864	 80947	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17864	 80947	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17864	 80948	 0.003203	 0.008464	 0.00198	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80474	 17865	 0.000773	 0.005418	 0.00922	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	17865	 80948	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80949	 17865	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17866	 17931	 0.00263	 0.00886	 0.0022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79521	 17866	 0.012828	 0.081275	 0.02207	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80475	 17866	 0.002095	 0.008388	 0.00211	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80545	 17866	 0.018698	 0.062387	 0.01583	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80948	 17866	 0.006018	 0.015905	 0.00372	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17866	 80953	 0.002689	 0.009737	 0.00209	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17867	 17872	 0.001277	 0.005692	 0.00155	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17867	 17874	 0.001157	 0.005307	 0.00136	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17868	 17884	 0.001731	 0.005012	 0.00121	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17868	 17932	 0.002079	 0.005962	 0.00147	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17869	 17870	 0.000669	 0.004236	 0.00115	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17869	 80950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17869	 80950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17869	 80956	 0.000936	 0.006913	 0.002	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17870	 17880	 0.000723	 0.004493	 0.00127	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17870	 80951	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17870	 80951	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17871	 17872	 0.000769	 0.002784	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17871	 80952	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17871	 80952	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17871	 80956	 0.002892	 0.01194	 0.00283	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17872	 17884	 0.001161	 0.005328	 0.00136	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80952	 17873	 0.008673	 0.028933	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17874	 17892	 0.001285	 0.00505	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17875	 17882	 3.4e-05	 0.000437	 0.02791	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17875	 80953	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17876	 17877	 0.001914	 0.01163	 0.00021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80950	 17876	 0.017178	 0.036105	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80954	 17876	 0.002752	 0.01546	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17877	 17878	 0.006036	 0.027986	 0.00058	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17878	 80958	 0.005873	 0.028658	 0.00049	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17879	 17885	 0.004047	 0.010694	 0.0025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17879	 17889	 0.003069	 0.008888	 0.00214	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17880	 17889	 0.002088	 0.007162	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17880	 17895	 0.001517	 0.006648	 0.00229	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17880	 80955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17880	 80955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80955	 17881	 0.02121	 0.016626	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17882	 80956	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17882	 80956	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80950	 17883	 0.022461	 0.017776	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80956	 17884	 0.002683	 0.010742	 0.00271	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17884	 80957	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17884	 80957	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17885	 17891	 0.008985	 0.024122	 0.00547	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17885	 80958	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17885	 80958	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80543	 17886	 0.048065	 0.13786	 0.00212	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80958	 17886	 0.013248	 0.03137	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17887	 17888	 0.019582	 0.015497	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17888	 17890	 0.014186	 0.032934	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80958	 17888	 0.010915	 0.048639	 0.00083	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17890	 80962	 0.059947	 0.047442	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80545	 17891	 0.011801	 0.031682	 0.00718	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17892	 80959	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17892	 80959	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17893	 17904	 0.004766	 0.018335	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80959	 17893	 0.002477	 0.014083	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17893	 80961	 0.018946	 0.020636	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80959	 17894	 0.024342	 0.019264	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17894	 80960	 0.023551	 0.017327	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17895	 17897	 0.001485	 0.005644	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17895	 80960	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17895	 80960	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17896	 17904	 0.022495	 0.020296	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17896	 80964	 0.006896	 0.012822	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17897	 17898	 0.001097	 0.004393	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17898	 17903	 0.001171	 0.004687	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17898	 80961	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17898	 80961	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17899	 17900	 0.003891	 0.010283	 0.00241	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17899	 17921	 0.002814	 0.01191	 0.00268	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80475	 17899	 0.005695	 0.03358	 0.02735	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17899	 80962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17899	 80962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17900	 17901	 0.001459	 0.006952	 0.00201	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17900	 80963	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17900	 80963	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17901	 17903	 0.002103	 0.007213	 0.00173	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17901	 80964	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17901	 80964	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17901	 80966	 0.003965	 0.023617	 0.00621	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80962	 17902	 0.015746	 0.026299	 0.00045	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80963	 17902	 0.019518	 0.03288	 0.00047	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17902	 80965	 0.004039	 0.013798	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17903	 80965	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17903	 80965	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80962	 17904	 0.072283	 0.073009	 0.00097	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17905	 17906	 0.04016	 0.042788	 0.00061	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80964	 17905	 0.011186	 0.023509	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17906	 17913	 0.012369	 0.032698	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17906	 80967	 0.009092	 0.040511	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80476	 17907	 0.004368	 0.029795	 0.05367	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80927	 17907	 0.000981	 0.009493	 0.03357	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17907	 80966	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80967	 17907	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17908	 17915	 0.001985	 0.008079	 0.00197	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17908	 17928	 0.005634	 0.018982	 0.00472	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17908	 80968	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17908	 80968	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17909	 80969	 0.019472	 0.039849	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17910	 17911	 0.015073	 0.030846	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80963	 17910	 0.017997	 0.045769	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17911	 17913	 0.016944	 0.055915	 0.00091	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17911	 17925	 0.030991	 0.082142	 0.00208	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17912	 17913	 0.017016	 0.031639	 0.00074	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17912	 80972	 0.049157	 0.087804	 0.0013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17914	 17915	 0.001713	 0.006857	 0.00173	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80966	 17914	 0.001877	 0.00861	 0.00221	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17915	 80969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17915	 80969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17916	 17919	 0.002656	 0.008663	 0.0023	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17917	 17918	 0.00879	 0.017987	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17917	 80970	 0.012104	 0.034716	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17918	 17924	 0.029864	 0.045749	 0.00064	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80521	 17918	 0.11389	 0.090135	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17919	 17920	 0.001831	 0.007124	 0.0019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17919	 80970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17919	 80970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17920	 17921	 0.001843	 0.007243	 0.00189	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17922	 17923	 0.012551	 0.058196	 0.00121	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80963	 17922	 0.007653	 0.035991	 0.00067	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17923	 17924	 0.070891	 0.054379	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17923	 17925	 0.022999	 0.070554	 0.00191	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80522	 17925	 0.012367	 0.068101	 0.00154	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80761	 17925	 0.059535	 0.15739	 0.00286	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80966	 17926	 0.014816	 0.059326	 0.01495	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17926	 80971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17926	 80971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80968	 17927	 0.022898	 0.054223	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17927	 80972	 0.02236	 0.037141	 0.00079	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17928	 17929	 0.003366	 0.011548	 0.00277	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17929	 80972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17929	 80972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80928	 17930	 0.002241	 0.012849	 0.00427	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17930	 80973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17930	 80973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17931	 17932	 0.003489	 0.010596	 0.00232	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17933	 17934	 0.004808	 0.020351	 0.00458	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17933	 17936	 0.009733	 0.03897	 0.00982	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79556	 17935	 0.073524	 0.22583	 0.00424	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80591	 17935	 0.08349	 0.26891	 0.00458	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17935	 80974	 0.02352	 0.13371	 0.00242	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17935	 80975	 0.046981	 0.15505	 0.00251	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17936	 17937	 0.006203	 0.027928	 0.00743	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79633	 17936	 0.005963	 0.036663	 0.01057	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17937	 17938	 0.010397	 0.027913	 0.00633	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17937	 80974	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17937	 80974	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17938	 80975	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17938	 80975	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17939	 17941	 0.003951	 0.017788	 0.00473	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17940	 17941	 0.004053	 0.016735	 0.00396	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80303	 17942	 0.02549	 0.17296	 0.00323	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17942	 80978	 0.006914	 0.06694	 0.00134	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17943	 39795	 0.00292	 0.03416	 0.11967	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17943	 80976	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17943	 80976	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17943	 81452	 0.002917	 0.033107	 0.07272	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17944	 17945	 0.001663	 0.013359	 0.00375	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80976	 17944	 0.002212	 0.020591	 0.00638	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17944	 80977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17944	 80977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17945	 17946	 0.002308	 0.010586	 0.00271	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17945	 17947	 0.002906	 0.015486	 0.00435	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80976	 17945	 0.003845	 0.028959	 0.00804	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17945	 80978	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17945	 80978	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17946	 17947	 0.00111	 0.006285	 0.00156	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17946	 80979	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17946	 80979	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17947	 17952	 0.005116	 0.017238	 0.00428	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17947	 80980	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17947	 80980	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17947	 81463	 0.022604	 0.15952	 0.09101	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80353	 17948	 0.078639	 0.26238	 0.00416	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80979	 17948	 0.021064	 0.040339	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80980	 17948	 0.014269	 0.0476	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17949	 17950	 0.026187	 0.069409	 0.00176	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17949	 17951	 0.018423	 0.082095	 0.00139	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80304	 17949	 0.013777	 0.084704	 0.00153	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17950	 17951	 0.03075	 0.079048	 0.00122	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80354	 17950	 0.17852	 0.21767	 0.00349	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80980	 17951	 0.004305	 0.031467	 0.00058	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80977	 17953	 0.0185	 0.061714	 0.00098	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80979	 17953	 0.058344	 0.093131	 0.00215	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80306	 17954	 0.00358	 0.026163	 0.00048	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80308	 17954	 0.016087	 0.11758	 0.00217	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17955	 17956	 0.004928	 0.019732	 0.00497	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79542	 17955	 0.009247	 0.042424	 0.01087	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17955	 80981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17955	 80981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17956	 17960	 0.004066	 0.019732	 0.00451	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17956	 17972	 0.002327	 0.013369	 0.00379	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17957	 17960	 0.004836	 0.016921	 0.00561	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17957	 18006	 0.007463	 0.027025	 0.0058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17958	 80984	 0.03213	 0.051286	 0.00118	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17959	 17974	 0.00305	 0.015886	 0.00417	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17961	 17962	 0.015392	 0.059218	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80648	 17961	 0.042274	 0.082851	 0.00124	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17962	 80983	 0.006923	 0.042072	 0.00078	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17963	 80982	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80983	 17963	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17964	 17965	 0.01048	 0.028136	 0.00638	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17964	 17968	 0.007188	 0.018069	 0.00468	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80982	 17965	 0.010002	 0.032622	 0.00866	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17966	 17967	 0.005424	 0.014335	 0.00336	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17966	 17969	 0.005441	 0.019702	 0.00423	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17967	 17969	 0.005433	 0.019674	 0.00422	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17968	 17970	 0.012274	 0.031867	 0.00773	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79531	 17968	 0.002633	 0.010245	 0.00274	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79542	 17968	 0.003927	 0.011577	 0.00269	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79531	 17969	 0.005572	 0.033698	 0.0086	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79531	 17971	 0.001208	 0.009052	 0.00221	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79542	 17971	 0.002079	 0.008801	 0.00198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79542	 17972	 0.002376	 0.015937	 0.00385	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17973	 17978	 0.017316	 0.02892	 0.00049	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17973	 17979	 0.009976	 0.027633	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79543	 17973	 0.021177	 0.09278	 0.00199	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17974	 17975	 0.001117	 0.006126	 0.00162	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17974	 80984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17974	 80984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80982	 17975	 0.001745	 0.009576	 0.00253	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17975	 80985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17975	 80985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17976	 17979	 0.005503	 0.024246	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79543	 17976	 0.030367	 0.080488	 0.00204	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80983	 17976	 0.012031	 0.027931	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17977	 17980	 0.001764	 0.006148	 0.00143	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80982	 17977	 0.003492	 0.009375	 0.00212	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17978	 80986	 0.004571	 0.023259	 0.00053	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80983	 17979	 0.013759	 0.0459	 0.00073	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80984	 17979	 0.003732	 0.036566	 0.00072	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80985	 17979	 0.004561	 0.02307	 0.0004	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79542	 17980	 0.002854	 0.016716	 0.00455	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17980	 80986	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17980	 80986	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17981	 17982	 0.009206	 0.025674	 0.00539	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	17981	 80987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17981	 80987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17983	 17987	 0.00451	 0.02949	 0.0075	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17983	 80988	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17983	 80988	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17984	 17988	 0.009315	 0.035409	 0.00991	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17985	 17986	 0.006281	 0.02567	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80988	 17985	 0.01316	 0.05221	 0.00149	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17986	 17993	 0.021856	 0.028726	 0.00039	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	17986	 80989	 0.006577	 0.044625	 0.00083	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17987	 17989	 0.002845	 0.015121	 0.00351	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17987	 80989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17987	 80989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17988	 17989	 0.003328	 0.013541	 0.0033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	17988	 80990	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17988	 80990	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17989	 17991	 0.006583	 0.026357	 0.00664	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80304	 17990	 0.033743	 0.17776	 0.00319	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80990	 17990	 0.043514	 0.12481	 0.00192	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17991	 80991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17991	 80991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17992	 17993	 0.06248	 0.095715	 0.00134	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80988	 17993	 0.014574	 0.081891	 0.00152	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80991	 17993	 0.038104	 0.1698	 0.00288	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80987	 17994	 0.05711	 0.13062	 0.00319	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17995	 17996	 0.003311	 0.01288	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17995	 17999	 0.012708	 0.025161	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17995	 80992	 0.017046	 0.039575	 0.00059	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17996	 17997	 0.015029	 0.010646	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17996	 18003	 0.015145	 0.011986	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	17996	 80994	 0.009556	 0.048337	 0.00084	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	17998	 17999	 0.013265	 0.024665	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17998	 18011	 0.069703	 0.11742	 0.00167	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	17998	 80994	 0.013879	 0.067728	 0.00117	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	17999	 18000	 0.017364	 0.019098	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17999	 18001	 0.031342	 0.028084	 0.00057	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18000	 18001	 0.046133	 0.032678	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18001	 80992	 0.028839	 0.052035	 0.00075	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18002	 80992	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18002	 80992	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18002	 80993	 0.002528	 0.014808	 0.00403	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18004	 80993	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80994	 18004	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18005	 18013	 0.018048	 0.067706	 0.00122	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80994	 18005	 0.025877	 0.063341	 0.00108	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18006	 80995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18006	 80995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18007	 18008	 0.07466	 0.098128	 0.00134	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80818	 18007	 0.028552	 0.12653	 0.0038	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80995	 18007	 0.01463	 0.080564	 0.00182	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80992	 18008	 0.07313	 0.080436	 0.00107	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80482	 18009	 0.053194	 0.14063	 0.00255	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80992	 18009	 0.020398	 0.090895	 0.00154	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80760	 18010	 0.059196	 0.086261	 0.00195	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80992	 18010	 0.04048	 0.10406	 0.00161	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18012	 18013	 0.079768	 0.086886	 0.00118	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80627	 18012	 0.10589	 0.20968	 0.00308	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80981	 18013	 0.029042	 0.12796	 0.00222	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18014	 18015	 0.021177	 0.094365	 0.0016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80515	 18014	 0.041383	 0.081935	 0.0012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18015	 18016	 0.026528	 0.1032	 0.00172	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18016	 80996	 0.024333	 0.074649	 0.00202	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18017	 18018	 0.007161	 0.028671	 0.00722	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18017	 80996	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18017	 80996	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18018	 18019	 0.007538	 0.030178	 0.0076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18019	 18020	 0.005451	 0.021423	 0.0056	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18019	 80997	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18019	 80997	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18022	 18023	 0.043773	 0.086668	 0.00127	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18023	 18025	 0.030425	 0.093438	 0.00175	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80746	 18024	 0.044323	 0.18116	 0.00367	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80661	 18025	 0.077122	 0.21888	 0.00344	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18026	 18034	 0.096683	 0.098727	 0.00154	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18027	 18028	 0.007646	 0.031569	 0.00747	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18027	 80998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18027	 80998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18028	 18030	 0.0079	 0.030735	 0.00821	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79628	 18029	 0.078932	 0.26336	 0.00418	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18029	 80999	 0.013737	 0.068703	 0.00122	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18030	 18031	 0.007471	 0.025627	 0.00614	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18030	 80999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18030	 80999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18032	 18919	 0.003822	 0.037339	 0.01048	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18032	 81000	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18032	 81000	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18033	 18922	 0.049357	 0.33891	 0.00618	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81000	 18033	 0.01497	 0.08244	 0.00186	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80998	 18034	 0.032506	 0.080684	 0.00134	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18035	 18037	 0.10518	 0.13386	 0.00196	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18035	 81005	 0.05258	 0.13517	 0.00209	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18036	 18038	 0.003992	 0.012478	 0.00361	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18036	 81218	 0.007511	 0.020166	 0.00457	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18037	 81003	 0.082509	 0.065298	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18038	 18044	 0.004631	 0.018542	 0.00467	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18038	 81001	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18038	 81001	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18039	 18041	 5.3e-05	 0.001319	 0.10949	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18040	 19327	 0.010933	 0.074182	 0.00138	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18040	 81192	 0.011089	 0.085419	 0.00163	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18041	 18652	 0.000258	 0.003223	 0.22089	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18041	 19334	 2.6e-05	 0.000706	 0.05291	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18041	 81002	 0.001179	 0.061322	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18041	 81002	 0.001179	 0.061322	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18042	 18045	 0.057587	 0.04514	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81001	 18042	 0.03206	 0.057265	 0.00085	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18042	 81003	 0.00941	 0.021843	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18043	 81003	 0.043364	 0.031904	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18043	 81494	 0.018537	 0.024124	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18044	 19332	 0.001419	 0.004867	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18044	 81003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18044	 81003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18044	 81496	 0.003499	 0.012003	 0.00288	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18045	 18049	 0.032595	 0.075673	 0.00113	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81003	 18045	 0.009014	 0.017262	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18046	 19331	 0.021252	 0.013758	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18047	 19330	 0.018741	 0.01469	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18048	 81493	 0.015595	 0.011963	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18049	 81042	 0.12334	 0.40722	 0.0066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18050	 18140	 8.1e-05	 0.002009	 0.16621	 2893.0	 3037.6	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18050	 18651	 0.000303	 0.004493	 0.28902	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18050	 19334	 0.000157	 0.002599	 0.22788	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18050	 81004	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18051	 18052	 0.007276	 0.029131	 0.00734	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18051	 18914	 0.002067	 0.030387	 0.00929	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81004	 18051	 0.002444	 0.017862	 0.00527	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18052	 19324	 0.007588	 0.03133	 0.00741	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18053	 18055	 0.023015	 0.088545	 0.00151	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18053	 18055	 0.023015	 0.088545	 0.00151	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79592	 18053	 0.01376	 0.097999	 0.0022	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18053	 81330	 0.093122	 0.36241	 0.00605	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18054	 19329	 0.023906	 0.018919	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18055	 19327	 0.002828	 0.023528	 0.00045	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18055	 19329	 0.008758	 0.022513	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18056	 18914	 0.017588	 0.060344	 0.01446	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79591	 18056	 0.013539	 0.05147	 0.01441	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18056	 81058	 0.010914	 0.042461	 0.01134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18057	 18059	 0.006398	 0.026417	 0.00625	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79638	 18057	 0.001274	 0.019572	 0.00548	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18057	 81006	 0.000765	 0.00744	 0.0049	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18058	 18149	 0.001733	 0.023325	 0.04862	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18058	 81006	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18058	 81006	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18059	 81046	 0.011046	 0.071167	 0.01866	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18060	 18062	 0.018103	 0.12427	 0.00227	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18060	 81517	 0.009996	 0.062767	 0.00137	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79627	 18061	 0.14227	 0.11259	 0.00142	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18062	 81733	 0.03584	 0.17206	 0.00514	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18063	 18308	 0.025587	 0.067635	 0.01584	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18063	 18928	 0.010116	 0.058023	 0.01929	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18063	 81007	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18063	 81007	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18064	 18287	 0.007057	 0.035457	 0.00923	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18064	 18926	 0.008015	 0.040943	 0.0103	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18064	 81008	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18064	 81008	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18065	 18066	 0.011604	 0.049116	 0.01105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18065	 19322	 0.010027	 0.03901	 0.01042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18065	 81009	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18065	 81009	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18066	 18913	 0.008245	 0.06318	 0.01693	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18066	 81560	 0.006068	 0.058266	 0.01695	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18067	 19471	 0.013617	 0.067564	 0.00161	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81009	 18067	 0.025861	 0.1316	 0.00298	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18068	 18069	 0.034774	 0.038248	 0.00051	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18069	 81012	 0.031656	 0.03448	 0.00047	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18069	 81554	 0.02817	 0.074467	 0.00135	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18070	 81010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18070	 81010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18070	 81011	 0.001256	 0.010092	 0.00284	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18070	 81563	 0.000684	 0.005203	 0.00163	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18071	 19476	 0.000786	 0.005561	 0.00153	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18071	 81011	 0.000992	 0.007014	 0.00192	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18072	 18073	 0.000359	 0.003523	 0.01208	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18072	 19489	 0.000451	 0.004216	 0.01598	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18072	 81011	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81012	 18072	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18073	 18075	 0.000875	 0.013094	 0.03063	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18074	 18193	 0.00886	 0.038563	 0.01099	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18074	 81013	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18074	 81013	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18074	 81014	 0.002828	 0.028061	 0.00763	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18074	 81059	 0.004391	 0.067446	 0.01887	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18074	 81560	 0.014611	 0.060838	 0.01898	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18074	 81563	 0.009098	 0.058608	 0.01537	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18075	 18191	 0.00134	 0.015671	 0.05485	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18075	 81014	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18075	 81014	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18076	 18203	 0.044409	 0.25248	 0.00457	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18076	 18967	 0.02851	 0.17529	 0.00316	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81013	 18076	 0.044585	 0.10558	 0.00193	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18077	 81529	 0.00762	 0.014169	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18077	 81530	 0.027633	 0.021196	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18078	 18481	 0.006362	 0.020487	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18078	 81017	 0.020087	 0.0264	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18079	 18475	 0.016899	 0.017068	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18079	 81015	 0.008889	 0.020422	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18079	 81016	 0.005225	 0.020325	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18080	 18081	 0.00053	 0.003102	 0.00085	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18080	 81015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18080	 81015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18081	 18083	 0.00044	 0.003139	 0.00097	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18081	 81016	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18081	 81016	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18082	 81021	 0.001866	 0.009104	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18082	 81023	 0.002413	 0.01075	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18083	 18085	 0.000705	 0.00291	 0.00069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18083	 18089	 0.001032	 0.004886	 0.00117	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18083	 18091	 0.000685	 0.00214	 0.00062	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18083	 81017	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18083	 81017	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81017	 18084	 0.011434	 0.009049	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18085	 18086	 0.000497	 0.002105	 0.00047	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18085	 81018	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18085	 81018	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18086	 18087	 0.000655	 0.002548	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18087	 19408	 0.000693	 0.002724	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18088	 18431	 0.001706	 0.007519	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81018	 18088	 0.008844	 0.017333	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18088	 81019	 0.004087	 0.013633	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18089	 81019	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18089	 81019	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18089	 81137	 0.000961	 0.005523	 0.00156	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18090	 18091	 0.000424	 0.001613	 0.00045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18090	 18419	 0.00194	 0.012285	 0.00333	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18090	 81020	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18090	 81020	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18091	 81021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18091	 81021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18092	 18094	 0.001098	 0.004316	 0.00113	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18092	 18105	 0.000319	 0.001462	 0.00037	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18092	 81022	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18092	 81022	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18093	 18104	 0.012024	 0.009425	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81022	 18093	 0.002912	 0.004649	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18094	 18097	 0.001217	 0.004785	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18094	 81023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18094	 81023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18095	 81024	 0.009816	 0.007768	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18096	 81025	 0.007439	 0.005887	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79754	 18097	 0.001279	 0.006424	 0.00167	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18097	 81024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18097	 81024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18098	 18102	 0.000399	 0.001344	 0.00033	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18098	 81025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18098	 81025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18099	 18100	 0.005701	 0.004512	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81024	 18099	 0.000976	 0.003753	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81025	 18099	 0.001429	 0.006395	 0.00013	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81023	 18101	 0.008333	 0.008416	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18102	 81026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18102	 81026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18103	 18104	 0.001789	 0.00797	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18103	 18112	 0.002823	 0.007483	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81026	 18103	 0.001386	 0.009512	 0.00017	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81022	 18104	 0.0164	 0.010617	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18104	 81028	 0.001385	 0.00951	 0.00017	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18105	 18107	 0.000284	 0.001305	 0.00033	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18105	 81027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18105	 81027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18106	 18112	 0.01391	 0.018281	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81022	 18106	 0.00542	 0.005903	 8e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81027	 18106	 0.002389	 0.00614	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18107	 18109	 0.000933	 0.004602	 0.00124	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18107	 81028	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18107	 81028	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81019	 18108	 0.004165	 0.010549	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18108	 81138	 0.004575	 0.011761	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18109	 81029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18109	 81029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18109	 81137	 0.000447	 0.002246	 0.00058	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18110	 18111	 0.000891	 0.005414	 0.0001	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81028	 18110	 0.000863	 0.005921	 0.00011	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81029	 18111	 0.008353	 0.015071	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18111	 81032	 0.001227	 0.006138	 0.00011	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18112	 81030	 0.001676	 0.008185	 0.00017	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18113	 18115	 0.000716	 0.005392	 0.0015	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18113	 18123	 0.000415	 0.001903	 0.00049	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79798	 18113	 0.002077	 0.012464	 0.00377	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18113	 81030	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18113	 81030	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18114	 18116	 0.000261	 0.001326	 0.00048	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18114	 18123	 0.000353	 0.002495	 0.00068	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18114	 81031	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18114	 81031	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18115	 18117	 0.0006	 0.002401	 0.0006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18115	 18449	 0.001053	 0.006781	 0.00178	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18115	 81032	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18115	 81032	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18115	 81475	 0.001923	 0.012572	 0.0032	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18116	 18118	 0.000273	 0.001388	 0.0005	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18117	 18450	 0.000655	 0.002772	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18117	 81033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18117	 81033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18118	 18119	 0.000267	 0.001566	 0.00043	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18119	 19284	 0.000198	 0.001231	 0.00035	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18119	 81034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18119	 81034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81034	 18120	 0.003394	 0.008307	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18120	 81484	 0.003131	 0.010444	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18121	 19285	 0.000324	 0.002463	 0.00077	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18121	 19303	 0.000291	 0.001949	 0.0006	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81032	 18122	 0.004417	 0.016331	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18122	 81035	 0.002107	 0.009282	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18122	 81039	 0.010588	 0.008715	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18123	 18128	 0.00135	 0.005714	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18123	 81035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18123	 81035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81030	 18124	 0.001825	 0.007099	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81035	 18124	 0.002909	 0.008932	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18124	 81037	 0.002691	 0.011857	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81025	 18125	 0.005329	 0.013698	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81030	 18125	 0.004035	 0.012391	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18126	 18131	 0.000253	 0.00118	 0.00029	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79798	 18126	 0.001707	 0.012474	 0.00368	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18126	 81036	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18126	 81036	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18127	 81037	 0.006659	 0.006661	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18128	 81037	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18128	 81037	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79758	 18129	 0.004472	 0.014918	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81036	 18129	 0.00215	 0.005526	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18130	 18131	 0.000272	 0.001322	 0.0003	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18130	 18132	 0.00022	 0.001253	 0.00036	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18130	 81038	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18130	 81038	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18132	 18133	 0.000363	 0.002088	 0.00059	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18133	 19303	 0.00044	 0.003298	 0.0008	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18133	 81039	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18133	 81039	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79758	 18134	 0.019327	 0.015295	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81036	 18135	 0.004616	 0.008454	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18136	 18143	 0.000174	 0.00217	 0.14869	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18136	 81040	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18136	 81040	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18137	 19106	 0.005647	 0.040626	 0.01077	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18137	 81041	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18137	 81041	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18137	 81045	 0.004919	 0.039524	 0.01111	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18138	 18142	 0.004944	 0.022031	 0.00599	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18138	 81042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18138	 81042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18138	 81398	 0.004239	 0.044925	 0.01334	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18138	 81665	 0.004854	 0.043009	 0.01145	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18139	 81043	 0.003617	 0.032849	 0.0107	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18139	 81398	 0.003021	 0.028435	 0.00861	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18140	 18652	 0.000357	 0.006611	 0.43678	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18140	 19906	 2.7e-05	 0.000778	 0.0541	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18141	 19776	 4.2e-05	 0.001151	 0.08626	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18141	 19908	 3.8e-05	 0.001085	 0.07548	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18141	 81043	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18141	 81043	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18142	 81665	 0.003983	 0.020748	 0.00544	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18143	 19776	 0.000156	 0.002142	 0.16208	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18143	 81044	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81045	 18143	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18144	 18145	 0.001915	 0.017587	 0.0151	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18144	 18147	 0.00657	 0.02958	 0.00787	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18144	 81665	 0.000977	 0.016739	 0.00481	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18145	 19090	 0.003439	 0.037856	 0.0225	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18146	 18148	 0.007849	 0.023835	 0.00522	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18146	 81665	 0.01075	 0.027023	 0.007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18147	 18148	 0.004491	 0.020946	 0.00519	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18148	 18914	 0.006487	 0.031482	 0.0072	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79582	 18149	 0.000778	 0.012206	 0.04052	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18149	 81046	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18149	 81046	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18150	 19472	 0.033046	 0.064764	 0.00097	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18151	 18152	 0.002854	 0.010334	 0.00222	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18151	 81047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18151	 81047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18152	 18153	 0.001081	 0.012344	 0.00587	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18152	 18195	 0.000449	 0.006812	 0.00251	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18153	 81048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18153	 81048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18153	 81489	 0.002124	 0.023021	 0.01412	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18154	 18158	 0.005493	 0.031558	 0.00894	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18154	 18200	 0.005395	 0.033525	 0.00946	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18154	 81489	 0.009576	 0.040533	 0.00912	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18155	 18169	 0.010484	 0.050886	 0.01163	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18155	 19092	 0.010813	 0.043295	 0.01091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81048	 18156	 0.04882	 0.18994	 0.00317	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18156	 81052	 0.080265	 0.18442	 0.0028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18156	 81490	 0.011292	 0.054201	 0.00162	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18157	 18160	 0.00675	 0.041942	 0.01184	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18157	 18164	 0.00699	 0.034532	 0.01009	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18157	 81489	 0.001036	 0.007295	 0.00415	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18158	 18159	 0.002687	 0.024443	 0.00617	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18158	 18160	 0.008116	 0.024306	 0.00548	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79604	 18159	 0.000983	 0.010017	 0.00258	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18160	 18604	 0.003536	 0.025439	 0.00674	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18160	 81049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18160	 81049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81049	 18161	 0.036771	 0.090006	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18161	 81050	 0.020421	 0.07295	 0.00145	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18162	 18163	 0.002254	 0.011741	 0.00308	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18162	 19084	 0.005111	 0.021633	 0.00487	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18162	 19085	 0.005677	 0.019474	 0.00467	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18162	 81050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18162	 81050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18163	 18164	 0.003082	 0.015751	 0.00429	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18165	 18169	 0.009244	 0.035965	 0.00961	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18165	 19088	 0.011626	 0.045697	 0.01196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18166	 19259	 0.018294	 0.051018	 0.01071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18166	 20199	 0.016099	 0.056112	 0.01301	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18167	 20196	 0.006071	 0.037726	 0.01065	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18167	 81463	 0.00648	 0.037234	 0.01055	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18168	 18170	 0.001116	 0.015649	 0.03001	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18168	 81051	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18168	 81051	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18169	 81052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18169	 81052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18170	 81053	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18170	 81053	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18170	 81659	 0.002102	 0.020656	 0.07086	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18171	 19075	 0.005759	 0.028103	 0.00776	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81053	 18171	 0.005724	 0.028757	 0.00748	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18172	 18173	 0.003371	 0.021354	 0.0058	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18172	 18174	 0.004128	 0.017473	 0.00393	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81053	 18172	 0.005781	 0.023146	 0.00583	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18173	 19074	 0.002014	 0.015171	 0.00421	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18174	 19088	 0.004805	 0.016985	 0.00383	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18174	 81054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18174	 81054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18175	 19087	 0.033019	 0.08488	 0.00131	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81052	 18175	 0.074539	 0.24602	 0.00399	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81054	 18175	 0.012514	 0.029048	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18176	 18177	 0.005162	 0.031737	 0.00915	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18176	 18313	 0.008699	 0.053988	 0.01308	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18177	 18178	 0.000914	 0.01012	 0.00329	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18177	 18179	 0.001505	 0.018285	 0.00493	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18177	 18653	 0.004676	 0.043533	 0.01349	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18178	 18179	 0.00069	 0.007449	 0.00255	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18179	 18180	 0.0083	 0.033776	 0.00823	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18179	 81319	 0.006921	 0.065158	 0.01974	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18181	 18182	 0.008793	 0.023606	 0.00535	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18181	 81055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18181	 81055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18182	 20213	 0.028857	 0.076283	 0.01786	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18182	 81056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18182	 81056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18183	 18309	 0.01955	 0.077563	 0.00222	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81056	 18183	 0.030212	 0.17175	 0.00311	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18184	 18186	 0.020975	 0.088773	 0.00167	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81055	 18184	 0.046488	 0.092044	 0.00135	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18185	 19220	 0.011844	 0.030749	 0.00746	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18185	 20146	 0.007936	 0.027224	 0.00652	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18185	 81057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18185	 81057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18186	 18187	 0.095338	 0.13535	 0.00223	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79635	 18186	 0.004368	 0.019355	 0.00058	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81055	 18186	 0.065133	 0.18683	 0.00287	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18186	 81399	 0.051962	 0.14746	 0.00232	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18188	 18191	 0.001426	 0.013808	 0.04884	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18188	 81058	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18188	 81058	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18189	 81096	 0.008353	 0.042668	 0.01073	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18190	 18308	 0.006654	 0.027078	 0.0066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18190	 81059	 0.007319	 0.041608	 0.01204	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18191	 81059	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18191	 81059	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81013	 18192	 0.052203	 0.13837	 0.00351	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18192	 81060	 0.02714	 0.10558	 0.00176	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18192	 81564	 0.01587	 0.069925	 0.00121	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18193	 18202	 0.005825	 0.037525	 0.00984	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18193	 81060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18193	 81060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18194	 18199	 0.002096	 0.02348	 0.00746	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18194	 81560	 0.001045	 0.009983	 0.00366	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18195	 18196	 0.002476	 0.005966	 0.00168	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18195	 19486	 0.001026	 0.007602	 0.00389	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18196	 81061	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18196	 81061	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18197	 18198	 0.015623	 0.053369	 0.00116	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81061	 18197	 0.008523	 0.033158	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81048	 18198	 0.027072	 0.12064	 0.00205	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18199	 18200	 0.002338	 0.028818	 0.00931	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18200	 18201	 0.001461	 0.009554	 0.00243	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79624	 18203	 0.078328	 0.3048	 0.00509	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18203	 81069	 0.027204	 0.15309	 0.00331	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18204	 18207	 0.007608	 0.033115	 0.00943	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18205	 18207	 0.002854	 0.022926	 0.00644	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18205	 18210	 0.002793	 0.022438	 0.00631	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18205	 81062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18205	 81062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81062	 18206	 0.21272	 0.16837	 0.00212	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79594	 18207	 0.011896	 0.043078	 0.00924	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18208	 19163	 0.048646	 0.12506	 0.00194	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79595	 18208	 0.016111	 0.03297	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18209	 18665	 0.000655	 0.008729	 0.03129	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79593	 18209	 0.000545	 0.006277	 0.02266	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79607	 18210	 0.002422	 0.017586	 0.00608	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18211	 19063	 0.018302	 0.048373	 0.01132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18211	 81063	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18211	 81063	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18212	 18214	 0.006087	 0.025765	 0.0058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18212	 19065	 0.015088	 0.095605	 0.02596	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18212	 81064	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18212	 81064	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18212	 81535	 0.006062	 0.040667	 0.00982	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18213	 19418	 0.040815	 0.10492	 0.00162	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81064	 18213	 0.035107	 0.10567	 0.00207	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18214	 18216	 0.005181	 0.019693	 0.00551	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18214	 81535	 0.003189	 0.02735	 0.00778	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18215	 18217	 0.091813	 0.16567	 0.0024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18215	 18599	 0.035951	 0.18188	 0.00316	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81064	 18215	 0.036069	 0.16726	 0.00347	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18218	 18219	 7.6e-05	 0.001095	 0.07564	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18218	 18232	 0.000148	 0.002124	 0.14672	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18218	 81065	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18218	 81065	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18219	 18220	 0.000162	 0.001933	 0.14499	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18219	 81066	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18219	 81066	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18220	 18785	 0.000141	 0.002606	 0.17208	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18220	 81067	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18220	 81067	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18221	 18969	 0.000669	 0.010841	 0.04205	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18221	 81068	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18221	 81068	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79584	 18222	 0.003151	 0.033148	 0.01862	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81068	 18222	 0.002073	 0.033356	 0.0109	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18222	 81069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18222	 81069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18223	 18656	 0.1649	 0.16541	 0.00267	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18223	 18889	 0.25426	 0.19934	 0.00256	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79585	 18223	 0.13278	 0.10509	 0.00132	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18224	 18225	 0.006212	 0.015967	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18224	 18264	 0.006018	 0.023412	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18224	 18265	 0.00519	 0.020189	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18225	 19740	 0.004071	 0.015838	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18226	 19737	 0.003728	 0.017285	 0.00036	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18226	 81078	 0.004703	 0.026427	 0.00049	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18227	 18229	 0.006755	 0.020722	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18227	 81078	 0.003926	 0.021006	 0.00064	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18228	 18266	 0.031531	 0.024953	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18229	 18230	 0.012873	 0.020986	 0.00032	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18229	 18266	 0.01393	 0.035809	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18229	 18273	 0.003679	 0.016394	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18229	 81080	 0.012474	 0.070909	 0.00128	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18230	 19736	 0.017798	 0.017977	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18231	 18233	 0.001609	 0.007383	 0.00189	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18231	 81070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18231	 81070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18232	 81071	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18232	 81071	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18233	 18236	 0.001324	 0.008389	 0.00228	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18233	 18251	 0.002219	 0.008033	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18233	 81072	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18233	 81072	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18234	 18252	 0.036225	 0.028395	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81070	 18234	 0.014544	 0.015841	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81072	 18234	 0.028041	 0.02198	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18235	 18252	 0.021796	 0.014111	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81072	 18235	 0.017374	 0.012307	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79609	 18236	 0.001537	 0.012271	 0.00302	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18236	 81073	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18236	 81073	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81073	 18237	 0.015045	 0.026458	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18238	 81074	 0.030202	 0.023901	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18239	 18240	 0.002143	 0.008579	 0.00216	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18239	 18262	 0.005252	 0.013636	 0.00331	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79609	 18239	 0.004693	 0.016355	 0.00379	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18239	 81074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18239	 81074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18240	 81075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18240	 81075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18240	 81076	 0.002382	 0.009833	 0.00233	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81075	 18241	 0.01069	 0.026534	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18241	 81081	 0.038876	 0.058962	 0.00085	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18242	 19378	 0.00426	 0.028905	 0.00054	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81075	 18242	 0.003883	 0.020933	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18243	 19376	 0.000499	 0.004132	 0.01303	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79608	 18243	 0.000398	 0.006477	 0.01279	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18243	 81076	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18243	 81076	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18244	 19465	 0.000861	 0.00733	 0.00183	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81071	 18244	 0.001622	 0.012777	 0.00374	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18245	 19379	 0.001071	 0.002831	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18245	 19630	 0.002032	 0.005371	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18246	 18247	 0.047721	 0.037406	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18246	 81516	 0.007666	 0.018154	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18248	 81081	 0.041219	 0.080783	 0.00121	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18249	 18251	 0.001971	 0.005117	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18249	 81077	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18249	 81077	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18250	 18251	 0.001787	 0.004865	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18250	 18259	 0.002354	 0.00632	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18252	 81080	 0.058473	 0.054834	 0.00085	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18253	 18283	 0.025885	 0.021305	 0.00043	 49.0	 49.0	 49.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18253	 81080	 0.02138	 0.045817	 0.0008	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18254	 18255	 0.033091	 0.023921	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18255	 18256	 0.01305	 0.017789	 0.00039	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18256	 18257	 0.021531	 0.022993	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81073	 18256	 0.018144	 0.033232	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18257	 18263	 0.009078	 0.030282	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18257	 81080	 0.026068	 0.032358	 0.00071	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18258	 81078	 0.012254	 0.025076	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18258	 81080	 0.009377	 0.021445	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18259	 81078	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18259	 81078	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18259	 81079	 0.0019	 0.007732	 0.00188	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18260	 18962	 0.005241	 0.035376	 0.06517	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79608	 18260	 0.001089	 0.008318	 0.03091	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18260	 81079	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81080	 18260	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18261	 18291	 0.10054	 0.079568	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18261	 81081	 0.042763	 0.084668	 0.00124	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18262	 81081	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18262	 81081	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81074	 18263	 0.007832	 0.039169	 0.0007	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18264	 18271	 0.02212	 0.022341	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18264	 81646	 0.002576	 0.017476	 0.00033	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18265	 18273	 0.00593	 0.022812	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18265	 81084	 0.009641	 0.02215	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18266	 18281	 0.037303	 0.02415	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18267	 81082	 0.022464	 0.034407	 0.0006	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18268	 18274	 0.036678	 0.054387	 0.00082	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18268	 18285	 0.005717	 0.014696	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18268	 81083	 0.011289	 0.027633	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18268	 81086	 0.00323	 0.019629	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18269	 18288	 0.003914	 0.015385	 0.00402	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81079	 18269	 0.006914	 0.02255	 0.00599	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18269	 81082	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18269	 81082	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18270	 18272	 0.001281	 0.006216	 0.00142	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18270	 19731	 0.002041	 0.011557	 0.00286	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18270	 81083	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18270	 81083	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81083	 18271	 0.008594	 0.017016	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18272	 81084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18272	 81084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18274	 81347	 0.1098	 0.086894	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18275	 18284	 0.012837	 0.026269	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81083	 18275	 0.015811	 0.0367	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18275	 81233	 0.006735	 0.035883	 0.00063	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18276	 18277	 0.006061	 0.023671	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18276	 81088	 0.020096	 0.059096	 0.00121	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18276	 81348	 0.15833	 0.12146	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18277	 81085	 0.007503	 0.033432	 0.00057	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18278	 18279	 0.001121	 0.004362	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18278	 81085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18278	 81085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18279	 81086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18279	 81086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81084	 18280	 0.010836	 0.027855	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81086	 18280	 0.004947	 0.019246	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18282	 18283	 0.027751	 0.017966	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18283	 18293	 0.016932	 0.043526	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81082	 18283	 0.029062	 0.031965	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18284	 18285	 0.009735	 0.023828	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18286	 81088	 0.052913	 0.1037	 0.00155	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18286	 81348	 0.082359	 0.083187	 0.0011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18287	 18290	 0.003625	 0.016905	 0.00419	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18287	 81087	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18287	 81087	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18288	 18289	 0.001659	 0.006641	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18288	 81088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18288	 81088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18289	 18290	 0.001631	 0.006526	 0.0022	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18291	 18294	 0.007501	 0.036191	 0.00064	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81087	 18291	 0.012538	 0.086064	 0.00157	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18292	 18293	 0.011498	 0.021731	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81088	 18292	 0.021879	 0.033183	 0.00048	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18293	 18294	 0.0051	 0.018678	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18295	 18296	 0.004221	 0.025936	 0.00948	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18295	 18297	 0.006837	 0.031368	 0.00804	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18295	 81089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18295	 81089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18295	 81708	 0.020573	 0.067115	 0.01782	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18296	 19224	 0.009314	 0.037291	 0.0094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18296	 81204	 0.004301	 0.026728	 0.00754	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18297	 18824	 0.006719	 0.031339	 0.00776	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18298	 19071	 0.01038	 0.041562	 0.01047	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18298	 19382	 0.020411	 0.093673	 0.02401	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18298	 20238	 0.006376	 0.051231	 0.0144	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18299	 81091	 0.030458	 0.078298	 0.00121	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18299	 81189	 0.094533	 0.31205	 0.00506	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18300	 18596	 0.008469	 0.026471	 0.00767	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18300	 81092	 0.01014	 0.034786	 0.00833	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18301	 18303	 0.000828	 0.00637	 0.01136	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18301	 81090	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81091	 18301	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18302	 19068	 0.009097	 0.035758	 0.00935	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81090	 18302	 0.00761	 0.019129	 0.00496	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18302	 81092	 0.012919	 0.032477	 0.00841	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18303	 81092	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18303	 81092	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18304	 18306	 0.000562	 0.008354	 0.03096	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79596	 18304	 0.000873	 0.006897	 0.02394	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79599	 18304	 0.001029	 0.010134	 0.0216	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18304	 81093	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18304	 81093	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18305	 18933	 0.000115	 0.001918	 0.18945	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18305	 81094	 0.000101	 0.00811	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81095	 18305	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81094	 18306	 0.000349	 0.005431	 0.02282	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18307	 18964	 0.000883	 0.010244	 0.03641	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18307	 18968	 0.002216	 0.021455	 0.07591	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18307	 81096	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18307	 81096	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81096	 18308	 0.002502	 0.038232	 0.01232	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18308	 81353	 0.002213	 0.037924	 0.0109	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18309	 18312	 0.042916	 0.16697	 0.00279	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18310	 18311	 0.13713	 0.10853	 0.00137	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18311	 18312	 0.061498	 0.14278	 0.00212	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18311	 19248	 0.038138	 0.10109	 0.00256	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79589	 18312	 0.027188	 0.15278	 0.00283	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18312	 81400	 0.060631	 0.13867	 0.00339	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18313	 18318	 0.00758	 0.038084	 0.00991	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18314	 18315	 0.049425	 0.12268	 0.00204	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18315	 18316	 0.01625	 0.031846	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18315	 81097	 0.009627	 0.051291	 0.0009	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18316	 81610	 0.015641	 0.030968	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18317	 18318	 0.005642	 0.028346	 0.00738	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18317	 19639	 0.006147	 0.02461	 0.0062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18317	 81097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18317	 81097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18318	 19207	 0.012493	 0.055675	 0.01513	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18318	 81514	 0.013915	 0.062664	 0.01668	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18319	 18794	 0.009479	 0.061989	 0.01577	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18319	 19246	 0.006824	 0.043225	 0.01173	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18320	 18786	 0.009722	 0.036955	 0.01034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18320	 19069	 0.007604	 0.029887	 0.00782	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18320	 81098	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18320	 81098	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81098	 18321	 0.055089	 0.1279	 0.0019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18321	 81277	 0.027281	 0.13313	 0.0023	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18321	 81388	 0.048445	 0.16162	 0.00256	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18322	 18345	 0.00074	 0.003396	 0.00087	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18322	 18355	 0.001038	 0.004675	 0.00124	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18323	 19316	 0.004701	 0.018287	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18323	 81108	 0.005414	 0.023989	 0.00072	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18324	 18325	 0.018867	 0.014931	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18324	 18326	 0.024282	 0.019216	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18325	 18326	 0.005229	 0.008347	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18325	 81108	 0.002576	 0.014644	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18325	 81109	 0.003884	 0.012958	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18326	 18328	 0.025021	 0.016199	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18326	 81099	 0.003543	 0.013099	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18326	 81109	 0.009421	 0.017255	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18327	 18330	 0.001127	 0.004385	 0.00117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18327	 18357	 0.0016	 0.006405	 0.00161	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18327	 81099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18327	 81099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18329	 18330	 0.000917	 0.003883	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80152	 18329	 0.002041	 0.007423	 0.00227	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18330	 81100	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18330	 81100	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81100	 18331	 0.003785	 0.016678	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18331	 81101	 0.002904	 0.01469	 0.00026	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18332	 18358	 0.00066	 0.002972	 0.00079	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18332	 18360	 0.00098	 0.005007	 0.00126	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18332	 81101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18332	 81101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81101	 18333	 0.008577	 0.015948	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18333	 81112	 0.007261	 0.018466	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18334	 18335	 0.009467	 0.042185	 0.00072	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18334	 18361	 0.008473	 0.041349	 0.00071	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18334	 81113	 0.012507	 0.025594	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18335	 18977	 0.008251	 0.041985	 0.00095	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79960	 18335	 0.016785	 0.074794	 0.00127	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18336	 18349	 0.000984	 0.006339	 0.00166	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18336	 18447	 0.001181	 0.004131	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18336	 81102	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18336	 81102	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18337	 18338	 0.002384	 0.009173	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81102	 18337	 0.002294	 0.012634	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18338	 18339	 0.002917	 0.009626	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18339	 81115	 0.019056	 0.012337	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18340	 18346	 0.000751	 0.003006	 0.00076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18340	 19296	 0.000499	 0.0031	 0.00087	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18340	 81103	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18340	 81103	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18341	 18343	 0.000288	 0.001153	 0.00029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18341	 19298	 0.000431	 0.001639	 0.00046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18342	 81104	 0.004102	 0.003246	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18343	 18344	 0.000331	 0.001324	 0.00033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18343	 81104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18343	 81104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18344	 18345	 0.000438	 0.001755	 0.00044	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18346	 18367	 0.001335	 0.005193	 0.00139	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18346	 81105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18346	 81105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81103	 18347	 0.023799	 0.02034	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81105	 18347	 0.002678	 0.008215	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18347	 81108	 0.00563	 0.014472	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18348	 18351	 0.003449	 0.015368	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18348	 18369	 0.004294	 0.011879	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18348	 81106	 0.006523	 0.016769	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18349	 81106	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18349	 81106	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18349	 81123	 0.000506	 0.003984	 0.00117	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18350	 18368	 0.000821	 0.008133	 0.00249	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18350	 81107	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18350	 81107	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18350	 81131	 0.000598	 0.005707	 0.00231	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81107	 18351	 0.002175	 0.014927	 0.00027	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18352	 18361	 0.006904	 0.018251	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81107	 18352	 0.006077	 0.013961	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18353	 18359	 0.015607	 0.020512	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18353	 18370	 0.018177	 0.015535	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18354	 18370	 0.007078	 0.02361	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18354	 81109	 0.008124	 0.02066	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18355	 18356	 0.000839	 0.005156	 0.00149	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18355	 81108	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18355	 81108	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18356	 81109	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18356	 81109	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18356	 81131	 0.001541	 0.022655	 0.00693	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18357	 18358	 0.000537	 0.002419	 0.00064	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18357	 81110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18357	 81110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18358	 81111	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18358	 81111	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81101	 18359	 0.01046	 0.0205	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81111	 18359	 0.006974	 0.007448	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18360	 18362	 0.002264	 0.01519	 0.00367	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18360	 81112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18360	 81112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81112	 18361	 0.007642	 0.025493	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18362	 18363	 0.001271	 0.004832	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18362	 18364	 0.001596	 0.008787	 0.00317	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18362	 81131	 0.001159	 0.004639	 0.00117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18363	 18364	 0.001044	 0.005825	 0.00149	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18363	 81131	 0.002013	 0.008521	 0.00192	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18364	 18978	 0.001307	 0.009658	 0.00279	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18364	 81113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18364	 81113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18365	 18575	 0.000998	 0.003995	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18365	 81114	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18365	 81114	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18366	 18978	 0.000903	 0.007594	 0.00225	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18367	 18368	 0.000381	 0.003658	 0.00106	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18367	 19290	 0.001625	 0.006504	 0.00164	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18367	 81115	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18367	 81115	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18368	 81116	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18368	 81116	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18369	 18370	 0.003275	 0.008419	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81116	 18370	 0.011218	 0.01198	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81115	 18371	 0.018101	 0.013318	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18372	 18374	 0.001376	 0.004865	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18372	 18394	 0.001204	 0.00482	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18372	 18542	 0.004264	 0.014627	 0.0035	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18373	 18396	 0.019632	 0.013187	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18373	 81117	 0.011769	 0.008659	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18374	 18391	 0.001564	 0.004611	 0.00107	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18374	 81117	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18374	 81117	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18375	 18393	 0.01853	 0.028087	 0.00058	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18375	 18410	 0.007446	 0.017287	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18375	 18411	 0.007194	 0.023997	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81117	 18375	 0.006015	 0.011184	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18375	 81125	 0.005864	 0.018884	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81117	 18376	 0.017472	 0.013827	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18377	 18385	 0.002454	 0.009545	 0.00255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18377	 81118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18377	 81118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18378	 18380	 0.000561	 0.003078	 0.00081	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18378	 18444	 0.000547	 0.003004	 0.00079	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18379	 18445	 0.001141	 0.006626	 0.00156	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18379	 81119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18379	 81119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18379	 81123	 0.000636	 0.005551	 0.00152	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18380	 81123	 0.000909	 0.00482	 0.00161	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18381	 18382	 0.007455	 0.008199	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18381	 81120	 0.002461	 0.01689	 0.00031	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18381	 81124	 0.012266	 0.031531	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18383	 18386	 0.001135	 0.003	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18383	 81120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18383	 81120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18384	 18393	 0.004378	 0.010164	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81120	 18384	 0.010837	 0.013452	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18384	 81121	 0.009637	 0.015797	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18385	 18386	 0.001349	 0.003621	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18385	 81128	 0.001448	 0.004968	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18386	 18400	 0.001373	 0.004628	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18386	 81121	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18386	 81121	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18387	 18401	 0.001074	 0.003796	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18387	 81122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18387	 81122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18388	 18389	 0.002529	 0.009688	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81122	 18388	 0.001578	 0.010708	 0.0002	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18389	 81124	 0.005168	 0.020104	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18390	 18398	 0.000708	 0.007339	 0.01581	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18390	 81123	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81124	 18390	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18390	 81130	 0.000294	 0.003175	 0.0063	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18390	 81130	 0.000294	 0.003175	 0.0063	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18390	 81478	 0.000313	 0.004655	 0.01725	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18391	 18392	 0.000651	 0.002901	 0.00079	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18391	 18397	 0.000541	 0.002578	 0.00075	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18391	 81125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18391	 81125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18392	 18413	 0.000822	 0.003834	 0.00095	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18394	 18395	 0.00096	 0.002752	 0.00068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18394	 18569	 0.003001	 0.007932	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18394	 81126	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18394	 81126	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18395	 81128	 0.001453	 0.00526	 0.00113	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81126	 18396	 0.017819	 0.019598	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18396	 81127	 0.013289	 0.012462	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18397	 81127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18397	 81127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18397	 81128	 0.000718	 0.003724	 0.00091	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18398	 18570	 0.00035	 0.003734	 0.00759	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18398	 18570	 0.00035	 0.003734	 0.00759	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18398	 81128	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81129	 18398	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18399	 18400	 0.000976	 0.002878	 0.00067	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81128	 18399	 0.001566	 0.004615	 0.00107	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18400	 18401	 0.000843	 0.003868	 0.00099	 214.0	 214.0	 214.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18401	 18572	 0.001307	 0.005231	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18401	 18574	 0.001658	 0.005686	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18402	 18403	 0.017555	 0.011365	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18402	 18404	 0.013455	 0.02664	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18402	 81188	 0.003138	 0.012207	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18404	 81132	 0.019357	 0.015173	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18405	 18982	 7.2e-05	 0.002066	 0.14376	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18405	 19292	 5.2e-05	 0.001445	 0.1083	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18405	 19403	 0.000178	 0.002224	 0.15242	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18405	 81130	 9.9e-05	 0.007891	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18405	 81130	 9.9e-05	 0.007891	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18406	 18408	 0.00072	 0.004138	 0.00117	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18406	 81527	 0.000837	 0.005023	 0.00152	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18407	 18408	 0.000569	 0.003904	 0.00114	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18407	 18417	 0.001208	 0.008105	 0.00196	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18407	 18468	 0.000845	 0.003438	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18408	 18409	 0.000906	 0.003561	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18408	 18421	 0.001445	 0.006437	 0.00175	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18408	 81527	 0.001505	 0.009353	 0.00264	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18409	 18415	 0.001236	 0.005102	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18409	 18423	 0.000862	 0.00351	 0.00086	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18410	 81528	 0.00768	 0.022583	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18411	 19404	 0.005403	 0.0193	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18411	 19405	 0.007098	 0.011957	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18411	 81528	 0.004948	 0.028127	 0.00051	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18412	 18563	 0.038049	 0.029825	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18412	 19404	 0.012169	 0.011954	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18413	 18414	 0.000599	 0.002906	 0.00066	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18414	 18415	 0.00054	 0.002053	 0.00057	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18415	 81133	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18415	 81133	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18416	 18417	 0.001075	 0.00336	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18416	 18468	 0.001312	 0.005251	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18416	 18490	 0.000631	 0.002482	 0.00065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18417	 18418	 0.000588	 0.003613	 0.00104	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18417	 18420	 0.000767	 0.002914	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18417	 18422	 0.000629	 0.00256	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18418	 18419	 0.000867	 0.003471	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18418	 19408	 0.000468	 0.003016	 0.00079	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18419	 18420	 0.000635	 0.002543	 0.00064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18419	 18438	 0.002131	 0.00867	 0.00211	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18421	 18422	 0.000646	 0.002965	 0.00076	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18421	 81134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18421	 81134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18422	 81135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18422	 81135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18423	 18424	 0.0007	 0.002801	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18424	 81136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18424	 81136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18425	 18427	 0.00268	 0.010426	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81136	 18425	 0.00175	 0.008852	 0.00015	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18426	 18427	 0.01193	 0.00982	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81135	 18426	 0.022853	 0.018086	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18427	 81139	 0.002536	 0.009716	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18428	 18429	 0.001669	 0.009485	 0.00017	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18428	 18437	 0.002812	 0.015825	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18429	 18430	 0.002845	 0.012677	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18430	 18432	 0.0039	 0.010108	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18431	 18432	 0.006594	 0.008666	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18431	 81530	 0.004945	 0.01454	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18432	 81138	 0.012157	 0.019818	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79797	 18433	 0.000647	 0.006052	 0.02293	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80121	 18433	 0.001142	 0.011657	 0.03702	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18433	 81137	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81138	 18433	 0.000318	 0.023855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18433	 81478	 0.000437	 0.004912	 0.00899	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18433	 81478	 0.000437	 0.004912	 0.00899	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18434	 18435	 0.007759	 0.008534	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81138	 18434	 0.004378	 0.011135	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18436	 18437	 0.018373	 0.014401	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18436	 81471	 0.009268	 0.013138	 0.00027	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18437	 81139	 0.005565	 0.018565	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18437	 81480	 0.005941	 0.028662	 0.00051	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18438	 18439	 0.000618	 0.003391	 0.0009	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18438	 81139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18438	 81139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18439	 18440	 0.000989	 0.003888	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18439	 18445	 0.00109	 0.004364	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18440	 18444	 0.000798	 0.00366	 0.00094	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18441	 18442	 0.006538	 0.010013	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18441	 18443	 0.004519	 0.00725	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81119	 18441	 0.017055	 0.043374	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81136	 18442	 0.005269	 0.013545	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18444	 81140	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18444	 81140	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18445	 81141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18445	 81141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18446	 81481	 0.008804	 0.013485	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18447	 81479	 0.001361	 0.005449	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18448	 81142	 0.004029	 0.007614	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18449	 19279	 0.00039	 0.001972	 0.00055	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18449	 81142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18449	 81142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18450	 19283	 0.000287	 0.001147	 0.00039	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18451	 18495	 0.008766	 0.022534	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18451	 81143	 0.004622	 0.024627	 0.00043	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18452	 18463	 0.001474	 0.008089	 0.00214	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18452	 18532	 0.002154	 0.006699	 0.0014	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18452	 81143	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18452	 81143	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81143	 18453	 0.002456	 0.013192	 0.00031	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18453	 81145	 0.002039	 0.012528	 0.00029	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18454	 18461	 0.000624	 0.003587	 0.00102	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18454	 18493	 0.001593	 0.006743	 0.00152	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18455	 18456	 0.000868	 0.003473	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18455	 18493	 0.001162	 0.004653	 0.00117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18456	 18468	 0.001005	 0.005326	 0.00178	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18456	 18487	 0.001204	 0.004016	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18457	 18458	 0.005164	 0.017227	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18457	 81149	 0.006791	 0.012253	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18458	 81148	 0.002764	 0.009678	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18459	 18460	 0.000963	 0.004078	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18459	 18469	 0.001755	 0.007428	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18459	 81144	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18459	 81144	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18460	 18461	 0.000869	 0.003588	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18461	 81145	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18461	 81145	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81144	 18462	 0.012255	 0.013087	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81145	 18462	 0.005618	 0.018741	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18462	 81146	 0.00582	 0.015083	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18463	 18466	 0.001358	 0.005749	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18463	 81146	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18463	 81146	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18464	 18471	 0.003151	 0.016863	 0.00051	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18464	 18519	 0.010631	 0.020835	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81146	 18464	 0.006605	 0.022032	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18464	 81163	 0.042527	 0.046321	 0.00063	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18465	 19401	 0.001766	 0.00474	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18465	 81147	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18465	 81147	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18466	 18472	 0.000842	 0.00337	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18467	 18469	 0.000933	 0.002466	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18467	 81148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18467	 81148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18468	 81149	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18468	 81149	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18468	 81527	 0.001761	 0.01349	 0.00361	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18469	 18490	 0.001577	 0.009986	 0.00271	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18469	 81527	 0.000568	 0.006996	 0.00226	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18470	 18471	 0.020597	 0.015154	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18470	 81150	 0.010435	 0.008259	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18471	 18473	 0.00124	 0.006272	 0.00011	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18472	 19402	 0.0009	 0.0035	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18472	 81150	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18472	 81150	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18473	 81525	 0.009471	 0.014365	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18473	 81526	 0.002218	 0.00983	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18474	 18477	 0.001361	 0.005294	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18474	 18579	 0.000639	 0.002601	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18475	 18476	 0.009978	 0.017934	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18476	 81151	 0.005429	 0.019882	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18477	 18478	 0.00091	 0.003577	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18477	 81151	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18477	 81151	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18478	 18485	 0.000913	 0.003656	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18479	 18480	 0.002872	 0.010054	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18479	 18481	 0.003392	 0.012998	 0.00037	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80126	 18479	 0.015767	 0.048421	 0.00091	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18480	 81152	 0.003874	 0.013563	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18481	 81529	 0.004247	 0.020726	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18482	 18483	 0.011527	 0.017482	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18482	 81529	 0.007135	 0.014995	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18483	 18486	 0.002696	 0.010329	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18483	 81152	 0.002561	 0.014409	 0.00031	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18484	 81152	 0.003734	 0.011239	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18484	 81155	 0.004656	 0.011968	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18485	 18493	 0.000787	 0.00388	 0.00105	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18485	 81152	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18485	 81152	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18486	 81153	 0.001266	 0.00869	 0.00016	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18487	 81153	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18487	 81153	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81153	 18488	 0.005821	 0.006969	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18488	 81154	 0.005118	 0.010132	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18489	 18490	 0.000622	 0.002854	 0.00073	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18489	 19407	 0.000724	 0.002898	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18489	 81154	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18489	 81154	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18491	 18522	 0.02652	 0.061561	 0.00117	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81151	 18492	 0.008558	 0.026282	 0.00049	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18492	 81155	 0.010312	 0.021103	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18493	 81155	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18493	 81155	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18493	 81168	 0.007193	 0.038124	 0.01272	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81155	 18494	 0.011302	 0.01231	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80127	 18495	 0.01255	 0.040244	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18495	 81164	 0.014593	 0.077756	 0.00136	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18496	 18522	 0.017839	 0.031373	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18497	 18498	 0.018647	 0.036544	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18498	 18500	 0.007465	 0.017677	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18498	 18851	 0.02335	 0.032543	 0.00056	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18499	 18503	 0.006628	 0.017037	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18499	 18857	 0.006386	 0.011523	 0.00017	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18500	 18501	 0.016724	 0.013109	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18500	 18504	 0.004015	 0.012927	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18502	 18504	 0.015156	 0.015308	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18502	 18525	 0.025817	 0.020431	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18503	 18504	 0.006137	 0.01141	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18503	 81156	 0.001987	 0.012208	 0.00028	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18504	 81158	 0.002605	 0.011546	 0.00035	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18504	 95342	 0.001079	 0.020069	 1.3339	 2226.0	 2337.3	 2448.6	 1.0	 0.0	 0	 -30.0	 30.0;
	18505	 18862	 0.001343	 0.004607	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18505	 81156	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18505	 81156	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18505	 81157	 0.001242	 0.004879	 0.00128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18506	 81157	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81158	 18506	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18506	 81167	 0.000313	 0.003079	 0.01056	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81156	 18507	 0.004734	 0.01579	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18507	 81160	 0.004944	 0.015182	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81156	 18508	 0.003983	 0.013145	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18508	 81160	 0.005671	 0.016675	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18509	 81159	 0.006848	 0.004951	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18510	 18511	 0.000503	 0.001694	 0.00042	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18510	 18515	 0.000942	 0.00341	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18510	 81159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18510	 81159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18511	 81160	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18511	 81160	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18511	 81168	 0.001519	 0.00521	 0.00125	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81159	 18512	 0.006023	 0.010826	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81160	 18512	 0.002719	 0.005328	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18512	 81169	 0.004555	 0.013709	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18513	 18535	 0.011831	 0.016142	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81160	 18513	 0.020778	 0.013452	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18514	 18530	 0.002206	 0.007567	 0.00181	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18514	 18536	 0.001382	 0.005431	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18514	 81161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18514	 81161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18515	 18516	 0.001005	 0.003502	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18516	 81162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18516	 81162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18517	 18518	 0.006888	 0.010994	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18517	 18531	 0.006439	 0.009382	 0.00021	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81162	 18517	 0.01568	 0.025027	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18518	 18519	 0.007991	 0.020541	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18519	 81163	 0.010453	 0.026871	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18520	 18538	 0.002231	 0.005895	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18520	 81163	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18520	 81163	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18521	 18562	 0.020595	 0.014589	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18522	 81164	 0.006741	 0.032896	 0.00057	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18522	 81166	 0.007694	 0.02034	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18523	 18524	 0.01256	 0.01368	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18524	 81164	 0.008214	 0.021116	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18525	 18526	 0.012827	 0.009839	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18526	 81164	 0.004298	 0.008509	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18527	 18528	 0.000577	 0.002021	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18527	 18529	 0.00188	 0.004968	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18527	 81164	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18527	 81164	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81157	 18528	 0.000899	 0.004286	 0.00124	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18529	 18530	 0.000783	 0.002446	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18529	 18532	 0.002343	 0.008038	 0.00193	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18529	 81165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18529	 81165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18532	 81166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18532	 81166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18533	 18540	 6.3e-05	 0.000868	 0.06565	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18533	 18837	 0.00016	 0.002073	 0.13228	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18533	 81167	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18534	 18535	 0.0088	 0.013193	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18534	 81170	 0.011222	 0.018716	 0.00027	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81169	 18535	 0.006359	 0.016479	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18536	 18537	 0.001347	 0.005392	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18537	 81170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18537	 81170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18537	 81172	 0.001319	 0.009746	 0.00281	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18538	 18568	 0.001183	 0.003946	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18538	 81171	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18538	 81171	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18539	 18557	 0.001083	 0.007081	 0.0018	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18539	 18558	 0.001009	 0.004202	 0.00131	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18539	 18559	 0.001365	 0.005186	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18540	 19022	 0.000143	 0.002445	 0.19032	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18540	 20037	 0.00128	 0.035987	 2.7651	 1800.0	 1800.0	 1800.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18540	 81172	 0.000111	 0.008871	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18541	 18552	 0.000425	 0.002689	 0.00073	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18541	 18554	 0.001323	 0.004537	 0.00109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18541	 18557	 0.000294	 0.002046	 0.00077	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18542	 18565	 0.001932	 0.005259	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18542	 81174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18542	 81174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18543	 81175	 0.033846	 0.024901	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18544	 18546	 0.001499	 0.0061	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81172	 18544	 0.002485	 0.009949	 0.00251	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18544	 81175	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18544	 81175	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81175	 18545	 0.004368	 0.008939	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18545	 81176	 0.003018	 0.013505	 0.00028	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18546	 18547	 0.000642	 0.002569	 0.00065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18546	 81176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18546	 81176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18547	 18551	 0.000825	 0.002886	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18547	 81177	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18547	 81177	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81176	 18548	 0.005748	 0.016904	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81177	 18548	 0.004174	 0.008087	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18548	 81178	 0.001513	 0.006744	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18549	 18550	 0.001067	 0.006873	 0.0018	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18549	 19055	 0.000936	 0.007377	 0.00216	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18550	 18551	 0.000349	 0.002168	 0.00061	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18551	 81178	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18551	 81178	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18552	 18553	 0.000417	 0.002594	 0.00073	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18552	 81179	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18552	 81179	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18553	 18555	 0.000416	 0.003322	 0.00082	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18553	 81180	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18553	 81180	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18554	 18556	 0.000541	 0.003246	 0.00098	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18554	 18569	 0.004795	 0.01645	 0.00394	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81172	 18554	 0.005444	 0.019048	 0.00631	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18554	 81181	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18554	 81181	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18555	 19057	 0.001271	 0.009143	 0.00242	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18556	 19058	 0.001196	 0.007177	 0.00217	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18558	 18566	 0.001497	 0.00542	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18559	 18560	 0.00115	 0.003874	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81172	 18559	 0.001575	 0.006505	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18559	 81182	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18559	 81182	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18560	 18568	 0.001482	 0.005083	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18561	 18566	 0.001566	 0.004139	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18561	 81183	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18561	 81183	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18562	 18564	 0.017682	 0.016286	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81147	 18562	 0.014768	 0.02924	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81170	 18562	 0.045079	 0.056644	 0.00085	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81183	 18562	 0.004622	 0.01073	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18563	 18564	 0.008207	 0.010188	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81147	 18563	 0.023748	 0.018794	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81174	 18564	 0.008661	 0.017148	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18565	 18566	 0.001174	 0.003103	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18565	 81184	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18565	 81184	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18566	 18567	 0.000782	 0.002029	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18567	 18568	 0.001146	 0.00303	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18570	 81185	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18570	 81185	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18570	 81371	 0.000309	 0.004807	 0.02019	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18571	 18572	 0.00141	 0.00946	 0.00228	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18571	 19014	 0.002072	 0.010053	 0.0023	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81185	 18571	 0.00366	 0.012753	 0.00296	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18571	 81186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18571	 81186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18572	 81187	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18572	 81187	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81186	 18573	 0.008506	 0.030386	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81187	 18573	 0.010032	 0.023291	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18574	 18575	 0.000908	 0.003637	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18574	 81188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18574	 81188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18576	 81569	 0.039692	 0.04053	 0.00063	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81124	 18577	 0.002415	 0.017445	 0.00033	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81132	 18577	 0.002017	 0.013189	 0.00031	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81168	 18578	 0.001102	 0.005056	 0.0013	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81172	 18578	 0.002036	 0.008918	 0.00307	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18580	 18586	 0.01022	 0.049876	 0.01378	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18580	 18824	 0.015726	 0.043855	 0.00921	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18580	 18825	 0.007603	 0.034882	 0.00894	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18581	 18582	 0.004332	 0.030903	 0.00958	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18581	 19223	 0.00315	 0.023272	 0.00672	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18582	 18586	 0.002949	 0.02369	 0.00666	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18583	 18584	 0.009826	 0.025969	 0.00608	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18583	 18586	 0.002932	 0.015272	 0.00401	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18583	 19068	 0.0095	 0.054591	 0.01547	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18584	 18585	 0.005119	 0.013528	 0.00317	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18585	 18594	 0.009696	 0.025173	 0.00611	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18586	 18587	 0.002039	 0.013135	 0.00344	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79600	 18586	 0.009233	 0.05152	 0.01316	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18587	 18590	 0.002152	 0.01386	 0.00363	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18587	 81189	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18587	 81189	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18588	 19039	 0.033031	 0.109	 0.00177	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81189	 18588	 0.018538	 0.05693	 0.00107	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18589	 18590	 0.00184	 0.012346	 0.00298	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18589	 19038	 0.001737	 0.014899	 0.00424	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18589	 81190	 0.003252	 0.018046	 0.00549	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18589	 81382	 0.002698	 0.017091	 0.00464	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18591	 19044	 0.000347	 0.006044	 0.02029	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79599	 18591	 0.00133	 0.014667	 0.02787	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79599	 18591	 0.00133	 0.014667	 0.02787	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18591	 81190	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18591	 81190	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18592	 19194	 0.066062	 0.12101	 0.00209	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79598	 18592	 0.032766	 0.067054	 0.00165	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18593	 18594	 0.003763	 0.020049	 0.00563	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18593	 19184	 0.001499	 0.023239	 0.00655	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79597	 18593	 0.003081	 0.029004	 0.00879	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79600	 18594	 0.001548	 0.013279	 0.00378	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79597	 18595	 0.000803	 0.003896	 0.00089	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79600	 18595	 0.000228	 0.000887	 0.00024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79600	 18596	 0.005537	 0.016324	 0.0038	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18597	 18912	 0.012348	 0.043038	 0.00998	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18597	 81191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18597	 81191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18598	 18609	 0.066769	 0.22037	 0.00357	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18598	 18610	 0.038621	 0.12745	 0.00206	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18598	 18940	 0.077658	 0.19752	 0.00312	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81191	 18598	 0.014566	 0.079714	 0.00156	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18599	 81329	 0.035479	 0.19937	 0.00369	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18600	 18601	 0.001825	 0.013677	 0.00334	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79591	 18600	 0.004781	 0.029709	 0.00838	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18600	 81316	 0.002832	 0.04163	 0.01273	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79591	 18601	 0.004127	 0.018931	 0.00485	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18601	 81192	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18601	 81192	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18601	 81194	 0.004922	 0.031173	 0.00846	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18602	 18875	 0.005364	 0.041807	 0.0125	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79591	 18602	 0.009007	 0.041323	 0.01059	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18602	 81193	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18602	 81193	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18603	 81194	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18603	 81194	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18604	 18606	 0.004566	 0.028922	 0.00785	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18604	 81195	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18604	 81195	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81195	 18605	 0.04238	 0.076175	 0.00137	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18605	 81196	 0.031054	 0.10248	 0.00166	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18606	 81196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18606	 81196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18606	 81199	 0.002459	 0.025297	 0.00717	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18607	 18608	 0.056226	 0.10299	 0.00178	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81050	 18607	 0.10762	 0.10765	 0.00145	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81196	 18608	 0.032242	 0.10756	 0.0017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18608	 81658	 0.048344	 0.15351	 0.00269	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18609	 81391	 0.17278	 0.18822	 0.00256	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18610	 81197	 0.050955	 0.13099	 0.00203	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18611	 18765	 0.007314	 0.032932	 0.00876	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18611	 81197	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18611	 81197	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18611	 81199	 0.004908	 0.027057	 0.00632	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18612	 19317	 0.000437	 0.007817	 0.55537	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18612	 19768	 0.000432	 0.005586	 0.35663	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18612	 81198	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18612	 81198	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81199	 18612	 0.000124	 0.009885	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18613	 18755	 0.01699	 0.043679	 0.01082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81199	 18613	 0.016512	 0.04151	 0.01075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18614	 19933	 0.018075	 0.070318	 0.00117	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18614	 81207	 0.011442	 0.065042	 0.00118	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18615	 81207	 0.026831	 0.076956	 0.00118	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18616	 19934	 0.008764	 0.053008	 0.01353	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18616	 20012	 0.007003	 0.04016	 0.01335	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18617	 18618	 6.2e-05	 0.001772	 0.12329	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18617	 19130	 0.000298	 0.005056	 0.3992	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18617	 20016	 7.6e-05	 0.002192	 0.15252	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18617	 81200	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18617	 81200	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81201	 18617	 0.00016	 0.012814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18618	 19914	 3.2e-05	 0.000834	 0.06874	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18619	 18624	 0.000376	 0.005657	 0.02557	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18619	 19037	 0.004818	 0.045124	 0.17132	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18619	 19125	 0.000993	 0.009759	 0.03347	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81200	 18619	 0.001084	 0.011243	 0.02421	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81200	 18619	 0.001084	 0.011243	 0.02421	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18619	 81202	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18619	 81202	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18620	 18621	 0.005744	 0.01729	 0.00541	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81202	 18620	 0.003198	 0.017844	 0.00456	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18620	 81405	 0.004547	 0.021479	 0.00687	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18621	 18622	 0.003786	 0.012988	 0.00311	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18622	 81203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18622	 81203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81203	 18623	 0.010589	 0.02458	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18623	 81205	 0.011689	 0.038995	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18624	 19916	 0.000203	 0.001964	 0.00486	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18624	 19916	 0.000203	 0.001964	 0.00486	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18624	 81204	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81205	 18624	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18625	 18626	 0.005252	 0.029856	 0.00054	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18625	 81207	 0.047579	 0.052331	 0.0007	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18625	 81700	 0.010499	 0.0316	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18625	 81704	 0.015397	 0.051363	 0.00081	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81089	 18626	 0.019946	 0.096237	 0.0017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18627	 19913	 1.8e-05	 0.000478	 0.03937	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18627	 19931	 0.000136	 0.003593	 0.2961	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18627	 81206	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18628	 18629	 0.002055	 0.021774	 0.00646	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18628	 18900	 0.002387	 0.025749	 0.00737	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18630	 19260	 0.000619	 0.008603	 0.54954	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18630	 81208	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18630	 81208	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18631	 19061	 0.004027	 0.033866	 0.01003	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81208	 18631	 0.002906	 0.024175	 0.00732	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18632	 18894	 0.025859	 0.11991	 0.00249	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79613	 18632	 0.055681	 0.18576	 0.00294	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18632	 81209	 0.015591	 0.08863	 0.0016	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18633	 18635	 0.003725	 0.018401	 0.00537	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18633	 18882	 0.007816	 0.03308	 0.00744	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18633	 81209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18633	 81209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18634	 18635	 0.003411	 0.01777	 0.00466	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18634	 19277	 0.006199	 0.034018	 0.00899	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18635	 18883	 0.010465	 0.035901	 0.0086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18635	 81210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18635	 81210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79590	 18636	 0.002581	 0.020605	 0.00508	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18636	 81211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18636	 81211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18637	 18638	 0.013203	 0.051365	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18637	 18638	 0.013203	 0.051365	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81210	 18637	 0.016455	 0.10117	 0.00182	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18637	 81212	 0.030752	 0.11964	 0.002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81211	 18638	 0.014504	 0.055799	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81211	 18638	 0.014504	 0.055799	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18639	 18883	 0.005387	 0.039804	 0.01149	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79590	 18639	 0.000798	 0.013352	 0.00757	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18639	 81212	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18639	 81212	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18640	 18641	 0.010459	 0.029167	 0.00612	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18640	 18697	 0.001571	 0.009951	 0.0027	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18640	 18960	 0.00573	 0.027961	 0.00772	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18640	 81213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18640	 81213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18641	 18642	 0.002977	 0.015509	 0.00407	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18641	 18643	 0.009265	 0.036415	 0.00953	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18641	 18667	 0.006961	 0.031935	 0.00818	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18642	 18963	 0.000564	 0.003411	 0.00087	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18643	 18876	 0.0083	 0.043958	 0.01114	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18643	 18965	 0.017892	 0.15255	 0.03811	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79591	 18643	 0.011519	 0.10482	 0.02648	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79594	 18643	 0.021156	 0.13156	 0.03717	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18643	 81214	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18643	 81214	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81193	 18644	 0.030137	 0.13279	 0.00231	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81214	 18644	 0.029023	 0.099142	 0.00216	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18645	 81215	 0.02178	 0.097055	 0.00165	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18646	 81535	 0.003095	 0.019234	 0.00543	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18647	 18648	 0.009387	 0.038202	 0.00931	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18647	 81215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18647	 81215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18647	 81535	 0.00656	 0.042896	 0.01091	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18648	 19139	 0.009237	 0.036967	 0.01249	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18649	 19139	 0.008095	 0.042168	 0.01106	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18650	 18881	 0.007649	 0.037716	 0.0102	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18650	 81216	 0.006624	 0.027351	 0.00647	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18650	 81218	 0.008934	 0.034757	 0.00928	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18651	 18652	 0.000144	 0.001974	 0.14935	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18651	 19111	 0.000228	 0.002717	 0.20385	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18651	 81216	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18652	 18934	 8.7e-05	 0.00197	 0.19682	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18652	 81218	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18652	 81218	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18653	 19207	 0.005949	 0.027291	 0.00699	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18653	 19399	 0.00565	 0.027419	 0.00627	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18653	 81219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18653	 81219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18653	 81514	 0.03581	 0.1517	 0.03418	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18654	 19145	 0.24612	 0.24866	 0.00329	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81219	 18654	 0.039339	 0.062793	 0.00145	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18655	 19399	 0.003168	 0.023865	 0.00662	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79585	 18656	 0.02822	 0.065507	 0.00125	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18656	 81222	 0.047376	 0.12179	 0.00188	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18656	 81223	 0.071326	 0.23541	 0.00381	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18657	 18944	 0.063261	 0.16769	 0.00425	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18657	 81222	 0.031637	 0.17986	 0.00325	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18658	 18950	 0.15597	 0.14628	 0.00226	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18658	 81222	 0.25786	 0.20412	 0.00257	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18659	 18952	 0.10875	 0.11615	 0.00246	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18659	 81223	 0.2194	 0.17366	 0.00219	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18660	 81220	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18660	 81220	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79523	 18661	 0.000831	 0.012958	 0.02784	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18661	 81221	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18661	 81221	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18662	 18663	 0.004805	 0.029816	 0.00722	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79584	 18662	 0.006487	 0.041785	 0.01096	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18662	 81222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18662	 81222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18663	 18664	 0.003141	 0.013669	 0.00389	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79525	 18663	 0.010093	 0.070043	 0.02	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79584	 18663	 0.010723	 0.06437	 0.0195	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18663	 81223	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18663	 81223	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79584	 18664	 0.00494	 0.058424	 0.01663	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81220	 18664	 0.00229	 0.033355	 0.01068	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81221	 18664	 0.009897	 0.040863	 0.00967	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18665	 81224	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18665	 81224	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18666	 18667	 0.00276	 0.021148	 0.00567	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18666	 18707	 0.004443	 0.030268	 0.01031	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18666	 18876	 0.009241	 0.033463	 0.00718	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81224	 18666	 0.001729	 0.028338	 0.00891	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18667	 18707	 0.006255	 0.016531	 0.00387	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18668	 18669	 0.006123	 0.039502	 0.00126	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18668	 18715	 0.016417	 0.054176	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18668	 81227	 0.015307	 0.081556	 0.00143	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18668	 81237	 0.032771	 0.084241	 0.0013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18669	 81225	 0.005369	 0.041843	 0.00078	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79607	 18670	 0.00491	 0.014221	 0.00343	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18670	 81225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18670	 81225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18671	 18735	 0.014284	 0.087817	 0.00158	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81225	 18671	 0.007737	 0.034475	 0.00059	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81225	 18672	 0.064958	 0.071447	 0.00095	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18673	 18793	 0.01166	 0.033774	 0.00815	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18673	 18794	 0.006847	 0.043367	 0.01177	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18673	 81226	 0.003512	 0.020922	 0.0055	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18674	 19703	 0.001221	 0.011824	 0.04182	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81067	 18674	 0.004122	 0.040539	 0.1392	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18674	 81226	 9.7e-05	 0.007785	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81227	 18674	 0.000262	 0.019645	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18675	 81228	 0.006494	 0.018626	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18675	 81229	 0.015889	 0.037625	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18676	 18677	 0.001269	 0.005082	 0.00128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81226	 18676	 0.00287	 0.011163	 0.00298	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18676	 81228	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18676	 81228	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18677	 18733	 0.001755	 0.007026	 0.00177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18678	 18679	 0.002109	 0.008444	 0.00213	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81226	 18678	 0.006235	 0.024962	 0.00629	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18678	 81229	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18678	 81229	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18679	 18680	 0.002014	 0.010493	 0.00275	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18679	 18681	 0.001549	 0.007331	 0.00176	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18679	 18683	 0.002718	 0.011223	 0.00266	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18680	 18685	 0.003097	 0.016462	 0.00382	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18680	 81230	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18680	 81230	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18681	 18736	 0.001751	 0.008288	 0.00199	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18682	 18684	 0.024247	 0.024318	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18682	 81231	 0.008158	 0.018742	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18683	 18741	 0.001693	 0.007368	 0.0021	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18683	 81231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18683	 81231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18684	 18686	 0.022456	 0.042441	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18684	 81258	 0.020211	 0.066696	 0.00108	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18685	 18793	 0.004049	 0.019965	 0.0054	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18686	 18687	 0.10029	 0.064928	 0.00124	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18688	 18689	 0.007191	 0.018485	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18688	 81238	 0.002957	 0.018176	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18688	 81239	 0.006677	 0.017165	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18689	 18702	 0.004209	 0.016375	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18689	 81232	 0.004517	 0.020126	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18690	 18691	 0.00127	 0.004991	 0.00131	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18690	 18695	 0.001291	 0.004697	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18690	 18708	 0.00103	 0.005477	 0.00127	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18690	 81232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18690	 81232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18691	 18692	 0.001568	 0.006279	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18691	 18694	 0.002169	 0.00622	 0.00153	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18692	 19731	 0.001778	 0.006469	 0.00198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18692	 81233	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18692	 81233	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18693	 81238	 0.027857	 0.022045	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18694	 18701	 0.001123	 0.004065	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18695	 18704	 0.001097	 0.004391	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18696	 18705	 0.001629	 0.007906	 0.00181	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18696	 18706	 0.000845	 0.008109	 0.00236	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18696	 18722	 0.001961	 0.004727	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18696	 81234	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18696	 81234	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18697	 18698	 0.000689	 0.00316	 0.00081	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18698	 18705	 0.001747	 0.005151	 0.0012	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18698	 81235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18698	 81235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81235	 18699	 0.0036	 0.019179	 0.00034	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18699	 81236	 0.002217	 0.010596	 0.00023	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81213	 18700	 0.046157	 0.050768	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18700	 81236	 0.020919	 0.017218	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18701	 81236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18701	 81236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18702	 18703	 0.002209	 0.008286	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18703	 81240	 0.003588	 0.010801	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18704	 18705	 0.001239	 0.005245	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18706	 18707	 0.000567	 0.00556	 0.00174	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18706	 81237	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18706	 81237	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18708	 18709	 0.000914	 0.003868	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18708	 81238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18708	 81238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18709	 19721	 0.001026	 0.004034	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18710	 18723	 0.00295	 0.014396	 0.00025	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18710	 81637	 0.002273	 0.012919	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18711	 18723	 0.009738	 0.013274	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81238	 18712	 0.040848	 0.029529	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18712	 81242	 0.005508	 0.021429	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18712	 81244	 0.011467	 0.038252	 0.00061	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18712	 81638	 0.009642	 0.02736	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18713	 18717	 0.001245	 0.004272	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18713	 81239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18713	 81239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18714	 18723	 0.002122	 0.01206	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18714	 81242	 0.002265	 0.011526	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18715	 81243	 0.015535	 0.034383	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18715	 81250	 0.007382	 0.032713	 0.00098	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18716	 18722	 0.001648	 0.005968	 0.00128	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18716	 81240	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18716	 81240	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18717	 81241	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18717	 81241	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18718	 18725	 0.001247	 0.004994	 0.00126	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18718	 81242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18718	 81242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18719	 18721	 0.006454	 0.02153	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81241	 18719	 0.003003	 0.016003	 0.00028	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81241	 18720	 0.005179	 0.008724	 0.00012	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18720	 81245	 0.028157	 0.022283	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18721	 81243	 0.009045	 0.017908	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18722	 81243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18722	 81243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18723	 81244	 0.003345	 0.014736	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18724	 18726	 0.001335	 0.005343	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18724	 18727	 0.001548	 0.00639	 0.00151	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18724	 81244	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18724	 81244	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18724	 81628	 0.001125	 0.009035	 0.00254	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81226	 18725	 0.01144	 0.028758	 0.00745	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18725	 81245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18725	 81245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18726	 18728	 0.001414	 0.005985	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18726	 81246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18726	 81246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18727	 18729	 0.001836	 0.004615	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18727	 81247	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18727	 81247	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18728	 18734	 0.001547	 0.006079	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18728	 81248	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18728	 81248	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18729	 18730	 0.000738	 0.005219	 0.00143	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18729	 18733	 0.000648	 0.005656	 0.00224	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18730	 19678	 0.001043	 0.004783	 0.00123	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18730	 81249	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18730	 81249	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18731	 19684	 0.005433	 0.017929	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81249	 18731	 0.004175	 0.018605	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18731	 81629	 0.011301	 0.043964	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18732	 18734	 0.001267	 0.005364	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81226	 18732	 0.005968	 0.015467	 0.00468	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18732	 81250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18732	 81250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81226	 18733	 0.003727	 0.021827	 0.00595	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18733	 81251	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18733	 81251	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18734	 81252	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18734	 81252	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81252	 18735	 0.002621	 0.019155	 0.00035	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18736	 18737	 0.002382	 0.006184	 0.0015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18736	 18738	 0.001104	 0.006078	 0.00219	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18736	 81253	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18736	 81253	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18737	 81254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18737	 81254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18738	 18739	 0.001386	 0.005448	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18738	 19689	 0.001064	 0.003872	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18738	 81255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18738	 81255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18739	 81256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18739	 81256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18739	 81259	 0.002054	 0.00836	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18740	 19696	 0.001091	 0.004437	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79618	 18740	 0.001298	 0.008221	 0.00223	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18740	 81257	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18740	 81257	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18740	 81259	 0.001696	 0.006791	 0.00171	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18741	 18742	 0.001117	 0.005027	 0.00134	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18742	 81258	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18742	 81258	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18742	 81259	 0.000762	 0.004737	 0.00134	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18743	 81259	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81260	 18743	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81258	 18744	 0.027287	 0.062691	 0.00095	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18744	 81261	 0.034849	 0.04497	 0.0009	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18745	 18751	 0.003842	 0.017918	 0.00444	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18745	 18917	 0.00994	 0.039071	 0.01022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18745	 81261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18745	 81261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79618	 18746	 0.000835	 0.002168	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18746	 81262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18746	 81262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18746	 81643	 0.003967	 0.013607	 0.00326	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18747	 18749	 0.002012	 0.012746	 0.00346	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18747	 18751	 0.00191	 0.010597	 0.00322	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18747	 81263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18747	 81263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81065	 18748	 0.008768	 0.064761	 0.00135	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81263	 18748	 0.009524	 0.057663	 0.00181	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79609	 18749	 0.001824	 0.012656	 0.00361	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81260	 18750	 0.020875	 0.04133	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79618	 18751	 0.003175	 0.011221	 0.00253	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18752	 18753	 0.002373	 0.007738	 0.00205	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18752	 19500	 0.002946	 0.010107	 0.00242	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18752	 81264	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18752	 81264	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18753	 18765	 0.004792	 0.01498	 0.00434	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18754	 19499	 0.018713	 0.047591	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18754	 81268	 0.040901	 0.12311	 0.00241	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18755	 18954	 0.011028	 0.037832	 0.00906	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18756	 18947	 0.018387	 0.074839	 0.01824	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18756	 81266	 0.004986	 0.019961	 0.00503	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18757	 81265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18757	 81265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18757	 81266	 0.002488	 0.009678	 0.00258	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18758	 18763	 0.001385	 0.014064	 0.04517	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81198	 18758	 0.00369	 0.039369	 0.08011	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81198	 18758	 0.00369	 0.039369	 0.08011	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18758	 81266	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81267	 18758	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18759	 18761	 0.025787	 0.081881	 0.00144	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81267	 18759	 0.038279	 0.098401	 0.00152	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81265	 18760	 0.027901	 0.070956	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18760	 81268	 0.023101	 0.089873	 0.0015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18761	 18762	 0.037694	 0.072188	 0.00114	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18762	 81268	 0.055424	 0.072844	 0.001	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81198	 18763	 0.002357	 0.018908	 0.06367	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18763	 81268	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18763	 81268	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81268	 18764	 0.10456	 0.076927	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18765	 81269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18765	 81269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79583	 18766	 0.004173	 0.060249	 0.01913	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18766	 81270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18766	 81270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18766	 81822	 0.00894	 0.062955	 0.03581	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18767	 18769	 0.009344	 0.024019	 0.00595	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79620	 18767	 0.014287	 0.037092	 0.009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18768	 19788	 0.006198	 0.016381	 0.00383	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18768	 81271	 0.005974	 0.021116	 0.00476	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18768	 81573	 0.011918	 0.031498	 0.00737	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18769	 18771	 0.003258	 0.009085	 0.00191	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79619	 18770	 0.003247	 0.020568	 0.04308	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18770	 81271	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18770	 81271	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18771	 19789	 0.011423	 0.031854	 0.00669	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81271	 18771	 0.003732	 0.010019	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18772	 18773	 0.007988	 0.02784	 0.00646	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81271	 18772	 0.008464	 0.021974	 0.00533	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18773	 18774	 0.007559	 0.034679	 0.00888	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18775	 18776	 0.02219	 0.058659	 0.00107	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18775	 81470	 0.054041	 0.054584	 0.00072	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18776	 81468	 0.081672	 0.057854	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18776	 81587	 0.025654	 0.085582	 0.00136	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18777	 18778	 0.005919	 0.032391	 0.00063	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18777	 18782	 0.01054	 0.027094	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18777	 81272	 0.01681	 0.042749	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79581	 18778	 0.011959	 0.073524	 0.00133	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18779	 18780	 0.002929	 0.007863	 0.00178	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18779	 19911	 0.001832	 0.004842	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18779	 81272	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18779	 81272	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18780	 81273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18780	 81273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18780	 81275	 0.006103	 0.022098	 0.00474	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79619	 18781	 0.00166	 0.016311	 0.05594	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81067	 18781	 0.0007	 0.008054	 0.02908	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18781	 81274	 0.000746	 0.004841	 0.00964	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18782	 19205	 0.11624	 0.11627	 0.00157	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18782	 81699	 0.027133	 0.062337	 0.00095	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81065	 18783	 0.19123	 0.33646	 0.00632	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81273	 18783	 0.023015	 0.056335	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18784	 18918	 0.005824	 0.033105	 0.00958	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18784	 81275	 0.001899	 0.011395	 0.00345	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18785	 81274	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18786	 81277	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18786	 81277	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18787	 18796	 0.002131	 0.015069	 0.00413	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18787	 18893	 0.005799	 0.031935	 0.01153	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79483	 18788	 0.004287	 0.022704	 0.00575	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79967	 18788	 0.009514	 0.061293	 0.01607	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81226	 18788	 0.026018	 0.16012	 0.05868	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18788	 81278	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18788	 81278	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81278	 18789	 0.010037	 0.056395	 0.00104	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18789	 81279	 0.021099	 0.0935	 0.00281	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18790	 81279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18790	 81279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18791	 18792	 0.030395	 0.097878	 0.00167	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79586	 18791	 0.013123	 0.090081	 0.00164	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81279	 18791	 0.018356	 0.071687	 0.00159	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18792	 81456	 0.03158	 0.090578	 0.00139	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18793	 18794	 0.004776	 0.024395	 0.00614	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18794	 81280	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18794	 81280	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18795	 18796	 0.012063	 0.041384	 0.00992	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18795	 18917	 0.011814	 0.04053	 0.00971	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18795	 81281	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18795	 81281	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18797	 18798	 0.00662	 0.026506	 0.00668	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18797	 18893	 0.005999	 0.036006	 0.0109	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18797	 19244	 0.013335	 0.087221	 0.02219	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18798	 18799	 0.003496	 0.021723	 0.00613	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18798	 81282	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18798	 81282	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18799	 18896	 0.004535	 0.027425	 0.007	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18799	 81283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18799	 81283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18800	 18801	 0.056449	 0.11177	 0.00164	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18801	 19120	 0.015686	 0.1305	 0.00247	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18801	 81460	 0.022144	 0.12443	 0.0023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18802	 18803	 0.11861	 0.13046	 0.00174	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18802	 18804	 0.13875	 0.13632	 0.0023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18802	 81460	 0.066238	 0.20324	 0.00551	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18803	 18804	 0.14005	 0.10611	 0.00146	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18804	 81284	 0.11462	 0.26616	 0.00396	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18805	 19253	 0.063927	 0.16454	 0.04081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18805	 81284	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18805	 81284	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18806	 18807	 4.1e-05	 0.001075	 0.08853	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18806	 18808	 0.000108	 0.001347	 0.09229	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18806	 20067	 5.8e-05	 0.001617	 0.12118	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18806	 81285	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18806	 81285	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18807	 18810	 4.4e-05	 0.001268	 0.0882	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18807	 81286	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18807	 81286	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18808	 18822	 8.3e-05	 0.000987	 0.07406	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18809	 18821	 0.002145	 0.014391	 0.00347	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18809	 20069	 0.001995	 0.014351	 0.0038	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18810	 18814	 0.000125	 0.001493	 0.11203	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18811	 18813	 0.012491	 0.019938	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18812	 18813	 0.007596	 0.019319	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79489	 18812	 0.033643	 0.089172	 0.00226	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18813	 18819	 0.0121	 0.023957	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18813	 81288	 0.001875	 0.012721	 0.00024	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18814	 18815	 3.7e-05	 0.000462	 0.03164	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18814	 18817	 3.8e-05	 0.000618	 0.04339	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18814	 81287	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18815	 18833	 4.1e-05	 0.000483	 0.03626	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18815	 81289	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18815	 81289	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18816	 18830	 0.001503	 0.004352	 0.00105	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81289	 18816	 0.002007	 0.006761	 0.00168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18817	 18823	 4.3e-05	 0.000694	 0.0487	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18818	 81290	 0.03843	 0.030413	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18819	 18844	 0.081373	 0.086902	 0.00184	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81288	 18819	 0.004358	 0.011204	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18820	 18845	 0.004947	 0.018805	 0.00526	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81287	 18820	 0.003479	 0.009339	 0.00212	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18820	 81290	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18820	 81290	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18821	 18824	 0.003946	 0.02499	 0.00678	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18821	 81291	 0.001294	 0.008682	 0.0021	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18822	 18823	 5.4e-05	 0.000828	 0.06371	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18822	 81291	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18825	 18845	 0.005958	 0.024597	 0.00582	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18826	 18831	 0.00204	 0.005851	 0.00144	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18826	 18836	 0.000882	 0.003588	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18826	 18847	 0.00109	 0.006049	 0.00184	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18826	 81293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18826	 81293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81290	 18827	 0.015822	 0.036733	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18827	 81294	 0.033389	 0.033397	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18827	 81298	 0.038804	 0.027487	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18828	 18840	 0.00126	 0.004322	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18828	 81294	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18828	 81294	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18828	 81299	 0.001602	 0.005496	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18829	 18841	 0.000315	 0.002139	 0.00389	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80052	 18829	 0.003124	 0.019792	 0.04146	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18829	 81295	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81296	 18829	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18830	 18831	 0.001385	 0.004013	 0.00097	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18830	 81297	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18830	 81297	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18832	 81298	 0.021837	 0.016066	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18833	 18835	 3.2e-05	 0.000408	 0.02606	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18833	 81298	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18833	 81298	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81294	 18834	 0.026543	 0.020806	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18834	 81300	 0.005198	 0.010188	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18835	 18837	 1.8e-05	 0.000223	 0.01529	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18835	 81299	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18836	 81301	 0.000572	 0.00229	 0.00058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18837	 81301	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18837	 81301	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81295	 18838	 0.00062	 0.00467	 0.0013	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81301	 18838	 0.000291	 0.002214	 0.0007	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18839	 18860	 0.030726	 0.040383	 0.00055	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81296	 18839	 0.009622	 0.018856	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81295	 18840	 0.002176	 0.007098	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18840	 81302	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18840	 81302	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81167	 18841	 0.001146	 0.007549	 0.01461	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18841	 81303	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81304	 18841	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18842	 18843	 0.006451	 0.014753	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18842	 81311	 0.008807	 0.018023	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18843	 18844	 0.01046	 0.01747	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81302	 18844	 0.025505	 0.025511	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18845	 18846	 0.004099	 0.012338	 0.00386	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18846	 18863	 0.002993	 0.010581	 0.00238	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18846	 18869	 0.00204	 0.008017	 0.0021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18847	 18848	 0.000714	 0.004255	 0.00112	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18848	 18852	 0.001177	 0.004261	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18848	 18858	 0.002313	 0.00537	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18849	 18851	 0.041777	 0.033062	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18849	 18854	 0.003531	 0.017862	 0.00031	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18849	 81305	 0.002666	 0.015154	 0.00027	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18850	 18851	 0.005393	 0.012517	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18850	 18855	 0.006631	 0.01902	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18851	 81307	 0.004498	 0.027336	 0.0005	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18852	 81305	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18852	 81305	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81305	 18853	 0.016714	 0.021967	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18853	 81306	 0.027265	 0.021577	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18853	 81307	 0.028949	 0.029239	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18854	 18855	 0.017069	 0.01724	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80054	 18854	 0.016222	 0.055415	 0.0012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18856	 18857	 0.021194	 0.016613	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18856	 81307	 0.023462	 0.025805	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18858	 18859	 0.001734	 0.004457	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18858	 81306	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18858	 81306	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18859	 18862	 0.002828	 0.009702	 0.00232	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18859	 81307	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18859	 81307	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18860	 18861	 0.004563	 0.011729	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81304	 18860	 0.012121	 0.031158	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81307	 18861	 0.009395	 0.018601	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81303	 18862	 0.003495	 0.012355	 0.00278	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18863	 18864	 0.00205	 0.007031	 0.00168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18864	 18865	 0.001669	 0.005724	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18864	 18868	 0.001744	 0.008464	 0.00193	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18864	 81308	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18864	 81308	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18865	 18867	 0.001755	 0.004893	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18865	 81309	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18865	 81309	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81173	 18866	 0.025722	 0.042897	 0.00062	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81308	 18866	 0.008243	 0.032069	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81309	 18866	 0.006209	 0.020489	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18866	 81311	 0.040801	 0.07362	 0.00106	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18867	 81310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18867	 81310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18868	 19045	 0.00331	 0.0145	 0.00499	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18869	 18870	 0.003335	 0.010128	 0.00222	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18869	 81311	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18869	 81311	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18870	 81312	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18870	 81312	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18871	 18962	 0.002994	 0.029836	 0.09963	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79577	 18871	 0.000595	 0.008849	 0.0328	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18871	 81313	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18871	 81313	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18872	 18874	 0.000974	 0.010894	 0.02235	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18872	 81314	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18872	 81314	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79577	 18873	 0.000841	 0.009575	 0.01895	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18873	 81315	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18873	 81315	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79617	 18874	 0.000757	 0.005981	 0.02076	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18874	 81316	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18874	 81316	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81313	 18875	 0.005505	 0.042912	 0.01283	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79578	 18876	 0.00695	 0.059617	 0.01697	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81313	 18876	 0.003729	 0.028357	 0.00891	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18877	 18878	 0.006114	 0.043983	 0.01166	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18877	 18879	 0.00478	 0.039666	 0.01044	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18877	 18928	 0.002642	 0.042976	 0.01219	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18878	 18888	 0.006567	 0.04685	 0.01452	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18879	 81319	 0.004314	 0.03675	 0.00917	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81091	 18880	 0.060826	 0.20075	 0.00325	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18880	 81339	 0.052929	 0.15566	 0.00319	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18881	 19068	 0.016984	 0.066765	 0.01747	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18881	 81317	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18881	 81317	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18882	 18896	 0.003187	 0.019127	 0.00579	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18882	 81318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18882	 81318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18883	 18920	 0.015012	 0.087956	 0.02397	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18884	 18885	 0.16303	 0.1278	 0.00164	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18884	 81320	 0.031637	 0.081326	 0.00126	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18886	 81319	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81320	 18886	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79634	 18887	 0.023165	 0.14079	 0.0026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81320	 18887	 0.018582	 0.081409	 0.00175	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18888	 18890	 0.009991	 0.040001	 0.01008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79584	 18888	 0.007392	 0.061354	 0.01614	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79626	 18889	 0.073386	 0.13191	 0.00237	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18890	 18891	 0.0054	 0.024776	 0.00635	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79633	 18891	 0.005209	 0.020472	 0.00536	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81221	 18892	 0.006715	 0.027724	 0.00656	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18894	 18895	 0.035765	 0.11931	 0.00189	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81283	 18895	 0.016741	 0.10293	 0.00186	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18895	 81321	 0.015844	 0.070178	 0.0016	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18896	 81321	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18896	 81321	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18897	 18900	 0.001452	 0.008504	 0.00232	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18897	 81322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18897	 81322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18897	 81325	 0.001552	 0.008824	 0.00255	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79637	 18898	 0.027841	 0.092878	 0.00147	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81322	 18898	 0.008647	 0.022229	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18899	 18903	 0.073266	 0.05743	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18899	 81326	 0.039987	 0.031645	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18900	 18901	 0.001995	 0.007584	 0.00212	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18900	 81323	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18900	 81323	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18901	 81324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18901	 81324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18902	 18903	 0.023837	 0.040155	 0.00057	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18902	 18910	 0.016571	 0.05089	 0.00095	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81323	 18902	 0.014594	 0.051096	 0.00141	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18903	 18910	 0.02254	 0.059741	 0.00152	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81324	 18903	 0.004435	 0.036898	 0.0007	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18903	 81326	 0.018814	 0.031377	 0.00046	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18903	 81327	 0.014897	 0.059101	 0.00169	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18904	 81325	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81326	 18904	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18904	 81659	 0.002745	 0.022879	 0.07139	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81325	 18905	 0.001988	 0.012588	 0.00342	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18905	 81327	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18905	 81327	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18905	 81660	 0.012521	 0.077819	 0.02197	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18906	 18911	 0.020018	 0.070088	 0.00194	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81327	 18906	 0.021035	 0.039112	 0.00092	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18906	 81329	 0.036401	 0.12143	 0.00192	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81327	 18907	 0.016999	 0.066131	 0.0011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18907	 81329	 0.021355	 0.061248	 0.00094	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18908	 18912	 0.004745	 0.024717	 0.00648	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81325	 18908	 0.005236	 0.015759	 0.00493	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18909	 81328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18909	 81328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18910	 19076	 0.027687	 0.1574	 0.00285	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18911	 19077	 0.042565	 0.13707	 0.00234	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18911	 19078	 0.033813	 0.13155	 0.0022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81327	 18911	 0.029879	 0.11496	 0.00196	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18912	 19674	 0.003676	 0.028598	 0.00743	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18912	 81329	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18912	 81329	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79591	 18913	 0.022672	 0.10213	 0.02719	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18913	 81330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18913	 81330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18914	 18915	 0.004597	 0.043268	 0.01311	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18914	 81331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18914	 81331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18915	 19089	 0.006469	 0.062116	 0.01807	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18915	 81332	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18915	 81332	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81261	 18916	 0.04058	 0.10432	 0.00161	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81281	 18916	 0.10162	 0.17873	 0.00336	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81066	 18918	 0.010898	 0.050002	 0.01281	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18919	 18920	 0.006009	 0.033126	 0.00774	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18919	 18921	 0.012863	 0.072856	 0.01806	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18921	 19642	 0.0152	 0.094486	 0.02668	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18921	 81333	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18921	 81333	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81333	 18922	 0.015296	 0.105	 0.00191	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18923	 18924	 0.04292	 0.1231	 0.00189	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18923	 19070	 0.039888	 0.08163	 0.00201	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18924	 18925	 0.03715	 0.1226	 0.00199	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81282	 18925	 0.017518	 0.12025	 0.00219	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18926	 18927	 0.005392	 0.027093	 0.00705	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18926	 18928	 0.009945	 0.05181	 0.01359	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18926	 81334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18926	 81334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18927	 18928	 0.004769	 0.025257	 0.0064	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81226	 18928	 0.034504	 0.23199	 0.05618	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18928	 81335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18928	 81335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81334	 18929	 0.14543	 0.1151	 0.00145	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18930	 18932	 0.005256	 0.031547	 0.00955	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18930	 81336	 0.004641	 0.031098	 0.00953	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18931	 18932	 0.003896	 0.024676	 0.0067	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18931	 19149	 0.002408	 0.015512	 0.00407	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18931	 19177	 0.004577	 0.012097	 0.00283	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81093	 18931	 0.01377	 0.031966	 0.00974	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18933	 18934	 6.8e-05	 0.001597	 0.12924	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18933	 81336	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18933	 81336	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18934	 81337	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18934	 81337	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18935	 18936	 0.005227	 0.024911	 0.00722	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18935	 19067	 0.008599	 0.039449	 0.01011	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18936	 18937	 0.007242	 0.028463	 0.00745	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18936	 81408	 0.012162	 0.047804	 0.01251	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18937	 18938	 0.006551	 0.025748	 0.00674	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18938	 18939	 0.004946	 0.019802	 0.00499	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18939	 19097	 0.01016	 0.046614	 0.01194	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18939	 81340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18939	 81340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81268	 18940	 0.072235	 0.19149	 0.00486	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18940	 81341	 0.045466	 0.18041	 0.00515	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18941	 81341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18941	 81341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18941	 81660	 0.03101	 0.2084	 0.05044	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18942	 18943	 0.032626	 0.074617	 0.00182	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81268	 18943	 0.054461	 0.17974	 0.00291	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79624	 18944	 0.06033	 0.14007	 0.00208	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18946	 18947	 0.013299	 0.054123	 0.01319	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79604	 18946	 0.005011	 0.019693	 0.00515	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18947	 18949	 0.015962	 0.054763	 0.01312	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18947	 81342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18947	 81342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18948	 18949	 0.009264	 0.023288	 0.00603	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18948	 18953	 0.009287	 0.024545	 0.00575	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18948	 19384	 0.011311	 0.062073	 0.01641	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79604	 18948	 0.025523	 0.061519	 0.01737	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79604	 18949	 0.019955	 0.052743	 0.01235	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18949	 81343	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18949	 81343	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81343	 18950	 0.099868	 0.16825	 0.0024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18951	 18959	 0.014045	 0.055722	 0.00159	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18951	 81344	 0.022692	 0.068301	 0.00134	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18952	 18959	 0.02649	 0.088371	 0.0014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18953	 81344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18953	 81344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18954	 81345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18954	 81345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81342	 18955	 0.21964	 0.15561	 0.00246	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81345	 18955	 0.041138	 0.095509	 0.00142	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18955	 81346	 0.070432	 0.085863	 0.00138	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81345	 18956	 0.013734	 0.084434	 0.00152	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18957	 19397	 0.032543	 0.025509	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18958	 19383	 0.00398	 0.010519	 0.00246	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18958	 81346	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18958	 81346	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18959	 19386	 0.013701	 0.042075	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81223	 18959	 0.51704	 0.40955	 0.00516	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18959	 81518	 0.062729	 0.049644	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18959	 81523	 0.008934	 0.047807	 0.00145	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18960	 81347	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18960	 81347	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18960	 81349	 0.004763	 0.030166	 0.00819	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18961	 81348	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18961	 81348	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18961	 81349	 0.011889	 0.031423	 0.00736	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18962	 18964	 0.000608	 0.007348	 0.03215	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18962	 81349	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18962	 81349	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81349	 18963	 0.003915	 0.022933	 0.00625	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18964	 81350	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18964	 81350	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18965	 18966	 0.008336	 0.028597	 0.00685	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79584	 18965	 0.007876	 0.12921	 0.04069	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18965	 81351	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18965	 81351	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18965	 81353	 0.004041	 0.020306	 0.00528	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18966	 81352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18966	 81352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18966	 81353	 0.0018	 0.007001	 0.00187	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81351	 18967	 0.071898	 0.19008	 0.00345	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81352	 18967	 0.016065	 0.0866	 0.00175	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18968	 18969	 0.00057	 0.00967	 0.03417	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18968	 81353	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18968	 81353	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18970	 18971	 0.00287	 0.009845	 0.00236	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18970	 19464	 0.002447	 0.016413	 0.00396	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18970	 81514	 0.000759	 0.006902	 0.00174	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18971	 19467	 0.003066	 0.010836	 0.00244	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18972	 81553	 0.024256	 0.043597	 0.00078	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18973	 18974	 0.11005	 0.11238	 0.00175	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18973	 19469	 0.04272	 0.035163	 0.00071	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79629	 18973	 0.024828	 0.033843	 0.00075	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18973	 81354	 0.1989	 0.15592	 0.002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18975	 19209	 0.01878	 0.093186	 0.00222	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	18975	 81354	 0.014665	 0.078135	 0.00137	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18976	 19210	 0.015556	 0.063311	 0.01543	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18976	 19638	 0.004193	 0.014614	 0.00339	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18976	 81354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18976	 81354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18977	 81362	 0.002076	 0.015171	 0.00028	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18978	 18980	 0.000955	 0.003631	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18978	 18990	 0.000731	 0.006272	 0.00178	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18978	 81355	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18978	 81355	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18978	 81360	 0.001225	 0.007759	 0.00211	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18979	 18981	 0.003886	 0.00902	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18979	 19007	 0.038063	 0.026962	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18979	 81356	 0.002035	 0.007124	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18980	 81356	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18980	 81356	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18980	 81360	 0.000572	 0.004045	 0.00111	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81355	 18981	 0.029044	 0.022985	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18982	 18992	 5.5e-05	 0.000712	 0.04546	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18982	 81357	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81358	 18982	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18983	 18986	 0.000451	 0.003332	 0.00096	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81358	 18983	 0.001174	 0.004778	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18983	 81359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18983	 81359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18984	 18985	 0.001132	 0.003337	 0.00078	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18984	 18987	 0.003646	 0.010168	 0.00213	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18984	 19018	 0.002002	 0.006866	 0.00164	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	18985	 18986	 0.000763	 0.002902	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18985	 19001	 0.001172	 0.004769	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18986	 19003	 0.000843	 0.004306	 0.00108	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18987	 19000	 0.002108	 0.007452	 0.00168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81130	 18988	 0.00086	 0.007881	 0.03111	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18988	 81360	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81361	 18988	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18988	 81364	 0.000168	 0.001996	 0.00788	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81361	 18989	 0.006157	 0.02054	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18989	 81363	 0.002645	 0.008115	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18990	 81362	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18990	 81362	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18990	 81365	 0.000568	 0.005832	 0.00184	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18991	 18993	 0.000173	 0.001534	 0.0065	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81357	 18991	 0.000479	 0.003297	 0.00582	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18991	 81363	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18991	 81363	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18991	 81364	 8.1e-05	 0.001286	 0.00264	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	18992	 81364	 0.000104	 0.008342	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81365	 18992	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18993	 18994	 0.000146	 0.001417	 0.00501	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18994	 18996	 0.000124	 0.001427	 0.00515	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	18995	 18997	 0.000935	 0.004699	 0.00122	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18995	 19004	 0.000949	 0.008928	 0.0027	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79580	 18995	 0.003388	 0.011621	 0.00278	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79579	 18996	 0.000127	 0.001909	 0.00685	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	18996	 81366	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18996	 81366	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79580	 18997	 0.002109	 0.008443	 0.00213	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18997	 81367	 0.001483	 0.005189	 0.00172	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18997	 81432	 0.004042	 0.026036	 0.00683	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	18998	 18999	 0.001855	 0.009971	 0.00245	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	18998	 19002	 0.001669	 0.008231	 0.00223	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	18998	 19183	 0.003088	 0.020687	 0.00634	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18998	 19186	 0.006342	 0.042546	 0.01027	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79580	 18998	 0.010388	 0.02697	 0.00655	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	18999	 19025	 0.0017	 0.007445	 0.00256	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81366	 19000	 0.003124	 0.010717	 0.00257	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19001	 19002	 0.000809	 0.003991	 0.00108	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19001	 19004	 0.004325	 0.011429	 0.00268	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19001	 19019	 0.001098	 0.004174	 0.00117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19003	 19004	 0.00087	 0.004773	 0.00126	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79579	 19005	 0.000559	 0.003729	 0.00703	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19005	 81367	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19005	 81367	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19006	 19010	 0.012668	 0.02277	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81359	 19006	 0.003962	 0.017455	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19007	 81369	 0.03061	 0.024224	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19008	 19014	 0.001374	 0.006301	 0.00161	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81358	 19008	 0.000563	 0.005968	 0.00177	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81360	 19008	 0.002032	 0.008599	 0.00193	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19008	 81368	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19008	 81368	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19009	 19010	 0.003514	 0.011597	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19009	 19016	 0.00538	 0.013943	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19010	 81370	 0.00322	 0.013161	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19011	 19027	 0.037718	 0.041486	 0.00055	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19011	 81373	 0.016149	 0.041069	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19012	 19013	 0.004121	 0.011693	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19012	 19028	 0.004418	 0.011358	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19012	 81369	 0.023096	 0.014952	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81186	 19013	 0.009419	 0.03142	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19013	 81369	 0.003588	 0.009222	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19014	 81369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19014	 81369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81368	 19015	 0.005412	 0.013911	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81369	 19015	 0.004651	 0.015347	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81368	 19016	 0.013936	 0.021744	 0.00036	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19017	 19018	 0.001313	 0.004503	 0.00108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19017	 19021	 0.001725	 0.004697	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19017	 81370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19017	 81370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19018	 19020	 0.001704	 0.004575	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19019	 19020	 0.001268	 0.005078	 0.00128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19020	 19021	 0.000991	 0.003856	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19021	 19024	 0.002345	 0.00939	 0.00237	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19022	 19493	 3.4e-05	 0.000538	 0.03938	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19022	 81371	 0.000118	 0.009419	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81372	 19022	 0.000243	 0.018209	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19023	 19024	 0.002808	 0.011426	 0.00278	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19023	 19494	 0.001874	 0.007123	 0.00199	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19024	 19025	 0.002148	 0.010238	 0.00297	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19024	 19030	 0.005487	 0.014105	 0.00349	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81372	 19024	 0.002269	 0.017	 0.00415	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19024	 81373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19024	 81373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19026	 19027	 0.022627	 0.016357	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19027	 19028	 0.003954	 0.012143	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81368	 19027	 0.063449	 0.050213	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81370	 19027	 0.006812	 0.030013	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19029	 19030	 0.002471	 0.006414	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19029	 19496	 0.001808	 0.007106	 0.00186	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19029	 81374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19029	 81374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19031	 19032	 0.10162	 0.080421	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19031	 81568	 0.040928	 0.06533	 0.0015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81373	 19032	 0.06736	 0.053309	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19033	 19490	 0.000642	 0.006167	 0.00179	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19033	 81375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19033	 81375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19033	 81378	 0.000589	 0.006317	 0.00202	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81375	 19034	 0.003921	 0.019131	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19034	 81376	 0.003195	 0.019644	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19035	 19045	 0.004883	 0.019869	 0.00484	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19035	 81376	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19035	 81376	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19035	 81378	 0.00244	 0.009274	 0.0026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19036	 19403	 0.00013	 0.003438	 0.28329	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19036	 19493	 5.4e-05	 0.000991	 0.0795	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19036	 81377	 9.1e-05	 0.007299	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19036	 81377	 9.1e-05	 0.007299	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19037	 19041	 0.00019	 0.002382	 0.0097	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81377	 19037	 0.000381	 0.003952	 0.00851	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81377	 19037	 0.000381	 0.003952	 0.00851	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19037	 81380	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19037	 81380	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19038	 19040	 0.004458	 0.01243	 0.00261	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19038	 19050	 0.000593	 0.004921	 0.00129	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81380	 19039	 0.010011	 0.028408	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19039	 81381	 0.022715	 0.017805	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81378	 19040	 0.000983	 0.011009	 0.0035	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19040	 81381	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19040	 81381	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19040	 81382	 0.000329	 0.003566	 0.00111	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19041	 19044	 0.000116	 0.001935	 0.00703	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19041	 81382	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19041	 81382	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81379	 19042	 0.048591	 0.038455	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81379	 19043	 0.010608	 0.028042	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19043	 81568	 0.015008	 0.025029	 0.00036	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19045	 19051	 0.005083	 0.017787	 0.00589	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81380	 19046	 0.056493	 0.036574	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19047	 19048	 0.000614	 0.004212	 0.00123	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19047	 19052	 0.001979	 0.008051	 0.00196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19047	 81383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19047	 81383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19048	 19049	 0.000309	 0.002284	 0.00066	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19049	 19050	 0.000665	 0.004857	 0.00143	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19051	 19053	 0.001018	 0.004074	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19052	 19053	 0.001313	 0.005341	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19054	 19057	 0.000763	 0.005295	 0.00151	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19054	 81384	 0.000403	 0.002416	 0.00073	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19055	 81384	 0.000605	 0.005191	 0.00148	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81371	 19056	 0.000436	 0.006517	 0.01524	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81377	 19056	 0.000376	 0.004012	 0.00816	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81377	 19056	 0.000376	 0.004012	 0.00816	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19056	 81384	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81385	 19056	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19057	 19497	 0.0006	 0.002701	 0.00072	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19058	 19498	 0.000849	 0.005826	 0.0017	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19059	 19066	 0.029318	 0.08409	 0.00129	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79636	 19059	 0.030221	 0.18979	 0.00415	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19060	 19062	 0.004061	 0.020405	 0.00531	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19060	 19063	 0.006899	 0.017343	 0.00449	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19060	 81386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19060	 81386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19061	 19062	 0.004258	 0.023364	 0.00618	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19061	 19065	 0.002867	 0.027531	 0.00801	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19062	 19259	 0.006145	 0.035306	 0.01	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79622	 19064	 0.1803	 0.1427	 0.0018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19065	 19674	 0.003714	 0.024914	 0.00601	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19065	 19676	 0.002083	 0.017287	 0.00455	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19065	 81387	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19065	 81387	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81387	 19066	 0.016136	 0.041479	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19067	 19068	 0.006066	 0.029603	 0.00818	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19067	 19230	 0.006793	 0.027198	 0.00685	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19069	 19244	 0.008342	 0.037562	 0.01	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79607	 19069	 0.019782	 0.15404	 0.04008	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19069	 81388	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19069	 81388	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81388	 19070	 0.043084	 0.14219	 0.0023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19071	 19767	 0.004716	 0.018534	 0.00485	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19072	 81655	 0.008718	 0.021637	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19073	 81389	 0.007463	 0.018979	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19074	 19744	 0.000817	 0.005018	 0.00183	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19074	 81389	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19074	 81389	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19075	 19757	 0.002381	 0.010923	 0.0028	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19075	 81390	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19075	 81390	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19076	 19770	 0.038862	 0.059524	 0.00103	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19076	 81661	 0.056395	 0.085535	 0.00123	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19077	 19770	 0.026772	 0.063396	 0.00116	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19078	 81662	 0.064882	 0.11707	 0.00169	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19079	 19080	 0.013993	 0.023337	 0.00034	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19079	 81662	 0.016216	 0.041684	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19080	 19081	 0.005867	 0.01555	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19080	 81654	 0.00766	 0.01778	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19081	 19765	 0.010029	 0.025781	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19081	 81391	 0.017889	 0.023511	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19082	 19755	 0.004618	 0.014361	 0.003	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19082	 81391	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19082	 81391	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81391	 19083	 0.02719	 0.04887	 0.00088	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19084	 19762	 0.0025	 0.010321	 0.00244	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19085	 19748	 0.001595	 0.006204	 0.00166	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19086	 19087	 0.010086	 0.025928	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19086	 81650	 0.005466	 0.012397	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81050	 19087	 0.035809	 0.064613	 0.00093	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19088	 19747	 0.001418	 0.007389	 0.00194	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19089	 19090	 0.009871	 0.046724	 0.01124	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19089	 19322	 0.004029	 0.031401	 0.00939	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81006	 19090	 0.007096	 0.06955	 0.02179	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81046	 19090	 0.008074	 0.069262	 0.01972	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19091	 19470	 0.006814	 0.027728	 0.00676	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81006	 19091	 0.011214	 0.052304	 0.01296	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19092	 19322	 0.009027	 0.036733	 0.00895	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19093	 81392	 0.051874	 0.041052	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19094	 19095	 0.004649	 0.018613	 0.00469	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81216	 19094	 0.00966	 0.039884	 0.00944	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19094	 81392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19094	 81392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19095	 19110	 0.005411	 0.022902	 0.00515	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19096	 81394	 0.096289	 0.076204	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19097	 19452	 0.003449	 0.015111	 0.0052	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19098	 19099	 0.004661	 0.018131	 0.00484	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19098	 19462	 0.004518	 0.019122	 0.0043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19098	 81393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19098	 81393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19099	 19100	 0.00648	 0.027428	 0.00617	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19099	 19132	 0.009898	 0.059413	 0.01799	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19099	 81395	 0.005735	 0.036942	 0.00968	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19100	 81394	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19100	 81394	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19100	 81740	 0.042828	 0.10772	 0.02792	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19101	 19126	 0.19809	 0.18579	 0.00287	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81394	 19101	 0.036362	 0.071994	 0.00106	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19102	 81396	 0.12387	 0.17265	 0.00295	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19102	 81821	 0.17489	 0.35814	 0.00882	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19103	 19460	 0.002522	 0.016824	 0.03171	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19103	 20272	 0.001481	 0.0176	 0.03517	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19103	 81395	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81396	 19103	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81041	 19104	 0.05586	 0.1436	 0.00222	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81396	 19104	 0.052666	 0.084067	 0.00194	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81395	 19105	 0.00946	 0.039061	 0.00924	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19105	 81550	 0.002231	 0.008768	 0.00229	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19106	 19454	 0.002496	 0.015511	 0.00438	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19106	 81397	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19106	 81397	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81042	 19107	 0.040644	 0.10448	 0.00162	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81397	 19107	 0.018929	 0.028997	 0.00041	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19108	 19109	 0.003532	 0.015372	 0.00438	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19109	 81398	 0.006297	 0.025209	 0.00635	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19110	 19456	 0.004736	 0.022984	 0.00525	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19111	 81398	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19111	 81398	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19112	 19116	 0.009728	 0.035226	 0.00756	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19112	 81399	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19112	 81399	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79588	 19113	 0.001673	 0.014826	 0.00395	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19113	 81400	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19113	 81400	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19113	 81403	 0.005337	 0.029775	 0.00761	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19114	 19232	 0.012921	 0.050272	 0.01343	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19114	 81401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19114	 81401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19114	 81403	 0.007323	 0.025123	 0.00602	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19115	 19141	 0.024504	 0.10122	 0.02396	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79588	 19115	 0.001785	 0.030593	 0.00879	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19115	 81402	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19115	 81402	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19116	 19239	 0.015965	 0.057814	 0.01241	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81399	 19117	 0.026244	 0.1021	 0.0017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81400	 19117	 0.025938	 0.11558	 0.00196	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79587	 19118	 0.00088	 0.005713	 0.01138	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19118	 81403	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19118	 81403	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19118	 81457	 0.004803	 0.032039	 0.06041	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19119	 81404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19119	 81404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19119	 81608	 0.024198	 0.083031	 0.0199	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81404	 19120	 0.048722	 0.17407	 0.00346	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81404	 19120	 0.048722	 0.17407	 0.00346	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19121	 19122	 0.12914	 0.11896	 0.00191	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19121	 81609	 0.05474	 0.15701	 0.00241	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81404	 19122	 0.064973	 0.15085	 0.00224	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19122	 81492	 0.18475	 0.36595	 0.00537	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81401	 19123	 0.20679	 0.22528	 0.00307	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81404	 19124	 0.047096	 0.050178	 0.00072	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19125	 81405	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19125	 81405	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19125	 81407	 0.001698	 0.017611	 0.03793	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19125	 81407	 0.001698	 0.017611	 0.03793	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19125	 81739	 0.002832	 0.028227	 0.09425	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19126	 81741	 0.28846	 0.22835	 0.00288	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19127	 81406	 0.044107	 0.080787	 0.00139	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19128	 19225	 0.005868	 0.035218	 0.01067	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19128	 81406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19128	 81406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19128	 81408	 0.003719	 0.024319	 0.00618	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81406	 19129	 0.058496	 0.11582	 0.0017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19129	 81409	 0.036746	 0.093452	 0.00148	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19130	 20026	 0.000171	 0.004217	 0.31075	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19130	 81407	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19130	 81407	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81409	 19131	 0.011141	 0.076476	 0.00139	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19131	 81410	 0.011545	 0.089985	 0.00168	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19132	 81410	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19132	 81410	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19132	 81740	 0.029507	 0.079237	 0.01796	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81340	 19133	 0.11852	 0.19798	 0.00336	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81410	 19133	 0.046986	 0.089984	 0.00142	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19134	 19135	 0.012161	 0.04949	 0.01206	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19134	 19137	 0.007529	 0.019897	 0.00466	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19134	 19218	 0.013553	 0.05273	 0.01409	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19135	 81411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19135	 81411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81411	 19136	 0.063652	 0.14624	 0.00222	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19136	 81414	 0.018944	 0.048697	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19137	 19140	 0.007479	 0.019765	 0.00463	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19137	 81412	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19137	 81412	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19138	 19139	 0.006176	 0.021188	 0.00508	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19138	 19261	 0.015737	 0.041594	 0.00974	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19139	 19140	 0.009416	 0.024447	 0.00593	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19139	 81413	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19139	 81413	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19139	 81463	 0.027618	 0.06657	 0.0188	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19141	 81414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19141	 81414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81414	 19142	 0.077722	 0.11788	 0.00169	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19143	 19211	 0.008761	 0.034435	 0.00901	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19143	 19409	 0.007165	 0.045384	 0.01232	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19143	 81415	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19143	 81415	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19144	 19147	 0.016241	 0.043606	 0.00988	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19144	 19208	 0.016496	 0.066056	 0.01664	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19144	 19399	 0.014421	 0.057744	 0.01455	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19144	 81416	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19144	 81416	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81416	 19145	 0.048615	 0.035768	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19146	 19409	 0.003657	 0.012544	 0.00301	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19146	 81417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19146	 81417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19148	 19156	 0.0045	 0.015435	 0.0037	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19148	 19176	 0.003634	 0.021282	 0.0058	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19148	 81418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19148	 81418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19149	 19150	 0.003688	 0.018852	 0.00514	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19149	 81419	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19149	 81419	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19150	 19155	 0.001168	 0.009322	 0.0023	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19150	 81440	 0.001045	 0.013148	 0.00407	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19151	 19414	 2.8e-05	 0.00042	 0.02701	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19151	 81420	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19151	 81420	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19152	 19164	 0.000523	 0.00578	 0.00173	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19152	 19416	 0.000652	 0.005967	 0.00239	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19153	 19154	 0.010672	 0.013771	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19153	 81423	 0.047585	 0.037299	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19154	 81421	 0.009744	 0.015553	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19155	 19156	 0.000839	 0.002922	 0.00068	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19155	 19158	 0.001758	 0.005924	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81418	 19157	 0.026077	 0.04687	 0.00084	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19157	 81421	 0.047022	 0.045433	 0.00066	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19158	 19169	 0.002854	 0.011612	 0.00283	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19158	 81421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19158	 81421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19159	 19161	 0.002121	 0.008759	 0.00207	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19159	 81422	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19159	 81422	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19160	 81426	 0.003125	 0.017224	 0.00403	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19160	 81533	 0.001635	 0.007361	 0.00196	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19161	 19162	 0.001629	 0.006403	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19162	 81425	 0.001393	 0.005294	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19163	 81427	 0.056293	 0.057482	 0.0009	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19164	 81423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19164	 81423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19164	 81425	 0.000614	 0.005017	 0.00136	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19164	 81426	 0.001234	 0.011844	 0.00345	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19165	 19166	 2.6e-05	 0.00049	 0.03232	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19165	 19414	 4.8e-05	 0.000895	 0.0591	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19165	 81424	 0.000104	 0.008342	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81425	 19165	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19166	 81426	 0.000173	 0.013839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19167	 19168	 0.005598	 0.011457	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81423	 19167	 0.008451	 0.020013	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81427	 19168	 0.01781	 0.049334	 0.00081	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19168	 81428	 0.01222	 0.023949	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81426	 19169	 0.001757	 0.006904	 0.00181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19169	 81428	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19169	 81428	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19170	 19171	 0.004203	 0.017104	 0.00417	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81426	 19170	 0.002685	 0.011087	 0.00262	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79594	 19171	 0.006182	 0.024751	 0.00624	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19172	 19173	 0.000444	 0.005268	 0.01794	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79593	 19172	 0.000721	 0.008417	 0.01744	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81424	 19172	 0.00166	 0.013829	 0.04314	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79577	 19173	 0.00045	 0.005005	 0.01938	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19174	 19176	 0.006672	 0.034757	 0.00912	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79578	 19174	 0.004758	 0.028777	 0.00734	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81339	 19175	 0.1318	 0.43991	 0.00698	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19175	 81429	 0.030745	 0.079034	 0.00122	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19176	 19177	 0.007586	 0.020655	 0.00455	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19176	 81429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19176	 81429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19178	 81436	 0.016025	 0.031407	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19178	 81438	 0.004786	 0.01862	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19179	 19180	 0.000227	 0.003476	 0.01214	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19179	 19181	 0.000253	 0.002966	 0.01196	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19179	 19190	 0.000655	 0.004595	 0.00782	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19179	 81430	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19179	 81430	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81420	 19180	 0.001157	 0.011531	 0.03848	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19180	 81431	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19180	 81431	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79579	 19181	 0.000754	 0.007405	 0.02539	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19181	 81432	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19181	 81432	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19182	 81436	 0.028992	 0.028012	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19183	 19184	 0.002193	 0.021052	 0.00612	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19183	 81435	 0.004822	 0.017461	 0.00375	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19184	 19186	 0.004198	 0.014145	 0.00352	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19185	 19190	 0.000453	 0.004516	 0.01507	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19185	 19195	 0.000599	 0.006781	 0.0253	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19185	 81433	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19185	 81433	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19186	 19187	 0.003336	 0.009082	 0.002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19186	 81440	 0.005136	 0.031917	 0.00901	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19187	 19191	 0.00208	 0.0065	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81433	 19187	 0.003127	 0.015711	 0.00409	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19187	 81434	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19187	 81434	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19188	 19190	 0.000218	 0.002414	 0.00559	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79579	 19188	 0.000552	 0.007489	 0.0334	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79596	 19188	 0.002231	 0.021923	 0.0752	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19188	 81435	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81436	 19188	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81430	 19189	 0.003752	 0.011667	 0.00243	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81433	 19189	 0.00108	 0.011107	 0.00315	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19189	 81437	 0.001515	 0.006065	 0.00153	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19190	 81437	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81438	 19190	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81437	 19191	 0.001152	 0.003844	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19191	 81439	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19191	 81439	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19192	 19193	 0.012838	 0.012841	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81438	 19192	 0.039517	 0.031273	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81434	 19193	 0.00591	 0.016951	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81439	 19193	 0.028206	 0.01998	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19194	 81441	 0.063988	 0.097052	 0.00139	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81420	 19195	 0.000804	 0.007373	 0.0291	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19195	 81440	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81441	 19195	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19196	 19197	 0.001514	 0.011249	 0.00429	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19196	 19412	 0.001296	 0.013203	 0.0034	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81433	 19197	 0.001388	 0.01134	 0.00308	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19198	 19199	 0.011219	 0.028839	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81438	 19198	 0.036017	 0.12015	 0.0019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19199	 81442	 0.009685	 0.02679	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19200	 19201	 0.000263	 0.003748	 0.00125	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81431	 19200	 0.002017	 0.014591	 0.00785	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19201	 19411	 0.000327	 0.004957	 0.00183	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19201	 81442	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19201	 81442	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19202	 19415	 0.009685	 0.032309	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81442	 19202	 0.014414	 0.023007	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19203	 19204	 0.00286	 0.014369	 0.00374	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81431	 19203	 0.002788	 0.014522	 0.00381	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19205	 19206	 0.064155	 0.12574	 0.00188	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79629	 19206	 0.55783	 0.44193	 0.00556	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81415	 19206	 0.078724	 0.26267	 0.00416	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19206	 81444	 0.079485	 0.15739	 0.00231	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19208	 19399	 0.014795	 0.09678	 0.02462	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19208	 81443	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19208	 81443	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81443	 19209	 0.020955	 0.11912	 0.00216	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19210	 19211	 0.006752	 0.027879	 0.0066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19210	 81444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19210	 81444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19212	 19213	 0.006464	 0.017084	 0.004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19212	 19219	 0.007772	 0.01998	 0.00495	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19212	 20148	 0.008872	 0.023034	 0.00559	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19213	 19222	 0.010656	 0.028162	 0.00659	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79614	 19213	 0.042258	 0.10869	 0.02693	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19213	 81445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19213	 81445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19214	 19215	 0.021432	 0.13177	 0.00238	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19214	 81785	 0.059925	 0.10976	 0.00189	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19214	 81786	 0.055983	 0.21782	 0.00364	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81400	 19215	 0.12946	 0.43208	 0.00685	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19215	 81446	 0.026396	 0.069962	 0.00177	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81399	 19216	 0.012637	 0.071833	 0.0013	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19216	 81446	 0.007825	 0.044479	 0.0008	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19217	 19221	 0.033189	 0.11338	 0.00247	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81411	 19217	 0.086842	 0.1567	 0.00227	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19218	 19222	 0.005019	 0.021845	 0.00622	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19219	 19222	 0.004264	 0.011889	 0.0025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19220	 81446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19220	 81446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79635	 19221	 0.076985	 0.19792	 0.00306	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81399	 19221	 0.024282	 0.1185	 0.00205	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19223	 19224	 0.010443	 0.028432	 0.00626	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19223	 19228	 0.002846	 0.017659	 0.00428	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81405	 19224	 0.004628	 0.042096	 0.01063	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19224	 81447	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19224	 81447	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19225	 19226	 0.002728	 0.016951	 0.00478	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19225	 19230	 0.006393	 0.0243	 0.0068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81405	 19225	 0.009513	 0.033627	 0.00758	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19226	 19227	 0.000527	 0.003532	 0.00085	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19227	 19228	 0.001334	 0.007664	 0.00217	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19227	 81448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19227	 81448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81317	 19229	 0.14783	 0.48819	 0.00792	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81447	 19229	 0.072228	 0.12983	 0.00233	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81448	 19229	 0.089278	 0.0578	 0.0011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19231	 19234	 0.004121	 0.016499	 0.00416	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79630	 19231	 0.000805	 0.00627	 0.00187	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19232	 81491	 0.002533	 0.010721	 0.00241	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19233	 19235	 0.005514	 0.018578	 0.00462	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81403	 19233	 0.013744	 0.048586	 0.01095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80305	 19234	 0.022081	 0.13713	 0.03325	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19234	 81449	 0.001816	 0.018504	 0.00477	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19235	 81449	 0.004502	 0.015019	 0.00381	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19236	 19238	 0.022604	 0.074596	 0.00121	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79631	 19236	 0.023588	 0.12266	 0.00266	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81401	 19236	 0.3349	 0.33843	 0.00448	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19236	 81450	 0.004959	 0.01929	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19237	 19243	 0.000111	 0.001428	 0.10709	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19237	 19260	 0.000601	 0.011143	 0.73716	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19237	 81449	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19238	 19242	 0.036646	 0.093199	 0.00147	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80304	 19238	 0.29887	 0.58637	 0.0088	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81450	 19238	 0.0105	 0.053426	 0.00121	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19239	 81451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19239	 81451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81411	 19240	 0.014706	 0.10749	 0.00198	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81450	 19240	 0.018745	 0.17453	 0.00338	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19241	 19242	 0.13421	 0.10622	 0.00134	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19243	 81452	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19243	 81452	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19244	 81453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19244	 81453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81388	 19245	 0.029617	 0.15402	 0.00334	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19245	 81454	 0.068456	 0.12729	 0.00298	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19246	 81454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19246	 81454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19246	 81455	 0.003948	 0.025005	 0.00679	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79482	 19247	 0.000962	 0.009936	 0.03084	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19247	 81455	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81456	 19247	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19248	 19249	 0.12084	 0.095635	 0.0012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19248	 81459	 0.037816	 0.11614	 0.00218	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19250	 81457	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19251	 19252	 0.054635	 0.12685	 0.00189	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81459	 19251	 0.019001	 0.092725	 0.0016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19251	 81609	 0.036416	 0.078039	 0.00137	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19253	 81460	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19253	 81460	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19253	 81608	 0.006446	 0.042153	 0.01072	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19254	 81609	 0.053212	 0.10536	 0.00155	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81458	 19255	 0.003543	 0.014417	 0.00351	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19255	 81461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19255	 81461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19256	 19257	 0.018861	 0.062919	 0.001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81461	 19256	 0.007562	 0.051909	 0.00095	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19257	 19258	 0.030114	 0.064534	 0.00113	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79589	 19258	 0.04219	 0.14075	 0.00223	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81402	 19258	 0.051584	 0.19768	 0.00559	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19259	 81462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19259	 81462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19259	 81463	 0.005428	 0.052117	 0.01516	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19260	 19417	 0.000266	 0.006563	 0.48386	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19260	 81463	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19260	 81463	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81463	 19261	 0.004573	 0.019356	 0.00436	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19261	 81464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19261	 81464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19262	 19263	 0.043297	 0.13943	 0.00238	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81464	 19262	 0.035925	 0.073519	 0.00181	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81462	 19263	 0.028927	 0.14468	 0.00258	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81464	 19263	 0.032825	 0.14628	 0.00248	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81462	 19264	 0.086497	 0.15608	 0.00226	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19265	 19266	 0.002474	 0.006641	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19265	 19267	 0.002747	 0.00748	 0.00165	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19265	 81582	 0.001933	 0.006763	 0.00224	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19266	 19268	 0.001343	 0.004042	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19266	 19430	 0.003034	 0.008787	 0.00212	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19267	 19268	 0.001895	 0.005703	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19267	 19270	 0.002328	 0.009851	 0.00222	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19268	 19641	 0.00163	 0.007477	 0.00192	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19269	 19270	 0.001345	 0.005474	 0.00133	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79590	 19269	 0.003995	 0.013461	 0.00335	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19269	 81466	 0.004023	 0.010341	 0.00256	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19271	 19528	 0.003042	 0.007821	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19271	 19537	 0.001716	 0.004534	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19272	 19538	 0.002173	 0.005586	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19272	 81465	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19272	 81465	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19272	 81466	 0.002947	 0.01217	 0.00288	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19273	 81466	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81467	 19273	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81467	 19274	 0.023498	 0.018419	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19275	 19276	 0.005006	 0.020372	 0.00496	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79590	 19275	 0.000872	 0.01233	 0.00408	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19276	 19278	 0.003839	 0.01625	 0.00366	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19276	 81468	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19276	 81468	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81275	 19277	 0.003693	 0.020334	 0.00734	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19277	 81469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19277	 81469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19278	 19911	 0.004655	 0.016222	 0.00376	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19278	 81470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19278	 81470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19279	 19280	 0.000605	 0.003478	 0.00099	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19280	 19293	 0.000468	 0.002685	 0.00089	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19280	 81471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19280	 81471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19281	 19282	 0.000359	 0.002311	 0.00061	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19281	 81475	 0.000575	 0.003535	 0.00102	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19282	 19283	 0.000256	 0.001469	 0.00042	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19282	 19284	 0.000263	 0.002102	 0.00052	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19282	 19287	 0.000305	 0.00168	 0.00061	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19283	 81472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19283	 81472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19284	 81473	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19284	 81473	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19285	 81474	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19285	 81474	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19285	 81475	 0.00076	 0.006392	 0.00189	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19286	 19295	 0.005956	 0.010033	 0.00014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19286	 19300	 0.020943	 0.016574	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19287	 19288	 0.000233	 0.001646	 0.00045	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19288	 81475	 0.000308	 0.002277	 0.00066	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19289	 19292	 1e-05	 0.00014	 0.0106	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19289	 81475	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19290	 19296	 0.00071	 0.005024	 0.00138	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19290	 81477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19290	 81477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19290	 81479	 0.000537	 0.00215	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81477	 19291	 0.010189	 0.007496	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19292	 81478	 9.9e-05	 0.007891	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81475	 19293	 0.000175	 0.0022	 0.00068	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81479	 19293	 9.8e-05	 0.000955	 0.00063	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19293	 81481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19293	 81481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81480	 19294	 0.003388	 0.009615	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81481	 19294	 0.002902	 0.005688	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81476	 19295	 0.005691	 0.016321	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19295	 81482	 0.003215	 0.010609	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19296	 19302	 0.001916	 0.007281	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19296	 81482	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19296	 81482	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19297	 19301	 0.001858	 0.00723	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81482	 19297	 0.002745	 0.015422	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19298	 81483	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19298	 81483	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81483	 19299	 0.008368	 0.011879	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19301	 19310	 0.004088	 0.011726	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19302	 19307	 0.00121	 0.005123	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19303	 81484	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19303	 81484	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19304	 19305	 0.004801	 0.009409	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81484	 19304	 0.003204	 0.008236	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19305	 19308	 0.018696	 0.014655	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19305	 81486	 0.009684	 0.007664	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19306	 19307	 0.000614	 0.002457	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19306	 81485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19306	 81485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19307	 19312	 0.001279	 0.003588	 0.00092	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19307	 81486	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19307	 81486	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19308	 19309	 0.002618	 0.006498	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19308	 81487	 0.004804	 0.008668	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19309	 19310	 0.00384	 0.009766	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19311	 19314	 0.003915	 0.00717	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19311	 81487	 0.022471	 0.017783	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81479	 19312	 0.002976	 0.01786	 0.00541	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19312	 81487	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19312	 81487	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19313	 19314	 0.0111	 0.007186	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19314	 19315	 0.003155	 0.007471	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81483	 19314	 0.006537	 0.013435	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19315	 19316	 0.003598	 0.00925	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19317	 19485	 0.000269	 0.004981	 0.32895	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19317	 81488	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19318	 81491	 0.001442	 0.007368	 0.00201	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19319	 81491	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81492	 19319	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19320	 19321	 0.040634	 0.044693	 0.0006	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81492	 19320	 0.008816	 0.022663	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79631	 19321	 0.013369	 0.041057	 0.00077	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19322	 19470	 0.006067	 0.024689	 0.00602	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79583	 19322	 0.059079	 0.17441	 0.04064	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19323	 81493	 0.002584	 0.00862	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19323	 81494	 0.011486	 0.02414	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19323	 81497	 0.005336	 0.011971	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19324	 81493	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19324	 81493	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19324	 81496	 0.001326	 0.003802	 0.00094	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19325	 81494	 0.008702	 0.020202	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19325	 81497	 0.005885	 0.015128	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19326	 19327	 0.004485	 0.012864	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19326	 19328	 0.002655	 0.008152	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81002	 19327	 0.007253	 0.043459	 0.00105	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19327	 81497	 0.002995	 0.017026	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81493	 19328	 0.005156	 0.009586	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81493	 19330	 0.006453	 0.016587	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81493	 19331	 0.006189	 0.011507	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19332	 81496	 0.002097	 0.006839	 0.00182	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19333	 81494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19333	 81494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19333	 81496	 0.001782	 0.005336	 0.0012	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19334	 81495	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19334	 81495	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19335	 81498	 0.019696	 0.015587	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19336	 19337	 0.001011	 0.004047	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19336	 19597	 0.000945	 0.003785	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19336	 81498	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19336	 81498	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19337	 19347	 0.002708	 0.010842	 0.00273	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19337	 81499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19337	 81499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19338	 19339	 0.008559	 0.011249	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19338	 81505	 0.023961	 0.01838	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19339	 81500	 0.004423	 0.011464	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19340	 19341	 0.000778	 0.003025	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19340	 81598	 0.000938	 0.003873	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19341	 19342	 0.000854	 0.005002	 0.00136	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19341	 81500	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19341	 81500	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19341	 81598	 0.001196	 0.006775	 0.00168	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79605	 19342	 0.000902	 0.006761	 0.00165	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19342	 81501	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19342	 81501	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81501	 19343	 0.014836	 0.01488	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19344	 19349	 0.000623	 0.004843	 0.00126	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19344	 19353	 0.000455	 0.003586	 0.00105	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19344	 81502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19344	 81502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19345	 19348	 0.058606	 0.042366	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19345	 81509	 0.029011	 0.044	 0.00063	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19346	 19596	 7e-05	 0.001258	 0.08928	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19346	 81503	 0.000135	 0.010812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19347	 19896	 0.001371	 0.005579	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81503	 19347	 0.000587	 0.005334	 0.00174	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81504	 19348	 0.008926	 0.018266	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19349	 19350	 0.000661	 0.003967	 0.0012	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19349	 19610	 0.00425	 0.014811	 0.00343	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19349	 81505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19349	 81505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19350	 19888	 0.002458	 0.011928	 0.00273	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19350	 81506	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19350	 81506	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19351	 19353	 0.000468	 0.003669	 0.00168	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79602	 19351	 0.000235	 0.003824	 0.00108	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19352	 19354	 0.001567	 0.005676	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19352	 19356	 0.001617	 0.005549	 0.00133	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79605	 19352	 0.001392	 0.011294	 0.0036	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19352	 81507	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19352	 81507	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81503	 19353	 0.001014	 0.005157	 0.00187	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19354	 19363	 0.005981	 0.015035	 0.0039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81503	 19354	 0.001263	 0.005055	 0.00127	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19355	 19357	 0.053444	 0.0346	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19355	 19358	 0.038692	 0.02797	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19355	 19365	 0.032912	 0.052534	 0.00121	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81507	 19355	 0.099968	 0.097817	 0.00138	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19356	 81508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19356	 81508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19357	 19360	 0.0422	 0.030506	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19357	 19365	 0.060003	 0.064078	 0.00135	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81508	 19357	 0.069949	 0.055357	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19359	 19360	 0.016688	 0.010804	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81508	 19359	 0.011408	 0.020063	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81508	 19360	 0.032038	 0.035238	 0.00047	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19361	 81509	 0.014576	 0.022328	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19362	 81509	 0.037114	 0.024027	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19363	 81509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19363	 81509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19364	 19903	 0.16756	 0.13136	 0.00169	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80427	 19364	 0.044644	 0.13711	 0.00257	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81504	 19364	 0.17726	 0.17906	 0.00237	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80798	 19365	 0.097014	 0.29209	 0.00571	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19366	 19368	 0.004405	 0.014694	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19366	 81511	 0.012626	 0.032456	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79603	 19367	 0.064925	 0.051381	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80805	 19367	 0.17482	 0.58376	 0.00926	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19367	 81510	 0.019211	 0.034314	 0.00051	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19368	 81510	 0.010704	 0.027517	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79605	 19369	 0.001687	 0.004974	 0.00116	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19369	 81510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19369	 81510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19370	 19658	 0.004585	 0.020433	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19370	 19660	 0.004447	 0.022627	 0.00051	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79603	 19370	 0.003352	 0.019056	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79606	 19370	 0.001219	 0.011941	 0.00023	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81510	 19370	 0.007168	 0.022013	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19371	 19662	 0.001105	 0.004423	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79605	 19371	 0.002123	 0.01424	 0.00344	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19371	 81511	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19371	 81511	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19372	 81512	 0.013166	 0.033484	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19373	 19665	 0.002588	 0.009021	 0.00209	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19373	 19796	 0.008644	 0.022845	 0.00535	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19373	 19799	 0.013291	 0.052243	 0.01367	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19373	 81512	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19373	 81512	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19373	 81571	 0.016635	 0.043966	 0.01029	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19374	 19645	 0.016372	 0.046956	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19374	 81513	 0.025085	 0.019852	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19375	 19782	 0.002986	 0.008017	 0.00182	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19375	 81513	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19375	 81513	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19376	 81514	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81515	 19376	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19377	 19378	 0.001278	 0.007622	 0.00021	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19377	 19380	 0.007914	 0.024304	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81515	 19377	 0.00386	 0.021687	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81514	 19379	 0.003486	 0.009051	 0.0022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19379	 81516	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 1.0	 1	 -30.0	 30.0;
	19379	 81516	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 1.0	 1	 -30.0	 30.0;
	79629	 19380	 0.039263	 0.13098	 0.00208	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81516	 19380	 0.005534	 0.009229	 0.00013	 49.0	 49.0	 49.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79627	 19381	 0.005102	 0.012487	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79639	 19381	 0.02076	 0.080763	 0.00135	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19381	 81517	 0.009346	 0.030095	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79638	 19382	 0.002618	 0.021036	 0.00591	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81051	 19382	 0.011929	 0.041743	 0.01383	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19382	 81517	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19382	 81517	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19383	 81518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19383	 81518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19384	 19385	 0.001134	 0.003952	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19384	 19389	 0.003805	 0.010214	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19384	 19390	 0.002225	 0.009418	 0.00212	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19384	 81519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19384	 81519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19385	 19396	 0.001347	 0.006883	 0.00188	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19385	 81520	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19385	 81520	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19386	 19387	 0.027466	 0.036098	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81520	 19386	 0.003315	 0.014606	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19387	 19388	 0.004769	 0.010182	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19387	 19393	 0.024302	 0.019232	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19388	 81521	 0.006287	 0.016618	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19389	 81521	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19389	 81521	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19390	 19391	 0.002321	 0.009029	 0.00241	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19390	 81522	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19390	 81522	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19392	 19394	 0.002979	 0.020449	 0.00037	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81521	 19392	 0.003429	 0.015281	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80363	 19394	 0.009326	 0.056676	 0.00105	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19395	 19396	 0.001208	 0.006628	 0.00175	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19395	 81523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19395	 81523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81522	 19397	 0.021805	 0.039938	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81523	 19398	 0.02994	 0.023694	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19399	 81524	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19399	 81524	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81219	 19400	 0.051443	 0.094225	 0.00163	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81524	 19400	 0.008174	 0.021011	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19401	 19402	 0.001509	 0.005177	 0.00124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19401	 81525	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19401	 81525	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19402	 81526	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19402	 81526	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19402	 81527	 0.000374	 0.003592	 0.00104	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19403	 81527	 0.00016	 0.012814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81525	 19404	 0.005974	 0.013725	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19406	 19407	 0.000589	 0.002494	 0.00056	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19406	 19408	 0.001303	 0.004541	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19406	 81529	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19406	 81529	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81137	 19408	 0.002639	 0.010568	 0.00266	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19408	 81530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19408	 81530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19411	 81532	 0.000131	 0.001316	 0.00081	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19411	 81533	 0.000317	 0.003833	 0.00217	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19412	 19416	 0.000494	 0.004482	 0.00146	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19412	 81531	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19412	 81531	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19412	 81532	 0.000423	 0.002931	 0.00084	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19413	 19414	 1e-05	 0.000282	 0.02115	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19413	 81532	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19413	 81532	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19414	 81533	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81534	 19415	 0.005021	 0.016571	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19417	 81535	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81536	 19418	 0.007714	 0.022124	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19419	 19438	 0.001075	 0.00455	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19419	 19642	 0.002808	 0.016449	 0.00448	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19419	 81537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19419	 81537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19420	 19441	 0.002529	 0.011267	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81537	 19420	 0.014707	 0.028824	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19421	 81538	 0.010168	 0.026138	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19421	 81612	 0.024475	 0.040654	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19422	 81538	 0.02306	 0.025363	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19422	 81583	 0.045269	 0.059498	 0.00082	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19423	 19429	 0.000881	 0.004345	 0.00117	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19423	 19430	 0.001165	 0.005929	 0.00215	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19423	 19436	 0.001889	 0.004386	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19424	 19428	 0.001732	 0.00594	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19424	 19517	 0.002493	 0.006461	 0.00195	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19425	 19426	 0.001336	 0.003637	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19425	 81572	 0.001342	 0.003742	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19426	 19428	 0.000999	 0.003427	 0.00082	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19426	 19431	 0.001112	 0.003815	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19427	 19428	 0.000776	 0.002015	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19427	 19429	 0.002019	 0.005335	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19427	 19431	 0.001932	 0.006734	 0.00156	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19429	 81541	 0.001194	 0.008516	 0.00264	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19430	 81538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19430	 81538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19431	 81539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19431	 81539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19431	 81541	 0.000435	 0.004315	 0.00132	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19432	 19596	 0.000281	 0.003355	 0.2517	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19432	 81540	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19433	 19435	 0.00143	 0.005727	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81541	 19433	 0.001575	 0.006307	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19434	 19435	 0.001206	 0.003186	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19434	 19440	 0.002558	 0.007132	 0.0015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19434	 19447	 0.001355	 0.004906	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19434	 81543	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19434	 81543	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19435	 19436	 0.000698	 0.003203	 0.00082	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19436	 19437	 0.000641	 0.002943	 0.00075	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19436	 19447	 0.003033	 0.010119	 0.00257	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19437	 19438	 0.000905	 0.003555	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19438	 81544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19438	 81544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19439	 19441	 0.037847	 0.028674	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81543	 19439	 0.004208	 0.020209	 0.00039	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81544	 19439	 0.011858	 0.023478	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19440	 19444	 0.001134	 0.002944	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19440	 81545	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19440	 81545	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19441	 19443	 0.002641	 0.011571	 0.00025	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19442	 19443	 0.011881	 0.023524	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19442	 19552	 0.017695	 0.059031	 0.00094	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19442	 81546	 0.026119	 0.016909	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81545	 19443	 0.00318	 0.012234	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19444	 81546	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19444	 81546	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81543	 19445	 0.010704	 0.014918	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81546	 19445	 0.015416	 0.0122	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19446	 81547	 0.01025	 0.01028	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19447	 19448	 0.000655	 0.002137	 0.00057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19447	 81591	 0.004623	 0.024486	 0.00621	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81541	 19448	 0.001559	 0.007021	 0.00187	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19448	 81547	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19448	 81547	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81542	 19449	 0.013539	 0.013578	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19450	 19505	 0.021645	 0.023061	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19450	 19507	 0.03291	 0.02379	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81542	 19450	 0.004122	 0.018367	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81537	 19451	 0.02665	 0.029028	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19452	 19455	 0.000895	 0.003584	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19452	 19462	 0.001101	 0.004407	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19453	 81548	 0.008595	 0.022094	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19454	 81550	 0.00118	 0.005137	 0.00146	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19455	 19458	 0.001313	 0.004595	 0.00152	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19456	 19458	 0.001456	 0.003847	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19456	 81548	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19456	 81548	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19456	 81550	 0.002274	 0.009627	 0.00217	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81548	 19457	 0.01322	 0.02167	 0.00038	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19457	 81549	 0.005586	 0.01197	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19457	 81551	 0.005618	 0.021613	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19458	 81549	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19458	 81549	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19458	 81550	 0.000595	 0.005189	 0.00143	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19459	 81551	 0.004138	 0.016913	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19459	 81552	 0.007973	 0.026596	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19460	 81550	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81551	 19460	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19460	 81664	 0.001898	 0.022261	 0.08982	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19461	 81552	 0.005094	 0.013501	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19462	 81552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19462	 81552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19462	 81665	 0.024821	 0.099419	 0.02506	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79623	 19463	 0.005501	 0.011258	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79629	 19463	 0.006089	 0.018328	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81074	 19463	 0.036772	 0.14306	 0.00239	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19464	 19465	 0.001037	 0.006375	 0.00184	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19465	 19466	 0.000786	 0.003089	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81514	 19465	 0.004083	 0.016615	 0.00405	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19466	 19467	 0.001166	 0.004583	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19467	 81553	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19467	 81553	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79632	 19468	 0.004646	 0.011942	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81553	 19468	 0.005746	 0.019169	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79623	 19469	 0.003596	 0.011044	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79629	 19469	 0.000853	 0.002192	 3e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79632	 19469	 0.003272	 0.009385	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19471	 19472	 0.009909	 0.033849	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19471	 19475	 0.007599	 0.03708	 0.00064	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19472	 19473	 0.004507	 0.027391	 0.00051	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19473	 19474	 0.005495	 0.024485	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19473	 81561	 0.01374	 0.061225	 0.00104	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19474	 19481	 0.002998	 0.011664	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19474	 81556	 0.008564	 0.019883	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19474	 81557	 0.00187	 0.00803	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19475	 81556	 0.003344	 0.020998	 0.00046	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19476	 19478	 0.00053	 0.004062	 0.00109	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19477	 19484	 0.00343	 0.010324	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81010	 19477	 0.00573	 0.022293	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19478	 81554	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19478	 81554	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19478	 81555	 0.000323	 0.003792	 0.00101	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19479	 81555	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81556	 19479	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19479	 81559	 0.000331	 0.002572	 0.00922	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19480	 19483	 0.001145	 0.005251	 0.00135	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81555	 19480	 0.000674	 0.002742	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19480	 81557	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19480	 81557	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19481	 19482	 0.003656	 0.014631	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19481	 81558	 0.00473	 0.018402	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19482	 19488	 0.007477	 0.022962	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19482	 81561	 0.008583	 0.038247	 0.00065	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19482	 81562	 0.008436	 0.02588	 0.0007	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19482	 81562	 0.008436	 0.02588	 0.0007	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19483	 81558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19483	 81558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19483	 81560	 0.000957	 0.005142	 0.00126	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81556	 19484	 0.003401	 0.01276	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81556	 19484	 0.003401	 0.01276	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19484	 81564	 0.004224	 0.025967	 0.00047	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19485	 81559	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81560	 19486	 0.000848	 0.010022	 0.00285	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19486	 81562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19486	 81562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19487	 19488	 0.021218	 0.023338	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81559	 19489	 0.000304	 0.002991	 0.01025	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19489	 81563	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81564	 19489	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19490	 19491	 0.000388	 0.003608	 0.00112	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19491	 19497	 0.001068	 0.005367	 0.0014	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19491	 81565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19491	 81565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19491	 81566	 0.000907	 0.004291	 0.00103	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81180	 19492	 0.021996	 0.073378	 0.00116	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81385	 19492	 0.00268	 0.013078	 0.00023	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81565	 19492	 0.006103	 0.014169	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19493	 81566	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19493	 81566	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81566	 19494	 0.001068	 0.003737	 0.00124	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19494	 81567	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19494	 81567	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81374	 19495	 0.009069	 0.023314	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81565	 19495	 0.010697	 0.02118	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81567	 19495	 0.022102	 0.017491	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81378	 19496	 0.001143	 0.00724	 0.00197	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19496	 81568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19496	 81568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81566	 19498	 0.000724	 0.00617	 0.00154	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19498	 81569	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19498	 81569	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19499	 81570	 0.002881	 0.017714	 0.00032	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19500	 19502	 0.001484	 0.00509	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19501	 19502	 0.001357	 0.004797	 0.00108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19501	 81570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19501	 81570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81265	 19503	 0.009584	 0.042884	 0.00088	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81267	 19503	 0.011748	 0.056391	 0.00169	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81570	 19503	 0.006742	 0.026229	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81570	 19503	 0.006742	 0.026229	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81540	 19504	 0.000731	 0.004986	 0.00898	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19504	 81571	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19504	 81571	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19505	 19507	 0.009559	 0.007493	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19505	 19508	 0.017813	 0.013106	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19505	 81667	 0.18265	 0.14456	 0.00182	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19506	 19509	 0.001566	 0.004065	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81571	 19506	 0.000965	 0.002844	 0.00066	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19508	 19513	 0.042032	 0.033263	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19509	 19510	 0.000893	 0.002245	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19510	 19512	 0.001152	 0.003213	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19511	 19512	 0.000943	 0.002492	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81571	 19511	 0.003371	 0.008909	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19511	 81572	 0.004299	 0.011362	 0.00266	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19512	 81573	 0.005232	 0.013828	 0.00324	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81539	 19513	 0.021411	 0.021626	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19514	 19515	 0.000257	 0.001771	 0.00313	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81540	 19514	 0.000802	 0.005203	 0.01036	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19514	 81572	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19514	 81572	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19515	 81573	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19515	 81573	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81539	 19516	 0.02992	 0.054802	 0.00095	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19516	 81574	 0.018801	 0.014737	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19517	 81574	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19517	 81574	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19517	 81582	 0.002491	 0.006403	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19518	 19519	 0.001068	 0.002867	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19518	 19521	 0.001471	 0.003819	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19518	 81575	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19518	 81575	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19519	 19534	 0.000887	 0.002416	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19519	 81576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19519	 81576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81575	 19520	 0.021172	 0.016755	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19521	 19522	 0.001983	 0.005241	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19522	 19533	 0.001331	 0.003573	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19523	 81578	 0.028635	 0.022445	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19523	 81585	 0.048883	 0.038685	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19524	 19525	 0.001342	 0.003485	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19524	 19533	 0.00245	 0.006359	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19525	 81577	 0.001151	 0.00321	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19526	 81578	 0.026862	 0.019763	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19526	 81581	 0.02866	 0.020301	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19526	 81586	 0.023186	 0.018349	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19527	 19535	 0.000895	 0.005806	 0.01156	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19527	 19540	 0.00036	 0.002481	 0.00438	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19527	 81577	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81578	 19527	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19528	 19541	 0.002054	 0.005428	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19528	 19544	 0.002899	 0.007662	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79590	 19528	 0.004483	 0.025385	 0.00629	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19528	 81579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19528	 81579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19529	 81581	 0.014791	 0.011706	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19529	 81583	 0.014416	 0.02575	 0.00038	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19530	 81583	 0.033142	 0.025422	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19531	 19538	 0.002392	 0.00615	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19531	 19545	 0.001835	 0.004763	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19531	 19547	 0.003373	 0.008914	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19531	 81580	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19531	 81580	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19532	 19539	 0.001467	 0.004091	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19532	 19545	 0.001914	 0.004812	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19533	 81581	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19533	 81581	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19534	 81582	 0.001328	 0.003509	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81540	 19535	 0.001516	 0.01044	 0.01843	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19535	 81582	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81583	 19535	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19536	 19537	 0.002584	 0.007207	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81582	 19536	 0.001388	 0.003669	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19539	 19544	 0.001721	 0.004148	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19539	 81584	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19539	 81584	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19540	 19546	 0.00031	 0.002135	 0.00377	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19540	 81585	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19540	 81585	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81577	 19541	 0.001301	 0.003438	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19541	 81586	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19541	 81586	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19542	 19545	 0.000867	 0.002973	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79620	 19542	 0.008589	 0.031101	 0.00667	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81580	 19543	 0.050286	 0.039796	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81584	 19543	 0.045685	 0.033025	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81585	 19543	 0.009756	 0.019316	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79619	 19546	 0.001325	 0.008726	 0.01688	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19546	 81587	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19546	 81587	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79590	 19547	 0.00398	 0.024069	 0.00614	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79620	 19547	 0.009014	 0.030372	 0.00755	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19548	 19549	 0.013198	 0.017346	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19548	 19611	 0.020757	 0.014703	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19549	 19550	 0.01066	 0.007843	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19549	 81589	 0.007946	 0.015573	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19550	 19555	 0.014204	 0.015623	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19551	 19552	 0.024624	 0.028864	 0.0005	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19551	 81588	 0.005384	 0.01066	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19552	 81588	 0.009691	 0.024645	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19553	 19554	 0.001169	 0.003034	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19553	 81588	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19553	 81588	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19553	 81591	 0.002258	 0.009322	 0.00221	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19554	 81589	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19554	 81589	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19555	 19598	 0.018467	 0.013081	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19555	 19600	 0.025445	 0.016473	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81588	 19555	 0.026184	 0.020722	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81589	 19555	 0.011664	 0.007551	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81588	 19556	 0.016066	 0.010401	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19557	 19583	 0.006226	 0.015652	 0.00405	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19557	 81590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19557	 81590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19557	 81591	 0.001147	 0.003934	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81540	 19558	 0.001693	 0.011145	 0.02156	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19558	 81591	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81592	 19558	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19558	 81605	 0.001454	 0.00957	 0.01852	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81590	 19559	 0.005687	 0.013204	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81592	 19559	 0.006163	 0.014159	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19560	 19572	 0.003112	 0.00808	 0.00196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81591	 19560	 0.002593	 0.007644	 0.00178	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19560	 81593	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19560	 81593	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19561	 19563	 0.008697	 0.00563	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19561	 19565	 0.019746	 0.014274	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81590	 19561	 0.013524	 0.020718	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19562	 19568	 0.010828	 0.009974	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19562	 81601	 0.016103	 0.011407	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19563	 19564	 0.014703	 0.011525	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19563	 19565	 0.012802	 0.009069	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81590	 19564	 0.006704	 0.011975	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81593	 19564	 0.016708	 0.012293	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19565	 19568	 0.007279	 0.005991	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19566	 19574	 0.037664	 0.0253	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19566	 19602	 0.014918	 0.011806	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19567	 19568	 0.023886	 0.015464	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19567	 19577	 0.016343	 0.012933	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19569	 19570	 0.012519	 0.009908	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19570	 19625	 0.030246	 0.021864	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81593	 19570	 0.028829	 0.022815	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19571	 19573	 0.006974	 0.013808	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19571	 81594	 0.014002	 0.010302	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19572	 81594	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19572	 81594	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19573	 19575	 0.01813	 0.014348	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19573	 81595	 0.003305	 0.007671	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81594	 19574	 0.011325	 0.011328	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19575	 19576	 0.01706	 0.013501	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19575	 19577	 0.033279	 0.026337	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19575	 19582	 0.006266	 0.01228	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81592	 19575	 0.081808	 0.076719	 0.00118	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19576	 19577	 0.016323	 0.012918	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19576	 19578	 0.005482	 0.009156	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19577	 19607	 0.011501	 0.014968	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19577	 19608	 0.005576	 0.015823	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19578	 19579	 0.004068	 0.008718	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19578	 19581	 0.020179	 0.018924	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19579	 19590	 0.004769	 0.012259	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19579	 19608	 0.014044	 0.012003	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19580	 19581	 0.013674	 0.01036	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19581	 19587	 0.004214	 0.008344	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19582	 81595	 0.012996	 0.010285	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19582	 81597	 0.005714	 0.014531	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19583	 19584	 0.000838	 0.002214	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19583	 19595	 0.001234	 0.004849	 0.00127	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19583	 81595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19583	 81595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19584	 81596	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19584	 81596	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19585	 81597	 0.012272	 0.009712	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81595	 19586	 0.011685	 0.011802	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19586	 81597	 0.003351	 0.012572	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19587	 81597	 0.001957	 0.00646	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19588	 19594	 0.006935	 0.006388	 0.0001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19589	 19593	 0.011726	 0.00928	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19590	 19592	 0.005523	 0.014198	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19591	 19592	 0.009722	 0.007621	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19591	 81607	 0.009913	 0.017707	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19592	 81600	 0.00466	 0.01431	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19592	 81604	 0.009274	 0.015488	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19593	 81600	 0.007655	 0.018128	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19594	 81597	 0.00384	 0.009092	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19595	 81597	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19595	 81597	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19595	 81598	 0.000822	 0.006158	 0.0015	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19596	 19626	 6.3e-05	 0.00082	 0.05233	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19596	 81598	 0.000149	 0.01193	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81598	 19597	 0.001365	 0.005776	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19597	 81600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19597	 81600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81589	 19598	 0.02906	 0.022998	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81590	 19598	 0.015348	 0.035631	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19599	 19600	 0.006365	 0.011439	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19599	 19613	 0.01356	 0.010731	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19599	 19614	 0.022917	 0.018136	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19600	 81601	 0.005615	 0.014279	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19601	 19603	 0.001525	 0.004095	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81591	 19601	 0.0039	 0.014123	 0.00303	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19601	 81601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19601	 81601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19602	 19607	 0.019876	 0.015579	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81601	 19602	 0.021863	 0.017302	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19602	 81602	 0.016327	 0.016491	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19603	 19604	 0.001001	 0.003433	 0.00082	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19603	 81602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19603	 81602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19604	 81603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19604	 81603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19604	 81673	 0.003457	 0.012048	 0.00279	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19605	 19606	 0.014787	 0.010474	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19605	 19608	 0.011481	 0.020715	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81603	 19605	 0.008411	 0.014168	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19606	 19608	 0.010122	 0.018192	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19606	 19609	 0.011837	 0.008968	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19608	 81607	 0.002697	 0.011952	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19609	 19620	 0.016066	 0.024611	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19610	 81604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19610	 81604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19610	 81606	 0.001316	 0.003881	 0.0009	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19611	 19612	 0.023258	 0.017112	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19612	 19617	 0.020901	 0.022988	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19612	 19805	 0.017194	 0.033697	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19614	 19615	 0.01423	 0.011154	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19615	 19617	 0.014594	 0.01155	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19616	 19617	 0.017341	 0.011226	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19617	 19618	 0.006946	 0.017593	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81602	 19618	 0.002497	 0.010205	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19619	 19627	 0.008155	 0.015982	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81603	 19619	 0.015528	 0.017078	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19620	 19621	 0.018285	 0.012283	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19620	 19623	 0.008506	 0.017407	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19620	 81675	 0.009835	 0.018286	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19621	 19879	 0.019059	 0.031241	 0.00055	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19621	 81607	 0.006721	 0.032277	 0.00062	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19622	 19624	 0.003923	 0.016601	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19622	 19880	 0.002968	 0.010384	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19623	 81607	 0.006517	 0.017805	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81604	 19624	 0.002371	 0.011382	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81596	 19625	 0.018846	 0.013865	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19626	 19806	 6.3e-05	 0.000817	 0.05217	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19626	 81605	 0.000118	 0.009419	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19627	 81674	 0.006086	 0.017271	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81457	 19628	 0.000609	 0.008247	 0.01698	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19628	 81608	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81609	 19628	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19629	 81611	 0.006841	 0.017585	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19630	 19639	 0.002096	 0.00719	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19630	 81610	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 -1.0	 1	 -30.0	 30.0;
	19630	 81610	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 -1.0	 1	 -30.0	 30.0;
	19631	 19632	 0.010126	 0.020049	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81610	 19631	 0.003662	 0.007251	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19631	 81611	 0.007585	 0.021756	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19633	 19634	 0.012027	 0.009518	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19634	 81611	 0.007418	 0.014686	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19635	 81611	 0.012283	 0.021601	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19636	 19637	 0.013006	 0.02575	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19636	 81611	 0.009352	 0.035979	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19638	 19639	 0.002851	 0.011091	 0.00296	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81514	 19639	 0.004787	 0.012652	 0.00296	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19639	 81611	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19639	 81611	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19640	 81612	 0.034497	 0.02704	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19641	 19642	 0.002006	 0.010256	 0.0028	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81466	 19641	 0.008311	 0.028967	 0.00672	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19641	 81612	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19641	 81612	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19643	 81613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19643	 81613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19644	 19645	 0.013153	 0.008515	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19644	 19646	 0.005761	 0.011405	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19645	 19646	 0.008802	 0.017427	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19646	 19650	 0.003949	 0.008082	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19646	 19651	 0.01497	 0.012322	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81613	 19646	 0.006784	 0.014259	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19647	 19649	 0.00232	 0.008122	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81613	 19647	 0.002729	 0.00975	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19648	 19657	 0.005127	 0.010947	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19648	 19672	 0.014241	 0.009566	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81599	 19648	 0.012398	 0.017278	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19649	 19654	 0.003568	 0.008856	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81599	 19649	 0.012879	 0.032754	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19650	 19651	 0.002372	 0.006973	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19650	 19653	 0.003465	 0.013481	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19651	 19652	 0.006727	 0.010791	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19652	 19666	 0.015875	 0.016953	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19653	 19659	 0.006779	 0.017425	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19653	 19661	 0.003693	 0.012319	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19654	 19655	 0.00272	 0.008975	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19654	 19656	 0.004246	 0.00869	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19655	 19656	 0.013657	 0.010048	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19655	 19659	 0.004949	 0.015715	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19656	 19657	 0.003297	 0.008475	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19657	 19673	 0.003465	 0.01416	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19658	 19659	 0.002545	 0.011342	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19659	 19660	 0.008334	 0.012143	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19660	 19661	 0.004579	 0.01177	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19660	 19663	 0.00455	 0.013971	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19661	 81614	 0.035625	 0.02621	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19662	 19664	 0.000967	 0.003799	 0.00099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19662	 81614	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19662	 81614	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81614	 19663	 0.007432	 0.014714	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19664	 19665	 0.001189	 0.003967	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19664	 81615	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19664	 81615	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19666	 19668	 0.007296	 0.032509	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81615	 19666	 0.00498	 0.014645	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19667	 19670	 0.001137	 0.005304	 0.00131	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19668	 81616	 0.009278	 0.02271	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19669	 19782	 0.002188	 0.005782	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19669	 81616	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19669	 81616	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19670	 19671	 0.001014	 0.003305	 0.00088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19670	 81617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19670	 81617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19671	 19782	 0.001377	 0.004639	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81500	 19673	 0.012399	 0.019953	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19674	 19676	 0.001712	 0.006659	 0.00178	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19674	 81618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19674	 81618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79637	 19675	 0.009678	 0.048406	 0.00086	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81618	 19675	 0.001564	 0.008238	 0.00015	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81325	 19676	 0.005652	 0.044531	 0.01303	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19676	 81619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19676	 81619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81244	 19677	 0.005242	 0.016098	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19677	 81620	 0.00226	 0.01103	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19678	 19679	 0.000609	 0.002793	 0.00072	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19679	 19680	 0.000409	 0.002743	 0.00066	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19679	 81620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19679	 81620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19680	 19682	 0.000485	 0.002569	 0.00086	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19680	 81621	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19680	 81621	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19680	 81628	 0.00111	 0.004699	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19681	 19683	 0.005209	 0.008315	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81621	 19681	 0.007276	 0.010602	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19682	 19687	 0.000432	 0.002378	 0.00086	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19682	 81622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19682	 81622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19683	 19684	 0.004522	 0.008283	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81622	 19683	 0.004292	 0.010164	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81254	 19684	 0.003911	 0.015213	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19685	 19700	 0.003706	 0.016823	 0.00036	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81254	 19685	 0.002707	 0.015389	 0.00028	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19686	 19700	 0.017851	 0.012904	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19687	 19701	 0.000635	 0.004689	 0.00135	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19688	 19691	 0.014206	 0.010897	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19689	 19690	 0.00047	 0.001881	 0.00047	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19690	 19696	 0.000741	 0.003596	 0.00082	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19690	 81623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19690	 81623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81623	 19691	 0.005475	 0.012578	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19691	 81625	 0.008802	 0.014828	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19692	 19693	 0.002823	 0.007258	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19692	 81625	 0.005475	 0.018264	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19692	 81639	 0.004942	 0.024996	 0.00049	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19693	 19694	 0.002181	 0.005606	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19693	 19695	 0.011385	 0.00901	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19693	 19698	 0.005283	 0.016773	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81623	 19693	 0.00466	 0.011035	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81623	 19694	 0.00194	 0.005705	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19694	 81624	 0.005042	 0.01194	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19696	 81624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19696	 81624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19697	 19699	 0.004024	 0.011542	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81257	 19697	 0.005344	 0.012221	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19698	 19699	 0.002205	 0.008447	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81624	 19698	 0.002871	 0.016318	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19698	 81644	 0.008809	 0.029386	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79612	 19699	 0.006228	 0.03115	 0.00055	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81262	 19699	 0.009051	 0.024727	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19700	 81625	 0.001362	 0.007177	 0.00013	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19701	 81625	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19701	 81625	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19701	 81626	 0.000266	 0.002284	 0.00065	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79610	 19702	 0.000187	 0.003105	 0.01146	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19702	 81626	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81627	 19702	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79610	 19703	 0.000694	 0.007015	 0.01592	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79610	 19703	 0.000694	 0.007015	 0.01592	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19703	 81628	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81629	 19703	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81626	 19704	 0.0009	 0.003148	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19704	 81630	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19704	 81630	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81630	 19705	 0.002145	 0.006908	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19705	 81636	 0.004169	 0.011049	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19706	 19711	 0.000112	 0.000828	 0.00042	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81628	 19706	 0.000229	 0.001698	 0.00087	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19706	 81631	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19706	 81631	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19707	 19710	 0.002529	 0.007613	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81631	 19707	 0.001163	 0.00789	 0.00015	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19707	 81632	 0.001175	 0.004662	 0.00013	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19708	 19709	 0.000692	 0.002505	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19708	 19717	 0.000528	 0.002112	 0.00053	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19708	 81632	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19708	 81632	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19709	 81633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19709	 81633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81629	 19710	 0.005526	 0.016249	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81633	 19710	 0.001212	 0.005297	 0.00014	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19710	 81634	 0.003143	 0.012228	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19710	 81636	 0.002287	 0.013541	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19711	 19712	 0.000129	 0.00101	 0.00046	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19712	 19715	 9.3e-05	 0.001398	 0.00047	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19712	 81634	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19712	 81634	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81627	 19713	 0.001331	 0.007124	 0.00022	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81630	 19713	 0.001424	 0.008093	 0.00015	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19713	 81635	 0.003799	 0.012232	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19714	 19715	 0.000323	 0.002753	 0.00069	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19714	 19730	 0.000586	 0.005023	 0.00143	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19714	 81635	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19714	 81635	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19715	 19726	 0.001145	 0.006352	 0.00193	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19715	 81636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19715	 81636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81635	 19716	 0.026292	 0.019007	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19716	 81642	 0.029027	 0.018792	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19717	 19718	 0.000613	 0.002384	 0.00064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19718	 19720	 0.000653	 0.003111	 0.0009	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81628	 19718	 0.001922	 0.007556	 0.00198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19718	 81637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19718	 81637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81633	 19719	 0.002791	 0.012438	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81637	 19719	 0.002236	 0.009965	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19720	 19721	 0.000971	 0.004455	 0.00114	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19721	 81638	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19721	 81638	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81633	 19722	 0.028578	 0.022616	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19723	 19724	 0.000868	 0.005499	 0.00149	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79611	 19723	 0.000735	 0.004212	 0.0014	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19723	 81639	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19723	 81639	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19723	 81643	 0.000224	 0.001798	 0.00051	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19724	 19725	 0.000534	 0.003183	 0.00084	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19724	 81640	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19724	 81640	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19725	 19726	 0.000774	 0.00389	 0.00101	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19725	 81641	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19725	 81641	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19726	 81642	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19726	 81642	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79608	 19727	 0.000846	 0.010281	 0.03329	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79610	 19727	 8.1e-05	 0.000773	 0.00283	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19727	 81643	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81644	 19727	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19728	 19729	 0.000657	 0.004164	 0.00113	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79611	 19728	 0.000983	 0.005024	 0.00137	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79611	 19730	 0.00077	 0.007925	 0.00225	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19730	 81645	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19730	 81645	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19731	 81646	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19731	 81646	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19732	 19733	 0.010595	 0.015438	 0.00035	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19733	 19742	 0.006994	 0.023333	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81629	 19733	 0.065435	 0.061364	 0.00095	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81646	 19733	 0.018329	 0.041576	 0.00083	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19734	 19736	 0.006749	 0.01735	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19734	 19741	 0.006585	 0.013476	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81640	 19734	 0.008233	 0.024211	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81640	 19735	 0.009384	 0.018579	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19735	 81647	 0.007009	 0.023382	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19736	 19737	 0.007673	 0.019887	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19737	 81647	 0.016895	 0.030367	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81077	 19738	 0.002973	 0.020406	 0.00037	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19738	 81647	 0.00405	 0.01954	 0.00035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79611	 19739	 0.001912	 0.007893	 0.00187	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19739	 81647	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19739	 81647	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19740	 19742	 0.019166	 0.01957	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81647	 19740	 0.011295	 0.056489	 0.00101	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81642	 19741	 0.006323	 0.012939	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81642	 19742	 0.00248	 0.016825	 0.00031	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19743	 19749	 0.000922	 0.003355	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19743	 19757	 0.001017	 0.004305	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19743	 81648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19743	 81648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19744	 19745	 0.001103	 0.004915	 0.00134	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19744	 19758	 0.00165	 0.005775	 0.00191	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19744	 81649	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19744	 81649	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19744	 81660	 0.002295	 0.019681	 0.0056	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19745	 19746	 0.00147	 0.006071	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19746	 19747	 0.001435	 0.005639	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19747	 19748	 0.001108	 0.004986	 0.00133	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19747	 81660	 0.003411	 0.028381	 0.00859	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19748	 81650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19748	 81650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19749	 19754	 0.001165	 0.005246	 0.0014	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19749	 19756	 0.000558	 0.003537	 0.00096	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19749	 81651	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19749	 81651	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19750	 19753	 0.001403	 0.003708	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19750	 81652	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19750	 81652	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19750	 81660	 0.003844	 0.017928	 0.00444	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19751	 19752	 0.005961	 0.011802	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81652	 19752	 0.005238	 0.020455	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19753	 19754	 0.000888	 0.003998	 0.00106	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19753	 19764	 0.000969	 0.004316	 0.00117	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19754	 81653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19754	 81653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19755	 19769	 0.00139	 0.006855	 0.00185	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19755	 81654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19755	 81654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19756	 81660	 0.00139	 0.008623	 0.00209	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19757	 19766	 0.002072	 0.009505	 0.00243	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19757	 81655	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19757	 81655	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19758	 19759	 0.001494	 0.003469	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19758	 81656	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19758	 81656	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19759	 81657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19759	 81657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19760	 19761	 0.008159	 0.012499	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81657	 19761	 0.008947	 0.027446	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19761	 81658	 0.025104	 0.049703	 0.00073	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19762	 19763	 0.001733	 0.006588	 0.00184	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19763	 19764	 0.001567	 0.005459	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19763	 81658	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19763	 81658	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19763	 81660	 0.006218	 0.026319	 0.00592	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81653	 19765	 0.005211	 0.013812	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19765	 81662	 0.015627	 0.052131	 0.00083	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19766	 81660	 0.001232	 0.006416	 0.00168	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19767	 81660	 0.002076	 0.008158	 0.00213	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19768	 81659	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81660	 19769	 0.000506	 0.004598	 0.00116	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19769	 81662	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19769	 81662	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81661	 19770	 0.014714	 0.024786	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81662	 19770	 0.007469	 0.024917	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19771	 19772	 0.001234	 0.004691	 0.00131	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19771	 81665	 0.001384	 0.005542	 0.0014	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81045	 19772	 0.007212	 0.026237	 0.00803	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19772	 81663	 0.001995	 0.00518	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81044	 19773	 0.001411	 0.008937	 0.01872	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19773	 81663	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19773	 81663	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19774	 19775	 0.019372	 0.029676	 0.00042	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19775	 81666	 0.011328	 0.027018	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19776	 81664	 9.4e-05	 0.007487	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19776	 81664	 9.4e-05	 0.007487	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19777	 19781	 0.004793	 0.009809	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19777	 19795	 0.028417	 0.025463	 0.00052	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19777	 81668	 0.045186	 0.03576	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19778	 19779	 0.008743	 0.016523	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19778	 81668	 0.013817	 0.021167	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19779	 19780	 0.015297	 0.01159	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19779	 81671	 0.012623	 0.034917	 0.00081	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19780	 19781	 0.008878	 0.017002	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19780	 81670	 0.004208	 0.020542	 0.00043	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19781	 19797	 0.017606	 0.028102	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19782	 19783	 0.003041	 0.008036	 0.00188	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81571	 19782	 0.010156	 0.02684	 0.00628	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19783	 19788	 0.004996	 0.012559	 0.00325	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19783	 81667	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19783	 81667	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81667	 19784	 0.071204	 0.071919	 0.00095	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19785	 19786	 0.030144	 0.019515	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19785	 19787	 0.04441	 0.032104	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19785	 81669	 0.058209	 0.054587	 0.00084	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19786	 19787	 0.029852	 0.021963	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81667	 19786	 0.05227	 0.03384	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81512	 19787	 0.012716	 0.030111	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81513	 19787	 0.043385	 0.034335	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19789	 19791	 0.007467	 0.022016	 0.00512	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19790	 19791	 0.002653	 0.00894	 0.00222	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19790	 19800	 0.003357	 0.015658	 0.00388	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19790	 81668	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19790	 81668	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19792	 19793	 0.062304	 0.048837	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81668	 19792	 0.056342	 0.044589	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19793	 19794	 0.033787	 0.051751	 0.0009	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79616	 19794	 0.067542	 0.20745	 0.00389	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81415	 19794	 0.39627	 0.28664	 0.00435	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81668	 19794	 0.12707	 0.10056	 0.00127	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19794	 81671	 0.086332	 0.071061	 0.00144	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81614	 19795	 0.1707	 0.18777	 0.00251	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81668	 19795	 0.06023	 0.047666	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19796	 81669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19796	 81669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19797	 81670	 0.013924	 0.035793	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19798	 81672	 0.1391	 0.10904	 0.0014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19799	 19800	 0.002967	 0.007842	 0.00184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19799	 81670	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19799	 81670	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19800	 19801	 0.002031	 0.009614	 0.00231	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19800	 81671	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19800	 81671	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19801	 19802	 0.004418	 0.01768	 0.00597	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19802	 81672	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19802	 81672	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19803	 19804	 0.050377	 0.099746	 0.00146	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80539	 19803	 0.10072	 0.19943	 0.00293	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79616	 19804	 0.13981	 0.11065	 0.00139	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79625	 19804	 0.25199	 0.19096	 0.00263	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81672	 19804	 0.066676	 0.1191	 0.00176	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19805	 19819	 0.011729	 0.023223	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19805	 81676	 0.016506	 0.042431	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19806	 81673	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81673	 19807	 0.001417	 0.005851	 0.00138	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19807	 81675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19807	 81675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81674	 19808	 0.027589	 0.019542	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19809	 19817	 0.002598	 0.010995	 0.00247	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81673	 19809	 0.000937	 0.00437	 0.00108	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19809	 81676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19809	 81676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19810	 19812	 0.008293	 0.014905	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19810	 19879	 0.021094	 0.021306	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19811	 19814	 0.005905	 0.016935	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19811	 19818	 0.007058	 0.015124	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81675	 19811	 0.003661	 0.02383	 0.00048	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81675	 19812	 0.005744	 0.014765	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19813	 19867	 0.001351	 0.006018	 0.00164	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81673	 19813	 0.001641	 0.013802	 0.00409	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19813	 81677	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19813	 81677	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19814	 19865	 0.009017	 0.015858	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81677	 19814	 0.018862	 0.020746	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81677	 19815	 0.014747	 0.011559	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19816	 19818	 0.01439	 0.022969	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19816	 81678	 0.016172	 0.017787	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19817	 19829	 0.003488	 0.01233	 0.00278	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19817	 81678	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19817	 81678	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19819	 19820	 0.017785	 0.017963	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81678	 19820	 0.007547	 0.019194	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19820	 81682	 0.032175	 0.052741	 0.00093	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19821	 19822	 0.030181	 0.019539	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19821	 19828	 0.049103	 0.038489	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19822	 81679	 0.02407	 0.017709	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19822	 81680	 0.010559	 0.017788	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19823	 19824	 0.001437	 0.00493	 0.00118	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19823	 19825	 0.001325	 0.003502	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19823	 81679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19823	 81679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19824	 19867	 0.001594	 0.005468	 0.00131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19824	 81680	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19824	 81680	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19825	 81681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19825	 81681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19826	 19827	 0.007797	 0.011361	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19826	 19853	 0.01856	 0.017405	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19826	 19870	 0.013306	 0.013439	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19826	 81686	 0.009392	 0.026937	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81681	 19827	 0.017139	 0.013563	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19828	 81682	 0.028516	 0.022567	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19829	 19830	 0.001267	 0.004267	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19830	 81682	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19830	 81682	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19831	 19832	 0.006629	 0.023196	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81682	 19831	 0.005944	 0.033396	 0.00062	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19832	 19833	 0.00669	 0.017732	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19833	 19834	 0.004895	 0.012685	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19834	 19835	 0.009392	 0.019301	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19834	 19842	 0.038083	 0.041887	 0.00056	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19835	 19837	 0.011759	 0.012934	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19835	 19838	 0.015016	 0.025295	 0.00036	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19836	 19838	 0.010506	 0.018956	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19838	 81683	 0.007052	 0.03567	 0.00062	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19839	 19840	 0.004911	 0.013936	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81679	 19839	 0.017063	 0.033784	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81682	 19839	 0.024717	 0.044425	 0.0008	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19840	 19841	 0.021758	 0.017055	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81681	 19841	 0.029229	 0.057871	 0.00085	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19842	 19843	 0.002596	 0.006674	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19843	 81683	 0.00992	 0.033093	 0.00052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19844	 19845	 0.016887	 0.013899	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81681	 19845	 0.006074	 0.014384	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19846	 19851	 0.002554	 0.008762	 0.0021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19846	 81683	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19846	 81683	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19846	 81685	 0.000976	 0.007313	 0.00178	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19847	 19863	 0.027767	 0.022855	 0.00046	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19847	 19864	 0.010854	 0.016461	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19847	 81687	 0.036725	 0.048268	 0.00066	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19848	 19874	 0.018912	 0.014824	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19848	 19875	 0.015286	 0.009896	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19848	 81684	 0.008337	 0.01527	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81503	 19849	 0.003859	 0.0331	 0.00942	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19849	 81684	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19849	 81684	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19849	 81685	 0.003547	 0.009374	 0.00219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81605	 19850	 0.00177	 0.01422	 0.03084	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19850	 81685	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81686	 19850	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19851	 81687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19851	 81687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19852	 19856	 0.055269	 0.043323	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19853	 19854	 0.014744	 0.01117	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81684	 19853	 0.009594	 0.022269	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19855	 19860	 0.025416	 0.04077	 0.00075	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81683	 19855	 0.021909	 0.040737	 0.00095	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81684	 19855	 0.007093	 0.043606	 0.00079	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81687	 19855	 0.011544	 0.024262	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19856	 19859	 0.029465	 0.060299	 0.00148	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19856	 19862	 0.020372	 0.020802	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19857	 19858	 0.013532	 0.00876	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81684	 19858	 0.015172	 0.0252	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81684	 19859	 0.024696	 0.058905	 0.00132	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19861	 19862	 0.013354	 0.010568	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19862	 19863	 0.022686	 0.017782	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81687	 19862	 0.0114	 0.027905	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81683	 19864	 0.02337	 0.046271	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19865	 19866	 0.01335	 0.011962	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19866	 81688	 0.009864	 0.007566	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19867	 19869	 0.002336	 0.006271	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19867	 81688	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19867	 81688	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19868	 19870	 0.013823	 0.015203	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19868	 19872	 0.016511	 0.012665	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81688	 19868	 0.002635	 0.008791	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19869	 19878	 0.001106	 0.004203	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19869	 19882	 0.002077	 0.005391	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19869	 81689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19869	 81689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19870	 19871	 0.009131	 0.008411	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19871	 19874	 0.010989	 0.011736	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19872	 19873	 0.011107	 0.00879	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19874	 81691	 0.004407	 0.0147	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19876	 19880	 0.017919	 0.019708	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19876	 81692	 0.015465	 0.013217	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81677	 19877	 0.019165	 0.015167	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19877	 81690	 0.017493	 0.017669	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19878	 19888	 0.001464	 0.006717	 0.00172	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19878	 81690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19878	 81690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19879	 19880	 0.010899	 0.013287	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81689	 19881	 0.009721	 0.009819	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81690	 19881	 0.009621	 0.019048	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19882	 81691	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19882	 81691	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19883	 19884	 0.009211	 0.009836	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19884	 19894	 0.00745	 0.024584	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81684	 19884	 0.022856	 0.029744	 0.00042	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19885	 19886	 0.035906	 0.025957	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81684	 19885	 0.01169	 0.029731	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81499	 19887	 0.018926	 0.024875	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19888	 81692	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19888	 81692	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19889	 19898	 0.017973	 0.017585	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81504	 19889	 0.00918	 0.04066	 0.00093	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19889	 81694	 0.003641	 0.015199	 0.00044	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19890	 19891	 0.018585	 0.018772	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81692	 19890	 0.020961	 0.01643	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19891	 19893	 0.008708	 0.012913	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19891	 81693	 0.005695	 0.014638	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19892	 19899	 0.001384	 0.005714	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19892	 19902	 0.001661	 0.005789	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19892	 81693	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19892	 81693	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19893	 81695	 0.015739	 0.012456	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19894	 81695	 0.002585	 0.013077	 0.00023	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19895	 19901	 0.005707	 0.017177	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19895	 81694	 0.004487	 0.014808	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19896	 19899	 0.001117	 0.004729	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19897	 19898	 0.008645	 0.011362	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81499	 19897	 0.009979	 0.019556	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81506	 19897	 0.009996	 0.017966	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19899	 81694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19899	 81694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81694	 19900	 0.016205	 0.011715	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81693	 19901	 0.021045	 0.015213	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19901	 81695	 0.004569	 0.015241	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81685	 19902	 0.005696	 0.01954	 0.00468	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19902	 81695	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19902	 81695	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19904	 19905	 0.000208	 0.002095	 0.00128	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19904	 81697	 0.000306	 0.0035	 0.00166	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81665	 19905	 0.002484	 0.037953	 0.01223	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19905	 81696	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19905	 81696	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19906	 19907	 1e-05	 0.00028	 0.01928	 2893.0	 3037.6	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19906	 81697	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19906	 81697	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19907	 19908	 1e-05	 0.000262	 0.01799	 2811.0	 2951.5	 3092.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19907	 81698	 0.00209	 0.091976	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19907	 81698	 0.00209	 0.091976	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19909	 19910	 0.016724	 0.028172	 0.0004	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19909	 81699	 0.048268	 0.037024	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81470	 19910	 0.010352	 0.029377	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19911	 81699	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19911	 81699	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81206	 19912	 0.000442	 0.00545	 0.00176	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19912	 81700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19912	 81700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19912	 81702	 0.000429	 0.002973	 0.00174	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19913	 19914	 1e-05	 0.000296	 0.02059	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19914	 81701	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19914	 81701	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19915	 20060	 0.0016	 0.019972	 0.07099	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81701	 19915	 8.6e-05	 0.001234	 0.00491	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19915	 81702	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19915	 81702	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81701	 19916	 0.000238	 0.00257	 0.0051	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81701	 19916	 0.000238	 0.00257	 0.0051	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19916	 81703	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81704	 19916	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19917	 19920	 0.005572	 0.043431	 0.01299	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19917	 20038	 0.005332	 0.048506	 0.01225	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19917	 81705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19917	 81705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19918	 20335	 0.14908	 0.22841	 0.00321	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79669	 19918	 0.13567	 0.45283	 0.00718	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81705	 19918	 0.011886	 0.04554	 0.00129	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19919	 20317	 0.015783	 0.065174	 0.01542	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19919	 20334	 0.012173	 0.04785	 0.01252	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19920	 20315	 0.002938	 0.021475	 0.00634	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19921	 19922	 0.001941	 0.007771	 0.00196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19921	 81706	 0.004078	 0.015864	 0.00424	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79506	 19922	 0.00442	 0.017697	 0.00446	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19923	 19924	 0.000895	 0.013184	 0.00644	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19923	 81706	 0.000837	 0.01036	 0.00559	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19924	 81814	 0.001277	 0.017746	 0.00975	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19925	 19931	 0.000145	 0.001726	 0.12949	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19925	 81706	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19925	 81706	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19926	 19929	 0.00337	 0.020225	 0.00612	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19926	 20056	 0.002062	 0.01306	 0.00354	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19927	 81707	 0.022986	 0.01892	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19927	 81709	 0.030909	 0.071013	 0.00108	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19928	 19929	 0.001154	 0.004882	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81706	 19928	 0.00318	 0.012731	 0.00321	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81706	 19929	 0.004249	 0.017012	 0.00429	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19929	 81707	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19929	 81707	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19929	 81708	 0.00093	 0.012109	 0.0035	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19929	 81710	 0.000752	 0.009085	 0.00515	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19930	 20244	 0.033702	 0.13112	 0.00219	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19930	 20244	 0.033702	 0.13112	 0.00219	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19930	 81709	 0.011583	 0.08607	 0.00205	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19930	 81711	 0.054764	 0.12582	 0.00191	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19931	 19932	 2.9e-05	 0.000835	 0.0581	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19931	 81708	 0.00014	 0.01116	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19932	 20067	 8.4e-05	 0.002396	 0.16667	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19932	 81710	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19932	 81710	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19933	 81711	 0.016124	 0.053787	 0.00085	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81708	 19934	 0.002859	 0.016425	 0.00465	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19934	 81711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19934	 81711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19935	 20111	 0.001629	 0.01111	 0.02	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19935	 81713	 0.00232	 0.015061	 0.03	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19936	 19937	 0.004569	 0.012266	 0.00278	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19936	 20135	 0.011086	 0.029298	 0.00686	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19936	 81781	 0.013182	 0.053646	 0.01307	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19937	 19942	 0.007331	 0.021615	 0.00503	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19938	 19939	 9.3e-05	 0.001107	 0.08302	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19938	 20107	 0.000216	 0.004002	 0.2643	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19938	 81712	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19938	 81712	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19939	 37467	 0.000659	 0.011792	 0.83893	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19939	 81713	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81714	 19939	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19940	 20110	 0.000739	 0.007885	 0.01603	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19940	 20110	 0.000739	 0.007885	 0.01603	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81712	 19940	 0.000572	 0.007252	 0.01383	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81713	 19940	 0.001329	 0.010807	 0.03541	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19941	 20138	 0.005875	 0.032782	 0.00837	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81714	 19941	 0.007016	 0.041097	 0.0112	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81714	 19942	 0.006843	 0.019627	 0.00483	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19943	 20000	 0.011423	 0.045736	 0.01152	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19943	 81715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19943	 81715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19944	 19983	 0.006563	 0.053645	 0.01456	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19944	 20000	 0.007701	 0.067204	 0.01846	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19944	 81716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19944	 81716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19945	 20245	 0.11216	 0.18735	 0.00318	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81716	 19945	 0.059336	 0.15254	 0.00236	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19946	 19948	 0.00044	 0.00412	 0.01561	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77678	 19946	 0.001248	 0.02089	 0.07594	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79652	 19946	 0.003166	 0.040479	 0.15838	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19946	 81717	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19946	 81717	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19947	 81719	 0.012653	 0.032525	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79652	 19948	 0.003059	 0.040465	 0.12818	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19948	 81718	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81719	 19948	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81719	 19949	 0.016638	 0.042313	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19950	 19951	 0.007077	 0.053767	 0.00122	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19951	 20265	 0.009314	 0.0791	 0.00185	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19952	 19953	 0.000269	 0.002162	 0.00061	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19952	 19975	 0.002887	 0.020032	 0.00572	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19952	 19978	 0.00722	 0.04229	 0.01152	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79664	 19952	 0.003391	 0.035942	 0.01067	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19952	 81720	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19952	 81720	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19953	 19968	 0.00056	 0.004496	 0.00126	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19954	 26557	 0.002996	 0.029357	 0.00057	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81720	 19954	 0.004021	 0.014363	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81720	 19954	 0.004021	 0.014363	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19955	 19956	 0.00065	 0.002298	 0.00052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19955	 81721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19955	 81721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19956	 81722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19956	 81722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81722	 19957	 0.002528	 0.017353	 0.00032	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19957	 81723	 0.001138	 0.008318	 0.00015	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19958	 19967	 0.001032	 0.007907	 0.00212	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79664	 19958	 0.00225	 0.024113	 0.00771	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19958	 81723	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19958	 81723	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19959	 19961	 0.002152	 0.008371	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19959	 19961	 0.002152	 0.008371	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19959	 19980	 0.001729	 0.013077	 0.00043	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19960	 19961	 0.004631	 0.018016	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19960	 19961	 0.004631	 0.018016	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19960	 81843	 0.005909	 0.02185	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19960	 81843	 0.005909	 0.02185	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19961	 19962	 0.007708	 0.015261	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79665	 19961	 0.018383	 0.071517	 0.00119	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79665	 19961	 0.018383	 0.071517	 0.00119	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19962	 19970	 0.021032	 0.014898	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19963	 19964	 0.001168	 0.009102	 0.00017	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19963	 19980	 0.001057	 0.007854	 0.00019	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19964	 19965	 0.001083	 0.006161	 0.00019	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19965	 19969	 0.019758	 0.014969	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19965	 81724	 0.001243	 0.006844	 0.00015	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19966	 19967	 0.000807	 0.00323	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19966	 81724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19966	 81724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19967	 19968	 0.00038	 0.00316	 0.00096	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81722	 19971	 0.028353	 0.073484	 0.00139	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19971	 81725	 0.026669	 0.08801	 0.00143	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81720	 19972	 0.007705	 0.038969	 0.00076	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19972	 81725	 0.006874	 0.042262	 0.00076	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81720	 19973	 0.027286	 0.03551	 0.0005	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19974	 19975	 0.003481	 0.014373	 0.0034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19974	 19978	 0.005346	 0.024071	 0.0064	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19975	 19977	 0.007311	 0.028442	 0.0076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19975	 81725	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19975	 81725	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81725	 19976	 0.064844	 0.099336	 0.00139	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19977	 19979	 0.004779	 0.019133	 0.00482	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	19978	 19979	 0.009377	 0.033955	 0.00729	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	19978	 81798	 0.004655	 0.047059	 0.01384	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19979	 20295	 0.004104	 0.024446	 0.00643	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19981	 81839	 0.091439	 0.25952	 0.00408	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19981	 81851	 0.15589	 0.28135	 0.00407	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81716	 19982	 0.035805	 0.2015	 0.00435	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19982	 81726	 0.22152	 0.6361	 0.0098	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19982	 81839	 0.026925	 0.20743	 0.00397	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19983	 19984	 0.003113	 0.024114	 0.00845	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19984	 81769	 0.006483	 0.050225	 0.0176	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19985	 20102	 0.002507	 0.017268	 0.03049	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19985	 20247	 0.001749	 0.012211	 0.02096	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19986	 19987	 0.002534	 0.028976	 0.00812	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19986	 20043	 0.001771	 0.019591	 0.00588	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19987	 20321	 0.003093	 0.034206	 0.01026	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	19987	 81726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19987	 81726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81198	 19988	 0.010926	 0.10084	 0.40206	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19988	 81727	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81728	 19988	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19989	 19999	 0.010726	 0.040772	 0.01141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81727	 19989	 0.003961	 0.017651	 0.0048	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19990	 19992	 0.010044	 0.026077	 0.00633	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81727	 19990	 0.002021	 0.014023	 0.004	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19990	 81729	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19990	 81729	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19990	 81731	 0.004263	 0.027283	 0.00918	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81729	 19991	 0.020029	 0.039655	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19991	 81730	 0.093048	 0.06846	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19992	 20300	 0.014214	 0.037568	 0.00879	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	19992	 81730	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19992	 81730	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81730	 19993	 0.061594	 0.048745	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19993	 81836	 0.086002	 0.06597	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19994	 20312	 0.005869	 0.032568	 0.0099	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	19994	 81731	 0.005092	 0.032797	 0.0086	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79654	 19995	 0.000834	 0.01219	 0.04671	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	19995	 81731	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81732	 19995	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79654	 19996	 0.000854	 0.010217	 0.03955	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	19997	 20247	 0.001091	 0.01131	 0.02172	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	19998	 20007	 0.025006	 0.14215	 0.00257	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81728	 19998	 0.025659	 0.15776	 0.00284	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19998	 81837	 0.086964	 0.26713	 0.00501	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	19999	 20328	 0.010804	 0.04326	 0.0109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20000	 20001	 0.005636	 0.028812	 0.00785	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20000	 20124	 0.004106	 0.045412	 0.01362	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20001	 20322	 0.01621	 0.082884	 0.0226	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79503	 20002	 0.021737	 0.064096	 0.01491	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20002	 81740	 0.011809	 0.098035	 0.0258	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20003	 20004	 0.00804	 0.031602	 0.00827	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20003	 20337	 0.01465	 0.057587	 0.01507	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20004	 20027	 0.004159	 0.027868	 0.00854	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79660	 20006	 0.01409	 0.011597	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79660	 20007	 0.035631	 0.24462	 0.00446	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20008	 20009	 0.009418	 0.043211	 0.01107	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20008	 20010	 0.012909	 0.034119	 0.00799	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20009	 20328	 0.010179	 0.045833	 0.0122	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20010	 20011	 0.006679	 0.017339	 0.00421	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20011	 81733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20011	 81733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20012	 20013	 0.004784	 0.032839	 0.00958	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20013	 81803	 0.007345	 0.053643	 0.01379	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20014	 20015	 6.3e-05	 0.001651	 0.13605	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20014	 20203	 5.5e-05	 0.001532	 0.11478	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20014	 81734	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20014	 81734	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20015	 20016	 9.8e-05	 0.002799	 0.19474	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20015	 81735	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20015	 81735	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20017	 81736	 0.006374	 0.016386	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20017	 81738	 0.014958	 0.0429	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20018	 20023	 0.00252	 0.010089	 0.00254	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81717	 20018	 0.002257	 0.008872	 0.00232	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20018	 81736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20018	 81736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81717	 20019	 0.014481	 0.057984	 0.01461	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20019	 81737	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20019	 81737	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20019	 82019	 0.00133	 0.013552	 0.00349	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20019	 83651	 0.003073	 0.021092	 0.00615	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20020	 20021	 0.025963	 0.043737	 0.00062	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20021	 81738	 0.035908	 0.091322	 0.00144	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20022	 20023	 0.001869	 0.006094	 0.00162	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81718	 20022	 0.006738	 0.023113	 0.00554	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20023	 81738	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20023	 81738	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20023	 82019	 0.006098	 0.030071	 0.00813	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81737	 20024	 0.007036	 0.051426	 0.00095	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20024	 83654	 0.006039	 0.037125	 0.00067	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81734	 20025	 0.021616	 0.074167	 0.01777	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81735	 20025	 0.009591	 0.044003	 0.01127	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20025	 81740	 0.006543	 0.033425	 0.00841	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20026	 81739	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20026	 81739	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81740	 20027	 0.005806	 0.036076	 0.01018	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20028	 20033	 0.001718	 0.008688	 0.00242	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20028	 20034	 0.003077	 0.011697	 0.00327	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20028	 81742	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20028	 81742	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20028	 81747	 0.000869	 0.009609	 0.00288	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20029	 20033	 0.002131	 0.008671	 0.00211	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20029	 81743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20029	 81743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81743	 20030	 0.003807	 0.023138	 0.00043	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20030	 81748	 0.008103	 0.031173	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81742	 20031	 0.015799	 0.015803	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20032	 20039	 0.13586	 0.10294	 0.00142	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20032	 20040	 0.11586	 0.091692	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20032	 81744	 0.009364	 0.053232	 0.00096	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20032	 81748	 0.015303	 0.049279	 0.00084	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20033	 81745	 0.001354	 0.013932	 0.00395	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20034	 81744	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20034	 81744	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20034	 81745	 0.001895	 0.014204	 0.00346	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20035	 20042	 0.000367	 0.004459	 0.01444	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79582	 20035	 0.018339	 0.12434	 0.23056	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79644	 20035	 0.000579	 0.010081	 0.03385	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79652	 20035	 0.004856	 0.047069	 0.16679	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20035	 81745	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81746	 20035	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79645	 20036	 0.008146	 0.039751	 0.00069	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81743	 20036	 0.007241	 0.056437	 0.00105	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20037	 20363	 0.000281	 0.007421	 0.61205	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20037	 81747	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20037	 81747	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95342	 20037	 0.001063	 0.01978	 1.3144	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 0	 -30.0	 30.0;
	81747	 20038	 0.001578	 0.01515	 0.00441	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20039	 20125	 0.05253	 0.14907	 0.00234	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81748	 20039	 0.043489	 0.10298	 0.00188	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81744	 20041	 0.056563	 0.11199	 0.00164	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20042	 20274	 0.004389	 0.042531	 0.15065	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20042	 81749	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20042	 81749	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81745	 20043	 0.001485	 0.021402	 0.00777	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81749	 20043	 0.001288	 0.012362	 0.0036	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81746	 20044	 0.026345	 0.12856	 0.00222	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20044	 81792	 0.029148	 0.12462	 0.00282	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20045	 20163	 4.6e-05	 0.001227	 0.10297	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20045	 81750	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20045	 81750	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95335	 20045	 0.000345	 0.009405	 0.91717	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20046	 20047	 0.012549	 0.048818	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79645	 20046	 0.007482	 0.026726	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79645	 20046	 0.007482	 0.026726	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20046	 81789	 0.023819	 0.092664	 0.00155	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20046	 81789	 0.023819	 0.092664	 0.00155	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20047	 20049	 0.021801	 0.061866	 0.00097	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79645	 20047	 0.021009	 0.070084	 0.00111	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20048	 20049	 0.006589	 0.024363	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81748	 20048	 0.013722	 0.06982	 0.00158	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20050	 20051	 0.001352	 0.016051	 0.00559	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20050	 20367	 0.006866	 0.050145	 0.01289	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20051	 81751	 0.002031	 0.02555	 0.00792	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20052	 20054	 0.000578	 0.008588	 0.03183	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79640	 20052	 0.00106	 0.00938	 0.03975	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79658	 20052	 0.001124	 0.012271	 0.0238	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79658	 20052	 0.001124	 0.012271	 0.0238	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20052	 81751	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81752	 20052	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20053	 20180	 0.053947	 0.13982	 0.00264	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81752	 20053	 0.037902	 0.087982	 0.00168	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20053	 81851	 0.082351	 0.3367	 0.00681	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20054	 20055	 0.001149	 0.009573	 0.02986	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20055	 20097	 0.001178	 0.019149	 0.03781	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20055	 20102	 0.005296	 0.037153	 0.06329	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20055	 81753	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20055	 81753	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20056	 81754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20056	 81754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20057	 20058	 0.001672	 0.010278	 0.00296	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20057	 81759	 0.002163	 0.0137	 0.00372	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81710	 20058	 0.003794	 0.024807	 0.00631	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20058	 81755	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20058	 81755	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81710	 20059	 0.004172	 0.016702	 0.00421	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20059	 81758	 0.004058	 0.012684	 0.00367	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20060	 20061	 0.000179	 0.002092	 0.00732	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20060	 81756	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81757	 20060	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20061	 81758	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20061	 81758	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20062	 20070	 0.015156	 0.045617	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81757	 20062	 0.013195	 0.037844	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81757	 20063	 0.033145	 0.033477	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20064	 20065	 0.000931	 0.007334	 0.00215	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81756	 20064	 0.000675	 0.004773	 0.00131	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81758	 20064	 0.003183	 0.013473	 0.00303	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20065	 20069	 0.002523	 0.018149	 0.00481	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20066	 20068	 0.001058	 0.005318	 0.00138	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81756	 20066	 0.002833	 0.014092	 0.00455	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20067	 81759	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20067	 81759	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81285	 20068	 0.003109	 0.016118	 0.00394	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81089	 20070	 0.023019	 0.073816	 0.00183	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20071	 20072	 0.007666	 0.017389	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20071	 20076	 0.005026	 0.018854	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20071	 81776	 0.00213	 0.014621	 0.00027	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20072	 20073	 0.01508	 0.043251	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20073	 20075	 0.009643	 0.019734	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20073	 20099	 0.076818	 0.060794	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20073	 20100	 0.021628	 0.062033	 0.00095	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20074	 20077	 0.004552	 0.015023	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20074	 20078	 0.005999	 0.015858	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20075	 20076	 0.004233	 0.008663	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20076	 20077	 0.004454	 0.012774	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20077	 81762	 0.003377	 0.014435	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20078	 81760	 0.006774	 0.015727	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20079	 20080	 0.000919	 0.004869	 0.00162	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20079	 20082	 0.001324	 0.006075	 0.00156	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20080	 20088	 0.001377	 0.00945	 0.00276	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20080	 81760	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20080	 81760	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81760	 20081	 0.002183	 0.005658	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20081	 81761	 0.008936	 0.027442	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20082	 20103	 0.001733	 0.023761	 0.00956	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20082	 81761	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20082	 81761	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20082	 81771	 0.00175	 0.017092	 0.0048	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20082	 81775	 0.002176	 0.019921	 0.00798	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20083	 20084	 0.014039	 0.040265	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20083	 81772	 0.008432	 0.027825	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81761	 20084	 0.009042	 0.030164	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20084	 81784	 0.71736	 0.56871	 0.00716	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20085	 81774	 0.023103	 0.02541	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20086	 20087	 0.031352	 0.024812	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20087	 81762	 0.010434	 0.020659	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20088	 81762	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20088	 81762	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20088	 81775	 0.001009	 0.0076	 0.00211	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20089	 81765	 0.023877	 0.033845	 0.00069	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20090	 20091	 0.011162	 0.008749	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20090	 20115	 0.036453	 0.027618	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20090	 81765	 0.01229	 0.031255	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20092	 20113	 7.9e-05	 0.001027	 0.06556	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20092	 81763	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20092	 81763	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20093	 20096	 0.00435	 0.036126	 0.00088	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81765	 20093	 0.00506	 0.025745	 0.00058	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20093	 81767	 0.015556	 0.031834	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20094	 20120	 0.000728	 0.00461	 0.00965	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79642	 20094	 0.000483	 0.006414	 0.0137	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81763	 20094	 0.000733	 0.004758	 0.00948	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20094	 81766	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20094	 81766	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79643	 20095	 0.003984	 0.013885	 0.00322	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20095	 81767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20095	 81767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20096	 81768	 0.01288	 0.10715	 0.00203	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20097	 20291	 0.000798	 0.006398	 0.02154	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20097	 81768	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20097	 81768	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81768	 20098	 0.1456	 0.11414	 0.00147	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20100	 20101	 0.02627	 0.1026	 0.00228	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81760	 20100	 0.032132	 0.07609	 0.00139	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81768	 20101	 0.075122	 0.19313	 0.00299	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20101	 81839	 0.090958	 0.29178	 0.00722	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20102	 81769	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20102	 81769	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81769	 20103	 0.002667	 0.039555	 0.01219	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20103	 81770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20103	 81770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81770	 20104	 0.02761	 0.056502	 0.00139	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81761	 20105	 0.073116	 0.051792	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79655	 20106	 0.01315	 0.10249	 0.00192	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20106	 81772	 0.007266	 0.050617	 0.00119	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20107	 20113	 8.3e-05	 0.002191	 0.18052	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20107	 81771	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79655	 20108	 0.022839	 0.10177	 0.00173	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81770	 20108	 0.036465	 0.14187	 0.00237	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79655	 20109	 0.12185	 0.13273	 0.00181	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79654	 20110	 0.00091	 0.010224	 0.01871	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79654	 20110	 0.00091	 0.010224	 0.01871	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20111	 81773	 0.001475	 0.009576	 0.01907	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20112	 20113	 2.1e-05	 0.000269	 0.01715	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20112	 81773	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20113	 81775	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81765	 20114	 0.025491	 0.052165	 0.00128	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20115	 20116	 0.05576	 0.047657	 0.00089	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20116	 81778	 0.018462	 0.036554	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20117	 20118	 0.001936	 0.005196	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20117	 81777	 0.001769	 0.004593	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20117	 81781	 0.016146	 0.045027	 0.00945	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20118	 20119	 0.001677	 0.004354	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81764	 20118	 0.002468	 0.006407	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81766	 20119	 0.002731	 0.007333	 0.00166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20120	 20129	 0.002078	 0.013491	 0.02687	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81763	 20120	 0.000833	 0.005555	 0.01047	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20120	 81777	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81778	 20120	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20121	 20122	 0.062274	 0.049284	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20122	 81779	 0.016143	 0.031961	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81766	 20123	 0.00249	 0.009969	 0.00251	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20123	 81779	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20123	 81779	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20124	 20127	 0.006886	 0.028432	 0.00673	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81747	 20124	 0.018226	 0.083639	 0.02144	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20125	 20128	 0.065652	 0.17357	 0.00315	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20125	 81780	 0.02855	 0.052293	 0.0009	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20126	 20127	 0.002365	 0.009623	 0.00234	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81747	 20126	 0.016263	 0.065124	 0.01641	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20126	 81780	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20126	 81780	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81715	 20128	 0.033656	 0.18145	 0.00366	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81780	 20128	 0.061758	 0.15118	 0.00258	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20129	 81781	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20129	 81781	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20130	 20131	 0.058454	 0.15027	 0.00233	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20130	 20133	 0.089766	 0.1433	 0.0033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20130	 20289	 0.12654	 0.29386	 0.00437	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20130	 20296	 0.036359	 0.11708	 0.00199	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20131	 20133	 0.060313	 0.14283	 0.00261	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20131	 20353	 0.048096	 0.16045	 0.00254	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20131	 20357	 0.053728	 0.15247	 0.0024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20132	 20133	 0.21566	 0.1587	 0.00232	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20134	 20135	 0.008962	 0.027872	 0.00582	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20134	 20136	 0.007753	 0.026597	 0.00637	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20136	 20139	 0.012988	 0.051052	 0.01336	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20136	 20140	 0.007284	 0.024541	 0.0061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20136	 20207	 0.011588	 0.046397	 0.01169	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20136	 20354	 0.020605	 0.14588	 0.04009	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20136	 81782	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20136	 81782	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20137	 20139	 0.007093	 0.03002	 0.00675	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20137	 20141	 0.011777	 0.031125	 0.00729	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20137	 20396	 0.008031	 0.047043	 0.01282	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20138	 20396	 0.004515	 0.023081	 0.00629	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20139	 20213	 0.013159	 0.035827	 0.00789	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20139	 81783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20139	 81783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20140	 20211	 0.01303	 0.034437	 0.00806	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81781	 20141	 0.03572	 0.099647	 0.02093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20141	 81784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20141	 81784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81782	 20142	 0.036595	 0.094845	 0.00179	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81784	 20142	 0.033424	 0.085004	 0.00134	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20143	 81786	 0.064102	 0.11567	 0.00167	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20143	 81787	 0.076312	 0.12281	 0.00192	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20144	 20150	 0.029615	 0.1058	 0.0021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20144	 20398	 0.074472	 0.13641	 0.00236	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20144	 81858	 0.02585	 0.13077	 0.00228	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20145	 20146	 0.014548	 0.039611	 0.00873	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20145	 20212	 0.019587	 0.049243	 0.01276	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20146	 20147	 0.01729	 0.058264	 0.01448	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20147	 81785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20147	 81785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20148	 20149	 0.007242	 0.028462	 0.00745	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20148	 20191	 0.013835	 0.037668	 0.0083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20148	 81786	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20148	 81786	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20149	 20399	 0.010003	 0.042339	 0.00953	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20149	 81787	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20149	 81787	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81057	 20150	 0.040547	 0.16573	 0.00335	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20151	 20152	 0.009619	 0.007612	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20152	 20153	 0.003769	 0.013186	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20152	 20153	 0.003769	 0.013186	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20152	 20158	 0.023939	 0.018945	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20152	 81788	 0.003797	 0.037209	 0.00073	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20153	 20154	 0.005986	 0.030281	 0.00053	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20153	 20161	 0.00298	 0.018109	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20154	 20164	 0.00672	 0.035805	 0.00063	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20155	 20156	 0.033606	 0.026595	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20155	 81788	 0.010212	 0.024181	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79673	 20157	 0.000807	 0.007511	 0.00233	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20157	 81788	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20157	 81788	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20157	 81812	 0.003365	 0.028665	 0.00715	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20159	 20332	 0.070267	 0.14769	 0.00269	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81788	 20159	 0.012346	 0.043227	 0.0012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81788	 20160	 0.075792	 0.083364	 0.00111	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20161	 81789	 0.005096	 0.037243	 0.00069	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20162	 20333	 0.006221	 0.023648	 0.00662	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79662	 20162	 0.011552	 0.041832	 0.00898	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20162	 81789	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20162	 81789	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20163	 20165	 6.9e-05	 0.001848	 0.15507	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20163	 20165	 6.9e-05	 0.001848	 0.15507	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 0	 -30.0	 30.0;
	20163	 81790	 9.9e-05	 0.007891	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20163	 81790	 9.9e-05	 0.007891	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79663	 20164	 0.007275	 0.049933	 0.00091	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20165	 20230	 0.000128	 0.003437	 0.28848	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20165	 20230	 0.000128	 0.003437	 0.28848	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 0	 -30.0	 30.0;
	20165	 81791	 0.000104	 0.008342	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20165	 81791	 0.000104	 0.008342	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20166	 20167	 0.003797	 0.015194	 0.00513	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79662	 20166	 0.005869	 0.023499	 0.00592	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20167	 20168	 0.001219	 0.014475	 0.00504	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20167	 20228	 0.004144	 0.03175	 0.00851	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20168	 20364	 0.00453	 0.042645	 0.01292	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20168	 81792	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20168	 81792	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79653	 20169	 0.001235	 0.016749	 0.00968	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20169	 81793	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20169	 81793	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20169	 82035	 0.000167	 0.002203	 0.00135	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20170	 20268	 0.010054	 0.030842	 0.00084	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20170	 24977	 0.002903	 0.011169	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20171	 20176	 0.047986	 0.031066	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20172	 20176	 0.017706	 0.036233	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81793	 20172	 0.007033	 0.024623	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20172	 83551	 0.009609	 0.027559	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20173	 20175	 0.010949	 0.085339	 0.00159	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20173	 81795	 0.013921	 0.1296	 0.00251	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20174	 20363	 0.000111	 0.003192	 0.22208	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20174	 81794	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20174	 81794	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81793	 20175	 0.00708	 0.058799	 0.00144	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20176	 20177	 0.072181	 0.057124	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79641	 20178	 0.024491	 0.09528	 0.00159	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79641	 20178	 0.024491	 0.09528	 0.00159	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20178	 81796	 0.023911	 0.091994	 0.00157	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20178	 81796	 0.023911	 0.091994	 0.00157	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20178	 83959	 0.033902	 0.11581	 0.00252	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20178	 83959	 0.033902	 0.11581	 0.00252	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20179	 20181	 0.005322	 0.033068	 0.00933	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79659	 20179	 0.001649	 0.016672	 0.0049	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20179	 81796	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20179	 81796	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81796	 20180	 0.056593	 0.14393	 0.00228	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20181	 81797	 0.004146	 0.030628	 0.00884	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20182	 20183	 0.001195	 0.009295	 0.03332	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79658	 20182	 0.002134	 0.026096	 0.05361	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20182	 81797	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20182	 81797	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20183	 20290	 0.001447	 0.015221	 0.06599	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20183	 81798	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20183	 81798	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20184	 20185	 0.006851	 0.022856	 0.0058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20184	 20306	 0.011735	 0.040257	 0.00965	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20185	 20190	 0.004752	 0.017209	 0.00369	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20185	 81799	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20185	 81799	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20186	 20331	 0.009839	 0.038674	 0.01012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79614	 20186	 0.007609	 0.030465	 0.00768	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20187	 20188	 0.003429	 0.015279	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79636	 20187	 0.068624	 0.23446	 0.0051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20188	 20189	 0.021446	 0.023795	 0.00046	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20188	 20198	 0.040091	 0.063994	 0.00147	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79615	 20188	 0.031721	 0.17825	 0.0033	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81799	 20188	 0.026981	 0.076564	 0.0012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20190	 20193	 0.003165	 0.010857	 0.0026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20191	 20192	 0.006895	 0.017332	 0.00449	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20192	 20195	 0.004431	 0.011138	 0.00289	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20192	 81800	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20192	 81800	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20193	 20197	 0.005017	 0.020714	 0.0049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20193	 81801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20193	 81801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81800	 20194	 0.021547	 0.061801	 0.00095	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81801	 20194	 0.015468	 0.040996	 0.00104	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20194	 81802	 0.01539	 0.030471	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20195	 20196	 0.002066	 0.005625	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20196	 20197	 0.002122	 0.008494	 0.00214	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20197	 81802	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20197	 81802	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81801	 20198	 0.023026	 0.066041	 0.00102	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79614	 20199	 0.007884	 0.027047	 0.00648	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79806	 20200	 0.001532	 0.006323	 0.0015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20201	 81803	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20201	 81803	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79486	 20202	 0.004832	 0.023029	 0.00667	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81803	 20202	 0.003354	 0.017473	 0.00458	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20203	 20204	 4.9e-05	 0.001346	 0.10083	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20204	 20206	 4.7e-05	 0.0013	 0.09739	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20204	 81804	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20204	 81804	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79509	 20205	 0.024227	 0.054955	 0.0011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79811	 20205	 0.028659	 0.064297	 0.00103	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20206	 81805	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20206	 81805	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20207	 20358	 0.008834	 0.035951	 0.00876	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20208	 20209	 0.069717	 0.074453	 0.00157	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81782	 20208	 0.055243	 0.12826	 0.00191	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20209	 20210	 0.099248	 0.078546	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81782	 20210	 0.15905	 0.26532	 0.00386	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20211	 20212	 0.010153	 0.027642	 0.00609	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79668	 20214	 0.006048	 0.011078	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20214	 81806	 0.002964	 0.004994	 7e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20215	 20219	 0.000636	 0.006218	 0.00174	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20215	 20222	 0.000884	 0.003474	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20215	 81806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20215	 81806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20216	 20217	 0.003629	 0.009327	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20216	 20237	 0.006881	 0.012416	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79668	 20216	 0.001776	 0.010919	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20217	 81807	 0.005947	 0.015413	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20218	 20226	 0.007914	 0.016196	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20218	 20237	 0.004154	 0.008501	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79649	 20219	 0.00095	 0.013431	 0.00445	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20219	 81807	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20219	 81807	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20219	 81808	 0.000498	 0.005904	 0.00302	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81806	 20220	 0.015982	 0.016142	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20221	 20230	 2.4e-05	 0.000574	 0.05529	 3786.0	 3975.3	 4164.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20221	 20235	 2.8e-05	 0.000611	 0.07203	 3786.0	 3975.3	 4164.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20221	 81808	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20221	 81808	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20222	 20223	 0.0003	 0.003564	 0.00124	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20222	 20224	 0.001152	 0.006912	 0.00209	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20222	 20225	 0.00099	 0.006273	 0.0017	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20223	 20232	 0.001237	 0.014396	 0.00423	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20224	 20225	 0.001903	 0.006529	 0.00156	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20224	 81812	 0.003482	 0.021634	 0.00611	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81794	 20225	 0.015014	 0.16923	 0.04903	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79668	 20226	 0.033976	 0.034317	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81788	 20226	 0.041458	 0.14517	 0.00402	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20227	 20229	 0.00077	 0.008647	 0.01582	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20227	 20229	 0.00077	 0.008647	 0.01582	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79661	 20227	 0.000503	 0.006125	 0.02284	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81791	 20227	 0.000465	 0.005436	 0.01903	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20228	 81809	 0.006471	 0.04577	 0.01256	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77688	 20229	 0.001512	 0.013859	 0.05471	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79648	 20229	 0.000489	 0.007627	 0.02561	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20229	 81809	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20229	 81809	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20230	 81810	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20230	 81810	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81810	 20231	 0.12173	 0.096339	 0.00121	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20232	 20234	 0.000706	 0.006946	 0.00287	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81808	 20233	 0.008593	 0.039422	 0.0101	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20233	 81827	 0.006813	 0.027279	 0.00687	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20234	 81811	 0.000698	 0.007717	 0.00231	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20235	 20280	 6.5e-05	 0.001571	 0.15146	 3786.0	 3975.3	 4164.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20235	 81811	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20235	 81811	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20236	 20281	 0.001691	 0.017263	 0.05483	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20236	 81812	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20236	 81812	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81807	 20237	 0.008418	 0.024144	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20238	 20239	 0.005129	 0.041635	 0.01326	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20238	 81813	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20238	 81813	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20239	 20240	 0.007263	 0.043268	 0.01138	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20239	 20329	 0.01021	 0.040132	 0.0105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79614	 20240	 0.005484	 0.034077	 0.00962	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20241	 20242	 4.9e-05	 0.001051	 0.09381	 3084.0	 3238.2	 3392.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20241	 81814	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20241	 81814	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20242	 81815	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79803	 20243	 0.002734	 0.032465	 0.01131	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81815	 20243	 0.003233	 0.036379	 0.00956	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20243	 81817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20243	 81817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81816	 20244	 0.022982	 0.13968	 0.00258	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81817	 20244	 0.016364	 0.10276	 0.00225	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20245	 20248	 0.042791	 0.14275	 0.00226	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20245	 20359	 0.059901	 0.30309	 0.00528	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81732	 20245	 0.088216	 0.49684	 0.01074	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20246	 81818	 0.006892	 0.037995	 0.00888	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20247	 81818	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20247	 81818	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20248	 20249	 0.068747	 0.13612	 0.002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20248	 20359	 0.061584	 0.28563	 0.00594	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79671	 20248	 0.025309	 0.21057	 0.00399	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20249	 20361	 0.19192	 0.15046	 0.00193	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20250	 20251	 0.004732	 0.034557	 0.00888	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20252	 20257	 0.00388	 0.013716	 0.00309	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20252	 81819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20252	 81819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20253	 20254	 0.015737	 0.011376	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20254	 81820	 0.003852	 0.015744	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20254	 83553	 0.002898	 0.011273	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20255	 81820	 0.002261	 0.013901	 0.00025	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20255	 83548	 0.008533	 0.052463	 0.00095	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20256	 20269	 0.011103	 0.008169	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79653	 20257	 0.008624	 0.063727	 0.0184	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20257	 81820	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20257	 81820	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20258	 20268	 0.018609	 0.014099	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20259	 20260	 0.017615	 0.026984	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20259	 20261	 0.031788	 0.022979	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20259	 20264	 0.035568	 0.028148	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81820	 20259	 0.00496	 0.019294	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20261	 20262	 0.022634	 0.015204	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20263	 20267	 0.063561	 0.083539	 0.00114	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81820	 20263	 0.0262	 0.066632	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20265	 20266	 0.016807	 0.065383	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20265	 20266	 0.016807	 0.065383	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81819	 20265	 0.009746	 0.0341	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81819	 20265	 0.009746	 0.0341	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20265	 84114	 0.013469	 0.051816	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20265	 84114	 0.013469	 0.051816	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81820	 20268	 0.010575	 0.027956	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81820	 20269	 0.007494	 0.008003	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20270	 20271	 0.006686	 0.03415	 0.00859	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20270	 20318	 0.00799	 0.04913	 0.01417	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20270	 81821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20270	 81821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81740	 20271	 0.02082	 0.12947	 0.03658	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20271	 81822	 0.008769	 0.034467	 0.00902	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79650	 20272	 0.009503	 0.061761	 0.12324	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20272	 81822	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20272	 81822	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20273	 20341	 0.004661	 0.051546	 0.01546	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20273	 81823	 0.002866	 0.032766	 0.00999	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20274	 81823	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20274	 81823	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20275	 20276	 0.022772	 0.12945	 0.00234	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81270	 20275	 0.038119	 0.14606	 0.00413	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20276	 81838	 0.023302	 0.15996	 0.00292	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20277	 20278	 0.005634	 0.051248	 0.01294	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79583	 20277	 0.006466	 0.050952	 0.01491	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20279	 20282	 7.5e-05	 0.001973	 0.16251	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20279	 81824	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20279	 81824	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20281	 20283	 0.001284	 0.012522	 0.04361	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20281	 20284	 0.000562	 0.004444	 0.01542	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20281	 81825	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20281	 81825	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79650	 20283	 0.001265	 0.02085	 0.07825	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80003	 20283	 0.001498	 0.015172	 0.03054	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20283	 81826	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20283	 81826	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20284	 81827	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20284	 81827	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20285	 20286	 0.009107	 0.03219	 0.00725	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81827	 20285	 0.005965	 0.020098	 0.005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20286	 20336	 0.014794	 0.039798	 0.01116	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79643	 20287	 0.013521	 0.035736	 0.00836	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81798	 20288	 0.0033	 0.034478	 0.00947	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79675	 20289	 0.042433	 0.084015	 0.00123	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79642	 20290	 0.000437	 0.004773	 0.00926	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79642	 20290	 0.000437	 0.004773	 0.00926	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20290	 81828	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81829	 20290	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79642	 20291	 0.00028	 0.002788	 0.0093	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20292	 20294	 0.01833	 0.048584	 0.00123	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81779	 20292	 0.014513	 0.05366	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81779	 20292	 0.014513	 0.05366	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81829	 20292	 0.01194	 0.04645	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81829	 20292	 0.01194	 0.04645	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20293	 20295	 0.002748	 0.009997	 0.00306	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81828	 20293	 0.005652	 0.022631	 0.0057	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20294	 81830	 0.004973	 0.013585	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20295	 81830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20295	 81830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81779	 20296	 0.08704	 0.13334	 0.00187	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20297	 20301	 0.001668	 0.006678	 0.00168	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20297	 20305	 0.006803	 0.016395	 0.00463	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20297	 81831	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20297	 81831	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20298	 20299	 0.052776	 0.041767	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81831	 20298	 0.029267	 0.038465	 0.00053	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20298	 81833	 0.044922	 0.045373	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20299	 20302	 0.045007	 0.045458	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81831	 20299	 0.028529	 0.022578	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20300	 20301	 0.001684	 0.006553	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20300	 20307	 0.007696	 0.020339	 0.00476	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20300	 20312	 0.003138	 0.014395	 0.00369	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81831	 20302	 0.013338	 0.022277	 0.00038	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20302	 81835	 0.011409	 0.035037	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20303	 20313	 0.009158	 0.036667	 0.00924	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20303	 20329	 0.015333	 0.061398	 0.01547	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20303	 81832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20303	 81832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81832	 20304	 0.01539	 0.068578	 0.00116	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20304	 81833	 0.009187	 0.040939	 0.0007	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20304	 81840	 0.068144	 0.17519	 0.00271	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20305	 81833	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20305	 81833	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20306	 20308	 0.007184	 0.024207	 0.00602	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20306	 20400	 0.010473	 0.044328	 0.00998	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20306	 81834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20306	 81834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20307	 20308	 0.003444	 0.011603	 0.00288	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20307	 81835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20307	 81835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20309	 20311	 0.005255	 0.027935	 0.00648	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20309	 20395	 0.006225	 0.033093	 0.00768	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81732	 20310	 0.27563	 0.24709	 0.00506	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20311	 20312	 0.004777	 0.016388	 0.00393	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20312	 81836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20312	 81836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81727	 20313	 0.020448	 0.058657	 0.01444	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20313	 81837	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20313	 81837	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20314	 20320	 0.011846	 0.047433	 0.01195	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20314	 20347	 0.00896	 0.035218	 0.00921	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20315	 20316	 0.002138	 0.008561	 0.00216	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20315	 20319	 0.00737	 0.029506	 0.00743	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20316	 20317	 0.003616	 0.014479	 0.00365	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20317	 20338	 0.006377	 0.039624	 0.01118	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20318	 20319	 0.007027	 0.043667	 0.01233	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20318	 20338	 0.020917	 0.061677	 0.01435	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79583	 20319	 0.033732	 0.15957	 0.05117	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79583	 20320	 0.031508	 0.13018	 0.03083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20320	 81838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20320	 81838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20321	 20323	 0.003327	 0.030264	 0.00764	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81823	 20321	 0.013918	 0.057952	 0.01808	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20322	 20323	 0.004034	 0.032741	 0.01042	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20322	 20368	 0.00481	 0.041256	 0.01174	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20322	 20389	 0.011694	 0.055742	 0.01615	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20324	 20326	 0.002949	 0.015876	 0.00436	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20324	 20367	 0.006586	 0.044188	 0.01067	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20325	 20327	 0.013542	 0.047198	 0.01094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81753	 20325	 0.013091	 0.045627	 0.01058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20326	 20327	 0.011106	 0.050955	 0.01306	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81753	 20326	 0.015971	 0.065952	 0.01561	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20326	 81839	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20326	 81839	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81769	 20327	 0.015756	 0.057057	 0.01224	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20328	 20330	 0.008741	 0.034999	 0.00882	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20330	 20331	 0.00814	 0.03259	 0.00821	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20330	 81840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20330	 81840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20332	 20335	 0.068698	 0.090291	 0.00124	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20333	 20334	 0.005367	 0.020881	 0.00558	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20336	 20338	 0.008703	 0.030332	 0.00703	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20339	 20340	 0.006589	 0.017106	 0.00415	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20339	 20365	 0.010002	 0.025966	 0.0063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79647	 20340	 0.009986	 0.090861	 0.02295	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20340	 81841	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20340	 81841	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20341	 20365	 0.020669	 0.054632	 0.01279	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81749	 20341	 0.009251	 0.078817	 0.01967	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20342	 20344	 0.004418	 0.015999	 0.00343	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81747	 20342	 0.02011	 0.069	 0.01653	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20343	 81842	 0.012135	 0.015949	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20344	 20347	 0.007172	 0.030353	 0.00683	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20344	 81842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20344	 81842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81842	 20345	 0.061713	 0.048839	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20346	 20359	 0.079205	 0.27722	 0.00574	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81842	 20346	 0.072353	 0.20754	 0.00319	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20348	 20349	 6.3e-05	 0.001084	 0.00059	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20348	 26554	 0.000581	 0.008739	 0.00615	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20348	 81843	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20348	 81843	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20349	 20350	 0.000156	 0.002611	 0.00148	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79664	 20350	 0.000298	 0.003601	 0.00204	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20350	 81845	 0.00031	 0.005498	 0.00276	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20351	 26543	 0.001482	 0.025349	 0.01374	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79664	 20351	 0.000488	 0.008169	 0.00463	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79670	 20351	 0.00064	 0.011358	 0.00571	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20351	 81844	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20351	 81844	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20352	 37372	 0.005194	 0.037669	 0.07589	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20352	 81845	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20352	 81845	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20353	 81846	 0.02195	 0.078413	 0.00156	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81845	 20354	 0.002776	 0.024221	 0.00665	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20354	 81846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20354	 81846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20355	 20356	 0.008138	 0.036642	 0.00975	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79670	 20355	 0.006983	 0.035672	 0.00897	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20356	 20358	 0.011335	 0.045383	 0.01144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20356	 81847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20356	 81847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81847	 20357	 0.052787	 0.13103	 0.00218	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20359	 20360	 0.03514	 0.14063	 0.00297	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81715	 20359	 0.11929	 0.27701	 0.00412	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81838	 20360	 0.078283	 0.30463	 0.00509	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79646	 20362	 0.005236	 0.047941	 0.09238	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79652	 20362	 0.002634	 0.017966	 0.03235	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20362	 81848	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81849	 20362	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20363	 81850	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20363	 81850	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81850	 20364	 0.003168	 0.034166	 0.00978	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79672	 20365	 0.005412	 0.018564	 0.00445	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81849	 20366	 0.078494	 0.06212	 0.00078	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20367	 20368	 0.001784	 0.025705	 0.00933	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20367	 81851	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20367	 81851	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20368	 20389	 0.005549	 0.040294	 0.01393	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20369	 20371	 0.001179	 0.004867	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20369	 20372	 0.001577	 0.007353	 0.00182	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20369	 20381	 0.000783	 0.007522	 0.00219	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20370	 20385	 0.012609	 0.032679	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20370	 27728	 0.064206	 0.18417	 0.00283	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20370	 81852	 0.003381	 0.010178	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20371	 20374	 0.000716	 0.002605	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20372	 20373	 0.000601	 0.002915	 0.00067	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20372	 81852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20372	 81852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20373	 20374	 0.001109	 0.004358	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20373	 20375	 0.000706	 0.004136	 0.00113	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20373	 20394	 0.001166	 0.005251	 0.0014	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20373	 81857	 0.002112	 0.023769	 0.00687	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20375	 20377	 0.000274	 0.002627	 0.00076	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20375	 20389	 0.005063	 0.033968	 0.0082	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20375	 81853	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20375	 81853	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81853	 20376	 0.011356	 0.021747	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20376	 81854	 0.004147	 0.020976	 0.00036	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20377	 20378	 0.001084	 0.004477	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20377	 20379	 0.001185	 0.005017	 0.00113	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20378	 20393	 0.002602	 0.00989	 0.00277	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20379	 81854	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20379	 81854	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20379	 81857	 0.005276	 0.021472	 0.00523	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20380	 20383	 0.002651	 0.011814	 0.00321	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20380	 20387	 0.002834	 0.013003	 0.00333	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20381	 20387	 0.001577	 0.015143	 0.0044	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20382	 27724	 0.004424	 0.015805	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20382	 27724	 0.004424	 0.015805	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79657	 20382	 0.027494	 0.10696	 0.00179	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79657	 20382	 0.027494	 0.10696	 0.00179	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20383	 20386	 0.001469	 0.006616	 0.00176	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20383	 81855	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20383	 81855	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20384	 20385	 0.016963	 0.032485	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81855	 20384	 0.008618	 0.014518	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20385	 81856	 0.020833	 0.01598	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20386	 20394	 0.002017	 0.008072	 0.00273	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20386	 81856	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20386	 81856	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79656	 20387	 0.00086	 0.01361	 0.00408	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20388	 20389	 0.0019	 0.018159	 0.00598	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79656	 20388	 0.001396	 0.014499	 0.00448	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20390	 20391	 0.002547	 0.025749	 0.00757	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20390	 81857	 0.002966	 0.030215	 0.00779	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79640	 20392	 0.003092	 0.033392	 0.06631	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79640	 20392	 0.003092	 0.033392	 0.06631	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20392	 81857	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20392	 81857	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81857	 20393	 0.003171	 0.012695	 0.0032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20395	 20397	 0.006564	 0.034193	 0.00897	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20396	 20397	 0.001243	 0.017068	 0.00615	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20397	 20399	 0.008654	 0.031336	 0.00672	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81783	 20398	 0.082443	 0.20969	 0.00332	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20399	 20400	 0.008029	 0.044798	 0.01144	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81771	 20399	 0.078184	 0.20336	 0.04947	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20399	 81858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20399	 81858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20401	 20415	 0.000971	 0.011043	 0.09974	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20401	 20441	 0.004723	 0.052055	 0.50897	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20401	 20857	 0.001011	 0.016464	 0.25723	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20401	 21714	 0.00078	 0.013891	 0.14413	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20401	 21992	 0.001457	 0.016943	 0.14655	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20401	 81859	 0.000116	 0.009249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20401	 81859	 0.000116	 0.009249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20402	 21030	 0.000668	 0.014038	 4.9409	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20402	 21381	 0.000382	 0.011965	 6.2567	 6811.0	 7151.6	 7492.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20402	 81861	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20402	 81861	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20402	 81861	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20403	 20412	 0.000709	 0.0128	 0.28386	 1959.0	 2056.9	 2154.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20403	 21305	 6.6e-05	 0.001087	 0.01019	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20403	 21313	 0.000101	 0.00186	 0.01787	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20403	 21323	 0.000512	 0.008481	 0.09059	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20403	 81864	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20403	 81864	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20404	 20406	 0.000211	 0.004335	 1.5345	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20404	 21483	 0.000216	 0.007605	 3.4258	 6388.0	 6707.4	 7026.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20404	 81866	 0.000175	 0.013999	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20404	 81866	 0.000175	 0.013999	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20405	 20436	 7e-05	 0.000814	 0.00713	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20405	 21667	 0.001745	 0.020148	 0.17678	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20405	 21940	 0.001573	 0.019834	 0.30271	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20405	 81869	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20405	 81869	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20406	 21483	 0.000375	 0.009514	 4.1878	 5108.0	 5363.4	 5618.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20406	 81871	 0.000163	 0.013066	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20406	 81871	 0.000163	 0.013066	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81872	 20406	 0.000336	 0.025174	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 0	 -30.0	 30.0;
	81872	 20406	 0.000336	 0.025174	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 0	 -30.0	 30.0;
	20407	 21758	 0.000769	 0.008434	 0.08193	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20407	 21997	 0.000388	 0.004258	 0.04135	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81861	 20407	 0.001947	 0.02207	 0.20114	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20407	 81873	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20407	 81873	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20408	 21120	 4e-05	 0.000644	 0.00649	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20408	 81875	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20408	 81875	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20408	 81883	 0.001224	 0.019116	 0.32546	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20409	 22032	 0.000379	 0.004291	 0.03906	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20409	 22034	 0.000104	 0.001923	 0.01848	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20409	 41668	 0.001329	 0.022215	 0.43316	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20409	 81877	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20409	 81877	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20409	 81902	 0.000437	 0.005109	 0.09053	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20410	 22091	 0.000732	 0.008146	 0.07682	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20410	 81878	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20410	 81878	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20411	 21191	 0.00041	 0.005419	 0.0868	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20411	 21726	 5.1e-05	 0.000936	 0.0175	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20411	 81880	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20411	 81880	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20412	 21238	 5.6e-05	 0.001078	 0.01817	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20412	 21238	 5.6e-05	 0.001078	 0.01817	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20412	 21239	 4.7e-05	 0.000794	 0.0146	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20412	 41378	 0.000712	 0.007189	 0.11833	 1212.0	 1212.0	 1212.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20412	 41378	 0.000712	 0.007189	 0.11833	 1212.0	 1212.0	 1212.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20412	 41378	 0.000712	 0.007189	 0.11833	 1212.0	 1212.0	 1212.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20412	 81881	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20412	 81881	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20413	 20417	 4e-06	 8.6e-05	 0.02971	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20413	 24882	 0.000339	 0.010448	 5.5896	 6811.0	 7151.6	 7492.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20413	 81883	 0.000169	 0.013516	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20413	 81883	 0.000169	 0.013516	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20413	 81883	 0.000169	 0.013516	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20414	 21132	 0.000387	 0.005262	 0.05421	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20414	 21540	 0.000137	 0.001505	 0.01462	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20414	 21570	 0.000124	 0.001358	 0.0132	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20414	 21591	 0.000408	 0.004705	 0.04125	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20414	 81886	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20414	 81886	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20415	 20428	 2.1e-05	 0.000254	 0.00258	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20415	 21992	 0.000585	 0.006657	 0.06012	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20415	 21995	 0.000955	 0.010483	 0.10185	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81861	 20415	 0.002367	 0.02638	 0.24916	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20415	 81888	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20415	 81888	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20416	 81889	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20416	 81889	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20416	 82348	 0.000556	 0.003197	 0.00091	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20417	 21487	 0.000328	 0.008322	 3.6545	 5108.0	 5363.4	 5618.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20417	 27331	 0.000473	 0.010961	 4.6888	 4718.0	 4953.9	 5189.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20417	 81890	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20417	 81890	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20417	 81890	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20418	 21238	 5e-05	 0.000533	 0.00797	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20418	 21239	 6.8e-05	 0.000698	 0.01097	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20418	 81893	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20418	 81893	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20419	 20751	 0.000317	 0.003481	 0.03381	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20419	 20752	 0.000294	 0.004158	 0.03965	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20419	 20766	 0.000517	 0.007337	 0.0694	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20419	 20910	 9.2e-05	 0.001027	 0.00968	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20419	 20913	 0.000235	 0.002714	 0.02379	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20419	 20924	 0.000251	 0.002791	 0.02631	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20419	 81894	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20419	 81894	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20420	 20713	 0.000378	 0.004877	 0.04549	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20420	 21685	 0.000455	 0.005254	 0.04606	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20420	 42371	 0.002163	 0.029318	 0.51838	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20420	 81895	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20420	 81895	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20421	 21745	 0.014922	 0.060732	 0.0148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20421	 21751	 0.004787	 0.021554	 0.00574	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20421	 21891	 0.005417	 0.061948	 0.01735	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20421	 81896	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20421	 81896	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20422	 21190	 6.4e-05	 0.001079	 0.01956	 1556.0	 1556.0	 1556.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20422	 21193	 8.4e-05	 0.000967	 0.00848	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20422	 21238	 7.7e-05	 0.001163	 0.02114	 1420.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20422	 81897	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20422	 81897	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20423	 20796	 0.000566	 0.006532	 0.05726	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81866	 20423	 0.001155	 0.014636	 0.2558	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81871	 20423	 0.000611	 0.006775	 0.06451	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20423	 81898	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20423	 81898	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81871	 20424	 5.6e-05	 0.000642	 0.00563	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20424	 81900	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20424	 81900	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20425	 20748	 0.000357	 0.00876	 4.5852	 5793.0	 6082.6	 6372.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20425	 21483	 0.000322	 0.00663	 2.3519	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20425	 81902	 0.000175	 0.013999	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20425	 81902	 0.000175	 0.013999	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20425	 81902	 0.000175	 0.013999	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81903	 20425	 0.000214	 0.017119	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81903	 20425	 0.000214	 0.017119	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20426	 20713	 0.000451	 0.008189	 0.08186	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20426	 21107	 0.001082	 0.012998	 0.12862	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20426	 81904	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20426	 81904	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20427	 22037	 0.000227	 0.003957	 0.04281	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20427	 22039	 5.7e-05	 0.000663	 0.00581	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20427	 81905	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20427	 81905	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20428	 81906	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20428	 81906	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20429	 20431	 0.001391	 0.011929	 0.00339	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20429	 21936	 0.011012	 0.044813	 0.01092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81878	 20429	 0.001157	 0.017119	 0.00589	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20429	 81907	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20429	 81907	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20430	 20436	 0.002767	 0.030857	 0.29162	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20430	 21108	 0.001163	 0.012695	 0.12468	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20430	 21289	 0.003815	 0.043345	 0.3963	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20430	 21685	 0.000585	 0.010818	 0.10396	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20430	 21926	 0.000992	 0.017402	 0.18632	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20430	 81908	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20430	 81908	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20431	 20432	 0.002996	 0.010591	 0.00239	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20431	 82585	 0.037013	 0.1568	 0.03533	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20432	 22088	 0.003871	 0.01328	 0.00318	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20433	 20434	 0.000311	 0.001561	 0.00041	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20433	 21237	 0.002555	 0.009711	 0.00272	 212.0	 212.0	 212.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81893	 20433	 0.002418	 0.008148	 0.00202	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20435	 21219	 0.000513	 0.00739	 0.00268	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81881	 20435	 0.000111	 0.000654	 0.00053	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20435	 81910	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20435	 81910	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20435	 82365	 0.000908	 0.005754	 0.00156	 233.0	 233.0	 233.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20436	 20929	 0.000417	 0.007362	 0.06887	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20436	 22020	 0.002001	 0.023111	 0.20283	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20436	 81911	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20436	 81911	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20437	 21382	 5e-06	 5.5e-05	 0.00054	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20437	 21387	 4.6e-05	 0.00063	 0.00628	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20438	 20710	 0.001339	 0.021386	 0.21639	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20438	 20857	 0.002026	 0.026157	 0.24436	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20438	 21339	 0.000249	 0.002873	 0.02518	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20438	 81913	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20438	 81913	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20439	 21729	 0.001269	 0.008515	 0.00206	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20439	 21752	 0.000205	 0.002246	 0.00062	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20439	 81915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20439	 81915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20440	 20973	 0.000183	 0.002068	 0.01882	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20440	 20985	 0.000213	 0.003535	 0.03313	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20440	 81916	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20440	 81916	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20441	 21651	 0.001453	 0.01678	 0.14718	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20441	 22034	 0.001945	 0.021671	 0.20457	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20441	 81917	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20441	 81917	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20442	 22084	 0.000583	 0.006602	 0.06011	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20442	 81919	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20442	 81919	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20443	 21970	 9.5e-05	 0.001038	 0.01008	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20443	 21997	 0.000212	 0.002397	 0.02183	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20443	 81921	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20443	 81921	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20444	 21722	 0.00125	 0.016948	 0.0098	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20444	 21752	 0.001412	 0.005654	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20444	 21753	 0.000171	 0.001983	 0.00106	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20444	 81922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20444	 81922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20445	 21150	 0.0065	 0.06119	 0.01854	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20445	 21671	 0.002725	 0.027539	 0.0081	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20445	 21672	 0.006038	 0.038243	 0.01038	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20445	 21676	 0.006145	 0.029821	 0.00682	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20445	 21678	 0.004176	 0.011035	 0.00258	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20445	 21681	 0.010215	 0.031929	 0.00925	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20445	 81923	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20445	 81923	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20446	 20900	 0.005371	 0.017919	 0.00454	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20446	 20901	 0.002034	 0.008144	 0.00205	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20446	 81924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20446	 81924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20447	 22065	 0.000127	 0.001468	 0.01287	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20447	 81925	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20447	 81925	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20448	 21345	 0.000718	 0.008672	 0.00492	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20448	 21356	 0.000819	 0.008001	 0.00225	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20448	 21373	 0.000741	 0.00464	 0.00334	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20448	 81926	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20448	 81926	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20449	 20793	 0.006579	 0.050409	 0.0135	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20449	 21151	 0.003191	 0.016032	 0.00417	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20449	 21152	 0.001007	 0.009615	 0.00353	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20450	 22066	 0.002835	 0.009918	 0.00329	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20450	 22067	 0.001502	 0.006014	 0.00152	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20450	 22068	 8.4e-05	 0.000701	 0.00018	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20450	 22070	 0.000897	 0.011284	 0.0035	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20451	 21921	 0.021214	 0.030912	 0.0007	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20451	 21932	 0.000593	 0.003369	 6e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20451	 82665	 0.008366	 0.016396	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20452	 20739	 0.048436	 0.12452	 0.00193	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20452	 20740	 0.11118	 0.091518	 0.00185	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20452	 20745	 0.005721	 0.008764	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20452	 82129	 0.023953	 0.018956	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20453	 21663	 0.002713	 0.007781	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20453	 21665	 0.013916	 0.022213	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20453	 82544	 0.005443	 0.013991	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20454	 82511	 0.003098	 0.00576	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20455	 21954	 0.001731	 0.005103	 0.00119	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20455	 21994	 0.000764	 0.0027	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20456	 21623	 0.000342	 0.000888	 0.00022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20456	 81927	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20456	 81927	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20457	 21907	 0.006728	 0.023447	 0.00544	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20457	 81928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20457	 81928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20458	 22106	 0.001112	 0.023692	 8.8332	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20458	 23398	 8e-06	 0.000162	 0.05715	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20458	 24603	 0.00027	 0.008413	 4.3569	 6811.0	 7151.6	 7492.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20458	 81929	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20458	 81929	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20459	 20878	 0.000189	 0.003838	 1.3887	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20459	 23398	 0.000612	 0.015928	 6.9715	 5108.0	 5363.4	 5618.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20459	 81932	 0.000163	 0.013066	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20459	 81932	 0.000163	 0.013066	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81933	 20459	 0.000317	 0.023776	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 0	 -30.0	 30.0;
	81933	 20459	 0.000317	 0.023776	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 0	 -30.0	 30.0;
	20460	 20465	 5.6e-05	 0.000734	 0.00655	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20460	 22199	 0.000975	 0.010647	 0.10455	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20460	 22222	 0.000566	 0.006529	 0.05723	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20460	 81934	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20460	 81934	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20461	 23330	 0.000153	 0.003087	 1.3207	 4345.0	 4562.3	 4779.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20461	 81935	 0.000373	 0.026131	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20461	 81935	 0.000373	 0.026131	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81936	 20461	 0.000634	 0.047551	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81936	 20461	 0.000634	 0.047551	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20462	 20482	 0.00019	 0.002147	 0.01955	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20462	 22759	 0.003108	 0.057795	 0.55979	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20462	 23371	 0.000229	 0.002546	 0.02401	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20462	 23475	 0.00139	 0.024496	 0.40774	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20462	 81937	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20462	 81937	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20463	 24310	 0.000584	 0.006742	 0.05911	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20463	 24383	 0.000135	 0.001478	 0.01435	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20463	 24387	 0.000127	 0.001389	 0.0135	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20463	 24766	 0.000249	 0.002879	 0.02524	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20463	 24853	 2.1e-05	 0.000231	 0.00227	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20464	 22936	 0.000973	 0.011462	 0.20031	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20464	 23910	 0.000174	 0.003047	 0.0326	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20464	 23944	 0.000246	 0.004234	 0.07373	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20464	 81939	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20464	 81939	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20465	 22826	 0.001101	 0.019898	 0.31448	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20465	 24144	 0.000813	 0.012782	 0.13327	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20465	 81941	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20465	 81941	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20466	 22527	 0.001523	 0.010565	 0.00302	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20466	 22529	 0.002524	 0.021227	 0.00629	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20466	 81942	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20466	 81942	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20467	 22949	 0.001198	 0.01702	 0.16107	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20467	 23932	 5.8e-05	 0.000665	 0.00583	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20467	 81943	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20467	 81943	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20468	 24386	 0.000103	 0.001185	 0.01039	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20468	 24716	 4.5e-05	 0.000506	 0.00461	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20468	 24854	 3.8e-05	 0.000432	 0.00393	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20468	 81944	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20468	 81944	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20469	 22365	 0.001133	 0.013081	 0.11471	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20469	 81946	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20469	 81946	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20469	 83095	 0.002575	 0.029752	 0.26132	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20470	 23590	 0.001029	 0.004632	 0.00123	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20470	 23693	 0.000394	 0.003383	 0.00096	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20470	 81948	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20470	 81948	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20471	 20473	 2.3e-05	 0.000275	 0.00272	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20471	 23996	 0.000693	 0.007564	 0.07427	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20471	 81949	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20471	 81949	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20472	 22402	 0.000639	 0.007062	 0.00212	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20472	 22423	 0.003097	 0.010626	 0.00255	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20472	 81950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20472	 81950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20473	 22178	 0.000194	 0.002236	 0.0196	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20473	 22185	 0.000125	 0.001436	 0.01407	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20473	 23010	 0.001557	 0.024876	 0.405	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20473	 81951	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20473	 81951	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20474	 24324	 1.8e-05	 0.000204	 0.00179	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20474	 81952	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20474	 81952	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20475	 22639	 0.002185	 0.0227	 0.00702	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20475	 81954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20475	 81954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20476	 24766	 0.000424	 0.004798	 0.04368	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20476	 24807	 0.000563	 0.006381	 0.05809	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20476	 24835	 3.6e-05	 0.000403	 0.0038	 810.0	 810.0	 810.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20476	 81955	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20476	 81955	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20477	 23432	 0.000601	 0.006934	 0.06079	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20477	 23450	 0.000194	 0.0022	 0.02002	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20477	 26733	 0.000381	 0.004176	 0.04057	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20477	 81957	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20477	 81957	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20478	 22106	 0.000293	 0.006094	 2.1146	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20478	 81959	 0.000213	 0.017042	 0.0	 1150.0	 1150.0	 1150.0	 0.975	 0.0	 1	 -30.0	 30.0;
	20478	 81959	 0.000213	 0.017042	 0.0	 1150.0	 1150.0	 1150.0	 0.975	 0.0	 1	 -30.0	 30.0;
	20479	 24048	 0.000114	 0.001611	 0.02602	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81935	 20479	 9e-06	 0.000145	 0.00135	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20479	 81962	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20479	 81962	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20480	 23619	 0.001598	 0.025147	 0.26251	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20480	 24000	 0.002627	 0.036392	 0.36449	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20480	 81964	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20480	 81964	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20481	 23439	 0.030273	 0.078612	 0.01909	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20481	 24204	 0.000977	 0.008377	 0.00238	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20481	 24207	 0.00728	 0.02453	 0.0061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20481	 24216	 0.016438	 0.047151	 0.0116	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20481	 24809	 0.002527	 0.014679	 0.00346	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20481	 81966	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20481	 81966	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20482	 23340	 0.001199	 0.013589	 0.12376	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20482	 81967	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20482	 81967	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20483	 23890	 0.007945	 0.046147	 0.01087	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20483	 23892	 0.001576	 0.003797	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20483	 81968	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20483	 81968	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20484	 23902	 5e-05	 0.000618	 0.00621	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20484	 23907	 0.000175	 0.00201	 0.01969	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20484	 81969	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20484	 81969	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20485	 24021	 0.001349	 0.007399	 0.00196	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20485	 24044	 0.00263	 0.010231	 0.00273	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20485	 81971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20485	 81971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20486	 22281	 0.000675	 0.007407	 0.07196	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20486	 22826	 0.000334	 0.003856	 0.03381	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20486	 81972	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20486	 81972	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20487	 22639	 0.022832	 0.053008	 0.01615	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20487	 24096	 0.029727	 0.10365	 0.02405	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20487	 81974	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20487	 81974	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20488	 24352	 0.000489	 0.001676	 0.0004	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20488	 81975	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20488	 81975	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20489	 23427	 0.004895	 0.012708	 0.00308	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20489	 81976	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20489	 81976	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20490	 23320	 0.000862	 0.002237	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20490	 24287	 0.000598	 0.002052	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20490	 81977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20490	 81977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20491	 24185	 0.001218	 0.003061	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20491	 81978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20491	 81978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20492	 22676	 0.000255	 0.001806	 0.0005	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20492	 81979	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20492	 81979	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20493	 22858	 0.019691	 0.10844	 0.00245	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20493	 22859	 0.010719	 0.030745	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20493	 22860	 0.15826	 0.17409	 0.00232	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20493	 22862	 0.067541	 0.13823	 0.0034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 22764	 0.001907	 0.007635	 0.00192	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 22772	 0.000273	 0.002897	 0.00086	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 22774	 0.002168	 0.008678	 0.00219	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 22780	 0.002845	 0.016175	 0.00468	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 22784	 0.00287	 0.009844	 0.00236	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 22786	 0.001265	 0.01073	 0.00643	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 24240	 0.007663	 0.096446	 0.0299	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 81980	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20494	 81980	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20495	 24860	 0.00716	 0.024125	 0.006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20495	 81981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20495	 81981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20496	 22286	 0.028555	 0.087694	 0.00165	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20496	 22608	 0.001896	 0.010777	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20496	 82878	 0.020107	 0.12355	 0.00282	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20496	 82879	 0.011965	 0.088911	 0.00212	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20497	 22632	 0.17719	 0.14024	 0.00177	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20497	 22633	 0.012139	 0.050398	 0.00131	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20497	 22634	 0.053317	 0.10557	 0.00155	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20497	 22635	 0.095282	 0.18867	 0.00277	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20498	 22135	 0.02989	 0.069394	 0.00103	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20498	 22136	 0.003177	 0.009747	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20498	 22141	 0.059201	 0.16981	 0.00261	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20499	 24147	 0.000614	 0.002497	 0.00061	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20499	 24159	 0.002364	 0.008561	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20499	 81982	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20499	 81982	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20500	 22365	 0.001187	 0.013509	 0.12204	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20500	 22695	 0.00021	 0.002374	 0.02161	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20500	 81983	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20500	 81983	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20501	 24859	 0.004233	 0.015398	 0.00471	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20501	 24863	 0.001512	 0.004337	 0.00107	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20501	 81985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20501	 81985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20502	 23891	 0.002445	 0.007642	 0.00221	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20502	 23892	 0.001392	 0.00856	 0.00247	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20502	 81986	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20502	 81986	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20503	 22337	 0.029286	 0.07605	 0.01846	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20503	 81987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20503	 81987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20504	 82852	 0.010613	 0.02813	 0.00071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20504	 82853	 0.002334	 0.00542	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20505	 22130	 3.4e-05	 0.00038	 0.00346	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20505	 23944	 0.000218	 0.002521	 0.0221	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20506	 22376	 0.033977	 0.080458	 0.00147	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20506	 22377	 0.070407	 0.17907	 0.00283	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20506	 82809	 0.016031	 0.042378	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20507	 22857	 0.001488	 0.007711	 0.00188	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81972	 20507	 0.000149	 0.000615	 0.00015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20508	 22942	 0.002338	 0.00802	 0.00192	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20508	 81988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20508	 81988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20508	 82969	 0.009259	 0.021494	 0.00655	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20509	 23382	 0.029992	 0.14471	 0.00256	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20509	 23519	 0.042939	 0.11038	 0.00171	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20509	 23520	 0.023105	 0.018285	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20509	 23521	 0.069699	 0.090708	 0.00127	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20510	 24243	 0.058358	 0.046184	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20510	 24244	 0.18432	 0.18619	 0.00247	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20510	 83420	 0.008457	 0.02961	 0.00082	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20511	 22383	 9.9e-05	 0.001667	 0.03022	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20511	 23392	 0.001956	 0.03554	 0.35637	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20511	 81989	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20511	 81989	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20512	 22393	 0.01909	 0.063682	 0.00101	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20512	 82813	 0.009215	 0.026149	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20513	 22327	 0.04386	 0.092185	 0.00168	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20513	 23949	 0.29402	 0.23275	 0.00293	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20513	 23952	 0.052843	 0.11325	 0.00198	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20514	 23379	 0.028402	 0.1386	 0.00239	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20514	 23881	 0.052263	 0.13546	 0.00256	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20514	 23883	 0.024751	 0.15218	 0.00274	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20514	 23884	 0.03743	 0.065826	 0.00124	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20515	 23349	 0.026757	 0.029429	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20515	 83085	 0.000917	 0.000977	 1e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20516	 23943	 0.000253	 0.000854	 0.00021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20516	 83251	 0.001095	 0.003653	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20517	 24050	 0.006938	 0.0129	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20518	 22330	 0.020858	 0.041298	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20518	 22331	 0.00666	 0.013186	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81987	 20518	 0.030812	 0.024384	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20519	 23891	 0.006088	 0.015805	 0.00384	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20519	 23893	 0.005419	 0.045576	 0.0135	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20519	 81991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20519	 81991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20520	 22386	 0.003032	 0.018638	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81990	 20520	 0.018697	 0.043408	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20521	 22113	 0.00485	 0.054604	 0.01579	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20521	 22114	 0.00361	 0.027459	 0.00863	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20521	 81992	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20521	 81992	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20521	 82727	 0.000541	 0.008271	 0.00266	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20522	 82811	 0.008596	 0.018067	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20523	 23930	 0.00475	 0.008484	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20523	 23945	 0.020698	 0.027203	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20523	 23946	 0.038485	 0.030166	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20523	 83247	 0.050311	 0.039816	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20524	 23948	 0.001117	 0.004544	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20524	 83251	 0.000609	 0.002394	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20525	 22126	 0.000994	 0.003409	 0.00082	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20525	 81993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20525	 81993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20526	 22392	 0.091699	 0.25638	 0.05398	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20526	 22743	 0.077855	 0.20615	 0.04836	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20526	 23345	 0.001258	 0.003608	 0.00089	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20526	 24101	 0.10661	 0.27777	 0.0677	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81960	 20526	 0.005364	 0.014177	 0.00332	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20526	 81994	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20526	 81994	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20527	 23339	 0.00611	 0.015863	 0.00385	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20527	 24858	 0.011948	 0.050573	 0.01138	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20527	 81995	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20527	 81995	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20528	 22321	 0.065499	 0.16839	 0.00261	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20528	 22425	 0.15806	 0.12509	 0.00158	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20528	 23114	 0.44051	 0.44226	 0.00715	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20528	 23116	 0.30164	 0.222	 0.00325	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20529	 23878	 0.019201	 0.097116	 0.00189	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20529	 83230	 0.076445	 0.20265	 0.00514	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20530	 22133	 0.062216	 0.14445	 0.00215	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20530	 23467	 0.090455	 0.068534	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20530	 23469	 0.22644	 0.17923	 0.00226	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20531	 20537	 0.000174	 0.003583	 1.2675	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20531	 81996	 0.000175	 0.013999	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20531	 81996	 0.000175	 0.013999	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20531	 81996	 0.000175	 0.013999	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20532	 26524	 0.000128	 0.002388	 0.04226	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20532	 26532	 8.6e-05	 0.001543	 0.03003	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20532	 26539	 6.3e-05	 0.000869	 0.00859	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20532	 81999	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20532	 81999	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20533	 20541	 0.000148	 0.004579	 2.356	 6811.0	 7151.6	 7492.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20533	 27331	 0.000161	 0.004077	 1.7799	 5108.0	 5363.4	 5618.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20533	 82000	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20533	 82000	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20533	 82000	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82001	 20533	 0.000167	 0.013374	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82001	 20533	 0.000167	 0.013374	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20534	 24828	 0.00227	 0.025737	 0.23466	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20534	 27173	 0.000556	 0.005891	 0.06145	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20534	 27176	 0.000226	 0.003985	 0.06617	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20534	 27308	 0.0009	 0.010392	 0.09112	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20534	 82002	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20534	 82002	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20535	 24864	 0.000799	 0.012564	 0.13099	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20535	 24869	 0.000157	 0.002868	 0.04442	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20535	 25179	 0.002547	 0.035453	 0.35156	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20535	 82003	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20535	 82003	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20536	 20546	 0.000694	 0.012598	 0.12598	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20536	 24966	 0.000524	 0.009499	 0.09497	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20536	 26467	 0.000167	 0.002657	 0.04363	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20536	 26468	 0.000127	 0.001393	 0.01353	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20536	 27384	 0.003223	 0.037278	 0.32778	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20536	 82005	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20536	 82005	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20536	 84364	 0.001612	 0.028429	 0.47361	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20537	 27331	 0.000243	 0.004522	 1.976	 4162.0	 4370.1	 4578.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20537	 82006	 0.000158	 0.012644	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20537	 82006	 0.000158	 0.012644	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82007	 20537	 0.0003	 0.022524	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 0	 -30.0	 30.0;
	82007	 20537	 0.0003	 0.022524	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20538	 25689	 0.000223	 0.00247	 0.02351	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20538	 26078	 0.000872	 0.009709	 0.09157	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20538	 27179	 0.000887	 0.016416	 0.15782	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20538	 27772	 0.000928	 0.010189	 0.09899	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20538	 82008	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20538	 82008	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20539	 24918	 0.000115	 0.001134	 0.0194	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20539	 24918	 0.000115	 0.001134	 0.0194	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20539	 26532	 0.000451	 0.00748	 0.17004	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20539	 82010	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20539	 82010	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20540	 25283	 0.000449	 0.004073	 0.00213	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20540	 25293	 4.8e-05	 0.000795	 0.00024	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20540	 82011	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20540	 82011	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20541	 25669	 0.000363	 0.011199	 6.0053	 6811.0	 7151.6	 7492.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20541	 27162	 6.1e-05	 0.001545	 0.65751	 5108.0	 5363.4	 5618.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20541	 82012	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20541	 82012	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20541	 82012	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20541	 82012	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20541	 82012	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20542	 20545	 0.000755	 0.010279	 0.10592	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20542	 26942	 0.000266	 0.004716	 0.0494	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82000	 20542	 6.4e-05	 0.001056	 0.0099	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20542	 82013	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20542	 82013	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20543	 27721	 0.001137	 0.012658	 0.11941	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82012	 20543	 4e-05	 0.000669	 0.01302	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20543	 82014	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20543	 82014	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20543	 84364	 0.000318	 0.007542	 0.13657	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20544	 20693	 0.000357	 0.003915	 0.03803	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20544	 21110	 0.001089	 0.0203	 0.19238	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20544	 24873	 0.000939	 0.017369	 0.167	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20544	 27179	 0.000609	 0.006903	 0.06285	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20544	 82015	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20544	 82015	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20545	 24942	 0.000868	 0.013781	 0.14478	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20545	 27200	 0.001146	 0.018128	 0.3942	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20545	 27685	 0.000283	 0.003175	 0.06105	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82000	 20545	 0.000559	 0.009806	 0.10493	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20545	 82017	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20545	 82017	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20546	 25201	 0.000243	 0.00251	 0.03943	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20546	 25201	 0.000243	 0.00251	 0.03943	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20546	 25205	 0.000419	 0.004428	 0.06623	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20546	 25205	 0.000419	 0.004428	 0.06623	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20546	 26461	 0.000166	 0.002806	 0.02873	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20546	 27241	 0.003041	 0.034508	 0.315	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20546	 27385	 0.00224	 0.025878	 0.22718	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20546	 82019	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20546	 82019	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20547	 26940	 0.000871	 0.015955	 0.29441	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82012	 20547	 0.000221	 0.002339	 0.03498	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82012	 20547	 0.000221	 0.002339	 0.03498	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20547	 82021	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20547	 82021	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20548	 26379	 0.001784	 0.019584	 0.1904	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20548	 26798	 0.00063	 0.006881	 0.06756	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20548	 27174	 0.000304	 0.004411	 0.03989	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20548	 27786	 0.000308	 0.003434	 0.03239	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20548	 82023	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20548	 82023	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20549	 27331	 5.7e-05	 0.001179	 0.40798	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20549	 82025	 0.000373	 0.026131	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20549	 82025	 0.000373	 0.026131	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20550	 25211	 3e-05	 0.000553	 0.0102	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20550	 25213	 0.000255	 0.002693	 0.04028	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20550	 25213	 0.000255	 0.002693	 0.04028	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20550	 25759	 0.001608	 0.0292	 0.29249	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20550	 27142	 0.000151	 0.003659	 0.0631	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20550	 27648	 0.001172	 0.015857	 0.27962	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20550	 82028	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20550	 82028	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20551	 26683	 0.001934	 0.016049	 0.00422	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20551	 26736	 0.004117	 0.025551	 0.00619	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20551	 26795	 0.000745	 0.0057	 0.0042	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20551	 82029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20551	 82029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20551	 83105	 0.016628	 0.058193	 0.01929	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20551	 83487	 0.039886	 0.13693	 0.03284	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20551	 84206	 0.001134	 0.00954	 0.00283	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20552	 27598	 0.011511	 0.030422	 0.00712	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20552	 27626	 0.000182	 0.002713	 0.0008	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20552	 27630	 0.001366	 0.005313	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20552	 82030	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20552	 82030	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20553	 27059	 0.000717	 0.008194	 0.0025	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20553	 27061	 0.00112	 0.004257	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20554	 25478	 0.000274	 0.003719	 0.05666	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20554	 26504	 2.5e-05	 0.000433	 0.00763	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20554	 82031	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20554	 82031	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20555	 25157	 0.000111	 0.002614	 0.04796	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20555	 25169	 0.000178	 0.002029	 0.01832	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20555	 26356	 0.000888	 0.010299	 0.1095	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81996	 20555	 0.000563	 0.00627	 0.05913	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20555	 82032	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20555	 82032	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20556	 26050	 0.000947	 0.013921	 0.00426	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20556	 27194	 0.000862	 0.013175	 0.00424	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20556	 27197	 0.001335	 0.015261	 0.00427	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20556	 82034	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20556	 82034	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20556	 83951	 0.000855	 0.011218	 0.00538	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20557	 24966	 0.000414	 0.007219	 0.07811	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20557	 82035	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20557	 82035	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20557	 84364	 0.001321	 0.021713	 0.33322	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20558	 25047	 8.3e-05	 0.001442	 0.0156	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20558	 25063	 9.8e-05	 0.001129	 0.0099	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20558	 25065	 6.9e-05	 0.000787	 0.00717	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20558	 82037	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20558	 82037	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20559	 25981	 0.000457	 0.008378	 0.15447	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20559	 27196	 0.000194	 0.002304	 0.02116	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20559	 27198	 0.00019	 0.002568	 0.03913	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20559	 82038	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20559	 82038	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20560	 20564	 4e-06	 6e-05	 0.00057	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20560	 27013	 2.4e-05	 0.00041	 0.00713	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20560	 27053	 0.000365	 0.0042	 0.04115	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20560	 82039	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20560	 82039	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20561	 25047	 0.000152	 0.001723	 0.01569	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20561	 25073	 4.3e-05	 0.000493	 0.00432	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20561	 27252	 0.000932	 0.01017	 0.09986	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20561	 82040	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20561	 82040	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20562	 26604	 4.2e-05	 0.000741	 0.00769	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20562	 82042	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20562	 82042	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20563	 25736	 0.000667	 0.008817	 0.14126	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20563	 26672	 3e-05	 0.000538	 0.0085	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20563	 82044	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20563	 82044	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20564	 27067	 0.000179	 0.003308	 0.03179	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20564	 82046	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20564	 82046	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20565	 25067	 0.000305	 0.005641	 0.0542	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20565	 27071	 4e-05	 0.000574	 0.00526	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20565	 82048	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20565	 82048	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20566	 25674	 0.000763	 0.002571	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20566	 82049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20566	 82049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20567	 27330	 0.000116	 0.001369	 0.02391	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82025	 20567	 0.000147	 0.001482	 0.0244	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20568	 20805	 0.00018	 0.001821	 0.02996	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20568	 20805	 0.00018	 0.001821	 0.02996	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20568	 25038	 0.000828	 0.015324	 0.14731	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20568	 26244	 0.00028	 0.005012	 0.09757	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20568	 26253	 0.000182	 0.00182	 0.03033	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20568	 26253	 0.000182	 0.00182	 0.03033	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81890	 20568	 0.000185	 0.001953	 0.0292	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81890	 20568	 0.000185	 0.001953	 0.0292	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20569	 25684	 0.001418	 0.005676	 0.00192	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20569	 25685	 0.00021	 0.002279	 0.0014	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20569	 25687	 0.005767	 0.024408	 0.00549	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20569	 82050	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20569	 82050	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20570	 26518	 0.000706	 0.003216	 0.00102	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20570	 26522	 0.000307	 0.001978	 0.00052	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20570	 26523	 0.001396	 0.009873	 0.00271	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20570	 82051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20570	 82051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20571	 26163	 0.008099	 0.014833	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20571	 26168	 0.006495	 0.015078	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20571	 26169	 0.002264	 0.005257	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20571	 26170	 0.000657	 0.004509	 8e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20571	 26171	 0.008418	 0.006661	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20572	 27283	 0.014677	 0.042094	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20572	 27284	 0.004424	 0.011251	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20572	 27285	 0.018597	 0.072349	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20573	 27773	 0.000533	 0.004482	 0.00133	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20573	 83957	 0.007904	 0.050064	 0.01359	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20573	 84625	 0.000579	 0.001952	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20574	 27784	 0.011607	 0.040455	 0.00938	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20574	 27793	 0.003256	 0.008866	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20574	 27795	 0.003103	 0.007203	 0.00219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20574	 82052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20574	 82052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20575	 25227	 0.014547	 0.034696	 0.00078	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20575	 25228	 0.02672	 0.021146	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20575	 83667	 0.016758	 0.026748	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20576	 26401	 0.000711	 0.009103	 0.00272	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20576	 82053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20576	 82053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20576	 84086	 0.003434	 0.029247	 0.0073	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20577	 25255	 0.000253	 0.00065	 0.00016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20577	 82054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20577	 82054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20577	 83677	 0.000768	 0.002029	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20578	 25027	 0.001308	 0.004488	 0.00108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20578	 82055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20578	 82055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20579	 27794	 0.008548	 0.012964	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20579	 27796	 0.014492	 0.01359	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82052	 20579	 0.004532	 0.010411	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20579	 84634	 0.031115	 0.037931	 0.00061	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20579	 84636	 0.060242	 0.047221	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20580	 84111	 0.006143	 0.017619	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20581	 27699	 0.001014	 0.00406	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20581	 27701	 0.000793	 0.003986	 0.00104	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20582	 26610	 0.001292	 0.005174	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20582	 26613	 0.001374	 0.007322	 0.00205	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20582	 82056	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20582	 82056	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20583	 27653	 0.000728	 0.002453	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20583	 82057	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20583	 82057	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20583	 84567	 0.002602	 0.00868	 0.0022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20584	 24999	 0.000267	 0.003003	 0.00079	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20584	 25069	 0.000665	 0.002661	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20584	 82058	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20584	 82058	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20585	 82059	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20585	 82059	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20585	 84433	 0.005315	 0.014047	 0.00329	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20585	 84434	 0.00185	 0.005569	 0.00174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20586	 25133	 0.001822	 0.00635	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20586	 82060	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20586	 82060	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20587	 24919	 0.000238	 0.004224	 0.00212	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20587	 82061	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20587	 82061	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20587	 83527	 0.000219	 0.003885	 0.00195	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20588	 26944	 0.01194	 0.073405	 0.00132	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20588	 83540	 0.058265	 0.35423	 0.00654	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20589	 27330	 0.000108	 0.00127	 0.02218	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20589	 27337	 0.00053	 0.005878	 0.05597	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20589	 84444	 0.000316	 0.003644	 0.03195	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20590	 27743	 0.000577	 0.004714	 0.00128	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20590	 27744	 0.00143	 0.005179	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20590	 27745	 0.000407	 0.001629	 0.00041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20591	 27590	 0.002022	 0.012431	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20591	 84547	 0.00211	 0.010737	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20592	 26957	 0.06073	 0.059421	 0.00084	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20592	 84280	 0.006398	 0.01835	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20592	 84283	 0.034197	 0.071873	 0.00131	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20593	 20594	 0.004909	 0.013178	 0.00299	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20593	 20692	 0.009382	 0.024117	 0.00597	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20594	 20595	 0.002638	 0.010562	 0.00266	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20594	 20598	 0.012549	 0.053117	 0.01195	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82015	 20594	 0.0158	 0.054205	 0.01299	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20595	 20596	 0.002004	 0.010651	 0.00247	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20596	 20597	 0.003859	 0.022606	 0.00616	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20597	 20599	 0.00996	 0.026324	 0.00616	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20597	 22081	 0.007396	 0.037163	 0.00967	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20597	 82062	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20597	 82062	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20598	 20599	 0.002195	 0.012476	 0.00361	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20598	 82063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20598	 82063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20599	 82317	 0.002292	 0.024735	 0.00847	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20600	 20601	 0.000864	 0.002912	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20600	 20627	 0.002066	 0.005762	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20600	 82064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20600	 82064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20601	 82065	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20601	 82065	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20601	 82076	 0.001616	 0.005542	 0.00133	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20602	 82075	 0.005517	 0.014182	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20602	 82077	 0.003539	 0.010149	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20603	 20605	 0.012982	 0.009384	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82065	 20603	 0.019218	 0.012441	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20604	 20612	 0.023073	 0.01826	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20605	 20607	 0.013222	 0.013501	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20606	 20607	 0.017603	 0.017607	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20606	 82102	 0.008947	 0.017714	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20607	 20608	 0.00608	 0.011915	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20607	 82077	 0.073262	 0.051896	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20607	 82082	 0.013491	 0.03431	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20608	 20609	 0.004335	 0.00887	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20609	 82070	 0.006557	 0.015639	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20610	 82070	 0.016036	 0.010382	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20611	 20612	 0.009236	 0.010158	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20611	 82070	 0.006802	 0.017298	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20612	 82077	 0.022994	 0.023224	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20612	 82078	 0.011593	 0.020918	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20613	 20614	 7.8e-05	 0.000852	 0.00828	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20613	 20638	 6.4e-05	 0.000751	 0.00708	 1000.0	 1050.0	 1100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20613	 20690	 0.000497	 0.00565	 0.05102	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20613	 20695	 0.000322	 0.003652	 0.03325	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20613	 20820	 0.001276	 0.014281	 0.13348	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20613	 82066	 9.7e-05	 0.007789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20613	 82412	 0.0049	 0.051197	 0.80414	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20613	 82412	 0.0049	 0.051197	 0.80414	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20613	 82412	 0.0049	 0.051197	 0.80414	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20614	 82068	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20615	 20616	 0.000859	 0.002607	 0.00057	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20615	 20639	 0.001132	 0.002845	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20616	 20617	 0.001316	 0.004586	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20616	 20681	 0.002256	 0.014289	 0.00388	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82066	 20616	 0.005215	 0.01354	 0.00329	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20616	 82070	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20616	 82070	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20617	 20680	 0.003212	 0.008956	 0.00188	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20617	 20681	 0.000993	 0.010038	 0.00295	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20617	 20686	 0.00677	 0.017891	 0.00419	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82066	 20617	 0.006856	 0.017798	 0.00432	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20617	 82071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20617	 82071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20618	 20635	 0.00118	 0.00348	 0.00081	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20618	 82072	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20618	 82072	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20619	 20620	 0.00706	 0.009279	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20619	 20631	 0.015887	 0.031456	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20620	 82078	 0.016051	 0.011603	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82069	 20621	 0.01254	 0.009226	 0.00013	 33.0	 33.0	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20621	 82073	 0.015523	 0.012285	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20621	 82078	 0.01591	 0.011705	 0.00017	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82067	 20622	 0.00789	 0.011201	 0.00018	 49.0	 49.0	 49.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82069	 20622	 0.014316	 0.017137	 0.00029	 45.0	 45.0	 45.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20623	 20635	 0.001022	 0.003506	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82066	 20623	 0.00174	 0.005675	 0.00151	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20623	 82073	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20623	 82073	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20624	 20625	 0.005913	 0.015199	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20624	 20630	 0.010581	 0.025899	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82069	 20624	 0.0073	 0.028397	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82072	 20624	 0.00214	 0.01023	 0.00022	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20625	 20633	 0.024132	 0.024374	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20626	 20637	 0.016338	 0.015986	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20626	 20654	 0.024923	 0.019723	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20626	 82086	 0.025159	 0.025165	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20627	 82074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20627	 82074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20627	 82084	 0.003698	 0.010902	 0.00254	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20628	 20637	 0.019189	 0.029395	 0.00041	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20628	 82075	 0.004559	 0.01172	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20629	 82075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20629	 82075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20629	 82076	 0.001065	 0.006184	 0.00146	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20630	 20634	 0.02697	 0.021344	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82071	 20631	 0.029848	 0.030148	 0.0004	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20631	 82097	 0.00915	 0.026242	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82071	 20632	 0.021896	 0.050834	 0.00076	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20632	 82099	 0.013875	 0.061827	 0.00105	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20636	 20668	 0.02522	 0.016328	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20638	 20673	 9.9e-05	 0.001788	 0.01787	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20638	 82076	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82068	 20639	 0.00127	 0.003264	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20639	 82078	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20639	 82078	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20640	 82079	 0.036893	 0.09484	 0.00147	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20640	 84373	 0.064287	 0.14924	 0.00284	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20641	 82079	 0.012372	 0.047599	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20641	 82080	 0.022168	 0.063581	 0.00098	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20641	 82081	 0.018664	 0.047977	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20642	 20824	 0.004727	 0.029942	 0.00813	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82066	 20642	 0.003899	 0.044571	 0.01359	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20642	 82079	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20642	 82079	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20643	 20644	 0.003675	 0.012381	 0.00308	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20643	 20656	 0.001846	 0.008961	 0.00205	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20643	 20660	 0.009394	 0.02415	 0.00598	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20643	 82080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20643	 82080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20644	 20823	 0.007435	 0.017917	 0.00506	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20644	 82081	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20644	 82081	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82081	 20645	 0.040317	 0.049149	 0.00079	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20645	 82083	 0.021028	 0.07512	 0.00149	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20646	 20647	 0.023895	 0.023965	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20647	 82087	 0.010921	 0.027773	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20648	 82083	 0.12914	 0.1022	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20649	 82082	 0.10783	 0.076388	 0.00121	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20650	 20686	 0.005096	 0.013467	 0.00315	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20650	 82082	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20650	 82082	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20650	 82101	 0.003021	 0.010678	 0.00241	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20651	 22094	 0.003824	 0.036719	 0.01068	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20651	 82084	 0.000845	 0.007245	 0.00206	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20652	 82083	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20652	 82083	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20652	 82084	 0.002089	 0.007165	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20653	 20695	 7.9e-05	 0.000893	 0.00813	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20653	 82084	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20654	 82086	 0.009007	 0.018432	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20654	 82087	 0.011478	 0.022725	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20655	 20656	 0.00108	 0.007243	 0.00175	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20655	 82086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20655	 82086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20655	 82101	 0.000622	 0.006396	 0.00181	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20656	 82087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20656	 82087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20657	 20658	 0.008005	 0.015849	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20657	 20659	 0.012587	 0.026972	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20657	 20668	 0.008387	 0.013387	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82075	 20657	 0.005673	 0.037492	 0.00074	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20657	 82088	 0.039232	 0.035155	 0.00072	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20658	 82088	 0.03549	 0.027223	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20659	 20664	 0.01847	 0.02165	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20659	 20666	 0.009286	 0.023615	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20660	 20661	 0.001747	 0.004391	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20660	 82088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20660	 82088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20661	 82089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20661	 82089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20662	 82090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20662	 82090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20662	 82093	 0.002259	 0.005866	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82089	 20663	 0.011415	 0.021574	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20663	 82092	 0.008661	 0.02484	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82074	 20664	 0.013913	 0.059754	 0.00109	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82080	 20664	 0.033705	 0.034043	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20665	 20666	 0.005876	 0.022608	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20665	 82168	 0.069411	 0.19699	 0.0031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82088	 20666	 0.005041	 0.022461	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20667	 20669	 0.007777	 0.014893	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82090	 20667	 0.01958	 0.019585	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20668	 20694	 0.009317	 0.023695	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82075	 20669	 0.006148	 0.012582	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20670	 82091	 0.019508	 0.087292	 0.0018	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20670	 84375	 0.1458	 0.23278	 0.00536	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20671	 20673	 0.000494	 0.005416	 0.05261	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20671	 20693	 0.000403	 0.00442	 0.04294	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20671	 27179	 0.000512	 0.007	 0.07134	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20671	 82091	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20671	 82091	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20672	 82092	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20672	 82092	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20672	 82093	 0.00374	 0.009709	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20673	 82093	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20674	 20675	 0.031373	 0.029421	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82094	 20674	 0.014634	 0.018165	 0.0004	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20675	 20676	 0.030812	 0.021826	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20675	 82095	 0.025305	 0.049594	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82092	 20676	 0.022429	 0.01452	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20677	 82095	 0.018538	 0.030916	 0.00045	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20678	 20679	 0.001396	 0.007906	 0.00196	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82066	 20678	 0.000777	 0.007988	 0.00227	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20678	 82095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20678	 82095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20679	 20691	 0.003973	 0.015102	 0.00423	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20680	 82096	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20680	 82096	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20681	 82097	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20681	 82097	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20681	 82300	 0.010013	 0.078911	 0.02309	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20682	 20683	 0.007558	 0.015467	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20682	 20685	 0.009175	 0.018166	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82096	 20682	 0.05102	 0.05117	 0.00083	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20683	 20684	 0.00818	 0.021028	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20683	 20687	 0.027922	 0.049104	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20684	 20689	 0.026649	 0.069067	 0.00131	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82071	 20685	 0.092308	 0.073053	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20685	 82098	 0.01827	 0.018275	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20686	 82098	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20686	 82098	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82098	 20687	 0.018674	 0.048004	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20687	 82723	 0.029442	 0.097162	 0.00157	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20688	 22100	 0.03048	 0.10889	 0.00216	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82098	 20688	 0.023021	 0.070696	 0.00133	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82097	 20689	 0.0251	 0.077002	 0.00209	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20689	 82298	 0.024935	 0.17117	 0.00312	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20690	 22084	 0.000577	 0.010463	 0.10461	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20690	 82099	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20690	 82099	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20691	 20692	 0.00733	 0.025147	 0.00602	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20692	 82100	 0.006249	 0.021778	 0.00505	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20693	 82100	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20693	 82100	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82064	 20694	 0.007577	 0.02173	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20695	 82101	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20696	 20702	 8.6e-05	 0.000994	 0.00871	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20696	 20710	 0.000489	 0.005443	 0.05133	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20696	 82103	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20697	 20698	 9.4e-05	 0.00109	 0.00956	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20697	 20702	 9e-05	 0.000992	 0.00964	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20697	 82105	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20697	 82105	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20698	 82106	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20698	 82106	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82106	 20699	 0.001995	 0.005272	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20699	 82107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20699	 82107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20699	 82642	 0.018004	 0.045262	 0.01173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20700	 20707	 0.011438	 0.028753	 0.00745	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20700	 82108	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20700	 82108	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20700	 82109	 0.002732	 0.006869	 0.00178	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20701	 20709	 0.11071	 0.11183	 0.00148	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82108	 20701	 0.021038	 0.014902	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20701	 82110	 0.039269	 0.031077	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20702	 21880	 0.00083	 0.009104	 0.08845	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20702	 82109	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82104	 20703	 0.009313	 0.026712	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20703	 82115	 0.048311	 0.12287	 0.00194	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82104	 20704	 0.062503	 0.060392	 0.00088	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20704	 82112	 0.014682	 0.030045	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20705	 20710	 0.00043	 0.004721	 0.04586	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20705	 82111	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20706	 21148	 0.016554	 0.042558	 0.01054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82111	 20706	 0.012217	 0.031717	 0.0077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20706	 82113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20706	 82113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20707	 82642	 0.009882	 0.022939	 0.00699	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20708	 21124	 0.053354	 0.12203	 0.00298	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82110	 20708	 0.032189	 0.10623	 0.00172	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20709	 82115	 0.063816	 0.11471	 0.00206	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20710	 21117	 0.001883	 0.02057	 0.20214	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20710	 82114	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81907	 20711	 0.02289	 0.13012	 0.00235	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81909	 20711	 0.017854	 0.12256	 0.00223	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20711	 82315	 0.098101	 0.28143	 0.00433	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81904	 20712	 0.004012	 0.020493	 0.00515	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81908	 20712	 0.003837	 0.019988	 0.00524	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20713	 82116	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20713	 82116	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20714	 20715	 0.001457	 0.016655	 0.00508	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81919	 20714	 0.002296	 0.026258	 0.00735	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20715	 20716	 0.000718	 0.006158	 0.00175	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20716	 20851	 0.002303	 0.025794	 0.0082	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20716	 82117	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20716	 82117	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20717	 20962	 0.059122	 0.15199	 0.00235	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82117	 20717	 0.046408	 0.050548	 0.00069	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20717	 82180	 0.16868	 0.3307	 0.00496	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20718	 20723	 0.010697	 0.037281	 0.00864	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20718	 20788	 0.017609	 0.046541	 0.01089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20719	 20785	 0.005564	 0.044422	 0.01095	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20719	 21660	 0.003613	 0.030388	 0.009	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20719	 82118	 0.011292	 0.030745	 0.00677	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20720	 21924	 0.001793	 0.020319	 0.18515	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20720	 82118	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20720	 82280	 0.000785	 0.008891	 0.08095	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20721	 20722	 0.008713	 0.023033	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82119	 20721	 0.009407	 0.03138	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82119	 20722	 0.013538	 0.052666	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20722	 82251	 0.08423	 0.23906	 0.00376	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20723	 82120	 0.005763	 0.020083	 0.00466	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20724	 20726	 0.000174	 0.001905	 0.01851	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20724	 82120	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20724	 82120	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20724	 82280	 0.000299	 0.003446	 0.03021	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20725	 82121	 0.040236	 0.039526	 0.00067	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20726	 82121	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20726	 82121	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20726	 82412	 0.000137	 0.001508	 0.01465	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20727	 21033	 0.049123	 0.11633	 0.00213	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20728	 20730	 0.008329	 0.021623	 0.00525	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20728	 21676	 0.018278	 0.047456	 0.01152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20728	 82122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20728	 82122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20729	 82540	 0.035376	 0.13555	 0.00383	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20729	 82549	 0.049263	 0.16435	 0.00261	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20730	 20731	 0.013077	 0.036467	 0.00765	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20731	 21097	 0.020019	 0.05451	 0.01201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20732	 20737	 0.000419	 0.004685	 0.04377	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20732	 20747	 0.00056	 0.009823	 0.10512	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20732	 82123	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20732	 82123	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20733	 20734	 0.11197	 0.082386	 0.0012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20734	 22093	 0.072118	 0.11822	 0.00209	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20735	 20737	 0.000312	 0.005663	 0.05661	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20735	 21933	 0.000428	 0.00479	 0.04476	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20735	 82124	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20735	 82124	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20736	 20783	 0.023742	 0.062757	 0.01469	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82124	 20736	 0.002458	 0.018515	 0.00514	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20736	 82125	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20736	 82125	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20736	 82126	 0.005396	 0.022837	 0.00514	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20737	 82126	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20738	 21079	 0.035848	 0.1183	 0.00192	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82125	 20738	 0.056261	 0.15966	 0.00251	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82127	 20738	 0.029825	 0.085543	 0.00132	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20739	 82234	 0.13231	 0.21124	 0.00487	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20740	 82128	 0.028761	 0.086568	 0.00169	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20741	 20744	 0.007728	 0.039474	 0.00993	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20741	 20938	 0.009277	 0.054341	 0.01481	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20741	 82128	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20741	 82128	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20741	 82719	 0.003099	 0.02242	 0.01206	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20742	 82129	 0.011368	 0.023264	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20743	 82129	 0.007675	 0.015041	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20744	 82129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20744	 82129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20744	 82132	 0.005399	 0.015056	 0.00316	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82129	 20745	 0.024307	 0.019236	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82129	 20746	 0.0206	 0.040786	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20747	 21062	 0.001098	 0.012054	 0.11712	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20747	 21621	 0.000278	 0.004875	 0.05215	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20747	 82130	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20747	 82130	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20747	 82131	 0.000436	 0.005066	 0.04379	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20748	 20878	 0.000328	 0.006645	 2.8532	 4345.0	 4562.3	 4779.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20748	 82131	 0.000158	 0.012644	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20748	 82131	 0.000158	 0.012644	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82132	 20748	 0.000145	 0.011567	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 0	 -30.0	 30.0;
	20749	 21062	 0.00067	 0.007731	 0.06778	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20749	 21628	 0.000442	 0.004854	 0.04715	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20749	 22092	 0.000861	 0.015108	 0.16173	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20749	 82133	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20749	 82133	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20750	 82135	 0.003745	 0.012493	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20751	 20762	 0.000193	 0.002123	 0.02062	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20751	 82134	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20752	 20762	 0.00014	 0.00158	 0.01439	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20752	 82136	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20753	 20765	 0.019087	 0.014043	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82137	 20753	 0.007398	 0.018813	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20753	 82139	 0.004161	 0.018331	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20753	 82145	 0.013349	 0.11338	 0.00265	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82137	 20754	 0.022562	 0.01631	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82135	 20755	 0.009409	 0.018628	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82137	 20755	 0.00698	 0.012784	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20756	 20758	 0.017137	 0.017309	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82135	 20756	 0.008917	 0.022923	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20757	 20758	 0.016009	 0.011778	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82135	 20757	 0.014167	 0.02805	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20757	 82138	 0.016839	 0.025793	 0.00045	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20758	 20765	 0.019562	 0.035297	 0.00051	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20758	 20905	 0.004475	 0.025143	 0.00047	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20759	 20760	 0.000694	 0.003874	 0.00099	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20759	 20906	 0.00034	 0.001935	 0.00056	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20760	 20761	 0.000939	 0.003287	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20761	 20764	 0.001836	 0.007142	 0.00191	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20761	 82138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20761	 82138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20762	 20766	 0.00013	 0.002038	 0.02124	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20762	 82139	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20762	 82139	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82139	 20763	 0.01578	 0.024172	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20764	 82140	 0.003694	 0.013058	 0.00294	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20766	 20773	 0.000169	 0.002179	 0.03658	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20766	 82140	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20767	 20918	 0.001034	 0.007479	 0.00402	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20767	 82142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20767	 82142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20767	 82144	 0.001047	 0.016494	 0.00562	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82142	 20768	 0.051645	 0.037997	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20768	 82226	 0.024293	 0.062447	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20769	 20770	 0.001677	 0.023927	 0.00799	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20769	 20916	 0.006978	 0.023939	 0.00574	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20769	 82276	 0.009497	 0.065871	 0.03864	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20770	 20771	 0.001733	 0.017512	 0.00515	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20770	 82143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20770	 82143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20771	 21870	 0.00352	 0.03019	 0.00859	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20772	 20775	 0.002776	 0.027549	 0.00749	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20772	 82144	 0.001376	 0.01522	 0.00456	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81883	 20773	 0.002448	 0.031503	 0.53777	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20773	 82144	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82143	 20774	 0.042368	 0.098365	 0.00146	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82145	 20774	 0.017603	 0.040257	 0.00098	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20775	 21118	 0.004696	 0.039493	 0.0117	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20776	 20777	 0.002989	 0.010253	 0.00246	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20776	 20779	 0.002576	 0.008011	 0.00167	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20776	 22029	 0.010321	 0.031067	 0.00972	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20777	 20778	 0.001022	 0.00709	 0.00202	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20777	 20780	 0.011162	 0.038293	 0.00917	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20778	 21771	 0.005501	 0.028122	 0.00766	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20779	 22029	 0.008191	 0.026716	 0.00709	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20780	 20781	 0.008434	 0.041591	 0.01125	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20781	 82247	 0.007744	 0.04536	 0.01236	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20782	 21080	 0.097581	 0.19322	 0.00284	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20782	 82251	 0.063245	 0.20084	 0.00352	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20783	 20787	 0.007906	 0.020525	 0.00498	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20784	 21944	 0.059387	 0.11374	 0.00179	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20785	 20786	 0.007067	 0.017765	 0.0046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20785	 82146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20785	 82146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20786	 20788	 0.003187	 0.008887	 0.00187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20786	 82147	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20786	 82147	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20787	 20788	 0.00215	 0.005581	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20787	 82148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20787	 82148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20788	 82149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20788	 82149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82146	 20789	 0.042622	 0.0581	 0.00129	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82147	 20789	 0.02471	 0.019369	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82149	 20789	 0.025442	 0.018392	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20790	 22058	 0.008001	 0.059967	 0.01463	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20790	 82150	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20790	 82150	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20790	 82151	 0.003629	 0.040838	 0.01073	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20791	 82152	 0.17102	 0.18813	 0.00251	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20791	 82190	 0.21288	 0.21506	 0.00285	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20792	 20857	 0.001808	 0.019849	 0.19298	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20792	 21024	 0.000403	 0.007078	 0.07573	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20792	 21714	 0.001247	 0.014401	 0.1263	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20792	 82151	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20793	 20964	 0.008846	 0.05928	 0.01816	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20793	 82153	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20793	 82153	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81868	 20794	 0.28322	 0.41308	 0.00934	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82153	 20794	 0.065764	 0.18864	 0.0029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20794	 82155	 0.035728	 0.073115	 0.0018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20795	 21617	 0.001961	 0.014528	 0.00744	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20795	 82154	 0.003066	 0.027799	 0.01453	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20796	 39963	 0.001852	 0.031935	 0.55859	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20796	 39963	 0.001852	 0.031935	 0.55859	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81871	 20796	 0.000381	 0.004577	 0.04527	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20796	 82154	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20796	 82154	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20797	 20798	 0.001715	 0.005882	 0.00141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81898	 20797	 0.008461	 0.023035	 0.00507	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20797	 82155	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20797	 82155	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20798	 20799	 0.001088	 0.004605	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82154	 20799	 0.004667	 0.018685	 0.00471	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20800	 20803	 0.030756	 0.079063	 0.00122	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20800	 20809	 0.047279	 0.12154	 0.00188	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20800	 82598	 0.032217	 0.082818	 0.00128	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20801	 20802	 0.059997	 0.047481	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20801	 82157	 0.017642	 0.086092	 0.00149	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20801	 84073	 0.015698	 0.052367	 0.00083	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20803	 20804	 0.032122	 0.072863	 0.00145	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20804	 84072	 0.033946	 0.067211	 0.00099	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81883	 20805	 5.3e-05	 0.000533	 0.00888	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81883	 20805	 5.3e-05	 0.000533	 0.00888	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81890	 20805	 5.5e-05	 0.000902	 0.01408	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20805	 82156	 0.000109	 0.008705	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20806	 21785	 0.009626	 0.064589	 0.0156	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82156	 20806	 0.002635	 0.011154	 0.00251	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20806	 82158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20806	 82158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81885	 20807	 0.027631	 0.054706	 0.0008	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81892	 20807	 0.02243	 0.041706	 0.00098	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20807	 82159	 0.036954	 0.10487	 0.00165	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20808	 21785	 0.003709	 0.031811	 0.00905	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81891	 20808	 0.008331	 0.038221	 0.00979	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20808	 82159	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20808	 82159	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82158	 20809	 0.14571	 0.10721	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82159	 20809	 0.040199	 0.10627	 0.00193	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20810	 20812	 0.006005	 0.031924	 0.00741	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20810	 21789	 0.024054	 0.063582	 0.01488	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20810	 82160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20810	 82160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20811	 20812	 0.006449	 0.019014	 0.00442	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20811	 20815	 0.011782	 0.0397	 0.00987	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82114	 20812	 0.00652	 0.10498	 0.03433	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20812	 82161	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20812	 82161	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82160	 20813	 0.031552	 0.081774	 0.00155	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82161	 20813	 0.016306	 0.036987	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82161	 20814	 0.036961	 0.11351	 0.00213	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20814	 82600	 0.044903	 0.11902	 0.00302	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20815	 21123	 0.017801	 0.045763	 0.01133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20815	 82162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20815	 82162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20816	 20817	 0.00319	 0.025626	 0.0072	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20816	 21901	 0.004278	 0.01926	 0.00512	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20816	 82163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20816	 82163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20817	 20822	 0.00448	 0.015676	 0.00519	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20817	 21901	 0.006595	 0.041775	 0.01134	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20817	 82165	 0.000911	 0.01146	 0.00355	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20818	 20824	 0.005592	 0.025653	 0.00657	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20818	 21898	 0.026536	 0.079486	 0.01791	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20818	 27775	 0.003341	 0.035847	 0.00933	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82066	 20818	 0.011569	 0.099264	 0.02827	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20818	 82164	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20818	 82164	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82164	 20819	 0.038686	 0.11096	 0.00171	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20819	 82166	 0.005714	 0.044531	 0.00083	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20819	 82168	 0.038108	 0.10814	 0.0017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20820	 21688	 0.000597	 0.008444	 0.08053	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20820	 82165	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20821	 21694	 0.032049	 0.073296	 0.00179	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20821	 82167	 0.019618	 0.050431	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20822	 20823	 0.005844	 0.016296	 0.00342	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20822	 82167	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20822	 82167	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20824	 25691	 0.009612	 0.032975	 0.0079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20824	 82168	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20824	 82168	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20825	 20831	 7.6e-05	 0.001328	 0.01421	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20825	 20837	 5.7e-05	 0.000655	 0.00641	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20825	 82169	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20826	 20828	 0.000299	 0.003018	 0.00089	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20826	 20840	 0.000717	 0.003291	 0.00084	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82169	 20826	 0.000236	 0.0027	 0.00082	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20827	 20841	 7.8e-05	 0.000888	 0.00809	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20827	 20847	 0.000277	 0.003135	 0.02854	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20827	 82171	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20827	 82171	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82171	 20828	 0.000315	 0.004586	 0.00147	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20828	 82172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20828	 82172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20829	 20853	 0.005965	 0.013641	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82172	 20829	 0.003313	 0.007515	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20830	 20833	 0.001399	 0.004712	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82171	 20830	 0.000943	 0.003773	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20831	 20841	 0.000187	 0.002156	 0.0189	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20831	 20959	 0.00077	 0.014238	 0.13686	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20831	 82173	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20832	 20848	 0.032884	 0.070469	 0.00123	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20832	 82175	 0.003868	 0.020611	 0.00036	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20832	 82185	 0.022576	 0.064751	 0.001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20832	 82188	 0.028449	 0.022514	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20833	 82175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20833	 82175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82174	 20834	 0.002975	 0.007647	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20834	 82176	 0.004821	 0.011026	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20835	 20836	 0.000299	 0.004313	 0.00137	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82173	 20835	 0.00034	 0.002784	 0.00179	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20835	 82176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20835	 82176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20836	 82181	 0.000241	 0.003751	 0.00116	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20837	 20842	 0.000128	 0.00147	 0.0144	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20837	 82177	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20837	 82177	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20838	 20839	 0.014134	 0.011186	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20839	 20843	 0.025086	 0.025092	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82170	 20839	 0.005968	 0.015776	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20839	 82178	 0.00699	 0.012293	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20839	 82180	 0.013202	 0.030193	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82177	 20840	 0.000723	 0.007661	 0.00227	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20840	 82178	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20840	 82178	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20840	 82179	 0.000389	 0.005857	 0.00175	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20841	 21014	 0.001429	 0.019866	 0.19658	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20841	 82179	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20842	 20852	 0.000405	 0.00487	 0.04818	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20842	 82181	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20842	 82181	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20844	 21777	 0.00644	 0.030696	 0.00889	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82177	 20844	 0.003041	 0.018894	 0.00533	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82180	 20845	 0.037862	 0.056764	 0.00103	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20846	 20847	 0.000219	 0.002434	 0.02295	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20846	 22078	 0.00123	 0.022319	 0.22336	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20846	 82182	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20846	 82182	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20847	 20954	 0.000965	 0.017059	 0.15967	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20847	 82183	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82184	 20848	 0.013994	 0.036267	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20849	 20851	 0.002314	 0.026446	 0.00807	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20849	 21363	 0.002332	 0.016168	 0.00948	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20850	 20854	 0.002447	 0.013174	 0.00362	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20850	 21115	 0.002748	 0.045792	 0.01393	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82179	 20850	 0.004828	 0.026587	 0.0096	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20850	 82185	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20850	 82185	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20851	 82186	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20851	 82186	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20852	 21109	 0.000514	 0.009314	 0.09312	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20852	 82187	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20852	 82187	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82170	 20853	 0.006515	 0.012899	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82176	 20853	 0.008675	 0.020141	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82173	 20854	 0.00096	 0.005623	 0.00153	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20854	 82188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20854	 82188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20855	 21718	 0.010687	 0.031509	 0.00733	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20855	 82189	 0.007674	 0.020281	 0.00475	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20856	 82189	 0.003481	 0.012305	 0.00277	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20857	 20860	 0.000535	 0.006057	 0.05515	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81871	 20857	 0.001223	 0.013355	 0.13116	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20857	 82189	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20857	 82189	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20858	 21618	 0.017562	 0.060254	 0.01444	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82189	 20858	 0.002824	 0.015048	 0.00422	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20859	 21701	 0.006631	 0.046901	 0.01287	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82189	 20859	 0.003807	 0.028203	 0.01445	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20859	 82190	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20859	 82190	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20860	 20861	 0.000186	 0.002106	 0.01917	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20860	 82191	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20860	 82191	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20861	 82192	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20861	 82192	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20862	 20866	 0.004161	 0.010803	 0.00262	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20862	 20868	 0.0013	 0.004529	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20862	 82193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20862	 82193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20863	 20869	 0.034738	 0.06878	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82193	 20863	 0.00322	 0.022655	 0.00045	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20863	 82194	 0.003976	 0.033073	 0.00063	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20864	 20865	 0.000122	 0.001392	 0.01257	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20864	 20873	 0.000273	 0.002995	 0.02909	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20865	 21691	 0.00078	 0.008643	 0.0823	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20865	 82194	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20865	 82194	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20865	 82198	 0.000622	 0.008518	 0.08681	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20866	 20874	 0.00798	 0.021424	 0.00486	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20867	 20868	 0.001353	 0.005416	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20867	 20889	 0.002168	 0.011894	 0.00314	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20869	 82207	 0.011216	 0.063758	 0.00115	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20870	 24084	 0.003887	 0.027361	 0.01556	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20870	 82206	 0.001103	 0.018372	 0.00559	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20871	 20872	 0.001009	 0.011303	 0.00359	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20871	 21183	 0.004994	 0.027402	 0.00724	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20871	 21184	 0.014423	 0.043801	 0.00959	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20871	 24084	 0.011288	 0.035104	 0.00733	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20871	 82195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20871	 82195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20872	 82199	 0.00491	 0.042289	 0.02456	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20873	 21690	 0.000554	 0.006275	 0.05713	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20873	 24085	 0.001475	 0.016424	 0.15497	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20873	 82196	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20873	 82196	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20874	 82197	 0.006556	 0.030079	 0.00771	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20875	 21604	 0.00055	 0.006095	 0.05803	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20875	 82197	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20875	 82197	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20876	 21163	 0.006543	 0.022804	 0.00529	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82197	 20876	 0.004086	 0.010271	 0.00266	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20876	 82512	 0.007918	 0.030806	 0.00823	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82197	 20877	 0.009414	 0.022685	 0.00641	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20877	 82199	 0.007744	 0.027373	 0.00617	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20878	 82198	 0.000158	 0.012644	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20878	 82198	 0.000158	 0.012644	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20878	 82198	 0.000158	 0.012644	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82199	 20878	 0.000191	 0.015285	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 0	 -30.0	 30.0;
	82199	 20878	 0.000191	 0.015285	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 0	 -30.0	 30.0;
	20879	 21848	 0.008291	 0.021314	 0.00528	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82199	 20879	 0.002836	 0.013228	 0.00328	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20879	 82200	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20879	 82200	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20880	 21847	 0.003285	 0.008681	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20880	 82202	 0.003503	 0.009259	 0.00217	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20881	 20884	 0.001638	 0.004116	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20881	 82201	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20881	 82201	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82198	 20882	 0.000379	 0.004288	 0.03904	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20882	 82202	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82202	 20883	 0.001382	 0.008025	 0.00189	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20883	 82204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20883	 82204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20884	 20897	 0.002218	 0.005758	 0.0014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82202	 20884	 0.003754	 0.010221	 0.00225	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20885	 22301	 0.017838	 0.045859	 0.01136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82202	 20885	 0.004584	 0.014328	 0.00415	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82204	 20886	 0.075356	 0.059069	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20886	 82205	 0.017776	 0.045207	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20886	 82207	 0.01892	 0.037461	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20887	 20891	 0.002245	 0.005644	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20887	 20897	 0.002049	 0.005415	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82199	 20887	 0.004287	 0.021538	 0.00561	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20887	 82205	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20887	 82205	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20887	 82206	 0.001148	 0.007395	 0.00194	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82198	 20888	 0.000431	 0.004725	 0.0459	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20888	 82206	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20889	 20892	 0.002109	 0.015583	 0.0045	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82205	 20890	 0.070279	 0.055619	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20890	 82208	 0.023732	 0.036355	 0.00051	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20891	 20892	 0.003468	 0.00967	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82199	 20892	 0.001186	 0.010783	 0.00272	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20892	 82208	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20892	 82208	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20892	 82209	 0.002258	 0.008783	 0.00235	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82198	 20893	 0.000152	 0.001759	 0.01542	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20893	 82209	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20893	 82209	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82202	 20894	 0.004896	 0.012711	 0.00309	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82209	 20894	 0.000739	 0.005315	 0.00141	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20894	 82210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20894	 82210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20895	 20896	 0.009184	 0.0114	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82205	 20895	 0.039939	 0.031607	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82210	 20896	 0.002618	 0.011667	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82209	 20897	 0.001845	 0.010239	 0.00311	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20898	 82213	 0.089999	 0.070547	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20899	 20901	 0.000282	 0.00204	 0.0011	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20899	 82211	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20899	 82211	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20899	 82712	 0.002767	 0.035439	 0.01058	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20900	 82212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20900	 82212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20901	 20902	 0.000635	 0.004635	 0.00119	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20902	 20903	 0.000618	 0.006663	 0.00191	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81884	 20902	 0.065872	 0.16956	 0.04205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20902	 82213	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20902	 82213	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20903	 20904	 0.001739	 0.012584	 0.00677	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20903	 82214	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20903	 82214	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20904	 21786	 0.002241	 0.03053	 0.01091	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20904	 82215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20904	 82215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20905	 82216	 0.003665	 0.010511	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20905	 82217	 0.004163	 0.022179	 0.00039	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20906	 20915	 0.000708	 0.004066	 0.00115	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20907	 20908	 0.001018	 0.003492	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20907	 20915	 0.001069	 0.003667	 0.00088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20907	 82216	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20907	 82216	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20908	 20909	 0.000619	 0.002889	 0.00072	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20909	 82217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20909	 82217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20909	 82218	 0.000569	 0.005635	 0.00173	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20910	 21023	 0.00068	 0.010311	 0.11574	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20910	 82218	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82217	 20911	 0.01258	 0.011797	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20911	 82220	 0.01029	 0.017334	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82218	 20912	 0.001015	 0.006535	 0.00171	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20912	 82220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20912	 82220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20912	 82221	 0.00089	 0.00506	 0.00146	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20913	 82221	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20914	 20918	 0.000691	 0.008206	 0.00286	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20914	 20919	 0.000794	 0.005406	 0.00184	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82221	 20914	 0.000394	 0.003391	 0.00197	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82221	 20915	 0.000976	 0.004029	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20916	 82223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20916	 82223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20917	 82227	 0.10148	 0.080314	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20918	 82224	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20918	 82224	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20919	 20920	 0.001152	 0.004613	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20919	 82225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20919	 82225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20920	 82226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20920	 82226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81894	 20921	 0.013891	 0.037294	 0.00845	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20921	 82227	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20921	 82227	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20921	 82274	 0.007942	 0.042217	 0.0098	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20922	 20923	 0.034459	 0.044844	 0.00063	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82220	 20922	 0.026295	 0.055266	 0.00101	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82227	 20922	 0.027397	 0.050942	 0.00119	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82219	 20923	 0.026015	 0.053463	 0.00102	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20923	 82228	 0.011691	 0.056408	 0.001	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20924	 21026	 0.000441	 0.005125	 0.0443	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20924	 82228	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20924	 82228	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20925	 20928	 0.000556	 0.006304	 0.05739	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20925	 21940	 0.000457	 0.00801	 0.0857	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20925	 82229	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20925	 82229	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20926	 20927	 0.015464	 0.044794	 0.0108	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20926	 22043	 0.009143	 0.031865	 0.00739	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82116	 20926	 0.014638	 0.08789	 0.02663	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82229	 20926	 0.001569	 0.017195	 0.00477	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20926	 82230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20926	 82230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20927	 22002	 0.012703	 0.042803	 0.01064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20928	 20929	 0.000503	 0.005807	 0.05091	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20928	 82231	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20928	 82231	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20929	 82232	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20929	 82232	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20930	 20934	 0.048436	 0.11078	 0.0027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82160	 20930	 0.037779	 0.14698	 0.00245	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20930	 82599	 0.12433	 0.12696	 0.00198	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20931	 26359	 0.018792	 0.049669	 0.01163	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20931	 82233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20931	 82233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20932	 20933	 0.029595	 0.075265	 0.00119	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82233	 20932	 0.026623	 0.076359	 0.00117	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20933	 20934	 0.029157	 0.12993	 0.00221	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20933	 82598	 0.041204	 0.15789	 0.00446	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82215	 20934	 0.058241	 0.11532	 0.00169	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20935	 21615	 0.046009	 0.13197	 0.00203	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20935	 82234	 0.052903	 0.089121	 0.00127	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20936	 20939	 0.005706	 0.02169	 0.00607	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20936	 21605	 0.031419	 0.10591	 0.02634	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20936	 82234	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20936	 82234	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20936	 82235	 0.01371	 0.036235	 0.00848	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82234	 20937	 0.044123	 0.12054	 0.00205	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20938	 20939	 0.005806	 0.031261	 0.00859	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20940	 21608	 0.000976	 0.017712	 0.17718	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20940	 21619	 0.000515	 0.005828	 0.05306	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20940	 82235	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20940	 82235	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20941	 21754	 0.19435	 0.12584	 0.0024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81863	 20941	 0.056051	 0.10985	 0.00165	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20942	 82236	 0.070023	 0.1781	 0.00282	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20942	 82237	 0.078571	 0.15558	 0.00228	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20942	 82684	 0.020975	 0.11176	 0.00196	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20943	 20945	 0.010923	 0.028079	 0.00695	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20943	 21721	 0.009098	 0.030351	 0.0077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20943	 22046	 0.003085	 0.031433	 0.0081	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81900	 20943	 0.02172	 0.073196	 0.0182	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20943	 82236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20943	 82236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20944	 20946	 0.004066	 0.019841	 0.00548	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20944	 21160	 0.007247	 0.038525	 0.00894	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20945	 20946	 0.0058	 0.017099	 0.00398	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81862	 20946	 0.003517	 0.041768	 0.01455	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20946	 82237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20946	 82237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82237	 20947	 0.011971	 0.030771	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20948	 20950	 0.004705	 0.023532	 0.00042	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20948	 82238	 0.002182	 0.013208	 0.00041	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20949	 20963	 0.009259	 0.032271	 0.00748	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20949	 82238	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20949	 82238	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20949	 82240	 0.000691	 0.007782	 0.00225	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81920	 20950	 0.072582	 0.28243	 0.00472	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20951	 82239	 0.017127	 0.02126	 0.00046	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20952	 82239	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20952	 82239	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20952	 82240	 0.005094	 0.017164	 0.00427	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82238	 20953	 0.01307	 0.030343	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82239	 20953	 0.011055	 0.021888	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20954	 21072	 0.001452	 0.016764	 0.14704	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20954	 22042	 0.000949	 0.010755	 0.09794	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20954	 82240	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82238	 20955	 0.012485	 0.029565	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82241	 20955	 0.00628	 0.016644	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82241	 20956	 0.021993	 0.12358	 0.00229	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20956	 82301	 0.216	 0.29458	 0.00654	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20957	 21076	 0.056699	 0.14576	 0.00226	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82241	 20957	 0.038395	 0.10489	 0.00178	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20957	 82406	 0.12098	 0.1475	 0.00236	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20958	 21363	 0.004986	 0.040059	 0.01126	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20958	 82242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20958	 82242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20958	 82243	 0.005993	 0.01584	 0.00371	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20959	 20960	 0.000122	 0.001383	 0.01259	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20959	 82243	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20959	 82243	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20960	 22042	 0.001138	 0.012675	 0.11956	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20960	 82244	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20961	 20963	 0.009127	 0.024849	 0.00547	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82244	 20961	 0.002638	 0.00905	 0.00217	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82117	 20962	 0.038634	 0.11081	 0.0017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82186	 20962	 0.073015	 0.1431	 0.00215	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82242	 20962	 0.015844	 0.070209	 0.00211	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20963	 21090	 0.008859	 0.034464	 0.00921	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20964	 20965	 0.006066	 0.035529	 0.00968	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20965	 21650	 0.005252	 0.029304	 0.00749	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20965	 82565	 0.012703	 0.033574	 0.00786	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20966	 20967	 0.000361	 0.006257	 0.06852	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20966	 21339	 0.001797	 0.02002	 0.18896	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20966	 21708	 0.000626	 0.007005	 0.06545	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20966	 22034	 0.002086	 0.02291	 0.22281	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20966	 82246	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20966	 82246	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81861	 20967	 0.003638	 0.040616	 0.38448	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81866	 20967	 0.001312	 0.015149	 0.13287	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20967	 82247	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20968	 21905	 0.069716	 0.13664	 0.00205	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82248	 20968	 0.055595	 0.10183	 0.00176	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20968	 82564	 0.15023	 0.38955	 0.00737	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20969	 20970	 0.001555	 0.004584	 0.00107	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20969	 21906	 0.0126	 0.043227	 0.01036	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82247	 20970	 0.006859	 0.017805	 0.00432	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20971	 20972	 0.067803	 0.13425	 0.00197	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82153	 20971	 0.022162	 0.10061	 0.00218	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82248	 20971	 0.16117	 0.1628	 0.00216	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20972	 21637	 0.11376	 0.26025	 0.00636	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81918	 20972	 0.020425	 0.078579	 0.00134	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20973	 21950	 0.000813	 0.009058	 0.08543	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20973	 82249	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20973	 82249	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20974	 20975	 0.004271	 0.014651	 0.00351	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20974	 21949	 0.004846	 0.027039	 0.00691	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20974	 82250	 0.008804	 0.02937	 0.00745	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20975	 20986	 0.003849	 0.013938	 0.00299	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20976	 21072	 0.001283	 0.016481	 0.15509	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20976	 21950	 0.000908	 0.010551	 0.09122	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20976	 82250	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20976	 82412	 0.000505	 0.009152	 0.0915	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20977	 82252	 0.044662	 0.058699	 0.0008	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20978	 20979	 0.000317	 0.003412	 0.00182	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82250	 20978	 0.004486	 0.028412	 0.00771	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20978	 82252	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20978	 82252	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20978	 82253	 0.000827	 0.010595	 0.00316	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20978	 82413	 0.002899	 0.03374	 0.00992	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20979	 82260	 0.000278	 0.003933	 0.0013	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20980	 20984	 0.002302	 0.008376	 0.00256	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20980	 20987	 0.002063	 0.008729	 0.00196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81916	 20980	 0.000705	 0.005665	 0.00159	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20981	 20988	 0.002512	 0.006743	 0.00153	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20981	 20994	 0.003016	 0.011853	 0.0031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20982	 20985	 0.000148	 0.001624	 0.01577	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20982	 21003	 0.000292	 0.003687	 0.03288	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20982	 82253	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20982	 82253	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20983	 20988	 0.000667	 0.005903	 0.00324	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20983	 82261	 0.000856	 0.013077	 0.00421	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20984	 82254	 0.002177	 0.008557	 0.00224	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20985	 82254	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20985	 82254	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82254	 20986	 0.001547	 0.005468	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20987	 20988	 0.000722	 0.004364	 0.00111	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81916	 20988	 0.002824	 0.01755	 0.00495	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20989	 21375	 0.002158	 0.0183	 0.01096	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20989	 21377	 0.001486	 0.015744	 0.00467	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20989	 82257	 0.000741	 0.007792	 0.00438	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20990	 82256	 0.006661	 0.021982	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20990	 82258	 0.016089	 0.037353	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20991	 20994	 0.002499	 0.009722	 0.0026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20991	 82257	 0.00188	 0.007315	 0.00195	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20992	 20993	 0.000184	 0.002048	 0.01931	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20992	 21434	 0.000129	 0.002149	 0.02029	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20992	 82255	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20993	 82257	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20994	 20997	 0.001488	 0.005387	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20994	 82436	 0.005097	 0.020406	 0.00514	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82255	 20995	 0.001994	 0.007049	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20995	 82436	 0.001521	 0.006976	 0.00179	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20996	 82269	 0.025204	 0.027721	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20997	 82263	 0.001576	 0.006194	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20998	 21001	 0.000173	 0.00193	 0.0182	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20998	 82259	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20998	 82259	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20999	 21000	 0.001497	 0.006092	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20999	 82261	 0.001152	 0.004482	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21000	 21009	 0.001368	 0.005789	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21000	 82260	 0.001756	 0.004232	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21001	 21008	 0.000131	 0.001515	 0.01328	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21001	 82260	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21001	 82260	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21002	 21008	 0.000135	 0.001502	 0.01416	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21002	 82261	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21003	 21010	 0.000183	 0.002049	 0.01914	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21003	 82263	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82259	 21004	 0.00059	 0.007006	 0.00244	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21004	 82413	 0.001068	 0.009455	 0.00519	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21005	 21006	 0.008128	 0.020894	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82262	 21005	 0.011544	 0.026522	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21005	 82266	 0.006578	 0.016728	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21006	 82269	 0.006228	 0.014457	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21007	 82266	 0.036241	 0.026198	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21007	 82267	 0.030379	 0.022351	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21007	 82421	 0.031149	 0.040938	 0.00056	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21008	 21400	 0.00021	 0.003685	 0.03943	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21008	 82265	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21009	 21011	 0.00211	 0.011946	 0.00296	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82265	 21009	 0.001902	 0.005028	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21009	 82267	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21009	 82267	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21010	 21434	 0.000144	 0.001632	 0.01486	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21010	 82268	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21011	 21398	 0.001028	 0.004	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82268	 21011	 0.001128	 0.016681	 0.00574	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21011	 82270	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21011	 82270	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21011	 82413	 0.000807	 0.007411	 0.00636	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21012	 82272	 0.12737	 0.12775	 0.00207	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21012	 82411	 0.064866	 0.085254	 0.00117	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82258	 21013	 0.019345	 0.093341	 0.00165	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21014	 21053	 0.001267	 0.013902	 0.13509	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21014	 21541	 0.000923	 0.01163	 0.17732	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21014	 21873	 0.001	 0.01133	 0.10318	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21014	 82271	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82271	 21015	 0.00264	 0.006128	 0.00187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21015	 82273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21015	 82273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82273	 21016	 0.023957	 0.026094	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82272	 21017	 0.016394	 0.032459	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82273	 21017	 0.022521	 0.022747	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21018	 21060	 0.067533	 0.1568	 0.00233	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82272	 21018	 0.017484	 0.085318	 0.00147	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21019	 21021	 0.029182	 0.052655	 0.00076	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21019	 82495	 0.022613	 0.10077	 0.00171	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21020	 82490	 0.031992	 0.082914	 0.00157	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82150	 21022	 0.06244	 0.16052	 0.00248	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82227	 21022	 0.071412	 0.15304	 0.00268	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21022	 82275	 0.079209	 0.092852	 0.00161	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21023	 21024	 0.000454	 0.005235	 0.04589	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21023	 82274	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21024	 21025	 0.000345	 0.003842	 0.03623	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21024	 21714	 0.00151	 0.01815	 0.17967	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21024	 82276	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21025	 21026	 0.000249	 0.002769	 0.02611	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82228	 21027	 0.23023	 0.25083	 0.00342	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82277	 21027	 0.069436	 0.16444	 0.00301	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21028	 21464	 0.00013	 0.001478	 0.01346	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21028	 82278	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21028	 82280	 0.000179	 0.00286	 0.02891	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21029	 82281	 0.016141	 0.041832	 0.00079	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21030	 21381	 3.6e-05	 0.000733	 0.26505	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21030	 21483	 5.7e-05	 0.001179	 0.40787	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21030	 82280	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21030	 82280	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21030	 82280	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21031	 21032	 0.013799	 0.027043	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21032	 21037	 0.049434	 0.052791	 0.00112	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82281	 21032	 0.014441	 0.069358	 0.00134	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82281	 21033	 0.015255	 0.093788	 0.00169	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21033	 82282	 0.036729	 0.091166	 0.00152	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21034	 21668	 0.06907	 0.17757	 0.00275	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21034	 82282	 0.036101	 0.091812	 0.00145	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21035	 21036	 0.006083	 0.015636	 0.00387	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21035	 82282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21035	 82282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21036	 21045	 0.012063	 0.03364	 0.00706	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21036	 21048	 0.009128	 0.029773	 0.0079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21036	 82283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21036	 82283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82283	 21037	 0.13851	 0.10962	 0.00138	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21037	 82284	 0.030388	 0.060165	 0.00088	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82278	 21038	 0.005288	 0.013976	 0.00327	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21038	 82284	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21038	 82284	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21038	 82454	 0.004488	 0.015397	 0.00369	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21039	 21046	 0.042783	 0.043212	 0.00057	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21039	 82285	 0.021105	 0.054252	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21040	 82285	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21040	 82285	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21040	 82454	 0.003115	 0.012471	 0.00314	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21041	 21045	 0.002636	 0.006843	 0.00166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21041	 82286	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21041	 82286	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21041	 82454	 0.001491	 0.012787	 0.00364	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21042	 21567	 0.004043	 0.013868	 0.00332	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21042	 21672	 0.002137	 0.011133	 0.00292	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21043	 21044	 0.003766	 0.009954	 0.00233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21043	 82287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21043	 82287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21044	 21045	 0.001968	 0.004948	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82286	 21046	 0.038163	 0.050158	 0.00069	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82287	 21046	 0.056859	 0.048596	 0.00091	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21047	 21674	 0.032766	 0.07759	 0.00142	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82283	 21047	 0.12616	 0.099847	 0.00126	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82287	 21047	 0.11188	 0.088547	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21048	 21769	 0.009281	 0.032346	 0.0075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21048	 82288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21048	 82288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21049	 21055	 0.044462	 0.068112	 0.00096	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21050	 21055	 0.090603	 0.11908	 0.00163	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21051	 21052	 0.005003	 0.023332	 0.00578	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21051	 82289	 0.005508	 0.022414	 0.00546	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21052	 21372	 0.00412	 0.022988	 0.00587	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21053	 82289	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21054	 21055	 0.012793	 0.019961	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21055	 21056	 0.006648	 0.013973	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82290	 21055	 0.007634	 0.046935	 0.00085	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21056	 21058	 0.00651	 0.01395	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21057	 21061	 0.015736	 0.083845	 0.00147	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82290	 21057	 0.005646	 0.01732	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82290	 21057	 0.005646	 0.01732	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21057	 82291	 0.002269	 0.018879	 0.00036	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21058	 82291	 0.004753	 0.009727	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21059	 21779	 0.005991	 0.066266	 0.01988	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82289	 21059	 0.000645	 0.009196	 0.00307	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21059	 82291	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21059	 82291	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82290	 21060	 0.067727	 0.12594	 0.00295	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82212	 21061	 0.037648	 0.1617	 0.00296	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21062	 21072	 8.5e-05	 0.000983	 0.00862	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21062	 82292	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21062	 82292	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21063	 82293	 0.008383	 0.016598	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21064	 21078	 0.004376	 0.010158	 0.00309	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82292	 21064	 0.002092	 0.005432	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21064	 82293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21064	 82293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21065	 21066	 0.001556	 0.00404	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21065	 21069	 0.00165	 0.00436	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21066	 21078	 0.003783	 0.010298	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21067	 82294	 0.013047	 0.024985	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21068	 21080	 0.031195	 0.079334	 0.00125	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21068	 21081	 0.056805	 0.041064	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21068	 82296	 0.023741	 0.037895	 0.00087	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21069	 82294	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21069	 82294	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21069	 82295	 0.001896	 0.005011	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21070	 21071	 0.027485	 0.021751	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21070	 21073	 0.061122	 0.039571	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82294	 21070	 0.007695	 0.011786	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21071	 21081	 0.050264	 0.035605	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21071	 82296	 0.019313	 0.032208	 0.00047	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21072	 21950	 0.000524	 0.008189	 0.0863	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21072	 82295	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82296	 21073	 0.010014	 0.025466	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21073	 82297	 0.010922	 0.023318	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21074	 21075	 0.001877	 0.00644	 0.00154	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82295	 21074	 0.002837	 0.007724	 0.0017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21075	 21948	 0.005432	 0.017717	 0.0047	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82238	 21076	 0.085966	 0.2466	 0.00379	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82296	 21076	 0.056071	 0.14823	 0.00269	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21076	 82297	 0.022757	 0.10141	 0.00172	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82295	 21077	 0.004001	 0.013945	 0.00323	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21077	 82297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21077	 82297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82133	 21078	 0.010506	 0.029471	 0.00759	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21079	 21080	 0.034779	 0.091939	 0.00167	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21080	 21081	 0.039226	 0.076877	 0.00115	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21082	 22100	 0.031516	 0.096787	 0.00182	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21082	 82298	 0.019605	 0.075426	 0.00129	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21083	 21084	 0.000546	 0.00673	 0.00217	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21083	 82300	 0.000987	 0.007106	 0.00593	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21084	 21085	 0.000502	 0.005414	 0.00155	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21085	 82298	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21085	 82298	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21086	 21087	 0.001772	 0.016093	 0.00524	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21086	 22080	 0.001793	 0.023986	 0.00656	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82066	 21086	 0.005293	 0.078532	 0.02422	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21086	 82299	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21086	 82299	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21087	 82300	 0.000971	 0.010294	 0.00306	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21088	 21089	 0.000187	 0.002168	 0.01874	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21088	 21691	 0.002568	 0.029129	 0.2657	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21088	 22038	 0.000377	 0.006607	 0.07069	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21088	 82300	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21089	 82302	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21089	 82302	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82302	 21090	 0.008724	 0.033162	 0.00928	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21091	 21092	 0.000914	 0.008775	 0.00255	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21091	 21126	 0.003706	 0.021068	 0.0061	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82114	 21091	 0.014711	 0.050471	 0.01209	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21092	 21094	 0.000612	 0.004243	 0.00249	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21092	 82303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21092	 82303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82115	 21093	 0.089716	 0.16189	 0.00234	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21093	 82305	 0.00427	 0.024029	 0.00052	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21093	 82307	 0.021424	 0.12178	 0.0022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21094	 21096	 0.000282	 0.002494	 0.00137	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21094	 82304	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21094	 82304	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82303	 21095	 0.00573	 0.030528	 0.00054	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82304	 21095	 0.007447	 0.017109	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21095	 82305	 0.002078	 0.017255	 0.00042	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21096	 21098	 0.002133	 0.027759	 0.00802	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21096	 82305	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21096	 82305	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21097	 21099	 0.017417	 0.048574	 0.0102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21097	 21334	 0.008482	 0.066845	 0.01956	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21097	 82306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21097	 82306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21098	 21099	 0.005448	 0.024531	 0.00653	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81913	 21098	 0.009437	 0.074028	 0.03385	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21098	 82307	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21098	 82307	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21099	 22057	 0.011556	 0.039644	 0.0095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82307	 21100	 0.089812	 0.17603	 0.00264	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21100	 82632	 0.11233	 0.072723	 0.00138	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21101	 21104	 0.003171	 0.018573	 0.00506	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21101	 21105	 0.008356	 0.028666	 0.00687	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21101	 21302	 0.014447	 0.051072	 0.01151	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21101	 82308	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21101	 82308	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21102	 21104	 0.007774	 0.048308	 0.01364	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21102	 82309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21102	 82309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21102	 82312	 0.014382	 0.04934	 0.01182	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21103	 21739	 0.25943	 0.28543	 0.00381	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81896	 21103	 0.031178	 0.063805	 0.00157	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21104	 21750	 0.009121	 0.029751	 0.0079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21104	 82310	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21104	 82310	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21105	 82311	 0.009957	 0.034843	 0.01155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21106	 21108	 0.000549	 0.006144	 0.0574	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21106	 82311	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21106	 82311	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21107	 21763	 0.000646	 0.011337	 0.12133	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21107	 82312	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21108	 82314	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21109	 21110	 0.000647	 0.007102	 0.06899	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21109	 21113	 0.000417	 0.004574	 0.04443	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21109	 82316	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21109	 82316	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21110	 82317	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21111	 82319	 0.016233	 0.079216	 0.00137	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21111	 82321	 0.044708	 0.09581	 0.00168	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21111	 82592	 0.035698	 0.13888	 0.00232	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21112	 26953	 0.004102	 0.04689	 0.0143	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21112	 82319	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21112	 82319	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21112	 82320	 0.000387	 0.006021	 0.00187	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21113	 21114	 0.000517	 0.005475	 0.05711	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21113	 82320	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21114	 82322	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21114	 82322	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82187	 21115	 0.001562	 0.022088	 0.00732	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82316	 21115	 0.003692	 0.030717	 0.0093	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82322	 21115	 0.001461	 0.013251	 0.00693	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21116	 21121	 0.001516	 0.016432	 0.01008	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21116	 21785	 0.003275	 0.051611	 0.0176	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21116	 82323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21116	 82323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21117	 21120	 0.000402	 0.004481	 0.04226	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21117	 82324	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21117	 82324	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21118	 21119	 0.002042	 0.016686	 0.00453	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21118	 21870	 0.002809	 0.02644	 0.00801	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81875	 21118	 0.003447	 0.029565	 0.00841	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81875	 21119	 0.002289	 0.014747	 0.00387	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21120	 82325	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21120	 82325	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81875	 21121	 0.000753	 0.011729	 0.0041	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81876	 21122	 0.048929	 0.038353	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21123	 21783	 0.003091	 0.028293	 0.01133	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82325	 21123	 0.004559	 0.073384	 0.02398	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21124	 21125	 0.006947	 0.047684	 0.00087	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82162	 21124	 0.026701	 0.12381	 0.00257	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21125	 21127	 0.031591	 0.062547	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21125	 82326	 0.014523	 0.089285	 0.00161	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21126	 21128	 0.010857	 0.028694	 0.00672	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21126	 82326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21126	 82326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21127	 82327	 0.024559	 0.10252	 0.00296	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82324	 21128	 0.012517	 0.042942	 0.01029	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21128	 82327	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21128	 82327	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21129	 82328	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21129	 82328	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21129	 82329	 0.00244	 0.018376	 0.0051	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21130	 21589	 0.00462	 0.01849	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21130	 82330	 0.00335	 0.018825	 0.00035	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21131	 21136	 0.020243	 0.05806	 0.00089	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21131	 82330	 0.005769	 0.025706	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21132	 21651	 0.001335	 0.023796	 0.24715	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21132	 21879	 0.000692	 0.012139	 0.12992	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21132	 82329	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21133	 21588	 0.001815	 0.004562	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82329	 21133	 0.00208	 0.005662	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82330	 21134	 0.021069	 0.02769	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21135	 21139	 0.00198	 0.006791	 0.00163	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82329	 21135	 0.00146	 0.004228	 0.00102	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82328	 21136	 0.017541	 0.053868	 0.00101	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21136	 82331	 0.018563	 0.042647	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21137	 21138	 0.003065	 0.009037	 0.0021	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21137	 21140	 0.002434	 0.006119	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21138	 21141	 0.004586	 0.012487	 0.00275	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21138	 21671	 0.006414	 0.034537	 0.00949	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21139	 21141	 0.002967	 0.009677	 0.00257	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21140	 21586	 0.001825	 0.00469	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21141	 21142	 0.00328	 0.011878	 0.00255	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21142	 21676	 0.009267	 0.037711	 0.00919	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21143	 82331	 0.043152	 0.081556	 0.00132	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21143	 82332	 0.037307	 0.076347	 0.00188	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21144	 21145	 0.003485	 0.008761	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21144	 82331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21144	 82331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21145	 21146	 0.002064	 0.00554	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21146	 21147	 0.001581	 0.005726	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21146	 21150	 0.004018	 0.028667	 0.00889	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21147	 21148	 0.003314	 0.011998	 0.00257	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82113	 21149	 0.035878	 0.064487	 0.00116	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82331	 21149	 0.11375	 0.21787	 0.00343	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21149	 82641	 0.29259	 0.2245	 0.00301	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21150	 82332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21150	 82332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81898	 21151	 0.005122	 0.027289	 0.00766	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21152	 21906	 0.007614	 0.037546	 0.01015	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21152	 82333	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21152	 82333	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21153	 21154	 0.07205	 0.13197	 0.00228	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81868	 21153	 0.44401	 0.35162	 0.00443	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82333	 21153	 0.22745	 0.18004	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21154	 21155	 0.004848	 0.012462	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21154	 82334	 0.011859	 0.028082	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21155	 21157	 0.021759	 0.017055	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21155	 82334	 0.009578	 0.018964	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21156	 21160	 0.009828	 0.033115	 0.00823	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21156	 82334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21156	 82334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21157	 21158	 0.014909	 0.026798	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82334	 21157	 0.007927	 0.012653	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21158	 21159	 0.063602	 0.14767	 0.0022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81899	 21159	 0.016322	 0.063498	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81901	 21159	 0.11602	 0.1525	 0.00209	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81900	 21160	 0.026725	 0.070645	 0.01654	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21161	 82335	 0.072205	 0.057143	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21162	 21169	 0.01401	 0.037027	 0.00867	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82197	 21162	 0.005038	 0.050923	 0.01498	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21162	 82335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21162	 82335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21163	 82336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21163	 82336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21164	 21614	 0.052147	 0.12105	 0.00231	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82336	 21164	 0.037869	 0.10862	 0.00167	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21164	 82338	 0.13105	 0.10371	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21165	 82337	 0.026671	 0.060498	 0.00121	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21166	 21167	 0.026334	 0.042034	 0.00097	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21166	 21692	 0.020372	 0.10855	 0.0019	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82335	 21166	 0.012804	 0.056415	 0.00098	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21167	 21168	 0.02247	 0.050413	 0.0008	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21168	 82337	 0.024005	 0.061709	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21168	 82340	 0.093357	 0.060442	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21169	 21172	 0.002717	 0.011219	 0.00265	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21169	 82337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21169	 82337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21170	 21171	 0.002102	 0.010384	 0.00303	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21170	 21173	 0.003941	 0.019935	 0.00555	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21170	 21177	 0.002058	 0.031442	 0.01013	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21170	 82338	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21170	 82338	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21170	 82512	 0.011599	 0.069634	 0.02109	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21171	 21172	 0.000396	 0.004526	 0.00138	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21171	 21175	 0.002834	 0.011996	 0.0027	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21172	 21173	 0.002171	 0.007446	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21172	 82339	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21172	 82339	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21173	 21174	 0.004797	 0.018853	 0.00493	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21174	 82340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21174	 82340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21175	 82341	 0.00648	 0.03145	 0.00719	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82338	 21176	 0.046965	 0.068437	 0.00155	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21176	 82342	 0.055861	 0.14768	 0.00268	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82235	 21177	 0.002138	 0.022492	 0.01264	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21178	 22035	 0.000482	 0.005567	 0.04881	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82198	 21178	 0.002357	 0.027234	 0.23913	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21178	 82341	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21178	 82341	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21179	 82342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21179	 82342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21179	 82697	 0.009735	 0.032476	 0.00824	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21180	 24074	 0.020976	 0.10491	 0.00187	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21180	 82343	 0.039129	 0.10059	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21181	 21183	 0.002662	 0.029443	 0.00883	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21181	 82343	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21181	 82343	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82195	 21182	 0.036629	 0.094161	 0.00146	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82343	 21182	 0.037502	 0.11505	 0.00312	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21182	 83304	 0.019498	 0.10389	 0.00182	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21183	 82344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21183	 82344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21183	 82559	 0.010739	 0.043	 0.01083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21183	 83303	 0.029246	 0.073537	 0.01906	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21184	 82345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21184	 82345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21184	 82559	 0.003327	 0.024296	 0.00624	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21185	 21186	 0.020424	 0.051942	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21185	 21187	 0.029656	 0.10965	 0.00203	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82343	 21185	 0.009137	 0.061994	 0.00116	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21186	 21689	 0.025189	 0.066588	 0.00121	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82345	 21186	 0.033305	 0.16253	 0.00281	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21186	 82554	 0.053852	 0.13844	 0.00214	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21187	 21900	 0.024253	 0.084864	 0.00176	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21187	 82554	 0.051942	 0.11934	 0.00181	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21188	 21189	 0.003654	 0.017831	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21188	 21728	 0.015147	 0.042982	 0.00068	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21189	 21268	 0.037398	 0.048669	 0.00068	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21189	 82355	 0.003129	 0.022519	 0.00074	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21190	 21191	 9.1e-05	 0.00139	 0.02491	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21190	 82346	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21191	 21258	 0.000271	 0.004167	 0.07267	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21191	 21305	 0.000619	 0.011168	 0.17632	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21191	 82348	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21192	 21198	 0.008939	 0.025637	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21192	 21234	 0.006025	 0.023439	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21192	 21261	 0.008464	 0.017393	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21192	 82351	 0.007407	 0.03027	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21193	 82350	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21194	 21216	 0.000175	 0.002617	 0.00077	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82346	 21194	 0.000353	 0.00435	 0.0014	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21194	 82352	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21194	 82352	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21195	 21196	 0.000404	 0.00197	 0.00054	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21195	 21216	 0.000693	 0.003544	 0.00097	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82348	 21196	 0.000681	 0.003106	 0.00099	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21196	 82353	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21196	 82353	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21197	 21198	 0.005585	 0.015469	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21197	 21201	 0.006047	 0.015316	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82352	 21197	 0.00347	 0.011575	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21198	 21199	 0.020595	 0.016299	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21199	 21200	 0.005646	 0.016194	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21199	 21262	 0.004186	 0.016039	 0.00045	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21200	 21206	 0.005302	 0.015207	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21200	 21207	 0.002963	 0.015212	 0.00029	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82347	 21200	 0.007794	 0.038979	 0.00069	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21201	 21205	 0.002457	 0.009453	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21201	 21205	 0.002457	 0.009453	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21201	 21206	 0.003447	 0.008556	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21201	 82357	 0.001184	 0.008656	 0.00016	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21202	 21203	 0.000505	 0.004698	 0.00146	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21202	 21204	 0.000568	 0.002899	 0.00073	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21202	 82354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21202	 82354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21203	 21729	 0.002952	 0.022124	 0.0054	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21203	 82355	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21203	 82355	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21204	 82356	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21204	 82356	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82356	 21205	 0.002644	 0.009253	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82356	 21205	 0.002644	 0.009253	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21207	 21208	 0.005942	 0.007809	 0.00011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21207	 21209	 0.002312	 0.012023	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21208	 21212	 0.009761	 0.017612	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21209	 21210	 0.001394	 0.007428	 0.00013	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82356	 21210	 0.001595	 0.008068	 0.00014	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21211	 21214	 0.007643	 0.018097	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82354	 21211	 0.008517	 0.028413	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21212	 21213	 0.009354	 0.024045	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21213	 21214	 0.005078	 0.01694	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21213	 21215	 0.023301	 0.01844	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21213	 21265	 0.01411	 0.01106	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21213	 82374	 0.004189	 0.022417	 0.00068	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21216	 82357	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21216	 82357	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21217	 21247	 0.001789	 0.006712	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21217	 82358	 0.001864	 0.00615	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81881	 21218	 0.001431	 0.00719	 0.00187	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21218	 82358	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21218	 82358	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21220	 82359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21220	 82359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21220	 82365	 0.001509	 0.009375	 0.00265	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21221	 21224	 0.000297	 0.003345	 0.00088	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21221	 21241	 0.000263	 0.003008	 0.00092	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82359	 21222	 0.018886	 0.014487	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21223	 21230	 0.008153	 0.023136	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82359	 21223	 0.004935	 0.019274	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21224	 21226	 0.002778	 0.009267	 0.00235	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21224	 21254	 0.003398	 0.013828	 0.00337	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21224	 82360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21224	 82360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21225	 21242	 0.002632	 0.01114	 0.00251	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21225	 82361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21225	 82361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21225	 82379	 0.004197	 0.023285	 0.00708	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82350	 21226	 0.003664	 0.009835	 0.00223	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21226	 82362	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21226	 82362	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21227	 21235	 0.007949	 0.013391	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21227	 21255	 0.009813	 0.015664	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82361	 21227	 0.00837	 0.021516	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21228	 21233	 0.023068	 0.016676	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82361	 21228	 0.016477	 0.016642	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21229	 21230	 0.016169	 0.012796	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82360	 21229	 0.01102	 0.018564	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21230	 21231	 0.004849	 0.011141	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21231	 21232	 0.004455	 0.008283	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21232	 21249	 0.011314	 0.022174	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21233	 82370	 0.022613	 0.024872	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21234	 21235	 0.010621	 0.01627	 0.00023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82362	 21234	 0.004637	 0.011059	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21234	 82368	 0.005522	 0.024471	 0.00073	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21236	 21245	 0.000692	 0.003895	 8e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81897	 21236	 0.004645	 0.026403	 0.00048	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21237	 82363	 0.000182	 0.000739	 0.00018	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21237	 82363	 0.000182	 0.000739	 0.00018	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21238	 82363	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21239	 82365	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21240	 21241	 0.000343	 0.003921	 0.0012	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82365	 21240	 0.000517	 0.004051	 0.00185	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21241	 82367	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21241	 82367	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82350	 21242	 0.000994	 0.006663	 0.00204	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82363	 21242	 0.000704	 0.005093	 0.00274	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21242	 82368	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21242	 82368	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21243	 21244	 0.010703	 0.01081	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82364	 21243	 0.00194	 0.009816	 0.00017	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82368	 21243	 0.00423	 0.018166	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21244	 21245	 0.00436	 0.009782	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82364	 21245	 0.001508	 0.009273	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21246	 21247	 0.005577	 0.014335	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81882	 21246	 0.000566	 0.003649	 0.00012	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81910	 21246	 0.000675	 0.002071	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82366	 21247	 0.027689	 0.038589	 0.00066	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21248	 21249	 0.023172	 0.020906	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21248	 21251	 0.031028	 0.021978	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21248	 82380	 0.016608	 0.067875	 0.00137	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21249	 21251	 0.008953	 0.016921	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21249	 82370	 0.013724	 0.021414	 0.00036	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21250	 21290	 0.002042	 0.007005	 0.00168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21250	 82369	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21250	 82369	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82369	 21251	 0.003164	 0.016003	 0.00028	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21252	 21253	 0.000734	 0.00369	 0.00096	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21252	 21254	 0.001115	 0.004337	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21253	 21288	 0.001192	 0.007099	 0.00187	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21254	 82370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21254	 82370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21255	 21256	 0.012433	 0.016341	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21255	 21259	 0.008931	 0.022957	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82370	 21255	 0.006094	 0.020328	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21256	 21257	 0.007023	 0.009788	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21256	 21259	 0.007537	 0.017494	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21256	 21260	 0.004261	 0.021555	 0.00038	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82370	 21257	 0.00881	 0.022315	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21258	 21289	 4.6e-05	 0.000724	 0.01571	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21258	 82371	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21259	 21261	 0.008065	 0.01872	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21259	 21262	 0.012989	 0.027731	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82372	 21259	 0.006491	 0.036898	 0.00067	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82372	 21260	 0.003055	 0.015359	 0.00042	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21262	 21263	 0.006894	 0.019774	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21263	 82373	 0.004425	 0.014761	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21264	 21274	 0.001518	 0.005966	 0.00156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82371	 21264	 0.000968	 0.006813	 0.00387	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21264	 82373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21264	 82373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21266	 21270	 0.006274	 0.046342	 0.00097	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21266	 21271	 0.005721	 0.014707	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82349	 21266	 0.011218	 0.063766	 0.00115	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21267	 21268	 0.0047	 0.018648	 0.00053	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82355	 21267	 0.00357	 0.015821	 0.00048	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21268	 21269	 0.017779	 0.031955	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21268	 82576	 0.01461	 0.051121	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21269	 21270	 0.003446	 0.025188	 0.00046	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21269	 21736	 0.005829	 0.035835	 0.00065	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21270	 21273	 0.06143	 0.050563	 0.00102	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21271	 21272	 0.006447	 0.019778	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21272	 82376	 0.007072	 0.027097	 0.00077	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21273	 21747	 0.0174	 0.074389	 0.00168	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21273	 82380	 0.024154	 0.1468	 0.00271	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21273	 82384	 0.033226	 0.087836	 0.00159	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21274	 21279	 0.008019	 0.020818	 0.00505	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21274	 82374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21274	 82374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21275	 21276	 0.001381	 0.007356	 0.00206	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21275	 21280	 0.00296	 0.010718	 0.0023	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21275	 21281	 0.000751	 0.009151	 0.00302	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21275	 82375	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21275	 82375	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21276	 82376	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21276	 82376	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21277	 21283	 0.023404	 0.025492	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82375	 21277	 0.012817	 0.025119	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21277	 82377	 0.027531	 0.029987	 0.00041	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82375	 21278	 0.009272	 0.02358	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21278	 82377	 0.033875	 0.026553	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21279	 21280	 0.001544	 0.005037	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21279	 21294	 0.00313	 0.008273	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21279	 21750	 0.011077	 0.057426	 0.01402	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21280	 82377	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21280	 82377	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21281	 82379	 0.000583	 0.00596	 0.00354	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21282	 21284	 0.008912	 0.021815	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21282	 82378	 0.008907	 0.03969	 0.00067	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21283	 21284	 0.00916	 0.017952	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21285	 21286	 0.024767	 0.027241	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21286	 21291	 0.016371	 0.027579	 0.00039	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21286	 82378	 0.021907	 0.035714	 0.00054	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21286	 82380	 0.019959	 0.052761	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21287	 21288	 0.002803	 0.007407	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21287	 21301	 0.01913	 0.063828	 0.01619	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21287	 82378	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21287	 82378	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21287	 82379	 0.000635	 0.00578	 0.00146	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21288	 82379	 0.000663	 0.005689	 0.00162	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21289	 43154	 0.001018	 0.010772	 0.16115	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21289	 43154	 0.001018	 0.010772	 0.16115	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21289	 82379	 0.000112	 0.008969	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82379	 21290	 0.001904	 0.009689	 0.00351	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21290	 82381	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21290	 82381	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82381	 21291	 0.013215	 0.025898	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21292	 21298	 0.004021	 0.010627	 0.00249	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21292	 82382	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21292	 82382	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82380	 21293	 0.023966	 0.11695	 0.00202	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82382	 21293	 0.042178	 0.042601	 0.00056	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21294	 21296	 0.004005	 0.009297	 0.00283	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21295	 21299	 0.008125	 0.035598	 0.00077	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82377	 21295	 0.007542	 0.037419	 0.00089	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21295	 82383	 0.004193	 0.028778	 0.00052	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21296	 21297	 0.002269	 0.007783	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21296	 21298	 0.003491	 0.009792	 0.00252	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82379	 21296	 0.004695	 0.029739	 0.00807	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21297	 82383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21297	 82383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21298	 21302	 0.008108	 0.020382	 0.00528	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21299	 21303	 0.18007	 0.13644	 0.00188	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21299	 82384	 0.016661	 0.064816	 0.00108	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21300	 21748	 0.006359	 0.016807	 0.00393	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21300	 82384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21300	 82384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21301	 21302	 0.006533	 0.016422	 0.00425	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21301	 21682	 0.014837	 0.038522	 0.00935	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81895	 21302	 0.050563	 0.18332	 0.0394	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21302	 82385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21302	 82385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21303	 21304	 0.046595	 0.074376	 0.00171	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82308	 21303	 0.2001	 0.14724	 0.00215	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82385	 21304	 0.017951	 0.046144	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21304	 82551	 0.16697	 0.30135	 0.00436	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21305	 21723	 0.000338	 0.004628	 0.04716	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21305	 82386	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21306	 21310	 0.00427	 0.018814	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21306	 21311	 0.002354	 0.010373	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81865	 21306	 0.003842	 0.014946	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81865	 21306	 0.003842	 0.014946	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82387	 21306	 0.003817	 0.014686	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82387	 21306	 0.003817	 0.014686	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21307	 21308	 0.000454	 0.00342	 0.00095	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82386	 21307	 0.000546	 0.0043	 0.00126	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21308	 21316	 0.000621	 0.004058	 0.0015	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21309	 21312	 0.002011	 0.007281	 0.00156	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21309	 21316	 0.002001	 0.008143	 0.00198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21310	 21311	 0.002293	 0.008824	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21310	 82390	 0.004513	 0.030542	 0.00088	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21312	 21332	 0.001623	 0.004288	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21313	 21314	 0.000132	 0.001521	 0.01333	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21313	 22229	 0.000283	 0.004957	 0.05303	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21313	 82388	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21313	 82388	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21314	 21325	 0.000583	 0.007245	 0.07278	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21314	 82389	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21314	 82389	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21315	 21332	 0.003466	 0.01208	 0.0028	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21315	 82390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21315	 82390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21316	 21317	 0.003139	 0.012336	 0.00323	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21317	 21327	 0.00213	 0.015777	 0.00808	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21317	 82573	 0.002139	 0.015476	 0.00833	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21318	 21322	 0.029717	 0.070881	 0.00159	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82390	 21318	 0.009431	 0.039366	 0.00114	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21318	 82773	 0.056002	 0.11088	 0.00163	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21319	 21320	 0.10307	 0.081573	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21319	 82775	 0.053281	 0.089758	 0.00128	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21320	 82392	 0.029341	 0.093168	 0.00163	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21321	 21861	 0.00393	 0.028431	 0.0153	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21321	 82391	 0.00227	 0.020579	 0.01076	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21322	 82392	 0.004775	 0.035479	 0.00085	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21322	 82395	 0.006743	 0.048716	 0.00092	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21322	 82773	 0.22518	 0.17823	 0.00224	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21323	 21325	 5.4e-05	 0.000724	 0.01276	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21323	 21325	 5.4e-05	 0.000724	 0.01276	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21323	 21608	 0.00149	 0.016601	 0.15664	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21323	 21833	 0.000529	 0.006314	 0.10738	 1600.0	 1680.0	 1720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21323	 21863	 0.000848	 0.009301	 0.09036	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21323	 21889	 0.001652	 0.018136	 0.1763	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21323	 82391	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82392	 21324	 0.018147	 0.032617	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21324	 82397	 0.14458	 0.11443	 0.00144	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21325	 21723	 0.000471	 0.008704	 0.08363	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21325	 82393	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21325	 82393	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21326	 21328	 0.003968	 0.021143	 0.00593	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21326	 82394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21326	 82394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82393	 21327	 0.000625	 0.009106	 0.00291	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21327	 82395	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21327	 82395	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21328	 82396	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21328	 82396	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21328	 82575	 0.004483	 0.051267	 0.01436	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82391	 21329	 0.013202	 0.034891	 0.00817	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21329	 82397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21329	 82397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82396	 21330	 0.022543	 0.099328	 0.00173	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82397	 21330	 0.032084	 0.12344	 0.00211	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21331	 82581	 0.028635	 0.13	 0.00282	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21331	 82645	 0.052027	 0.14923	 0.0023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81864	 21332	 0.000222	 0.003388	 0.00109	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82388	 21332	 0.000641	 0.006947	 0.00217	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21333	 82401	 0.16172	 0.128	 0.00161	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21334	 82398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21334	 82398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21334	 82400	 0.002101	 0.022543	 0.00587	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21335	 21616	 0.005804	 0.041996	 0.0226	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21335	 21658	 0.003739	 0.02985	 0.00736	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21335	 82399	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21335	 82399	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81914	 21336	 0.068314	 0.13526	 0.00199	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21337	 21340	 0.021705	 0.023873	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81914	 21338	 0.093648	 0.093673	 0.00127	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82399	 21338	 0.052789	 0.12256	 0.00182	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21338	 82401	 0.032626	 0.035885	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21339	 82400	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82401	 21340	 0.008246	 0.016874	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81914	 21341	 0.010809	 0.061446	 0.00111	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21341	 82706	 0.13529	 0.30698	 0.00613	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21342	 21698	 0.063923	 0.11534	 0.00167	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81914	 21342	 0.030049	 0.071158	 0.0013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21343	 21353	 0.000821	 0.006396	 0.00191	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21343	 21378	 0.000299	 0.002564	 0.00073	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21343	 82402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21343	 82402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82402	 21344	 0.00669	 0.01311	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21344	 82403	 0.005535	 0.018466	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21344	 82405	 0.006709	 0.0261	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21345	 21352	 0.001539	 0.011921	 0.00418	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21345	 21379	 0.000306	 0.003179	 0.00098	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21345	 82403	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21345	 82403	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21346	 21347	 8.8e-05	 0.001203	 0.00043	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21346	 21378	 0.000301	 0.003383	 0.00098	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21346	 21379	 0.000159	 0.001785	 0.00052	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21347	 21348	 0.000255	 0.002762	 0.00116	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21348	 21349	 0.001837	 0.004854	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21348	 21358	 0.000442	 0.005147	 0.00151	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21348	 21370	 0.000738	 0.0096	 0.00277	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21348	 82404	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21348	 82404	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21349	 21351	 0.003003	 0.007795	 0.00189	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82184	 21350	 0.020848	 0.11481	 0.00259	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82404	 21350	 0.002289	 0.015714	 0.00029	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21351	 21352	 0.00086	 0.004929	 0.00164	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21351	 21365	 0.003845	 0.015645	 0.00381	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21353	 21369	 0.001365	 0.021254	 0.00742	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21353	 82405	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21353	 82405	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21354	 21355	 0.004245	 0.016331	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81926	 21354	 0.035707	 0.054156	 0.00078	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21354	 82410	 0.018283	 0.081469	 0.00138	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82403	 21355	 0.006245	 0.017912	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21356	 21357	 0.000374	 0.005395	 0.00171	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21357	 21358	 0.000461	 0.006001	 0.00173	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21359	 21362	 0.001811	 0.029455	 0.00835	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82243	 21359	 0.0024	 0.03423	 0.01143	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21359	 82406	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21359	 82406	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21360	 21361	 0.000515	 0.004107	 0.00101	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21360	 82666	 0.006146	 0.039592	 0.01038	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21361	 21362	 0.001733	 0.011625	 0.00281	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21362	 21367	 0.002177	 0.008989	 0.00213	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81916	 21362	 0.004298	 0.038977	 0.02038	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21362	 82407	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21362	 82407	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21363	 21364	 0.001287	 0.00931	 0.00501	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21363	 21365	 0.005623	 0.022099	 0.00578	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21363	 82408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21363	 82408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21364	 21367	 0.001851	 0.0157	 0.0094	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82405	 21366	 0.031892	 0.052973	 0.00112	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82407	 21366	 0.052682	 0.10325	 0.00155	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21366	 82409	 0.034027	 0.067372	 0.00099	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21367	 21368	 0.001823	 0.0175	 0.00815	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21367	 82409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21367	 82409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82249	 21368	 0.001824	 0.017511	 0.00816	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21368	 82410	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21368	 82410	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81916	 21369	 0.002592	 0.034667	 0.00948	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21370	 21371	 0.00032	 0.005068	 0.00152	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82182	 21371	 0.001273	 0.015118	 0.00527	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21372	 21374	 0.00331	 0.020568	 0.0058	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21373	 21376	 0.000673	 0.004739	 0.00269	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21374	 21375	 0.001226	 0.009498	 0.00333	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21374	 82411	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21374	 82411	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21375	 21376	 0.000459	 0.005455	 0.0019	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21375	 21377	 0.001427	 0.01146	 0.00322	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82281	 21380	 0.014658	 0.065318	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21380	 82416	 0.012533	 0.029096	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21380	 82420	 0.057509	 0.06264	 0.00085	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21381	 82412	 0.000122	 0.009799	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21381	 82412	 0.000122	 0.009799	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21381	 82412	 0.000122	 0.009799	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82413	 21381	 0.000149	 0.011888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 0	 -30.0	 30.0;
	82413	 21381	 0.000149	 0.011888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 0	 -30.0	 30.0;
	82412	 21382	 6.4e-05	 0.000748	 0.00711	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21383	 21397	 0.001398	 0.005494	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82413	 21383	 0.000392	 0.004432	 0.00249	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21383	 82414	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21383	 82414	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21383	 82422	 0.000456	 0.003554	 0.00106	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82279	 21384	 0.008591	 0.022085	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21384	 82444	 0.018843	 0.033868	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21385	 21386	 0.00153	 0.004387	 0.00108	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21385	 21390	 0.001127	 0.002979	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82278	 21386	 0.003191	 0.013505	 0.00304	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21386	 82418	 0.002216	 0.007834	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21386	 82443	 0.001202	 0.002897	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21387	 21391	 0.000248	 0.002761	 0.02604	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21387	 82415	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21387	 82415	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21388	 21390	 0.003581	 0.009986	 0.0021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21388	 21393	 0.001327	 0.004427	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82415	 21388	 0.000951	 0.00575	 0.00147	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21388	 82416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21388	 82416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21389	 21392	 0.001779	 0.004777	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21389	 21415	 0.001045	 0.005532	 0.0014	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82415	 21389	 0.000289	 0.00334	 0.00207	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21389	 82417	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21389	 82417	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21390	 82418	 0.002069	 0.005553	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21391	 21465	 7e-05	 0.000769	 0.00747	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21391	 21489	 0.00035	 0.004041	 0.03543	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21391	 82418	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21391	 82418	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21392	 21396	 0.002131	 0.005802	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82418	 21392	 0.003828	 0.010276	 0.00233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21393	 21396	 0.001351	 0.003502	 0.00106	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21393	 82419	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21393	 82419	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82416	 21394	 0.012025	 0.014927	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82419	 21394	 0.018211	 0.014412	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21395	 21417	 0.004988	 0.01919	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21395	 82420	 0.004308	 0.018983	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82418	 21396	 0.001775	 0.004563	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21396	 82420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21396	 82420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21397	 21398	 0.00103	 0.004253	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21399	 21401	 0.00054	 0.005797	 0.00151	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21399	 21403	 0.000405	 0.004991	 0.00161	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21399	 82421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21399	 82421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82412	 21400	 0.000148	 0.001706	 0.01496	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21400	 82422	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21400	 82422	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21401	 21412	 0.000965	 0.004847	 0.00126	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82422	 21401	 0.000226	 0.003641	 0.00119	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21402	 21405	 0.000486	 0.003254	 0.00205	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21402	 21412	 0.001062	 0.005643	 0.00131	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21402	 21413	 0.001859	 0.010795	 0.00254	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21403	 21404	 0.000365	 0.004329	 0.00151	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82268	 21404	 0.000611	 0.006981	 0.00196	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21405	 21407	 0.000512	 0.004917	 0.00143	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21405	 82423	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21405	 82423	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21406	 82424	 0.008933	 0.022172	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21406	 82437	 0.008019	 0.020784	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21407	 82424	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21407	 82424	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21407	 82438	 0.001223	 0.006144	 0.0016	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21408	 21421	 0.002035	 0.005837	 0.00144	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21408	 82438	 0.003332	 0.009292	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82423	 21409	 0.011257	 0.022061	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21409	 82426	 0.00955	 0.033414	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21409	 82427	 0.003362	 0.014375	 0.00032	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21410	 21411	 0.025432	 0.016464	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21411	 21420	 0.003967	 0.017677	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21411	 82425	 0.005077	 0.022242	 0.00048	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21411	 82426	 0.022652	 0.017926	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21413	 21415	 0.00118	 0.004128	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21413	 82425	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21413	 82425	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82414	 21414	 0.005451	 0.016723	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82425	 21414	 0.004329	 0.016843	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21416	 21417	 0.039318	 0.025454	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21416	 21418	 0.006858	 0.018178	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82417	 21416	 0.003075	 0.021105	 0.00038	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21417	 82448	 0.006078	 0.018644	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21418	 82426	 0.03537	 0.026023	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21418	 82430	 0.007477	 0.021446	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21419	 21424	 0.000676	 0.003298	 0.00091	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82422	 21419	 0.003277	 0.015284	 0.00379	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21419	 82426	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21419	 82426	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21420	 82429	 0.00314	 0.009631	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21421	 21422	 0.001618	 0.004275	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21421	 82427	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21421	 82427	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21422	 21423	 0.001941	 0.007027	 0.00151	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21422	 21432	 0.001978	 0.005311	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21422	 82428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21422	 82428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21423	 21425	 0.003045	 0.00882	 0.00213	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21423	 82429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21423	 82429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21424	 21429	 0.000507	 0.002326	 0.0006	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21425	 21426	 0.001211	 0.003143	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21425	 21428	 0.001537	 0.003952	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21425	 82430	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21425	 82430	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21426	 21598	 0.001491	 0.004003	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21426	 82431	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21426	 82431	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21427	 21492	 0.00875	 0.008596	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82430	 21427	 0.013514	 0.020702	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21427	 82432	 0.003203	 0.008234	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21427	 82462	 0.011685	 0.019684	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21428	 21429	 0.000602	 0.002065	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21428	 82432	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21428	 82432	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21429	 82433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21429	 82433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21430	 21431	 0.012891	 0.01302	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82428	 21430	 0.016476	 0.027478	 0.0004	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82433	 21430	 0.00566	 0.01455	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21431	 82460	 0.022341	 0.014463	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21432	 21493	 0.001439	 0.003804	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21432	 82434	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21432	 82434	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21433	 21455	 0.001234	 0.004158	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21433	 21494	 0.001373	 0.003739	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21433	 82435	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21433	 82435	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21434	 21435	 9.7e-05	 0.00106	 0.01041	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21434	 82436	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21435	 21547	 0.000387	 0.004247	 0.04125	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82412	 21435	 0.000582	 0.006595	 0.06005	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21435	 82438	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21436	 21437	 0.006951	 0.023188	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21436	 21439	 0.011595	 0.026639	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82439	 21436	 0.002386	 0.01271	 0.00022	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21437	 21438	 0.035729	 0.030536	 0.00057	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21437	 21441	 0.023127	 0.049559	 0.00087	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21438	 21439	 0.007478	 0.017101	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21438	 21441	 0.009979	 0.028316	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82437	 21439	 0.005865	 0.026136	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21440	 82490	 0.013778	 0.035418	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21441	 21443	 0.017336	 0.017702	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21441	 21444	 0.008262	 0.01918	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82410	 21441	 0.10344	 0.29675	 0.00457	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21442	 21599	 0.002641	 0.009061	 0.00217	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21442	 82440	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21442	 82440	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82440	 21444	 0.01476	 0.029224	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82440	 21445	 0.009469	 0.02408	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21446	 21447	 0.002743	 0.006896	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82438	 21446	 0.002777	 0.007209	 0.00175	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21447	 21454	 0.001827	 0.004744	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21448	 21452	 0.001247	 0.004409	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21448	 21599	 0.001627	 0.005307	 0.00141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21449	 21451	 0.007286	 0.011879	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21449	 82508	 0.011255	 0.026129	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21450	 21451	 0.004445	 0.008402	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21450	 21453	 0.005393	 0.013863	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21450	 82490	 0.005544	 0.012871	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21452	 21544	 0.001129	 0.00518	 0.00133	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21453	 82488	 0.006554	 0.016848	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21454	 21455	 0.001452	 0.00428	 0.001	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21454	 21544	 0.001749	 0.004694	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21455	 21543	 0.001641	 0.004337	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21456	 21463	 0.001847	 0.004644	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21456	 82441	 0.001231	 0.004291	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21457	 21464	 0.000164	 0.001798	 0.01747	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21457	 82441	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21457	 82453	 0.000125	 0.001422	 0.01294	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21458	 21460	 5.6e-05	 0.000675	 0.00668	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21458	 21465	 3.3e-05	 0.000392	 0.00387	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21459	 21473	 0.027639	 0.022749	 0.00046	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21459	 82444	 0.014137	 0.010014	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21460	 21462	 3.6e-05	 0.000488	 0.00498	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21460	 82443	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82441	 21461	 0.001372	 0.006894	 0.00179	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82443	 21461	 0.002208	 0.007439	 0.00185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21461	 82445	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21461	 82445	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21462	 21464	 5.2e-05	 0.000718	 0.00731	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21463	 82446	 0.002131	 0.005533	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21464	 82446	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21464	 82446	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21465	 21600	 0.000155	 0.002768	 0.02871	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21466	 21467	 0.001257	 0.004553	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21466	 21474	 0.001096	 0.003967	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21467	 21472	 0.000823	 0.004819	 0.00131	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82418	 21467	 0.000706	 0.004991	 0.00137	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21467	 82447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21467	 82447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82447	 21468	 0.005274	 0.012243	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21468	 82448	 0.006649	 0.019071	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21469	 21471	 0.002467	 0.006879	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21469	 21490	 0.001409	 0.004596	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21469	 82448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21469	 82448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82448	 21470	 0.020857	 0.022717	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21470	 82449	 0.009974	 0.019748	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21470	 82469	 0.026115	 0.020032	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21471	 21475	 0.001179	 0.004866	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21471	 82449	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21471	 82449	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21472	 21475	 0.000612	 0.003298	 0.00091	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21473	 21480	 0.033647	 0.021783	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82445	 21473	 0.009354	 0.01363	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21474	 21481	 0.001274	 0.005941	 0.00147	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21475	 21479	 0.000654	 0.003327	 0.00121	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21475	 82450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21475	 82450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21475	 82458	 0.003001	 0.012494	 0.0039	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82449	 21476	 0.026211	 0.018567	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82450	 21476	 0.007174	 0.014681	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21476	 82511	 0.030185	 0.050849	 0.00072	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21477	 21513	 0.001012	 0.003975	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21477	 82451	 0.0005	 0.002003	 0.0005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21478	 21600	 3.1e-05	 0.00034	 0.00321	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21478	 21603	 9.6e-05	 0.001338	 0.01323	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21478	 82451	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21478	 82451	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21479	 21488	 0.000494	 0.003848	 0.00115	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82442	 21480	 0.005867	 0.014361	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21480	 82452	 0.005769	 0.015251	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21481	 82452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21481	 82452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21481	 82455	 0.002094	 0.007184	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82452	 21482	 0.013314	 0.009796	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21483	 21487	 1.9e-05	 0.00053	 0.19264	 4426.0	 4647.3	 4868.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21483	 82453	 0.000163	 0.013066	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21483	 82453	 0.000163	 0.013066	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82454	 21483	 0.000149	 0.011888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 0	 -30.0	 30.0;
	82453	 21484	 4.5e-05	 0.000783	 0.01612	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21484	 82455	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21484	 82455	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21484	 82457	 8.5e-05	 0.001527	 0.02972	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21485	 21488	 0.0004	 0.004956	 0.00215	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82454	 21485	 0.00104	 0.007521	 0.00405	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82455	 21485	 0.000478	 0.004103	 0.00117	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21485	 82456	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21485	 82456	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21486	 21566	 0.010561	 0.025008	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82456	 21486	 0.003623	 0.020596	 0.00037	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21487	 82457	 0.000129	 0.010315	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21487	 82457	 0.000129	 0.010315	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82458	 21487	 0.000233	 0.018607	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 0	 -30.0	 30.0;
	82458	 21487	 0.000233	 0.018607	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 0	 -30.0	 30.0;
	21488	 82459	 0.001686	 0.006558	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82457	 21489	 8.3e-05	 0.000906	 0.0088	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21489	 82459	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21489	 82459	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21490	 21598	 0.001175	 0.003569	 0.00078	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82431	 21491	 0.006525	 0.012918	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21491	 82463	 0.005516	 0.009293	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82431	 21492	 0.018713	 0.024353	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21492	 82462	 0.005379	 0.010649	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21493	 21496	 0.001066	 0.002474	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21493	 82460	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21493	 82460	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21494	 21495	 0.001339	 0.003367	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21494	 82461	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21494	 82461	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21495	 21503	 0.001299	 0.003434	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21496	 21497	 0.001213	 0.003206	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21497	 21498	 0.001022	 0.002653	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21497	 82462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21497	 82462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21498	 82463	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21498	 82463	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21498	 82464	 0.001568	 0.003778	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21499	 21513	 0.001843	 0.004872	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21499	 21598	 0.001421	 0.0033	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82462	 21500	 0.020498	 0.016222	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21500	 82465	 0.010963	 0.00841	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21501	 21511	 4.5e-05	 0.000521	 0.00457	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21501	 82464	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21502	 21510	 0.001123	 0.003491	 0.00073	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21502	 21602	 0.000995	 0.004049	 0.00099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21502	 82466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21502	 82466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21503	 21510	 0.001498	 0.003959	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21504	 21505	 0.001437	 0.003858	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21504	 21510	 0.001785	 0.005006	 0.00129	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21505	 21542	 0.00169	 0.004536	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21506	 21507	 0.015717	 0.012438	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21507	 21508	 0.022107	 0.014312	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21507	 21523	 0.023452	 0.01856	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21507	 82472	 0.008423	 0.014189	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21507	 82495	 0.091382	 0.066061	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21508	 21509	 0.020463	 0.015055	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21508	 82472	 0.01402	 0.014315	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82466	 21509	 0.022534	 0.02301	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21509	 82467	 0.014583	 0.011048	 0.00015	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21509	 82470	 0.008213	 0.01626	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21510	 82467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21510	 82467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21510	 82510	 0.002748	 0.011346	 0.00268	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21511	 21538	 0.000214	 0.002466	 0.02161	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21511	 82468	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21511	 82468	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21512	 21513	 0.000883	 0.00347	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82468	 21512	 0.00069	 0.002764	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21513	 82469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21513	 82469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21514	 21515	 0.000593	 0.002372	 0.0006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21514	 82510	 0.000816	 0.00406	 0.00131	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21515	 21516	 0.000528	 0.001779	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21516	 21517	 0.000373	 0.001317	 0.0003	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21516	 82470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21516	 82470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21517	 21520	 0.000852	 0.002288	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21517	 82471	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21517	 82471	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82471	 21518	 0.006568	 0.007224	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21518	 82472	 0.015537	 0.012296	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21519	 21520	 0.001121	 0.002817	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21519	 82472	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21519	 82472	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21519	 82473	 0.000834	 0.002165	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21521	 21522	 4.7e-05	 0.000535	 0.00487	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21521	 21525	 5.3e-05	 0.000591	 0.00562	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21521	 82473	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21522	 21558	 6.8e-05	 0.000783	 0.00686	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21522	 21561	 8.7e-05	 0.000991	 0.00902	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21522	 82475	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21522	 82475	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82474	 21523	 0.010064	 0.009018	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21524	 21535	 0.023822	 0.018852	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21524	 82477	 0.005449	 0.015463	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21525	 21538	 0.000148	 0.001613	 0.01583	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21525	 82476	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21526	 21527	 0.000984	 0.00276	 0.00071	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82476	 21526	 0.001589	 0.003995	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21526	 82478	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21526	 82478	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21527	 21531	 0.000973	 0.003336	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21527	 82479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21527	 82479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82479	 21528	 0.015705	 0.011554	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21528	 82511	 0.00474	 0.016192	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82459	 21529	 0.000708	 0.004484	 0.00122	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21529	 82480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21529	 82480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21529	 82487	 0.002117	 0.007666	 0.00164	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21530	 82481	 0.011958	 0.00906	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21531	 82481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21531	 82481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21531	 82484	 0.000487	 0.002232	 0.00057	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21532	 21533	 0.006429	 0.009849	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21532	 21534	 0.020094	 0.015902	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82479	 21532	 0.014127	 0.010703	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82481	 21532	 0.00197	 0.007578	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21533	 21534	 0.013696	 0.010839	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82478	 21533	 0.020472	 0.016047	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21534	 21537	 0.020394	 0.016139	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21535	 82483	 0.008928	 0.017498	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21536	 21561	 0.000147	 0.001634	 0.01556	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21536	 21591	 0.000119	 0.001351	 0.0123	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21536	 82482	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21537	 82499	 0.007411	 0.015229	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21538	 21541	 0.000122	 0.001357	 0.01292	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21538	 82484	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82484	 21539	 0.000779	 0.00282	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21539	 82498	 0.000904	 0.00446	 0.00121	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21540	 21541	 5.6e-05	 0.000638	 0.00581	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21540	 82486	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21540	 82486	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21541	 21600	 0.000146	 0.001685	 0.01477	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21541	 21603	 0.000133	 0.001545	 0.01336	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82457	 21541	 8.3e-05	 0.000875	 0.01309	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82457	 21541	 8.3e-05	 0.000875	 0.01309	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21541	 82487	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21541	 82487	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21542	 21543	 0.00162	 0.004282	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21542	 82489	 0.00216	 0.005608	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21542	 82492	 0.001622	 0.00421	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21544	 82489	 0.000878	 0.004263	 0.00097	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21545	 82488	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21545	 82488	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21545	 82489	 0.001587	 0.007145	 0.0019	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82488	 21546	 0.009094	 0.018005	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21546	 82491	 0.013363	 0.026188	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21547	 21558	 0.000102	 0.001156	 0.01053	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21547	 21603	 0.000407	 0.004625	 0.04177	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21547	 82489	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21547	 82489	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21548	 82490	 0.008905	 0.017632	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82489	 21549	 0.001037	 0.010478	 0.00308	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21549	 82490	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21549	 82490	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21550	 21551	 0.011754	 0.018005	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82490	 21550	 0.008735	 0.024787	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21552	 21564	 0.042979	 0.043886	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82490	 21552	 0.042512	 0.049833	 0.00087	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21553	 21554	 0.012432	 0.019844	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21554	 82491	 0.003987	 0.012229	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21555	 21557	 0.0017	 0.004493	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21555	 82491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21555	 82491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21556	 21557	 0.001322	 0.003897	 0.00091	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21556	 21560	 0.00126	 0.00432	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82489	 21557	 0.00174	 0.004737	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21558	 82492	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21558	 82492	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21559	 21560	 0.000766	 0.002086	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82475	 21559	 0.001374	 0.003742	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21560	 82493	 0.001121	 0.002911	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21561	 82493	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82491	 21562	 0.010885	 0.021332	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82494	 21562	 0.009983	 0.027616	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82493	 21563	 0.003234	 0.008395	 0.00204	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21563	 82495	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21563	 82495	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21563	 82505	 0.003093	 0.01078	 0.0025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82495	 21564	 0.012132	 0.05406	 0.00092	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21565	 21601	 0.002092	 0.008378	 0.00211	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81886	 21565	 0.002296	 0.0126	 0.00333	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21565	 82496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21565	 82496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81887	 21566	 0.009564	 0.024584	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82496	 21566	 0.010724	 0.027567	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21567	 21568	 0.003216	 0.011207	 0.0026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21568	 21569	 0.003772	 0.00997	 0.00233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81886	 21569	 0.00343	 0.010324	 0.00323	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21569	 82497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21569	 82497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21570	 82498	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21570	 82498	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21571	 21574	 0.001538	 0.005436	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82498	 21571	 0.001148	 0.007123	 0.00173	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21571	 82499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21571	 82499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21572	 21575	 0.032337	 0.023376	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21572	 82506	 0.037291	 0.029511	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21573	 21574	 0.001278	 0.003565	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21573	 82500	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21573	 82500	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21573	 82505	 0.001639	 0.00395	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21575	 21576	 0.004782	 0.009468	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21575	 82502	 0.010702	 0.012811	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82499	 21576	 0.003965	 0.01259	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21577	 21578	 0.001215	 0.004169	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21577	 21582	 0.004212	 0.013739	 0.00365	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81886	 21577	 0.000877	 0.0087	 0.00237	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21578	 21579	 0.002825	 0.007584	 0.00172	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21578	 82501	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21578	 82501	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21579	 82502	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21579	 82502	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21580	 21581	 0.01806	 0.014292	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21580	 21583	 0.009729	 0.019262	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21581	 21596	 0.028292	 0.02239	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21581	 82503	 0.048362	 0.038273	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21582	 21587	 0.001116	 0.003233	 0.00078	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21582	 82503	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21582	 82503	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21583	 21584	 0.041942	 0.030858	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82502	 21583	 0.00572	 0.015122	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82503	 21583	 0.023782	 0.018821	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21584	 21585	 0.022252	 0.01761	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82501	 21584	 0.008797	 0.017418	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21585	 82504	 0.008771	 0.017366	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21586	 82504	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21586	 82504	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21587	 21588	 0.000838	 0.002249	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21589	 82507	 0.013877	 0.046293	 0.00073	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21590	 21592	 0.038959	 0.047493	 0.00076	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21590	 21596	 0.047009	 0.04702	 0.00064	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21590	 82506	 0.008183	 0.026351	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21591	 82505	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21593	 21595	 0.028502	 0.043661	 0.00061	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21594	 21597	 0.001653	 0.005672	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21594	 82507	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21594	 82507	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82507	 21595	 0.004903	 0.019072	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82506	 21596	 0.012956	 0.030681	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82329	 21597	 0.00338	 0.013531	 0.00341	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21599	 82508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21599	 82508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21600	 82509	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21600	 82509	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82454	 21601	 0.001027	 0.006432	 0.00463	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82468	 21602	 0.000699	 0.002796	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21603	 82510	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21604	 21817	 0.000971	 0.010651	 0.10348	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21604	 21855	 0.000766	 0.008565	 0.08003	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82131	 21604	 0.003027	 0.036036	 0.33181	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21604	 82512	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82512	 21605	 0.002751	 0.00714	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21605	 82514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21605	 82514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21606	 21610	 0.045083	 0.089263	 0.00131	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21606	 82519	 0.032859	 0.084469	 0.00131	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21606	 82611	 0.094466	 0.271	 0.00417	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21607	 82516	 0.096576	 0.12694	 0.00174	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21607	 82630	 0.047562	 0.093215	 0.0014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21608	 21609	 0.00042	 0.004851	 0.04253	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21608	 82515	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21609	 21762	 0.000917	 0.010581	 0.09278	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21609	 82517	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82513	 21610	 0.042436	 0.13019	 0.00353	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21610	 82519	 0.011347	 0.02917	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21610	 82520	 0.006122	 0.029402	 0.00057	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21611	 21612	 0.000764	 0.008736	 0.00266	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21611	 82519	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21611	 82519	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82515	 21612	 0.001113	 0.018553	 0.00564	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21612	 82520	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21612	 82520	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82520	 21613	 0.049456	 0.0505	 0.00079	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82514	 21614	 0.04492	 0.091928	 0.00226	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82518	 21615	 0.068568	 0.17628	 0.00273	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21616	 21617	 0.005477	 0.040001	 0.01028	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82154	 21616	 0.008647	 0.088977	 0.02525	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21617	 21618	 0.009369	 0.03214	 0.0077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21618	 21700	 0.005169	 0.036563	 0.01003	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21619	 21621	 0.000619	 0.006798	 0.06603	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21619	 22041	 0.000519	 0.009592	 0.09217	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21619	 82521	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21619	 82521	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21620	 21621	 0.000127	 0.001416	 0.01336	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21620	 22037	 0.000405	 0.007067	 0.07646	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21620	 82522	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21621	 21628	 0.000458	 0.005445	 0.05	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21621	 82524	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21621	 82524	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81927	 21622	 0.02475	 0.023913	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21622	 82526	 0.010228	 0.020045	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21623	 82525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21623	 82525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21624	 21627	 0.002813	 0.015433	 0.00408	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82524	 21624	 0.002395	 0.008068	 0.00201	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21624	 82526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21624	 82526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21625	 21626	 0.001675	 0.017621	 0.0099	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21625	 82703	 0.00254	 0.020799	 0.01337	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82295	 21626	 0.011943	 0.047821	 0.01205	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82522	 21626	 0.016946	 0.045498	 0.01031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21626	 82527	 0.002633	 0.014968	 0.00433	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82130	 21627	 0.004103	 0.022515	 0.00595	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21627	 82527	 0.006105	 0.016133	 0.00378	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21628	 21924	 0.002472	 0.027152	 0.26421	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21628	 22037	 0.00123	 0.013634	 0.12985	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21628	 82527	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21628	 82527	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21629	 21632	 0.010321	 0.013565	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21629	 21638	 0.015439	 0.015765	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21629	 21659	 0.012876	 0.012441	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21630	 21659	 0.017042	 0.013487	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21630	 82528	 0.006444	 0.012628	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21631	 21647	 0.003049	 0.008058	 0.00189	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21631	 82528	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21631	 82528	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21632	 21633	 0.007647	 0.011142	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21632	 82529	 0.012804	 0.02535	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21632	 82535	 0.00609	 0.014907	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21634	 21636	 0.003109	 0.007991	 0.00198	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21634	 82529	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21634	 82529	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82529	 21635	 0.009354	 0.013258	 0.00027	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21635	 82536	 0.037252	 0.088854	 0.00199	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82400	 21636	 0.026159	 0.087294	 0.02215	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21636	 82530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21636	 82530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82529	 21637	 0.022961	 0.038139	 0.00081	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82530	 21637	 0.014162	 0.025552	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21638	 21639	 0.014833	 0.011738	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82529	 21638	 0.006049	 0.01404	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21640	 21641	 0.002996	 0.010847	 0.00233	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21640	 21652	 0.004907	 0.017768	 0.00381	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21641	 21644	 0.005045	 0.013736	 0.00303	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21641	 21655	 0.00844	 0.028952	 0.00694	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21641	 82531	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21641	 82531	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82528	 21642	 0.021528	 0.017037	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21642	 82533	 0.019873	 0.020292	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21643	 82532	 0.008828	 0.017301	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21644	 21645	 0.002061	 0.006259	 0.00137	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21644	 21656	 0.005915	 0.015357	 0.00373	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21644	 82532	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21644	 82532	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21645	 21646	 0.001313	 0.004642	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21645	 82533	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21645	 82533	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21646	 21657	 0.003795	 0.014425	 0.00404	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21646	 82534	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21646	 82534	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21647	 21648	 0.00176	 0.005929	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21647	 82535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21647	 82535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21648	 21649	 0.002284	 0.007833	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21649	 21650	 0.004718	 0.01997	 0.00449	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21650	 82536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21650	 82536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21651	 21708	 0.000414	 0.005663	 0.05771	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21651	 82537	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82537	 21652	 0.001062	 0.00966	 0.00244	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21652	 82539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21652	 82539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82538	 21653	 0.012097	 0.034328	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82539	 21653	 0.015179	 0.035241	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82530	 21654	 0.036299	 0.064837	 0.00096	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82539	 21654	 0.015725	 0.029239	 0.00068	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21655	 21677	 0.008859	 0.029555	 0.0075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21656	 82540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21656	 82540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21657	 21658	 0.003196	 0.014567	 0.00462	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21658	 82541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21658	 82541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21660	 21664	 0.002798	 0.028779	 0.00816	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21661	 21662	 0.002842	 0.021121	 0.00805	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21661	 21945	 0.006157	 0.033788	 0.00893	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21661	 82542	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21661	 82542	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21662	 21666	 0.012469	 0.032372	 0.00786	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82231	 21662	 0.004685	 0.039405	 0.01167	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21662	 82543	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21662	 82543	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82543	 21663	 0.017625	 0.078536	 0.00133	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21663	 82544	 0.017937	 0.023574	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21664	 82544	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21664	 82544	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21664	 82545	 0.001682	 0.024725	 0.00756	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82544	 21665	 0.010941	 0.027825	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21665	 82546	 0.017723	 0.078088	 0.00136	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21666	 21709	 0.018384	 0.050057	 0.01103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21666	 82545	 0.007433	 0.029759	 0.0075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21667	 82545	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82546	 21668	 0.019311	 0.094234	 0.00163	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21669	 82547	 0.028778	 0.073977	 0.00114	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21670	 82547	 0.057379	 0.037148	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21670	 82548	 0.02995	 0.023702	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21671	 21672	 0.003903	 0.010884	 0.00228	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21671	 82547	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21671	 82547	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21672	 82548	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21672	 82548	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21673	 21674	 0.02602	 0.067437	 0.00128	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81923	 21673	 0.20091	 0.15902	 0.002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21673	 82563	 0.068296	 0.1866	 0.00317	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82288	 21674	 0.18658	 0.12081	 0.0023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81923	 21675	 0.018097	 0.042853	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82547	 21675	 0.025644	 0.073551	 0.00113	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21676	 82549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21676	 82549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21677	 21679	 0.005482	 0.012725	 0.00388	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21678	 21679	 0.003439	 0.009233	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21679	 82550	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21679	 82550	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82539	 21680	 0.091951	 0.26098	 0.0041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82550	 21680	 0.009077	 0.013608	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21681	 21704	 0.006849	 0.03142	 0.00805	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21682	 21683	 0.014336	 0.038489	 0.00872	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82311	 21683	 0.014517	 0.044084	 0.00966	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21683	 82551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21683	 82551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21683	 82552	 0.008119	 0.056336	 0.01608	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82315	 21684	 0.060944	 0.17481	 0.00269	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21684	 82553	 0.036841	 0.090179	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21685	 82552	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21686	 21688	 0.000218	 0.002517	 0.02207	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21686	 82554	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21686	 82554	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82167	 21687	 0.059149	 0.16966	 0.00261	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82554	 21687	 0.019789	 0.035569	 0.00064	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21687	 82556	 0.008477	 0.024928	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21688	 82555	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82556	 21689	 0.031285	 0.077653	 0.00129	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21690	 21691	 0.000141	 0.001551	 0.01506	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21690	 82557	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21691	 82559	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21691	 82559	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82558	 21692	 0.05537	 0.14234	 0.0022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21692	 82720	 0.057812	 0.22494	 0.00376	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21693	 21695	 0.007098	 0.02842	 0.00716	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82555	 21693	 0.001511	 0.014786	 0.01285	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82557	 21693	 0.001857	 0.024359	 0.01169	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82085	 21694	 0.32232	 0.25517	 0.00321	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82556	 21694	 0.05044	 0.12828	 0.00203	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21694	 82720	 0.043682	 0.14573	 0.00231	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21695	 22094	 0.006982	 0.028414	 0.00692	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21696	 21697	 0.13514	 0.090783	 0.0016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82159	 21697	 0.022722	 0.088398	 0.00148	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21697	 82651	 0.019236	 0.11826	 0.00213	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82115	 21698	 0.22038	 0.50462	 0.01234	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21698	 82560	 0.037691	 0.21181	 0.00392	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21699	 82560	 0.035407	 0.091018	 0.00141	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21699	 82562	 0.069617	 0.13784	 0.00202	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21700	 82560	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21700	 82560	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21701	 21702	 0.004794	 0.028082	 0.00765	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21701	 82561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21701	 82561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21702	 22058	 0.007333	 0.053562	 0.01377	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21702	 82562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21702	 82562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82562	 21703	 0.11943	 0.094523	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21704	 21707	 0.005357	 0.026648	 0.0086	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21704	 82563	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21704	 82563	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21705	 21706	 0.009349	 0.038925	 0.01214	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21705	 21770	 0.006407	 0.0419	 0.01066	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21705	 82564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21705	 82564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81917	 21706	 0.00996	 0.061819	 0.01498	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82537	 21707	 0.010508	 0.02728	 0.00662	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21707	 82565	 0.004321	 0.025741	 0.00677	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21708	 82565	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21708	 82565	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21709	 21711	 0.012484	 0.032995	 0.00772	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21709	 82566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21709	 82566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21710	 21711	 0.008991	 0.023762	 0.00556	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21710	 22006	 0.008869	 0.023025	 0.00559	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21710	 82567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21710	 82567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21712	 21766	 0.13163	 0.18347	 0.00314	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82567	 21712	 0.06815	 0.1752	 0.00271	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21713	 82569	 0.10013	 0.17612	 0.00331	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21714	 82568	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81859	 21715	 0.003509	 0.057523	 0.01809	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82568	 21715	 0.001981	 0.022185	 0.00705	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21715	 82570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21715	 82570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21716	 21717	 0.011474	 0.036946	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81860	 21716	 0.054896	 0.24466	 0.00416	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82570	 21716	 0.01757	 0.028045	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82569	 21717	 0.034652	 0.070914	 0.00175	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81900	 21718	 0.019939	 0.050127	 0.01299	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21718	 82571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21718	 82571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81901	 21719	 0.039961	 0.028888	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81901	 21720	 0.10903	 0.086285	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21720	 82572	 0.091761	 0.14648	 0.00337	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21721	 82572	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21721	 82572	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21722	 21724	 0.000748	 0.008866	 0.00454	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21722	 21737	 0.00362	 0.012665	 0.0042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21723	 21725	 0.000123	 0.001863	 0.03338	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21723	 82573	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21723	 82573	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21724	 82574	 0.000469	 0.007649	 0.00456	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21724	 82575	 0.0004	 0.005892	 0.00288	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21725	 21726	 0.000108	 0.001647	 0.02952	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21725	 82574	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21725	 82574	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21726	 82575	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21726	 82575	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21727	 21734	 0.002744	 0.007253	 0.0017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21727	 21753	 0.004274	 0.013358	 0.00387	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81915	 21728	 0.007028	 0.019943	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21728	 82576	 0.011158	 0.022093	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21729	 82576	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21729	 82576	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21730	 21733	 0.020314	 0.031118	 0.00044	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21730	 21735	 0.010549	 0.020887	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82576	 21730	 0.012892	 0.036976	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21731	 21734	 0.002254	 0.005794	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21731	 82577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21731	 82577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21732	 21736	 0.017095	 0.039687	 0.00059	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21732	 21747	 0.021183	 0.044521	 0.00081	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82577	 21732	 0.003016	 0.014716	 0.00025	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21733	 21736	 0.013143	 0.037695	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81922	 21733	 0.11943	 0.086341	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82577	 21733	 0.035463	 0.043231	 0.00069	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21733	 82578	 0.035953	 0.026452	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21734	 82578	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21734	 82578	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21736	 21747	 0.069475	 0.051115	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21737	 21740	 0.001548	 0.006198	 0.00156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21737	 21745	 0.010428	 0.027561	 0.00645	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21738	 21742	 0.002547	 0.023428	 0.00046	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82577	 21738	 0.004796	 0.047	 0.00092	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21739	 21742	 0.019736	 0.035473	 0.00064	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21739	 21744	 0.027501	 0.01948	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21739	 82580	 0.1209	 0.09274	 0.00125	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21740	 21745	 0.008181	 0.01899	 0.00579	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21740	 82579	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21740	 82579	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21741	 21742	 0.008827	 0.016167	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82579	 21741	 0.011414	 0.017486	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21742	 21744	 0.015455	 0.0306	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82579	 21742	 0.019725	 0.033229	 0.00047	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21743	 21744	 0.022247	 0.018311	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82579	 21743	 0.00764	 0.019352	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21745	 82580	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21745	 82580	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21746	 21747	 0.070205	 0.050752	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21748	 21749	 0.005509	 0.014559	 0.00341	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21749	 21750	 0.007945	 0.019972	 0.00517	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21751	 82581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21751	 82581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81880	 21752	 0.001638	 0.009594	 0.00261	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81880	 21753	 0.000146	 0.002201	 0.00155	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21754	 82582	 0.085907	 0.24643	 0.00379	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21755	 21756	 0.1515	 0.10953	 0.00166	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21755	 82584	 0.21571	 0.13968	 0.00266	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21756	 21998	 0.18553	 0.13144	 0.00208	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21756	 82582	 0.17861	 0.14136	 0.00178	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21757	 21760	 0.005947	 0.027281	 0.00699	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81873	 21757	 0.002058	 0.0155	 0.0043	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21757	 82582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21757	 82582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21758	 82583	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21758	 82583	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21759	 21760	 0.001413	 0.005981	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82583	 21759	 0.00317	 0.013416	 0.00302	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21760	 82584	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21760	 82584	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21761	 82586	 0.078475	 0.057737	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21762	 21763	 0.000354	 0.006592	 0.06242	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21762	 22092	 0.001163	 0.013173	 0.11997	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21762	 82585	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21763	 21889	 0.000625	 0.007078	 0.06444	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21763	 82587	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21764	 22087	 0.009911	 0.038956	 0.01019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82587	 21764	 0.011129	 0.039338	 0.00886	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21765	 21766	 0.058471	 0.15032	 0.00233	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82546	 21765	 0.059484	 0.13494	 0.00269	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21766	 82589	 0.023674	 0.072701	 0.00136	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21767	 21768	 0.00383	 0.012777	 0.00324	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21767	 21771	 0.010022	 0.034379	 0.00824	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21767	 82589	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21767	 82589	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21768	 21769	 0.006221	 0.02096	 0.00521	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21768	 21770	 0.009655	 0.032208	 0.00817	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82537	 21770	 0.025724	 0.0867	 0.02156	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21770	 82590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21770	 82590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21771	 82591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21771	 82591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21772	 21774	 0.006843	 0.023474	 0.00562	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21772	 21775	 0.002132	 0.025906	 0.00698	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21772	 82592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21772	 82592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82117	 21773	 0.16916	 0.30415	 0.00546	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82592	 21773	 0.051124	 0.14143	 0.00329	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21773	 82595	 0.035321	 0.10131	 0.00156	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21774	 82593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21774	 82593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21775	 21776	 0.00061	 0.005397	 0.00296	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21775	 82594	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21775	 82594	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21776	 21777	 0.006689	 0.026781	 0.00675	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21776	 21779	 0.008157	 0.03266	 0.00823	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21777	 82595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21777	 82595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21778	 22072	 0.004087	 0.035663	 0.00979	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21778	 25684	 0.007845	 0.043207	 0.0156	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21778	 82596	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21778	 82596	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21779	 82597	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21779	 82597	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21780	 21781	 0.007722	 0.027294	 0.00615	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21780	 82598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21780	 82598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21781	 21782	 0.002895	 0.026332	 0.00665	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21781	 82599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21781	 82599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21782	 21784	 0.003259	 0.029647	 0.00748	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21782	 82600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21782	 82600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21783	 21784	 0.008905	 0.031161	 0.01033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21784	 21785	 0.009647	 0.024799	 0.00614	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21786	 21789	 0.000851	 0.008603	 0.00253	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21787	 82601	 0.048308	 0.1144	 0.00209	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21787	 82634	 0.039505	 0.17605	 0.00299	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21788	 21789	 0.001111	 0.009242	 0.0028	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21788	 21790	 0.00368	 0.02772	 0.00769	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21788	 82601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21788	 82601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21790	 82637	 0.003359	 0.043717	 0.01264	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21791	 21813	 0.000811	 0.003649	 0.00097	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21791	 82602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21791	 82602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21792	 21793	 0.015696	 0.014719	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21792	 21795	 0.012469	 0.011693	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82602	 21792	 0.007251	 0.017171	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21792	 82603	 0.009374	 0.01856	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21794	 21796	 0.00259	 0.008883	 0.00213	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21794	 21835	 0.002764	 0.008006	 0.00193	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21794	 82603	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21794	 82603	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21795	 82604	 0.003977	 0.007284	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21796	 21811	 0.000643	 0.00224	 0.00052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21796	 82604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21796	 82604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21797	 21798	 0.011814	 0.00854	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21797	 21809	 0.007618	 0.008297	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21798	 21799	 0.001428	 0.006365	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21798	 21809	 0.007523	 0.01068	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21798	 21810	 0.007072	 0.016248	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21798	 82606	 0.007529	 0.017958	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21799	 21801	 0.009643	 0.014051	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21799	 21838	 0.002803	 0.014933	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21800	 21801	 0.008043	 0.011209	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21800	 21807	 0.005983	 0.012295	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21800	 82605	 0.001978	 0.008715	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21802	 21804	 0.009373	 0.014358	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21802	 21849	 0.003245	 0.011361	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21802	 82605	 0.006663	 0.03253	 0.00068	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21803	 21804	 0.015334	 0.015488	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21803	 21807	 0.005934	 0.011749	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21804	 21805	 0.012001	 0.009205	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21805	 21806	 0.004734	 0.009372	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21806	 21821	 0.002592	 0.009075	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21806	 82614	 0.017405	 0.013774	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21808	 21819	 0.001206	 0.003101	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21808	 21826	 0.00303	 0.010561	 0.00245	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21808	 82605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21808	 82605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21808	 82610	 0.000506	 0.003169	 0.00228	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21809	 21810	 0.002151	 0.005702	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21810	 82611	 0.002799	 0.010931	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21811	 21812	 0.00056	 0.002497	 0.00068	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21811	 82606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21811	 82606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21812	 21813	 0.001137	 0.0039	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21812	 82610	 0.000893	 0.003235	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21813	 21815	 0.000337	 0.003297	 0.00093	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21813	 21835	 0.003973	 0.015908	 0.00401	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21813	 82607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21813	 82607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21813	 82610	 0.002643	 0.006985	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82607	 21814	 0.001755	 0.009352	 0.00016	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21814	 82609	 0.0019	 0.009274	 0.00019	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21814	 82613	 0.043684	 0.037336	 0.0007	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21815	 21836	 0.000513	 0.0044	 0.00125	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21815	 82608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21815	 82608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21816	 21818	 0.001083	 0.004583	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21816	 21836	 0.001211	 0.006125	 0.0017	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21816	 82609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21816	 82609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21817	 21829	 0.000324	 0.004023	 0.04041	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21817	 21834	 0.000228	 0.004038	 0.0423	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21817	 22239	 0.000655	 0.007566	 0.06633	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21817	 82610	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21818	 21861	 0.001827	 0.020571	 0.00595	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82610	 21818	 0.000627	 0.005211	 0.00204	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21819	 82612	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21819	 82612	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21820	 21823	 0.011883	 0.009115	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82612	 21820	 0.008253	 0.008794	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21821	 21822	 0.007059	 0.018145	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82612	 21821	 0.008306	 0.016446	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21822	 82627	 0.010101	 0.021566	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21824	 21858	 0.001028	 0.00651	 0.00177	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82610	 21824	 0.002184	 0.00644	 0.0015	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21824	 82613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21824	 82613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82613	 21825	 0.031677	 0.025069	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21826	 21827	 0.001272	 0.004364	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21826	 82614	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21826	 82614	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21827	 21828	 0.001599	 0.003711	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21828	 21832	 0.002324	 0.005975	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21828	 82615	 0.001655	 0.004297	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21829	 21856	 8.8e-05	 0.001	 0.0091	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21829	 82615	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21829	 82615	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21830	 82622	 0.034628	 0.025477	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21830	 82625	 0.032322	 0.025579	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21831	 82616	 0.022315	 0.01766	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21831	 82626	 0.043245	 0.067477	 0.00113	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82610	 21832	 0.004566	 0.019011	 0.00593	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21832	 82616	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21832	 82616	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21833	 21834	 0.000157	 0.002908	 0.02794	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21833	 82617	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21833	 82617	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21834	 22227	 0.001117	 0.012893	 0.11306	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21834	 82618	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21834	 82618	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21835	 21841	 0.003605	 0.012146	 0.00302	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81933	 21835	 0.034221	 0.088873	 0.02158	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21835	 82619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21835	 82619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82618	 21836	 0.00076	 0.00799	 0.00449	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21837	 21838	 0.006119	 0.012115	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82603	 21837	 0.015701	 0.030068	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21838	 21839	 0.0113	 0.03241	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82619	 21838	 0.087478	 0.067102	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21839	 21843	 0.039044	 0.030605	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21839	 21849	 0.012111	 0.022889	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21839	 21852	 0.014889	 0.031293	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21840	 21841	 0.001708	 0.005696	 0.00144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21840	 82620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21840	 82620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82620	 21842	 0.04123	 0.030334	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82620	 21843	 0.028873	 0.02285	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82620	 21844	 0.010413	 0.027598	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21844	 82621	 0.00932	 0.018453	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21845	 21846	 0.002166	 0.005444	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21845	 22242	 0.00778	 0.022937	 0.00534	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21845	 82621	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21845	 82621	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21846	 21848	 0.002894	 0.006717	 0.00205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21847	 21848	 0.00311	 0.009169	 0.00213	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21848	 22303	 0.007313	 0.017624	 0.00498	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82199	 21848	 0.011682	 0.031806	 0.00701	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21849	 21853	 0.024112	 0.019082	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82199	 21850	 0.009653	 0.025512	 0.00597	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82615	 21850	 0.00115	 0.005776	 0.0015	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21850	 82622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21850	 82622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21850	 82778	 0.019742	 0.053754	 0.01184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21851	 21852	 0.041332	 0.03876	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21851	 21854	 0.01937	 0.037961	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82622	 21851	 0.008407	 0.02161	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82616	 21853	 0.010193	 0.020181	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82200	 21854	 0.069463	 0.054972	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21855	 21856	 0.000151	 0.00171	 0.01557	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21855	 82623	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82198	 21856	 0.000315	 0.003657	 0.03162	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21856	 82625	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21856	 82625	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21857	 21859	 0.004041	 0.012632	 0.00366	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21857	 82626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21857	 82626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21858	 21859	 0.001117	 0.006942	 0.00196	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21858	 21860	 0.000852	 0.009193	 0.00263	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21859	 82627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21859	 82627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21860	 21864	 0.001801	 0.016953	 0.00514	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21862	 21863	 0.000322	 0.003531	 0.0343	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21862	 22230	 0.001301	 0.014738	 0.13424	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21862	 82628	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21862	 82628	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21863	 82629	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82628	 21864	 0.002401	 0.029176	 0.00786	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21864	 82631	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21864	 82631	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82512	 21865	 0.009483	 0.024376	 0.00604	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82623	 21865	 0.011033	 0.02916	 0.00683	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21866	 82632	 0.093506	 0.073296	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21866	 82633	 0.12945	 0.083815	 0.0016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21867	 21869	 0.007083	 0.019015	 0.00431	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21867	 82632	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21867	 82632	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21868	 21869	 0.00247	 0.01419	 0.00402	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21868	 22056	 0.002961	 0.026234	 0.00698	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21869	 21870	 0.010481	 0.02814	 0.00638	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21869	 82633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21869	 82633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21871	 82634	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21871	 82634	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21871	 82635	 0.003522	 0.022683	 0.00595	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82328	 21872	 0.035207	 0.093319	 0.00237	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82634	 21872	 0.054289	 0.14352	 0.00261	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21873	 21875	 0.000248	 0.002623	 0.02736	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21873	 82635	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21873	 82635	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82329	 21874	 0.006713	 0.062507	 0.01937	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21874	 82636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21874	 82636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21874	 82637	 0.003228	 0.013135	 0.0032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21875	 21878	 6.2e-05	 0.001123	 0.01123	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21875	 82637	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21875	 82637	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21876	 21877	 0.000358	 0.002035	 0.00059	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82635	 21876	 0.004384	 0.017229	 0.00451	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82637	 21876	 0.001455	 0.006157	 0.00139	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21876	 82638	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21876	 82638	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21877	 82639	 0.000461	 0.002831	 0.00082	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21878	 21879	 0.000119	 0.001504	 0.01342	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21878	 82639	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21879	 21880	 0.000345	 0.00379	 0.03682	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21879	 82641	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21879	 82641	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21880	 82642	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21880	 82642	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21881	 21882	 0.003372	 0.023736	 0.0135	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21881	 21883	 0.007702	 0.053441	 0.01526	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82191	 21881	 0.001733	 0.028397	 0.00893	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 21882	 0.002765	 0.02507	 0.01311	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 21883	 0.002241	 0.025616	 0.00781	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21883	 82643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21883	 82643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81860	 21884	 0.12545	 0.13665	 0.00186	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82643	 21884	 0.08281	 0.16397	 0.00241	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21884	 82705	 0.10115	 0.20029	 0.00294	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81860	 21885	 0.086169	 0.068194	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21886	 21887	 0.0031	 0.019239	 0.00466	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82629	 21886	 0.004605	 0.025692	 0.00656	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21887	 21890	 0.002301	 0.016801	 0.00432	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82517	 21888	 0.002921	 0.021704	 0.00828	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21888	 82644	 0.001869	 0.020669	 0.0062	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21889	 82644	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21889	 82644	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21890	 21891	 0.002206	 0.0223	 0.00656	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82644	 21890	 0.007894	 0.020863	 0.00488	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82587	 21891	 0.016511	 0.042868	 0.01041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21891	 82645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21891	 82645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81896	 21892	 0.060261	 0.15326	 0.00242	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82581	 21892	 0.062804	 0.16145	 0.0025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82588	 21892	 0.052619	 0.13383	 0.00212	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21893	 21897	 0.011242	 0.029713	 0.00696	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21893	 21898	 0.013011	 0.033448	 0.00828	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21893	 21901	 0.00843	 0.053402	 0.0145	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21893	 22610	 0.025774	 0.088445	 0.0212	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21893	 82646	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21893	 82646	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21894	 21896	 0.03182	 0.058282	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21894	 22251	 0.040563	 0.11511	 0.00181	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21894	 22252	 0.04659	 0.095346	 0.00235	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21894	 82647	 0.031376	 0.089991	 0.00138	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21895	 82647	 0.12588	 0.12715	 0.00168	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21896	 21900	 0.033149	 0.12896	 0.00215	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21896	 82647	 0.012772	 0.049136	 0.00084	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21897	 21898	 0.00571	 0.026197	 0.00671	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21897	 27768	 0.004331	 0.031661	 0.00934	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21898	 82647	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21898	 82647	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82647	 21899	 0.014339	 0.042167	 0.00086	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21899	 82648	 0.009472	 0.053301	 0.00115	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21901	 82648	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21901	 82648	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21902	 21904	 0.005198	 0.029868	 0.00846	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21902	 22031	 0.012069	 0.043703	 0.00938	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81868	 21903	 0.012687	 0.032881	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21903	 82649	 0.036732	 0.075171	 0.00185	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81867	 21904	 0.003172	 0.022433	 0.00616	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21904	 82649	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21904	 82649	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82649	 21905	 0.12055	 0.095405	 0.0012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21905	 82650	 0.050044	 0.1323	 0.0024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21906	 82650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21906	 82650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21907	 82651	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21907	 82651	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21908	 21909	 0.11952	 0.12072	 0.0016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81928	 21909	 0.082497	 0.16335	 0.0024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82323	 21909	 0.033904	 0.15108	 0.00257	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21910	 82652	 0.007449	 0.015308	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21910	 82664	 0.017895	 0.041546	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21911	 82652	 0.016763	 0.013266	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21912	 21913	 0.000868	 0.004235	 0.00117	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21912	 21914	 0.00099	 0.003394	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21912	 82657	 0.001681	 0.005034	 0.00113	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21913	 21931	 0.001945	 0.005222	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21913	 21946	 0.000986	 0.005655	 0.00188	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21913	 82652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21913	 82652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21914	 21915	 0.001753	 0.004552	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21915	 82653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21915	 82653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21915	 82655	 0.002446	 0.005895	 0.00166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21916	 21917	 0.00986	 0.007803	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21917	 21918	 0.003251	 0.008268	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82652	 21917	 0.031581	 0.02237	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21917	 82665	 0.004915	 0.015825	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82653	 21918	 0.003675	 0.008531	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21918	 82656	 0.02167	 0.026899	 0.00059	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21919	 21920	 0.000764	 0.002765	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21919	 21946	 0.002451	 0.006364	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21920	 21922	 0.001063	 0.003648	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21921	 82654	 0.008135	 0.020688	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21922	 21923	 0.000814	 0.005464	 0.00132	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21922	 82654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21922	 82654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21923	 82662	 0.002803	 0.022751	 0.00724	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21924	 21926	 0.000201	 0.002285	 0.02063	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21924	 21940	 0.000351	 0.005819	 0.05454	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21924	 82655	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82655	 21925	 0.003137	 0.00854	 0.00188	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21925	 82657	 0.0017	 0.005545	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21926	 21933	 0.000234	 0.004097	 0.04383	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21926	 21942	 4.2e-05	 0.000477	 0.00434	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21926	 82657	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21926	 82657	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21927	 21928	 0.001917	 0.005219	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21927	 21936	 0.002611	 0.007488	 0.00184	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21927	 82658	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21927	 82658	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21928	 21929	 0.001701	 0.005015	 0.00117	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21928	 21931	 0.00302	 0.01036	 0.00248	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81878	 21928	 0.014263	 0.051652	 0.01108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21929	 21931	 0.001606	 0.005018	 0.00145	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21930	 82659	 0.010583	 0.008295	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21931	 21946	 0.000783	 0.00572	 0.00147	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21931	 82659	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21931	 82659	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82659	 21932	 0.002299	 0.007668	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21933	 82660	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21934	 21935	 0.049185	 0.067105	 0.0012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81907	 21934	 0.043127	 0.10013	 0.00149	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82658	 21935	 0.023551	 0.030953	 0.00042	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21937	 21938	 0.008241	 0.009064	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82658	 21937	 0.042531	 0.033659	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21938	 21939	 0.011498	 0.009099	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82659	 21938	 0.005748	 0.011762	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21940	 82662	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21940	 82662	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21941	 21945	 0.006855	 0.024822	 0.00533	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82655	 21941	 0.006074	 0.016938	 0.00356	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21942	 82663	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82664	 21943	 0.040366	 0.064433	 0.00148	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82656	 21944	 0.015523	 0.078985	 0.00179	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82662	 21946	 0.001395	 0.015565	 0.01036	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21946	 82665	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21946	 82665	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82406	 21947	 0.060347	 0.15641	 0.00296	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21947	 82667	 0.03373	 0.096744	 0.00149	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21948	 21949	 0.007274	 0.029125	 0.00734	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21950	 82666	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21951	 21952	 0.060937	 0.10717	 0.00201	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82213	 21951	 0.041676	 0.18364	 0.00319	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21951	 82709	 0.20415	 0.16159	 0.00203	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21952	 25005	 0.1602	 0.16183	 0.00214	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21953	 21973	 0.021665	 0.01594	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21953	 21974	 0.024466	 0.019362	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21953	 82668	 0.026188	 0.027902	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21954	 82677	 0.002307	 0.007912	 0.0019	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21955	 21956	 0.001693	 0.004721	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21955	 82668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21955	 82668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21955	 82677	 0.002396	 0.010786	 0.00287	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21956	 21972	 0.001893	 0.005002	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21956	 82669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21956	 82669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82668	 21957	 0.020366	 0.016117	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82669	 21957	 0.014804	 0.011604	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21958	 21987	 0.002016	 0.005328	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21958	 82670	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21958	 82670	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21959	 21960	 0.012324	 0.009753	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82670	 21959	 0.019678	 0.015573	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21960	 21961	 0.024083	 0.017719	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21960	 21963	 0.034508	 0.027309	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82668	 21961	 0.024082	 0.036891	 0.00052	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21961	 82676	 0.023551	 0.018638	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21962	 21963	 0.026137	 0.020685	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82669	 21962	 0.038998	 0.03768	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21963	 21996	 0.042207	 0.08674	 0.00165	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21964	 21965	 0.011764	 0.007616	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21964	 21968	 0.011474	 0.00908	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21965	 21967	 0.008301	 0.008384	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21966	 21967	 0.007642	 0.008405	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21966	 82673	 0.005439	 0.009162	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21968	 21969	 0.0042	 0.010797	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21969	 82672	 0.002367	 0.010164	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21970	 21992	 0.000374	 0.004109	 0.03991	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21970	 82671	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21971	 21975	 0.004849	 0.010879	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82672	 21971	 0.004327	 0.011124	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82671	 21972	 0.001405	 0.006326	 0.00168	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21972	 82673	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21972	 82673	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82673	 21973	 0.002198	 0.009794	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21973	 82674	 0.011373	 0.029236	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21974	 21975	 0.008435	 0.0167	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21974	 21984	 0.013088	 0.025913	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21975	 82674	 0.007654	 0.015154	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21976	 21977	 0.001273	 0.003304	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82671	 21976	 0.000788	 0.003153	 0.00079	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21976	 82674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21976	 82674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21977	 21978	 0.001966	 0.005918	 0.00185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81921	 21978	 0.000129	 0.001126	 0.00031	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82671	 21978	 0.002212	 0.006717	 0.00147	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21978	 82675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21978	 82675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82675	 21979	 0.017641	 0.01856	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21980	 21981	 0.001278	 0.003285	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81921	 21980	 0.001016	 0.002611	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21981	 82682	 0.003729	 0.009374	 0.00243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21982	 21991	 0.016454	 0.025205	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82674	 21982	 0.007941	 0.015386	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21983	 21991	 0.01604	 0.010385	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21984	 82679	 0.015888	 0.024339	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21985	 22001	 0.028167	 0.02134	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21985	 82676	 0.010552	 0.017776	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82668	 21986	 0.009057	 0.021026	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82670	 21986	 0.024094	 0.018482	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21986	 82704	 0.035914	 0.064551	 0.00116	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21987	 21988	 0.002009	 0.005308	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21987	 82676	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21987	 82676	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21988	 21989	 0.00193	 0.005101	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21989	 22051	 0.003056	 0.007935	 0.00193	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82676	 21990	 0.031037	 0.031045	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21990	 82678	 0.036356	 0.071252	 0.00107	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21991	 82681	 0.007896	 0.020297	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21992	 82677	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21993	 82681	 0.012521	 0.048709	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21993	 82684	 0.038417	 0.063812	 0.00135	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21994	 82679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21994	 82679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21995	 82680	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81874	 21996	 0.010694	 0.05698	 0.001	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81861	 21997	 0.001625	 0.017841	 0.17343	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21997	 82682	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21998	 21999	 0.1266	 0.081968	 0.00156	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82681	 21998	 0.06461	 0.057896	 0.00118	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82683	 21998	 0.029988	 0.058102	 0.00125	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82680	 22000	 0.004766	 0.023503	 0.00636	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22000	 82684	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22000	 82684	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81869	 22002	 0.010775	 0.035144	 0.00933	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22003	 22004	 0.004231	 0.036291	 0.01033	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81869	 22003	 0.004109	 0.026464	 0.00694	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81911	 22003	 0.002818	 0.024587	 0.00675	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22003	 82685	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22003	 82685	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22004	 22005	 0.003406	 0.017111	 0.00445	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22004	 82686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22004	 82686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22005	 22026	 0.006385	 0.020827	 0.00553	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22005	 82687	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22005	 82687	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22006	 22024	 0.007284	 0.023759	 0.00631	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22006	 82688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22006	 82688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22007	 82695	 0.010424	 0.019702	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22008	 22009	 0.000316	 0.00191	 0.00049	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22008	 22011	 0.001072	 0.006787	 0.00184	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22008	 22014	 0.00038	 0.00365	 0.00106	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22008	 22015	 0.000328	 0.002812	 0.0008	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22009	 22010	 0.000399	 0.002336	 0.00064	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22010	 22011	 0.000454	 0.002876	 0.00078	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22011	 82689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22011	 82689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22011	 82691	 0.000335	 0.003038	 0.00159	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22012	 22013	 0.000621	 0.00596	 0.00173	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22012	 22033	 0.000829	 0.007802	 0.00236	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22013	 22014	 0.00052	 0.004464	 0.00127	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81903	 22013	 0.000461	 0.005466	 0.0028	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22015	 22016	 0.000474	 0.004313	 0.00109	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22015	 22017	 0.002611	 0.00701	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81903	 22016	 0.002792	 0.015323	 0.00405	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22016	 82690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22016	 82690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22017	 22019	 0.001991	 0.005118	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82689	 22018	 0.02169	 0.01568	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82690	 22018	 0.017434	 0.050004	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22018	 82692	 0.007093	 0.017966	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22019	 22030	 0.005173	 0.012465	 0.00352	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22020	 22032	 0.000369	 0.006481	 0.06934	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22020	 22034	 0.000185	 0.003288	 0.0341	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81902	 22020	 0.000262	 0.003219	 0.05158	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22020	 82691	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22021	 22022	 0.001205	 0.004734	 0.00124	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82691	 22021	 0.001051	 0.003605	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22022	 82693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22022	 82693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22022	 82696	 0.001746	 0.015878	 0.00401	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22023	 22025	 0.024372	 0.048254	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81903	 22024	 0.008161	 0.021188	 0.00514	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82686	 22025	 0.083127	 0.17014	 0.00419	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82690	 22025	 0.015311	 0.0523	 0.00114	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81903	 22026	 0.003613	 0.012393	 0.00297	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22027	 22028	 0.000953	 0.009795	 0.00371	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81877	 22027	 0.001316	 0.015624	 0.00544	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22028	 22033	 0.000475	 0.005775	 0.00156	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82691	 22029	 0.00224	 0.022645	 0.00666	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22030	 22031	 0.006865	 0.024266	 0.00547	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81866	 22032	 0.000862	 0.011291	 0.10222	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22032	 82694	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22032	 82694	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82691	 22033	 0.001153	 0.007153	 0.00173	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22033	 82695	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22033	 82695	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22034	 82696	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22034	 82696	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22035	 22036	 0.000104	 0.0012	 0.01052	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22035	 22037	 0.000434	 0.006819	 0.07107	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22035	 82697	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22035	 82697	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22036	 82698	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22036	 82698	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22037	 82699	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22037	 82699	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22038	 22039	 0.000219	 0.003103	 0.02935	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22038	 82700	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22038	 82700	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22039	 22041	 7.3e-05	 0.001159	 0.01216	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22039	 82701	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22039	 82701	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82699	 22040	 0.004132	 0.018954	 0.00486	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22040	 82702	 0.002106	 0.006868	 0.00182	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22041	 22042	 0.000333	 0.003652	 0.03547	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22041	 82702	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22041	 82702	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22042	 82703	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22042	 82703	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81908	 22043	 0.012202	 0.053115	 0.01514	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81912	 22044	 0.15517	 0.44529	 0.00685	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82230	 22044	 0.074073	 0.15569	 0.00284	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82572	 22045	 0.090116	 0.21343	 0.0039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82643	 22045	 0.060191	 0.15308	 0.00242	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22046	 22050	 0.003236	 0.033806	 0.00929	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22047	 22054	 0.032866	 0.084488	 0.00131	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22048	 22054	 0.063742	 0.050445	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22049	 22050	 0.000938	 0.010503	 0.00334	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81888	 22049	 0.002332	 0.01679	 0.01402	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22051	 22055	 0.002251	 0.005948	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22051	 82704	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22051	 82704	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22052	 22053	 0.002411	 0.008269	 0.00198	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22052	 22055	 0.001695	 0.005815	 0.00139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81888	 22053	 0.001213	 0.013859	 0.00423	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22053	 82705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22053	 82705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82705	 22054	 0.006353	 0.04361	 0.00079	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22056	 22060	 0.002551	 0.02492	 0.00699	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22057	 22059	 0.007798	 0.031223	 0.00787	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22058	 22059	 0.001952	 0.020536	 0.01154	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22058	 22061	 0.014302	 0.037132	 0.00901	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22059	 22060	 0.000908	 0.009181	 0.0027	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22060	 82706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22060	 82706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82274	 22061	 0.016883	 0.057922	 0.01388	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22062	 22068	 0.00178	 0.008299	 0.00206	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22062	 82707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22062	 82707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22063	 22064	 0.01169	 0.027136	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22063	 82711	 0.020623	 0.043344	 0.00079	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82707	 22064	 0.002743	 0.009371	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22065	 22078	 0.000273	 0.003149	 0.0276	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22065	 82708	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22065	 82708	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22066	 82713	 0.001472	 0.010211	 0.00291	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82708	 22067	 0.002502	 0.008756	 0.0029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22068	 82709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22068	 82709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82707	 22069	 0.008631	 0.00908	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22070	 27244	 0.010341	 0.062078	 0.0188	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22070	 82710	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22070	 82710	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22071	 22072	 0.00189	 0.018145	 0.00528	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82708	 22071	 0.000946	 0.009723	 0.00368	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22071	 82711	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22071	 82711	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22073	 22074	 0.09776	 0.097787	 0.00132	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82597	 22073	 0.048401	 0.12442	 0.00193	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22074	 22076	 0.12723	 0.13995	 0.00187	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22075	 22076	 0.024352	 0.09474	 0.00158	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22075	 82714	 0.026088	 0.084007	 0.00143	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82212	 22076	 0.087137	 0.13349	 0.00187	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82291	 22076	 0.030298	 0.18415	 0.0034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22077	 22078	 0.000205	 0.002282	 0.02152	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22077	 27252	 0.000758	 0.013815	 0.13698	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22077	 82712	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22077	 82712	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22078	 82713	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82099	 22079	 0.03876	 0.099639	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22080	 22082	 0.00263	 0.027872	 0.00827	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22081	 22083	 0.001046	 0.010571	 0.00311	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22082	 82715	 0.000878	 0.008874	 0.00261	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22083	 82715	 0.000676	 0.004685	 0.00275	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22084	 82715	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22084	 82715	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81920	 22085	 0.020617	 0.040405	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22086	 22090	 0.00917	 0.036716	 0.00925	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82585	 22086	 0.021876	 0.057823	 0.01354	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22086	 82716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22086	 82716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22086	 82719	 0.006318	 0.024833	 0.0065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22087	 22088	 0.014852	 0.050952	 0.01221	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22087	 82717	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22087	 82717	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22089	 22090	 0.001388	 0.015866	 0.00484	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81878	 22089	 0.008271	 0.033657	 0.0082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82312	 22089	 0.011884	 0.073083	 0.02108	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22090	 82718	 0.001747	 0.006996	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22091	 22092	 0.000339	 0.003773	 0.03558	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22091	 82718	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22091	 82718	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22092	 82719	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22092	 82719	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81879	 22093	 0.014941	 0.049843	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22094	 22099	 0.00629	 0.025598	 0.00624	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22094	 82720	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22094	 82720	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82340	 22095	 0.020051	 0.13605	 0.00254	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22095	 82721	 0.023675	 0.092105	 0.00154	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22095	 82722	 0.060592	 0.14068	 0.00209	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22096	 22098	 0.001547	 0.021814	 0.00746	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82341	 22096	 0.001969	 0.025628	 0.00741	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22097	 22098	 0.002412	 0.016177	 0.00391	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22097	 22099	 0.003636	 0.021294	 0.0058	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22097	 82721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22097	 82721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22098	 82722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22098	 82722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22099	 82723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22099	 82723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82722	 22100	 0.035622	 0.10217	 0.00157	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22101	 22102	 0.079064	 0.13206	 0.00224	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22101	 22141	 0.073904	 0.14485	 0.00217	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22102	 22103	 0.25145	 0.18182	 0.00276	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22102	 22141	 0.080779	 0.20546	 0.00325	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22102	 22737	 0.16642	 0.38251	 0.00581	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22103	 22104	 0.082581	 0.19172	 0.00365	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22103	 22105	 0.050295	 0.10738	 0.00242	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22103	 22141	 0.18043	 0.35375	 0.0053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22103	 82904	 0.078059	 0.19109	 0.00327	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22104	 23886	 0.097898	 0.2517	 0.0039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22105	 22736	 0.028067	 0.07215	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22106	 82724	 0.001712	 0.085583	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22107	 22108	 0.2631	 0.20628	 0.00265	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22107	 23351	 0.38405	 0.30408	 0.00383	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22108	 22380	 0.15584	 0.33288	 0.00752	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22108	 23351	 0.4582	 0.35941	 0.00461	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22108	 23364	 0.19184	 0.29394	 0.00511	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22108	 24099	 0.13073	 0.58311	 0.00992	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22109	 22118	 0.011598	 0.030653	 0.00717	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22109	 22129	 0.005384	 0.014228	 0.00333	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22109	 82726	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22109	 82726	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22110	 23934	 0.000285	 0.003173	 0.02992	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22110	 82727	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22110	 82727	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22111	 22112	 0.038655	 0.099369	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81992	 22111	 0.043459	 0.11172	 0.00173	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22111	 82983	 0.036522	 0.083908	 0.00127	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22112	 82728	 0.043763	 0.1016	 0.00151	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22113	 22160	 0.004134	 0.024211	 0.00659	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22113	 82728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22113	 82728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22114	 22124	 0.004719	 0.035364	 0.00863	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22115	 22122	 0.000508	 0.005759	 0.05243	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22115	 22130	 0.000761	 0.008469	 0.07988	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22115	 82729	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22115	 82729	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22116	 82730	 0.051876	 0.082807	 0.00191	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22116	 82733	 0.11169	 0.11202	 0.00181	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22117	 22118	 0.009534	 0.023967	 0.00621	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22117	 82730	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22117	 82730	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22117	 82740	 0.012543	 0.032565	 0.0079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22118	 22119	 0.019458	 0.054266	 0.01139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22118	 82731	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22118	 82731	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22119	 24133	 0.011648	 0.029281	 0.00759	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22119	 24134	 0.006531	 0.021301	 0.00566	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22119	 82732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22119	 82732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82731	 22120	 0.14235	 0.092165	 0.00175	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82732	 22120	 0.14106	 0.10379	 0.00152	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22121	 24133	 0.006296	 0.031047	 0.0084	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82729	 22121	 0.015147	 0.03894	 0.00964	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22121	 82733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22121	 82733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22122	 24144	 0.001293	 0.014196	 0.13795	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22122	 82734	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81993	 22123	 0.052454	 0.15045	 0.00231	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82730	 22123	 0.064258	 0.17033	 0.00432	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82735	 22123	 0.013145	 0.030517	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22124	 22127	 0.00482	 0.020977	 0.00598	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22125	 22126	 0.003663	 0.012947	 0.00292	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22125	 22841	 0.003943	 0.024503	 0.00692	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82734	 22125	 0.001434	 0.021626	 0.00645	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22125	 82736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22125	 82736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22126	 82737	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22126	 82737	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22127	 22128	 0.001293	 0.010018	 0.00351	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22127	 82738	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22127	 82738	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22128	 22838	 0.002896	 0.029268	 0.00861	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22128	 22839	 0.006921	 0.020727	 0.00467	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22128	 82739	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22128	 82739	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22128	 82740	 0.015743	 0.13074	 0.03443	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22129	 23947	 0.001653	 0.00461	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22130	 82740	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82730	 22131	 0.040904	 0.076058	 0.00178	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82741	 22131	 0.040161	 0.035987	 0.00074	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22131	 83253	 0.041348	 0.074607	 0.00108	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22132	 23931	 0.017777	 0.014068	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82731	 22132	 0.20816	 0.16476	 0.00207	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22132	 83254	 0.044915	 0.029078	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22133	 82742	 0.052457	 0.12179	 0.00181	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22134	 23892	 0.038902	 0.21749	 0.05572	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22134	 82742	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22134	 82742	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22136	 22137	 0.03407	 0.026962	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22136	 22138	 0.093757	 0.0607	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22136	 22139	 0.043356	 0.085843	 0.00126	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22136	 22140	 0.039551	 0.0313	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22137	 22139	 0.022528	 0.057911	 0.0009	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22137	 22140	 0.018787	 0.013822	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22139	 22141	 0.06171	 0.12629	 0.00311	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82742	 22139	 0.009119	 0.053986	 0.00105	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22142	 22144	 0.047483	 0.12076	 0.00191	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22142	 22313	 0.062896	 0.12453	 0.00183	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22143	 22145	 0.061096	 0.12504	 0.00308	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22143	 22148	 0.21975	 0.17393	 0.00219	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22143	 22317	 0.048014	 0.13626	 0.00214	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22143	 22858	 0.15911	 0.30081	 0.00487	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22144	 22147	 0.061335	 0.12553	 0.00309	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22145	 22146	 0.036006	 0.092559	 0.00143	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22145	 22858	 0.11443	 0.16222	 0.00332	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22146	 22147	 0.041683	 0.094553	 0.00189	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22147	 22581	 0.037816	 0.14549	 0.00248	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22148	 22861	 0.11393	 0.12531	 0.00167	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22148	 22862	 0.089399	 0.20449	 0.00499	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81986	 22148	 0.12136	 0.24033	 0.00353	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22149	 22152	 0.12914	 0.10221	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22149	 22739	 0.19366	 0.15182	 0.00195	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22150	 22151	 0.073828	 0.1447	 0.00217	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22150	 23874	 0.068285	 0.17555	 0.00272	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22151	 22152	 0.21913	 0.15525	 0.00245	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22151	 23875	 0.27012	 0.21179	 0.00272	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22151	 82743	 0.054619	 0.10004	 0.00173	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22153	 22189	 0.009869	 0.025622	 0.00622	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22153	 82743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22153	 82743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22154	 22626	 0.04825	 0.13146	 0.02899	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81960	 22154	 0.050675	 0.17096	 0.04256	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22154	 82744	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22154	 82744	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22155	 22627	 0.33587	 0.2659	 0.00335	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22155	 23361	 0.61008	 0.44949	 0.00657	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82744	 22155	 0.34468	 0.22327	 0.00425	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22156	 22157	 0.055336	 0.12656	 0.00309	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22156	 22165	 0.040834	 0.10497	 0.00162	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22156	 82815	 0.084578	 0.22362	 0.00406	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22157	 82967	 0.051839	 0.13704	 0.00249	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82728	 22158	 0.081857	 0.14771	 0.00214	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22158	 82984	 0.081708	 0.10739	 0.00147	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22159	 22161	 0.052649	 0.10424	 0.00153	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82728	 22159	 0.042394	 0.14143	 0.00224	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22160	 22166	 0.004548	 0.024231	 0.0068	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22161	 22162	 0.020732	 0.086076	 0.00224	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82739	 22161	 0.017159	 0.071627	 0.00207	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22161	 82933	 0.10994	 0.10127	 0.00162	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22162	 22163	 0.024424	 0.074927	 0.00203	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22162	 22267	 0.11635	 0.20785	 0.00307	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22162	 82745	 0.052678	 0.14949	 0.00235	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22162	 82933	 0.093477	 0.16441	 0.00309	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22163	 22164	 0.037973	 0.089923	 0.00164	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22164	 22413	 0.039037	 0.10035	 0.00155	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22165	 82745	 0.018381	 0.092981	 0.00162	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22166	 82745	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22166	 82745	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22167	 82746	 0.004386	 0.007713	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22167	 82747	 0.018364	 0.014533	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22167	 82748	 0.006377	 0.019582	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22168	 22170	 0.000725	 0.002266	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22168	 22191	 0.000914	 0.002415	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22168	 82746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22168	 82746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22169	 22170	 0.00137	 0.004701	 0.00113	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22169	 22176	 0.001547	 0.006079	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22169	 82747	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22169	 82747	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22171	 22172	 0.018258	 0.01182	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22171	 82756	 0.009601	 0.019009	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22172	 22173	 0.010066	 0.021155	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82747	 22172	 0.016427	 0.032193	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22173	 23985	 0.080305	 0.10555	 0.00145	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22173	 82756	 0.038427	 0.050505	 0.00069	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22173	 83272	 0.039187	 0.09098	 0.00135	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82746	 22174	 0.022182	 0.026554	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22174	 82751	 0.008617	 0.033523	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22174	 82756	 0.008691	 0.020177	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22175	 22184	 0.002363	 0.008352	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22175	 82748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22175	 82748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22175	 82752	 0.001522	 0.005221	 0.00125	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22176	 22177	 0.004036	 0.015861	 0.00415	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81949	 22176	 0.001976	 0.00719	 0.0022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22177	 24121	 0.002958	 0.032026	 0.01348	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22177	 82749	 0.00109	 0.009286	 0.00232	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22178	 82749	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22178	 82749	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81949	 22179	 0.008229	 0.032344	 0.00846	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22179	 83275	 0.008338	 0.028603	 0.00685	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22180	 23985	 0.00936	 0.045676	 0.00079	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22180	 82750	 0.006253	 0.042919	 0.00078	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22181	 82750	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22181	 82750	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22181	 82752	 0.003907	 0.024023	 0.00693	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22181	 83265	 0.001887	 0.028453	 0.00849	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22182	 22187	 0.006694	 0.026799	 0.00675	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22182	 83096	 0.00467	 0.018698	 0.00471	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82750	 22183	 0.019562	 0.049748	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22183	 82751	 0.06346	 0.064097	 0.00085	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22184	 82751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22184	 82751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22185	 82752	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82753	 22186	 0.05983	 0.047349	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22187	 82754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22187	 82754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22188	 22566	 0.11918	 0.27041	 0.0054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82754	 22188	 0.035059	 0.090864	 0.00172	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22188	 82755	 0.039399	 0.10415	 0.00189	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81951	 22189	 0.024589	 0.072511	 0.01687	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22189	 82755	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22189	 82755	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22190	 22572	 0.052033	 0.14925	 0.0023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22190	 23874	 0.18207	 0.29075	 0.0067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82743	 22190	 0.049516	 0.11726	 0.00214	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82755	 22190	 0.043971	 0.099744	 0.00199	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82752	 22191	 0.003463	 0.01188	 0.00285	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22191	 82756	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22191	 82756	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82748	 22192	 0.023066	 0.021246	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22193	 22194	 0.008304	 0.033793	 0.00823	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22193	 22587	 0.012753	 0.0519	 0.01265	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22194	 22197	 0.011241	 0.045747	 0.01115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22194	 82757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22194	 82757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22195	 22196	 0.044897	 0.061255	 0.00109	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82757	 22195	 0.1006	 0.13222	 0.00181	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22196	 82758	 0.065736	 0.13016	 0.00191	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22197	 23335	 0.006474	 0.029148	 0.00776	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22197	 82758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22197	 82758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22198	 22216	 0.011945	 0.023651	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22198	 82760	 0.002887	 0.012721	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22199	 22204	 0.000189	 0.002182	 0.01913	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22199	 82759	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22200	 22201	 0.011432	 0.009047	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82760	 22201	 0.010842	 0.019487	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22202	 22206	 0.038367	 0.030074	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22202	 22214	 0.010061	 0.01797	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22202	 82763	 0.007043	 0.013312	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22203	 22205	 0.00172	 0.004465	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82759	 22203	 0.002088	 0.005248	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22204	 22209	 0.000294	 0.003279	 0.03092	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22204	 82761	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22205	 82763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22205	 82763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82762	 22206	 0.023637	 0.024136	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82761	 22207	 0.002156	 0.005871	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22207	 82764	 0.005711	 0.015549	 0.00343	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22208	 22210	 0.026406	 0.020897	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82762	 22208	 0.024548	 0.048603	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81932	 22209	 0.000182	 0.002066	 0.01881	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22209	 82764	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22210	 22211	 0.016071	 0.015071	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22211	 22212	 0.056213	 0.056777	 0.00075	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22211	 22226	 0.08363	 0.084471	 0.00112	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82765	 22211	 0.013432	 0.038115	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22212	 82766	 0.071237	 0.05584	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22213	 22215	 0.007781	 0.018751	 0.00529	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22213	 22244	 0.008129	 0.020896	 0.00517	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22213	 82766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22213	 82766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22214	 82767	 0.031989	 0.025315	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82759	 22215	 0.002938	 0.010078	 0.00241	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22215	 82767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22215	 82767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22216	 22217	 0.02297	 0.018906	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22217	 22219	 0.027087	 0.021437	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22218	 22223	 0.10831	 0.082066	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82767	 22218	 0.016697	 0.045616	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22219	 22220	 0.086027	 0.068082	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82760	 22219	 0.028987	 0.056809	 0.00085	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22220	 22221	 0.082329	 0.065156	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22221	 24137	 0.050274	 0.090363	 0.00162	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22221	 82769	 0.041479	 0.054516	 0.00075	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22221	 83320	 0.12943	 0.13074	 0.00173	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22222	 22236	 0.001391	 0.015264	 0.14835	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22222	 82768	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82769	 22223	 0.037454	 0.09628	 0.00149	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22223	 82795	 0.054932	 0.11242	 0.00277	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82766	 22224	 0.10932	 0.083857	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22225	 22244	 0.005528	 0.014609	 0.00342	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22225	 82777	 0.008587	 0.022075	 0.00547	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22226	 82771	 0.013782	 0.053021	 0.00091	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22226	 82782	 0.03591	 0.0711	 0.00104	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81932	 22227	 0.000166	 0.001823	 0.0177	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22227	 82770	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82771	 22228	 0.017538	 0.089243	 0.00202	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22228	 82775	 0.011093	 0.067414	 0.00124	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22229	 22230	 0.000316	 0.003642	 0.03193	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22229	 82772	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22230	 82774	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22231	 22232	 0.004923	 0.019349	 0.00506	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82617	 22231	 0.007373	 0.028979	 0.00758	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82770	 22232	 0.007294	 0.025021	 0.00599	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22233	 82776	 0.070526	 0.055814	 0.0007	 28.0	 28.0	 28.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22233	 82782	 0.077738	 0.086256	 0.00168	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81933	 22234	 0.023335	 0.061681	 0.01444	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22234	 82776	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22234	 82776	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22234	 82778	 0.007731	 0.020432	 0.00478	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82619	 22235	 0.10786	 0.079361	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82776	 22235	 0.024666	 0.039372	 0.00091	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22236	 22238	 0.000162	 0.001866	 0.01636	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22236	 82777	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22236	 82777	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 0	 -30.0	 30.0;
	22237	 82780	 0.008035	 0.012826	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22238	 22239	 7.8e-05	 0.000901	 0.00779	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22238	 82778	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22238	 82778	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22239	 82779	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22239	 82779	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22240	 22300	 0.002734	 0.008918	 0.00237	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82777	 22240	 0.00417	 0.014049	 0.00349	 142.0	 149.1	 156.2	 0.0	 0.0	 0	 -30.0	 30.0;
	82779	 22240	 0.001123	 0.006047	 0.00166	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22240	 82780	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22240	 82780	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22241	 22242	 0.001921	 0.007816	 0.0019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82779	 22241	 0.000914	 0.005013	 0.00133	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22242	 82781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22242	 82781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82620	 22243	 0.053857	 0.042216	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82780	 22243	 0.10958	 0.086724	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82781	 22243	 0.030305	 0.023983	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22244	 22245	 0.005514	 0.014574	 0.00341	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81933	 22245	 0.013689	 0.032989	 0.00931	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22245	 82782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22245	 82782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22246	 22284	 0.06525	 0.1515	 0.00225	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22246	 22608	 0.061395	 0.15553	 0.00308	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22246	 82784	 0.038846	 0.098795	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22247	 22248	 0.008735	 0.029965	 0.00718	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22247	 22283	 0.007179	 0.024626	 0.0059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22248	 82783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22248	 82783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22249	 22251	 0.03096	 0.088799	 0.00137	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22249	 22254	 0.016926	 0.083986	 0.002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22249	 22609	 0.016084	 0.091428	 0.00165	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22250	 22254	 0.042859	 0.04714	 0.00063	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22251	 22252	 0.035865	 0.083253	 0.00159	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22251	 82786	 0.017545	 0.098725	 0.00213	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22253	 24086	 0.030199	 0.10567	 0.00219	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82783	 22253	 0.047636	 0.097488	 0.0024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22254	 82784	 0.005522	 0.024707	 0.00051	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22254	 82786	 0.011344	 0.055358	 0.00096	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22255	 22295	 0.034028	 0.094922	 0.01993	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22255	 82784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22255	 82784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22255	 82785	 0.002264	 0.009066	 0.00228	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82784	 22256	 0.007294	 0.018549	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22256	 82786	 0.012363	 0.032681	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22257	 22826	 0.002054	 0.023287	 0.21226	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22257	 27179	 0.003648	 0.040128	 0.39129	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22257	 82785	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22258	 22262	 0.001951	 0.013239	 0.00025	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22258	 82787	 0.002319	 0.014042	 0.00044	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22259	 22265	 0.001671	 0.005733	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22259	 82787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22259	 82787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22260	 82794	 0.017339	 0.012757	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22261	 82794	 0.023455	 0.023461	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22262	 22274	 0.012733	 0.043493	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22262	 22276	 0.003729	 0.014287	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22262	 82794	 0.003921	 0.023741	 0.00074	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22263	 22264	 0.025732	 0.020364	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22264	 22278	 0.070869	 0.056086	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82787	 22264	 0.026189	 0.026195	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22264	 82788	 0.008119	 0.02087	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22265	 22266	 0.001531	 0.006018	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22265	 82788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22265	 82788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22266	 22269	 0.004574	 0.012452	 0.00274	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22266	 22280	 0.004481	 0.015098	 0.00375	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22266	 82789	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22266	 82789	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82787	 22267	 0.057589	 0.063342	 0.00085	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82788	 22267	 0.050254	 0.047127	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82789	 22267	 0.02657	 0.024474	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82789	 22268	 0.022128	 0.024338	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22268	 82790	 0.013713	 0.024115	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22269	 82790	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22269	 82790	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22269	 82791	 0.000758	 0.008533	 0.00247	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22270	 22271	 0.017674	 0.045432	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22270	 22282	 0.024352	 0.074706	 0.00202	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82790	 22270	 0.016339	 0.038692	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22271	 22272	 0.02659	 0.019222	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82790	 22271	 0.012228	 0.031432	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22271	 82794	 0.012824	 0.026952	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22273	 22282	 0.024045	 0.063565	 0.00115	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82790	 22273	 0.015506	 0.054255	 0.00112	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22274	 22275	 0.017197	 0.045461	 0.00083	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22275	 22276	 0.014546	 0.042774	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22275	 22294	 0.023757	 0.10586	 0.0018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22276	 22277	 0.025691	 0.066042	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22277	 22413	 0.067162	 0.17266	 0.00267	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82788	 22279	 0.059863	 0.047375	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22280	 22837	 0.005048	 0.021363	 0.00481	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22281	 82791	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22281	 82791	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22282	 22284	 0.025534	 0.11315	 0.0034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22283	 82937	 0.011764	 0.064565	 0.01707	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22284	 22285	 0.035857	 0.09479	 0.00172	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22284	 82793	 0.094995	 0.12486	 0.00171	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22285	 22286	 0.026694	 0.098701	 0.00183	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22285	 82793	 0.044988	 0.11565	 0.00179	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22286	 22608	 0.052594	 0.10308	 0.00155	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22287	 82792	 0.039745	 0.043714	 0.00058	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22288	 82792	 0.038066	 0.02557	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22289	 82792	 0.061371	 0.044365	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22290	 22791	 0.018992	 0.092679	 0.0016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22290	 22792	 0.075219	 0.19338	 0.00299	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22290	 22793	 0.052696	 0.12234	 0.00182	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22290	 82792	 0.007964	 0.030641	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22290	 82792	 0.007964	 0.030641	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22291	 22295	 0.002206	 0.031108	 0.01064	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22291	 82792	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22291	 82792	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22292	 22293	 0.009778	 0.025843	 0.00605	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22292	 22418	 0.010754	 0.028423	 0.00665	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22293	 22295	 0.007283	 0.018907	 0.00459	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22294	 82793	 0.011623	 0.042975	 0.0008	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22295	 82793	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22295	 82793	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22295	 82929	 0.007553	 0.089537	 0.04586	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82791	 22296	 0.001692	 0.012801	 0.00629	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22296	 82794	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22296	 82794	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22297	 22298	 0.023503	 0.10473	 0.00178	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22297	 24080	 0.030725	 0.081436	 0.00207	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82204	 22298	 0.008073	 0.049631	 0.00089	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82203	 22299	 0.091904	 0.072733	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22300	 22303	 0.005433	 0.018125	 0.0046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22301	 22305	 0.017344	 0.04584	 0.01073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22301	 22306	 0.009386	 0.025555	 0.00563	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22302	 24081	 0.006327	 0.035303	 0.00902	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22302	 24143	 0.005047	 0.033004	 0.00839	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22304	 22305	 0.004279	 0.020453	 0.00716	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82768	 22304	 0.01101	 0.047923	 0.01366	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22304	 82795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22304	 82795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22305	 22306	 0.013291	 0.033412	 0.00866	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22305	 24142	 0.008233	 0.028242	 0.00677	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22305	 24143	 0.005144	 0.040096	 0.01199	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82202	 22306	 0.020081	 0.053917	 0.01222	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82780	 22307	 0.053363	 0.085181	 0.00196	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82795	 22307	 0.19085	 0.15105	 0.0019	 27.0	 27.0	 27.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22308	 22309	 0.009624	 0.025435	 0.00595	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22308	 23891	 0.016432	 0.042663	 0.01036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22308	 82796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22308	 82796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22309	 22430	 0.009682	 0.02636	 0.00581	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22310	 22318	 0.12874	 0.10092	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22310	 82797	 0.059227	 0.11727	 0.00172	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22311	 22320	 0.00698	 0.017942	 0.00444	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22311	 22430	 0.012582	 0.041041	 0.0109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22311	 82797	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22311	 82797	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22311	 82869	 0.034625	 0.17725	 0.04841	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22312	 22320	 0.046581	 0.12319	 0.02886	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22312	 23115	 0.048785	 0.11765	 0.03325	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82797	 22313	 0.13549	 0.14904	 0.00199	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82797	 22314	 0.061772	 0.093638	 0.00195	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22315	 22316	 0.032454	 0.025439	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82797	 22316	 0.075881	 0.1553	 0.00382	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22317	 22318	 0.029712	 0.058828	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82796	 22317	 0.22406	 0.14509	 0.00276	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22317	 82819	 0.28314	 0.22413	 0.00282	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22318	 22319	 0.01877	 0.014713	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22321	 22322	 0.03982	 0.10236	 0.00158	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22321	 22325	 0.23855	 0.18882	 0.00238	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22322	 22323	 0.093888	 0.074304	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22322	 23117	 0.20229	 0.15858	 0.00204	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22323	 22324	 0.13989	 0.10293	 0.00151	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22323	 22429	 0.25337	 0.42706	 0.00609	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22324	 22327	 0.10289	 0.18496	 0.00332	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22325	 22326	 0.15833	 0.12411	 0.00159	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22325	 22327	 0.26005	 0.1684	 0.00321	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22325	 22328	 0.3647	 0.286	 0.00367	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22325	 22426	 0.28091	 0.22025	 0.00283	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22326	 22429	 0.21056	 0.15224	 0.00231	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22327	 22328	 0.08464	 0.16759	 0.00246	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22328	 83232	 0.07651	 0.1967	 0.00304	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22329	 22330	 0.16864	 0.13347	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22331	 22332	 0.019426	 0.015227	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22333	 22334	 0.10386	 0.22261	 0.0039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81987	 22333	 0.017447	 0.044371	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22334	 22335	 0.50215	 0.39774	 0.00501	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22334	 22336	 0.18729	 0.18099	 0.00263	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22334	 23114	 0.5912	 0.43553	 0.00637	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22335	 83017	 0.36307	 0.26725	 0.00391	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22336	 82798	 0.088905	 0.17604	 0.00258	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22337	 23111	 0.074924	 0.19836	 0.04653	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22337	 82798	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22337	 82798	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22338	 22339	 0.61045	 0.47912	 0.00615	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22338	 22340	 0.12323	 0.24156	 0.00362	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22338	 23113	 0.18136	 0.19757	 0.00269	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82798	 22340	 0.002947	 0.007496	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22341	 22349	 0.038028	 0.070711	 0.00166	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22341	 22567	 0.061917	 0.1776	 0.00273	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22341	 23962	 0.056711	 0.14579	 0.00226	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22342	 22350	 0.04239	 0.10897	 0.00169	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22342	 23879	 0.069979	 0.17991	 0.00278	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22343	 22351	 0.053466	 0.17837	 0.00283	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81981	 22343	 0.076618	 0.33769	 0.00587	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22344	 24860	 0.021968	 0.13295	 0.03396	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22344	 82799	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22344	 82799	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22344	 82908	 0.013364	 0.08467	 0.02299	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22345	 23883	 0.029848	 0.14566	 0.00251	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82799	 22345	 0.013214	 0.06448	 0.00111	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82799	 22346	 0.040567	 0.12446	 0.00337	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22346	 82800	 0.044305	 0.13607	 0.00255	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82799	 22347	 0.15848	 0.10261	 0.00195	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22348	 22571	 0.007876	 0.036134	 0.00926	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22348	 82800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22348	 82800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22349	 22351	 0.026678	 0.05717	 0.001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22350	 22351	 0.031404	 0.074365	 0.00136	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82800	 22351	 0.01917	 0.10214	 0.00179	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22352	 22357	 0.053411	 0.054539	 0.00085	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22352	 82801	 0.005484	 0.029347	 0.00089	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22352	 82807	 0.027369	 0.072351	 0.00131	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22353	 22354	 0.002077	 0.006773	 0.0018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22353	 22355	 0.002437	 0.006634	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22353	 22368	 0.004751	 0.016559	 0.00384	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22354	 82801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22354	 82801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22355	 22358	 0.003918	 0.010354	 0.00242	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22355	 82802	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22355	 82802	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22356	 22357	 0.035128	 0.0278	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22357	 22640	 0.030674	 0.024044	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22357	 22658	 0.00821	 0.016254	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22358	 22359	 0.003213	 0.017302	 0.00475	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22358	 22402	 0.010539	 0.027853	 0.00652	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22358	 22659	 0.001221	 0.006938	 0.00201	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22359	 82803	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22359	 82803	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22359	 82969	 0.01257	 0.15833	 0.04914	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22360	 22403	 0.057907	 0.1661	 0.00255	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22360	 82900	 0.039237	 0.11254	 0.00173	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22360	 82901	 0.057721	 0.10909	 0.00176	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82803	 22361	 0.10887	 0.21339	 0.0032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22361	 82804	 0.082455	 0.09871	 0.00164	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22361	 82877	 0.16784	 0.33241	 0.00488	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22361	 82899	 0.074982	 0.15346	 0.00378	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22362	 22363	 0.01095	 0.037566	 0.009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22362	 22603	 0.009942	 0.034106	 0.00817	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22362	 82804	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22362	 82804	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22363	 82805	 0.006152	 0.020065	 0.00533	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22364	 22369	 0.007409	 0.026187	 0.0059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22364	 22604	 0.00591	 0.036725	 0.01036	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22364	 24103	 0.004487	 0.028422	 0.00771	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22365	 82805	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22366	 22368	 0.007645	 0.026224	 0.00628	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82805	 22366	 0.001702	 0.00584	 0.0014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82806	 22367	 0.011955	 0.030403	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22367	 82808	 0.084703	 0.22395	 0.00407	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22369	 22370	 0.007382	 0.024628	 0.00625	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82805	 22369	 0.003741	 0.028176	 0.00782	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22370	 22371	 0.006432	 0.020979	 0.00557	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22371	 22372	 0.004582	 0.011895	 0.00289	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22371	 82807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22371	 82807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22372	 82808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22372	 82808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22373	 22667	 0.020921	 0.016557	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22374	 22377	 0.20596	 0.20605	 0.00278	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22374	 23886	 0.14523	 0.3695	 0.00585	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22374	 23888	 0.095224	 0.22111	 0.00329	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22374	 83234	 0.033933	 0.13464	 0.00385	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22375	 22862	 0.040426	 0.14146	 0.00293	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22375	 82809	 0.04732	 0.13091	 0.00304	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22377	 23889	 0.072698	 0.18046	 0.003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22378	 82809	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22378	 82809	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22378	 83497	 0.021242	 0.16977	 0.04192	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22379	 22380	 0.11943	 0.23651	 0.00347	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22379	 24100	 0.14122	 0.27968	 0.00411	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22380	 82811	 0.020737	 0.11788	 0.00213	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22381	 22382	 0.037821	 0.16854	 0.00286	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22381	 23364	 0.054615	 0.2125	 0.00355	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81990	 22382	 0.017193	 0.066888	 0.00112	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81990	 22382	 0.017193	 0.066888	 0.00112	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22382	 82811	 0.004445	 0.027328	 0.00049	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81959	 22383	 0.001914	 0.035467	 0.34178	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22383	 82810	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22383	 82810	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22384	 24101	 0.023232	 0.1445	 0.04084	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81989	 22384	 0.002078	 0.016373	 0.00479	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22384	 82811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22384	 82811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22385	 23387	 0.021442	 0.055673	 0.01352	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82810	 22385	 0.011094	 0.043605	 0.01141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22385	 82812	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22385	 82812	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22386	 22387	 0.011577	 0.029442	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22387	 22388	 0.014817	 0.011226	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22387	 22389	 0.01274	 0.029578	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22389	 83091	 0.18971	 0.31526	 0.00668	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22390	 22391	 0.3356	 0.24702	 0.00361	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22391	 23386	 0.10534	 0.26796	 0.00424	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22391	 82813	 0.1326	 0.13394	 0.00177	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22392	 23387	 0.017903	 0.12017	 0.02903	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22392	 82813	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22392	 82813	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22393	 22394	 0.013632	 0.03228	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22394	 22395	 0.009496	 0.017947	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22394	 22396	 0.011279	 0.026709	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82813	 22394	 0.035794	 0.10993	 0.00206	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22396	 22747	 0.10549	 0.24985	 0.00457	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22397	 22399	 0.011162	 0.016339	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22397	 22660	 0.0239	 0.031411	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22398	 22399	 0.009033	 0.017884	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22398	 22400	 0.00268	 0.012444	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22398	 22401	 0.019576	 0.012673	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22398	 22404	 0.002868	 0.021688	 0.00072	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22398	 22405	 0.044569	 0.035272	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22400	 22662	 0.00303	 0.014786	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22402	 82814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22402	 82814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22403	 22404	 0.012651	 0.032788	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22403	 22406	 0.042986	 0.043417	 0.00058	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22403	 22408	 0.027097	 0.062909	 0.00094	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81950	 22403	 0.054245	 0.05087	 0.00079	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81950	 22404	 0.005739	 0.020082	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22404	 82818	 0.022408	 0.06427	 0.00099	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22406	 22407	 0.025064	 0.019226	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22406	 22408	 0.00944	 0.027074	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82803	 22406	 0.077727	 0.10116	 0.00141	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22408	 82815	 0.015289	 0.05858	 0.00166	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22409	 22411	 0.007737	 0.022409	 0.00541	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22409	 22728	 0.01095	 0.028941	 0.00677	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22409	 82815	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22409	 82815	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22410	 82816	 0.028257	 0.072638	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22410	 82818	 0.049799	 0.089509	 0.00161	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22411	 22414	 0.008497	 0.022813	 0.00517	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22412	 22415	 0.005116	 0.049119	 0.01429	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22412	 82969	 0.009136	 0.10449	 0.03189	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22413	 22416	 0.039634	 0.12763	 0.00217	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22414	 22415	 0.002004	 0.006537	 0.00174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22414	 22423	 0.010255	 0.039898	 0.01066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22414	 82816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22414	 82816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22415	 22418	 0.009187	 0.02428	 0.00568	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22415	 82817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22415	 82817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82816	 22416	 0.011747	 0.033693	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82817	 22416	 0.01608	 0.026856	 0.00046	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22417	 22419	 0.033994	 0.087386	 0.00135	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82817	 22417	 0.023701	 0.056124	 0.00103	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22419	 22421	 0.01305	 0.043533	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22419	 22424	 0.044987	 0.075136	 0.00128	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22420	 22422	 0.006346	 0.032999	 0.00072	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22420	 22794	 0.033011	 0.1063	 0.00181	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22421	 22422	 0.010176	 0.02588	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81950	 22422	 0.05427	 0.16651	 0.00451	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22423	 82818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22423	 82818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82818	 22424	 0.017303	 0.044478	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22425	 22426	 0.25225	 0.16335	 0.00311	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22426	 22427	 0.077632	 0.15371	 0.00226	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22426	 22429	 0.29171	 0.23093	 0.00291	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22427	 22428	 0.049151	 0.125	 0.00198	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22427	 22429	 0.36055	 0.28546	 0.00359	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22427	 23114	 0.94493	 0.74298	 0.00954	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22428	 22431	 0.029821	 0.070617	 0.00129	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81986	 22429	 0.071431	 0.36148	 0.00629	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22430	 82819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22430	 82819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82819	 22431	 0.009364	 0.041724	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82797	 22432	 0.036179	 0.093003	 0.00144	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82819	 22432	 0.12926	 0.09345	 0.00142	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22433	 82820	 0.002319	 0.008112	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22433	 82822	 0.016336	 0.037926	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22433	 82839	 0.008768	 0.042787	 0.00074	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22434	 22436	 0.001558	 0.007793	 0.00014	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22434	 82838	 0.002855	 0.012773	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22435	 22439	 0.00099	 0.003851	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22435	 22478	 0.000732	 0.005513	 0.00153	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22435	 82820	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22435	 82820	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22436	 82821	 0.001787	 0.007151	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82820	 22437	 0.010708	 0.008474	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22438	 22452	 0.000812	 0.003251	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22438	 82821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22438	 82821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22439	 22441	 0.00073	 0.003089	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82821	 22440	 0.004841	 0.008451	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22440	 82863	 0.014686	 0.024739	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22441	 22442	 0.000688	 0.002706	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22441	 82822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22441	 82822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22442	 22443	 0.000506	 0.001841	 0.00056	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22442	 82823	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22442	 82823	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22443	 22561	 0.000646	 0.002457	 0.00069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22444	 82824	 0.003944	 0.007117	 0.0001	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22444	 82826	 0.014034	 0.021498	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22445	 22448	 0.000711	 0.003261	 0.00084	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22445	 22490	 0.000414	 0.003975	 0.00116	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22445	 82824	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22445	 82824	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82823	 22446	 0.007626	 0.0151	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22446	 82863	 0.008584	 0.01302	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22447	 22448	 0.000982	 0.003998	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22447	 22458	 0.001093	 0.003748	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22447	 82825	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22447	 82825	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22448	 82826	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22448	 82826	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22449	 22452	 0.001708	 0.004587	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22449	 22529	 0.001363	 0.004546	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22449	 82827	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22449	 82827	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22450	 22451	 0.003827	 0.009498	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82827	 22450	 0.008905	 0.015342	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22450	 82853	 0.00863	 0.019827	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22450	 82865	 0.035046	 0.027735	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22451	 82852	 0.004823	 0.007699	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22452	 22563	 0.000398	 0.002284	 0.00065	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22453	 22456	 0.001283	 0.003093	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22453	 22563	 0.000993	 0.002926	 0.00068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22454	 82865	 0.011464	 0.019311	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22455	 22457	 0.000647	 0.003449	 0.00097	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22455	 22523	 0.000532	 0.003218	 0.00082	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22456	 22460	 0.000708	 0.00308	 0.00088	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22456	 22561	 0.001042	 0.004055	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22456	 82828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22456	 82828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22457	 22461	 0.000457	 0.005369	 0.00142	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22457	 22563	 0.002036	 0.008151	 0.00205	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22457	 82829	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22457	 82829	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22458	 22468	 0.001317	 0.004655	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82828	 22459	 0.006083	 0.013035	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22459	 82831	 0.009244	 0.016615	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22460	 22462	 0.000868	 0.0033	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22461	 22506	 0.001362	 0.010361	 0.00326	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22461	 82830	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22461	 82830	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22462	 22463	 0.000366	 0.003121	 0.00078	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22462	 82831	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22462	 82831	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22463	 22465	 0.000612	 0.002663	 0.00076	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22463	 82832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22463	 82832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82832	 22464	 0.018775	 0.013813	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22465	 22505	 0.001032	 0.004367	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22465	 82833	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22465	 82833	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22466	 22467	 0.022784	 0.018031	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82825	 22467	 0.005779	 0.014696	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22467	 82834	 0.025861	 0.023821	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22468	 82834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22468	 82834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22469	 22560	 0.019246	 0.015086	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82833	 22469	 0.005116	 0.013559	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82834	 22469	 0.002857	 0.010464	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22470	 22471	 0.000541	 0.006663	 0.00215	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22470	 22473	 0.000582	 0.004564	 0.00209	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22470	 82835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22470	 82835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22471	 24020	 0.001116	 0.01384	 0.00599	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22471	 82836	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22471	 82836	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82835	 22472	 0.012286	 0.031583	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82836	 22472	 0.007873	 0.03063	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22472	 82837	 0.005836	 0.036645	 0.0008	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22472	 83290	 0.023944	 0.079018	 0.00128	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22473	 22475	 0.000562	 0.006022	 0.00193	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22473	 82837	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22473	 82837	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22474	 22477	 0.01748	 0.027901	 0.00064	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82835	 22474	 0.021569	 0.023723	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22475	 22483	 0.000788	 0.008355	 0.00248	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22476	 22477	 0.015035	 0.046171	 0.00087	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82836	 22476	 0.009684	 0.032306	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22476	 82854	 0.007858	 0.061243	 0.00114	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22477	 82841	 0.021355	 0.056601	 0.00144	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22478	 22479	 0.000345	 0.004189	 0.00113	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22478	 82838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22478	 82838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22479	 22483	 0.000596	 0.004312	 0.00232	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22480	 22481	 0.000657	 0.00736	 0.00234	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22480	 22490	 0.000605	 0.006911	 0.00211	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22481	 22484	 0.001065	 0.009136	 0.0026	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22481	 22488	 0.000691	 0.0079	 0.00241	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22481	 82855	 0.00195	 0.028155	 0.00894	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22482	 82839	 0.012396	 0.041353	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22482	 82841	 0.010553	 0.040601	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22483	 82839	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22483	 82839	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22484	 22486	 0.000615	 0.009567	 0.00297	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22484	 82840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22484	 82840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22485	 22542	 0.020621	 0.058515	 0.00092	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82840	 22485	 0.006901	 0.014123	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22486	 82841	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22486	 82841	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22486	 82855	 0.000923	 0.013652	 0.0047	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22487	 24102	 0.06264	 0.12403	 0.00182	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82841	 22487	 0.033728	 0.051667	 0.00073	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22488	 22491	 0.000724	 0.007931	 0.0022	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22489	 82842	 0.024233	 0.018588	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22490	 82842	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22490	 82842	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22491	 22494	 0.000949	 0.008632	 0.00218	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22491	 82843	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22491	 82843	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22492	 22493	 0.01566	 0.014032	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22492	 82844	 0.025295	 0.033245	 0.00046	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82826	 22493	 0.011589	 0.014386	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22494	 22562	 0.001348	 0.006186	 0.00158	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22494	 82844	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22494	 82844	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22495	 82849	 0.005848	 0.02275	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22495	 82864	 0.003672	 0.019651	 0.0006	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22496	 22498	 0.001393	 0.0083	 0.00218	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22496	 23537	 0.005238	 0.030095	 0.00853	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22496	 82845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22496	 82845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22497	 22500	 0.001465	 0.010821	 0.00312	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22497	 23539	 0.004116	 0.025577	 0.00722	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22497	 82846	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22497	 82846	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22497	 82990	 0.033589	 0.091479	 0.02016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22498	 22502	 0.000946	 0.007123	 0.00198	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22498	 82847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22498	 82847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82846	 22499	 0.04699	 0.047462	 0.00063	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82847	 22499	 0.007827	 0.018172	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22499	 82848	 0.013342	 0.044508	 0.00071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22500	 22501	 0.000659	 0.005991	 0.00151	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22501	 22504	 0.000686	 0.005846	 0.00146	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22501	 82848	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22501	 82848	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22502	 22506	 0.000928	 0.007901	 0.00197	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82847	 22503	 0.022681	 0.017949	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22504	 22505	 0.001019	 0.004078	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22504	 82849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22504	 82849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22506	 82850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22506	 82850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82850	 22507	 0.046498	 0.03421	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22508	 22509	 0.023284	 0.017131	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22508	 22510	 0.006532	 0.021555	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22508	 22513	 0.020924	 0.048569	 0.00092	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82829	 22510	 0.002757	 0.014335	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82830	 22510	 0.008529	 0.021604	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82830	 22511	 0.008315	 0.021375	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82850	 22511	 0.010525	 0.027824	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22512	 22513	 0.014713	 0.037821	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22512	 22559	 0.030446	 0.070674	 0.00135	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22513	 22517	 0.015147	 0.020665	 0.00037	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22514	 22515	 0.021273	 0.016117	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22515	 22516	 0.015247	 0.030189	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22515	 22517	 0.034748	 0.027499	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22515	 22518	 0.045014	 0.03254	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22515	 82989	 0.21628	 0.17119	 0.00216	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22516	 22521	 0.018899	 0.053629	 0.00084	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22517	 22518	 0.011808	 0.021305	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22518	 22519	 0.01281	 0.029296	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22519	 22520	 0.016704	 0.055724	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22520	 22521	 0.059827	 0.059841	 0.00081	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81942	 22520	 0.011174	 0.086071	 0.00165	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22521	 23020	 0.029685	 0.058773	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22522	 22524	 0.002191	 0.009046	 0.00214	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22522	 22527	 0.001054	 0.006549	 0.00185	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22522	 82851	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22522	 82851	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22523	 22524	 0.001824	 0.007718	 0.00174	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22523	 82852	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22523	 82852	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22525	 22526	 0.008693	 0.017212	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82852	 22525	 0.029726	 0.031745	 0.00067	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82851	 22526	 0.014162	 0.036406	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22528	 22530	 0.004772	 0.023286	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22528	 22531	 0.005429	 0.015572	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82839	 22528	 0.021767	 0.044544	 0.0011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22528	 82853	 0.004094	 0.028104	 0.00051	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22529	 22563	 0.002975	 0.009703	 0.00258	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22529	 82853	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22529	 82853	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22530	 22531	 0.004599	 0.011822	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82837	 22530	 0.007982	 0.047257	 0.00092	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22532	 22533	 0.017441	 0.039887	 0.00097	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22532	 22534	 0.048963	 0.043875	 0.0009	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22532	 83315	 0.049091	 0.12435	 0.00246	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22533	 23020	 0.05964	 0.11809	 0.00173	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81942	 22534	 0.013196	 0.028279	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22535	 22536	 0.07025	 0.055595	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81942	 22535	 0.003758	 0.029293	 0.00055	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82837	 22535	 0.007631	 0.034144	 0.0007	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22536	 24131	 0.12195	 0.089727	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22537	 22539	 0.00012	 0.001586	 0.0254	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22537	 24002	 0.000473	 0.005573	 0.09736	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22537	 24019	 0.00027	 0.00301	 0.02838	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22537	 82854	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22537	 82854	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82854	 22538	 0.044419	 0.029838	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22539	 23586	 0.001711	 0.031693	 0.30523	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22539	 82855	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22539	 82855	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22540	 22543	 0.019641	 0.076408	 0.00128	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82844	 22540	 0.025996	 0.045718	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22541	 22542	 0.068929	 0.05455	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82843	 22542	 0.014562	 0.033801	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22543	 24118	 0.020767	 0.054899	 0.001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22543	 82860	 0.045509	 0.13053	 0.00201	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22543	 83312	 0.032651	 0.093649	 0.00144	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22544	 82856	 0.034243	 0.05613	 0.00099	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22544	 82859	 0.043985	 0.05781	 0.00079	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22545	 22548	 0.001986	 0.012013	 0.00307	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22545	 22562	 0.003087	 0.010913	 0.00246	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22545	 82856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22545	 82856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22546	 22547	 0.002292	 0.01298	 0.00322	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22546	 22562	 0.001075	 0.01067	 0.0029	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22546	 82857	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22546	 82857	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22547	 22557	 0.003098	 0.012606	 0.00307	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22547	 82858	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22547	 82858	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22548	 22551	 0.003631	 0.012456	 0.00298	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22548	 82859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22548	 82859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22549	 82860	 0.064101	 0.050729	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22550	 22554	 0.005195	 0.013946	 0.00316	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22550	 82860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22550	 82860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22551	 22552	 0.002733	 0.009376	 0.00225	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22552	 22554	 0.00202	 0.00693	 0.00166	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82859	 22553	 0.059024	 0.11687	 0.00172	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22553	 82861	 0.038677	 0.030608	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22553	 82862	 0.018137	 0.046623	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22554	 22556	 0.003602	 0.014014	 0.00374	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22554	 82861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22554	 82861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22555	 22556	 0.0017	 0.005831	 0.0014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22555	 22557	 0.003316	 0.011064	 0.00281	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22556	 23050	 0.001205	 0.006997	 0.00165	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22556	 82862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22556	 82862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22558	 22559	 0.027116	 0.035639	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82847	 22558	 0.021177	 0.049158	 0.00094	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22559	 83142	 0.064805	 0.18589	 0.00286	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22561	 82863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22561	 82863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22562	 82864	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22562	 82864	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22562	 83273	 0.008181	 0.08612	 0.04842	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22563	 82865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22563	 82865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22564	 22565	 0.044663	 0.12372	 0.00204	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22564	 22570	 0.13983	 0.17049	 0.00273	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22564	 23963	 0.04303	 0.13664	 0.0024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22565	 22566	 0.069536	 0.13768	 0.00202	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22565	 23874	 0.057021	 0.14154	 0.00235	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22566	 22569	 0.10779	 0.11007	 0.00171	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22567	 22570	 0.026519	 0.068171	 0.00106	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22567	 82866	 0.17352	 0.15985	 0.00256	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22568	 22569	 0.028647	 0.067836	 0.00124	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22568	 22570	 0.025248	 0.064903	 0.001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22569	 22572	 0.037409	 0.1248	 0.00198	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22570	 83100	 0.397	 0.2572	 0.0049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22571	 23411	 0.011647	 0.039957	 0.00957	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22571	 82866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22571	 82866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22572	 23403	 0.050678	 0.085372	 0.00122	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22573	 22744	 0.6704	 0.53136	 0.00669	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22573	 82867	 0.5242	 0.33979	 0.00647	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22574	 82867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22574	 82867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22574	 83229	 0.052838	 0.13729	 0.03336	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22575	 22577	 0.11428	 0.090441	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22575	 22579	 0.07379	 0.13181	 0.00195	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82867	 22576	 0.242	 0.18973	 0.00244	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22577	 22578	 0.038137	 0.030181	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82867	 22577	 0.13499	 0.31023	 0.00471	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22579	 23878	 0.1522	 0.39143	 0.00606	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22580	 22582	 0.034985	 0.086837	 0.00144	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22580	 82870	 0.028071	 0.071104	 0.00141	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22581	 22589	 0.18364	 0.14396	 0.00185	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22581	 82870	 0.024649	 0.1119	 0.00243	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22582	 22859	 0.054446	 0.12893	 0.00236	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22583	 22585	 0.1865	 0.14761	 0.00186	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22583	 22586	 0.15422	 0.12206	 0.00154	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22583	 24857	 0.081928	 0.14303	 0.00222	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22584	 22588	 0.073163	 0.056121	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22585	 22586	 0.15887	 0.12574	 0.00158	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22586	 82870	 0.025373	 0.098711	 0.00165	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22586	 82872	 0.061453	 0.083772	 0.00186	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22586	 83496	 0.2355	 0.29982	 0.00439	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22587	 22594	 0.004469	 0.011602	 0.00282	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22587	 82868	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22587	 82868	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82868	 22588	 0.024619	 0.048743	 0.00072	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22590	 82871	 0.050853	 0.040244	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22591	 23340	 0.003052	 0.035293	 0.31023	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22591	 82869	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82869	 22592	 0.00179	 0.01074	 0.00325	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22592	 82871	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22592	 82871	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22593	 22594	 0.003429	 0.008902	 0.00216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22593	 82872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22593	 82872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22594	 82873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22594	 82873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82873	 22595	 0.041004	 0.026546	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22596	 23454	 0.040099	 0.10308	 0.0016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81947	 22596	 0.24618	 0.24872	 0.00329	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22596	 82875	 0.058008	 0.10427	 0.00187	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22597	 22600	 0.002771	 0.011095	 0.0028	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22597	 22602	 0.010853	 0.036569	 0.00909	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22598	 22599	 0.001515	 0.004004	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22598	 22600	 0.004298	 0.011048	 0.00274	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22598	 82874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22598	 82874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22599	 23407	 0.015322	 0.039779	 0.00966	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22600	 22756	 0.003801	 0.035776	 0.01084	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81946	 22600	 0.027257	 0.070778	 0.01718	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22600	 82875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22600	 82875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82874	 22601	 0.088294	 0.057163	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82875	 22601	 0.013973	 0.022304	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22602	 24012	 0.010155	 0.027647	 0.00609	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22602	 82876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22602	 82876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81946	 22603	 0.006582	 0.022577	 0.00541	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22604	 22605	 0.005035	 0.035614	 0.00977	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22604	 82877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22604	 82877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81946	 22605	 0.004806	 0.039014	 0.01242	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22606	 22611	 0.15714	 0.12437	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22606	 82919	 0.1416	 0.11206	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22607	 22610	 0.008764	 0.022753	 0.00552	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22607	 82878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22607	 82878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82786	 22608	 0.085862	 0.24631	 0.00379	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22609	 22614	 0.025423	 0.097809	 0.00167	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82646	 22609	 0.31094	 0.24615	 0.0031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22610	 22788	 0.009523	 0.06135	 0.01609	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22610	 82879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22610	 82879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22611	 22615	 0.141	 0.10375	 0.00152	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22612	 22613	 0.010202	 0.015295	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82879	 22612	 0.020794	 0.059639	 0.00092	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22613	 22614	 0.045386	 0.057029	 0.00086	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22614	 22615	 0.032108	 0.14308	 0.00243	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22615	 22616	 0.064411	 0.12753	 0.00187	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22615	 83000	 0.052019	 0.14921	 0.00229	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22616	 84623	 0.033207	 0.11078	 0.00176	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82646	 22617	 0.21397	 0.16935	 0.00213	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22618	 82881	 0.1505	 0.11798	 0.00151	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22619	 22991	 0.36539	 0.26896	 0.00393	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22619	 82880	 0.036179	 0.060946	 0.00087	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22620	 22992	 0.088117	 0.22707	 0.05639	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22620	 82880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22620	 82880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22621	 23366	 0.055174	 0.20009	 0.04302	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22621	 82881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22621	 82881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22622	 22623	 0.022351	 0.057457	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22622	 22625	 0.075202	 0.059515	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82881	 22622	 0.03597	 0.064653	 0.00116	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22623	 82882	 0.009777	 0.034233	 0.00095	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22624	 82882	 0.13441	 0.17348	 0.00349	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22624	 83230	 0.22037	 0.39634	 0.00712	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82744	 22625	 0.25111	 0.49756	 0.00731	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82881	 22625	 0.16276	 0.10538	 0.00201	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22626	 82882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22626	 82882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22627	 23876	 0.38422	 0.28283	 0.00414	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82744	 22627	 0.59724	 0.47322	 0.00596	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22627	 83230	 0.39677	 0.4325	 0.00589	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22628	 22629	 0.19645	 0.21402	 0.00291	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22628	 22630	 0.15474	 0.10019	 0.00191	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22628	 22737	 0.18717	 0.42842	 0.01047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81954	 22629	 0.035573	 0.13839	 0.00231	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22629	 82883	 0.052574	 0.1754	 0.00278	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22630	 22633	 0.23622	 0.18698	 0.00235	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22631	 22632	 0.1298	 0.10273	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22632	 22738	 0.43639	 0.48042	 0.00641	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22633	 22638	 0.03296	 0.076509	 0.00146	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22635	 24120	 0.17994	 0.14242	 0.00179	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22636	 22637	 0.093885	 0.10327	 0.00138	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22636	 22638	 0.16399	 0.12855	 0.00165	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81974	 22636	 0.01434	 0.030139	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22637	 22638	 0.034594	 0.068494	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22637	 24119	 0.14132	 0.27702	 0.00415	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81954	 22637	 0.086822	 0.26139	 0.00511	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22639	 24087	 0.008474	 0.047284	 0.01208	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22639	 82883	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22639	 82883	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22640	 22644	 0.00987	 0.01512	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22640	 22657	 0.006217	 0.016478	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22640	 22658	 0.004131	 0.010254	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82803	 22640	 0.022636	 0.11046	 0.00191	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22641	 22642	 0.004942	 0.012703	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22641	 22719	 0.003383	 0.008696	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22641	 82898	 0.009983	 0.012543	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22642	 22713	 0.003649	 0.00938	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22642	 22714	 0.003812	 0.009026	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22643	 22713	 0.008187	 0.0053	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22644	 22657	 0.004028	 0.015496	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22644	 22712	 0.021353	 0.016899	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22644	 22713	 0.002976	 0.011579	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22645	 22675	 0.004888	 0.018804	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22645	 22712	 0.002672	 0.011905	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22646	 22649	 0.003	 0.006963	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22646	 22712	 0.003794	 0.009754	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22647	 22716	 0.027145	 0.021482	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81983	 22648	 0.000261	 0.002224	 0.00055	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22648	 82884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22648	 82884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82884	 22649	 0.005398	 0.01399	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22650	 22718	 0.004163	 0.01194	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22650	 82885	 0.003442	 0.009403	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22651	 22652	 0.000464	 0.002254	 0.00052	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81983	 22651	 0.000571	 0.004303	 0.00119	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22651	 82885	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22651	 82885	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22652	 22653	 0.000763	 0.00323	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22653	 22654	 0.000762	 0.003226	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22654	 82891	 0.001311	 0.005153	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22655	 22718	 0.017994	 0.01424	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22656	 22717	 0.004277	 0.024314	 0.00044	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82885	 22656	 0.014872	 0.038229	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22656	 82892	 0.004322	 0.01926	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22657	 22666	 0.022655	 0.017929	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22657	 22667	 0.008984	 0.023094	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22657	 22670	 0.009779	 0.023156	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82808	 22657	 0.040711	 0.079788	 0.0012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22658	 82898	 0.008487	 0.023508	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22659	 22715	 0.000783	 0.004811	 0.00176	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22659	 82886	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22659	 82886	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82886	 22660	 0.006866	 0.009023	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82886	 22661	 0.004916	 0.016794	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22661	 82898	 0.005879	 0.017288	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22662	 22719	 0.004558	 0.012082	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82814	 22662	 0.014727	 0.037857	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22663	 22664	 0.003805	 0.008123	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82814	 22663	 0.00969	 0.02198	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22664	 22665	 0.004705	 0.010922	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22665	 22716	 0.008007	 0.018961	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22667	 22681	 0.009326	 0.019085	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22668	 22669	 0.004095	 0.011745	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22668	 22681	 0.004952	 0.014202	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22669	 22671	 0.004178	 0.012816	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22669	 22672	 0.002608	 0.009133	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22669	 22682	 0.004171	 0.015983	 0.00045	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22670	 22678	 0.003088	 0.007169	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81979	 22671	 0.004188	 0.020207	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22672	 82887	 0.003359	 0.008635	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22673	 22680	 0.000138	 0.001302	 0.00039	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22673	 22686	 0.000756	 0.008942	 0.00255	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22673	 82887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22673	 82887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22674	 22718	 0.002955	 0.016795	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81979	 22674	 0.002261	 0.012855	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22675	 22678	 0.003751	 0.009181	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22675	 82888	 0.001328	 0.005512	 0.00014	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22676	 22677	 0.000494	 0.003719	 0.00103	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22676	 82888	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22676	 82888	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22677	 22679	 9.6e-05	 0.001481	 0.00041	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22679	 22680	 6.6e-05	 0.00096	 0.00031	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82808	 22681	 0.024424	 0.037414	 0.00053	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22682	 22683	 0.004549	 0.020272	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22682	 22684	 0.002602	 0.021644	 0.00041	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82808	 22683	 0.006663	 0.033706	 0.00059	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22684	 22685	 0.041175	 0.027659	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22684	 82889	 0.003033	 0.020594	 0.00051	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22686	 22703	 0.003476	 0.039734	 0.01212	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22686	 82889	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22686	 82889	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82887	 22687	 0.029007	 0.021341	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22688	 22717	 0.00608	 0.031618	 0.00069	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22688	 82890	 0.009533	 0.046517	 0.0008	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22689	 22701	 0.005806	 0.015072	 0.00366	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22689	 82890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22689	 82890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22690	 22691	 0.006548	 0.0134	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22690	 22692	 0.035782	 0.025866	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82814	 22690	 0.010475	 0.04075	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22691	 22694	 0.006531	 0.015006	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22691	 22698	 0.012302	 0.054817	 0.00093	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22693	 82892	 0.014624	 0.019221	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82885	 22694	 0.018154	 0.042146	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22695	 82891	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22696	 22697	 0.020155	 0.013048	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82892	 22697	 0.004578	 0.031059	 0.00058	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22697	 82893	 0.005261	 0.020874	 0.0006	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22698	 22710	 0.023476	 0.074543	 0.00131	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22699	 22708	 0.001309	 0.014474	 0.00434	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82891	 22699	 0.001438	 0.009973	 0.00585	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22699	 82893	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22699	 82893	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82893	 22700	 0.036724	 0.071973	 0.00108	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22701	 82894	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22701	 82894	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82890	 22702	 0.017082	 0.076119	 0.00129	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82894	 22702	 0.003529	 0.023942	 0.00045	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22702	 82895	 0.009213	 0.063242	 0.00115	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22703	 23065	 0.001959	 0.021695	 0.00706	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22703	 82895	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22703	 82895	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22704	 22705	 0.03493	 0.089793	 0.00139	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22704	 22720	 0.006374	 0.052403	 0.00102	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22704	 22795	 0.10661	 0.1796	 0.00256	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22704	 24233	 0.042785	 0.19067	 0.00324	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22705	 23076	 0.03469	 0.089175	 0.00138	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22706	 22711	 0.038662	 0.0877	 0.00175	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22706	 22795	 0.013555	 0.072534	 0.0022	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22706	 82897	 0.03473	 0.11586	 0.00184	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22707	 22720	 0.005776	 0.048053	 0.00091	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22707	 82896	 0.014533	 0.060662	 0.00175	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22707	 82897	 0.013075	 0.069664	 0.00122	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22708	 22709	 0.000818	 0.005672	 0.00162	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22708	 82896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22708	 82896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22709	 82897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22709	 82897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22710	 22711	 0.029661	 0.098947	 0.00157	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82897	 22710	 0.037374	 0.086769	 0.00129	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22711	 22794	 0.043338	 0.11022	 0.00174	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22712	 22713	 0.00718	 0.01826	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81984	 22713	 0.008396	 0.02666	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22713	 82898	 0.006453	 0.017057	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81984	 22714	 0.003355	 0.010293	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82884	 22714	 0.021298	 0.021512	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81983	 22715	 0.00363	 0.009745	 0.00221	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22715	 82898	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22715	 82898	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81984	 22716	 0.007319	 0.012329	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82885	 22716	 0.010893	 0.021349	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81979	 22717	 0.007019	 0.019917	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82884	 22718	 0.007996	 0.022934	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81984	 22719	 0.012808	 0.025358	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22721	 22727	 0.016309	 0.03786	 0.01154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22721	 22729	 0.003378	 0.025449	 0.00706	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81946	 22721	 0.011001	 0.045423	 0.01075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22721	 82899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22721	 82899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22722	 22723	 0.025818	 0.020432	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22722	 83114	 0.024969	 0.083295	 0.00132	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22724	 82902	 0.080742	 0.15261	 0.00247	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22724	 83114	 0.026447	 0.12761	 0.00225	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22725	 22726	 0.033483	 0.14921	 0.00253	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82815	 22725	 0.075081	 0.1985	 0.0036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22725	 82901	 0.058166	 0.14238	 0.00243	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22725	 82903	 0.045423	 0.12008	 0.00218	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22726	 82903	 0.064877	 0.16678	 0.00258	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22726	 82967	 0.014887	 0.091525	 0.00165	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22726	 82968	 0.030865	 0.12008	 0.002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22727	 22728	 0.00954	 0.024767	 0.00601	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22727	 82900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22727	 82900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22728	 82901	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22728	 82901	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22729	 22730	 0.000902	 0.008203	 0.00207	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22730	 22731	 0.004114	 0.01647	 0.00415	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22730	 82902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22730	 82902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22731	 22946	 0.008413	 0.054198	 0.01421	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22731	 82903	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22731	 82903	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22732	 22733	 0.00531	 0.015229	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82902	 22732	 0.019651	 0.046534	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82903	 22733	 0.027992	 0.064987	 0.00097	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22733	 83112	 0.081216	 0.19374	 0.00434	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22734	 23873	 0.050536	 0.13366	 0.03131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22734	 82904	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22734	 82904	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22735	 22737	 0.21546	 0.17054	 0.00215	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22735	 22738	 0.050261	 0.098505	 0.00148	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82904	 22735	 0.060337	 0.12348	 0.00304	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22736	 22737	 0.045417	 0.083186	 0.00144	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22738	 22739	 0.13067	 0.19821	 0.00284	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22739	 22740	 0.060998	 0.15514	 0.00245	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22740	 22742	 0.26761	 0.20532	 0.00276	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22740	 23869	 0.096672	 0.26416	 0.00449	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22740	 23875	 0.17337	 0.13721	 0.00173	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82743	 22740	 0.51523	 0.39073	 0.00538	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22741	 23871	 0.18598	 0.1472	 0.00185	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82904	 22742	 0.17103	 0.13408	 0.00172	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22743	 82905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22743	 82905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22744	 22745	 0.24607	 0.19478	 0.00245	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22745	 22746	 0.14145	 0.11195	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82905	 22745	 0.33223	 0.33248	 0.00449	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22746	 22747	 0.11561	 0.22894	 0.00336	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82905	 22747	 0.35577	 0.23045	 0.00439	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22748	 22757	 0.038958	 0.11055	 0.00174	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82799	 22748	 0.02756	 0.12281	 0.00209	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22749	 22762	 0.029696	 0.10609	 0.00211	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22749	 83090	 0.0354	 0.20125	 0.00364	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22750	 22751	 0.1151	 0.10794	 0.00167	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22751	 22752	 0.025553	 0.042615	 0.00062	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22751	 22762	 0.017166	 0.052659	 0.00143	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22751	 82906	 0.036426	 0.06075	 0.00088	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22752	 22753	 0.005981	 0.015374	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22752	 22761	 0.00423	 0.00982	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22753	 22761	 0.009156	 0.023285	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22753	 82906	 0.007052	 0.016201	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22753	 82907	 0.019891	 0.089005	 0.00183	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22754	 22756	 0.001985	 0.019452	 0.00609	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22754	 82906	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22754	 82906	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22754	 82908	 0.000802	 0.010084	 0.00312	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82906	 22755	 0.033372	 0.02641	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22756	 82907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22756	 82907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22757	 22760	 0.030991	 0.087946	 0.00138	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22758	 82909	 0.01606	 0.11024	 0.00201	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22758	 83100	 0.015291	 0.094012	 0.00169	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81929	 22759	 0.001545	 0.016962	 0.16487	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22759	 82908	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22760	 22761	 0.003682	 0.021797	 0.00042	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82909	 22760	 0.008483	 0.037799	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22763	 22764	 0.001247	 0.003295	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22763	 82910	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22763	 82910	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22764	 22782	 0.003567	 0.009259	 0.00225	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22764	 82911	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22764	 82911	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81980	 22765	 0.005386	 0.015285	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22765	 82918	 0.035215	 0.027869	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22765	 82921	 0.015636	 0.012374	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82910	 22766	 0.017622	 0.011409	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22767	 22800	 0.001545	 0.004084	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22767	 82912	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22767	 82912	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22768	 82914	 0.041882	 0.030814	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82912	 22769	 0.0172	 0.011135	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22770	 22771	 0.011075	 0.008006	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82912	 22770	 0.01439	 0.010587	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22771	 22773	 0.009627	 0.010589	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22772	 22774	 0.002175	 0.005923	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22772	 22788	 0.013874	 0.038692	 0.00812	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22772	 82913	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22772	 82913	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82913	 22773	 0.03056	 0.024185	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22773	 82914	 0.025651	 0.018543	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22774	 22788	 0.010552	 0.031112	 0.00724	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22774	 82914	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22774	 82914	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82914	 22775	 0.048079	 0.032296	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82914	 22776	 0.059216	 0.064499	 0.00088	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22777	 22778	 0.029215	 0.0229	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22777	 82916	 0.017661	 0.027055	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22779	 22780	 0.002661	 0.018824	 0.00517	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22779	 82915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22779	 82915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22780	 82916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22780	 82916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22781	 22795	 0.011715	 0.071194	 0.00131	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22781	 82917	 0.005973	 0.026616	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22782	 82917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22782	 82917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22783	 22796	 0.031484	 0.1039	 0.00168	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82917	 22783	 0.010053	 0.022802	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22783	 82918	 0.0039	 0.011963	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22784	 82918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22784	 82918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81980	 22785	 0.010351	 0.06364	 0.00115	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22785	 83339	 0.082851	 0.18951	 0.00463	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22786	 22787	 0.002115	 0.013399	 0.00364	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22786	 22799	 0.002091	 0.021849	 0.00735	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22787	 22789	 0.005826	 0.019436	 0.00493	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22788	 82919	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22788	 82919	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22789	 82920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22789	 82920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22790	 23030	 0.032733	 0.093886	 0.00144	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82919	 22790	 0.007832	 0.065156	 0.00123	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82920	 22790	 0.012544	 0.058163	 0.00121	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82915	 22791	 0.020714	 0.091268	 0.00159	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82878	 22792	 0.044203	 0.10262	 0.00153	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82915	 22792	 0.023211	 0.11327	 0.00196	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22793	 22794	 0.029614	 0.097729	 0.00158	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22796	 22797	 0.033793	 0.089333	 0.00162	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22797	 24233	 0.14379	 0.10894	 0.0015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22797	 83339	 0.051381	 0.14738	 0.00227	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22798	 24230	 0.01599	 0.079974	 0.00142	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82920	 22798	 0.012108	 0.053654	 0.00161	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22799	 24236	 0.00203	 0.025016	 0.00808	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22800	 82921	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22800	 82921	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22801	 22803	 0.021499	 0.016852	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22801	 82923	 0.01995	 0.015637	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22802	 22809	 0.026804	 0.018005	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22802	 22815	 0.012889	 0.022666	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22802	 82922	 0.006382	 0.017434	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22802	 82923	 0.022054	 0.017287	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22803	 22811	 0.030902	 0.025435	 0.00052	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22803	 82922	 0.00239	 0.012589	 0.00023	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22803	 82927	 0.069194	 0.054238	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22804	 22807	 0.002771	 0.008296	 0.00187	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22804	 22812	 0.001042	 0.006052	 0.00143	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22804	 82922	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22804	 82922	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22805	 22806	 0.019994	 0.02199	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22805	 22814	 0.020401	 0.013208	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82922	 22805	 0.004208	 0.009624	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22806	 22809	 0.016522	 0.013075	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22807	 22808	 0.001282	 0.00333	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22807	 22825	 0.0021	 0.005549	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22807	 82923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22807	 82923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22808	 82924	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22808	 82924	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22808	 82926	 0.001428	 0.003707	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22809	 22810	 0.023343	 0.017906	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22809	 22822	 0.030774	 0.019923	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82924	 22809	 0.00769	 0.012773	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22810	 22821	 0.024544	 0.019423	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22811	 22840	 0.020928	 0.057969	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22811	 22851	 0.014627	 0.016088	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22812	 22839	 0.001374	 0.014131	 0.00401	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22812	 82925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22812	 82925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22813	 22842	 0.008298	 0.015199	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22816	 22817	 0.019815	 0.024156	 0.00039	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22816	 22842	 0.005086	 0.013073	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22817	 22818	 0.015154	 0.011878	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22817	 22820	 0.038352	 0.030351	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22818	 22819	 0.018479	 0.014485	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22819	 22820	 0.016353	 0.012941	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22820	 22830	 0.012801	 0.018653	 0.00042	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22820	 22844	 0.009514	 0.04192	 0.00073	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22820	 82939	 0.049277	 0.054199	 0.00072	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22821	 22822	 0.022582	 0.017871	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22822	 82939	 0.009415	 0.023368	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22823	 22826	 0.000216	 0.002446	 0.02227	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22823	 82926	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82927	 22824	 0.011842	 0.021284	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22824	 82928	 0.067631	 0.053523	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22824	 82930	 0.012962	 0.036783	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82926	 22825	 0.002566	 0.006449	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22825	 82928	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22825	 82928	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22826	 22833	 0.00017	 0.001957	 0.01917	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22826	 22848	 0.000259	 0.002932	 0.02669	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22826	 82929	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82929	 22827	 0.003541	 0.009875	 0.00207	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22827	 82931	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22827	 82931	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22828	 22830	 0.042579	 0.033697	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82931	 22828	 0.013853	 0.013992	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22829	 22833	 0.000106	 0.001394	 0.01261	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22829	 22847	 0.000116	 0.001616	 0.01598	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22830	 22831	 0.028753	 0.022755	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22831	 22832	 0.01627	 0.012876	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82931	 22832	 0.028548	 0.020637	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22833	 82932	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22833	 82932	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82930	 22834	 0.013077	 0.043624	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82932	 22834	 0.003192	 0.019622	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22834	 82940	 0.064238	 0.084429	 0.00116	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81973	 22835	 0.014592	 0.011548	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82927	 22835	 0.024889	 0.044908	 0.00065	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81973	 22836	 0.018974	 0.031689	 0.00054	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22836	 82933	 0.11434	 0.082659	 0.00125	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22837	 22838	 0.004487	 0.024619	 0.00651	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22838	 82933	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22838	 82933	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22839	 22841	 0.001521	 0.017039	 0.00542	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22839	 82934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22839	 82934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82934	 22840	 0.018999	 0.048839	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22841	 82935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22841	 82935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22841	 83321	 0.014811	 0.067958	 0.01741	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22842	 22843	 0.016469	 0.045558	 0.00106	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82925	 22842	 0.063536	 0.041134	 0.00078	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22843	 22844	 0.014994	 0.050019	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22843	 24132	 0.057085	 0.16374	 0.00252	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22843	 24138	 0.046951	 0.10738	 0.00262	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82935	 22843	 0.022969	 0.088367	 0.00151	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82930	 22844	 0.054545	 0.11464	 0.00209	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22844	 82936	 0.006666	 0.065322	 0.00128	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22845	 82936	 0.14487	 0.11356	 0.00146	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22846	 22847	 0.000141	 0.002032	 0.01864	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22846	 24139	 0.000232	 0.00321	 0.03205	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22846	 82936	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22846	 82936	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22848	 82937	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82938	 22849	 0.1205	 0.12172	 0.00161	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22850	 22854	 0.014154	 0.03947	 0.00828	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82926	 22850	 0.004167	 0.010818	 0.00263	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82929	 22850	 0.00321	 0.008952	 0.00188	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22850	 82939	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22850	 82939	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22851	 22852	 0.017691	 0.013867	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82928	 22852	 0.018018	 0.027598	 0.00048	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82933	 22852	 0.13146	 0.085113	 0.00162	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82932	 22853	 0.024867	 0.071323	 0.0011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22853	 82940	 0.051662	 0.052181	 0.00069	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22854	 24084	 0.02814	 0.096568	 0.02315	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82929	 22854	 0.011765	 0.030544	 0.00741	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22854	 82940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22854	 82940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82938	 22855	 0.14218	 0.092055	 0.00175	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82940	 22855	 0.080435	 0.081244	 0.00108	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22856	 22857	 0.004558	 0.020524	 0.00546	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82791	 22856	 0.003789	 0.015774	 0.00492	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82937	 22857	 0.00706	 0.024219	 0.0058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22860	 22862	 0.054942	 0.1424	 0.00269	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22860	 23412	 0.23482	 0.18587	 0.00234	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22860	 23413	 0.11644	 0.33051	 0.0052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22861	 22862	 0.054877	 0.14108	 0.00218	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22863	 22864	 0.011853	 0.009756	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22863	 22934	 0.016242	 0.031832	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22864	 22866	 0.020934	 0.014829	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22864	 22867	 0.018743	 0.014691	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22865	 22873	 0.019605	 0.025514	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22865	 22939	 0.04558	 0.029509	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22866	 22867	 0.019216	 0.015207	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22867	 82942	 0.023325	 0.017672	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22868	 82948	 0.012979	 0.021863	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22868	 82963	 0.029636	 0.037239	 0.00056	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22869	 82941	 0.011246	 0.014636	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22869	 82963	 0.013888	 0.027497	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22870	 22871	 0.000913	 0.00313	 0.00075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22870	 22879	 0.001557	 0.004589	 0.00107	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22870	 82941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22870	 82941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22870	 82962	 0.001194	 0.00686	 0.00194	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22871	 22876	 0.001138	 0.00286	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22871	 82942	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22871	 82942	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82942	 22872	 0.021588	 0.015883	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22872	 82943	 0.018893	 0.014952	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22873	 22874	 0.020555	 0.016112	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22873	 22886	 0.035632	 0.026996	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22873	 82943	 0.008862	 0.025416	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22875	 82943	 0.008258	 0.01265	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22875	 82949	 0.017464	 0.013821	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22876	 82943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22876	 82943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22877	 22878	 4.2e-05	 0.000479	 0.0042	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22877	 22889	 0.000137	 0.001547	 0.01409	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22877	 22957	 0.000448	 0.004917	 0.04777	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22877	 82944	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22878	 22935	 0.000157	 0.001754	 0.01638	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22878	 82946	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22879	 22880	 0.000635	 0.003485	 0.00092	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82946	 22879	 0.001021	 0.003099	 0.00068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22880	 22881	 0.00079	 0.004628	 0.00126	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22881	 82948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22881	 82948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22881	 82964	 0.002173	 0.010358	 0.003	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82947	 22882	 0.014183	 0.015599	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22883	 22884	 0.004099	 0.007747	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82941	 22883	 0.02018	 0.033995	 0.00048	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82945	 22883	 0.005312	 0.013656	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22884	 22892	 0.017449	 0.011296	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22885	 22887	 0.001244	 0.004267	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82944	 22885	 0.000941	 0.004729	 0.00123	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22885	 82949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22885	 82949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22886	 22940	 0.026506	 0.040604	 0.00057	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22886	 22950	 0.030509	 0.024144	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82941	 22886	 0.021694	 0.062222	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22886	 82950	 0.003907	 0.016533	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22887	 22951	 0.0016	 0.004461	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22887	 82950	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22887	 82950	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22888	 22893	 0.005263	 0.008789	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22888	 22895	 0.006868	 0.012344	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82949	 22888	 0.005479	 0.009847	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22889	 22899	 8.8e-05	 0.000993	 0.00904	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22889	 82951	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82941	 22890	 0.050164	 0.047042	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22890	 82978	 0.010336	 0.034109	 0.00055	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22891	 22894	 0.007932	 0.012151	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82952	 22891	 0.007253	 0.015543	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22892	 22893	 0.008721	 0.006902	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22893	 22894	 0.003849	 0.008936	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22894	 82954	 0.006416	 0.009391	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22895	 22896	 0.005656	 0.008029	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22896	 82971	 0.009386	 0.012336	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22897	 22898	 0.019854	 0.015042	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22898	 82955	 0.004558	 0.010872	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22898	 82956	 0.056679	 0.044855	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22898	 82971	 0.031494	 0.024924	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22899	 82953	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22900	 22904	 0.001398	 0.003807	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82953	 22900	 0.000645	 0.00251	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22900	 82955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22900	 82955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22901	 22902	 0.003499	 0.008994	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22901	 22903	 0.013118	 0.010381	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82952	 22902	 0.008099	 0.016036	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22902	 82977	 0.003248	 0.010834	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22904	 22970	 0.001563	 0.004018	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22905	 22906	 0.010166	 0.013857	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82955	 22905	 0.00754	 0.017104	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22906	 22908	 0.035713	 0.023121	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22907	 22951	 0.003371	 0.0094	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22907	 82956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22907	 82956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22907	 82973	 0.003599	 0.009251	 0.00229	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22908	 22909	 0.01743	 0.017434	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22908	 22956	 0.023263	 0.018235	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22909	 82981	 0.003299	 0.014699	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22910	 22911	 0.023859	 0.092819	 0.00155	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22910	 23459	 0.099818	 0.10873	 0.00148	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22910	 82957	 0.025348	 0.074541	 0.00153	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22911	 22920	 0.062709	 0.1028	 0.00182	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22911	 23460	 0.082365	 0.090594	 0.00121	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22911	 83113	 0.037503	 0.096408	 0.00149	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22911	 83114	 0.043299	 0.12419	 0.00191	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22912	 22914	 0.003752	 0.01502	 0.00378	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22912	 22918	 0.010765	 0.029309	 0.00646	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22912	 82957	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22912	 82957	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22913	 22914	 0.005887	 0.020599	 0.00683	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22913	 22916	 0.008268	 0.028362	 0.00679	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22913	 23517	 0.012628	 0.075245	 0.0198	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22913	 23524	 0.007119	 0.043057	 0.01099	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22913	 82958	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22913	 82958	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22915	 22916	 0.000862	 0.006722	 0.00201	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22915	 23896	 0.00316	 0.02539	 0.00714	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22915	 82959	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22915	 82959	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22916	 22918	 0.003367	 0.028874	 0.00822	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22916	 82960	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22916	 82960	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82960	 22917	 0.028096	 0.065219	 0.00124	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22917	 82961	 0.024347	 0.057655	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22918	 82961	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22918	 82961	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22919	 22920	 0.020978	 0.092432	 0.00161	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82957	 22919	 0.020824	 0.081011	 0.00135	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82961	 22919	 0.026512	 0.067425	 0.00107	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22920	 22921	 0.039465	 0.10037	 0.00159	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22920	 83114	 0.013623	 0.072586	 0.00127	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22921	 22922	 0.037968	 0.09656	 0.00153	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22922	 22923	 0.025946	 0.047523	 0.00082	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82961	 22922	 0.026279	 0.067554	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22923	 82966	 0.11597	 0.075085	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22924	 22925	 0.009526	 0.022557	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22924	 22927	 0.019078	 0.03739	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22925	 22930	 0.019992	 0.051392	 0.0008	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82961	 22925	 0.007742	 0.047052	 0.00087	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22926	 22927	 0.014402	 0.025724	 0.00038	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22927	 22930	 0.08342	 0.063203	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22927	 82963	 0.030226	 0.076564	 0.00152	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22928	 22929	 0.015605	 0.024908	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22928	 22934	 0.013483	 0.038671	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22929	 22930	 0.032351	 0.025602	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22930	 22939	 0.014422	 0.026415	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22931	 22932	 0.041761	 0.049992	 0.00083	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22931	 22933	 0.014903	 0.057977	 0.00097	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82960	 22931	 0.013087	 0.068052	 0.00148	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22932	 82965	 0.059652	 0.046759	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22933	 22934	 0.006388	 0.016422	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22934	 82963	 0.014227	 0.022709	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22935	 22936	 0.000189	 0.002075	 0.02016	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22935	 82962	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22936	 22957	 0.000744	 0.008117	 0.07969	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22936	 82964	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22937	 23911	 0.012672	 0.056464	 0.00096	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82948	 22937	 0.010258	 0.029421	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82965	 22937	 0.03894	 0.032051	 0.00065	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82948	 22938	 0.038011	 0.041808	 0.00056	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22939	 22940	 0.052041	 0.039919	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22940	 22943	 0.089748	 0.068844	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22941	 22943	 0.06706	 0.053071	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22941	 22950	 0.014283	 0.026161	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22941	 22955	 0.057283	 0.045333	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22942	 82966	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22942	 82966	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22943	 22947	 0.027063	 0.029766	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81988	 22943	 0.012264	 0.01787	 0.0004	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82966	 22943	 0.034657	 0.053091	 0.00075	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22944	 82967	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22944	 82967	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22944	 82969	 0.003397	 0.027289	 0.00767	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81988	 22945	 0.016258	 0.092421	 0.00167	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22945	 82968	 0.010629	 0.051865	 0.0009	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22946	 82968	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22946	 82968	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22946	 82969	 0.002058	 0.033122	 0.01082	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22947	 22948	 0.051734	 0.056902	 0.00076	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22947	 82970	 0.022155	 0.045338	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82967	 22948	 0.025694	 0.078825	 0.00214	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22948	 82970	 0.018663	 0.043323	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22949	 22957	 0.000217	 0.002378	 0.0231	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22949	 82969	 0.000112	 0.008969	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22950	 22952	 0.025372	 0.018341	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22950	 82971	 0.008882	 0.017408	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22951	 82971	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22951	 82971	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82956	 22952	 0.017994	 0.018046	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82969	 22953	 0.003628	 0.015357	 0.00346	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22953	 82972	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22953	 82972	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22954	 22955	 0.022519	 0.016568	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22955	 82974	 0.005895	 0.022933	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22956	 22958	 0.03856	 0.027875	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22956	 82974	 0.007357	 0.022144	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22957	 82973	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22958	 22959	 0.023816	 0.018848	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22958	 22961	 0.013008	 0.021912	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22960	 22962	 0.035039	 0.027729	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22961	 22962	 0.007342	 0.013651	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22962	 82981	 0.025063	 0.024216	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22962	 82982	 0.003278	 0.014361	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22963	 22984	 0.007222	 0.015476	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22963	 82982	 0.006784	 0.017438	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22964	 22968	 0.000615	 0.006664	 0.00208	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22964	 23916	 0.000888	 0.011367	 0.00339	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22964	 82975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22964	 82975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22965	 22966	 0.000433	 0.00459	 0.00136	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22965	 23913	 0.000721	 0.008242	 0.00251	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22966	 22972	 0.000627	 0.005375	 0.00153	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22966	 82976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22966	 82976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22967	 22969	 0.001035	 0.004145	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82951	 22967	 0.001466	 0.003943	 0.00111	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22967	 82977	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22967	 82977	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22968	 22969	 0.000851	 0.005484	 0.00144	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22968	 82978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22968	 82978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22969	 22971	 0.000999	 0.003998	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22970	 22971	 0.000523	 0.003937	 0.00109	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22970	 22977	 0.001481	 0.00508	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22971	 22973	 0.000622	 0.004839	 0.00126	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22971	 82979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22971	 82979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22972	 22973	 0.000335	 0.003051	 0.00077	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22972	 82980	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22972	 82980	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22974	 22980	 0.011043	 0.030588	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82980	 22974	 0.007329	 0.018841	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22975	 22976	 0.010497	 0.015738	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82979	 22975	 0.004916	 0.016222	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22976	 82981	 0.023436	 0.015743	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22976	 82982	 0.034226	 0.027086	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22977	 22978	 0.003426	 0.009055	 0.00212	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22977	 82981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22977	 82981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22978	 22982	 0.002243	 0.021533	 0.00626	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22978	 82982	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22978	 82982	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22979	 22981	 0.018369	 0.029321	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82976	 22979	 0.006999	 0.025001	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82982	 22980	 0.020184	 0.026268	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22981	 22983	 0.018065	 0.051814	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22981	 82983	 0.009224	 0.04613	 0.00082	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81943	 22982	 0.00437	 0.037638	 0.02186	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22982	 82983	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22982	 82983	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22983	 22984	 0.016803	 0.016441	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22983	 22985	 0.006493	 0.016691	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22984	 22985	 0.007216	 0.016753	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22985	 22988	 0.004681	 0.021694	 0.00042	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22986	 22988	 0.060578	 0.047484	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22987	 22988	 0.00939	 0.036127	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82972	 22987	 0.012641	 0.025869	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22989	 82984	 0.068323	 0.050268	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82969	 22990	 0.007829	 0.020691	 0.00484	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22990	 82984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22990	 82984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22993	 22996	 0.012255	 0.049875	 0.01215	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22993	 23367	 0.010279	 0.047941	 0.01187	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22994	 22995	 0.029011	 0.17837	 0.00322	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22994	 23884	 0.032886	 0.15466	 0.00288	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22995	 23373	 0.030099	 0.14457	 0.0028	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22995	 83227	 0.14471	 0.26117	 0.00378	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22996	 23880	 0.015013	 0.05307	 0.01196	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22997	 23002	 0.14366	 0.1137	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22998	 23001	 0.043583	 0.11204	 0.00173	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22998	 24129	 0.039157	 0.097192	 0.00162	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22999	 82985	 0.063173	 0.042435	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23000	 23006	 0.00436	 0.021159	 0.00484	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23000	 24130	 0.00525	 0.027972	 0.00785	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23000	 82985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23000	 82985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23001	 23002	 0.057228	 0.083392	 0.00188	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23001	 82987	 0.14614	 0.11456	 0.00147	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23002	 23003	 0.10962	 0.090232	 0.00183	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23002	 83307	 0.083349	 0.21605	 0.00409	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23003	 82986	 0.11687	 0.092493	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23004	 23005	 0.003641	 0.01249	 0.00299	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23004	 82986	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23004	 82986	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23004	 82990	 0.005068	 0.017385	 0.00416	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23005	 23006	 0.002215	 0.008618	 0.0023	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23005	 82987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23005	 82987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23006	 82988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23006	 82988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23007	 23009	 0.002974	 0.016595	 0.00424	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23007	 23019	 0.005214	 0.02392	 0.00613	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23008	 82989	 0.022548	 0.017844	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23009	 82989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23009	 82989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23009	 82990	 0.001252	 0.006173	 0.00167	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23010	 23527	 0.000665	 0.009409	 0.08974	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23010	 82990	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23011	 23012	 0.050294	 0.099579	 0.00146	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82989	 23011	 0.034312	 0.067246	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82991	 23011	 0.008946	 0.047124	 0.00085	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23011	 83135	 0.06508	 0.18029	 0.00298	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23012	 82992	 0.080911	 0.081725	 0.00108	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23013	 82992	 0.037512	 0.026571	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23014	 23015	 0.003931	 0.024395	 0.00591	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81964	 23014	 0.024724	 0.084839	 0.02033	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82990	 23014	 0.012195	 0.046358	 0.01298	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23014	 82992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23014	 82992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23015	 23016	 0.000798	 0.003942	 0.00115	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23016	 23122	 0.004407	 0.01964	 0.00534	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23016	 82993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23016	 82993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23017	 23123	 0.069124	 0.13687	 0.00201	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82992	 23017	 0.047642	 0.10807	 0.00216	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23018	 23528	 0.002536	 0.020722	 0.00562	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82990	 23018	 0.003872	 0.033787	 0.00928	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23019	 23532	 0.004529	 0.018133	 0.00457	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82988	 23020	 0.046615	 0.049665	 0.00071	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23021	 23022	 0.25687	 0.20333	 0.00256	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23022	 23023	 0.10416	 0.06997	 0.00123	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23022	 23026	 0.086475	 0.17123	 0.00251	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82757	 23024	 0.52241	 0.40988	 0.00526	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23025	 23026	 0.075298	 0.13792	 0.00238	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82871	 23026	 0.013573	 0.092093	 0.00172	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23027	 23035	 0.034889	 0.080987	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23027	 23048	 0.028452	 0.080739	 0.00127	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23027	 83103	 0.021323	 0.084599	 0.00242	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23028	 23029	 0.038797	 0.079398	 0.00195	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23028	 23049	 0.038206	 0.098215	 0.00152	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23029	 23030	 0.035347	 0.090865	 0.00141	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82920	 23029	 0.025548	 0.09939	 0.00166	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23029	 82998	 0.099913	 0.17573	 0.0033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23030	 23031	 0.14454	 0.11439	 0.00144	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23031	 82994	 0.05904	 0.10383	 0.00195	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23031	 83000	 0.042958	 0.099734	 0.00148	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23032	 23040	 0.005114	 0.025696	 0.00669	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23032	 23043	 0.004209	 0.026656	 0.00723	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23032	 82994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23032	 82994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23033	 23039	 0.074864	 0.059247	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23034	 23047	 0.016517	 0.043656	 0.01022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23034	 24226	 0.022289	 0.080728	 0.01733	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23034	 82995	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23034	 82995	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23034	 82996	 0.001833	 0.017911	 0.00503	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23035	 23048	 0.037261	 0.026936	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82995	 23035	 0.016166	 0.042846	 0.00109	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23036	 82997	 0.040303	 0.078989	 0.00118	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23036	 83001	 0.12131	 0.078544	 0.0015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23037	 26399	 0.001931	 0.021892	 0.19951	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23037	 82996	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82997	 23038	 0.022385	 0.017715	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23038	 82999	 0.020296	 0.014672	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82997	 23039	 0.032058	 0.02537	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23039	 82998	 0.005874	 0.013433	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23040	 23041	 0.002214	 0.007593	 0.00182	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23040	 82998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23040	 82998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82996	 23041	 0.002749	 0.007264	 0.0017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23041	 82999	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23041	 82999	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82994	 23042	 0.034097	 0.11375	 0.0018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82999	 23042	 0.029372	 0.038604	 0.00053	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23043	 23044	 0.00736	 0.02947	 0.00742	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23043	 83000	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23043	 83000	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23044	 83957	 0.013536	 0.070525	 0.0185	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23045	 23047	 0.006136	 0.029941	 0.00827	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23045	 26074	 0.007498	 0.041297	 0.01491	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23046	 23444	 0.042309	 0.1076	 0.0017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82997	 23046	 0.098864	 0.19576	 0.00287	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23046	 83001	 0.005855	 0.035997	 0.00065	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23047	 83001	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23047	 83001	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23048	 23049	 0.015085	 0.038363	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23049	 24229	 0.056704	 0.16092	 0.00253	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23049	 24230	 0.04736	 0.12045	 0.0019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23049	 24231	 0.21984	 0.174	 0.00219	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82995	 23049	 0.062684	 0.091344	 0.00206	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23050	 23052	 0.001248	 0.006208	 0.002	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82862	 23051	 0.10977	 0.080763	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23052	 23053	 0.00182	 0.009305	 0.00254	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23053	 23059	 0.002905	 0.013241	 0.0042	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82860	 23054	 0.087239	 0.071808	 0.00146	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23054	 83002	 0.13446	 0.097205	 0.00147	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23055	 23057	 0.00267	 0.01202	 0.0032	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23055	 23070	 0.00174	 0.007245	 0.00226	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23055	 83002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23055	 83002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23056	 23060	 0.019418	 0.047531	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83002	 23056	 0.019348	 0.049737	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23057	 23094	 0.001798	 0.008247	 0.00211	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23058	 83004	 0.021103	 0.054249	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23058	 83012	 0.015015	 0.038598	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23059	 23061	 0.004999	 0.01361	 0.003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23059	 23578	 0.002657	 0.014157	 0.00397	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23059	 83003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23059	 83003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83003	 23060	 0.01927	 0.049536	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23061	 23062	 0.004786	 0.01203	 0.00312	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23062	 23082	 0.003015	 0.008406	 0.00176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23062	 83004	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23062	 83004	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23063	 83310	 0.17592	 0.13924	 0.00175	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23064	 23070	 0.00349	 0.021459	 0.00619	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23064	 24110	 0.002887	 0.025579	 0.00681	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23064	 83005	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23064	 83005	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23065	 23066	 0.000389	 0.004372	 0.00115	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23066	 23068	 0.00141	 0.012788	 0.00669	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23066	 24104	 0.011968	 0.096185	 0.02705	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23066	 83006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23066	 83006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23067	 23076	 0.055216	 0.083747	 0.0012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82895	 23067	 0.018513	 0.11251	 0.00208	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83006	 23067	 0.010671	 0.041512	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23067	 83007	 0.007091	 0.051029	 0.00167	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23068	 23072	 0.001289	 0.013262	 0.00376	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23068	 83007	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23068	 83007	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83005	 23069	 0.051219	 0.074636	 0.00169	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83007	 23069	 0.028272	 0.047627	 0.00068	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23070	 83008	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23070	 83008	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83002	 23071	 0.032678	 0.054578	 0.00093	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83008	 23071	 0.02124	 0.049312	 0.00073	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23071	 83009	 0.005429	 0.012415	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23072	 23074	 0.002563	 0.009743	 0.00273	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23072	 83009	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23072	 83009	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23073	 23075	 0.008703	 0.052892	 0.00098	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83007	 23073	 0.00799	 0.048556	 0.0009	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23074	 23095	 0.003088	 0.011738	 0.00329	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23075	 23080	 0.013259	 0.080583	 0.00149	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23076	 23077	 0.029852	 0.098514	 0.0016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23077	 24233	 0.03449	 0.098923	 0.00152	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23078	 23080	 0.068883	 0.048794	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23079	 23080	 0.016545	 0.033858	 0.00083	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23079	 24233	 0.040777	 0.10482	 0.00162	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23080	 23104	 0.009031	 0.040244	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23080	 24232	 0.086259	 0.077297	 0.00158	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23081	 23085	 0.005765	 0.025688	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23081	 23581	 0.016586	 0.047572	 0.00073	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23082	 23084	 0.00281	 0.006522	 0.00199	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23083	 23087	 0.018678	 0.030057	 0.00047	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23083	 23092	 0.037991	 0.029141	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23083	 83010	 0.032599	 0.025798	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23084	 83010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23084	 83010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83010	 23085	 0.00479	 0.023375	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23086	 23089	 0.039351	 0.031142	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23087	 23089	 0.003045	 0.018722	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23087	 83011	 0.005107	 0.019648	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23088	 23091	 0.003667	 0.013937	 0.0039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23088	 23097	 0.00189	 0.007567	 0.00191	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23088	 23105	 0.003143	 0.019502	 0.00472	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23088	 83011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23088	 83011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23089	 23090	 0.004873	 0.011312	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23089	 83014	 0.036055	 0.055233	 0.00078	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23090	 23098	 0.041113	 0.032536	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23090	 23106	 0.019593	 0.013161	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23091	 23094	 0.002143	 0.0104	 0.00238	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83009	 23093	 0.01327	 0.051054	 0.00087	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23093	 83012	 0.005853	 0.013276	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23093	 83013	 0.030575	 0.077759	 0.00123	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23094	 83012	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23094	 83012	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23095	 23096	 0.001964	 0.008111	 0.00192	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23096	 23097	 0.002288	 0.008994	 0.00235	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23097	 83013	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23097	 83013	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23099	 23100	 0.033786	 0.044405	 0.00061	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83013	 23099	 0.026901	 0.052722	 0.00079	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23100	 23104	 0.022529	 0.021127	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23101	 23102	 0.059357	 0.046975	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23102	 23103	 0.010728	 0.040243	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23102	 83015	 0.036685	 0.033098	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23103	 23104	 0.004397	 0.026032	 0.00051	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23103	 24242	 0.022912	 0.059382	 0.00112	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23105	 83014	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23105	 83014	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23105	 83156	 0.009749	 0.03832	 0.01003	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23107	 23108	 0.003962	 0.010471	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23107	 83015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23107	 83015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23108	 83016	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23108	 83016	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83016	 23109	 0.008275	 0.028971	 0.0008	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23109	 83165	 0.004834	 0.018597	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23110	 24244	 0.017274	 0.044406	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83016	 23110	 0.007909	 0.022683	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23111	 23115	 0.025616	 0.0997	 0.02664	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82724	 23111	 0.062993	 0.16932	 0.03843	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23111	 83017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23111	 83017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83017	 23112	 0.2444	 0.15826	 0.00301	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23113	 23117	 0.31324	 0.31652	 0.00419	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83017	 23114	 0.20994	 0.39065	 0.00915	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23115	 24101	 0.029183	 0.11691	 0.02948	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23118	 23122	 0.002489	 0.012379	 0.004	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23118	 23124	 0.002965	 0.009267	 0.00268	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23119	 24069	 0.029574	 0.078387	 0.00199	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23119	 83019	 0.03432	 0.067952	 0.001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23120	 23129	 0.000223	 0.002451	 0.02381	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23120	 83018	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23121	 23122	 0.006545	 0.01699	 0.00412	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23121	 23124	 0.009288	 0.031294	 0.00778	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81964	 23121	 0.00948	 0.076972	 0.02452	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23121	 83020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23121	 83020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23121	 83023	 0.009918	 0.034024	 0.00815	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23122	 83021	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23122	 83021	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82993	 23123	 0.046837	 0.092734	 0.00136	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83021	 23123	 0.071329	 0.046179	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23123	 83208	 0.043476	 0.098621	 0.00197	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23124	 23125	 0.003787	 0.011397	 0.00357	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23124	 23127	 0.004359	 0.014686	 0.00365	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23125	 23155	 0.003783	 0.012976	 0.00311	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23125	 83022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23125	 83022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83022	 23126	 0.033405	 0.03374	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23127	 23162	 0.003582	 0.010877	 0.00238	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23128	 23142	 0.041829	 0.08282	 0.00122	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83020	 23128	 0.03019	 0.10071	 0.0016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23129	 23131	 0.000386	 0.004275	 0.0407	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23129	 83023	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23130	 23136	 0.046418	 0.034151	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23130	 24047	 0.23176	 0.25497	 0.0034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83024	 23130	 0.052946	 0.052959	 0.00072	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23130	 83025	 0.081356	 0.063772	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23131	 23132	 4.6e-05	 0.000722	 0.00753	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23131	 24057	 0.000161	 0.001893	 0.03306	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23131	 83025	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23131	 83025	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23132	 23138	 7e-05	 0.001117	 0.01129	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23132	 83026	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23132	 83026	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23133	 23141	 0.000101	 0.001163	 0.0102	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23133	 23327	 5.2e-05	 0.000868	 0.00814	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23133	 83027	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23133	 83027	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23134	 23140	 0.004396	 0.01162	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23134	 83029	 0.00704	 0.023232	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23135	 83028	 0.036682	 0.026517	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83025	 23136	 0.012912	 0.029529	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23136	 83029	 0.008405	 0.022276	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83023	 23137	 0.006448	 0.02451	 0.00686	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83027	 23137	 0.002643	 0.007415	 0.00191	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23137	 83028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23137	 83028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23138	 23327	 0.000139	 0.002305	 0.02161	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23138	 83029	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23138	 83029	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23139	 23224	 0.027455	 0.10563	 0.0018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83025	 23139	 0.024203	 0.044329	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83026	 23139	 0.011855	 0.022043	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23140	 83077	 0.022702	 0.058357	 0.0009	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23141	 23146	 0.000122	 0.001359	 0.01281	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23142	 23143	 0.07226	 0.056641	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23142	 23144	 0.068828	 0.05447	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23143	 23144	 0.036082	 0.028283	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23143	 23148	 0.086778	 0.065748	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23144	 23145	 0.01176	 0.017836	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23144	 83032	 0.07325	 0.05797	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23145	 23149	 0.02721	 0.021534	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83028	 23145	 0.031282	 0.081075	 0.00153	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23146	 23147	 6e-05	 0.000688	 0.00621	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23147	 23179	 0.000344	 0.003778	 0.03669	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23147	 23216	 8.7e-05	 0.000984	 0.00896	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23148	 23150	 0.023378	 0.0172	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23148	 23151	 0.032186	 0.020837	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23149	 23151	 0.01777	 0.014626	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23150	 23151	 0.022252	 0.016372	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23150	 83052	 0.007583	 0.019284	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23151	 83052	 0.013054	 0.025845	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23152	 23153	 0.012721	 0.016555	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23152	 23154	 0.045489	 0.033467	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23152	 83031	 0.014099	 0.025341	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23153	 23154	 0.010762	 0.016484	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23153	 23160	 0.041431	 0.045569	 0.00061	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23154	 83030	 0.005906	 0.01676	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23155	 23836	 0.010098	 0.026688	 0.00625	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23155	 83030	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23155	 83030	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83030	 23156	 0.036235	 0.028676	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23157	 23159	 0.011538	 0.019437	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23157	 23160	 0.040305	 0.029136	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23157	 23831	 0.022771	 0.018021	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23158	 23159	 0.007487	 0.014824	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23158	 23174	 0.005595	 0.018665	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23160	 23161	 0.025208	 0.027726	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23160	 83033	 0.023258	 0.056931	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23162	 23163	 0.00253	 0.006791	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23162	 23173	 0.01108	 0.028766	 0.00698	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23162	 83031	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23162	 83031	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23163	 23164	 0.001621	 0.003906	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23164	 23173	 0.007431	 0.020232	 0.00446	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23164	 83032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23164	 83032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23165	 23167	 0.036292	 0.028721	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83032	 23165	 0.023537	 0.018627	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23166	 23169	 0.026778	 0.021192	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83032	 23166	 0.044797	 0.035452	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23167	 23171	 0.02296	 0.01817	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23167	 83033	 0.02351	 0.039604	 0.00056	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23168	 83033	 0.035798	 0.02833	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23169	 23171	 0.023835	 0.018863	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23169	 83052	 0.004987	 0.016637	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23170	 23178	 0.025951	 0.020537	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23170	 23193	 0.018598	 0.014718	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23172	 83033	 0.029186	 0.022877	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23173	 83033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23173	 83033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23173	 83075	 0.001124	 0.01079	 0.00314	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23174	 83034	 0.005729	 0.032564	 0.00059	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23175	 23841	 0.01259	 0.040541	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23175	 83034	 0.002986	 0.016972	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23176	 23859	 0.003462	 0.015252	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23176	 83039	 0.003543	 0.021783	 0.00039	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23177	 83034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23177	 83034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23177	 83075	 0.002334	 0.007614	 0.00202	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23178	 23186	 0.012936	 0.036708	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23178	 23194	 0.051083	 0.033071	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83033	 23178	 0.021514	 0.023663	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23179	 23181	 6.8e-05	 0.000723	 0.00754	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23179	 83035	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23179	 83035	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23179	 83074	 0.00014	 0.001535	 0.01491	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23180	 23189	 0.002942	 0.007774	 0.00182	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23180	 23198	 0.001783	 0.006301	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83035	 23180	 0.000421	 0.003543	 0.00105	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23180	 83036	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23180	 83036	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23181	 23182	 0.00012	 0.001364	 0.01232	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23181	 83037	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23181	 83037	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23182	 23183	 6.1e-05	 0.000692	 0.00625	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23182	 83038	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23183	 83040	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23183	 83074	 0.000126	 0.001459	 0.01279	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23184	 23185	 0.001044	 0.003968	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23184	 23853	 0.00119	 0.004148	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23185	 23191	 0.000542	 0.004082	 0.00113	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23185	 83075	 0.000417	 0.003152	 0.00155	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23186	 23187	 0.024378	 0.015782	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23186	 83044	 0.01824	 0.018244	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23186	 83076	 0.005331	 0.017785	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23187	 83044	 0.032307	 0.020916	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23188	 23207	 0.010217	 0.017211	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83036	 23188	 0.008727	 0.015984	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23189	 23287	 0.000659	 0.005611	 0.0014	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23189	 83042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23189	 83042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23189	 83043	 0.000729	 0.005857	 0.00165	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23190	 83043	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23190	 83074	 0.000108	 0.001245	 0.01091	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23191	 23291	 0.000929	 0.00313	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23191	 83045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23191	 83045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23192	 23293	 0.000466	 0.003998	 0.00114	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23192	 23861	 0.001585	 0.004316	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23192	 83046	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23192	 83046	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23192	 83075	 0.000795	 0.009252	 0.00272	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23193	 23194	 0.017262	 0.013531	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23194	 23196	 0.024982	 0.019582	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23194	 83047	 0.013599	 0.014957	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23195	 23220	 0.001374	 0.005503	 0.00139	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23195	 23223	 0.001605	 0.004242	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83027	 23195	 0.002588	 0.01165	 0.0031	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23196	 83052	 0.024099	 0.019071	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23197	 23198	 0.001112	 0.003815	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23197	 23199	 0.001921	 0.004938	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23197	 23212	 0.003021	 0.007767	 0.00192	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23197	 83047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23197	 83047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23199	 23200	 0.001271	 0.003359	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23199	 83048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23199	 83048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23200	 23201	 0.001161	 0.003236	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23201	 23204	 0.001909	 0.004955	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23202	 23205	 0.025407	 0.022766	 0.00047	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23202	 83049	 0.024249	 0.019007	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23202	 83054	 0.01728	 0.040117	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23203	 23211	 0.001851	 0.00516	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23203	 23222	 0.0012	 0.003115	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23204	 23221	 0.003353	 0.009129	 0.00201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23204	 83049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23204	 83049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23205	 23206	 0.018672	 0.014777	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23206	 23207	 0.01334	 0.014246	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23206	 83057	 0.023037	 0.017453	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83042	 23207	 0.04	 0.031655	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23208	 83057	 0.017887	 0.014155	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23209	 23257	 0.026001	 0.019699	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83049	 23209	 0.009517	 0.015895	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23210	 23211	 0.001633	 0.00424	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23210	 83050	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23210	 83050	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23210	 83056	 0.004483	 0.011848	 0.00277	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23211	 83051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23211	 83051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23212	 23214	 0.001249	 0.004209	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23212	 83052	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23212	 83052	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23213	 23227	 0.010478	 0.018716	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23213	 23228	 0.001418	 0.004681	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23213	 23229	 0.017861	 0.013532	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83050	 23213	 0.006677	 0.022273	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83051	 23213	 0.005939	 0.013788	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23214	 23215	 0.001162	 0.004106	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23215	 83053	 0.000922	 0.004153	 0.00111	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23216	 83053	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23216	 83053	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83048	 23217	 0.025696	 0.018905	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23218	 23220	 0.002416	 0.006736	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23218	 23222	 0.00091	 0.003645	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23218	 23223	 0.001141	 0.004486	 0.00117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23218	 83054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23218	 83054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83054	 23219	 0.020057	 0.015873	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23219	 83055	 0.005697	 0.01128	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83053	 23220	 0.000619	 0.003333	 0.00092	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23220	 83055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23220	 83055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23220	 83056	 0.007877	 0.02045	 0.00496	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23221	 23222	 0.001241	 0.003118	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23223	 23331	 0.001392	 0.004852	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23224	 23226	 0.021708	 0.021926	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23224	 23227	 0.008279	 0.01774	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83054	 23224	 0.010954	 0.023023	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23225	 23227	 0.03656	 0.039043	 0.00083	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23225	 83077	 0.016936	 0.032814	 0.00071	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23226	 23228	 0.015177	 0.032524	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23226	 24054	 0.045951	 0.17878	 0.00298	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23227	 23228	 0.011028	 0.013444	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23228	 23229	 0.014279	 0.0113	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23230	 23231	 0.010841	 0.008498	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23231	 23232	 0.011264	 0.008914	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23232	 23233	 0.004472	 0.01269	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23232	 23236	 0.004108	 0.010559	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83050	 23233	 0.005316	 0.017732	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23234	 23235	 0.008883	 0.006963	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23234	 23258	 0.015362	 0.012157	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23235	 23236	 0.012003	 0.009499	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23236	 23237	 0.005281	 0.012258	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23237	 23238	 0.022532	 0.017831	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23237	 23240	 0.003195	 0.008213	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23238	 23239	 0.004451	 0.007105	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23238	 23258	 0.004452	 0.010619	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23239	 23244	 0.007965	 0.013056	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23240	 23241	 0.004453	 0.008726	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23241	 23242	 0.005642	 0.009005	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23242	 23243	 0.006785	 0.011122	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23242	 23246	 0.00384	 0.00871	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23243	 23244	 0.004289	 0.008491	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23244	 23265	 0.018653	 0.01884	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23245	 23276	 0.015764	 0.011396	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23246	 23247	 0.004831	 0.009468	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23247	 23248	 0.026833	 0.021235	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23247	 23249	 0.017631	 0.013358	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23247	 23250	 0.01539	 0.010902	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23247	 83068	 0.023636	 0.067791	 0.00104	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23248	 24554	 0.026286	 0.019339	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23249	 23251	 0.012921	 0.009789	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23250	 23252	 0.016958	 0.01342	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23252	 24553	 0.020457	 0.014788	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23253	 83056	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23253	 83074	 0.000314	 0.003555	 0.03236	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23254	 23286	 0.030239	 0.023931	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83057	 23254	 0.00893	 0.016356	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83042	 23255	 0.015316	 0.030016	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23255	 83058	 0.016622	 0.018282	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23256	 23259	 0.000397	 0.00313	 0.00092	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23256	 23287	 0.003285	 0.008682	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83056	 23256	 0.000352	 0.003364	 0.00123	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23256	 83058	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23256	 83058	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83058	 23257	 0.026595	 0.020846	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23258	 83059	 0.002502	 0.017174	 0.00031	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23259	 24547	 0.007924	 0.027615	 0.0064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23259	 83059	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23259	 83059	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23260	 23263	 0.003197	 0.006542	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23260	 23265	 0.005102	 0.017852	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83059	 23260	 0.001797	 0.008157	 0.00018	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23261	 23262	 0.008046	 0.014046	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83057	 23261	 0.006973	 0.031652	 0.00069	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23262	 83060	 0.003781	 0.008103	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23263	 23266	 0.004617	 0.009141	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23264	 23265	 0.012678	 0.009328	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23265	 23271	 0.008712	 0.007806	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23266	 23269	 0.005518	 0.009045	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23267	 23268	 0.000835	 0.002274	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23267	 83060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23267	 83060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23268	 23275	 0.000806	 0.002027	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23269	 23270	 0.002824	 0.008671	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23269	 23274	 0.013444	 0.010639	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83060	 23269	 0.0066	 0.012089	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23270	 23273	 0.00319	 0.0082	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23271	 23272	 0.011498	 0.009099	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23272	 23273	 0.016683	 0.0108	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23273	 23277	 0.003507	 0.009015	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23274	 23278	 0.014768	 0.010676	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23275	 23313	 0.001198	 0.003167	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23276	 23277	 0.020427	 0.016166	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23277	 23280	 0.009604	 0.009279	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23277	 23282	 0.007212	 0.017653	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23277	 83069	 0.006148	 0.028507	 0.00059	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23278	 23279	 0.013678	 0.009689	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23278	 83069	 0.008818	 0.017282	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23279	 23285	 0.006118	 0.011991	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23279	 83069	 0.004927	 0.011436	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23280	 23283	 0.019345	 0.015309	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23281	 23282	 0.011126	 0.008805	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23282	 24550	 0.025963	 0.020547	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23283	 23284	 0.011692	 0.008602	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23284	 23323	 0.010978	 0.021735	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23284	 24247	 0.015421	 0.009983	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23285	 23323	 0.006504	 0.010957	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23286	 83061	 0.012402	 0.008965	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23287	 23300	 0.000632	 0.004002	 0.00109	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23287	 83061	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23287	 83061	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23288	 23289	 0.012706	 0.009959	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23288	 23290	 0.004497	 0.0173	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23288	 23297	 0.004389	 0.008602	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83061	 23288	 0.023412	 0.017225	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83044	 23290	 0.002638	 0.016219	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23290	 83079	 0.010049	 0.019896	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23291	 23292	 0.000653	 0.002307	 0.00052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23292	 23295	 0.000441	 0.003028	 0.00088	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23292	 83078	 0.001505	 0.0039	 0.00118	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23293	 23783	 0.000545	 0.004585	 0.00136	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83046	 23294	 0.01011	 0.033726	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23294	 83066	 0.009342	 0.018309	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23295	 23307	 0.000567	 0.004138	 0.00106	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23295	 83062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23295	 83062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23296	 83063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23296	 83063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23296	 83078	 0.001241	 0.004493	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23297	 23298	 0.004323	 0.0069	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23298	 23302	 0.002896	 0.007655	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83063	 23298	 0.012397	 0.017598	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83061	 23299	 0.01203	 0.008521	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23300	 23301	 0.000342	 0.001741	 0.00063	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23301	 23324	 0.00035	 0.002008	 0.00057	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23302	 23303	 0.004629	 0.009166	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23303	 23312	 0.006635	 0.013137	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23304	 23305	 0.001817	 0.006361	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23304	 23311	 0.003987	 0.013299	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83063	 23305	 0.002023	 0.009393	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23305	 83064	 0.014201	 0.017312	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23306	 83064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23306	 83064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23306	 83078	 0.001404	 0.005338	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23307	 23308	 0.001056	 0.00384	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23307	 23310	 0.001294	 0.004438	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23307	 83065	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23307	 83065	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23308	 23789	 0.00164	 0.005626	 0.00135	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23308	 83066	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23308	 83066	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23309	 23317	 0.00844	 0.016541	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83066	 23309	 0.003054	 0.01545	 0.00027	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23309	 83207	 0.011802	 0.016448	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23310	 83067	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23310	 83067	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23311	 23325	 0.003417	 0.007814	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23312	 83073	 0.028628	 0.022656	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23313	 23314	 0.001563	 0.003628	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23313	 23324	 0.000605	 0.002883	 0.00084	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23313	 83068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23313	 83068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23314	 83069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23314	 83069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23314	 83072	 0.001558	 0.005345	 0.00128	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23315	 23326	 0.005663	 0.016243	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23315	 23332	 0.014104	 0.014245	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23316	 23317	 0.017897	 0.017901	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23316	 23319	 0.023829	 0.018858	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23318	 23319	 0.006371	 0.014788	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23318	 23777	 0.020471	 0.016046	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23318	 24294	 0.011044	 0.014515	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81977	 23319	 0.003688	 0.014349	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23320	 83070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23320	 83070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23320	 83072	 0.002065	 0.007083	 0.0017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23321	 23322	 0.011896	 0.009325	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83070	 23322	 0.012893	 0.014181	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23322	 83073	 0.004103	 0.015718	 0.00044	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23323	 24267	 0.005354	 0.012431	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23323	 83071	 0.001942	 0.009483	 0.0002	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23325	 23326	 0.005017	 0.009483	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83067	 23326	 0.005774	 0.016385	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23328	 24268	 0.00079	 0.003106	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23328	 83071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23328	 83071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23328	 83072	 0.000465	 0.003664	 0.00107	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23329	 23333	 0.000205	 0.002546	 0.02558	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23329	 24310	 0.000292	 0.003373	 0.02957	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23329	 24324	 0.000453	 0.005131	 0.04671	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23329	 83072	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23329	 83074	 0.000415	 0.004792	 0.04201	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23330	 24603	 0.000113	 0.002292	 0.82871	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23330	 24882	 0.000713	 0.013447	 5.9831	 4162.0	 4370.1	 4578.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23330	 83074	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23330	 83074	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23330	 83074	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83027	 23331	 0.003253	 0.01377	 0.0031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23331	 83077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23331	 83077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81977	 23332	 0.004408	 0.011211	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83070	 23332	 0.003477	 0.009973	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83074	 23333	 0.000187	 0.002163	 0.01896	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23333	 83078	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81995	 23334	 0.14581	 0.20325	 0.00348	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23335	 23336	 0.004306	 0.022431	 0.00588	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23336	 23337	 0.005075	 0.027848	 0.00736	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23337	 23342	 0.002578	 0.02211	 0.00629	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23337	 83080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23337	 83080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81995	 23338	 0.032444	 0.075312	 0.00143	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23338	 83082	 0.087609	 0.2004	 0.00489	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23339	 23367	 0.020056	 0.052073	 0.01264	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23340	 24862	 0.002548	 0.028531	 0.26706	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23340	 83081	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23340	 83081	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23341	 23369	 0.10093	 0.26165	 0.00495	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23341	 83082	 0.010224	 0.023736	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83081	 23342	 0.001139	 0.015927	 0.0054	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23342	 83082	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23342	 83082	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23343	 23344	 0.011033	 0.008117	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81994	 23343	 0.019737	 0.019742	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23343	 83083	 0.020272	 0.014915	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81961	 23344	 0.021133	 0.029999	 0.00049	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81994	 23344	 0.027469	 0.025302	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23344	 83083	 0.024688	 0.019538	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23344	 83084	 0.01561	 0.012353	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23345	 23346	 0.001132	 0.003039	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23345	 83083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23345	 83083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23346	 23347	 0.000956	 0.002565	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23346	 83084	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23346	 83084	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23347	 23348	 0.001969	 0.005204	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81960	 23348	 0.000711	 0.001983	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23348	 83085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23348	 83085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83084	 23349	 0.030998	 0.031309	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81994	 23350	 0.075001	 0.054219	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23351	 23362	 0.074696	 0.13343	 0.00197	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23352	 23358	 0.057435	 0.14765	 0.00229	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23352	 23364	 0.14912	 0.31352	 0.00571	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81994	 23352	 0.07913	 0.12632	 0.00291	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23353	 23354	 0.027459	 0.04586	 0.00078	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23353	 23356	 0.023959	 0.061589	 0.00095	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23353	 23365	 0.047701	 0.13682	 0.0021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81961	 23353	 0.038282	 0.14894	 0.00249	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82744	 23353	 0.54518	 0.60051	 0.00802	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23354	 23355	 0.03819	 0.038573	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23355	 23358	 0.060815	 0.043079	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23356	 23357	 0.055316	 0.035812	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23356	 23359	 0.047843	 0.052111	 0.00071	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23357	 23358	 0.023893	 0.023378	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23357	 23359	 0.05892	 0.046628	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23358	 23360	 0.1342	 0.1052	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23359	 23361	 0.13326	 0.20417	 0.00287	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23362	 23363	 0.10715	 0.083991	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23362	 23364	 0.096882	 0.20764	 0.00364	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81994	 23362	 0.094285	 0.21893	 0.00326	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81994	 23365	 0.010275	 0.023308	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83083	 23365	 0.013347	 0.026425	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81960	 23366	 0.021488	 0.083622	 0.02234	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23367	 23368	 0.004839	 0.03955	 0.01073	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23368	 23370	 0.003962	 0.03511	 0.00935	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23369	 83086	 0.017245	 0.035439	 0.00068	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23369	 83088	 0.18497	 0.1464	 0.00184	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23370	 83086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23370	 83086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23370	 83087	 0.000324	 0.004331	 0.00118	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23371	 83087	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23371	 83087	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81967	 23372	 0.007783	 0.0267	 0.0064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23372	 83088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23372	 83088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83088	 23373	 0.021275	 0.1308	 0.00236	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81938	 23374	 0.10383	 0.082175	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23375	 23376	 0.11825	 0.093582	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23376	 83090	 0.087553	 0.096301	 0.00129	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23377	 23385	 0.16661	 0.13061	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23378	 23379	 0.034305	 0.049988	 0.00113	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23379	 23380	 0.016824	 0.036052	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23380	 23385	 0.02469	 0.018165	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23380	 83089	 0.028331	 0.065774	 0.00098	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23381	 23383	 0.004226	 0.045344	 0.0118	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23381	 23514	 0.003446	 0.052667	 0.01697	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23381	 83089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23381	 83089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23382	 23384	 0.040014	 0.17632	 0.00306	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23382	 23458	 0.047033	 0.10757	 0.00263	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83089	 23382	 0.026108	 0.10448	 0.00221	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23383	 83090	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23383	 83090	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23384	 23457	 0.01814	 0.10312	 0.00187	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83090	 23384	 0.022674	 0.086875	 0.00246	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82812	 23386	 0.10397	 0.24139	 0.0046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23387	 83091	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23387	 83091	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23388	 23389	 0.026454	 0.19542	 0.00408	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82813	 23388	 0.1005	 0.34345	 0.00747	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83091	 23388	 0.10283	 0.2204	 0.00386	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23389	 23390	 0.017531	 0.14585	 0.00276	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83091	 23390	 0.049984	 0.41605	 0.00788	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23390	 83092	 0.01642	 0.063879	 0.00107	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23390	 83092	 0.01642	 0.063879	 0.00107	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23391	 83092	 0.006727	 0.013319	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23392	 45510	 0.001792	 0.022052	 0.35396	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23392	 83092	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23392	 83092	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23393	 23395	 0.001834	 0.00476	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23393	 23405	 0.007433	 0.019644	 0.0046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81930	 23393	 0.002753	 0.00997	 0.00214	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23393	 83093	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23393	 83093	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23394	 23400	 0.001633	 0.005603	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81930	 23394	 0.002375	 0.009335	 0.00244	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23394	 83094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23394	 83094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23395	 23401	 0.001852	 0.004808	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83093	 23396	 0.022886	 0.030079	 0.00041	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23396	 83099	 0.014042	 0.027801	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81931	 23397	 0.035049	 0.027737	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23398	 83095	 0.000181	 0.014517	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23398	 83095	 0.000181	 0.014517	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83096	 23398	 0.000162	 0.012969	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 0	 -30.0	 30.0;
	81931	 23399	 0.066355	 0.052513	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23399	 83097	 0.027011	 0.021172	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23400	 23401	 0.002386	 0.006407	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83096	 23400	 0.003044	 0.012185	 0.00307	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23400	 83097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23400	 83097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23401	 83098	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23401	 83098	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23402	 23404	 0.004914	 0.012757	 0.0031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23402	 83099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23402	 83099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83098	 23403	 0.081522	 0.16142	 0.00237	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23404	 23411	 0.01234	 0.049391	 0.01669	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83096	 23404	 0.012886	 0.032394	 0.00839	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23405	 23408	 0.008133	 0.021114	 0.00512	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23406	 24012	 0.010979	 0.029016	 0.00679	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81930	 23406	 0.007777	 0.02019	 0.0049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23407	 23408	 0.009074	 0.023981	 0.00561	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23409	 23410	 0.053208	 0.10428	 0.00156	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82866	 23409	 0.053199	 0.13676	 0.00212	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83099	 23410	 0.054008	 0.13736	 0.00217	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23410	 83100	 0.058147	 0.11513	 0.00169	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23411	 83100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23411	 83100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23412	 23415	 0.084372	 0.21691	 0.00336	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23412	 83496	 0.11009	 0.28004	 0.00443	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23413	 23414	 0.019382	 0.085889	 0.00258	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23413	 24861	 0.036431	 0.10449	 0.00161	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81985	 23413	 0.037795	 0.11376	 0.00222	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23414	 23415	 0.040223	 0.14084	 0.0039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81981	 23414	 0.01342	 0.073443	 0.00144	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23415	 23962	 0.03266	 0.18567	 0.00336	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23416	 23417	 0.004885	 0.01291	 0.00302	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23416	 24844	 0.003184	 0.008267	 0.00201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23417	 83101	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23417	 83101	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23418	 23427	 0.009194	 0.023112	 0.00599	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23418	 24846	 0.007001	 0.018503	 0.00433	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23418	 83102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23418	 83102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23419	 23420	 0.095343	 0.075455	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83102	 23419	 0.053075	 0.043686	 0.00089	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23420	 23424	 0.11391	 0.090146	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23420	 24817	 0.085306	 0.10719	 0.00161	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23421	 24221	 0.11686	 0.091605	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23421	 83107	 0.28698	 0.2112	 0.00309	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23422	 24222	 0.006284	 0.016607	 0.00389	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23422	 83103	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23422	 83103	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23423	 23444	 0.039077	 0.092536	 0.00169	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81958	 23423	 0.19043	 0.23646	 0.00515	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83103	 23423	 0.13927	 0.11022	 0.00139	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23424	 23425	 0.081446	 0.05273	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23425	 23443	 0.12354	 0.090898	 0.00133	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23425	 83107	 0.066462	 0.086494	 0.00121	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23426	 23430	 0.070279	 0.055618	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23427	 23428	 0.003599	 0.009046	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23427	 83104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23427	 83104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23428	 83105	 0.00255	 0.008886	 0.00206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23429	 23438	 0.024004	 0.031548	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23429	 83106	 0.071647	 0.06719	 0.00104	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23430	 23431	 0.008837	 0.011246	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23430	 23436	 0.032473	 0.021023	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23431	 83106	 0.009839	 0.022502	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23432	 24828	 0.000973	 0.010619	 0.10427	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23432	 83105	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23433	 23434	 0.031949	 0.025284	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23433	 23440	 0.045274	 0.029311	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83106	 23433	 0.009568	 0.027442	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23434	 23435	 0.017352	 0.011234	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23435	 23436	 0.021714	 0.015975	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23435	 23437	 0.013558	 0.014913	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23436	 23437	 0.006277	 0.010019	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23437	 23438	 0.02186	 0.014152	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23437	 83107	 0.010965	 0.031115	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23438	 83107	 0.009476	 0.02244	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81957	 23439	 0.012051	 0.032353	 0.00733	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23439	 83107	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23439	 83107	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23439	 83109	 0.014318	 0.035994	 0.00933	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23440	 23441	 0.027616	 0.054678	 0.0008	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23441	 23442	 0.077037	 0.056679	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81958	 23441	 0.018221	 0.048293	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23443	 23444	 0.10946	 0.11056	 0.00146	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23443	 23447	 0.10925	 0.086465	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23445	 26773	 0.028398	 0.06063	 0.00137	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23446	 23452	 0.062254	 0.049267	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23447	 23452	 0.048611	 0.040011	 0.00081	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23447	 83110	 0.021987	 0.05652	 0.00087	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23448	 84212	 0.037975	 0.04942	 0.00069	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23449	 26735	 0.003489	 0.009221	 0.00216	 144.0	 182.0	 184.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23449	 83108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23449	 83108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23449	 83109	 0.002674	 0.011042	 0.00261	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23450	 83109	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23451	 26731	 0.006981	 0.019466	 0.00409	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81957	 23451	 0.001576	 0.004394	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83109	 23451	 0.003612	 0.009696	 0.0022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23452	 23453	 0.040023	 0.031673	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83108	 23452	 0.018523	 0.036302	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23453	 26738	 0.025205	 0.019947	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23453	 84209	 0.03473	 0.027485	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23454	 23455	 0.038376	 0.098651	 0.00153	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23455	 23456	 0.032655	 0.09366	 0.00144	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23455	 23457	 0.060458	 0.17158	 0.0027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81947	 23455	 0.10645	 0.27078	 0.00428	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23456	 23457	 0.024913	 0.088999	 0.00177	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23456	 23460	 0.045415	 0.13026	 0.002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23456	 23461	 0.045251	 0.11463	 0.00227	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23458	 23459	 0.038236	 0.097241	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23459	 23460	 0.06081	 0.15633	 0.00242	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23459	 83132	 0.066963	 0.4119	 0.00743	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23461	 23462	 0.047532	 0.10782	 0.00215	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23461	 83112	 0.048455	 0.1125	 0.00167	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23462	 83111	 0.034533	 0.070671	 0.00174	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23463	 23464	 0.004193	 0.039473	 0.01196	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81946	 23463	 0.001517	 0.019082	 0.00591	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23463	 83111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23463	 83111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23464	 23465	 0.005347	 0.02263	 0.00509	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23464	 23466	 0.004958	 0.026695	 0.00733	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23464	 83112	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23464	 83112	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23465	 23466	 0.002795	 0.012455	 0.00338	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23465	 83113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23465	 83113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23465	 83116	 0.013994	 0.15851	 0.06117	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23466	 83114	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23466	 83114	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23467	 83115	 0.13979	 0.27683	 0.00406	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23468	 23950	 0.049292	 0.13037	 0.03054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23468	 83115	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23468	 83115	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23469	 23470	 0.072957	 0.16937	 0.00323	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23469	 23886	 0.073927	 0.18803	 0.00297	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23470	 23471	 0.12902	 0.097756	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23470	 83234	 0.075561	 0.19977	 0.00363	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23471	 23885	 0.052803	 0.13686	 0.00259	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23471	 83234	 0.048876	 0.11658	 0.00261	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23472	 23474	 0.027219	 0.017622	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23472	 23489	 0.009836	 0.017299	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23472	 83123	 0.056704	 0.044875	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23473	 23474	 0.008031	 0.012882	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23473	 23476	 0.006315	 0.012503	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23473	 83121	 0.060038	 0.047514	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23473	 83130	 0.007275	 0.010601	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23474	 23489	 0.009411	 0.018024	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23475	 23497	 0.000178	 0.003153	 0.03303	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23475	 83116	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23476	 83120	 0.005847	 0.015031	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23477	 23478	 0.010808	 0.018207	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23477	 83119	 0.005151	 0.013242	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23478	 23491	 0.007213	 0.01428	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23478	 23513	 0.02107	 0.034997	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23478	 83118	 0.015583	 0.044693	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23478	 83121	 0.05093	 0.036077	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23479	 23480	 0.001714	 0.005972	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23479	 23492	 0.002243	 0.006498	 0.00157	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23480	 23485	 0.003775	 0.015112	 0.00381	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23480	 23495	 0.008888	 0.023489	 0.0055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23480	 83118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23480	 83118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23481	 23482	 0.000875	 0.003438	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23481	 83119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23481	 83119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83116	 23482	 0.000723	 0.006079	 0.0018	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23482	 83120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23482	 83120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23483	 23513	 0.015728	 0.012447	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23484	 23512	 0.002936	 0.008187	 0.00172	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23484	 83121	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23484	 83121	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23485	 23506	 0.005278	 0.017784	 0.00442	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23485	 83122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23485	 83122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83121	 23486	 0.015871	 0.028637	 0.00041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83122	 23486	 0.018729	 0.034824	 0.00082	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23487	 23505	 0.003313	 0.01171	 0.00264	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83116	 23487	 0.003789	 0.019641	 0.0048	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23487	 83123	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23487	 83123	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23487	 83126	 0.007368	 0.039021	 0.00989	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23488	 23503	 0.058655	 0.064514	 0.00086	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83117	 23488	 0.015523	 0.051783	 0.00082	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83117	 23489	 0.004746	 0.019398	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83117	 23490	 0.044759	 0.032931	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83119	 23491	 0.006594	 0.013493	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23492	 83124	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23492	 83124	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23492	 83126	 0.006616	 0.019162	 0.00462	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83124	 23493	 0.006839	 0.022816	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83124	 23494	 0.016133	 0.016295	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23494	 83125	 0.051343	 0.03324	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23495	 83125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23495	 83125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23495	 83126	 0.001966	 0.00787	 0.00198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83117	 23496	 0.00646	 0.025131	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83125	 23496	 0.019499	 0.055926	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23497	 23902	 0.000192	 0.002714	 0.02588	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23497	 83126	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23497	 83126	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83117	 23498	 0.020241	 0.032309	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23499	 23500	 0.043501	 0.10301	 0.00188	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23499	 23900	 0.02255	 0.052353	 0.00078	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83117	 23499	 0.012723	 0.087337	 0.00159	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23499	 83237	 0.025081	 0.083668	 0.00133	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23501	 83127	 0.028558	 0.1111	 0.00185	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23501	 83133	 0.0378	 0.086451	 0.00211	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83116	 23502	 0.002045	 0.029167	 0.00974	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23502	 83127	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23502	 83127	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83127	 23504	 0.05431	 0.12421	 0.00303	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23504	 83129	 0.023953	 0.095034	 0.00271	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23504	 83132	 0.048349	 0.1613	 0.00256	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23505	 23507	 0.00433	 0.013032	 0.00408	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23506	 23508	 0.003387	 0.013561	 0.00342	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23507	 23511	 0.004751	 0.019021	 0.00479	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81937	 23508	 0.016172	 0.13882	 0.03956	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23508	 83128	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23508	 83128	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23509	 23510	 0.01339	 0.044187	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83122	 23509	 0.165	 0.17974	 0.00245	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83128	 23509	 0.052701	 0.051565	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23510	 83225	 0.031419	 0.12223	 0.00204	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23511	 23862	 0.006828	 0.042375	 0.01027	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23511	 83129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23511	 83129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23512	 83130	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23512	 83130	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83117	 23513	 0.005506	 0.0313	 0.00057	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83119	 23513	 0.022035	 0.017438	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83120	 23513	 0.004692	 0.011883	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23514	 23864	 0.005842	 0.05412	 0.02712	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23514	 83131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23514	 83131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23515	 23518	 0.051655	 0.13279	 0.00206	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23515	 23865	 0.074223	 0.21065	 0.00331	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23516	 83132	 0.076372	 0.05619	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23517	 23524	 0.006212	 0.037009	 0.00974	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81937	 23517	 0.009146	 0.1399	 0.04513	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23517	 83132	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23517	 83132	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23518	 23521	 0.053058	 0.13494	 0.00213	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83131	 23519	 0.045926	 0.17868	 0.00298	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83132	 23519	 0.090761	 0.21074	 0.00313	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23521	 23523	 0.034877	 0.096481	 0.00224	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23522	 23523	 0.1412	 0.11175	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82958	 23523	 0.028676	 0.11156	 0.00186	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23523	 83133	 0.052487	 0.099202	 0.0016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23524	 23896	 0.025226	 0.06668	 0.01561	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23524	 83133	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23524	 83133	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23525	 23526	 0.070213	 0.053859	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23526	 83135	 0.039531	 0.059956	 0.00086	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23527	 23619	 0.000495	 0.006781	 0.0691	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23527	 83134	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23528	 23533	 0.004369	 0.015286	 0.00507	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23528	 83136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23528	 83136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23529	 23564	 0.001735	 0.010778	 0.00304	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83134	 23529	 0.000912	 0.008081	 0.00215	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23529	 83137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23529	 83137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23530	 23531	 0.003809	 0.019383	 0.00044	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83136	 23530	 0.005639	 0.027068	 0.00081	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83137	 23530	 0.056236	 0.036408	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23531	 23555	 0.04234	 0.033507	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23531	 23560	 0.008081	 0.021419	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23532	 23535	 0.003517	 0.010186	 0.00246	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23532	 83138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23532	 83138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23533	 23547	 0.004674	 0.015591	 0.00395	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23533	 83139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23533	 83139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23534	 23542	 0.023241	 0.055034	 0.00101	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83138	 23534	 0.010174	 0.057832	 0.00105	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83139	 23534	 0.053581	 0.054118	 0.00072	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23535	 23537	 0.004544	 0.012008	 0.00281	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23536	 83140	 0.11017	 0.081062	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23537	 23543	 0.002192	 0.01843	 0.00546	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82846	 23538	 0.012737	 0.067094	 0.0012	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23538	 83140	 0.011112	 0.029451	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23539	 23541	 0.005474	 0.020806	 0.00582	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23539	 83140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23539	 83140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23540	 23567	 0.042748	 0.097767	 0.00239	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83140	 23540	 0.01595	 0.040562	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23541	 23576	 0.004002	 0.01373	 0.00329	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23541	 23577	 0.004812	 0.012717	 0.00298	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23542	 83141	 0.031551	 0.024969	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23542	 83142	 0.048779	 0.053652	 0.00072	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23543	 23544	 0.001669	 0.005724	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23543	 23549	 0.004877	 0.019528	 0.00492	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23543	 83141	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23543	 83141	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23544	 23545	 0.002502	 0.007598	 0.00166	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23545	 23566	 0.005687	 0.014295	 0.0037	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83139	 23546	 0.070274	 0.050802	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23547	 23549	 0.003949	 0.013819	 0.00458	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23547	 83142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23547	 83142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23548	 23551	 0.036897	 0.029199	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23548	 83143	 0.035916	 0.028423	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23549	 23642	 0.002669	 0.009155	 0.00219	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23549	 23643	 0.002193	 0.007389	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23549	 83143	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23549	 83143	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23550	 23551	 0.026231	 0.027948	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23550	 83144	 0.024811	 0.025059	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83142	 23551	 0.009542	 0.042519	 0.00072	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23551	 83144	 0.022015	 0.039722	 0.00057	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23552	 23557	 0.049352	 0.039057	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23552	 23561	 0.014667	 0.029039	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23552	 83144	 0.01593	 0.025554	 0.00047	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23553	 23641	 0.00316	 0.008484	 0.00192	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23553	 83144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23553	 83144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23554	 83146	 0.028988	 0.022236	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23554	 83148	 0.0149	 0.016389	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23555	 83148	 0.035509	 0.028101	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23556	 23560	 0.013213	 0.033965	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23556	 23561	 0.010486	 0.020761	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23556	 83169	 0.10907	 0.070615	 0.00134	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23557	 23562	 0.022678	 0.017947	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23557	 83145	 0.020794	 0.038086	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23558	 23559	 0.003442	 0.011598	 0.00288	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23558	 23563	 0.002842	 0.007305	 0.00181	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23558	 83145	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23558	 83145	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23558	 83168	 0.004639	 0.011662	 0.00302	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23559	 23564	 0.000632	 0.003361	 0.00078	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23559	 23812	 0.005285	 0.013967	 0.00327	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23559	 83146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23559	 83146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23562	 83170	 0.041694	 0.030141	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23563	 23814	 0.002258	 0.007745	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83134	 23563	 0.005261	 0.027882	 0.00931	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23563	 83147	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23563	 83147	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23564	 83148	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23564	 83148	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23565	 23566	 0.002836	 0.009729	 0.00233	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23565	 23569	 0.002594	 0.008898	 0.00213	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23565	 83149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23565	 83149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23566	 83150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23566	 83150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83150	 23567	 0.008674	 0.023994	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23567	 83152	 0.025642	 0.05077	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23568	 23570	 0.036588	 0.023687	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23568	 23598	 0.010756	 0.02305	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83003	 23568	 0.048063	 0.15262	 0.00268	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23569	 23572	 0.002442	 0.006454	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23569	 23644	 0.00421	 0.011127	 0.0026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23570	 23587	 0.019304	 0.044816	 0.00067	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83149	 23570	 0.087005	 0.068856	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83150	 23570	 0.030809	 0.051382	 0.00075	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23571	 23587	 0.035007	 0.022664	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23571	 83151	 0.02864	 0.022449	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23572	 23589	 0.004703	 0.012209	 0.00296	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23572	 83151	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23572	 83151	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23573	 23575	 0.001448	 0.00406	 0.00105	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23573	 23576	 0.002054	 0.00642	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23574	 23575	 0.003155	 0.00847	 0.00192	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23574	 23578	 0.001541	 0.009249	 0.0028	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23574	 23579	 0.005829	 0.019013	 0.00505	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23574	 23582	 0.003402	 0.011669	 0.0028	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23575	 83152	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23575	 83152	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23577	 23578	 0.003379	 0.009072	 0.00206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23579	 23582	 0.00335	 0.00842	 0.00218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23579	 23595	 0.002201	 0.007703	 0.00255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23579	 83153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23579	 83153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23579	 83156	 0.007177	 0.019268	 0.00437	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23580	 83154	 0.006629	 0.013125	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23580	 83160	 0.038033	 0.058263	 0.00082	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83153	 23581	 0.054442	 0.054989	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23582	 83154	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23582	 83154	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23583	 83157	 0.012483	 0.035803	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23583	 83160	 0.009244	 0.021461	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23584	 23595	 0.001248	 0.004369	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23584	 83155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23584	 83155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23585	 23601	 0.004779	 0.021297	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83155	 23585	 0.003711	 0.016353	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23586	 83156	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23586	 83412	 0.000645	 0.008017	 0.08054	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83151	 23587	 0.03923	 0.028359	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23587	 83158	 0.016101	 0.028759	 0.00042	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23588	 23591	 0.032131	 0.025428	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23588	 23596	 0.046879	 0.037099	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23588	 83159	 0.046644	 0.036914	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23589	 23590	 0.002862	 0.007563	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23589	 83158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23589	 83158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83156	 23590	 0.003563	 0.022113	 0.00536	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23590	 83159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23590	 83159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23591	 23597	 0.030965	 0.020047	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23592	 23594	 0.005665	 0.013414	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83157	 23592	 0.025088	 0.064491	 0.001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83159	 23592	 0.023648	 0.023717	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23593	 23606	 0.012774	 0.025291	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81948	 23593	 0.002864	 0.012298	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23594	 23606	 0.012487	 0.02899	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23595	 83160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23595	 83160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23596	 23597	 0.069779	 0.055223	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23596	 23598	 0.012972	 0.027263	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83155	 23597	 0.003639	 0.016216	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23597	 83161	 0.008516	 0.038105	 0.00078	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23599	 23606	 0.010841	 0.025168	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23599	 83162	 0.018286	 0.022698	 0.00049	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23600	 23604	 0.003491	 0.009736	 0.00204	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23600	 83161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23600	 83161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83161	 23601	 0.005674	 0.020271	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23602	 23605	 0.02664	 0.026907	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23602	 23609	 0.019533	 0.015458	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23602	 83162	 0.010817	 0.021417	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23603	 23605	 0.026057	 0.020621	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23603	 83197	 0.023468	 0.015193	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23604	 83162	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23604	 83162	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23604	 83413	 0.013662	 0.037197	 0.0082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23605	 24614	 0.01611	 0.014436	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23606	 23745	 0.029216	 0.018915	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23607	 23608	 0.007782	 0.029938	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83157	 23607	 0.006499	 0.032873	 0.00057	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23608	 23610	 0.01574	 0.030847	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23608	 24613	 0.021967	 0.039483	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23609	 23610	 0.018729	 0.013539	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23609	 24613	 0.028917	 0.022884	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23610	 24613	 0.018887	 0.014488	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23611	 23616	 0.021856	 0.040031	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23611	 24617	 0.031061	 0.072113	 0.00107	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23611	 83164	 0.029066	 0.053238	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23612	 83163	 0.033477	 0.02463	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23613	 23614	 0.002684	 0.009487	 0.00214	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23613	 23615	 0.004343	 0.011275	 0.00274	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23613	 83163	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23613	 83163	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83156	 23614	 0.002037	 0.01097	 0.00301	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23614	 83164	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23614	 83164	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23615	 83165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23615	 83165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83163	 23616	 0.048139	 0.038096	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83165	 23616	 0.005811	 0.010804	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23617	 23619	 0.000111	 0.001773	 0.01775	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23617	 23768	 0.000864	 0.009626	 0.09079	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83074	 23617	 0.000714	 0.007837	 0.07613	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23617	 83166	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83167	 23618	 0.014656	 0.029018	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23618	 83169	 0.010251	 0.020296	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23619	 83168	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83168	 23620	 0.002289	 0.009162	 0.00231	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23620	 83170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23620	 83170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23621	 83171	 0.010064	 0.017976	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23621	 83175	 0.019755	 0.015633	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23622	 83171	 0.013607	 0.012277	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23623	 23660	 0.001298	 0.004701	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23623	 23838	 0.002993	 0.007911	 0.00185	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83166	 23623	 0.001828	 0.009338	 0.00235	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23623	 83171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23623	 83171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23624	 23629	 0.00242	 0.008155	 0.00203	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23624	 23654	 0.003182	 0.008411	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23624	 83172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23624	 83172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83170	 23625	 0.006911	 0.017574	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23625	 83173	 0.019634	 0.01616	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23626	 23628	 0.006946	 0.009039	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83170	 23626	 0.013518	 0.026492	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23627	 23628	 0.016644	 0.013171	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23627	 83177	 0.044653	 0.035338	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23628	 83173	 0.026816	 0.021221	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23629	 23631	 0.001555	 0.00542	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83168	 23629	 0.001456	 0.011351	 0.00339	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23629	 83173	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23629	 83173	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83167	 23630	 0.012174	 0.021409	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83173	 23630	 0.029872	 0.021595	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23631	 23635	 0.000866	 0.003136	 0.00067	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83172	 23632	 0.018504	 0.013107	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23632	 83174	 0.032408	 0.025647	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23633	 23634	 0.016497	 0.013055	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23633	 23639	 0.011054	 0.012157	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83172	 23633	 0.00987	 0.019343	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23635	 83174	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23635	 83174	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23636	 23671	 0.00408	 0.013997	 0.00335	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83166	 23636	 0.002374	 0.01069	 0.00284	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23636	 83175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23636	 83175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83174	 23637	 0.001868	 0.010619	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23637	 83176	 0.00374	 0.009912	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23638	 23639	 0.019346	 0.014234	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23638	 83176	 0.024432	 0.017975	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23639	 23679	 0.017321	 0.019051	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23639	 83182	 0.009903	 0.019607	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23640	 23661	 0.001286	 0.003399	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23640	 83176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23640	 83176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23641	 83177	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23641	 83177	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23642	 23658	 0.005215	 0.013783	 0.00323	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23643	 23644	 0.001484	 0.005001	 0.00124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23643	 83178	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23643	 83178	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23644	 23645	 0.00214	 0.0062	 0.0015	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23644	 83179	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23644	 83179	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23645	 23658	 0.004053	 0.010522	 0.00255	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23645	 83180	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23645	 83180	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83144	 23646	 0.030664	 0.046973	 0.00066	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83172	 23646	 0.055897	 0.044236	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83177	 23646	 0.011395	 0.018679	 0.00033	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23646	 83183	 0.03099	 0.024525	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23647	 83181	 0.035249	 0.02282	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23647	 83183	 0.024595	 0.019464	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23648	 23659	 0.022881	 0.018108	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23648	 83183	 0.01425	 0.015674	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23649	 23658	 0.002487	 0.006573	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23649	 83181	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23649	 83181	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23650	 23651	 0.021617	 0.017107	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23650	 23657	 0.0349	 0.027619	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83180	 23650	 0.021001	 0.022427	 0.00047	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83181	 23651	 0.028172	 0.018239	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23652	 23653	 0.006835	 0.013532	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23652	 23683	 0.012587	 0.019639	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83181	 23653	 0.005176	 0.017082	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23654	 23658	 0.003086	 0.007933	 0.00196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23654	 83182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23654	 83182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23655	 23656	 0.02758	 0.021827	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23656	 23680	 0.037944	 0.029742	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83181	 23656	 0.040569	 0.033392	 0.00068	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83179	 23657	 0.011336	 0.022216	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83168	 23658	 0.007454	 0.024868	 0.00631	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23658	 83183	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23658	 83183	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83182	 23659	 0.016534	 0.016582	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83183	 23659	 0.019959	 0.020159	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23660	 23664	 0.001201	 0.004186	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23661	 83184	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23661	 83184	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23662	 23666	 0.007351	 0.021084	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23662	 23684	 0.019474	 0.029832	 0.00042	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83184	 23662	 0.008023	 0.016419	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83175	 23663	 0.022977	 0.038165	 0.00081	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23663	 83187	 0.033857	 0.026539	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23664	 23665	 0.002138	 0.007556	 0.0017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23665	 23847	 0.001724	 0.004809	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23665	 83185	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23665	 83185	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23666	 23668	 0.016009	 0.031696	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23667	 23668	 0.021923	 0.01735	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23667	 23691	 0.025377	 0.020083	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23668	 23669	 0.023135	 0.018308	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23668	 23704	 0.018186	 0.035642	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23669	 83186	 0.010436	 0.015207	 0.00034	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23670	 23671	 0.002708	 0.009289	 0.00223	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23670	 23673	 0.001319	 0.004443	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23670	 83186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23670	 83186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23671	 83187	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23671	 83187	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23672	 23676	 0.023689	 0.015336	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83186	 23672	 0.030353	 0.021942	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23673	 23702	 0.001435	 0.004156	 0.001	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23674	 23675	 0.005249	 0.012429	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23674	 23676	 0.012372	 0.017242	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23674	 23678	 0.002456	 0.011991	 0.00025	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23674	 83224	 0.010068	 0.019933	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23675	 83223	 0.003704	 0.007579	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83185	 23676	 0.007354	 0.024534	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23677	 23678	 0.011729	 0.009282	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23678	 23703	 0.004721	 0.011179	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23679	 23681	 0.018861	 0.01429	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23680	 23685	 0.018929	 0.01498	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23681	 23684	 0.00474	 0.012284	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83182	 23681	 0.009599	 0.02753	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23682	 23683	 0.018115	 0.021686	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23682	 23687	 0.030805	 0.023339	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23682	 23689	 0.048367	 0.038277	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23684	 23687	 0.012805	 0.022519	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83158	 23685	 0.018315	 0.035075	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83158	 23686	 0.008702	 0.015939	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23686	 83188	 0.036819	 0.029138	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23687	 23688	 0.011827	 0.017937	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23688	 23700	 0.037226	 0.02946	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23689	 23699	 0.018683	 0.035309	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23689	 83190	 0.005827	 0.015403	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23690	 23691	 0.024465	 0.019177	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23690	 23699	 0.009692	 0.016699	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23692	 23700	 0.022151	 0.014341	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23693	 23695	 0.002048	 0.007237	 0.00163	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23693	 23696	 0.000912	 0.00365	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23693	 83188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23693	 83188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23694	 23745	 0.00583	 0.013904	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81948	 23694	 0.005376	 0.01881	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23695	 83189	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23695	 83189	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23696	 23697	 0.001328	 0.004429	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23697	 83190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23697	 83190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23698	 23734	 0.005848	 0.016772	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83189	 23698	 0.005794	 0.015316	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83190	 23698	 0.018655	 0.018659	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23699	 23700	 0.022779	 0.018027	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23699	 23732	 0.01582	 0.031321	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23699	 23733	 0.00885	 0.016209	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23699	 23751	 0.09472	 0.072658	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83190	 23699	 0.003742	 0.019458	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23701	 23703	 0.052897	 0.041862	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23701	 23711	 0.040887	 0.031363	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23702	 23709	 0.001627	 0.004223	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23703	 23794	 0.019191	 0.012424	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23704	 23712	 0.026411	 0.020702	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23705	 23715	 0.021533	 0.021538	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23705	 23716	 0.021369	 0.016911	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23706	 23707	 0.018648	 0.014758	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23706	 23711	 0.034606	 0.027387	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23706	 23712	 0.021539	 0.013945	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23706	 23713	 0.017301	 0.013692	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23706	 23739	 0.013875	 0.02747	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23706	 23743	 0.026746	 0.048074	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23707	 23738	 0.018386	 0.015133	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23708	 23795	 0.024951	 0.018357	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23708	 83191	 0.023136	 0.01831	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23709	 23719	 0.003604	 0.009356	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23709	 83191	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23709	 83191	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23710	 23715	 0.017395	 0.012574	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23711	 23714	 0.02757	 0.021819	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23711	 23715	 0.026666	 0.017264	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23713	 23714	 0.033657	 0.026635	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23713	 23720	 0.023414	 0.015728	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23715	 83192	 0.007504	 0.017422	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23716	 23757	 0.02093	 0.016563	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23717	 23723	 0.022047	 0.016911	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23717	 23759	 0.010364	 0.017459	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23718	 23723	 0.023172	 0.016414	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23719	 23728	 0.005096	 0.011829	 0.0036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23719	 83192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23719	 83192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23720	 83194	 0.008762	 0.017173	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23721	 23728	 0.00248	 0.006374	 0.00158	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23721	 83193	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23721	 83193	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23722	 23727	 0.022733	 0.017819	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83192	 23722	 0.025663	 0.020116	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83193	 23722	 0.030777	 0.024357	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23723	 23725	 0.027955	 0.022123	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23723	 23726	 0.029565	 0.023397	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23724	 23725	 0.013972	 0.010952	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23725	 23726	 0.021703	 0.017176	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23725	 24480	 0.021091	 0.016691	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23725	 83198	 0.01381	 0.027343	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23726	 24487	 0.006427	 0.010258	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23727	 24488	 0.017462	 0.013819	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23728	 24568	 0.001035	 0.003487	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23728	 83194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23728	 83194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23729	 23730	 0.008667	 0.013145	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23729	 23741	 0.03578	 0.028315	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23730	 23750	 0.008829	 0.016416	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23730	 83195	 0.030339	 0.02401	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23731	 23749	 0.00891	 0.008999	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23731	 23753	 0.009337	 0.009365	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23731	 83197	 0.032069	 0.025379	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23732	 23737	 0.029337	 0.023217	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23733	 23736	 0.013782	 0.018114	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23734	 23735	 0.007373	 0.017118	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23735	 23741	 0.013822	 0.022063	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23736	 23737	 0.023945	 0.018769	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23737	 23738	 0.008781	 0.017386	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23737	 23740	 0.035144	 0.027812	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23737	 23741	 0.047937	 0.037576	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23739	 83196	 0.00787	 0.018268	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23740	 83196	 0.024061	 0.026207	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23741	 83197	 0.041424	 0.054444	 0.00075	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23742	 23744	 0.002072	 0.006206	 0.0014	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23742	 83195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23742	 83195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23742	 83413	 0.003673	 0.020157	 0.00533	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23743	 24582	 0.019497	 0.021444	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83195	 23743	 0.00997	 0.01954	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23743	 83196	 0.021145	 0.016575	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23744	 83196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23744	 83196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23745	 23747	 0.008148	 0.021116	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23746	 23747	 0.008878	 0.01417	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83189	 23746	 0.006466	 0.013233	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23747	 23751	 0.007043	 0.020201	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23747	 23752	 0.01213	 0.021886	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23748	 83197	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23748	 83197	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23748	 83413	 0.007724	 0.025768	 0.00654	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23749	 23750	 0.018975	 0.015016	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23750	 24585	 0.008771	 0.016066	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23750	 83404	 0.018592	 0.029676	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83197	 23751	 0.058031	 0.038981	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23752	 23753	 0.011656	 0.017283	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23754	 23758	 0.005654	 0.011884	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23754	 23796	 0.004214	 0.010832	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23755	 23756	 0.002531	 0.008442	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23755	 23795	 0.001825	 0.008133	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23756	 23757	 0.002889	 0.007893	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23757	 23759	 0.006304	 0.012482	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23758	 23759	 0.011707	 0.021124	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23759	 23766	 0.011501	 0.008147	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23759	 23810	 0.015962	 0.012632	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23759	 83198	 0.050157	 0.036902	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23760	 23761	 0.01148	 0.008299	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23760	 23762	 0.016592	 0.013131	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23760	 23809	 0.005712	 0.01326	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23760	 83198	 0.031919	 0.023074	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23763	 83198	 0.016925	 0.020261	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23764	 24474	 0.018291	 0.014337	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23764	 83198	 0.007146	 0.011464	 0.00021	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23765	 83198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23765	 83198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23765	 83400	 0.009558	 0.028768	 0.009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23767	 23771	 0.004058	 0.010319	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23767	 24472	 0.017656	 0.01299	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23767	 24473	 0.004961	 0.009723	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83198	 23767	 0.017758	 0.014054	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23768	 23774	 6.1e-05	 0.000706	 0.00619	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23768	 83199	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83200	 23769	 0.014614	 0.011565	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23770	 23772	 0.015233	 0.015386	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23770	 23808	 0.008566	 0.007676	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23771	 23772	 0.003959	 0.011234	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23772	 83202	 0.002555	 0.016632	 0.00034	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23773	 83202	 0.011467	 0.008988	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23774	 24396	 0.000485	 0.005324	 0.05172	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23774	 83201	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23774	 83412	 0.00085	 0.009812	 0.08603	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23775	 23776	 0.011952	 0.009168	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23776	 23777	 0.004919	 0.012209	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83202	 23777	 0.006231	 0.017238	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23777	 83203	 0.004611	 0.010593	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83201	 23778	 0.000341	 0.002434	 0.00075	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23778	 83203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23778	 83203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23779	 23780	 0.003306	 0.007498	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23779	 83222	 0.003065	 0.01095	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23780	 23781	 0.003318	 0.014786	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23780	 23782	 0.002376	 0.006297	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23780	 23790	 0.00556	 0.015946	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23781	 23791	 0.016328	 0.012922	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23781	 83221	 0.002672	 0.017392	 0.00035	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23782	 23792	 0.003474	 0.008835	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23783	 23784	 0.00141	 0.004836	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23783	 23785	 0.001635	 0.004244	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23783	 83204	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23783	 83204	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23784	 23854	 0.001788	 0.008202	 0.0021	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23784	 24451	 0.013202	 0.03824	 0.00922	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23784	 83205	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23784	 83205	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23785	 83206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23785	 83206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23786	 23788	 0.021383	 0.020052	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83066	 23786	 0.0061	 0.01493	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23787	 23788	 0.02208	 0.017307	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23787	 23803	 0.01588	 0.010281	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83206	 23787	 0.010095	 0.019784	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23788	 23803	 0.01625	 0.01286	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23788	 23807	 0.012778	 0.010112	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83200	 23788	 0.029269	 0.018949	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23788	 83207	 0.013176	 0.013308	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83199	 23789	 0.00276	 0.007409	 0.00168	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23789	 83207	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23789	 83207	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23790	 23793	 0.004472	 0.011589	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23790	 23795	 0.014366	 0.026313	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23790	 83224	 0.002116	 0.014354	 0.00027	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23792	 23797	 0.006581	 0.013029	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23793	 23795	 0.008587	 0.013774	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23794	 23795	 0.016591	 0.012206	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23795	 23796	 0.02478	 0.018232	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83200	 23795	 0.041968	 0.083094	 0.00122	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23796	 23797	 0.005536	 0.011328	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23797	 23798	 0.006642	 0.015417	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23797	 23800	 0.00821	 0.01281	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23798	 23799	 0.006686	 0.013238	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83205	 23798	 0.00222	 0.012222	 0.00028	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23799	 23802	 0.012419	 0.009828	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23800	 23801	 0.012328	 0.008733	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23801	 23805	 0.018589	 0.014711	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23802	 23806	 0.023814	 0.018667	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23804	 23806	 0.011912	 0.009138	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23805	 23806	 0.004665	 0.013379	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23805	 23809	 0.004685	 0.011914	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23806	 23808	 0.008755	 0.010868	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83200	 23806	 0.002165	 0.012969	 0.00031	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83200	 23807	 0.018133	 0.012845	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23811	 23812	 0.004969	 0.013528	 0.00298	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23811	 83208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23811	 83208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23813	 23820	 0.009518	 0.025226	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83208	 23813	 0.009987	 0.038854	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23813	 83209	 0.072044	 0.052081	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23814	 23815	 0.001969	 0.00696	 0.00157	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23815	 23821	 0.001352	 0.004409	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23816	 23817	 0.010471	 0.011517	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23816	 83211	 0.009427	 0.016838	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23817	 23818	 0.024534	 0.019416	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23817	 23820	 0.027784	 0.019681	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23818	 23819	 0.010715	 0.019138	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23818	 23820	 0.031032	 0.024558	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83169	 23818	 0.054415	 0.10774	 0.00158	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23818	 83212	 0.033939	 0.024534	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83030	 23819	 0.009171	 0.016128	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23821	 23822	 0.001237	 0.004311	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23822	 23827	 0.001538	 0.005275	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23822	 83209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23822	 83209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23823	 23824	 0.023743	 0.018611	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83169	 23824	 0.013407	 0.034096	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23824	 83210	 0.013551	 0.022599	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23825	 23836	 0.001403	 0.005938	 0.00134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83168	 23825	 0.002086	 0.010665	 0.00291	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23825	 83210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23825	 83210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83210	 23826	 0.01103	 0.017606	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23826	 83211	 0.016497	 0.021681	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23827	 83211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23827	 83211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23828	 23843	 0.067717	 0.055738	 0.00113	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83211	 23828	 0.004871	 0.017042	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23828	 83212	 0.00864	 0.017107	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23829	 23833	 0.00213	 0.00563	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23829	 83212	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23829	 83212	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83212	 23830	 0.02323	 0.018209	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23831	 83213	 0.023384	 0.018506	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23832	 23840	 0.016921	 0.025918	 0.00045	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23832	 83213	 0.026398	 0.020891	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23833	 83213	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23833	 83213	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23834	 23839	 0.024255	 0.019195	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83211	 23835	 0.013353	 0.022269	 0.00032	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23835	 83215	 0.041365	 0.02678	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23836	 23838	 0.000957	 0.003639	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23836	 83214	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23836	 83214	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23837	 23838	 0.001274	 0.003366	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23837	 23844	 0.00163	 0.003783	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23838	 83215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23838	 83215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23839	 23843	 0.037427	 0.02423	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83213	 23839	 0.044555	 0.028845	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83215	 23839	 0.016667	 0.033	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23840	 23841	 0.023269	 0.016821	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23840	 23859	 0.013867	 0.027456	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23841	 23842	 0.009785	 0.017655	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23842	 23843	 0.022382	 0.017713	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23843	 83216	 0.0366	 0.028965	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23843	 83218	 0.057374	 0.045405	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23844	 23845	 0.001759	 0.004421	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23845	 23848	 0.002485	 0.00645	 0.00157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23845	 83216	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23845	 83216	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83185	 23846	 0.026998	 0.021366	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23847	 23857	 0.001118	 0.003767	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23847	 83217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23847	 83217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23848	 23849	 0.001231	 0.004015	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23848	 83218	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23848	 83218	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23849	 23850	 0.00103	 0.004046	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23850	 23852	 0.001376	 0.004487	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23850	 83219	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23850	 83219	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23851	 23859	 0.023233	 0.015041	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83219	 23851	 0.018688	 0.020555	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23851	 83220	 0.023614	 0.015288	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23852	 23860	 0.00045	 0.00374	 0.00113	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23852	 83220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23852	 83220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23853	 23860	 0.001228	 0.004211	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23853	 23861	 0.000564	 0.003868	 0.00113	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23854	 23856	 0.001159	 0.007343	 0.00199	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23854	 23861	 0.000636	 0.005109	 0.00144	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83075	 23854	 0.001667	 0.012615	 0.0062	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23854	 83221	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23854	 83221	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83221	 23855	 0.023582	 0.018484	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23856	 23858	 0.001476	 0.004813	 0.00128	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23856	 83222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23856	 83222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23857	 23858	 0.001412	 0.003629	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23857	 83223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23857	 83223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23858	 83224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23858	 83224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83040	 23860	 0.00035	 0.003774	 0.00108	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81937	 23862	 0.009186	 0.064694	 0.0368	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23862	 83225	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23862	 83225	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23863	 23866	 0.003359	 0.023055	 0.00672	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23863	 83226	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23863	 83226	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81937	 23864	 0.004741	 0.048515	 0.02884	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23864	 83227	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23864	 83227	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83225	 23865	 0.031575	 0.1407	 0.00239	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81937	 23866	 0.004514	 0.034334	 0.01079	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23867	 23868	 0.045556	 0.13067	 0.00201	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83225	 23867	 0.051728	 0.10242	 0.0015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83226	 23868	 0.029177	 0.077333	 0.00196	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23869	 23870	 0.2334	 0.23351	 0.00315	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23869	 23887	 0.066167	 0.1701	 0.00263	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23869	 23889	 0.074234	 0.16979	 0.00415	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23870	 23874	 0.073442	 0.21067	 0.00324	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23870	 23956	 0.033955	 0.093931	 0.00218	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23870	 83228	 0.027859	 0.12275	 0.00213	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23870	 83234	 0.2288	 0.52396	 0.01281	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23871	 23872	 0.14813	 0.11724	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23872	 23875	 0.15013	 0.11882	 0.0015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23872	 83228	 0.078516	 0.15037	 0.00237	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81951	 23873	 0.068282	 0.19619	 0.04838	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23873	 83228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23873	 83228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83228	 23874	 0.036539	 0.093929	 0.00145	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23876	 83230	 0.13423	 0.18301	 0.00406	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81959	 23877	 0.005278	 0.061252	 0.5414	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23877	 83229	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83230	 23878	 0.12987	 0.27838	 0.00488	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23879	 23882	 0.049387	 0.14166	 0.00218	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23880	 24863	 0.013888	 0.046797	 0.01163	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23880	 83231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23880	 83231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83231	 23881	 0.053314	 0.13706	 0.00212	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83231	 23882	 0.041181	 0.18352	 0.00312	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23885	 23888	 0.047712	 0.12134	 0.00192	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23886	 23887	 0.27971	 0.21461	 0.00288	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23887	 23888	 0.080555	 0.18701	 0.00356	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23888	 23889	 0.11284	 0.11086	 0.00187	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23890	 83232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23890	 83232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23892	 83233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23892	 83233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23893	 83234	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23893	 83234	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23894	 23895	 0.0869	 0.05626	 0.00107	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83233	 23894	 0.034076	 0.069734	 0.00172	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23896	 23897	 0.003788	 0.021531	 0.00623	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23897	 23936	 0.000468	 0.006677	 0.00223	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23897	 23941	 0.004545	 0.029717	 0.00756	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23897	 83235	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23897	 83235	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23898	 23899	 0.000943	 0.014096	 0.00417	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23898	 23936	 0.001712	 0.021539	 0.00667	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23898	 83236	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23898	 83236	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23899	 23905	 0.000563	 0.003905	 0.00229	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23899	 83237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23899	 83237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23900	 83239	 0.018153	 0.042144	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23901	 83238	 0.010677	 0.027447	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23902	 83238	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23902	 83238	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23903	 23905	 0.001553	 0.006216	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81969	 23903	 0.000417	 0.003093	 0.00158	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23903	 83240	 0.001098	 0.008025	 0.00237	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81970	 23904	 0.00755	 0.024914	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83126	 23905	 0.00128	 0.014087	 0.00837	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23905	 83239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23905	 83239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23905	 83240	 0.001733	 0.008187	 0.00262	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23906	 83240	 0.001226	 0.007606	 0.00184	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23906	 83241	 0.001974	 0.010516	 0.00295	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23907	 23910	 0.000152	 0.002817	 0.02706	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23907	 83240	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23907	 83240	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23908	 23909	 0.039317	 0.06023	 0.00085	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83236	 23908	 0.034868	 0.069037	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23909	 83242	 0.017233	 0.066027	 0.00187	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23909	 83246	 0.030948	 0.14351	 0.00298	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23910	 83241	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23911	 83250	 0.010353	 0.052371	 0.00091	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82975	 23912	 0.01542	 0.055086	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23912	 83243	 0.005554	 0.034143	 0.00062	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23913	 23916	 0.000216	 0.002661	 0.00086	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23914	 23916	 0.000377	 0.005639	 0.0019	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23914	 23917	 0.001213	 0.005007	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23914	 23921	 0.002712	 0.025917	 0.00854	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23914	 83243	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23914	 83243	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23915	 23916	 0.000498	 0.005282	 0.00157	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23915	 23942	 0.000711	 0.008893	 0.00389	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23917	 23919	 0.001225	 0.006259	 0.00157	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23918	 23919	 0.001002	 0.00489	 0.00135	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23918	 23921	 0.002672	 0.019531	 0.00576	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23918	 83244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23918	 83244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23919	 83245	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23919	 83245	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23920	 23937	 0.014294	 0.05842	 0.00118	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23920	 83249	 0.009754	 0.043202	 0.00098	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81943	 23921	 0.000662	 0.007285	 0.00433	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23921	 83246	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23921	 83246	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23922	 23940	 0.001807	 0.026312	 0.00842	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81939	 23922	 0.001608	 0.016455	 0.00978	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23922	 83251	 0.005649	 0.028384	 0.00739	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23923	 23926	 0.013883	 0.055652	 0.00143	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81940	 23923	 0.005522	 0.027934	 0.00049	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23924	 23926	 0.036371	 0.025764	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23925	 23926	 0.00599	 0.026692	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23925	 83252	 0.008914	 0.031189	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23927	 23928	 0.031261	 0.023	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82726	 23927	 0.051167	 0.040107	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23928	 83254	 0.056939	 0.060666	 0.00086	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23929	 23930	 0.012631	 0.032736	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23929	 83252	 0.003005	 0.015629	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23930	 83247	 0.03895	 0.035142	 0.00059	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23931	 83254	 0.038436	 0.030418	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23932	 23934	 0.000366	 0.004148	 0.03776	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23932	 23944	 0.000269	 0.003343	 0.03097	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23932	 83247	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23932	 83247	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83244	 23933	 0.042714	 0.04127	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23934	 83248	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23934	 83248	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81943	 23935	 0.003858	 0.017994	 0.00446	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23935	 83251	 0.00148	 0.011659	 0.00341	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23937	 23938	 0.050942	 0.039931	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83243	 23937	 0.01335	 0.03829	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83245	 23937	 0.049109	 0.032988	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83244	 23938	 0.037419	 0.029613	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83235	 23939	 0.030831	 0.079905	 0.00151	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23939	 83249	 0.016147	 0.037097	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23940	 23941	 0.001303	 0.012511	 0.00364	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23940	 83249	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23940	 83249	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23941	 23942	 0.00076	 0.009561	 0.00296	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23941	 83250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23941	 83250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23943	 23947	 0.001758	 0.004237	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23944	 83251	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23947	 83253	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23947	 83253	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82740	 23948	 0.001401	 0.011256	 0.00316	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83241	 23948	 0.007785	 0.054017	 0.01542	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23948	 83254	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23948	 83254	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23950	 83255	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23950	 83255	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23951	 23952	 0.073755	 0.13715	 0.00321	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83255	 23951	 0.076788	 0.17829	 0.00265	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23953	 23954	 0.24066	 0.15584	 0.00297	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83255	 23953	 0.21069	 0.15504	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23955	 23956	 0.026379	 0.084945	 0.00145	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23955	 23957	 0.030064	 0.092328	 0.00173	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23957	 23961	 0.037576	 0.080525	 0.00141	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82809	 23957	 0.050845	 0.156	 0.00423	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23958	 23959	 0.12443	 0.09848	 0.00124	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23958	 23961	 0.028446	 0.087357	 0.00164	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82809	 23958	 0.029273	 0.10458	 0.00208	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23959	 23960	 0.08307	 0.065115	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23960	 23964	 0.18721	 0.14676	 0.00188	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23961	 23963	 0.071358	 0.18496	 0.0035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23962	 23963	 0.082419	 0.16869	 0.00415	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23962	 23964	 0.091933	 0.075672	 0.00153	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23965	 23983	 0.000124	 0.002176	 0.02328	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23965	 23996	 0.000137	 0.001535	 0.01434	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23965	 23999	 0.000313	 0.005381	 0.05313	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23965	 83256	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83257	 23966	 0.013152	 0.010409	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23967	 23969	 0.000595	 0.003277	 0.00077	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23967	 23980	 0.000807	 0.004807	 0.00126	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83256	 23967	 0.002005	 0.005298	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23968	 23972	 0.000307	 0.004436	 0.00141	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23968	 23975	 0.000381	 0.005189	 0.00186	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23968	 23979	 0.000458	 0.003676	 0.00103	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23968	 83258	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23968	 83258	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23969	 23971	 0.000793	 0.003475	 0.0012	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23969	 83259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23969	 83259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83259	 23970	 0.00478	 0.012288	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23970	 83274	 0.008094	 0.023215	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23971	 23972	 0.001505	 0.00468	 0.00098	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23971	 83273	 0.000848	 0.004704	 0.00143	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23972	 24001	 0.000617	 0.006758	 0.00187	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23972	 83260	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23972	 83260	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23973	 23974	 0.002972	 0.020403	 0.00037	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23973	 24005	 0.092115	 0.070659	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83260	 23973	 0.004981	 0.016617	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23973	 83279	 0.013717	 0.036262	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23974	 23994	 0.003751	 0.018006	 0.00054	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23974	 83261	 0.006948	 0.014218	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23975	 23976	 0.000181	 0.002562	 0.00085	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23975	 83261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23975	 83261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23976	 23992	 0.000327	 0.002363	 0.00127	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23977	 23978	 0.00022	 0.002333	 0.00069	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23977	 83264	 0.00028	 0.002876	 0.00082	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23978	 23979	 0.000234	 0.001903	 0.00061	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23978	 23980	 0.000581	 0.003336	 0.00094	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23978	 23982	 0.000644	 0.003422	 0.00079	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23980	 83262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23980	 83262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83259	 23981	 0.010251	 0.027098	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23981	 83263	 0.005292	 0.012532	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23982	 83263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23982	 83263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23982	 83264	 0.000539	 0.003938	 0.00101	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23983	 23990	 4.5e-05	 0.000447	 0.00766	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23983	 23990	 4.5e-05	 0.000447	 0.00766	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23983	 23997	 0.000142	 0.002494	 0.04141	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23983	 83264	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23983	 83264	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23984	 23986	 0.00025	 0.002521	 0.04149	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23984	 23986	 0.00025	 0.002521	 0.04149	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81929	 23984	 0.000144	 0.003506	 0.06047	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83095	 23984	 0.000127	 0.003016	 0.05391	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23984	 83265	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23984	 83265	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23985	 23987	 0.015542	 0.044103	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23985	 83272	 0.041805	 0.075141	 0.00135	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23986	 23991	 9.4e-05	 0.000974	 0.0153	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23986	 23991	 9.4e-05	 0.000974	 0.0153	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23987	 83266	 0.015449	 0.023161	 0.00042	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23987	 83268	 0.009262	 0.027877	 0.00055	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23988	 23993	 0.002332	 0.014922	 0.00502	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23988	 23995	 0.000868	 0.006346	 0.00187	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23988	 83266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23988	 83266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23988	 83267	 0.001893	 0.009513	 0.00248	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83263	 23989	 0.002232	 0.011161	 0.0002	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83266	 23989	 0.003369	 0.014927	 0.00045	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23990	 23991	 6.9e-05	 0.000735	 0.0108	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23990	 23991	 6.9e-05	 0.000735	 0.0108	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23990	 83267	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23991	 83269	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23991	 83269	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23992	 23993	 0.000319	 0.004877	 0.00157	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23992	 83270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23992	 83270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23993	 24008	 0.000744	 0.005702	 0.00153	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83269	 23993	 0.000279	 0.004558	 0.00225	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83270	 23994	 0.007353	 0.018902	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23994	 83283	 0.00724	 0.040678	 0.00075	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23995	 83271	 0.001768	 0.008795	 0.00284	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23996	 23997	 0.000287	 0.003308	 0.029	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23996	 83271	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23997	 24002	 8.3e-05	 0.0015	 0.0285	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23997	 83273	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83272	 23998	 0.010505	 0.042935	 0.00087	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83274	 23998	 0.039962	 0.072106	 0.00104	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23998	 83276	 0.041342	 0.081854	 0.0012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23999	 24000	 0.000357	 0.003923	 0.0381	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23999	 83275	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24000	 24002	 0.000426	 0.004745	 0.04474	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24000	 83277	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24001	 83279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24001	 83279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24001	 83280	 0.000548	 0.005937	 0.00186	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24002	 83280	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83279	 24003	 0.083606	 0.056162	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83281	 24004	 0.016512	 0.042445	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24004	 83289	 0.025378	 0.072017	 0.00113	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24006	 24007	 0.00167	 0.010754	 0.00282	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24006	 24008	 0.002615	 0.01625	 0.00459	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24007	 24009	 0.002672	 0.027013	 0.00794	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24007	 24016	 0.003322	 0.023699	 0.00735	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24007	 83282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24007	 83282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24008	 83283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24008	 83283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83265	 24009	 0.001536	 0.01423	 0.00713	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24009	 83284	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24009	 83284	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83282	 24010	 0.037359	 0.073969	 0.00109	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83283	 24010	 0.004638	 0.044907	 0.0009	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83284	 24010	 0.004318	 0.041809	 0.00084	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24011	 24013	 0.006628	 0.026536	 0.00669	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83265	 24011	 0.010508	 0.038051	 0.00816	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24011	 83285	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24011	 83285	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24013	 24014	 0.006545	 0.025726	 0.00673	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24014	 24015	 0.006412	 0.021997	 0.00527	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24015	 24103	 0.011536	 0.039576	 0.00948	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24015	 83286	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24015	 83286	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24016	 24017	 0.003328	 0.022841	 0.00666	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24017	 24116	 0.005266	 0.042748	 0.01361	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24017	 83287	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24017	 83287	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24018	 83289	 0.15587	 0.10092	 0.00192	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24019	 83288	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83277	 24020	 0.001847	 0.016744	 0.00875	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24020	 83290	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24020	 83290	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24021	 24041	 0.001944	 0.006667	 0.0016	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24021	 83291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24021	 83291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24022	 24023	 0.001967	 0.008803	 0.00018	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83291	 24022	 0.002788	 0.015849	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24023	 24024	 0.003417	 0.011275	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24024	 24027	 0.008111	 0.016059	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24025	 24026	 0.015473	 0.010017	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83291	 24025	 0.011704	 0.027716	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24027	 24028	 0.023805	 0.015991	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24027	 24029	 0.013266	 0.01555	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24027	 83292	 0.01077	 0.047993	 0.00082	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24029	 24030	 0.021821	 0.017104	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24029	 24034	 0.021147	 0.038732	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24031	 24032	 0.026875	 0.026881	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24031	 24033	 0.010876	 0.022256	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24031	 24034	 0.008433	 0.027155	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24032	 24036	 0.018803	 0.047818	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24032	 24040	 0.03331	 0.031237	 0.00048	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24033	 24035	 0.022982	 0.063659	 0.00105	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24035	 24093	 0.12425	 0.083466	 0.00147	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81965	 24035	 0.028427	 0.14218	 0.00253	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24036	 24037	 0.013718	 0.039345	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24037	 83299	 0.022357	 0.079866	 0.00159	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24038	 24039	 0.026046	 0.051569	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24038	 24047	 0.080462	 0.082162	 0.00128	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24039	 83292	 0.010581	 0.032461	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24040	 83292	 0.033706	 0.035995	 0.00076	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81964	 24041	 0.009347	 0.057471	 0.01658	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24041	 83292	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24041	 83292	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81971	 24042	 0.007188	 0.017841	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83291	 24042	 0.017501	 0.040207	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24042	 83293	 0.027544	 0.040319	 0.00062	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81971	 24043	 0.015536	 0.02591	 0.00038	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24044	 24045	 0.00236	 0.00945	 0.00238	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24044	 83293	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24044	 83293	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24044	 83294	 0.014661	 0.038063	 0.00924	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24045	 24049	 0.002527	 0.010116	 0.00255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24046	 24047	 0.020149	 0.042349	 0.00077	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24046	 83295	 0.020239	 0.046987	 0.0007	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83293	 24047	 0.051098	 0.08608	 0.00123	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24048	 24057	 0.000294	 0.003618	 0.05796	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24048	 83294	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24048	 83294	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81936	 24049	 0.003442	 0.013778	 0.00347	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24049	 83295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24049	 83295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24050	 24052	 0.099495	 0.10944	 0.00146	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81963	 24050	 0.002481	 0.006576	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83295	 24050	 0.072534	 0.073263	 0.00097	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24050	 83296	 0.042363	 0.064251	 0.00092	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24051	 24053	 0.008389	 0.024734	 0.00575	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81962	 24051	 0.004981	 0.017088	 0.00409	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24051	 83296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24051	 83296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83296	 24052	 0.050607	 0.050756	 0.00082	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24052	 83297	 0.025436	 0.059053	 0.00088	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24053	 83297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24053	 83297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24054	 24058	 0.034698	 0.048357	 0.00083	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83297	 24054	 0.008542	 0.038775	 0.00084	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83297	 24055	 0.091811	 0.07266	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83297	 24056	 0.038102	 0.038906	 0.00061	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24057	 83298	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24057	 83298	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83298	 24058	 0.024433	 0.032112	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24059	 24060	 0.00297	 0.011891	 0.003	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83294	 24059	 0.005271	 0.020715	 0.00542	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83018	 24060	 0.003961	 0.014343	 0.00308	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81964	 24061	 0.010793	 0.066371	 0.01915	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83018	 24061	 0.003685	 0.020219	 0.00534	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81964	 24062	 0.003713	 0.020376	 0.00539	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24062	 83299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24062	 83299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83299	 24063	 0.14172	 0.11216	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24064	 24068	 0.15786	 0.12494	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24064	 24098	 0.10521	 0.1595	 0.00332	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81965	 24065	 0.059699	 0.047245	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24066	 24067	 0.011183	 0.025576	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24066	 24068	 0.02932	 0.096758	 0.00157	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82992	 24067	 0.18512	 0.14652	 0.00184	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82993	 24067	 0.063116	 0.1237	 0.00185	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83299	 24068	 0.029183	 0.077351	 0.00196	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81965	 24069	 0.073309	 0.21028	 0.00323	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83020	 24069	 0.050175	 0.13004	 0.00246	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83299	 24069	 0.02713	 0.1324	 0.00229	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24070	 24073	 0.043424	 0.034365	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24070	 24078	 0.087307	 0.068437	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24070	 83300	 0.013981	 0.062297	 0.00106	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24071	 83300	 0.011959	 0.023678	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24072	 24081	 0.003549	 0.012912	 0.00395	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24072	 83300	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24072	 83300	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24072	 83303	 0.006746	 0.018367	 0.00405	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24074	 24077	 0.01522	 0.027356	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24074	 83301	 0.00636	 0.021217	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24075	 24076	 0.002291	 0.007641	 0.00194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24075	 83301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24075	 83301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24076	 83302	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24076	 83302	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24076	 83305	 0.000671	 0.008443	 0.00262	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83302	 24077	 0.011373	 0.029237	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82940	 24078	 0.12629	 0.10395	 0.00211	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24079	 24083	 0.053468	 0.10586	 0.00155	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82940	 24079	 0.046314	 0.14914	 0.00254	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83300	 24080	 0.026109	 0.080181	 0.0015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24080	 83304	 0.098732	 0.09876	 0.00133	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24082	 24085	 0.000391	 0.004288	 0.04166	 736.0	 772.8	 809.6	 0.0	 0.0	 0	 -30.0	 30.0;
	24082	 83303	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 0	 -30.0	 30.0;
	24082	 83303	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 0	 -30.0	 30.0;
	24083	 24086	 0.13702	 0.14926	 0.00203	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24084	 83304	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24084	 83304	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24085	 83305	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24085	 83305	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83302	 24086	 0.019311	 0.059242	 0.0016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24087	 24090	 0.00831	 0.038127	 0.00977	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24088	 24089	 0.20946	 0.15413	 0.00225	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81974	 24088	 0.045661	 0.097488	 0.0022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24088	 83306	 0.12819	 0.25385	 0.00373	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81964	 24090	 0.040493	 0.11297	 0.02373	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24090	 83306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24090	 83306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24091	 24092	 0.049909	 0.11586	 0.00221	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83306	 24091	 0.034345	 0.11457	 0.00182	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24092	 24094	 0.037708	 0.07466	 0.0011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81965	 24094	 0.11762	 0.16035	 0.00356	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24095	 24098	 0.089602	 0.19204	 0.00336	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82883	 24095	 0.087261	 0.35679	 0.00722	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83306	 24095	 0.049654	 0.11408	 0.00173	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24096	 83307	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24096	 83307	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83307	 24097	 0.10062	 0.15262	 0.00219	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81965	 24098	 0.24356	 0.19279	 0.00243	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82725	 24099	 0.033238	 0.11874	 0.00236	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83017	 24099	 0.5956	 0.49122	 0.00995	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24100	 83308	 0.28624	 0.22443	 0.00288	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24101	 83308	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24101	 83308	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24102	 83309	 0.063589	 0.16482	 0.00312	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24103	 24104	 0.002452	 0.018652	 0.00586	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81946	 24104	 0.008507	 0.12039	 0.03992	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24104	 83309	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24104	 83309	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24105	 24106	 0.010083	 0.018193	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24105	 24107	 0.005137	 0.010556	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24106	 24107	 0.005009	 0.01025	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24106	 83312	 0.05251	 0.13919	 0.00353	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24107	 24108	 0.009288	 0.01549	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24107	 24109	 0.005107	 0.012988	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83309	 24107	 0.005579	 0.040307	 0.00076	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24108	 24109	 0.026796	 0.021004	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24109	 83311	 0.009506	 0.024636	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24110	 24117	 0.003164	 0.02195	 0.00626	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24110	 83310	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24110	 83310	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83310	 24111	 0.037626	 0.10792	 0.00166	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24111	 83311	 0.042436	 0.10909	 0.00169	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24112	 24113	 0.043704	 0.10145	 0.00193	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24112	 24114	 0.038388	 0.1101	 0.00169	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83309	 24112	 0.062623	 0.113	 0.00163	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24113	 24114	 0.030018	 0.086096	 0.00132	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82807	 24113	 0.015391	 0.075019	 0.00141	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83005	 24114	 0.055146	 0.1884	 0.0041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24114	 83311	 0.20464	 0.20673	 0.00274	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24115	 24116	 0.001443	 0.012293	 0.00307	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24115	 24117	 0.003309	 0.023935	 0.01288	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24115	 83311	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24115	 83311	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24117	 83312	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24117	 83312	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83312	 24118	 0.01711	 0.043513	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24119	 24122	 0.15909	 0.12591	 0.00159	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24120	 83313	 0.12441	 0.16353	 0.00224	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24121	 24125	 0.002772	 0.029373	 0.00872	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24121	 83313	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24121	 83313	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24122	 24123	 0.14732	 0.11549	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24123	 24129	 0.041943	 0.10782	 0.00167	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24123	 83314	 0.044285	 0.14774	 0.00234	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24124	 24125	 0.008837	 0.023354	 0.00547	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81951	 24124	 0.01584	 0.095834	 0.02447	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24124	 83314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24124	 83314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24125	 24128	 0.002251	 0.025732	 0.00785	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83276	 24126	 0.14124	 0.10211	 0.00155	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24127	 24131	 0.1768	 0.13993	 0.00176	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83274	 24127	 0.047427	 0.26654	 0.00494	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24127	 83315	 0.1486	 0.14865	 0.00201	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24128	 24130	 0.001889	 0.021603	 0.00605	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24130	 83315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24130	 83315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24132	 24138	 0.062921	 0.09818	 0.00164	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82733	 24132	 0.020187	 0.13697	 0.00256	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24133	 24141	 0.017679	 0.044445	 0.01152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24133	 83316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24133	 83316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24134	 24135	 0.001828	 0.00637	 0.00148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81941	 24135	 0.002227	 0.018968	 0.00473	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24135	 83317	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24135	 83317	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83316	 24136	 0.072547	 0.125	 0.00199	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83317	 24136	 0.011397	 0.027896	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81934	 24137	 0.020593	 0.052936	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24138	 83322	 0.038801	 0.11129	 0.00171	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24139	 24144	 0.000248	 0.0039	 0.04064	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24139	 83318	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24139	 83318	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24140	 24142	 0.006909	 0.024079	 0.00558	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24140	 24146	 0.008084	 0.028176	 0.00653	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24140	 83319	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24140	 83319	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82768	 24141	 0.005493	 0.017916	 0.00476	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24141	 83320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24141	 83320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24143	 83321	 0.011056	 0.02922	 0.00684	 132.0	 132.0	 132.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24144	 83321	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83318	 24145	 0.026485	 0.052437	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81941	 24146	 0.009957	 0.042143	 0.00948	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24146	 83323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24146	 83323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24147	 24240	 0.00391	 0.024293	 0.00686	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24147	 83324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24147	 83324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24148	 24156	 0.006134	 0.012553	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24148	 24176	 0.011087	 0.025149	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81982	 24148	 0.000357	 0.001656	 3e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24149	 24150	 0.011114	 0.012225	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24149	 24151	 0.015213	 0.011925	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81982	 24149	 0.004449	 0.007996	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24150	 24151	 0.011475	 0.012499	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24150	 24175	 0.010822	 0.021427	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24151	 24152	 0.00473	 0.007549	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24152	 24168	 0.015439	 0.012218	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24152	 24172	 0.028579	 0.026324	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83324	 24152	 0.005926	 0.011733	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24152	 83341	 0.020236	 0.051463	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24153	 24162	 0.019294	 0.01296	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83324	 24153	 0.010621	 0.007678	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81982	 24154	 0.003517	 0.005387	 9e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83324	 24154	 0.004014	 0.007947	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24155	 24167	 0.009446	 0.018702	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81982	 24155	 0.005761	 0.013374	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24156	 83325	 0.007584	 0.013891	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24157	 24176	 0.026454	 0.020936	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24157	 24208	 0.027792	 0.029679	 0.00063	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24157	 83325	 0.019011	 0.020255	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24158	 83325	 0.016673	 0.010794	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24159	 24181	 0.008007	 0.022329	 0.00469	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24159	 83325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24159	 83325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24160	 24166	 0.021668	 0.017148	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83325	 24160	 0.029132	 0.022346	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24161	 24162	 0.022108	 0.01675	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24162	 24164	 0.017373	 0.012782	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24162	 83326	 0.010288	 0.024362	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24163	 24241	 0.001639	 0.006563	 0.00165	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24163	 83326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24163	 83326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24164	 24165	 0.012544	 0.009927	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24165	 24168	 0.004877	 0.010452	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83326	 24165	 0.003984	 0.014731	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24166	 24167	 0.013222	 0.011847	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24168	 24169	 0.013954	 0.011485	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24168	 24170	 0.006531	 0.011665	 0.00017	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24169	 24172	 0.01833	 0.029257	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83326	 24169	 0.007368	 0.019097	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24170	 24171	 0.009565	 0.0089	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24171	 24172	 0.019455	 0.014314	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24172	 24173	 0.005624	 0.014457	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24172	 24212	 0.022544	 0.017841	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24173	 24175	 0.023039	 0.018233	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24174	 24178	 0.001472	 0.003821	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24174	 24226	 0.008938	 0.024925	 0.00523	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24174	 83327	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24174	 83327	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24175	 24177	 0.019197	 0.015801	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83327	 24175	 0.02084	 0.016493	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24176	 24177	 0.031465	 0.024901	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83327	 24176	 0.045159	 0.029236	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24177	 24209	 0.008652	 0.01657	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83327	 24177	 0.025996	 0.01994	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24177	 83328	 0.021765	 0.015734	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24178	 24210	 0.001281	 0.003387	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24178	 83328	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24178	 83328	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24179	 24215	 0.035392	 0.027742	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83327	 24179	 0.006892	 0.011001	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83325	 24180	 0.013247	 0.026229	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24181	 24185	 0.006672	 0.017321	 0.0042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24181	 83329	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24181	 83329	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24181	 83428	 0.007169	 0.018947	 0.00443	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24182	 24197	 0.033119	 0.02621	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24182	 24199	 0.021392	 0.016768	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24182	 24646	 0.019485	 0.038578	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24183	 24199	 0.029428	 0.023289	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24184	 24208	 0.003345	 0.013013	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81978	 24184	 0.003285	 0.014637	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24184	 83330	 0.005508	 0.012357	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24185	 83330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24185	 83330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24186	 24191	 0.023371	 0.019237	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24186	 24194	 0.005218	 0.010332	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24187	 24188	 0.004821	 0.012394	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83330	 24187	 0.009123	 0.017878	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24187	 83334	 0.007362	 0.018925	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24188	 24189	 0.008311	 0.015222	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24189	 24190	 0.010998	 0.01103	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24190	 24191	 0.014564	 0.011526	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24191	 24192	 0.019128	 0.015138	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24191	 24198	 0.02985	 0.023623	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24191	 24246	 0.059504	 0.046642	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24193	 24194	 0.01095	 0.007089	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24194	 24195	 0.012254	 0.009697	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83330	 24194	 0.004788	 0.012308	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24196	 24198	 0.00615	 0.01764	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24196	 24202	 0.005701	 0.015772	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24197	 24198	 0.005775	 0.011433	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24197	 24199	 0.012933	 0.00992	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24198	 24246	 0.01577	 0.019575	 0.00043	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24200	 24246	 0.017777	 0.013079	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24201	 24203	 0.009065	 0.005869	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24202	 24205	 0.026551	 0.019193	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24202	 83331	 0.009851	 0.037898	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24203	 24246	 0.017988	 0.019165	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24204	 24812	 0.005255	 0.018575	 0.00419	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24204	 83331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24204	 83331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24205	 24206	 0.010611	 0.015909	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24206	 24220	 0.013747	 0.027218	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83331	 24206	 0.010367	 0.031838	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24206	 83332	 0.038585	 0.037904	 0.00064	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24207	 24218	 0.002915	 0.007568	 0.00184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24207	 83332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24207	 83332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24208	 24209	 0.003478	 0.008074	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24209	 83333	 0.01529	 0.009898	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24210	 24211	 0.001005	 0.002525	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24210	 83333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24210	 83333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24211	 83334	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24211	 83334	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24212	 24213	 0.015814	 0.017224	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24212	 83335	 0.049509	 0.03751	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24213	 24217	 0.04659	 0.036871	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83326	 24213	 0.031447	 0.054181	 0.00086	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83334	 24214	 0.014405	 0.014549	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24214	 83336	 0.007092	 0.01299	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24215	 83335	 0.007628	 0.029674	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24216	 24226	 0.003914	 0.010508	 0.00238	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24216	 83335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24216	 83335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24217	 24228	 0.021048	 0.035457	 0.00051	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83335	 24217	 0.027395	 0.021473	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24218	 83336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24218	 83336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24219	 24225	 0.029619	 0.023216	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83336	 24219	 0.036138	 0.039747	 0.00053	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24220	 24221	 0.055127	 0.045374	 0.00092	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24221	 24223	 0.090501	 0.066586	 0.00097	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24222	 83337	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24222	 83337	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83337	 24223	 0.017059	 0.0135	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24224	 24225	 0.071741	 0.050819	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24224	 24227	 0.034069	 0.062401	 0.00108	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83337	 24224	 0.072214	 0.056605	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24226	 83338	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24226	 83338	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83338	 24227	 0.007665	 0.019704	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83335	 24228	 0.043368	 0.046313	 0.00098	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24228	 83340	 0.029799	 0.084561	 0.00133	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83338	 24229	 0.033658	 0.053724	 0.00124	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24230	 24231	 0.037631	 0.096737	 0.0015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24232	 24233	 0.024047	 0.09355	 0.00156	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24232	 24235	 0.12896	 0.10207	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24232	 24239	 0.025845	 0.099432	 0.0017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24234	 24236	 0.002082	 0.011787	 0.00292	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24234	 24240	 0.005352	 0.032119	 0.00973	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24234	 83339	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24234	 83339	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24235	 24237	 0.01859	 0.053318	 0.00082	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83339	 24235	 0.005084	 0.012928	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24237	 24239	 0.014441	 0.07305	 0.00127	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83339	 24237	 0.014041	 0.060301	 0.0011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83326	 24238	 0.033517	 0.044052	 0.0006	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24239	 24242	 0.10864	 0.079931	 0.00117	 32.0	 32.0	 32.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83326	 24239	 0.023165	 0.077277	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24239	 83340	 0.040788	 0.051252	 0.00077	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24240	 24241	 0.001003	 0.010984	 0.00305	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24240	 83340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24240	 83340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24241	 83341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24241	 83341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24242	 24244	 0.02678	 0.070793	 0.00129	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24243	 24245	 0.07429	 0.088934	 0.00148	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24244	 24245	 0.033501	 0.041586	 0.00091	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81966	 24246	 0.011717	 0.065934	 0.00142	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24246	 83481	 0.017936	 0.035512	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24247	 24248	 0.015038	 0.010652	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24248	 24249	 0.008489	 0.008339	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24248	 24267	 0.00652	 0.012909	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24249	 24252	 0.003265	 0.008393	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24249	 83345	 0.00916	 0.021848	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24250	 83346	 0.017481	 0.013702	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24251	 24252	 0.007241	 0.009423	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24251	 24275	 0.008259	 0.010855	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24252	 24253	 0.008074	 0.015986	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24253	 24255	 0.00902	 0.009111	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24253	 24552	 0.011218	 0.008793	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24254	 24255	 0.015248	 0.012067	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24255	 24256	 0.007538	 0.005908	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24255	 24257	 0.012557	 0.016503	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24257	 24258	 0.004837	 0.007409	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24257	 24275	 0.010191	 0.007721	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24258	 83342	 0.004905	 0.009612	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24259	 24266	 0.001156	 0.003103	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24259	 83342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24259	 83342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83342	 24260	 0.017128	 0.013555	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24260	 83343	 0.022052	 0.017286	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24261	 83343	 0.011135	 0.008812	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24262	 24547	 0.002842	 0.007379	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24262	 83343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24262	 83343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24263	 24264	 0.006484	 0.011699	 0.00017	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83343	 24263	 0.006283	 0.010584	 0.00015	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24264	 24265	 0.011221	 0.007265	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24264	 83395	 0.00972	 0.018616	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24265	 83344	 0.008789	 0.006889	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24266	 24318	 0.000793	 0.002058	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24266	 83344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24266	 83344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24267	 24270	 0.011853	 0.009092	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24268	 24272	 0.00228	 0.006207	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24268	 83345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24268	 83345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24269	 24270	 0.017792	 0.013946	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83345	 24269	 0.004357	 0.006954	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24269	 83346	 0.011884	 0.008743	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24271	 24272	 0.000788	 0.002083	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24271	 83346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24271	 83346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24272	 24285	 0.000745	 0.002001	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24273	 24274	 0.012867	 0.010183	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24273	 24277	 0.00572	 0.011211	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24273	 83348	 0.003121	 0.007079	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24275	 24277	 0.01529	 0.016654	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24276	 24277	 0.011028	 0.007139	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24277	 24278	 0.011405	 0.00894	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24277	 24316	 0.005321	 0.011403	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24277	 83349	 0.028739	 0.022527	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24279	 24335	 0.007491	 0.013517	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24279	 83347	 0.024397	 0.019307	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24279	 83353	 0.008636	 0.013228	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24280	 24284	 0.00097	 0.002641	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24280	 83347	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24280	 83347	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24280	 83352	 0.00168	 0.004511	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24281	 24282	 0.016362	 0.016526	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83347	 24281	 0.028071	 0.021267	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24282	 24283	 0.005535	 0.008395	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83345	 24282	 0.019044	 0.014928	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24283	 83350	 0.003805	 0.010085	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24284	 24285	 0.000962	 0.002583	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24285	 83348	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24285	 83348	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24286	 83349	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24286	 83349	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24286	 83352	 0.002429	 0.006306	 0.00153	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83078	 24287	 0.005252	 0.021686	 0.00513	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24287	 83350	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24287	 83350	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24287	 83352	 0.004379	 0.013618	 0.00284	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24288	 24289	 0.004837	 0.010972	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83350	 24288	 0.003148	 0.008092	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24289	 83351	 0.015114	 0.017717	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24290	 83351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24290	 83351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24290	 83352	 0.002998	 0.008161	 0.0018	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24291	 24292	 0.00329	 0.008054	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83351	 24291	 0.005245	 0.010279	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24292	 24293	 0.003232	 0.006901	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81977	 24293	 0.003792	 0.008978	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24294	 24295	 0.011386	 0.008231	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24295	 24296	 0.012944	 0.009169	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83351	 24296	 0.016442	 0.012612	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24297	 24298	 0.011463	 0.008287	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24297	 24300	 0.017596	 0.012946	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24298	 24302	 0.028326	 0.022417	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24298	 24306	 0.010365	 0.008203	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24299	 24300	 0.016277	 0.012759	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24299	 24302	 0.011496	 0.009098	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24300	 24301	 0.01176	 0.009218	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24300	 24305	 0.005591	 0.014373	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24302	 24303	 0.00445	 0.00881	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24302	 24561	 0.007846	 0.015535	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83203	 24302	 0.012952	 0.030065	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24303	 24465	 0.007025	 0.011515	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24304	 24305	 0.00393	 0.008043	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24304	 24463	 0.006107	 0.015697	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83203	 24305	 0.002749	 0.012043	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24306	 24307	 0.01304	 0.01032	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24307	 24556	 0.00561	 0.008592	 0.00015	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24308	 24312	 0.007919	 0.010305	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24308	 24559	 0.013585	 0.009995	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24309	 24559	 0.011634	 0.00841	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24310	 24379	 0.000444	 0.005027	 0.04577	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24310	 83352	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24311	 24314	 0.008562	 0.006776	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24311	 24848	 0.027971	 0.02022	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83351	 24312	 0.004484	 0.008059	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24313	 24418	 0.01679	 0.012137	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24313	 24556	 0.021043	 0.016653	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24314	 83389	 0.005183	 0.007686	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24315	 24328	 0.038782	 0.026051	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83342	 24315	 0.017486	 0.01132	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24316	 24317	 0.005275	 0.012119	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24317	 24849	 0.013011	 0.011739	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24317	 83354	 0.012923	 0.009508	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24318	 24320	 0.001348	 0.004214	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24318	 83354	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24318	 83354	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24319	 83355	 0.012485	 0.00988	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24320	 83355	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24320	 83355	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24320	 83357	 0.001215	 0.004093	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24321	 24322	 0.000606	 0.002465	 0.0006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24321	 24538	 0.000681	 0.002725	 0.00069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81952	 24322	 0.00082	 0.003191	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24323	 83356	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24323	 83356	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24323	 83357	 0.001241	 0.004258	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24324	 83357	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24325	 24326	 0.004363	 0.010024	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24325	 24849	 0.006716	 0.012071	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83356	 24325	 0.004255	 0.006792	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24326	 24328	 0.015359	 0.012155	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24326	 24329	 0.004519	 0.009287	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83356	 24326	 0.011337	 0.018482	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24327	 24329	 0.004518	 0.010489	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24327	 24335	 0.003225	 0.005997	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83349	 24328	 0.016372	 0.012404	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24330	 24331	 0.007356	 0.011269	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24330	 24339	 0.006955	 0.008852	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24331	 24332	 0.003672	 0.009441	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24331	 24340	 0.008136	 0.008861	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24332	 24333	 0.00201	 0.005167	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83356	 24333	 0.003868	 0.009942	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24334	 24340	 0.006583	 0.017448	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24334	 24852	 0.007996	 0.006328	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81953	 24334	 0.00496	 0.019369	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24335	 83359	 0.011235	 0.010068	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24336	 83359	 0.020842	 0.015334	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24337	 24353	 0.000763	 0.002047	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83352	 24337	 0.002157	 0.007035	 0.00187	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24337	 83359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24337	 83359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83359	 24338	 0.017431	 0.011285	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24339	 24344	 0.00792	 0.010409	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24340	 24341	 0.005269	 0.015112	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24341	 24342	 0.00619	 0.004384	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24341	 24343	 0.016579	 0.01312	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24341	 24348	 0.032168	 0.025215	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24342	 24345	 0.013136	 0.010076	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24344	 24355	 0.010771	 0.011846	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24345	 24346	 0.009357	 0.007405	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24346	 24347	 0.008841	 0.00693	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24346	 24348	 0.012169	 0.00922	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24348	 83363	 0.005603	 0.01098	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24348	 83378	 0.031739	 0.050661	 0.00117	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24349	 83368	 0.014173	 0.01004	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24350	 24352	 0.001999	 0.005367	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24350	 24358	 0.000728	 0.001925	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24350	 83360	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24350	 83360	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24351	 24357	 0.004151	 0.008895	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24351	 24855	 0.002525	 0.008424	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83360	 24351	 0.014926	 0.009663	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24352	 24353	 0.000871	 0.002239	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24352	 83361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24352	 83361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24354	 24355	 0.012346	 0.009771	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83361	 24355	 0.006869	 0.010964	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83360	 24356	 0.015212	 0.011924	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24357	 24367	 0.008312	 0.012734	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24357	 83362	 0.014903	 0.011794	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24358	 24359	 0.000438	 0.001125	 0.00028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24358	 24373	 0.000975	 0.002349	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24359	 24365	 0.001446	 0.003636	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24359	 83362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24359	 83362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24360	 24361	 0.000722	 0.001937	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24360	 24373	 0.000832	 0.002138	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24360	 83363	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24360	 83363	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24361	 83377	 0.003474	 0.011917	 0.00285	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24362	 24365	 0.00174	 0.004474	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24362	 83364	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24362	 83364	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24362	 83377	 0.001922	 0.00696	 0.00149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24363	 24368	 0.001137	 0.003097	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24363	 24374	 0.000912	 0.003301	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24363	 83365	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24363	 83365	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83364	 24364	 0.012564	 0.013685	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83365	 24364	 0.02449	 0.019381	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24364	 83368	 0.022536	 0.017664	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83362	 24366	 0.005469	 0.003541	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24367	 24372	 0.007813	 0.01303	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83365	 24367	 0.030195	 0.023896	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24367	 83366	 0.013878	 0.010983	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24368	 24371	 0.001617	 0.004273	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24368	 83366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24368	 83366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24369	 24370	 0.013751	 0.010882	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24369	 24389	 0.01804	 0.01414	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24370	 24399	 0.01441	 0.011404	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24370	 83367	 0.010443	 0.011374	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24371	 24422	 0.001001	 0.002727	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24371	 83367	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24371	 83367	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24372	 83386	 0.014286	 0.011306	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24372	 83389	 0.014077	 0.01114	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24373	 83368	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24373	 83368	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24374	 24390	 0.000797	 0.002223	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24374	 83377	 0.002608	 0.006771	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24375	 24376	 0.003449	 0.00676	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24375	 24378	 0.007812	 0.011967	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24375	 83378	 0.010085	 0.015296	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24376	 24377	 0.006645	 0.006711	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83364	 24377	 0.011594	 0.009175	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83365	 24377	 0.023493	 0.018592	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24378	 83371	 0.013957	 0.013961	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24378	 83376	 0.017775	 0.023362	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24379	 24381	 5e-05	 0.000569	 0.00518	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24379	 83369	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24379	 83369	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24380	 83450	 0.007503	 0.013486	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24381	 24387	 9.6e-05	 0.001057	 0.01027	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24381	 24393	 9e-05	 0.001034	 0.00906	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24381	 83370	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81944	 24382	 0.001695	 0.00448	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83370	 24382	 0.000874	 0.002345	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24382	 83372	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24382	 83372	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24383	 24756	 8.3e-05	 0.000922	 0.0087	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24383	 83373	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24384	 24385	 0.020563	 0.014566	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24384	 83463	 0.009101	 0.01001	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24385	 83464	 0.015856	 0.010651	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24386	 24853	 6.5e-05	 0.000755	 0.00662	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24386	 83375	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24387	 83377	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24388	 24389	 0.010045	 0.007874	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24389	 83379	 0.003626	 0.006642	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83369	 24390	 0.001286	 0.003792	 0.00088	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24390	 83379	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24390	 83379	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24391	 24392	 0.000735	 0.001942	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83369	 24391	 0.001207	 0.00324	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24392	 24397	 0.000839	 0.002108	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24393	 24396	 5.6e-05	 0.000625	 0.00595	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24393	 24716	 6e-05	 0.000691	 0.00605	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24393	 83380	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24393	 83380	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24394	 24395	 0.010133	 0.008019	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83380	 24394	 0.016345	 0.012935	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24394	 83382	 0.018598	 0.014718	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83380	 24395	 0.018409	 0.014569	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24395	 83382	 0.008644	 0.006841	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24396	 83381	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24397	 24847	 0.000446	 0.001529	 0.00037	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83381	 24397	 0.000487	 0.001669	 0.0004	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24398	 24436	 0.000656	 0.002249	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83381	 24398	 0.000782	 0.002682	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24399	 24428	 0.008549	 0.006766	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24399	 83492	 0.01072	 0.011791	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24400	 83492	 0.011533	 0.008485	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24401	 24403	 0.013797	 0.011356	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24401	 24563	 0.008302	 0.00657	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24402	 24403	 0.017201	 0.013613	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24402	 24467	 0.025088	 0.019855	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24403	 24413	 0.004169	 0.008254	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24403	 24414	 0.016744	 0.011248	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24403	 83393	 0.007984	 0.021162	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24404	 24413	 0.01068	 0.008192	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24404	 24450	 0.010811	 0.008556	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24405	 24450	 0.014127	 0.010007	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24406	 24407	 0.000746	 0.001938	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24406	 83383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24406	 83383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24407	 24411	 0.000822	 0.002239	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24407	 83384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24407	 83384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24408	 24423	 0.016639	 0.013168	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83384	 24408	 0.013158	 0.009512	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24409	 24421	 0.006172	 0.009454	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24409	 83385	 0.006878	 0.008385	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24410	 24411	 0.000819	 0.002165	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24410	 83385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24410	 83385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24412	 24413	 0.005701	 0.008547	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24412	 24415	 0.011843	 0.007667	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24412	 24450	 0.025118	 0.01848	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83385	 24412	 0.004819	 0.012387	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24415	 24416	 0.010024	 0.007246	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24416	 24564	 0.01118	 0.00751	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24417	 24418	 0.005326	 0.006692	 0.0001	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24417	 24567	 0.005078	 0.008435	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83385	 24417	 0.020624	 0.014909	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24418	 24419	 0.0045	 0.00812	 0.00012	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24419	 83386	 0.006101	 0.011956	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24420	 24422	 0.000838	 0.002214	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24420	 24430	 0.000913	 0.002414	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24420	 83386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24420	 83386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24421	 24423	 0.012204	 0.009658	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83386	 24421	 0.004707	 0.007861	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24422	 83387	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24422	 83387	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24423	 24424	 0.012127	 0.007851	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24424	 24425	 0.011772	 0.009228	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24424	 24426	 0.012856	 0.010174	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83387	 24424	 0.016877	 0.013356	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83384	 24426	 0.01625	 0.016254	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24426	 83388	 0.00628	 0.014089	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83383	 24427	 0.003763	 0.010679	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24427	 83388	 0.00198	 0.005247	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24428	 83388	 0.01416	 0.009512	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24429	 24847	 0.00136	 0.003704	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24429	 83388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24429	 83388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83352	 24430	 0.004014	 0.014189	 0.0032	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24430	 83389	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24430	 83389	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24431	 24432	 0.010513	 0.012585	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83383	 24431	 0.006673	 0.00877	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24432	 24433	 0.011427	 0.008095	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24432	 83393	 0.016635	 0.013164	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24433	 24434	 0.005054	 0.007494	 0.00011	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24433	 24440	 0.007934	 0.012154	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24434	 24439	 0.019714	 0.015601	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24434	 24445	 0.004552	 0.007265	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24435	 24436	 0.000832	 0.003011	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24435	 24451	 0.002959	 0.00782	 0.00183	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24435	 83390	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24435	 83390	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83390	 24437	 0.014313	 0.011219	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24437	 83392	 0.017604	 0.013932	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24438	 24444	 0.000704	 0.002415	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24438	 24451	 0.00357	 0.009956	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24438	 24720	 0.001804	 0.005031	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24438	 83391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24438	 83391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24439	 24440	 0.005349	 0.010484	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83391	 24439	 0.004042	 0.009168	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24440	 24441	 0.019589	 0.015503	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24440	 24457	 0.00496	 0.011394	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24441	 24442	 0.00866	 0.012293	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24441	 83394	 0.04671	 0.036965	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24442	 24521	 0.020476	 0.016205	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83391	 24442	 0.005083	 0.009848	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24442	 83453	 0.015868	 0.020855	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24443	 24522	 0.015811	 0.01597	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24443	 83392	 0.026153	 0.020697	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24443	 83453	 0.015782	 0.010218	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24444	 83392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24444	 83392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24444	 83451	 0.000764	 0.003865	 0.00108	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83392	 24445	 0.004076	 0.009363	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24446	 24447	 0.01638	 0.011841	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24446	 24448	 0.004395	 0.007015	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24446	 24466	 0.02455	 0.019428	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24446	 24467	 0.011712	 0.007582	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24447	 24453	 0.010265	 0.008124	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24448	 24449	 0.003215	 0.008266	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24449	 83393	 0.003185	 0.012254	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24450	 83393	 0.003637	 0.010947	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24451	 83393	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24451	 83393	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24451	 83400	 0.008547	 0.028798	 0.00716	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83393	 24452	 0.015707	 0.012048	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24453	 24455	 0.013471	 0.010559	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24454	 24455	 0.011632	 0.008922	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24455	 24456	 0.004718	 0.009035	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24456	 24457	 0.015902	 0.012585	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24456	 24462	 0.016593	 0.013131	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24456	 24477	 0.037595	 0.029469	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83393	 24456	 0.004327	 0.016649	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24458	 24462	 0.012432	 0.009536	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24458	 24502	 0.007974	 0.013071	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24459	 24461	 0.011728	 0.009193	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24459	 24499	 0.019763	 0.012795	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24460	 24477	 0.012915	 0.009336	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24460	 24497	 0.02023	 0.016009	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24461	 24462	 0.010987	 0.007783	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24463	 24464	 0.011683	 0.009246	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24463	 24472	 0.009003	 0.017824	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24465	 24466	 0.018764	 0.014708	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24467	 24468	 0.011614	 0.007519	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24468	 24469	 0.018344	 0.014517	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24468	 24471	 0.008216	 0.008644	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24469	 24474	 0.037199	 0.026891	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24470	 24471	 0.017389	 0.013761	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24470	 24473	 0.008205	 0.008229	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24470	 24475	 0.017872	 0.013709	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24471	 24472	 0.004418	 0.008747	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24474	 24475	 0.0125	 0.009892	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24474	 24479	 0.017032	 0.01335	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83198	 24474	 0.009128	 0.015377	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24475	 24476	 0.015723	 0.012443	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24476	 24477	 0.016802	 0.01317	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24477	 24478	 0.012141	 0.009608	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24478	 24479	 0.013871	 0.00898	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24478	 24482	 0.021756	 0.017054	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24480	 24481	 0.011438	 0.009052	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24481	 24482	 0.005239	 0.008825	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24482	 24483	 0.011709	 0.008464	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24482	 24484	 0.008405	 0.014159	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24482	 24499	 0.045825	 0.03592	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24483	 24497	 0.011667	 0.008434	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24484	 24485	 0.00438	 0.008023	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24485	 24486	 0.003897	 0.01033	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24485	 24490	 0.004931	 0.008898	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24485	 24507	 0.0172	 0.013482	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24485	 24508	 0.002789	 0.015856	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24486	 24487	 0.00435	 0.007819	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24488	 24489	 0.011576	 0.009161	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24488	 24508	 0.035884	 0.030669	 0.00057	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24489	 24491	 0.018647	 0.014303	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24490	 24491	 0.004365	 0.008642	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24491	 24493	 0.003495	 0.010278	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24492	 24493	 0.002608	 0.010435	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24492	 24518	 0.005578	 0.015998	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24492	 24571	 0.004825	 0.008619	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24493	 24494	 0.023734	 0.018783	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24494	 24495	 0.011718	 0.009274	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24495	 24496	 0.006769	 0.008809	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83193	 24495	 0.035206	 0.027861	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24496	 83397	 0.007074	 0.014006	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24497	 24499	 0.022617	 0.017729	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24497	 24506	 0.008158	 0.016153	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24498	 24499	 0.011229	 0.008886	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24499	 24500	 0.012331	 0.009759	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24499	 83394	 0.008989	 0.024558	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24500	 24502	 0.008014	 0.010533	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24501	 24504	 0.013901	 0.011001	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24502	 24519	 0.011727	 0.008306	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24502	 83394	 0.004785	 0.015193	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24503	 24720	 0.005349	 0.013446	 0.00348	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24503	 83394	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24503	 83394	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24503	 83400	 0.002532	 0.013891	 0.00367	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83394	 24504	 0.012753	 0.010092	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24505	 24506	 0.003193	 0.009158	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24505	 24509	 0.005367	 0.00983	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83394	 24505	 0.011862	 0.019983	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24506	 24507	 0.009981	 0.007899	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24508	 24510	 0.012039	 0.009528	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24508	 24517	 0.005025	 0.012779	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24508	 83398	 0.008529	 0.029842	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24509	 24510	 0.005752	 0.011389	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24510	 24511	 0.002917	 0.00756	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24511	 24513	 0.012485	 0.008083	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24511	 24516	 0.004575	 0.015262	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83394	 24512	 0.018072	 0.013296	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24513	 24514	 0.013295	 0.010421	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24514	 24515	 0.005855	 0.015051	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24514	 24532	 0.004421	 0.010263	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24515	 24579	 0.024171	 0.015648	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24515	 83399	 0.010261	 0.020316	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24516	 83399	 0.003559	 0.013844	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24517	 83399	 0.007761	 0.02589	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24518	 83398	 0.002791	 0.009971	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24519	 24520	 0.011157	 0.007494	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24520	 24521	 0.011666	 0.009144	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24520	 24536	 0.027343	 0.021639	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24521	 24522	 0.011696	 0.008455	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24522	 24523	 0.011694	 0.007571	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24523	 24524	 0.009008	 0.009011	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24523	 24526	 0.027283	 0.021591	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24524	 24525	 0.024578	 0.018083	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24524	 24725	 0.020349	 0.020354	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24524	 83454	 0.011863	 0.015591	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24525	 24526	 0.011391	 0.009015	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24525	 83466	 0.016111	 0.021174	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24526	 24527	 0.011784	 0.00867	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24526	 24536	 0.048845	 0.038656	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24527	 24528	 0.011682	 0.009156	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24527	 24529	 0.018651	 0.01476	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24528	 24535	 0.011652	 0.009221	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24529	 24531	 0.033815	 0.026506	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24529	 24534	 0.016522	 0.013076	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24529	 24698	 0.028083	 0.022225	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24530	 24534	 0.024817	 0.019639	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24530	 24700	 0.01694	 0.013279	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24531	 24536	 0.018629	 0.024484	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24531	 83403	 0.005215	 0.023238	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24532	 24533	 0.011622	 0.008402	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83394	 24532	 0.020741	 0.013428	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24533	 24534	 0.011635	 0.008411	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24535	 24536	 0.014297	 0.011314	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24536	 24537	 0.010673	 0.008446	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83394	 24536	 0.020837	 0.01649	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83394	 24537	 0.014595	 0.009449	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24538	 24539	 0.000905	 0.003559	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83357	 24539	 0.001845	 0.007178	 0.00192	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24539	 83395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24539	 83395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83395	 24540	 0.016373	 0.012046	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24541	 24542	 0.003647	 0.005821	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83395	 24541	 0.007686	 0.019758	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24542	 24544	 0.016801	 0.014359	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24543	 24544	 0.018108	 0.01309	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24544	 24545	 0.018823	 0.013849	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83343	 24544	 0.022158	 0.016302	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24546	 83396	 0.020565	 0.016275	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24547	 83396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24547	 83396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24548	 24549	 0.005	 0.006507	 9e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83396	 24548	 0.00695	 0.01376	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24549	 24550	 0.021279	 0.016839	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24550	 24551	 0.014246	 0.011274	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24551	 24552	 0.009956	 0.006687	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24553	 24554	 0.018703	 0.014801	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83396	 24553	 0.00939	 0.016877	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24555	 24558	 0.011392	 0.007653	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24556	 24557	 0.004332	 0.008576	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24556	 24566	 0.008381	 0.015123	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83353	 24556	 0.012222	 0.031419	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24557	 24558	 0.003315	 0.008523	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24558	 24559	 0.002597	 0.006675	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83353	 24559	 0.002372	 0.012637	 0.00022	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24560	 24848	 0.004117	 0.010583	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24561	 24565	 0.014769	 0.009561	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24562	 24563	 0.008482	 0.006132	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24563	 24565	 0.006761	 0.013386	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24564	 24567	 0.010578	 0.007647	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24565	 24567	 0.007184	 0.010771	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24566	 24567	 0.015605	 0.012349	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24568	 24569	 0.000711	 0.00244	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24568	 83397	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24568	 83397	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24569	 24591	 0.00129	 0.00525	 0.00128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24570	 24571	 0.006471	 0.012813	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24570	 83405	 0.004868	 0.012903	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24572	 83398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24572	 83398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24572	 83400	 0.002106	 0.007097	 0.00176	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24573	 24574	 0.017838	 0.015246	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83398	 24573	 0.006703	 0.015561	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24573	 83406	 0.008655	 0.016961	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24574	 83401	 0.014866	 0.015641	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24575	 83399	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24575	 83399	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24575	 83400	 0.000919	 0.00368	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24576	 24790	 0.000567	 0.006589	 0.05696	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24576	 83400	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24576	 83412	 0.000237	 0.002691	 0.02431	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24577	 24705	 0.003119	 0.010869	 0.00252	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83400	 24577	 0.001116	 0.00364	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24577	 83402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24577	 83402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24578	 24611	 0.002421	 0.008766	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24578	 24765	 0.005337	 0.017408	 0.00462	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83400	 24578	 0.000771	 0.003538	 0.00091	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24578	 83403	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24578	 83403	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83403	 24579	 0.006737	 0.013339	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24580	 24701	 0.003233	 0.009173	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83403	 24580	 0.003059	 0.010926	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83402	 24581	 0.017565	 0.013901	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24582	 24583	 0.013654	 0.017946	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24582	 83405	 0.023384	 0.018329	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24583	 24590	 0.006429	 0.015956	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83195	 24583	 0.022809	 0.018051	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24584	 24589	 0.005799	 0.016455	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83195	 24584	 0.02711	 0.021455	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24585	 24587	 0.00646	 0.018527	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24586	 83404	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24586	 83404	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24586	 83413	 0.005294	 0.018162	 0.00435	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24587	 83408	 0.004114	 0.015826	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24588	 24589	 0.005773	 0.01526	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24588	 24595	 0.004848	 0.014592	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24590	 83407	 0.004912	 0.016209	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24591	 24592	 0.000521	 0.003926	 0.00109	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24591	 83405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24591	 83405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24592	 24593	 0.000451	 0.003789	 0.00112	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24592	 83406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24592	 83406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24593	 83407	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24593	 83407	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24593	 83410	 0.000505	 0.005355	 0.00159	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24594	 24595	 0.009476	 0.017097	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24594	 83411	 0.008808	 0.014059	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24595	 83409	 0.009973	 0.017926	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24596	 24599	 0.001772	 0.004942	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24596	 83408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24596	 83408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24597	 24598	 0.022557	 0.017851	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83408	 24597	 0.023625	 0.018696	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83408	 24598	 0.031938	 0.025276	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24598	 83409	 0.034089	 0.026977	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24598	 83432	 0.076347	 0.060421	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24599	 83409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24599	 83409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24599	 83413	 0.001775	 0.00609	 0.00146	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24600	 83410	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24600	 83412	 6.4e-05	 0.000742	 0.00651	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24601	 24602	 0.004084	 0.012528	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83407	 24601	 0.007325	 0.01362	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83411	 24601	 0.003089	 0.012255	 0.00035	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83401	 24602	 0.01449	 0.025482	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83406	 24602	 0.009707	 0.017515	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24603	 25669	 0.000417	 0.010617	 4.6849	 5108.0	 5363.4	 5618.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24603	 83412	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24603	 83412	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24603	 83412	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24604	 24627	 0.001948	 0.004694	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24604	 83415	 0.001648	 0.004859	 0.00113	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24605	 24632	 0.000322	 0.00372	 0.03261	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83412	 24605	 0.000106	 0.001219	 0.01068	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24605	 83415	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24606	 24607	 0.02125	 0.015361	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24607	 24608	 0.002042	 0.007854	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24607	 24670	 0.035407	 0.027754	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83414	 24607	 0.002235	 0.013743	 0.00025	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24608	 83437	 0.003564	 0.01048	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24609	 24611	 0.000556	 0.003934	 0.00108	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83413	 24609	 0.000618	 0.006628	 0.00173	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24609	 83417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24609	 83417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83417	 24610	 0.011667	 0.009145	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24611	 83418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24611	 83418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24612	 24666	 0.003099	 0.009508	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83418	 24612	 0.001546	 0.007167	 0.00015	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24613	 24614	 0.016778	 0.028264	 0.0004	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24613	 24618	 0.031507	 0.024934	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24614	 24615	 0.021774	 0.014096	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83404	 24614	 0.013976	 0.027671	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24615	 24616	 0.01656	 0.018214	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24616	 83419	 0.00891	 0.020469	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24617	 83420	 0.015833	 0.02944	 0.00069	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24618	 83420	 0.0179	 0.03383	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24619	 24624	 0.001418	 0.003416	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83413	 24619	 0.004859	 0.016209	 0.00411	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24619	 83419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24619	 83419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83413	 24620	 0.011634	 0.030748	 0.0072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24620	 83420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24620	 83420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83420	 24621	 0.03974	 0.03115	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24621	 83429	 0.04623	 0.036586	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24622	 24625	 0.011911	 0.021492	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83420	 24622	 0.009545	 0.017483	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24623	 24626	 0.028067	 0.018171	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24624	 83421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24624	 83421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24624	 83423	 0.003495	 0.009237	 0.00216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83421	 24625	 0.009484	 0.013217	 0.00023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83421	 24626	 0.023471	 0.015195	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24626	 83422	 0.016677	 0.016725	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24626	 83424	 0.037546	 0.02943	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24627	 24628	 0.001421	 0.003868	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24628	 83422	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24628	 83422	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24628	 83423	 0.001242	 0.003381	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24629	 24653	 0.018641	 0.014612	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83421	 24629	 0.054641	 0.0395	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24629	 83424	 0.02361	 0.01737	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24630	 24662	 0.000338	 0.003711	 0.03605	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83412	 24630	 0.000287	 0.003315	 0.02906	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24630	 83423	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83423	 24631	 0.002012	 0.005223	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24631	 83425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24631	 83425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24631	 83426	 0.001808	 0.004921	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24632	 24641	 8.9e-05	 0.000989	 0.00942	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24632	 83426	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24633	 24639	 0.0079	 0.015642	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83425	 24633	 0.009094	 0.016346	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24634	 24635	 0.011692	 0.009164	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24634	 24639	 0.01009	 0.010192	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24636	 24637	 0.02022	 0.014877	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24636	 24638	 0.008421	 0.015135	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83424	 24636	 0.005067	 0.014901	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24637	 83431	 0.021684	 0.01716	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24638	 24639	 0.027454	 0.021727	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24638	 24648	 0.023293	 0.018258	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24639	 24640	 0.011706	 0.009264	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24639	 24647	 0.012216	 0.022041	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83424	 24639	 0.012941	 0.03004	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24641	 83428	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24642	 24643	 0.006435	 0.013169	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24642	 24644	 0.018254	 0.027963	 0.00039	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83427	 24642	 0.013146	 0.027629	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83429	 24642	 0.010176	 0.023083	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24643	 24644	 0.035577	 0.023032	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24643	 24646	 0.013147	 0.025765	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24644	 24645	 0.034933	 0.027645	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24644	 24647	 0.029785	 0.023571	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24645	 24646	 0.035612	 0.023055	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24645	 83430	 0.040602	 0.026286	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24645	 83481	 0.059693	 0.047241	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24647	 24649	 0.026733	 0.019668	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24647	 83430	 0.049998	 0.035416	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24648	 24651	 0.029111	 0.022818	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24649	 83430	 0.023333	 0.018466	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24650	 24661	 0.004298	 0.011359	 0.00266	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24650	 24812	 0.00543	 0.013958	 0.00346	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24650	 83430	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24650	 83430	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24651	 83433	 0.035135	 0.022747	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24651	 83434	 0.027189	 0.021312	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24652	 24655	 0.001856	 0.004904	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83413	 24652	 0.005456	 0.018717	 0.00448	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24652	 83431	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24652	 83431	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24653	 83432	 0.018577	 0.020432	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83415	 24654	 0.001281	 0.004637	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24654	 83432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24654	 83432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24655	 24661	 0.002446	 0.006465	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24655	 83433	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24655	 83433	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24656	 24674	 0.026606	 0.020855	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83433	 24656	 0.017443	 0.013804	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24656	 83434	 0.018421	 0.014578	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24657	 24658	 0.006466	 0.010892	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24657	 24677	 0.011452	 0.015051	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24657	 24678	 0.017215	 0.012665	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24657	 83441	 0.015331	 0.021366	 0.00037	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24657	 83444	 0.027375	 0.017723	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24658	 24676	 0.014313	 0.011327	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24658	 24686	 0.018516	 0.014653	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24659	 24677	 0.012077	 0.008555	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24660	 24675	 0.015205	 0.010771	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24660	 83436	 0.009027	 0.017872	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24661	 83434	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24661	 83434	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24662	 24807	 0.000365	 0.004245	 0.0367	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83412	 24662	 0.000441	 0.004835	 0.04696	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24662	 83435	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24663	 24664	 0.012668	 0.013933	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24663	 24677	 0.031255	 0.024734	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24663	 24803	 0.022703	 0.017966	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83436	 24663	 0.010715	 0.024305	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24664	 24678	 0.039039	 0.030895	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24664	 24803	 0.029682	 0.021457	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24665	 24694	 0.005818	 0.008824	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24665	 24695	 0.02135	 0.013822	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24665	 24802	 0.031654	 0.02505	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24666	 24681	 0.006619	 0.012124	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24666	 24702	 0.008698	 0.017046	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24666	 83437	 0.00595	 0.028999	 0.00054	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24666	 83438	 0.010983	 0.021745	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24667	 24668	 0.005412	 0.010365	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83417	 24667	 0.005801	 0.016639	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83418	 24667	 0.033032	 0.026141	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24668	 83439	 0.012879	 0.013009	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24669	 24684	 0.000834	 0.004321	 0.00105	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83413	 24669	 0.000931	 0.007553	 0.0024	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24669	 83437	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24669	 83437	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83432	 24670	 0.025305	 0.017925	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24671	 24672	 0.025015	 0.018404	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24671	 24685	 0.008189	 0.014999	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83416	 24671	 0.011371	 0.034224	 0.00067	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24671	 83440	 0.021586	 0.01692	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24672	 24673	 0.019544	 0.015467	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24673	 24674	 0.016552	 0.016902	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24673	 24680	 0.005469	 0.014058	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24674	 24675	 0.018482	 0.013598	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24674	 24676	 0.007829	 0.01434	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83431	 24674	 0.019575	 0.029987	 0.00042	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83434	 24675	 0.027689	 0.017926	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24678	 83444	 0.011656	 0.009225	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83432	 24679	 0.017704	 0.011461	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83431	 24680	 0.025596	 0.020256	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83432	 24680	 0.00359	 0.017519	 0.0003	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24681	 83438	 0.004364	 0.00864	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24682	 24688	 0.000904	 0.002461	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24682	 83438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24682	 83438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24683	 24684	 0.001133	 0.003817	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24683	 24687	 0.00114	 0.003719	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24683	 24693	 0.003305	 0.009745	 0.00227	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24683	 83439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24683	 83439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24684	 83440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24684	 83440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24685	 24686	 0.005313	 0.00829	 0.00014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24687	 24693	 0.001983	 0.005743	 0.00139	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24687	 83441	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24687	 83441	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24688	 83442	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24688	 83442	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24689	 24691	 0.027128	 0.021468	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83442	 24689	 0.008984	 0.009074	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24690	 24696	 0.00223	 0.005986	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24690	 24713	 0.001454	 0.003738	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24690	 83443	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24690	 83443	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24691	 24692	 0.008817	 0.013372	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83443	 24691	 0.011838	 0.008709	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24691	 83445	 0.029237	 0.021135	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24692	 24695	 0.029213	 0.018913	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24692	 83444	 0.00477	 0.011295	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24693	 24784	 0.005229	 0.01382	 0.00323	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24693	 83444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24693	 83444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24694	 24802	 0.030656	 0.033718	 0.00045	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83444	 24694	 0.007973	 0.017022	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24695	 83445	 0.017268	 0.013665	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24696	 24707	 0.001354	 0.003634	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24696	 83445	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24696	 83445	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83445	 24697	 0.011738	 0.008636	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24698	 24699	 0.020934	 0.013552	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24698	 83466	 0.028367	 0.022449	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24699	 24700	 0.017778	 0.014633	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24699	 24726	 0.025126	 0.018163	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24700	 24701	 0.004736	 0.012044	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24701	 24702	 0.01012	 0.01826	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24701	 24703	 0.00861	 0.008635	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24703	 24704	 0.017395	 0.012798	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24704	 24726	 0.01165	 0.018595	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24704	 83446	 0.008756	 0.016549	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24705	 24712	 0.001224	 0.003236	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24705	 83446	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24705	 83446	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24706	 24726	 0.04589	 0.036317	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24706	 24732	 0.017468	 0.011734	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83443	 24706	 0.003634	 0.008605	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24707	 24784	 0.000898	 0.003174	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24708	 24732	 0.013032	 0.015887	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24708	 83471	 0.00764	 0.019429	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24709	 24733	 0.017511	 0.013858	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24709	 83470	 0.020648	 0.01634	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24710	 24711	 0.00122	 0.003277	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24710	 24783	 0.001691	 0.004604	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24711	 83447	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24711	 83447	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24712	 24713	 0.000806	 0.001871	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24713	 83448	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24713	 83448	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24714	 83454	 0.012166	 0.009537	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24714	 83455	 0.009468	 0.009668	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24715	 24725	 0.017404	 0.013773	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24715	 83455	 0.008282	 0.011542	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24716	 24717	 0.000123	 0.001347	 0.01308	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24716	 83449	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24717	 83451	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83392	 24718	 0.011486	 0.00909	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24718	 83454	 0.026696	 0.020925	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83452	 24719	 0.016599	 0.013136	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24720	 24721	 0.000837	 0.002173	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24720	 24722	 0.002296	 0.005329	 0.00162	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24720	 83453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24720	 83453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24721	 24722	 0.001743	 0.004481	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24721	 83454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24721	 83454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83449	 24722	 0.001357	 0.006045	 0.00164	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24722	 83455	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24722	 83455	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24723	 24724	 0.018252	 0.018435	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83452	 24723	 0.045014	 0.032541	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83455	 24723	 0.011867	 0.009391	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24724	 83458	 0.03637	 0.028783	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24724	 83495	 0.007355	 0.021094	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24725	 83458	 0.05173	 0.03349	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24725	 83495	 0.018017	 0.041829	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24726	 24727	 0.016727	 0.013112	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24726	 24728	 0.022713	 0.017422	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24728	 24729	 0.021165	 0.016749	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24729	 24730	 0.012358	 0.009092	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24729	 24731	 0.016715	 0.013228	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24729	 83456	 0.017814	 0.024827	 0.00042	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24730	 24731	 0.016844	 0.012392	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24730	 83466	 0.027593	 0.0276	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24731	 24732	 0.008304	 0.013612	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24731	 24733	 0.012831	 0.010057	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24734	 24737	 0.002287	 0.006559	 0.00161	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24734	 24765	 0.002529	 0.006566	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24734	 83456	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24734	 83456	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24735	 24736	 0.001133	 0.002629	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24735	 83457	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24735	 83457	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24736	 83458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24736	 83458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24737	 24782	 0.010249	 0.027087	 0.00634	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24737	 83459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24737	 83459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24737	 83461	 0.001325	 0.005036	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24738	 24739	 0.026346	 0.017057	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24738	 83462	 0.006031	 0.022623	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24739	 24740	 0.017939	 0.011614	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24739	 24787	 0.02156	 0.013958	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83447	 24739	 0.022198	 0.016332	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24740	 24741	 0.011346	 0.008979	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24740	 24788	 0.019604	 0.015514	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24741	 24748	 0.02511	 0.019872	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24742	 24748	 0.012803	 0.008289	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24743	 24744	 0.018004	 0.013015	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24743	 24753	 0.020687	 0.016371	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24743	 24778	 0.024354	 0.017918	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24745	 83465	 0.020256	 0.013114	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24746	 24747	 0.012661	 0.008197	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24746	 83465	 0.026416	 0.026681	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24747	 24749	 0.027296	 0.021396	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24747	 83462	 0.00753	 0.017481	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24748	 24749	 0.003324	 0.008454	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24749	 24750	 0.00447	 0.010377	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24749	 24753	 0.01828	 0.014329	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24750	 83460	 0.003301	 0.008555	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24751	 24763	 0.001006	 0.002658	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24751	 24774	 0.005135	 0.013786	 0.00312	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24751	 83460	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24751	 83460	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24752	 24755	 0.010768	 0.007784	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83460	 24752	 0.015348	 0.012147	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24753	 24754	 0.015003	 0.01176	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24753	 24780	 0.044735	 0.033893	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24754	 24777	 0.004734	 0.009374	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24755	 24768	 0.012542	 0.012579	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24755	 24769	 0.012479	 0.008079	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24756	 24854	 7.1e-05	 0.000825	 0.00723	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24756	 83461	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24756	 83461	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81944	 24757	 0.003555	 0.009395	 0.0022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83373	 24757	 0.002437	 0.006327	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83461	 24757	 0.001356	 0.003584	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24757	 83462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24757	 83462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24757	 83487	 0.016738	 0.038858	 0.01184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24758	 24759	 0.00545	 0.0087	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24758	 83494	 0.002813	 0.008628	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24759	 83463	 0.011636	 0.009209	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24760	 24762	 0.001577	 0.004399	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24760	 83463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24760	 83463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24761	 24764	 0.001428	 0.003981	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24761	 83493	 0.002023	 0.006818	 0.00169	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24762	 24763	 0.001501	 0.003966	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24762	 83464	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24762	 83464	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24763	 24764	 0.000805	 0.002191	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24763	 83465	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24763	 83465	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24765	 83466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24765	 83466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24766	 83467	 0.000905	 0.048849	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24766	 83467	 0.000905	 0.048849	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83460	 24767	 0.005544	 0.012872	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83467	 24767	 0.00469	 0.012055	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24768	 24769	 0.005481	 0.010852	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24768	 24771	 0.019075	 0.013511	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83467	 24768	 0.001913	 0.01019	 0.00018	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24769	 24777	 0.005958	 0.00951	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24770	 24771	 0.007121	 0.008524	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24770	 24780	 0.013433	 0.010631	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24771	 24772	 0.014079	 0.011035	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24772	 24773	 0.022547	 0.017843	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83467	 24772	 0.005957	 0.015439	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24772	 83468	 0.031055	 0.020105	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24773	 83468	 0.017154	 0.013575	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24774	 24837	 0.001607	 0.004374	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24774	 83468	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24774	 83468	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24775	 24778	 0.021043	 0.016653	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24775	 24779	 0.007333	 0.014519	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24776	 83469	 0.021386	 0.016925	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24777	 24780	 0.017503	 0.012878	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24778	 83476	 0.047816	 0.037481	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24779	 24780	 0.015335	 0.012021	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24779	 83469	 0.005415	 0.012569	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24779	 83489	 0.025261	 0.032874	 0.00046	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83468	 24780	 0.028289	 0.0217	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83468	 24781	 0.016664	 0.013188	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24781	 83469	 0.006486	 0.010353	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24782	 24838	 0.001616	 0.004195	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24782	 24839	 0.003213	 0.008626	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24782	 83469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24782	 83469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24783	 83470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24783	 83470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24784	 83471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24784	 83471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24784	 83473	 0.001518	 0.005208	 0.00125	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24785	 83472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24785	 83472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24785	 83473	 0.000859	 0.002946	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24786	 24789	 0.012763	 0.010101	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83470	 24786	 0.019225	 0.015214	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24787	 24793	 0.03374	 0.025563	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24788	 24793	 0.017805	 0.013099	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24789	 24795	 0.041213	 0.026681	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24790	 24796	 0.000111	 0.001239	 0.01168	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24790	 83473	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83474	 24791	 0.020046	 0.015187	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24791	 83475	 0.01647	 0.014758	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24792	 24793	 0.023358	 0.017917	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24792	 24795	 0.023451	 0.018559	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24793	 24794	 0.016589	 0.016638	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24793	 83476	 0.017937	 0.035513	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24794	 83476	 0.009405	 0.018621	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24795	 24799	 0.018301	 0.032893	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24796	 24807	 9.3e-05	 0.001076	 0.00943	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24796	 24828	 0.0004	 0.004531	 0.04126	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24796	 83475	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24796	 83475	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24797	 24800	 0.02577	 0.018629	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83475	 24797	 0.008758	 0.015403	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83473	 24798	 0.005415	 0.014311	 0.00335	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24798	 83476	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24798	 83476	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24798	 83484	 0.008196	 0.021661	 0.00507	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83476	 24799	 0.023202	 0.018362	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24799	 83482	 0.007089	 0.027275	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24800	 24821	 0.034374	 0.027203	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24801	 24823	 0.037549	 0.027626	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24801	 83478	 0.025733	 0.033821	 0.00046	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83445	 24802	 0.055441	 0.035893	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24802	 83478	 0.017285	 0.049049	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24803	 24804	 0.029917	 0.021192	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24804	 24851	 0.047708	 0.0351	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24804	 83477	 0.027802	 0.035383	 0.00052	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24805	 24806	 0.002736	 0.007925	 0.00191	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83435	 24805	 0.001305	 0.006176	 0.00148	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24806	 83477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24806	 83477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24807	 24822	 0.000307	 0.003538	 0.03102	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24807	 83478	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24807	 83478	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24808	 24815	 0.012589	 0.033278	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24808	 24819	 0.089773	 0.071047	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83477	 24808	 0.007385	 0.028411	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83478	 24808	 0.046321	 0.083581	 0.00121	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24809	 24810	 0.004235	 0.014968	 0.00337	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24809	 83479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24809	 83479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24810	 24812	 0.005133	 0.013564	 0.00317	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83413	 24810	 0.015833	 0.043111	 0.0095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24810	 83480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24810	 83480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83479	 24811	 0.017337	 0.031754	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83480	 24811	 0.034459	 0.02727	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24812	 83481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24812	 83481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24813	 24814	 0.01145	 0.029434	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83481	 24813	 0.010137	 0.023182	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81966	 24814	 0.010445	 0.029958	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83479	 24815	 0.010895	 0.028006	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83480	 24815	 0.061902	 0.062523	 0.00083	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24816	 24817	 0.026763	 0.048103	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81966	 24817	 0.011231	 0.043692	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24818	 24819	 0.074001	 0.05242	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24818	 24820	 0.028241	 0.047573	 0.00068	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83102	 24819	 0.10201	 0.13276	 0.00186	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24820	 24824	 0.020283	 0.038333	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24821	 83482	 0.01061	 0.01702	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24822	 24828	 0.000144	 0.001667	 0.01461	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24822	 83482	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24822	 83482	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83482	 24823	 0.028361	 0.043447	 0.00061	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24824	 83483	 0.005786	 0.019301	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24825	 83483	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24825	 83483	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24825	 83484	 0.002907	 0.007915	 0.00174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24826	 24830	 0.047634	 0.037697	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83101	 24826	 0.16197	 0.12697	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24826	 83491	 0.015979	 0.022269	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24827	 83491	 0.057029	 0.043745	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24828	 24836	 6.9e-05	 0.000758	 0.00736	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24828	 83484	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83483	 24829	 0.028246	 0.020782	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83485	 24829	 0.032157	 0.025448	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83483	 24830	 0.022867	 0.01653	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83485	 24830	 0.029446	 0.023303	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24831	 24842	 0.019511	 0.02146	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83468	 24831	 0.033636	 0.03592	 0.00076	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83485	 24831	 0.072145	 0.05534	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24831	 83486	 0.006427	 0.014699	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24831	 83490	 0.030058	 0.023561	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24832	 24839	 0.001288	 0.004338	 0.00108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24832	 83486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24832	 83486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24832	 83487	 0.001252	 0.006523	 0.00171	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83486	 24833	 0.017143	 0.013567	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83486	 24834	 0.016055	 0.016216	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24834	 83488	 0.007789	 0.01135	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24835	 24836	 5.4e-05	 0.000625	 0.00547	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24835	 83487	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 -1.0	 1	 -30.0	 30.0;
	24835	 83487	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 -1.0	 1	 -30.0	 30.0;
	24836	 83488	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24836	 83488	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81955	 24837	 0.003034	 0.016067	 0.00407	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24838	 24839	 0.001609	 0.004177	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24838	 83489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24838	 83489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83484	 24839	 0.003963	 0.010473	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24839	 83490	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24839	 83490	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81956	 24840	 0.014637	 0.024656	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24840	 83491	 0.056572	 0.044344	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24841	 24842	 0.011946	 0.021554	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81956	 24841	 0.019762	 0.031544	 0.00073	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24843	 24844	 0.004238	 0.011201	 0.00262	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81955	 24843	 0.002622	 0.008551	 0.00227	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24843	 83491	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24843	 83491	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24845	 24846	 0.001733	 0.004456	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83484	 24845	 0.003681	 0.012629	 0.00303	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24847	 83492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24847	 83492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83353	 24848	 0.00974	 0.025038	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83359	 24848	 0.005566	 0.015794	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83358	 24849	 0.00486	 0.018907	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83364	 24850	 0.014659	 0.010785	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83478	 24851	 0.007979	 0.025586	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24853	 83493	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24854	 83495	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24854	 83495	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81975	 24855	 0.000446	 0.001986	 3e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82869	 24856	 0.0281	 0.099361	 0.0224	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24856	 83496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24856	 83496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24856	 83497	 0.011318	 0.043023	 0.01204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82758	 24857	 0.15248	 0.36123	 0.00661	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83496	 24857	 0.20836	 0.20845	 0.00282	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24858	 24859	 0.009499	 0.037335	 0.00977	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24860	 83497	 0.000491	 0.006288	 0.00188	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24861	 83498	 0.00694	 0.023151	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24862	 83497	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83497	 24863	 0.00089	 0.003113	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24864	 24865	 0.000645	 0.007079	 0.06877	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24864	 27296	 0.001844	 0.021301	 0.18691	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24864	 83499	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24864	 83499	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24865	 26413	 0.000486	 0.005333	 0.05181	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24865	 83500	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24865	 83500	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24866	 83501	 0.22993	 0.18026	 0.00231	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24866	 83555	 0.25739	 0.16668	 0.00317	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82004	 24867	 0.10733	 0.10544	 0.00178	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82004	 24868	 0.021818	 0.12259	 0.00227	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24868	 84442	 0.043437	 0.19032	 0.00409	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24869	 27337	 0.001962	 0.021958	 0.20537	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81996	 24869	 0.002209	 0.025519	 0.22402	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82006	 24869	 0.000212	 0.003826	 0.06038	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24869	 83501	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24869	 83501	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24870	 24878	 0.002574	 0.038523	 0.01295	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24870	 26386	 0.00302	 0.025127	 0.00761	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24870	 27257	 0.009528	 0.031077	 0.00825	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24871	 83506	 0.040508	 0.10302	 0.00163	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24872	 24876	 0.084693	 0.054832	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24873	 83502	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24873	 83502	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24873	 83508	 0.00043	 0.00585	 0.06027	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24874	 24900	 0.057232	 0.091356	 0.0021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24874	 24901	 0.057582	 0.10127	 0.0019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24874	 83510	 0.030174	 0.070052	 0.00104	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24875	 24892	 0.001418	 0.005135	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24875	 83503	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24875	 83503	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24875	 83509	 0.0021	 0.008407	 0.00212	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24876	 83513	 0.012254	 0.031164	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24877	 83504	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24877	 83508	 0.000307	 0.003432	 0.03206	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24878	 26376	 0.016094	 0.10198	 0.0277	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83504	 24878	 0.000827	 0.007325	 0.00402	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24878	 83506	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24878	 83506	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24878	 83514	 0.00134	 0.010505	 0.0048	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83506	 24879	 0.1244	 0.098451	 0.00124	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24880	 24899	 0.000505	 0.005624	 0.05304	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24880	 25119	 0.002953	 0.034138	 0.30002	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24880	 83507	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24880	 83507	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24881	 24954	 0.002601	 0.023707	 0.00861	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24881	 83520	 0.001106	 0.011934	 0.00342	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24882	 83508	 0.000129	 0.010315	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24882	 83508	 0.000129	 0.010315	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24882	 83508	 0.000129	 0.010315	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24883	 27128	 0.004396	 0.049133	 0.46596	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83508	 24883	 0.00015	 0.001729	 0.01516	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24883	 83511	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83510	 24884	 0.040138	 0.031764	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24885	 24957	 0.13802	 0.11362	 0.0023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83510	 24885	 0.031337	 0.056325	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24886	 83513	 0.018197	 0.014401	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24887	 24891	 0.000656	 0.002626	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24887	 24902	 0.001618	 0.004201	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83504	 24887	 0.002991	 0.01083	 0.00232	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24887	 83513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24887	 83513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24888	 24902	 0.001323	 0.003832	 0.00092	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83504	 24888	 0.002846	 0.00775	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24889	 24896	 9.7e-05	 0.00112	 0.00982	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24889	 24897	 5.1e-05	 0.000565	 0.00528	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24889	 83514	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24889	 83514	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24890	 83516	 0.008225	 0.016284	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24890	 83518	 0.005875	 0.008561	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24891	 24892	 0.001329	 0.004132	 0.00086	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24891	 83515	 0.001795	 0.004513	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24893	 24894	 0.014285	 0.011305	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83503	 24893	 0.020801	 0.016304	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24894	 24895	 0.004267	 0.007934	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83510	 24894	 0.008142	 0.020931	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83513	 24895	 0.010665	 0.020902	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24895	 83516	 0.011681	 0.011798	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83508	 24896	 0.0001	 0.0011	 0.01068	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24896	 83515	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24897	 24899	 7.4e-05	 0.000851	 0.00746	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24897	 83517	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83517	 24898	 0.000762	 0.002014	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24898	 83519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24898	 83519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83508	 24899	 0.000147	 0.001696	 0.01487	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24899	 83520	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24900	 24901	 0.079026	 0.057129	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24900	 84578	 0.020065	 0.051579	 0.0008	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24901	 84578	 0.024265	 0.06629	 0.00113	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83515	 24902	 0.001528	 0.005243	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24903	 26920	 0.073865	 0.1353	 0.00234	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24903	 83523	 0.042295	 0.10873	 0.00168	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24903	 84422	 0.12965	 0.25414	 0.00381	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24903	 84616	 0.059811	 0.095474	 0.0022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24904	 26442	 0.016032	 0.043653	 0.00962	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24904	 83522	 0.01229	 0.033461	 0.00737	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24905	 24908	 0.022102	 0.039726	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24905	 83523	 0.099352	 0.078628	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24906	 27277	 0.000977	 0.010725	 0.1042	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24906	 27739	 0.001102	 0.012099	 0.11756	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24906	 83522	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24907	 24909	 0.071961	 0.056949	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83523	 24907	 0.047507	 0.03644	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24907	 83524	 0.069033	 0.054633	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24908	 24909	 0.06778	 0.053641	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24908	 84417	 0.023887	 0.076601	 0.0019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24909	 83524	 0.093829	 0.074257	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24909	 84417	 0.033507	 0.088578	 0.00161	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24910	 24911	 0.010901	 0.028024	 0.00694	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83522	 24910	 0.005484	 0.014723	 0.00334	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24910	 83524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24910	 83524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24911	 27750	 0.013071	 0.034545	 0.00809	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24912	 26425	 0.016617	 0.054205	 0.01439	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24912	 27276	 0.010521	 0.027315	 0.00663	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24912	 83525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24912	 83525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24913	 84097	 0.053612	 0.10972	 0.0027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24913	 84117	 0.068059	 0.19522	 0.003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24914	 83526	 0.001396	 0.003963	 6e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24915	 83526	 0.010875	 0.019621	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24916	 83526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24916	 83526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24916	 83527	 0.008216	 0.036993	 0.00984	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24917	 24935	 0.063668	 0.12034	 0.00195	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83526	 24917	 0.021175	 0.06496	 0.00176	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24917	 83528	 0.011157	 0.05802	 0.00126	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24918	 83527	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95339	 24918	 0.001336	 0.025689	 0.50414	 1959.0	 2056.9	 2154.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24919	 24921	 0.000136	 0.002417	 0.00122	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24919	 24924	 0.000412	 0.006434	 0.0042	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24920	 24926	 0.005843	 0.033215	 0.0006	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24920	 24927	 0.007124	 0.027713	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24920	 24927	 0.007124	 0.027713	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82061	 24920	 0.006161	 0.023702	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82061	 24920	 0.006161	 0.023702	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24920	 83531	 0.01182	 0.027032	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82010	 24921	 0.000363	 0.006441	 0.00324	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24921	 83529	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24921	 83529	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83529	 24922	 0.010454	 0.016014	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24923	 24928	 0.001315	 0.01394	 0.00414	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24923	 83530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24923	 83530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24924	 24934	 0.010781	 0.031785	 0.00739	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81999	 24924	 0.002867	 0.046773	 0.02792	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24924	 83531	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24924	 83531	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24925	 24929	 0.000917	 0.014078	 0.00394	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24925	 83532	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24925	 83532	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83531	 24926	 0.002833	 0.011023	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83531	 24926	 0.002833	 0.011023	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83532	 24926	 0.015223	 0.058565	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83532	 24926	 0.015223	 0.058565	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83532	 24927	 0.022731	 0.081204	 0.00161	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83532	 24927	 0.022731	 0.081204	 0.00161	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24927	 83535	 0.04576	 0.10624	 0.00158	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24928	 24930	 0.001147	 0.012907	 0.00339	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24929	 24930	 0.001733	 0.010977	 0.00298	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24929	 24932	 0.005963	 0.01576	 0.00369	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81999	 24929	 0.002683	 0.041753	 0.01295	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24930	 83533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24930	 83533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24930	 84142	 0.001294	 0.011882	 0.0102	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24931	 24938	 0.056317	 0.13075	 0.00194	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24931	 83534	 0.038228	 0.098271	 0.00152	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24932	 83534	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24932	 83534	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24933	 83535	 0.15629	 0.12252	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24934	 83535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24934	 83535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24936	 24937	 0.020671	 0.11313	 0.00221	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24936	 27604	 0.029129	 0.11161	 0.00316	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83535	 24937	 0.023315	 0.14641	 0.0032	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24938	 83969	 0.082531	 0.19546	 0.00357	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24939	 24940	 0.000303	 0.003496	 0.03065	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24939	 83536	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24939	 83536	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24940	 24942	 0.00035	 0.003965	 0.0361	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24941	 24945	 0.002459	 0.021181	 0.0123	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24941	 26421	 0.002734	 0.019776	 0.01064	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24942	 83537	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24942	 83537	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24943	 24953	 0.017657	 0.012508	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24944	 24952	 0.001119	 0.003397	 0.00074	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83537	 24944	 0.005189	 0.015299	 0.00356	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24945	 24951	 0.004549	 0.018212	 0.00459	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82001	 24945	 0.006976	 0.059543	 0.05117	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83537	 24945	 0.003785	 0.013189	 0.00306	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24945	 83538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24945	 83538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24946	 24948	 0.005458	 0.032513	 0.00855	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24946	 24950	 0.002059	 0.017969	 0.00494	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24946	 24952	 0.00431	 0.011733	 0.00258	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24947	 24953	 0.013021	 0.048146	 0.00089	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24947	 27135	 0.081785	 0.27288	 0.00433	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24948	 27734	 0.008127	 0.043303	 0.01215	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24949	 27721	 0.00062	 0.006903	 0.0651	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24949	 83539	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24949	 83539	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24950	 83540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24950	 83540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24950	 84268	 0.002915	 0.029205	 0.00972	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24951	 84581	 0.012685	 0.044841	 0.0101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24952	 83541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24952	 83541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83538	 24953	 0.02771	 0.05824	 0.00106	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83541	 24953	 0.001866	 0.007403	 0.00021	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24954	 26594	 0.003243	 0.027818	 0.00792	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24955	 24956	 0.004904	 0.01296	 0.00303	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24955	 24962	 0.007991	 0.027414	 0.00657	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83511	 24955	 0.006225	 0.020303	 0.00539	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24956	 24959	 0.007448	 0.047179	 0.01281	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24956	 24962	 0.003284	 0.014787	 0.00393	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83511	 24956	 0.009968	 0.034195	 0.00819	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24956	 83542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24956	 83542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83542	 24957	 0.031742	 0.02055	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24958	 24964	 0.010342	 0.026587	 0.00658	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83502	 24958	 0.012622	 0.033359	 0.00781	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24959	 24960	 0.004813	 0.016512	 0.00396	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24959	 24961	 0.011459	 0.029457	 0.00729	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24959	 24964	 0.002808	 0.011882	 0.00267	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24960	 26952	 0.007019	 0.028091	 0.00949	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24960	 83543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24960	 83543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24961	 27359	 0.00747	 0.019743	 0.00462	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24961	 83544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24961	 83544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24962	 27358	 0.00874	 0.031648	 0.00679	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24962	 27361	 0.01847	 0.065296	 0.01472	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24962	 83545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24962	 83545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83543	 24963	 0.13408	 0.086809	 0.00165	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24963	 83546	 0.008476	 0.019674	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24963	 84274	 0.035071	 0.080209	 0.00196	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24964	 26948	 0.006088	 0.027929	 0.00715	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24964	 83546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24964	 83546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24965	 83553	 0.013726	 0.036283	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24966	 83547	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24967	 26470	 0.016925	 0.081664	 0.00144	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83548	 24967	 0.013443	 0.067236	 0.0012	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24968	 24969	 0.004963	 0.023146	 0.00573	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24968	 24982	 0.003052	 0.03418	 0.01087	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24968	 26397	 0.008217	 0.0329	 0.00829	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24968	 83549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24968	 83549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24969	 24971	 0.004504	 0.025129	 0.00642	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24970	 24983	 0.025802	 0.13053	 0.00227	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24970	 83550	 0.010073	 0.069143	 0.00126	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24971	 83550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24971	 83550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24971	 84365	 0.010219	 0.10144	 0.0276	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83550	 24972	 0.19114	 0.12377	 0.00236	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24973	 26976	 0.38152	 0.30207	 0.0038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24973	 83551	 0.16392	 0.12974	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24974	 24975	 0.000875	 0.012015	 0.00433	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82035	 24974	 0.001039	 0.015136	 0.00484	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24974	 83551	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24974	 83551	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83547	 24975	 0.001487	 0.014732	 0.00451	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24975	 83552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24975	 83552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24976	 24977	 0.002336	 0.009546	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83552	 24976	 0.006324	 0.02423	 0.00068	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24977	 24978	 0.023506	 0.016651	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24979	 24981	 0.000576	 0.004595	 0.00113	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83547	 24979	 0.001766	 0.013533	 0.00363	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24980	 24981	 0.000745	 0.003528	 0.00085	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24980	 26472	 0.004209	 0.018321	 0.00522	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24981	 83553	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24981	 83553	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83547	 24982	 0.002466	 0.02775	 0.00729	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24983	 24984	 0.00793	 0.045078	 0.00082	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83548	 24984	 0.008901	 0.054721	 0.00099	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24985	 24986	 0.07402	 0.1247	 0.00178	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24985	 25182	 0.061816	 0.14352	 0.00213	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24985	 83617	 0.03948	 0.10041	 0.00159	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24986	 83554	 0.069139	 0.17774	 0.00275	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24986	 84091	 0.10608	 0.3011	 0.00473	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24987	 83629	 0.022989	 0.060932	 0.00155	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24988	 24989	 0.002904	 0.022878	 0.00669	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24988	 24992	 0.005884	 0.036516	 0.00885	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24988	 26414	 0.004189	 0.029046	 0.01703	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24988	 83554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24988	 83554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24989	 24990	 0.014135	 0.048493	 0.01162	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82007	 24989	 0.019509	 0.076695	 0.02007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24990	 24992	 0.017382	 0.045942	 0.01075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82007	 24990	 0.004041	 0.032257	 0.00795	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24990	 83555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24990	 83555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83555	 24991	 0.048774	 0.077855	 0.00179	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24991	 83556	 0.12967	 0.10164	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82007	 24992	 0.018256	 0.071768	 0.01878	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82032	 24992	 0.029154	 0.10309	 0.02324	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24992	 83556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24992	 83556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83554	 24993	 0.14597	 0.16057	 0.00214	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83556	 24993	 0.034954	 0.089855	 0.00139	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24994	 24995	 0.020149	 0.015455	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24994	 24997	 0.009545	 0.027375	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24994	 83564	 0.006346	 0.016313	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24996	 24997	 0.017182	 0.013598	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24997	 24998	 0.014139	 0.010221	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24997	 83557	 0.01056	 0.022629	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24997	 83570	 0.048159	 0.035432	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24999	 25025	 0.000624	 0.006994	 0.00222	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24999	 83557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24999	 83557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25000	 25001	 0.006795	 0.01761	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25000	 25013	 0.003461	 0.019445	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82058	 25000	 0.010907	 0.022414	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25001	 25070	 0.013619	 0.022325	 0.00039	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25001	 25072	 0.031311	 0.061994	 0.00091	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25001	 83560	 0.061501	 0.15811	 0.00245	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25001	 83595	 0.02234	 0.027234	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25002	 25003	 0.000321	 0.003609	 0.00095	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25002	 25069	 0.000287	 0.002484	 0.00089	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25003	 25071	 0.000404	 0.005174	 0.00154	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25003	 83558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25003	 83558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25004	 25005	 0.010915	 0.027091	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25004	 83560	 0.011954	 0.00946	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82233	 25005	 0.031836	 0.16106	 0.0028	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25005	 83559	 0.049312	 0.039025	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25006	 83559	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25006	 83559	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25006	 83561	 0.002037	 0.005289	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25007	 83560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25007	 83560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25007	 83561	 0.003258	 0.011798	 0.00253	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25008	 25012	 0.10153	 0.079588	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25008	 25072	 0.035098	 0.080269	 0.00196	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83560	 25008	 0.003351	 0.008615	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25009	 25010	 0.000525	 0.006098	 0.05272	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25009	 27252	 0.000449	 0.007884	 0.08436	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25009	 83561	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25009	 83561	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25010	 26358	 0.000364	 0.004127	 0.03757	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25010	 83562	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25010	 83562	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25011	 83584	 0.10622	 0.084065	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25013	 25014	 0.006602	 0.029417	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82041	 25014	 0.022361	 0.052951	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25015	 25071	 0.000907	 0.013203	 0.00423	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25015	 84070	 0.001658	 0.024376	 0.00745	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25016	 83564	 0.016196	 0.02481	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25017	 25018	 0.000974	 0.006168	 0.00167	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25017	 25023	 0.000535	 0.004167	 0.00125	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25017	 83563	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25017	 83563	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25018	 25019	 0.001184	 0.003861	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25018	 83564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25018	 83564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25019	 83565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25019	 83565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25020	 25021	 0.000528	 0.004799	 0.00121	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25020	 26293	 0.001026	 0.00758	 0.00219	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25020	 83566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25020	 83566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25021	 25022	 0.000781	 0.005852	 0.00143	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25021	 83567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25021	 83567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25022	 25027	 0.004488	 0.011652	 0.00283	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25022	 83576	 0.00286	 0.007559	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25023	 26290	 0.001289	 0.006355	 0.00172	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25023	 83568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25023	 83568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83568	 25024	 0.032349	 0.0238	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82040	 25025	 0.001334	 0.012213	 0.00489	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25025	 83569	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25025	 83569	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83569	 25026	 0.023442	 0.037418	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25026	 83570	 0.007186	 0.023715	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25026	 83572	 0.051789	 0.039237	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25027	 83570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25027	 83570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25028	 25030	 0.013453	 0.023659	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25028	 25039	 0.025867	 0.020276	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25028	 83578	 0.008086	 0.022945	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25029	 25030	 0.005289	 0.016225	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25029	 83580	 0.004769	 0.02626	 0.00059	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25030	 25044	 0.046193	 0.032721	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25030	 84594	 0.008421	 0.028092	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25031	 25033	 0.000165	 0.002096	 0.01843	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25031	 25038	 0.000207	 0.002406	 0.0208	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25031	 26309	 0.0004	 0.005041	 0.04914	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25031	 83571	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83572	 25032	 0.00374	 0.014607	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25032	 83578	 0.01677	 0.038352	 0.00094	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25032	 83579	 0.042655	 0.033435	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25033	 25050	 0.000319	 0.005395	 0.06221	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25033	 83573	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25033	 83573	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25034	 83574	 0.015259	 0.030211	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25034	 84593	 0.029068	 0.028555	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25035	 25040	 0.000836	 0.010879	 0.00314	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25035	 83574	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25035	 83574	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25035	 83575	 0.000488	 0.007449	 0.0024	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25036	 25046	 0.000132	 0.00149	 0.01356	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25036	 27712	 0.000522	 0.005813	 0.05482	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25036	 83575	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25036	 83575	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83571	 25037	 0.001763	 0.005751	 0.00153	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25037	 83576	 0.002683	 0.009714	 0.00208	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25038	 83576	 0.000119	 0.009548	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83576	 25040	 0.001445	 0.010708	 0.00549	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25040	 83578	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25040	 83578	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83574	 25041	 0.011536	 0.027516	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83578	 25041	 0.015857	 0.02084	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25041	 83579	 0.009842	 0.028229	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25042	 25043	 0.002419	 0.006587	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25042	 25045	 0.00183	 0.008398	 0.00215	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83576	 25042	 0.000785	 0.006731	 0.00192	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83571	 25043	 0.001604	 0.004729	 0.0011	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25043	 83579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25043	 83579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25044	 26307	 0.02532	 0.027849	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25045	 26313	 0.00276	 0.007295	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25045	 27705	 0.002903	 0.024895	 0.00708	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83576	 25045	 0.001282	 0.011663	 0.00294	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25045	 83580	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25045	 83580	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25046	 25063	 0.000184	 0.002124	 0.01862	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25046	 83581	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25047	 25050	 0.000346	 0.00399	 0.03498	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25047	 83583	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25047	 83583	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25048	 25064	 0.002385	 0.007958	 0.00202	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25048	 25066	 0.002513	 0.014285	 0.00414	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25048	 83584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25048	 83584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25048	 83596	 0.000725	 0.007944	 0.0022	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25049	 25066	 0.001641	 0.013183	 0.00371	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25049	 83585	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25049	 83585	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25049	 84582	 0.000888	 0.008064	 0.00263	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25050	 25057	 0.000115	 0.001328	 0.01164	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25050	 25073	 0.000289	 0.004163	 0.0382	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25050	 27128	 0.00043	 0.004717	 0.04582	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25050	 83586	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25050	 83586	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25051	 25054	 0.000362	 0.00405	 0.00129	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25051	 83587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25051	 83587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25051	 84582	 0.000891	 0.008516	 0.00281	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25052	 25053	 0.000614	 0.005893	 0.00171	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25052	 27718	 0.000859	 0.009104	 0.0027	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25052	 83588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25052	 83588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25053	 25062	 0.000463	 0.004963	 0.00129	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25054	 25055	 0.000232	 0.002831	 0.00094	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25055	 25059	 0.001327	 0.004806	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25055	 83593	 0.000503	 0.00411	 0.00112	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25056	 25064	 0.002083	 0.007018	 0.00174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25056	 83589	 0.00076	 0.002608	 0.00062	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25057	 25067	 4.6e-05	 0.0005	 0.00491	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25057	 83589	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25057	 83589	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25058	 83590	 0.019118	 0.01513	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25058	 83594	 0.020035	 0.015856	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25059	 25060	 0.00073	 0.002197	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25060	 25061	 0.000688	 0.002433	 0.00055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25060	 83590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25060	 83590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25061	 25062	 0.001357	 0.004653	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25061	 83591	 0.001641	 0.006571	 0.00166	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25061	 83592	 0.000992	 0.003402	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25062	 83592	 0.001066	 0.006039	 0.0015	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25063	 25067	 0.000145	 0.001596	 0.0155	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25063	 83591	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25063	 83591	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25065	 83592	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25065	 83592	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25066	 27253	 0.011033	 0.027735	 0.00719	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25067	 83593	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82058	 25068	 0.000643	 0.002867	 5e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83557	 25068	 0.002859	 0.011121	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25068	 83595	 0.003632	 0.010306	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25069	 83595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25069	 83595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83558	 25070	 0.007786	 0.023909	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25073	 83596	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25073	 83596	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25074	 25078	 0.005782	 0.028059	 0.00641	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25074	 25195	 0.001931	 0.020201	 0.01331	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25074	 83597	 0.001371	 0.02028	 0.00698	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25075	 27427	 0.000273	 0.002996	 0.0291	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25075	 83597	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25075	 83597	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25076	 25077	 0.006142	 0.025359	 0.006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25076	 27451	 0.002888	 0.012867	 0.0035	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83597	 25076	 0.00793	 0.028714	 0.00616	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25077	 25078	 0.005913	 0.03184	 0.00875	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25077	 83598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25077	 83598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25078	 25079	 0.006586	 0.025886	 0.00677	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25078	 26463	 0.022438	 0.08822	 0.02309	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25078	 83599	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25078	 83599	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25079	 26460	 0.007192	 0.028797	 0.00726	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25080	 26395	 0.025569	 0.11441	 0.00236	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83599	 25080	 0.029109	 0.10192	 0.00282	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25081	 25090	 0.10701	 0.084693	 0.00107	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25081	 84166	 0.21206	 0.16785	 0.00211	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25082	 25086	 0.07772	 0.13093	 0.00187	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25082	 84278	 0.075742	 0.19472	 0.00301	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25083	 25085	 0.005133	 0.013567	 0.00318	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25083	 25087	 0.007106	 0.018268	 0.00452	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25083	 83600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25083	 83600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83600	 25084	 0.069828	 0.055261	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25084	 83601	 0.02988	 0.0216	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25085	 25088	 0.003319	 0.013289	 0.00335	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25085	 26600	 0.016354	 0.064288	 0.01682	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25085	 83601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25085	 83601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25086	 25117	 0.025753	 0.13028	 0.00227	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25086	 25118	 0.10819	 0.10822	 0.00146	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83600	 25086	 0.022897	 0.089076	 0.00149	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25087	 26601	 0.011746	 0.031536	 0.00715	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25088	 83602	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25088	 83602	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25088	 83611	 0.001869	 0.021364	 0.00652	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25089	 25112	 0.14215	 0.10277	 0.00156	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25089	 83612	 0.068519	 0.1463	 0.0033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83602	 25090	 0.027412	 0.15583	 0.00282	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25090	 84574	 0.056895	 0.15041	 0.00273	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25091	 25092	 0.00211	 0.010552	 0.00019	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25091	 25100	 0.00102	 0.0058	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25092	 25093	 0.004707	 0.013499	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25092	 25102	 0.012665	 0.014052	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25093	 25104	 0.005678	 0.016286	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25094	 25095	 0.000527	 0.003188	 0.00081	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25094	 83603	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25094	 83603	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25095	 25096	 0.00062	 0.002624	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25095	 25103	 0.003668	 0.009523	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25096	 25133	 0.000688	 0.003341	 0.00076	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25097	 25133	 0.00025	 0.001335	 0.00037	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25097	 83604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25097	 83604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25098	 25099	 0.002683	 0.014132	 0.00025	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83604	 25098	 0.001953	 0.009878	 0.00017	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25099	 83608	 0.001843	 0.010087	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25100	 83605	 0.001654	 0.009402	 0.00017	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25101	 25110	 0.000705	 0.005868	 0.00178	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25101	 83605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25101	 83605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25102	 83606	 0.009515	 0.015187	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25103	 25130	 0.002304	 0.020103	 0.00552	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25103	 83606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25103	 83606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25104	 25105	 0.005034	 0.01294	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25104	 25106	 0.008526	 0.018871	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25104	 83609	 0.014997	 0.042556	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25105	 25106	 0.006961	 0.018401	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83603	 25105	 0.003014	 0.011726	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25106	 83609	 0.00596	 0.029808	 0.00053	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25107	 25113	 0.003435	 0.012026	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83603	 25107	 0.002098	 0.014231	 0.00027	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25108	 25110	 0.000758	 0.01122	 0.00386	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25108	 25134	 0.000549	 0.005648	 0.0016	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25108	 83607	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25108	 83607	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25109	 25123	 0.026943	 0.077277	 0.00119	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82060	 25109	 0.009318	 0.022807	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25110	 25127	 0.001533	 0.010938	 0.00339	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25110	 83608	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25110	 83608	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25110	 83977	 0.003234	 0.032581	 0.01998	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25111	 25119	 0.000373	 0.004095	 0.03978	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25111	 26141	 0.000745	 0.01182	 0.12416	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25111	 26805	 0.000617	 0.010766	 0.11651	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25111	 27196	 0.001063	 0.018657	 0.19978	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25111	 83609	 0.001096	 0.056989	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25111	 83609	 0.001096	 0.056989	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25112	 25131	 0.028022	 0.084342	 0.00165	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25112	 26804	 0.031818	 0.09126	 0.0014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25113	 25115	 0.010979	 0.017996	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25113	 25120	 0.012857	 0.035612	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25114	 25134	 0.000661	 0.004109	 0.00116	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25114	 83610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25114	 83610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25114	 83611	 0.003941	 0.015779	 0.00398	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25115	 25120	 0.004374	 0.021874	 0.00039	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83610	 25115	 0.002911	 0.016549	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25116	 25118	 0.016465	 0.038225	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83607	 25116	 0.008125	 0.029026	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25117	 25121	 0.009806	 0.060288	 0.00109	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25119	 83611	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83601	 25120	 0.043611	 0.11529	 0.00209	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83612	 25120	 0.032545	 0.032553	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25121	 25122	 0.026822	 0.028643	 0.00061	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25121	 84286	 0.02162	 0.057302	 0.00145	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25122	 83613	 0.027238	 0.063237	 0.00094	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25123	 83613	 0.028396	 0.058111	 0.00143	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25124	 83613	 0.013119	 0.025975	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25125	 26110	 0.003623	 0.012085	 0.00306	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25125	 83613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25125	 83613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25126	 25128	 0.000701	 0.006727	 0.00196	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25126	 26110	 0.00086	 0.009112	 0.0027	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25126	 83614	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25126	 83614	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25127	 25129	 0.00103	 0.008775	 0.00219	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25128	 25129	 0.000573	 0.004819	 0.00143	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25129	 83615	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25129	 83615	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25130	 26133	 0.005424	 0.031107	 0.01034	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25130	 26135	 0.002884	 0.024732	 0.00704	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25130	 26809	 0.011441	 0.07483	 0.01904	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25131	 25132	 0.034027	 0.086191	 0.00171	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83609	 25131	 0.037894	 0.083871	 0.00138	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25132	 26136	 0.051977	 0.13219	 0.00209	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25133	 83616	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25133	 83616	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25135	 25136	 0.004819	 0.012938	 0.00293	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25135	 25152	 0.009088	 0.038466	 0.00866	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25135	 83617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25135	 83617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25136	 25137	 0.005692	 0.015042	 0.00352	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25137	 83618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25137	 83618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25137	 83619	 0.006331	 0.015915	 0.00412	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25138	 25142	 0.000151	 0.001739	 0.01525	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25138	 27714	 0.000203	 0.002226	 0.02162	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25138	 83619	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25138	 83619	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83618	 25139	 0.025582	 0.059393	 0.00088	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25139	 83627	 0.029131	 0.059615	 0.00147	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25140	 25141	 0.001929	 0.005252	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25140	 26335	 0.002268	 0.005993	 0.0014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25141	 83620	 0.003193	 0.008439	 0.00198	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25142	 25149	 0.00017	 0.001926	 0.01753	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25142	 83620	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25142	 83620	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25143	 25148	 0.000254	 0.002815	 0.0268	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25143	 26315	 0.000524	 0.005724	 0.0562	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25143	 83621	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25144	 25149	 7.5e-05	 0.000819	 0.00804	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25144	 83623	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83622	 25145	 0.007753	 0.01535	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83624	 25145	 0.012754	 0.019538	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83622	 25146	 0.010875	 0.027956	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83624	 25146	 0.071	 0.056189	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25146	 84055	 0.028981	 0.053081	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25147	 25166	 0.001265	 0.007652	 0.00195	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83623	 25147	 0.004121	 0.013885	 0.00345	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25147	 83625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25147	 83625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25147	 83626	 0.005026	 0.014016	 0.00294	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25148	 25149	 0.00011	 0.001234	 0.01153	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25148	 83626	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25149	 83628	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25149	 83628	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83628	 25150	 0.043935	 0.033287	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25151	 25154	 0.04302	 0.085177	 0.00125	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83627	 25151	 0.10168	 0.080474	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81997	 25152	 0.007071	 0.060654	 0.01726	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25152	 83629	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25152	 83629	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25153	 25154	 0.014542	 0.029759	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83629	 25153	 0.088425	 0.079782	 0.00134	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25154	 83630	 0.007044	 0.04004	 0.00072	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25155	 25156	 0.000641	 0.007331	 0.00224	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25155	 25158	 0.00189	 0.010371	 0.00274	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25155	 83630	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25155	 83630	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25156	 25168	 0.000415	 0.005219	 0.00162	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25157	 26341	 0.000341	 0.004233	 0.03922	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25157	 26346	 0.000223	 0.002529	 0.02303	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25157	 83631	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25158	 25161	 0.001113	 0.00652	 0.00178	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25158	 25162	 0.000489	 0.007186	 0.0022	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83627	 25159	 0.016832	 0.041777	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25159	 83633	 0.007049	 0.016364	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83632	 25160	 0.006909	 0.016037	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25160	 83634	 0.021739	 0.022198	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25161	 25165	 0.001108	 0.009055	 0.00246	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83631	 25161	 0.000496	 0.004389	 0.00241	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83626	 25162	 0.000829	 0.008383	 0.00246	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25162	 83633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25162	 83633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25163	 26345	 0.030708	 0.024302	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25163	 83634	 0.01268	 0.025106	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83631	 25164	 0.002817	 0.009663	 0.00231	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25164	 83634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25164	 83634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25164	 84063	 0.002275	 0.006013	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25165	 25166	 0.000971	 0.006865	 0.00188	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82033	 25167	 0.023887	 0.037272	 0.00062	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82032	 25168	 0.001677	 0.011628	 0.00682	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25169	 25171	 0.000238	 0.002641	 0.02515	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25169	 83635	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25169	 83635	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83635	 25170	 0.085275	 0.067487	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81996	 25171	 0.000247	 0.002796	 0.02546	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25172	 25173	 0.010346	 0.024016	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83629	 25172	 0.048191	 0.084752	 0.00159	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81998	 25173	 0.045158	 0.13869	 0.0026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81998	 25174	 0.073922	 0.096205	 0.00135	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25175	 83639	 0.10054	 0.19907	 0.00292	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25176	 25177	 0.000186	 0.002152	 0.01887	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25176	 26127	 0.000592	 0.006835	 0.05992	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25176	 83636	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25176	 83636	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25177	 25179	 0.000158	 0.001821	 0.01596	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25177	 83637	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25177	 83637	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25178	 83639	 0.00851	 0.021877	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25178	 83976	 0.086986	 0.17224	 0.00253	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25179	 83638	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25180	 25181	 0.009934	 0.026256	 0.00615	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25180	 27697	 0.011186	 0.029565	 0.00692	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25181	 26409	 0.01668	 0.056208	 0.01397	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83631	 25181	 0.011373	 0.087165	 0.02336	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25181	 83640	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25181	 83640	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83639	 25182	 0.050988	 0.14625	 0.00225	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83640	 25182	 0.049862	 0.092716	 0.00217	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25183	 26409	 0.018143	 0.047954	 0.01123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83638	 25183	 0.011165	 0.026906	 0.0076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25184	 25198	 0.004934	 0.017197	 0.00399	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25184	 26878	 0.006366	 0.021839	 0.00523	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25185	 25186	 0.000148	 0.001629	 0.01583	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25185	 83641	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25185	 83641	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25186	 25190	 0.0005	 0.005482	 0.05325	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25186	 83642	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25187	 26459	 0.11336	 0.2939	 0.00556	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83643	 25187	 0.008579	 0.043399	 0.00076	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25187	 83644	 0.033605	 0.07802	 0.00116	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25187	 83648	 0.053751	 0.11897	 0.00195	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25188	 25194	 0.006307	 0.025251	 0.00636	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25188	 83644	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25188	 83644	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25188	 83645	 0.002795	 0.010873	 0.0029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83644	 25189	 0.014338	 0.037903	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25189	 83646	 0.01368	 0.03176	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25190	 25205	 0.001549	 0.017885	 0.15689	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25190	 26862	 0.000606	 0.006714	 0.06393	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25190	 27385	 0.000452	 0.007926	 0.08481	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25190	 83645	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25191	 26874	 0.006471	 0.02739	 0.00616	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83645	 25191	 0.001307	 0.01545	 0.0044	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25191	 83647	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25191	 83647	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83647	 25192	 0.010444	 0.074376	 0.00167	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25192	 84477	 0.01347	 0.097555	 0.00245	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83646	 25193	 0.12854	 0.1659	 0.00333	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25194	 25195	 0.006796	 0.027211	 0.00686	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25195	 83651	 0.009006	 0.043953	 0.01214	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25196	 83652	 0.11327	 0.089647	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83642	 25197	 0.007727	 0.028112	 0.00861	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25197	 83648	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25197	 83648	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25197	 83653	 0.00298	 0.042026	 0.01437	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25198	 25199	 0.001964	 0.024209	 0.00782	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25198	 83649	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25198	 83649	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25199	 83650	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25199	 83650	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25199	 83651	 0.001498	 0.018093	 0.01026	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25200	 25201	 0.000217	 0.002517	 0.02176	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25200	 83651	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25201	 25202	 0.000188	 0.001985	 0.02969	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25201	 25202	 0.000188	 0.001985	 0.02969	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25201	 83653	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25201	 83653	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25202	 25203	 7.4e-05	 0.000748	 0.01217	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25202	 25203	 7.4e-05	 0.000748	 0.01217	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25203	 25206	 8.5e-05	 0.000841	 0.01439	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25203	 25206	 8.5e-05	 0.000841	 0.01439	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83652	 25204	 0.023518	 0.077611	 0.00126	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25204	 83655	 0.003326	 0.00954	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25205	 25206	 6.4e-05	 0.000661	 0.01038	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25205	 25206	 6.4e-05	 0.000661	 0.01038	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25205	 26848	 0.001549	 0.017255	 0.16282	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77677	 25205	 0.000338	 0.003486	 0.05477	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77677	 25205	 0.000338	 0.003486	 0.05477	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25205	 83654	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25205	 83654	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25206	 83655	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25206	 83655	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83650	 25207	 0.009323	 0.062303	 0.00138	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83654	 25207	 0.005181	 0.036898	 0.00083	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25208	 25216	 0.000287	 0.003929	 0.05877	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25208	 27648	 0.000679	 0.012102	 0.12556	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25208	 83656	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25208	 83656	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25209	 26426	 0.004086	 0.043841	 0.01141	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25209	 83659	 0.002035	 0.021141	 0.00654	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25210	 25212	 0.000674	 0.007777	 0.06818	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25210	 26473	 0.000715	 0.008252	 0.07235	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25210	 83657	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25210	 83657	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25211	 25215	 0.000101	 0.001822	 0.02875	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25211	 83658	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25211	 83658	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25212	 25213	 0.000101	 0.00125	 0.01255	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25212	 83659	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25212	 83659	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25213	 25214	 8.2e-05	 0.001017	 0.01022	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25213	 26483	 0.001973	 0.02237	 0.20388	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25213	 27739	 0.001299	 0.018808	 0.28929	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25213	 83660	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25213	 83660	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25214	 25215	 6.6e-05	 0.000997	 0.01787	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25214	 25216	 0.000121	 0.001292	 0.01897	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25215	 83661	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25215	 83661	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25216	 83662	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25216	 83662	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83662	 25217	 0.001194	 0.018807	 0.00641	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25217	 83663	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25217	 83663	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25217	 83979	 0.002549	 0.028844	 0.0162	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25218	 26438	 0.065362	 0.12942	 0.0019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25218	 83665	 0.047024	 0.12188	 0.0023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25219	 25220	 0.011852	 0.048438	 0.00098	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25219	 84639	 0.033125	 0.17451	 0.00313	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25220	 83664	 0.008832	 0.038693	 0.00083	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25221	 25222	 0.026945	 0.021324	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25221	 83664	 0.008024	 0.045084	 0.00083	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25221	 83665	 0.050639	 0.084576	 0.00144	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25223	 25224	 0.002873	 0.021527	 0.00525	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25223	 26897	 0.008417	 0.0645	 0.01728	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25223	 83664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25223	 83664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25224	 25225	 0.003439	 0.022013	 0.00741	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25224	 26436	 0.049716	 0.12507	 0.03243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25224	 83665	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25224	 83665	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25225	 25226	 0.00392	 0.013446	 0.00322	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25225	 83666	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25225	 83666	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25226	 25230	 0.004227	 0.014942	 0.00337	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25227	 84420	 0.039669	 0.11257	 0.00177	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25228	 25229	 0.049338	 0.039045	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25228	 83667	 0.016668	 0.033001	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25230	 27136	 0.004815	 0.016517	 0.00396	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25230	 83667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25230	 83667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25231	 83669	 0.010001	 0.007915	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25232	 25233	 0.001759	 0.004721	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25232	 25234	 0.000756	 0.0019	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25233	 25254	 0.001933	 0.005698	 0.00133	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25233	 83670	 0.000732	 0.0031	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25234	 25520	 0.000657	 0.001737	 0.00041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25235	 25236	 0.000734	 0.00177	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25235	 83668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25235	 83668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25235	 83719	 0.000553	 0.003169	 0.00105	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25236	 25237	 0.000459	 0.001213	 0.00028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25237	 25238	 0.000658	 0.001765	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25237	 25246	 0.000919	 0.002428	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25238	 83669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25238	 83669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25238	 83670	 0.001168	 0.002936	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83669	 25239	 0.009355	 0.007333	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25239	 83671	 0.004489	 0.0059	 8e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25240	 25253	 4e-05	 0.000453	 0.00413	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25240	 25388	 0.000153	 0.001676	 0.01628	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25240	 83670	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83668	 25241	 0.006343	 0.0114	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25241	 83673	 0.007701	 0.007778	 0.0001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25242	 25243	 0.000952	 0.002517	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25242	 83672	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25242	 83672	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25243	 25244	 0.000617	 0.00163	 0.00038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25243	 83673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25243	 83673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25244	 25245	 0.000538	 0.001465	 0.00032	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25245	 25246	 0.0007	 0.001849	 0.00043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25246	 25247	 0.001291	 0.003466	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25247	 25248	 0.000822	 0.002558	 0.00053	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25247	 25265	 0.001353	 0.003401	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25247	 83674	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25247	 83674	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25248	 83675	 0.000503	 0.00182	 0.00039	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25249	 25253	 6.3e-05	 0.000692	 0.00672	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25249	 25261	 2.6e-05	 0.000291	 0.00274	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25249	 25262	 7.6e-05	 0.000846	 0.00805	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25249	 83675	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83671	 25250	 0.005081	 0.014572	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25250	 83679	 0.006637	 0.011068	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25251	 25281	 0.00596	 0.014216	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25251	 83679	 0.002595	 0.006599	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82054	 25252	 0.017174	 0.011536	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83671	 25252	 0.003015	 0.006926	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25252	 83678	 0.003482	 0.00528	 8e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25253	 83677	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25254	 83679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25254	 83679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25254	 83680	 0.0022	 0.005814	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25255	 25256	 0.000699	 0.001797	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25256	 25257	 0.000549	 0.001276	 0.00039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25257	 83684	 0.001894	 0.005007	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25258	 25262	 8.3e-05	 0.000957	 0.00838	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25258	 83680	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25259	 25260	 0.000296	 0.001699	 0.00048	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83680	 25259	 0.000256	 0.00143	 0.00037	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25259	 83682	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25259	 83682	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25260	 83684	 0.000398	 0.002667	 0.00064	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25261	 83683	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25261	 83683	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25262	 25388	 0.000294	 0.003221	 0.03129	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25262	 83684	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25262	 83807	 0.000124	 0.001591	 0.01496	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83676	 25263	 0.003155	 0.006761	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83685	 25263	 0.026126	 0.020676	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25263	 83686	 0.004528	 0.01164	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83674	 25264	 0.00804	 0.015919	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83685	 25264	 0.028961	 0.040362	 0.00069	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25265	 25266	 0.00094	 0.002485	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25266	 25268	 0.001297	 0.003335	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25266	 83686	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25266	 83686	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83686	 25267	 0.007918	 0.005724	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83684	 25268	 0.001748	 0.004537	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25269	 25279	 0.001446	 0.004032	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25269	 83687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25269	 83687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25270	 25276	 0.000756	 0.002467	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25270	 25278	 0.000518	 0.002515	 0.00057	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25270	 83688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25270	 83688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25271	 25272	 0.014446	 0.011323	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25272	 25277	 0.009782	 0.019367	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25273	 25274	 0.006343	 0.009717	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25273	 25277	 0.005584	 0.008913	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83686	 25273	 0.002632	 0.010126	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25274	 25277	 0.008033	 0.008578	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25274	 83689	 0.004654	 0.010805	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25275	 83689	 0.012362	 0.009095	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25276	 25432	 0.002327	 0.006527	 0.00168	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25276	 83689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25276	 83689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83687	 25277	 0.001833	 0.009769	 0.00017	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83688	 25277	 0.013455	 0.01359	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25278	 25279	 0.00052	 0.002853	 0.00075	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25279	 25567	 0.000485	 0.00429	 0.00236	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25279	 83808	 0.000273	 0.003302	 0.00187	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25280	 83690	 0.003535	 0.008775	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83681	 25281	 0.002767	 0.013504	 0.00023	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25281	 83690	 0.002698	 0.011585	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25282	 25283	 0.000713	 0.005271	 0.00152	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83680	 25282	 0.000736	 0.006018	 0.00163	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25282	 83690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25282	 83690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25283	 83691	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25283	 83691	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25284	 25285	 0.002601	 0.00515	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25284	 25286	 0.002498	 0.009608	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25284	 25286	 0.002498	 0.009608	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25284	 25302	 0.001421	 0.009845	 0.0002	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83691	 25284	 0.00504	 0.013959	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25286	 25287	 0.002421	 0.00942	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25286	 25287	 0.002421	 0.00942	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25287	 25288	 0.002148	 0.007338	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25287	 83809	 0.003695	 0.012927	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25287	 83809	 0.003695	 0.012927	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25288	 83692	 0.001749	 0.006467	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25289	 25290	 0.000494	 0.002659	 0.00073	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25289	 83692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25289	 83692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25290	 25291	 0.000217	 0.002273	 0.00076	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25290	 83693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25290	 83693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25291	 25292	 0.000253	 0.002807	 0.00091	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25292	 83808	 0.000411	 0.006049	 0.00185	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25293	 25297	 0.000212	 0.001996	 0.0006	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25293	 83694	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25293	 83694	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25294	 25324	 0.002036	 0.007921	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25294	 25324	 0.002036	 0.007921	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25294	 25327	 0.000758	 0.006306	 0.00012	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82011	 25294	 0.003141	 0.009634	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82011	 25294	 0.003141	 0.009634	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25295	 25300	 0.002691	 0.005003	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25295	 83695	 0.004122	 0.008833	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25296	 83695	 0.007317	 0.005289	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25297	 83695	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25297	 83695	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25298	 25299	 0.00106	 0.004723	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25298	 25301	 0.00116	 0.004059	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83695	 25298	 0.001119	 0.00546	 9e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25299	 25344	 0.001663	 0.006469	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25299	 25344	 0.001663	 0.006469	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83695	 25299	 0.001109	 0.006238	 0.00013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25300	 25301	 0.003526	 0.011763	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25300	 25303	 0.000937	 0.005758	 0.0001	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25301	 25304	 0.00168	 0.005153	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25301	 25349	 0.001266	 0.007785	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83694	 25301	 0.004061	 0.016253	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25302	 25303	 0.001157	 0.007029	 0.00013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25304	 25305	 0.000485	 0.003664	 0.00012	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25304	 25306	 0.002004	 0.007711	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25304	 25306	 0.002004	 0.007711	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25305	 25349	 0.00148	 0.004938	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25305	 25352	 0.001102	 0.006777	 0.00012	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25306	 25307	 0.001556	 0.005986	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25306	 25307	 0.001556	 0.005986	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25307	 25673	 0.001238	 0.004228	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25307	 25673	 0.001238	 0.004228	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83691	 25307	 0.010687	 0.027696	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25308	 25309	 0.000961	 0.005463	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25308	 25311	 0.00138	 0.007843	 0.00014	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25309	 83709	 0.002113	 0.010688	 0.00019	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25310	 25311	 0.002712	 0.010549	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25310	 25311	 0.002712	 0.010549	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83692	 25310	 0.001166	 0.006241	 0.00019	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25310	 83697	 0.004785	 0.018615	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25310	 83697	 0.004785	 0.018615	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25311	 25673	 0.001986	 0.006093	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25311	 25673	 0.001986	 0.006093	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25312	 25315	 0.00795	 0.006023	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25312	 83696	 0.012485	 0.008082	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25313	 25355	 0.000291	 0.004205	 0.00133	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25313	 83696	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25313	 83696	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25313	 83808	 0.000961	 0.008716	 0.00456	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25314	 25316	 0.000257	 0.001896	 0.00055	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25314	 83697	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25314	 83697	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25316	 25318	 0.000174	 0.001929	 0.00058	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25317	 83698	 0.008649	 0.006845	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25318	 25320	 0.000175	 0.002055	 0.00054	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83697	 25319	 0.008171	 0.015192	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25319	 83698	 0.002908	 0.011189	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25319	 83725	 0.006416	 0.016494	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25320	 25321	 0.000163	 0.001478	 0.00077	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25320	 83698	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25320	 83698	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25321	 83699	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25321	 83699	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25321	 83808	 0.000192	 0.00284	 0.00098	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25322	 25323	 0.00378	 0.012608	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83699	 25322	 0.001553	 0.009548	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25323	 25489	 0.002579	 0.006818	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25324	 25325	 0.00067	 0.00556	 0.00014	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25324	 25326	 0.001351	 0.011239	 0.00021	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25324	 25328	 0.001433	 0.008483	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25325	 25326	 0.000617	 0.005131	 0.0001	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25326	 83700	 0.002135	 0.007472	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25326	 83700	 0.002135	 0.007472	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25327	 25344	 0.00131	 0.007064	 0.00014	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83694	 25327	 0.002454	 0.015086	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25328	 25329	 0.001058	 0.006263	 0.00012	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25329	 25331	 0.000669	 0.00599	 0.00013	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25329	 25347	 0.001081	 0.008889	 0.00017	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25330	 25337	 0.000299	 0.003021	 0.00089	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25330	 83700	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25330	 83700	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25331	 25459	 0.001599	 0.005999	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83700	 25331	 0.001879	 0.011421	 0.00021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25332	 25458	 0.001808	 0.005545	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25332	 25458	 0.001808	 0.005545	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25332	 83702	 0.001562	 0.006078	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25332	 83702	 0.001562	 0.006078	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25333	 25334	 0.000237	 0.001668	 0.00095	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25333	 25336	 0.00023	 0.002896	 0.0009	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25334	 25337	 0.000144	 0.002155	 0.00064	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25335	 83701	 0.001859	 0.009299	 0.00017	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25335	 83704	 0.00239	 0.00854	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25336	 83701	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25336	 83701	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25336	 83706	 0.000228	 0.002814	 0.00091	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25337	 83702	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25337	 83702	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83701	 25338	 0.001554	 0.00871	 0.00024	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83702	 25338	 0.001688	 0.012341	 0.00023	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25339	 25461	 0.00129	 0.010728	 0.0002	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83702	 25339	 0.004481	 0.011846	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25339	 83708	 0.001322	 0.006344	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25340	 25341	 3.7e-05	 0.000414	 0.00394	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25340	 83703	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25341	 25478	 7.8e-05	 0.000901	 0.0079	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25341	 83705	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25341	 83705	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25342	 25478	 0.00012	 0.001357	 0.01236	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25342	 83706	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25343	 25462	 0.000197	 0.003107	 0.00106	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83706	 25343	 0.000287	 0.002932	 0.00174	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25343	 83708	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25343	 83708	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25344	 25345	 0.002033	 0.00782	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25344	 25345	 0.002033	 0.00782	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25345	 25346	 0.000799	 0.005749	 0.00019	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25345	 25347	 0.001901	 0.005832	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25345	 25347	 0.001901	 0.005832	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25346	 25349	 0.000715	 0.007009	 0.00014	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25347	 25348	 0.000697	 0.006489	 0.00013	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25347	 25458	 0.006009	 0.023378	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25347	 25458	 0.006009	 0.023378	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25347	 25468	 0.000694	 0.005346	 0.0001	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25348	 25350	 0.001053	 0.010322	 0.0002	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25350	 25351	 0.001225	 0.008314	 0.00016	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25350	 25352	 0.00251	 0.010733	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25350	 25353	 0.001029	 0.009581	 0.00019	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83694	 25350	 0.0108	 0.032507	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25351	 25449	 0.001973	 0.01199	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25353	 25354	 0.002124	 0.007589	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25353	 25354	 0.002124	 0.007589	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25354	 83709	 0.002653	 0.010207	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25354	 83709	 0.002653	 0.010207	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25355	 83709	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25355	 83709	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25356	 25359	 0.000926	 0.005605	 0.00018	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25356	 25452	 0.002362	 0.00919	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25356	 25452	 0.002362	 0.00919	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83709	 25356	 0.002373	 0.008302	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83709	 25356	 0.002373	 0.008302	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25357	 25359	 0.001299	 0.004545	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25357	 25359	 0.001299	 0.004545	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25357	 25362	 0.0016	 0.006155	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25357	 25362	 0.0016	 0.006155	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25358	 25359	 0.001121	 0.004359	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25358	 25359	 0.001121	 0.004359	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25358	 25602	 0.002094	 0.007481	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25358	 25602	 0.002094	 0.007481	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83709	 25359	 0.002265	 0.012875	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25360	 25362	 0.002308	 0.008978	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25360	 25362	 0.002308	 0.008978	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83696	 25360	 0.003531	 0.013736	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83696	 25360	 0.003531	 0.013736	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25361	 25362	 0.011026	 0.007138	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25362	 25367	 0.002786	 0.015834	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25363	 83712	 0.008939	 0.007074	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25364	 25606	 0.000121	 0.00095	 0.00028	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25364	 83711	 0.000337	 0.00271	 0.00076	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83696	 25365	 0.010907	 0.007726	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25366	 83710	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25366	 83710	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25366	 83724	 0.000281	 0.003018	 0.00079	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83710	 25367	 0.000936	 0.005257	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25368	 25373	 0.002206	 0.009665	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83710	 25368	 0.00197	 0.011199	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25369	 25403	 8.7e-05	 0.000957	 0.0093	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25369	 83711	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25370	 25373	 0.000796	 0.006271	 0.00013	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25370	 25374	 0.001015	 0.006469	 0.00016	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83712	 25370	 0.001077	 0.004191	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83712	 25370	 0.001077	 0.004191	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25371	 25372	 0.00725	 0.005737	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25372	 25609	 0.001093	 0.010177	 0.0002	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83712	 25372	 0.002194	 0.00844	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83712	 25372	 0.002194	 0.00844	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25373	 83714	 0.001587	 0.007743	 0.00013	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25374	 83714	 0.000803	 0.006262	 0.00012	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25375	 25377	 0.000365	 0.004171	 0.00127	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25375	 83713	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25375	 83713	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25375	 83724	 0.000164	 0.00206	 0.00064	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25376	 25377	 0.000135	 0.001319	 0.00037	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25376	 25378	 0.000206	 0.002638	 0.00079	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25376	 83714	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25376	 83714	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25378	 25381	 0.000215	 0.002132	 0.00058	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25379	 25380	 0.002194	 0.008705	 0.00025	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25379	 25610	 0.002774	 0.009252	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83712	 25379	 0.002444	 0.023658	 0.00047	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25380	 25639	 0.001871	 0.009129	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25381	 25383	 0.000861	 0.002955	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25381	 83715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25381	 83715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25382	 25639	 0.00374	 0.011473	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25382	 25639	 0.00374	 0.011473	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25382	 25640	 0.004278	 0.016643	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83715	 25382	 0.002586	 0.009948	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83715	 25382	 0.002586	 0.009948	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25383	 25384	 0.000577	 0.003058	 0.00078	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25383	 83716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25383	 83716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25384	 83717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25384	 83717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25385	 25386	 0.015486	 0.012138	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25386	 83721	 0.004761	 0.007599	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25387	 25389	 0.001796	 0.004664	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25387	 83718	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25387	 83718	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25388	 26604	 0.000501	 0.009094	 0.09092	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25388	 83719	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83719	 25389	 0.001027	 0.004347	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25389	 83721	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25389	 83721	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25390	 25392	 0.00525	 0.010395	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25390	 25398	 0.007396	 0.01154	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25391	 25394	 0.007651	 0.014226	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25391	 25488	 0.004247	 0.010057	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25392	 25597	 0.022571	 0.033469	 0.0005	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83720	 25392	 0.006429	 0.031375	 0.00054	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25393	 83722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25393	 83722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25393	 83776	 0.006028	 0.015494	 0.00384	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25394	 25435	 0.012465	 0.020999	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83722	 25394	 0.005211	 0.014944	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25394	 83723	 0.007142	 0.016408	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25395	 25397	 0.002889	 0.011809	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25395	 25399	 0.009387	 0.013326	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83720	 25395	 0.002289	 0.011648	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83721	 25395	 0.005841	 0.011565	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83720	 25396	 0.016606	 0.013142	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25397	 25398	 0.003144	 0.010489	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25398	 83723	 0.003695	 0.010598	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25399	 25672	 0.014508	 0.010674	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25400	 25401	 0.002097	 0.005709	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25400	 83723	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25400	 83723	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25401	 83776	 0.001654	 0.005673	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25402	 25439	 0.001734	 0.009755	 0.00021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25402	 25482	 0.001367	 0.010655	 0.0002	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83708	 25402	 0.004191	 0.00973	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25403	 25495	 9.4e-05	 0.00157	 0.0145	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25403	 83724	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25403	 83807	 9.1e-05	 0.001207	 0.01933	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25404	 25405	 0.000299	 0.004646	 0.00144	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25404	 25648	 0.000418	 0.00559	 0.00153	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25404	 26674	 0.000346	 0.003862	 0.00257	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25405	 25406	 0.000364	 0.00458	 0.00142	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25406	 25644	 0.000356	 0.004564	 0.00136	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25407	 25594	 0.007675	 0.029526	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25407	 83800	 0.002658	 0.014001	 0.00025	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25408	 25641	 0.000638	 0.007178	 0.00208	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25408	 83726	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25408	 83726	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25408	 83745	 0.002347	 0.028926	 0.00934	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25409	 25410	 0.002412	 0.010012	 0.00026	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25409	 25638	 0.002236	 0.012711	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25410	 25589	 0.006957	 0.017884	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25410	 83760	 0.003103	 0.0213	 0.00039	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25411	 25526	 0.000399	 0.003424	 0.00097	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25411	 83727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25411	 83727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25411	 83792	 0.002174	 0.013047	 0.00395	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25412	 25414	 0.000522	 0.002998	 0.00085	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25412	 25664	 0.0006	 0.003449	 0.00098	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25413	 25414	 0.000644	 0.00562	 0.00154	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25413	 25532	 0.000672	 0.004301	 0.00145	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25414	 25659	 0.001699	 0.006801	 0.00171	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25414	 83728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25414	 83728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25414	 83808	 0.001974	 0.027913	 0.00925	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25415	 25528	 0.005173	 0.016589	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83727	 25415	 0.003112	 0.018913	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25415	 83729	 0.001968	 0.014383	 0.00027	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25416	 25643	 0.001496	 0.005131	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25416	 83729	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25416	 83729	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25417	 25433	 0.002285	 0.00604	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25417	 25539	 0.003104	 0.008203	 0.00192	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25417	 83730	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25417	 83730	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25418	 25419	 0.003129	 0.013707	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25418	 83775	 0.003601	 0.01832	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25419	 25422	 0.005441	 0.012343	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83730	 25419	 0.01046	 0.015681	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25420	 25421	 0.005529	 0.013092	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25420	 25560	 0.00775	 0.019709	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25421	 25422	 0.025731	 0.018931	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25421	 25627	 0.007655	 0.018126	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25422	 25542	 0.005438	 0.017267	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25423	 83731	 0.009414	 0.021855	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25423	 83735	 0.008363	 0.019413	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25424	 25502	 0.001927	 0.00968	 0.00252	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25424	 83731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25424	 83731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25425	 25429	 0.000157	 0.001808	 0.01585	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25425	 27506	 0.000581	 0.010197	 0.10912	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25425	 83732	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25426	 27572	 0.023173	 0.052996	 0.00129	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25426	 27574	 0.040225	 0.037721	 0.00058	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83731	 25426	 0.011186	 0.043036	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83733	 25426	 0.017924	 0.034727	 0.00075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25426	 83805	 0.094686	 0.077938	 0.00158	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25427	 83773	 0.039425	 0.031201	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25427	 83782	 0.021981	 0.02889	 0.0004	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83733	 25428	 0.010298	 0.031624	 0.00059	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25428	 83774	 0.011881	 0.030542	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25429	 25598	 0.000181	 0.003181	 0.03403	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25429	 83734	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25430	 25431	 0.001037	 0.00274	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25430	 83736	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25430	 83736	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25431	 25432	 0.0011	 0.002553	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25433	 25552	 0.000868	 0.004989	 0.00141	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25433	 25675	 0.000986	 0.003323	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25434	 25436	 0.020196	 0.01583	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25434	 83766	 0.024297	 0.019228	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25434	 83810	 0.008786	 0.013456	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25435	 25436	 0.024793	 0.017922	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25435	 83738	 0.00746	 0.01477	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25436	 83739	 0.023239	 0.018391	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25437	 25561	 7.4e-05	 0.000821	 0.00782	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25437	 83737	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25438	 83739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25438	 83739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25438	 83776	 0.001654	 0.005847	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25439	 25441	 0.009527	 0.014594	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25439	 83740	 0.002052	 0.009144	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25440	 25441	 0.003604	 0.008367	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25440	 83740	 0.003765	 0.008448	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25441	 25442	 0.003333	 0.007737	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25442	 25443	 0.001104	 0.007972	 0.00015	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25442	 25447	 0.001698	 0.010431	 0.00024	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25443	 25618	 0.00603	 0.01088	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25443	 25619	 0.002576	 0.009525	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25443	 25620	 0.00588	 0.011392	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25444	 25446	 0.000755	 0.005818	 0.00011	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25444	 25450	 0.001603	 0.01191	 0.00028	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25445	 25448	 0.004326	 0.011436	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25445	 25668	 0.00305	 0.010066	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25446	 25448	 0.00228	 0.008869	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25446	 25448	 0.00228	 0.008869	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25446	 25456	 0.001925	 0.00749	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25446	 25456	 0.001925	 0.00749	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25446	 25668	 0.00303	 0.018417	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25447	 25448	 0.0013	 0.008287	 0.0002	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25448	 25622	 0.002016	 0.007054	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25448	 25622	 0.002016	 0.007054	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25448	 25635	 0.001915	 0.008104	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25449	 25450	 0.000901	 0.004685	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25449	 25466	 0.010012	 0.007924	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25449	 83740	 0.008957	 0.034461	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25449	 83740	 0.008957	 0.034461	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25450	 25451	 0.000984	 0.00492	 9e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25450	 25452	 0.001572	 0.012719	 0.00033	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25451	 25453	 0.001448	 0.006415	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25452	 25453	 0.001645	 0.009242	 0.00017	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25454	 25455	 0.001436	 0.005755	 0.00015	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25454	 25456	 0.002412	 0.007399	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25454	 25456	 0.002412	 0.007399	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25454	 25602	 0.003145	 0.012236	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25454	 25602	 0.003145	 0.012236	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25455	 25457	 0.001395	 0.006148	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25456	 25457	 0.002362	 0.010409	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25458	 25461	 0.002035	 0.007798	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25459	 25460	 0.001579	 0.004186	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25460	 25464	 0.001707	 0.005633	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25461	 25464	 0.002959	 0.011513	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25461	 25464	 0.002959	 0.011513	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25461	 83740	 0.001124	 0.006907	 0.00012	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25462	 83740	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25462	 83740	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25463	 25464	 0.010705	 0.008472	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25464	 25465	 0.00168	 0.009021	 0.00021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25465	 25468	 0.001042	 0.007072	 0.00013	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25467	 25468	 0.010535	 0.007615	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25469	 83741	 0.009049	 0.005858	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25470	 25472	 3.8e-05	 0.000668	 0.00723	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25470	 25477	 3.6e-05	 0.000385	 0.00576	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25470	 83741	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25470	 83741	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83741	 25471	 0.007448	 0.015241	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25471	 83742	 0.005997	 0.008738	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25472	 25475	 2.9e-05	 0.000549	 0.0052	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25472	 83742	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25472	 83742	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25473	 25474	 0.010283	 0.008138	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25474	 83744	 0.01559	 0.042589	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25474	 84125	 0.008462	 0.020037	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25475	 26493	 3.3e-05	 0.000585	 0.00626	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83704	 25476	 0.005185	 0.015607	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25476	 83744	 0.003462	 0.007917	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25477	 25478	 2.5e-05	 0.00026	 0.00389	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25477	 83743	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25478	 25479	 4.2e-05	 0.000467	 0.0044	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25478	 25614	 0.000647	 0.008992	 0.0889	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25479	 83745	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25480	 25483	 0.001798	 0.004896	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83745	 25480	 0.000683	 0.001832	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25481	 25482	 0.00531	 0.012327	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83707	 25481	 0.004434	 0.007919	 0.00012	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25482	 83747	 0.00222	 0.011105	 0.0002	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25483	 83747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25483	 83747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25484	 25487	 0.019053	 0.013774	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83722	 25484	 0.014711	 0.022535	 0.00032	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25484	 83771	 0.009829	 0.018002	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25485	 25487	 0.004285	 0.009844	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25485	 25488	 0.011	 0.023572	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25485	 25547	 0.003382	 0.013533	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25486	 25597	 0.019442	 0.015386	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83718	 25488	 0.006222	 0.020531	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25489	 25490	 0.006817	 0.012252	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25489	 25492	 0.011135	 0.010758	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25490	 25491	 0.004338	 0.009118	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25490	 83748	 0.016396	 0.013495	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83713	 25491	 0.006145	 0.014117	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25492	 83748	 0.019668	 0.015416	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25493	 25497	 0.000423	 0.006316	 0.00187	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25493	 83748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25493	 83748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25493	 83808	 0.000964	 0.006784	 0.00386	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25494	 25656	 0.009652	 0.020685	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25494	 83751	 0.005391	 0.008954	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25495	 25614	 0.000219	 0.003572	 0.05574	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25495	 83749	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25495	 83807	 0.000119	 0.001602	 0.02823	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83750	 25496	 0.002666	 0.009523	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25496	 83751	 0.003981	 0.009105	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25496	 83762	 0.004329	 0.011219	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25497	 25529	 0.000819	 0.003217	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25497	 25532	 0.000621	 0.00454	 0.00134	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25497	 83751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25497	 83751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83714	 25498	 0.00411	 0.01983	 0.00035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83716	 25498	 0.002089	 0.009204	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83750	 25498	 0.001703	 0.014163	 0.00027	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25499	 25591	 0.001309	 0.008046	 0.00232	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25499	 26494	 0.000683	 0.007029	 0.00199	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25499	 83752	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25499	 83752	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83752	 25500	 0.02359	 0.023826	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25501	 25502	 0.000742	 0.008311	 0.00264	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25501	 25601	 0.001458	 0.010584	 0.00366	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25501	 83753	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25501	 83753	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25501	 83808	 0.00072	 0.007365	 0.00438	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25502	 83754	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25502	 83754	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25503	 25504	 0.009773	 0.00719	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25504	 25505	 0.010072	 0.007971	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25504	 25511	 0.014309	 0.010344	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25504	 25513	 0.005268	 0.007478	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25505	 25506	 0.010103	 0.006787	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25506	 25507	 0.009814	 0.009843	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25507	 25509	 0.008189	 0.012544	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25507	 83757	 0.007629	 0.014952	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25508	 25509	 0.007522	 0.00487	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25509	 83759	 0.003178	 0.00817	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25510	 25511	 0.0033	 0.004502	 8e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25510	 25596	 0.005976	 0.009981	 0.00017	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25511	 83755	 0.01485	 0.014999	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25512	 83755	 0.016488	 0.013048	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25513	 83755	 0.009332	 0.007158	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25513	 83756	 0.015217	 0.011927	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25514	 25515	 0.000472	 0.001247	 0.00029	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25514	 83755	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25514	 83755	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25515	 25516	 0.000454	 0.0012	 0.00028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25515	 83756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25515	 83756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25516	 25517	 0.000385	 0.001363	 0.00031	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25517	 25518	 0.000384	 0.001561	 0.00038	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25517	 83757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25517	 83757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25518	 25519	 0.000641	 0.001648	 0.00041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83719	 25518	 0.000372	 0.003571	 0.00104	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25518	 83758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25518	 83758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25519	 25520	 0.000537	 0.001418	 0.00033	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25520	 83759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25520	 83759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83758	 25521	 0.01207	 0.009461	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83759	 25521	 0.010827	 0.008568	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25522	 25523	 0.001612	 0.011784	 0.00022	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25522	 25621	 0.001513	 0.009891	 0.00023	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25523	 25533	 0.005791	 0.01604	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25523	 25537	 0.041932	 0.038624	 0.00062	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83752	 25523	 0.019728	 0.03906	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25524	 25525	 0.000306	 0.00385	 0.00119	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25524	 25624	 0.001066	 0.004337	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25524	 83760	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25524	 83760	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25525	 25536	 0.000316	 0.003678	 0.00108	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25526	 25527	 0.000372	 0.003729	 0.00124	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25526	 83761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25526	 83761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25527	 25529	 0.000368	 0.003651	 0.00112	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25528	 25640	 0.005413	 0.014029	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83761	 25528	 0.002127	 0.008526	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83749	 25529	 0.000271	 0.004136	 0.00133	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25529	 83762	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25529	 83762	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25530	 25531	 0.004002	 0.009796	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83762	 25530	 0.002926	 0.008977	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25531	 83763	 0.004713	 0.008762	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25532	 83763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25532	 83763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25533	 83764	 0.005633	 0.013079	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25534	 25536	 0.000319	 0.003124	 0.00098	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25534	 25660	 0.001456	 0.007713	 0.00195	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25534	 83764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25534	 83764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25535	 25661	 0.007561	 0.02495	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83752	 25535	 0.02135	 0.041841	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83764	 25535	 0.004742	 0.01219	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25536	 83765	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25536	 83765	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83765	 25537	 0.006563	 0.012994	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83739	 25538	 0.008711	 0.02022	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25538	 83783	 0.032016	 0.025337	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25539	 83766	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25539	 83766	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25539	 83776	 0.005225	 0.013808	 0.00323	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25540	 25541	 0.01832	 0.014498	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25540	 25578	 0.021496	 0.017011	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25541	 25542	 0.020325	 0.020529	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25542	 25626	 0.036528	 0.028632	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25542	 25628	 0.020208	 0.036322	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83766	 25542	 0.003642	 0.0207	 0.00037	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25543	 25549	 0.000541	 0.00432	 0.00106	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25543	 26656	 0.001643	 0.006684	 0.00163	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25543	 83767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25543	 83767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25544	 25545	 0.000738	 0.003388	 0.00087	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25544	 25647	 0.000573	 0.002493	 0.00071	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25545	 25551	 0.001039	 0.003949	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25545	 83768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25545	 83768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25546	 25650	 0.006329	 0.016095	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83722	 25546	 0.016939	 0.048584	 0.00075	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83768	 25546	 0.009178	 0.017987	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25546	 83770	 0.00694	 0.01374	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25547	 83801	 0.003527	 0.017842	 0.00031	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83767	 25548	 0.014609	 0.019201	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25548	 83769	 0.005384	 0.019233	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25548	 84187	 0.00924	 0.02449	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25549	 25559	 0.00203	 0.009314	 0.00239	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25549	 83769	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25549	 83769	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83769	 25550	 0.005346	 0.020565	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25550	 83770	 0.009556	 0.018728	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25551	 25552	 0.000287	 0.002613	 0.00066	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25551	 83770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25551	 83770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25552	 83771	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25552	 83771	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25553	 25580	 0.003418	 0.009033	 0.00211	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25553	 83772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25553	 83772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83772	 25554	 0.011106	 0.021988	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25554	 83773	 0.024374	 0.024618	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25554	 83774	 0.052629	 0.051495	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25555	 25556	 0.001859	 0.00478	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25555	 25558	 0.003626	 0.009871	 0.00217	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25555	 83773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25555	 83773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25556	 25576	 0.001925	 0.005241	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25557	 25558	 0.003341	 0.008831	 0.00207	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25557	 25630	 0.003831	 0.012779	 0.00324	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25558	 83774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25558	 83774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25559	 25653	 0.002144	 0.008724	 0.00213	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25559	 83775	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25559	 83775	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25559	 83797	 0.007858	 0.026216	 0.00665	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83775	 25560	 0.008546	 0.02197	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25561	 25598	 0.000298	 0.003439	 0.03015	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25561	 83776	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25561	 83807	 0.000358	 0.004249	 0.03901	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25562	 25563	 0.016706	 0.013221	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25562	 25584	 0.010228	 0.017987	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25563	 25565	 0.01165	 0.014638	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25564	 25565	 0.010375	 0.00854	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25564	 25572	 0.01148	 0.007432	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25565	 83780	 0.008046	 0.018679	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25566	 25568	 0.0006	 0.002859	 0.00083	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25566	 25574	 0.001825	 0.006608	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25566	 83778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25566	 83778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25567	 25581	 0.001775	 0.010576	 0.00278	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25567	 83779	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25567	 83779	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25568	 83780	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25568	 83780	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25568	 83804	 0.00163	 0.006634	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25569	 25571	 0.01757	 0.013311	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25570	 25571	 0.008165	 0.010731	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25570	 83787	 0.010876	 0.011962	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25571	 25572	 0.005307	 0.012321	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25571	 83786	 0.021515	 0.017027	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83779	 25572	 0.003863	 0.021961	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83778	 25573	 0.004846	 0.01125	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83780	 25573	 0.008748	 0.017145	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25574	 25576	 0.001805	 0.006536	 0.0014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25574	 83781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25574	 83781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83781	 25575	 0.017978	 0.012996	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25575	 83786	 0.008443	 0.015176	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25576	 25601	 0.002543	 0.006827	 0.00155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25576	 83782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25576	 83782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25577	 25588	 0.001121	 0.002882	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25577	 83783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25577	 83783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83772	 25578	 0.014763	 0.02923	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83783	 25578	 0.002651	 0.010311	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25579	 25580	 0.001295	 0.003898	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25579	 25581	 0.001603	 0.005402	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25579	 83784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25579	 83784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25580	 83785	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25580	 83785	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25581	 83786	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25581	 83786	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83785	 25582	 0.025031	 0.01962	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83786	 25582	 0.016793	 0.025725	 0.00036	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25583	 25587	 0.005309	 0.010511	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83739	 25583	 0.005607	 0.014413	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83777	 25584	 0.005629	 0.011519	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25585	 25588	 0.002483	 0.005763	 0.00176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83776	 25585	 0.001196	 0.006229	 0.00163	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25585	 83787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25585	 83787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25586	 25587	 0.015334	 0.014379	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83784	 25586	 0.003511	 0.009964	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83787	 25586	 0.004673	 0.012386	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83783	 25587	 0.027966	 0.021921	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25589	 25590	 0.028967	 0.020519	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25589	 25662	 0.008704	 0.024965	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83745	 25591	 0.002096	 0.009613	 0.00246	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25591	 83788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25591	 83788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25592	 25593	 0.013292	 0.013572	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83746	 25592	 0.022312	 0.020552	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83747	 25592	 0.007271	 0.01688	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25594	 25597	 0.009437	 0.021909	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25595	 25597	 0.003364	 0.017721	 0.00032	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25595	 83800	 0.004629	 0.02222	 0.00066	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25596	 25597	 0.004147	 0.013685	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83756	 25596	 0.041759	 0.027035	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25598	 25654	 5.8e-05	 0.000652	 0.00594	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25598	 83789	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25598	 83789	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25599	 25600	 0.000666	 0.004135	 0.00117	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83789	 25599	 0.000821	 0.003767	 0.00096	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25599	 83790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25599	 83790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25600	 25601	 0.000776	 0.004308	 0.00131	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83734	 25601	 0.000608	 0.005386	 0.00296	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25602	 83791	 0.003658	 0.01423	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25602	 83791	 0.003658	 0.01423	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25603	 25608	 0.004864	 0.011124	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25603	 25636	 0.003591	 0.013278	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25603	 25636	 0.003591	 0.013278	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25603	 83791	 0.005181	 0.018507	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25603	 83791	 0.005181	 0.018507	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25604	 25638	 0.023086	 0.016985	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25605	 25606	 0.000116	 0.001158	 0.00039	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25605	 83791	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25605	 83791	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25607	 25611	 0.001099	 0.00709	 0.00023	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25607	 25638	 0.003691	 0.028768	 0.00054	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25608	 25610	 0.003037	 0.010132	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25609	 25610	 0.000748	 0.006959	 0.00013	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25610	 25612	 0.001036	 0.005545	 0.00017	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25611	 25612	 0.001214	 0.008025	 0.00016	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25611	 25639	 0.003498	 0.009272	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25613	 25666	 0.043887	 0.034401	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25613	 83793	 0.014026	 0.023425	 0.0004	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25614	 27570	 0.000386	 0.004234	 0.04112	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25614	 83792	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25615	 25616	 0.019257	 0.018917	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25615	 27531	 0.041867	 0.032817	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83793	 25616	 0.004332	 0.026631	 0.00048	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25616	 83794	 0.01139	 0.024409	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25617	 27210	 0.004536	 0.016503	 0.00505	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83792	 25617	 0.00147	 0.01302	 0.00347	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25617	 83794	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25617	 83794	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83708	 25618	 0.010865	 0.024961	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25618	 83795	 0.025659	 0.038917	 0.00056	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25619	 25621	 0.002539	 0.009877	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25620	 25621	 0.002376	 0.014607	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25620	 25623	 0.002773	 0.011002	 0.00031	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83788	 25621	 0.00302	 0.014432	 0.00032	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25622	 25623	 0.002601	 0.010118	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25622	 25623	 0.002601	 0.010118	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25623	 83795	 0.00201	 0.009451	 0.00018	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25624	 83795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25624	 83795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25625	 25627	 0.012364	 0.024479	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25625	 83798	 0.010631	 0.034234	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25628	 25629	 0.030206	 0.021835	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83772	 25629	 0.014854	 0.026532	 0.00039	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25630	 83796	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25630	 83796	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25630	 83797	 0.001564	 0.008139	 0.0024	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25631	 26933	 0.017099	 0.013532	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25631	 26934	 0.009001	 0.016736	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83796	 25631	 0.007466	 0.017074	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83796	 25632	 0.016176	 0.022544	 0.00039	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83796	 25633	 0.010783	 0.02135	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25633	 83798	 0.006995	 0.014316	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25634	 83797	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25634	 83807	 0.000883	 0.010007	 0.09112	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25635	 25637	 0.002638	 0.010108	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25636	 25637	 0.002514	 0.008798	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25636	 25637	 0.002514	 0.008798	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25637	 25638	 0.001265	 0.006964	 0.00016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83788	 25638	 0.01012	 0.057525	 0.00104	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83726	 25639	 0.008477	 0.032612	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83726	 25639	 0.008477	 0.032612	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25640	 25657	 0.002896	 0.011141	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25640	 25657	 0.002896	 0.011141	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83717	 25640	 0.001937	 0.0133	 0.00024	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83725	 25640	 0.009019	 0.061905	 0.00113	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25641	 25642	 0.00013	 0.001683	 0.00067	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25642	 25643	 0.001174	 0.003049	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25642	 83799	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25642	 83799	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25644	 25645	 0.001	 0.003639	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25644	 83800	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25644	 83800	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25645	 83801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25645	 83801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25646	 25647	 0.000585	 0.002683	 0.00069	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25646	 25649	 0.001015	 0.004658	 0.00119	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25648	 25649	 0.000947	 0.004908	 0.0012	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25648	 83802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25648	 83802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83801	 25650	 0.008206	 0.01905	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25650	 84168	 0.021757	 0.071799	 0.00116	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83775	 25651	 0.025694	 0.0182	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83769	 25652	 0.00658	 0.015276	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83775	 25652	 0.008586	 0.024364	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25652	 83803	 0.040999	 0.029638	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25653	 26660	 0.00244	 0.01155	 0.00278	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25653	 83803	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25653	 83803	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25654	 83804	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25654	 83804	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83700	 25655	 0.014409	 0.009328	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83753	 25656	 0.009249	 0.028374	 0.00077	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83754	 25656	 0.02147	 0.029292	 0.00052	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83799	 25657	 0.003906	 0.015196	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83799	 25657	 0.003906	 0.015196	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83726	 25658	 0.027411	 0.021026	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25659	 83805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25659	 83805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25660	 26494	 0.003107	 0.010133	 0.00269	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25660	 83806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25660	 83806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83806	 25661	 0.012144	 0.029725	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25661	 83962	 0.008201	 0.035222	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83726	 25662	 0.008602	 0.022113	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25663	 25671	 0.009738	 0.047518	 0.00082	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83726	 25663	 0.00606	 0.034445	 0.00062	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83792	 25664	 0.001375	 0.007164	 0.00188	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83793	 25665	 0.005843	 0.032175	 0.00073	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25665	 84539	 0.017635	 0.032791	 0.00077	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25667	 25671	 0.008533	 0.034873	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25667	 83965	 0.016884	 0.056325	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25667	 83966	 0.014124	 0.037337	 0.00068	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83740	 25668	 0.00398	 0.019905	 0.00035	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25669	 83807	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25669	 83807	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25669	 83807	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83808	 25669	 0.000162	 0.012969	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 0	 -30.0	 30.0;
	83808	 25669	 0.000162	 0.012969	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 0	 -30.0	 30.0;
	25670	 84128	 0.016552	 0.016718	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83672	 25672	 0.013912	 0.011451	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83680	 25674	 0.000875	 0.00305	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25674	 83809	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25674	 83809	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25675	 25676	 0.002018	 0.005334	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83737	 25676	 0.0028	 0.0074	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25676	 83810	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25676	 83810	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25677	 25679	 0.004163	 0.0248	 0.00652	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25677	 26952	 0.005911	 0.030754	 0.00906	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25678	 25682	 0.01253	 0.06705	 0.00203	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82593	 25678	 0.007481	 0.058306	 0.00109	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25679	 25683	 0.004027	 0.027646	 0.00806	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25680	 25681	 0.005566	 0.024804	 0.00674	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25680	 27359	 0.013205	 0.043072	 0.01144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25681	 25685	 0.001587	 0.025003	 0.00853	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25681	 26959	 0.001449	 0.022925	 0.00688	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82050	 25682	 0.019293	 0.075055	 0.00125	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25682	 83811	 0.02081	 0.052922	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25683	 25685	 0.001093	 0.008119	 0.0031	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25684	 83811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25684	 83811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25686	 27243	 0.02941	 0.14191	 0.00251	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82050	 25686	 0.1326	 0.13394	 0.00177	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25687	 25688	 0.007399	 0.025383	 0.00608	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25687	 83812	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25687	 83812	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25688	 27244	 0.007721	 0.027958	 0.006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25689	 83813	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25689	 83813	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25690	 25692	 0.10183	 0.11201	 0.00149	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25691	 27178	 0.010786	 0.028957	 0.00656	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25692	 83814	 0.077521	 0.14847	 0.00234	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25692	 84373	 0.041254	 0.13615	 0.00221	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82009	 25693	 0.012341	 0.019699	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25693	 83815	 0.038604	 0.029248	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25694	 27180	 0.007745	 0.047622	 0.01374	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82008	 25694	 0.003292	 0.019282	 0.00525	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25694	 83814	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25694	 83814	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25695	 27177	 0.030133	 0.11304	 0.00203	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82009	 25695	 0.032365	 0.06408	 0.00094	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83814	 25695	 0.012068	 0.034246	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25695	 83815	 0.007433	 0.03312	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82008	 25696	 0.003094	 0.008033	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25696	 83815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25696	 83815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83815	 25697	 0.098925	 0.07829	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25698	 25699	 0.00205	 0.005154	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25698	 25704	 0.00144	 0.005215	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25699	 83816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25699	 83816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25700	 83817	 0.029277	 0.02317	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25701	 83817	 0.006151	 0.014281	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25701	 83819	 0.009745	 0.022625	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25702	 83817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25702	 83817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25702	 83818	 0.002633	 0.008588	 0.00228	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25703	 25729	 0.000298	 0.003377	 0.03074	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25703	 26887	 0.001164	 0.012707	 0.12479	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25703	 83818	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25704	 25730	 0.001852	 0.004463	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25704	 83820	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25704	 83820	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25705	 27139	 0.025069	 0.12682	 0.00221	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83816	 25705	 0.013843	 0.066449	 0.00199	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25706	 83823	 0.013361	 0.075952	 0.00137	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25706	 84355	 0.023224	 0.081314	 0.00225	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25707	 26901	 0.097716	 0.11913	 0.00191	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83817	 25707	 0.039723	 0.078649	 0.00115	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25708	 83885	 0.033716	 0.026682	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25709	 26064	 0.06359	 0.042715	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25710	 25712	 0.007735	 0.020765	 0.00471	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83818	 25710	 0.007266	 0.020262	 0.00425	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25710	 83827	 0.003214	 0.009674	 0.00303	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25711	 83821	 0.014127	 0.032307	 0.00079	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25711	 83890	 0.006013	 0.029342	 0.00051	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25712	 25714	 0.003259	 0.008612	 0.00202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25713	 25877	 0.003116	 0.00869	 0.00182	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25713	 83825	 0.002196	 0.005978	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25714	 25719	 0.002083	 0.005355	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25714	 83821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25714	 83821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83821	 25715	 0.010884	 0.018079	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25715	 83828	 0.027329	 0.032716	 0.00054	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25716	 25724	 0.008886	 0.022842	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25716	 83828	 0.009983	 0.025661	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25717	 25730	 0.00631	 0.016941	 0.00384	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25717	 83822	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25717	 83822	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25717	 83827	 0.003105	 0.015067	 0.00344	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83822	 25718	 0.009286	 0.018386	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25719	 25893	 0.005205	 0.014513	 0.00305	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25720	 25722	 0.007139	 0.025233	 0.00569	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25720	 83823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25720	 83823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25721	 25723	 0.015176	 0.030047	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25721	 83900	 0.004847	 0.018856	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25722	 25726	 0.00122	 0.005597	 0.00143	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25722	 83824	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25722	 83824	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83824	 25723	 0.021002	 0.021213	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83824	 25724	 0.025188	 0.027704	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25725	 83904	 0.11069	 0.071662	 0.00136	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25726	 25910	 0.001543	 0.00803	 0.00236	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25727	 25729	 0.000226	 0.002508	 0.02388	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25727	 25865	 0.000432	 0.004892	 0.04454	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25727	 83825	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25728	 26901	 0.18994	 0.19001	 0.00257	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83819	 25728	 0.052337	 0.083541	 0.00192	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25729	 26483	 0.001157	 0.020316	 0.21759	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25729	 27672	 0.000335	 0.005488	 0.06742	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25729	 83827	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25729	 83827	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83824	 25731	 0.020146	 0.10477	 0.00227	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25731	 84355	 0.042159	 0.16221	 0.00277	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25732	 25915	 0.002225	 0.008056	 0.00173	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25732	 83828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25732	 83828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25733	 25734	 0.002983	 0.011943	 0.00301	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82044	 25733	 0.005617	 0.023774	 0.00535	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25734	 25735	 0.003844	 0.017634	 0.00452	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25735	 26431	 0.005396	 0.033486	 0.00811	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25735	 83829	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25735	 83829	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25736	 25747	 0.000157	 0.002847	 0.02846	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25736	 26887	 0.003804	 0.041859	 0.40832	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25736	 83830	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25736	 83830	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83830	 25737	 0.007716	 0.023225	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25738	 25740	 0.067014	 0.1587	 0.0029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25738	 84368	 0.076729	 0.2201	 0.00339	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25739	 25740	 0.007998	 0.02456	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83830	 25739	 0.013283	 0.097093	 0.00179	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25739	 83833	 0.003578	 0.013766	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25740	 83832	 0.003543	 0.011691	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25741	 25745	 0.000141	 0.001797	 0.02689	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25741	 27167	 0.000234	 0.003327	 0.05316	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25741	 83831	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25741	 83831	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25742	 25743	 0.000313	 0.001844	 0.0015	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83831	 25742	 0.000531	 0.004166	 0.0019	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25743	 25744	 0.000246	 0.003026	 0.00098	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25743	 83832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25743	 83832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25744	 83833	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25744	 83833	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25744	 83834	 0.000252	 0.002787	 0.00084	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25745	 25747	 6.8e-05	 0.001228	 0.01227	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25745	 83834	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25745	 83834	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25746	 25748	 0.000904	 0.009291	 0.00294	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83834	 25746	 0.000158	 0.002361	 0.00079	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25748	 25750	 0.00407	 0.018981	 0.0047	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83831	 25749	 0.00538	 0.015002	 0.00315	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25749	 83835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25749	 83835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25750	 26431	 0.006226	 0.02592	 0.00808	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25750	 27275	 0.046849	 0.15802	 0.03933	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82044	 25750	 0.014615	 0.087748	 0.02659	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83831	 25750	 0.005335	 0.033151	 0.00936	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25750	 83836	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25750	 83836	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25751	 25753	 0.000469	 0.005315	 0.04839	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25751	 26586	 0.000157	 0.001749	 0.0165	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25751	 27183	 0.000824	 0.009047	 0.08789	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25751	 83837	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25751	 83837	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25752	 25754	 0.000385	 0.004446	 0.03898	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25752	 25759	 0.000355	 0.004016	 0.03656	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25752	 83838	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25752	 83838	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25753	 25754	 0.000171	 0.001969	 0.01726	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25753	 83839	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25753	 83839	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25754	 25999	 0.000965	 0.010939	 0.09961	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25754	 83840	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25754	 83840	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25755	 25777	 0.001766	 0.008709	 0.00235	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25755	 25778	 0.001771	 0.006172	 0.00143	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25755	 83841	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25755	 83841	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25756	 25757	 0.003634	 0.013159	 0.00282	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25756	 26046	 0.004085	 0.014012	 0.00336	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25757	 25758	 0.006531	 0.023087	 0.0052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25757	 25777	 0.003468	 0.020313	 0.00553	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25757	 27193	 0.002902	 0.035255	 0.0095	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25758	 25764	 0.00154	 0.013211	 0.00376	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83839	 25758	 0.001744	 0.018223	 0.00613	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25758	 83843	 0.007319	 0.029305	 0.00738	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25759	 25762	 0.00022	 0.002639	 0.0261	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25760	 83844	 0.041801	 0.10746	 0.00166	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25761	 25762	 0.000216	 0.002737	 0.02441	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25761	 25771	 0.000403	 0.004394	 0.04314	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25761	 26419	 0.00037	 0.005869	 0.06163	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25761	 83842	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25761	 83842	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25762	 83843	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25763	 25767	 0.015727	 0.028268	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25763	 25768	 0.018365	 0.024137	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83844	 25763	 0.059619	 0.047182	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25763	 84356	 0.22425	 0.63712	 0.01003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25764	 25766	 0.000434	 0.004168	 0.00121	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25765	 83845	 0.022666	 0.023144	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25766	 25770	 0.000563	 0.006305	 0.002	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83843	 25766	 0.005712	 0.015095	 0.00353	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25766	 83845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25766	 83845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25767	 25768	 0.008182	 0.014986	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25767	 25769	 0.010081	 0.019757	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83845	 25767	 0.013881	 0.010881	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25767	 83848	 0.036605	 0.09487	 0.00179	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83844	 25768	 0.048219	 0.03816	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25769	 83846	 0.005098	 0.019126	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83842	 25770	 0.004347	 0.017085	 0.00447	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25770	 83846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25770	 83846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25770	 83847	 0.002004	 0.020415	 0.00526	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25771	 27200	 0.000815	 0.009235	 0.08409	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25771	 83847	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25772	 27190	 0.15029	 0.15181	 0.00201	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83848	 25772	 0.037523	 0.096458	 0.00149	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25772	 84427	 0.1313	 0.34044	 0.00644	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25773	 25775	 0.023364	 0.015126	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25773	 83849	 0.010318	 0.01565	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25774	 25776	 0.002934	 0.014989	 0.00377	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25774	 26039	 0.001546	 0.005302	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25774	 83849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25774	 83849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25775	 26579	 0.048461	 0.037986	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83849	 25775	 0.025341	 0.025595	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25776	 25778	 0.002852	 0.008868	 0.00185	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83840	 25776	 0.006301	 0.02102	 0.00533	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25779	 25783	 0.002349	 0.027341	 0.00804	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25779	 26812	 0.003394	 0.035463	 0.00974	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25780	 26813	 0.008321	 0.045662	 0.01207	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83637	 25780	 0.005054	 0.06359	 0.0197	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25780	 83850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25780	 83850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25781	 83851	 0.034276	 0.067865	 0.001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25782	 83851	 0.069696	 0.055157	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25783	 25784	 0.00063	 0.008887	 0.00304	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25783	 83851	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25783	 83851	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25784	 83852	 0.000771	 0.012629	 0.00397	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25785	 26406	 0.0005	 0.005563	 0.05246	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25785	 27199	 0.000656	 0.011449	 0.1239	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25785	 83852	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25785	 83852	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25786	 25895	 0.013309	 0.014213	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25786	 26068	 0.01297	 0.009376	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25787	 83916	 0.012185	 0.009551	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25788	 25789	 0.012486	 0.008845	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25789	 25793	 0.007329	 0.012346	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25789	 83853	 0.014636	 0.009831	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25789	 83916	 0.034798	 0.027538	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25790	 25791	 0.000667	 0.002358	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25790	 25794	 0.001089	 0.003734	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25791	 25792	 0.001161	 0.003237	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25791	 25957	 0.000857	 0.003368	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25792	 25800	 0.000836	 0.002171	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25793	 25960	 0.005561	 0.011011	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25794	 25795	 0.000641	 0.001931	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25794	 83853	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25794	 83853	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25795	 25796	 0.000511	 0.001667	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25796	 25804	 0.000538	 0.001845	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25796	 83854	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25796	 83854	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25797	 25798	 0.018314	 0.014494	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83854	 25797	 0.021166	 0.016751	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25798	 25810	 0.020679	 0.016365	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25798	 83856	 0.014604	 0.016062	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25798	 83859	 0.007231	 0.014317	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25799	 25802	 0.000927	 0.003179	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25799	 25811	 0.001175	 0.003959	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25800	 25802	 0.001184	 0.003302	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25800	 83855	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25800	 83855	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25801	 25803	 0.015094	 0.011945	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83855	 25801	 0.015297	 0.011058	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25801	 83856	 0.020065	 0.015202	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25801	 83913	 0.014427	 0.013017	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25802	 83856	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25802	 83856	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83856	 25803	 0.014252	 0.011279	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25804	 25808	 0.000507	 0.001766	 0.00041	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25804	 83857	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25804	 83857	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25805	 25806	 0.00535	 0.009799	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83854	 25805	 0.01519	 0.011176	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25806	 25816	 0.005563	 0.017067	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83857	 25806	 0.013224	 0.014545	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25806	 83869	 0.01448	 0.033613	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25807	 25959	 0.003471	 0.012567	 0.0027	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25807	 83858	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25807	 83858	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25807	 83873	 0.002078	 0.010246	 0.00277	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25808	 25809	 0.000468	 0.00156	 0.0004	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25808	 83859	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25808	 83859	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25809	 25812	 0.00063	 0.002122	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25810	 83860	 0.009056	 0.008426	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25811	 25821	 0.000821	 0.002903	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25811	 83860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25811	 83860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25812	 83861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25812	 83861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25812	 83868	 0.001457	 0.005832	 0.00147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83859	 25813	 0.00809	 0.014817	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83861	 25813	 0.006899	 0.00546	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25813	 83863	 0.002039	 0.009085	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25814	 25815	 0.007911	 0.006201	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25815	 25818	 0.00349	 0.006909	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25815	 25961	 0.014322	 0.02194	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83861	 25815	 0.021201	 0.016618	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25816	 83930	 0.001583	 0.009941	 0.00022	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25817	 25890	 0.001309	 0.003291	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25817	 25995	 0.000788	 0.002655	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25817	 83862	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25817	 83862	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25818	 25819	 0.010954	 0.008669	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25818	 83870	 0.004156	 0.011919	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25819	 83863	 0.010449	 0.008269	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25820	 83863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25820	 83863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25820	 83868	 0.001382	 0.003552	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25821	 25833	 0.00058	 0.002102	 0.00045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25822	 25823	 0.001477	 0.005065	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25822	 25944	 0.00174	 0.004599	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25822	 83864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25822	 83864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25823	 25837	 0.000959	 0.003342	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25824	 25945	 0.001595	 0.006205	 0.00166	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25824	 83865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25824	 83865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25824	 83940	 0.00058	 0.005751	 0.00156	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25825	 25827	 0.017541	 0.013881	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25826	 25828	 0.004893	 0.008128	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25826	 83941	 0.00633	 0.016273	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25827	 83941	 0.012563	 0.009636	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25828	 26010	 0.00271	 0.007024	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25828	 83866	 0.020028	 0.01585	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25829	 26006	 0.000466	 0.002953	 0.0008	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25829	 26011	 0.001748	 0.006999	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25829	 83866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25829	 83866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25830	 26021	 0.012713	 0.01006	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83866	 25830	 0.012683	 0.010037	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25831	 26022	 0.014595	 0.01155	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25831	 83939	 0.015415	 0.012199	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25832	 83867	 0.013516	 0.008751	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25832	 83871	 0.021263	 0.016827	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25833	 25836	 0.000611	 0.002096	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25833	 83867	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25833	 83867	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25834	 25841	 0.000183	 0.002072	 0.01886	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25834	 25955	 0.000326	 0.003632	 0.03425	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25834	 25999	 0.000235	 0.002582	 0.02508	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25834	 83868	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25835	 25996	 0.001457	 0.004295	 0.001	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83868	 25835	 0.001818	 0.004805	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25835	 83870	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25835	 83870	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25836	 25838	 0.000496	 0.001653	 0.00042	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25837	 25853	 0.000637	 0.002305	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25837	 83871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25837	 83871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25838	 25852	 0.000639	 0.002193	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25839	 25851	 0.000815	 0.002154	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83868	 25839	 0.001465	 0.003766	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25839	 83872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25839	 83872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25840	 25849	 0.017561	 0.017737	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83870	 25840	 0.012462	 0.013308	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83872	 25840	 0.02355	 0.017327	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25841	 25888	 0.000173	 0.001924	 0.01814	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25841	 25981	 0.00017	 0.001897	 0.01788	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25841	 83873	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25841	 83873	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25842	 25845	 0.007071	 0.010038	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25842	 25848	 0.011683	 0.02108	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25842	 25983	 0.01564	 0.021337	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25843	 25846	 0.000981	 0.003366	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25843	 83874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25843	 83874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25843	 83925	 0.001653	 0.005669	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25844	 25845	 0.004715	 0.009336	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83874	 25844	 0.003229	 0.00926	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25845	 83927	 0.026213	 0.020547	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25846	 25847	 0.001059	 0.00275	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25846	 83875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25846	 83875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25847	 25988	 0.000905	 0.002274	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25848	 25989	 0.019058	 0.015082	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25849	 25850	 0.008558	 0.016389	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25850	 25859	 0.036933	 0.026699	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25850	 83928	 0.007046	 0.016114	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25851	 25856	 0.001278	 0.003564	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25851	 25858	 0.000753	 0.002099	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25852	 25856	 0.000723	 0.002481	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25852	 83876	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25852	 83876	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25853	 25854	 0.000362	 0.00124	 0.0003	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25853	 83877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25853	 83877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25854	 25855	 0.000527	 0.001835	 0.00043	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25855	 25997	 0.000761	 0.002563	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25855	 83878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25855	 83878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25856	 25857	 0.000628	 0.002219	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25857	 25861	 0.000822	 0.002291	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25857	 25862	 0.000705	 0.002418	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25858	 25860	 0.001279	 0.00431	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25859	 83879	 0.00921	 0.00722	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25860	 25863	 0.000569	 0.00201	 0.00045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25860	 83879	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25860	 83879	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25861	 83880	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25861	 83880	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25861	 83931	 0.002413	 0.005815	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25862	 25998	 0.000798	 0.002737	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25863	 26000	 0.001763	 0.006142	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25863	 83881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25863	 83881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25864	 25963	 0.002603	 0.011944	 0.00306	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25864	 83882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25864	 83882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25865	 25970	 0.000381	 0.004321	 0.03934	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25865	 83883	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25866	 26065	 0.001789	 0.006136	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25866	 83885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25866	 83885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25867	 25871	 0.001241	 0.004492	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25867	 83886	 0.001361	 0.00454	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25868	 25958	 0.021363	 0.016745	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25869	 83895	 0.019318	 0.013684	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25870	 25888	 8e-05	 0.000876	 0.00851	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25870	 83886	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25870	 83886	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25871	 25885	 0.001163	 0.003634	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25872	 25873	 0.009727	 0.014901	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25872	 25874	 0.023235	 0.018213	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25873	 83916	 0.006848	 0.012733	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25874	 83893	 0.034851	 0.02758	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25875	 25876	 0.001318	 0.004397	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25875	 25879	 0.001675	 0.005747	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25875	 83887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25875	 83887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25876	 25885	 0.000932	 0.003295	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25876	 83888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25876	 83888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25877	 25878	 0.001814	 0.004869	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25877	 25883	 0.001634	 0.004319	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25877	 83889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25877	 83889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25878	 25879	 0.001811	 0.00545	 0.0017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25878	 83890	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25878	 83890	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25880	 25881	 0.003403	 0.008993	 0.0021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25880	 25886	 0.001617	 0.005636	 0.00131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25880	 83891	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25880	 83891	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25881	 25884	 0.001827	 0.004744	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25881	 83892	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25881	 83892	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25882	 25892	 0.005882	 0.016871	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83891	 25882	 0.004729	 0.016893	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25883	 25884	 0.001228	 0.003246	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25886	 25968	 0.004093	 0.016089	 0.00421	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25886	 83893	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25886	 83893	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25887	 83919	 0.03144	 0.024881	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25888	 83894	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25889	 25890	 0.000989	 0.002757	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83894	 25889	 0.001333	 0.00346	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25891	 25894	 0.013853	 0.010014	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25891	 25895	 0.012803	 0.025349	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25891	 25897	 0.01698	 0.013438	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25891	 83896	 0.0089	 0.017621	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25892	 83896	 0.008967	 0.016117	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25893	 25898	 0.002216	 0.007724	 0.00179	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25893	 25915	 0.001463	 0.007212	 0.00195	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83873	 25893	 0.006746	 0.037021	 0.00979	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25893	 83896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25893	 83896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25894	 25896	 0.00633	 0.00832	 0.00011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25895	 25908	 0.022432	 0.017752	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25895	 83916	 0.005118	 0.024972	 0.00043	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25896	 26068	 0.004854	 0.007956	 0.00014	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25898	 25899	 0.000868	 0.002977	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25899	 25900	 0.001171	 0.004082	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25900	 25956	 0.000697	 0.002391	 0.00057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25900	 83897	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25900	 83897	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25901	 25902	 0.000233	 0.002733	 0.00072	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25901	 25907	 0.000301	 0.00315	 0.00087	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25902	 25903	 0.0002	 0.00229	 0.0007	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25903	 83898	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25903	 83898	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25903	 83914	 0.000135	 0.002065	 0.00067	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25904	 25905	 0.017134	 0.01356	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25904	 25906	 0.01362	 0.008818	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25905	 26059	 0.011861	 0.013045	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25906	 25909	 0.013583	 0.018515	 0.00041	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25906	 83899	 0.002104	 0.009216	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25906	 83903	 0.015285	 0.019724	 0.0004	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25907	 25919	 0.000818	 0.004947	 0.00126	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25907	 83899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25907	 83899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25909	 83901	 0.020566	 0.016927	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25910	 25919	 0.001025	 0.006108	 0.00161	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25911	 25923	 0.001533	 0.004115	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25911	 83900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25911	 83900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25912	 25914	 0.00738	 0.016739	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83892	 25912	 0.006721	 0.019276	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83896	 25913	 0.029777	 0.023565	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25914	 25916	 0.00638	 0.0164	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25915	 83901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25915	 83901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83828	 25916	 0.014728	 0.026306	 0.00039	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83901	 25916	 0.010582	 0.009547	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25917	 25918	 0.000977	 0.003351	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25917	 25920	 0.001242	 0.004497	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25918	 25948	 0.000758	 0.003872	 0.00097	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25918	 83902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25918	 83902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25919	 25920	 0.001179	 0.003973	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25919	 25924	 0.001584	 0.005338	 0.00133	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25919	 83903	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25919	 83903	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25921	 25925	 0.022412	 0.015055	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83903	 25921	 0.012099	 0.019832	 0.00035	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25922	 25926	 0.0116	 0.032918	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25922	 25928	 0.007404	 0.018122	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25922	 25932	 0.021052	 0.023155	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25922	 25934	 0.057235	 0.045295	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25922	 26060	 0.015666	 0.040272	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25923	 25924	 0.001242	 0.004049	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25925	 25928	 0.031691	 0.02508	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25926	 25928	 0.002493	 0.010405	 0.0003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83902	 25926	 0.005143	 0.01322	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25926	 83912	 0.014192	 0.047343	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25927	 25930	 0.030016	 0.019432	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25929	 25933	 0.003131	 0.011066	 0.00249	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25929	 83904	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25929	 83904	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25930	 25931	 0.024311	 0.021784	 0.00045	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83904	 25930	 0.01567	 0.036381	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25930	 83905	 0.025413	 0.042382	 0.00062	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25931	 26060	 0.011295	 0.022136	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25933	 25935	 0.00308	 0.010565	 0.00253	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25933	 83905	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25933	 83905	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25934	 25940	 0.010882	 0.03591	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25934	 25941	 0.036707	 0.0392	 0.00083	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83905	 25934	 0.007752	 0.041303	 0.00072	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25935	 25937	 0.00203	 0.006963	 0.00167	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25936	 25937	 0.000438	 0.005341	 0.00177	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25936	 26041	 0.001676	 0.005749	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25936	 26580	 0.003685	 0.011458	 0.00239	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25936	 83906	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25936	 83906	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25936	 83933	 0.00416	 0.034613	 0.01048	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25937	 26578	 0.004604	 0.01284	 0.00269	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25937	 83907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25937	 83907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25938	 26061	 0.002921	 0.00772	 0.00181	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25938	 26069	 0.00277	 0.007769	 0.002	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25938	 83908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25938	 83908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25939	 25940	 0.00722	 0.013645	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25939	 83912	 0.04878	 0.036957	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25939	 83954	 0.008525	 0.021159	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25940	 83954	 0.007508	 0.02627	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83907	 25941	 0.014787	 0.033816	 0.00083	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25941	 83954	 0.006606	 0.031874	 0.00056	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25942	 25943	 0.022549	 0.014598	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83908	 25942	 0.016628	 0.032923	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25944	 25953	 0.003457	 0.00833	 0.00235	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25945	 25946	 0.001145	 0.004145	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25945	 83909	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25945	 83909	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25946	 25950	 0.001085	 0.003655	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25947	 25948	 0.000854	 0.003321	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25947	 25949	 0.000827	 0.002787	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25947	 83910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25947	 83910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25948	 26061	 0.001806	 0.004641	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25949	 25950	 0.00105	 0.003602	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25950	 83911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25950	 83911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83909	 25951	 0.006454	 0.016591	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25951	 83912	 0.008333	 0.02142	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25952	 26069	 0.004572	 0.01275	 0.00268	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25952	 83912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25952	 83912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25953	 83913	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25953	 83913	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25953	 83915	 0.001049	 0.002925	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25954	 25955	 3.8e-05	 0.000428	 0.00387	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25954	 83914	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25954	 83914	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25955	 83915	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25955	 83915	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25956	 25957	 0.000657	 0.002254	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83895	 25958	 0.010984	 0.02601	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25958	 83916	 0.006793	 0.015771	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25959	 83916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25959	 83916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83858	 25960	 0.007046	 0.018112	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83858	 25961	 0.007011	 0.01284	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83862	 25961	 0.002701	 0.009457	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25962	 26067	 0.021895	 0.036516	 0.00053	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25962	 26803	 0.081754	 0.076075	 0.00144	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83884	 25962	 0.027972	 0.04285	 0.0006	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25962	 83918	 0.019551	 0.050257	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25963	 83917	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25963	 83917	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25963	 83920	 0.002036	 0.014126	 0.00403	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83917	 25964	 0.01304	 0.023885	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25964	 83918	 0.005704	 0.014663	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25965	 83918	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25965	 83918	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25965	 83920	 0.000617	 0.005614	 0.00142	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25966	 25968	 0.001508	 0.008416	 0.00215	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25966	 83919	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25966	 83919	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25966	 83925	 0.001231	 0.011194	 0.00283	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83888	 25967	 0.009121	 0.021598	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83917	 25967	 0.004564	 0.023735	 0.00051	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25969	 25971	 0.064055	 0.050693	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25969	 83921	 0.009855	 0.025333	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25970	 25977	 0.000213	 0.003806	 0.03909	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25970	 25981	 0.000174	 0.001942	 0.01814	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25970	 83920	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25972	 25973	 0.017189	 0.013473	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25973	 25979	 0.009212	 0.010034	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25973	 25980	 0.021716	 0.014059	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25973	 25982	 0.017187	 0.013602	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25973	 83926	 0.008581	 0.028626	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25974	 25975	 0.038408	 0.027765	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25974	 25979	 0.019203	 0.015197	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25975	 83922	 0.009989	 0.028345	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83920	 25976	 0.002217	 0.005698	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25976	 83922	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25976	 83922	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25976	 83925	 0.003486	 0.008091	 0.00246	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25977	 26058	 0.000251	 0.002808	 0.02623	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25977	 27195	 0.000279	 0.005067	 0.05065	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25977	 83923	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25978	 26806	 0.059869	 0.095566	 0.0022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25978	 26807	 0.042713	 0.0818	 0.00129	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83924	 25978	 0.022255	 0.051669	 0.00077	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25981	 26052	 0.00032	 0.003636	 0.03284	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25981	 27672	 0.001162	 0.013162	 0.11987	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25981	 83925	 0.0001	 0.007999	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25982	 25985	 0.008307	 0.012962	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83926	 25983	 0.008747	 0.029181	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83926	 25984	 0.0165	 0.021685	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25985	 25986	 0.014045	 0.011115	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83926	 25985	 0.006806	 0.022458	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25986	 25987	 0.015324	 0.012011	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83875	 25987	 0.012076	 0.008112	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25988	 25990	 0.002298	 0.007184	 0.00208	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25988	 25992	 0.001742	 0.004603	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25988	 83927	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25988	 83927	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25989	 83928	 0.025455	 0.018031	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25990	 26003	 0.003003	 0.007549	 0.00196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25990	 83928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25990	 83928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83924	 25991	 0.011252	 0.037535	 0.00059	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83926	 25991	 0.021798	 0.043158	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25991	 83929	 0.00641	 0.034154	 0.0006	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25992	 25993	 0.001143	 0.004041	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25993	 83929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25993	 83929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25993	 83948	 0.002042	 0.007116	 0.00165	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25994	 26003	 0.002806	 0.007212	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25994	 26054	 0.002428	 0.008329	 0.002	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83873	 25995	 0.000855	 0.002979	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83873	 25996	 0.000721	 0.004024	 0.00103	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25996	 83930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25996	 83930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25997	 83931	 0.000893	 0.003575	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25998	 26000	 0.001605	 0.005354	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25999	 26001	 6.5e-05	 0.001027	 0.0107	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25999	 26008	 0.000165	 0.001882	 0.01699	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25999	 83931	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26000	 83933	 0.002516	 0.007417	 0.00173	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26000	 83936	 0.000876	 0.007641	 0.0021	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26001	 26005	 0.000142	 0.001613	 0.01468	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26001	 27200	 0.000775	 0.01365	 0.22681	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26001	 83933	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26002	 26049	 0.02219	 0.022412	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83934	 26002	 0.005849	 0.015034	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26002	 83938	 0.005961	 0.023191	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83933	 26003	 0.004754	 0.012563	 0.00294	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26003	 83935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26003	 83935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26004	 26005	 7.2e-05	 0.000826	 0.00725	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26004	 26055	 0.000232	 0.002633	 0.02397	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26004	 83936	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26004	 83936	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26005	 83937	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83931	 26006	 0.000835	 0.00546	 0.00202	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26006	 83939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26006	 83939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83871	 26007	 0.009191	 0.01535	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26007	 83941	 0.004071	 0.00757	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26008	 83940	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26009	 26012	 0.00066	 0.003144	 0.00091	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26009	 26069	 0.00147	 0.005195	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26010	 26021	 0.010964	 0.01847	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26010	 83942	 0.002035	 0.00783	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26011	 26012	 0.000477	 0.002484	 0.00065	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26011	 83942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26011	 83942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83942	 26013	 0.014094	 0.011154	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26014	 26015	 0.016715	 0.013102	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26014	 26027	 0.01639	 0.010611	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26015	 26031	 0.006946	 0.017665	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26015	 83943	 0.003897	 0.023072	 0.00045	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26016	 26018	 0.010985	 0.011095	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26016	 26021	 0.007588	 0.009656	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26017	 26018	 0.013764	 0.010892	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26018	 83943	 0.010164	 0.017122	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83933	 26019	 0.002189	 0.014098	 0.0037	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26019	 83943	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26019	 83943	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83943	 26020	 0.018287	 0.01322	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26021	 26023	 0.003566	 0.005692	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26022	 26024	 0.006668	 0.013646	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26022	 26025	 0.002625	 0.011747	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26023	 26024	 0.003101	 0.007125	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26025	 26026	 0.021627	 0.017116	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83932	 26025	 0.018622	 0.017463	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83934	 26025	 0.009523	 0.027023	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26026	 83946	 0.035498	 0.027825	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26027	 26028	 0.012106	 0.009286	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83942	 26027	 0.019256	 0.021179	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26029	 26031	 0.038926	 0.025201	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26030	 26035	 0.006814	 0.013491	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83906	 26030	 0.046267	 0.036615	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26031	 26033	 0.00848	 0.032991	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26031	 26037	 0.003424	 0.01332	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26032	 26033	 0.019294	 0.015124	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26033	 83945	 0.002944	 0.016508	 0.00045	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26034	 26062	 0.057475	 0.045485	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83849	 26034	 0.012725	 0.029542	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83943	 26034	 0.01181	 0.04219	 0.00084	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26035	 26038	 0.005981	 0.017587	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26035	 83944	 0.01061	 0.013945	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26036	 26039	 0.001494	 0.00528	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26036	 26041	 0.001	 0.003011	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26036	 83944	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26036	 83944	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26037	 26038	 0.002906	 0.010383	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26037	 26040	 0.017495	 0.013845	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26042	 83945	 0.018034	 0.013037	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26043	 26044	 0.002279	 0.007122	 0.00206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26043	 83945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26043	 83945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26044	 26047	 0.003809	 0.010066	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83931	 26044	 0.004501	 0.011895	 0.00278	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83933	 26044	 0.001597	 0.008585	 0.00211	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26044	 83946	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26044	 83946	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26045	 26063	 0.019033	 0.05459	 0.00084	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26045	 83947	 0.011118	 0.025543	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26046	 26048	 0.003295	 0.010993	 0.00279	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26047	 26048	 0.006126	 0.017084	 0.00359	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26047	 83947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26047	 83947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83937	 26050	 0.001003	 0.011779	 0.00312	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26051	 26057	 0.018383	 0.015131	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83929	 26051	 0.041867	 0.033133	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26051	 83949	 0.00408	 0.01361	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26051	 83950	 0.041822	 0.03077	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26052	 26053	 4.1e-05	 0.000474	 0.00416	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26052	 83948	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26053	 26055	 0.000184	 0.002123	 0.01861	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83948	 26054	 0.000666	 0.003826	 0.00108	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26054	 83950	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26054	 83950	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26055	 83951	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26055	 83951	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83951	 26056	 0.00109	 0.009048	 0.00354	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26056	 84382	 0.001582	 0.013819	 0.00547	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26058	 83952	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26058	 83952	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83896	 26059	 0.005644	 0.01155	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83841	 26062	 0.033862	 0.066363	 0.00099	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83947	 26062	 0.02776	 0.071359	 0.0011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82034	 26063	 0.01242	 0.0706	 0.00128	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83884	 26064	 0.028509	 0.045505	 0.00105	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83885	 26064	 0.036181	 0.023424	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26064	 83953	 0.033388	 0.026422	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83883	 26065	 0.003197	 0.010967	 0.00263	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26065	 83953	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26065	 83953	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26066	 26067	 0.016111	 0.01043	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83918	 26067	 0.008309	 0.020624	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83897	 26068	 0.017441	 0.022923	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83931	 26069	 0.003661	 0.022718	 0.0055	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26069	 83954	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26069	 83954	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26070	 26071	 0.036145	 0.085592	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26070	 83955	 0.041411	 0.11471	 0.00189	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26071	 26072	 0.025702	 0.066071	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26071	 26790	 0.014627	 0.064819	 0.00195	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26071	 26791	 0.055606	 0.045769	 0.00093	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26071	 84087	 0.043214	 0.16813	 0.00281	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26072	 26073	 0.030853	 0.066117	 0.00116	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26072	 84087	 0.023395	 0.10308	 0.00179	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26072	 84225	 0.047469	 0.11021	 0.00164	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26073	 83955	 0.017602	 0.058088	 0.00094	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26074	 26076	 0.001438	 0.020757	 0.00659	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26074	 83955	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26074	 83955	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83955	 26075	 0.034846	 0.092117	 0.00167	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26075	 83956	 0.019231	 0.063464	 0.00103	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26076	 26400	 0.005627	 0.035639	 0.00967	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26076	 83956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26076	 83956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26076	 83957	 0.003482	 0.033429	 0.00972	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26077	 83958	 0.15637	 0.11506	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26077	 84623	 0.078353	 0.20144	 0.00312	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26078	 26399	 0.000635	 0.011321	 0.11745	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26078	 83957	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26079	 26941	 0.013171	 0.045905	 0.01065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82013	 26079	 0.001278	 0.014388	 0.00416	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26079	 83959	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26079	 83959	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26080	 26448	 0.041844	 0.11091	 0.00281	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83959	 26080	 0.043595	 0.14544	 0.00231	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26081	 26083	 0.022253	 0.1265	 0.00229	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26081	 26548	 0.023905	 0.12164	 0.00276	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26082	 26084	 0.00223	 0.036258	 0.01029	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81798	 26082	 0.00321	 0.039564	 0.01278	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26082	 83960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26082	 83960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83959	 26083	 0.019057	 0.14681	 0.00281	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26083	 83961	 0.015691	 0.061044	 0.00102	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26083	 83961	 0.015691	 0.061044	 0.00102	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26084	 26085	 0.000595	 0.009707	 0.00579	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81797	 26084	 0.000806	 0.013148	 0.00784	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26084	 83961	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26084	 83961	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82001	 26085	 0.001184	 0.016592	 0.01348	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26086	 26087	 0.005058	 0.02025	 0.0051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26086	 26529	 0.004758	 0.016649	 0.00552	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26087	 26092	 0.004877	 0.019525	 0.00492	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26088	 26095	 0.005642	 0.019011	 0.00472	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26088	 83962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26088	 83962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26088	 84129	 0.00755	 0.031953	 0.00719	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26089	 26090	 0.009488	 0.045545	 0.00136	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83962	 26089	 0.0075	 0.037512	 0.00067	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26089	 83965	 0.03058	 0.062581	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26090	 83968	 0.008675	 0.054472	 0.00119	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26091	 83963	 0.016016	 0.070168	 0.00151	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26091	 83968	 0.022381	 0.07466	 0.00118	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26092	 26105	 0.00537	 0.021853	 0.00532	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26092	 83963	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26092	 83963	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26093	 26100	 0.038706	 0.074993	 0.00161	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26093	 83964	 0.016496	 0.079593	 0.00141	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26093	 83969	 0.017521	 0.057819	 0.00094	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26094	 83964	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26094	 83964	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26094	 83967	 0.013685	 0.034403	 0.00891	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26095	 26096	 0.004296	 0.011354	 0.00266	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26095	 83965	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26095	 83965	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26096	 26097	 0.002925	 0.010338	 0.00233	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26097	 83966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26097	 83966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26098	 26099	 0.015093	 0.073653	 0.00127	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83966	 26098	 0.005182	 0.032542	 0.00071	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26099	 27209	 0.013086	 0.08045	 0.00145	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83964	 26099	 0.038248	 0.078602	 0.0015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26099	 83968	 0.15882	 0.24334	 0.00342	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26100	 27207	 0.037886	 0.087958	 0.00131	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26101	 83969	 0.129	 0.08352	 0.00159	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26102	 26524	 0.000729	 0.008259	 0.07519	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26102	 83967	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26103	 26516	 0.001429	 0.015807	 0.00474	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83967	 26103	 0.001073	 0.00937	 0.00371	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83968	 26104	 0.083403	 0.065376	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26105	 27609	 0.007694	 0.059975	 0.01794	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83967	 26105	 0.00552	 0.04294	 0.01115	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26105	 83969	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26105	 83969	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83969	 26106	 0.058216	 0.042085	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26107	 26108	 0.01426	 0.010101	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26107	 26114	 0.003513	 0.00931	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26107	 83978	 0.008975	 0.027533	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26109	 27096	 0.002231	 0.006221	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26109	 27097	 0.001785	 0.011499	 0.00301	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26109	 83977	 0.000706	 0.007138	 0.0021	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26110	 83977	 0.000765	 0.011253	 0.00344	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83613	 26111	 0.020725	 0.058812	 0.00092	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26111	 83970	 0.005027	 0.016768	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26112	 26115	 0.001014	 0.008147	 0.00229	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26112	 83970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26112	 83970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26112	 83977	 0.000892	 0.006607	 0.00339	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26113	 26114	 0.006156	 0.017655	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83970	 26113	 0.008437	 0.019587	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26115	 26135	 0.002829	 0.014994	 0.005	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26116	 26121	 0.005925	 0.020731	 0.00687	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26116	 26123	 0.005125	 0.015937	 0.00333	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26116	 27102	 0.002374	 0.008595	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26116	 83977	 0.001639	 0.013957	 0.00348	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26117	 26118	 0.000615	 0.006011	 0.00169	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26117	 26122	 0.001451	 0.009016	 0.00254	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26118	 26120	 0.000365	 0.004669	 0.00139	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26118	 26123	 0.001606	 0.008649	 0.00238	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26118	 83971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26118	 83971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26119	 26120	 0.000417	 0.003268	 0.00149	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26119	 27042	 0.000582	 0.006081	 0.00167	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26121	 26131	 0.003095	 0.020764	 0.00501	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26122	 83977	 0.002783	 0.015442	 0.00469	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26123	 26124	 0.004352	 0.011849	 0.00261	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26124	 26128	 0.004547	 0.010554	 0.00322	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26125	 26126	 0.002597	 0.006675	 0.00165	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26125	 83972	 0.007312	 0.019326	 0.00452	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26126	 84317	 0.004754	 0.012943	 0.00285	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26127	 27055	 0.000453	 0.005231	 0.04586	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26127	 27714	 0.000894	 0.015685	 0.16792	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26127	 83972	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26127	 83972	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26128	 26129	 0.000507	 0.005603	 0.00168	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26128	 26133	 0.002283	 0.014705	 0.00385	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26128	 83973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26128	 83973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26129	 26130	 0.00071	 0.007043	 0.00192	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26130	 26131	 0.000578	 0.00752	 0.00217	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83972	 26131	 0.001038	 0.010916	 0.00613	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83973	 26132	 0.010314	 0.022021	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26132	 83974	 0.013421	 0.034499	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26133	 26134	 0.002254	 0.019973	 0.00532	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26133	 83974	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26133	 83974	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26133	 83977	 0.017209	 0.045484	 0.01065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26134	 26138	 0.004672	 0.016025	 0.00384	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83972	 26134	 0.003868	 0.024916	 0.00653	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26135	 83975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26135	 83975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26136	 26137	 0.036544	 0.096607	 0.00175	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83850	 26137	 0.049987	 0.1023	 0.00252	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26137	 83976	 0.014538	 0.082643	 0.0015	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26138	 26139	 0.005885	 0.02051	 0.00476	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83636	 26139	 0.003281	 0.025141	 0.00673	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26139	 83976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26139	 83976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83975	 26140	 0.030852	 0.024416	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26141	 26967	 0.001234	 0.013739	 0.12961	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26141	 26996	 0.000245	 0.004533	 0.04356	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81996	 26141	 0.003281	 0.033209	 0.54901	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81996	 26141	 0.003281	 0.033209	 0.54901	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26141	 83977	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26141	 83977	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26142	 26148	 0.005114	 0.031445	 0.00907	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26142	 27661	 0.009709	 0.057846	 0.01522	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26143	 26145	 0.000273	 0.003149	 0.0276	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26143	 26147	 0.000462	 0.00533	 0.04673	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26143	 83979	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26143	 83979	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26144	 83982	 0.015704	 0.037187	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26144	 84359	 0.23725	 0.3308	 0.00566	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26145	 83980	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26145	 83980	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26146	 83982	 0.024939	 0.019737	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26147	 26150	 0.00027	 0.003055	 0.02781	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26147	 83981	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26147	 83984	 0.000456	 0.005263	 0.04614	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26148	 26149	 0.006142	 0.024138	 0.00631	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83981	 26148	 0.002138	 0.014822	 0.00869	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26149	 27161	 0.007815	 0.031803	 0.00775	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82012	 26150	 0.001083	 0.012751	 0.22286	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26150	 83983	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26150	 83983	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26150	 84364	 0.000728	 0.008398	 0.07363	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26151	 27162	 6e-05	 0.001231	 0.43517	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26151	 83984	 0.000181	 0.014517	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26151	 83984	 0.000181	 0.014517	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83985	 26151	 0.000184	 0.014757	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26152	 26363	 0.000684	 0.004696	 9e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26152	 84002	 0.004736	 0.032508	 0.00059	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26153	 26364	 0.005983	 0.006043	 8e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26153	 84076	 0.008632	 0.022189	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26154	 26155	 0.001084	 0.003872	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26154	 26363	 0.001358	 0.005284	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26155	 26156	 0.002332	 0.005994	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26155	 26158	 0.002302	 0.005855	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26155	 26367	 0.017598	 0.013498	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26156	 26159	 0.00237	 0.006027	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26157	 26163	 0.002273	 0.007953	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26157	 26363	 0.00227	 0.008734	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26158	 26163	 0.002854	 0.007336	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26159	 26163	 0.00466	 0.007439	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26160	 26161	 0.014465	 0.010642	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26161	 26173	 0.010294	 0.007573	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26161	 26177	 0.006681	 0.014264	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26161	 26366	 0.002659	 0.009833	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26162	 26163	 0.00138	 0.005639	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26162	 26366	 0.001793	 0.007176	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26163	 26164	 0.008003	 0.006334	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26163	 26165	 0.014163	 0.009169	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26165	 26166	 0.008955	 0.007087	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26167	 26241	 0.001012	 0.01443	 0.00482	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26167	 26354	 0.002607	 0.014354	 0.00518	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26167	 83986	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26167	 83986	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83986	 26168	 0.003175	 0.012353	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26169	 26170	 0.002195	 0.00704	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26169	 84076	 0.003824	 0.021738	 0.00039	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26170	 26207	 0.006503	 0.012744	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26170	 26369	 0.001512	 0.006698	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26170	 84068	 0.009764	 0.037986	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26172	 26173	 0.010747	 0.007907	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26172	 26175	 0.004485	 0.01153	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26172	 26369	 0.00328	 0.008431	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26174	 26177	 0.016368	 0.012042	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26175	 26177	 0.002027	 0.005211	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26176	 26177	 0.003653	 0.012187	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26176	 84066	 0.003389	 0.011307	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26177	 26178	 0.009637	 0.00709	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26177	 83993	 0.04392	 0.034758	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26179	 83987	 0.042849	 0.033911	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26179	 84062	 0.040521	 0.029813	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26180	 26181	 0.00092	 0.002431	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26180	 26183	 0.00123	 0.004012	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26180	 83987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26180	 83987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26180	 84061	 0.001987	 0.006925	 0.00161	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26181	 26344	 0.001657	 0.004449	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83987	 26182	 0.009849	 0.019501	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26182	 84057	 0.047682	 0.052444	 0.0007	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26183	 26185	 0.00165	 0.005011	 0.0011	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26184	 26186	 0.026042	 0.01686	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26184	 84075	 0.006343	 0.010593	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26185	 26365	 0.002216	 0.005857	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26186	 26189	 0.015927	 0.012605	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26187	 26188	 0.001307	 0.003558	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26187	 26365	 0.001931	 0.005256	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26188	 26351	 0.001774	 0.005515	 0.00115	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26189	 83988	 0.009206	 0.011716	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26189	 84057	 0.033791	 0.024427	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26190	 26352	 0.003478	 0.009869	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26190	 83988	 0.004601	 0.008696	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26191	 26192	 0.001228	 0.003244	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26191	 26193	 0.001259	 0.003268	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26191	 83988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26191	 83988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26192	 26339	 0.001527	 0.004258	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26193	 26248	 0.001383	 0.003654	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26193	 26350	 0.000739	 0.004292	 0.00101	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26194	 26248	 0.001026	 0.003025	 0.0007	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26194	 26330	 0.005334	 0.014321	 0.00325	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26194	 83989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26194	 83989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26194	 84059	 0.003836	 0.015357	 0.00387	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26195	 84057	 0.021031	 0.015934	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26195	 84058	 0.020499	 0.015081	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26196	 83990	 0.016947	 0.012839	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26196	 84014	 0.027965	 0.036393	 0.00051	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26197	 26198	 0.000835	 0.00366	 0.00126	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26197	 26248	 0.001577	 0.004169	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26197	 26350	 0.000557	 0.004065	 0.00104	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26197	 83990	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26197	 83990	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26198	 26327	 0.000806	 0.003228	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26199	 26350	 0.001488	 0.004052	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26199	 83991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26199	 83991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26200	 26201	 0.001333	 0.004446	 0.00113	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26200	 83992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26200	 83992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26201	 26355	 0.000663	 0.0037	 0.00095	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26201	 26373	 0.001866	 0.010284	 0.0024	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26201	 84067	 0.00132	 0.007732	 0.00211	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26202	 26203	 0.000776	 0.003108	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26202	 26349	 0.000728	 0.002498	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26203	 26370	 0.001147	 0.004593	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26203	 84067	 0.000323	 0.004134	 0.00123	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26204	 83993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26204	 83993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26204	 84067	 0.001938	 0.004981	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26205	 26369	 0.004499	 0.013542	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83993	 26205	 0.003295	 0.01153	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26206	 26207	 0.004052	 0.010306	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83993	 26206	 0.006009	 0.015282	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26207	 26208	 0.003599	 0.008522	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26208	 26209	 0.004484	 0.010172	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26209	 26210	 0.005189	 0.012046	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26209	 83996	 0.003714	 0.012257	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83986	 26210	 0.004336	 0.009834	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26211	 26268	 0.000164	 0.002875	 0.03076	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26211	 26356	 7.1e-05	 0.000999	 0.00953	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26211	 83994	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26212	 26215	 0.000197	 0.002089	 0.00062	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83994	 26212	 0.000417	 0.004001	 0.00116	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26212	 83996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26212	 83996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26213	 26216	 0.00239	 0.009298	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83995	 26213	 0.003445	 0.012737	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26213	 84000	 0.014955	 0.027807	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26214	 83997	 0.004448	 0.01484	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26214	 84004	 0.005688	 0.020319	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26215	 26224	 0.000229	 0.002883	 0.00089	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26215	 83997	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26215	 83997	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83997	 26216	 0.00249	 0.008719	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26217	 26304	 0.003808	 0.010223	 0.00232	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26217	 83998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26217	 83998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26217	 84067	 0.002413	 0.006478	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26218	 26219	 0.001649	 0.004358	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83994	 26218	 0.002237	 0.005808	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26218	 83999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26218	 83999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26219	 26299	 0.001729	 0.004568	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26219	 84000	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26219	 84000	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84000	 26220	 0.010384	 0.006975	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26221	 26301	 0.000795	 0.003185	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26221	 84026	 0.001127	 0.004285	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83999	 26222	 0.001795	 0.010911	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26222	 84027	 0.00438	 0.026622	 0.00049	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83997	 26223	 0.005122	 0.017933	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26223	 84008	 0.005989	 0.023966	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26224	 26236	 0.000359	 0.004372	 0.00145	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26225	 26226	 0.020355	 0.013178	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26226	 84004	 0.014611	 0.011563	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26227	 26371	 0.01303	 0.009587	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83986	 26227	 0.005283	 0.026724	 0.00046	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26227	 84001	 0.001794	 0.011028	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26228	 26229	 0.000702	 0.002809	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26228	 26368	 0.001673	 0.007081	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26229	 26230	 0.000241	 0.001213	 0.00032	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26229	 84001	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26229	 84001	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26230	 26231	 0.000947	 0.002502	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26230	 26285	 0.001335	 0.006514	 0.0018	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26231	 26243	 0.000418	 0.003645	 0.001	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26231	 84002	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26231	 84002	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26232	 84003	 0.008217	 0.012184	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26232	 84010	 0.031437	 0.020352	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26233	 26239	 0.003119	 0.011141	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84001	 26233	 0.003922	 0.01085	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26234	 26247	 0.003825	 0.01045	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26234	 84003	 0.003979	 0.009236	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26235	 26238	 0.001111	 0.005678	 0.00155	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26235	 26283	 0.000517	 0.00268	 0.00065	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26235	 84003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26235	 84003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26236	 26237	 0.000832	 0.004061	 0.00112	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26236	 84004	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26236	 84004	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26236	 84007	 0.000213	 0.003038	 0.00101	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26237	 26238	 0.000466	 0.002343	 0.00061	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26237	 84005	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26237	 84005	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26238	 26241	 0.00174	 0.006965	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26238	 84006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26238	 84006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26239	 26247	 0.002959	 0.008905	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84006	 26239	 0.01142	 0.009038	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26240	 26272	 6.5e-05	 0.000724	 0.00683	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26240	 84007	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26241	 26277	 0.001847	 0.011476	 0.00324	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26241	 84009	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26241	 84009	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26241	 84030	 0.000431	 0.004134	 0.0012	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84005	 26242	 0.007981	 0.01274	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26242	 84013	 0.005141	 0.013591	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26242	 84028	 0.020624	 0.020684	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26243	 84010	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26243	 84010	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26243	 84011	 0.000588	 0.006912	 0.00183	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26244	 26275	 0.000144	 0.002598	 0.04099	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26244	 84011	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26245	 26246	 0.003986	 0.012229	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26245	 26280	 0.009745	 0.022623	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26245	 84032	 0.013167	 0.033486	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26246	 84018	 0.007602	 0.029688	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26247	 84013	 0.014786	 0.01159	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26247	 84033	 0.00719	 0.016694	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26249	 26279	 0.001325	 0.00344	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26249	 84013	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26249	 84013	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26250	 26316	 0.001936	 0.007009	 0.0015	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26250	 26370	 0.001104	 0.003681	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26250	 84014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26250	 84014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26251	 26305	 0.009419	 0.024212	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84000	 26251	 0.004817	 0.009858	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26252	 26253	 5.8e-05	 0.000974	 0.01895	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26252	 26254	 4.3e-05	 0.000658	 0.01494	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26252	 84015	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26252	 84015	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26253	 26358	 0.000481	 0.005354	 0.05049	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26253	 84016	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26253	 84016	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26254	 26274	 9.5e-05	 0.0016	 0.02901	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26254	 84017	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26255	 84020	 0.016086	 0.041352	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26255	 84071	 0.016842	 0.048306	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26256	 26257	 0.002133	 0.009602	 0.00255	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26256	 84070	 0.004016	 0.018081	 0.00481	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26257	 26290	 0.002018	 0.007931	 0.00207	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26257	 84019	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26257	 84019	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26258	 26265	 0.00062	 0.004163	 0.001	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26258	 26291	 0.001102	 0.006665	 0.0017	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26259	 26260	 0.000426	 0.005362	 0.00166	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26259	 26263	 0.000545	 0.007283	 0.00199	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26259	 84020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26259	 84020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26260	 26276	 0.000471	 0.005385	 0.00164	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26260	 84021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26260	 84021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26261	 26263	 0.000696	 0.005857	 0.00173	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26261	 26265	 0.000675	 0.006284	 0.00195	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26261	 84022	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26261	 84022	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26262	 84037	 0.018169	 0.014379	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26263	 84023	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26263	 84023	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26264	 84024	 0.013172	 0.010325	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26265	 26296	 0.001902	 0.005914	 0.00123	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26265	 84024	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26265	 84024	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84023	 26266	 0.005173	 0.022791	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26266	 84025	 0.005237	 0.013461	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26267	 26296	 0.001031	 0.005753	 0.00147	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26267	 84025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26267	 84025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26267	 84026	 0.001942	 0.006794	 0.00225	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26268	 26269	 6.7e-05	 0.000945	 0.00901	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26268	 26273	 4.4e-05	 0.000801	 0.01476	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26269	 26297	 0.000135	 0.002467	 0.02445	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26269	 84026	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84021	 26270	 0.013092	 0.033931	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84023	 26270	 0.003475	 0.019756	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26270	 84029	 0.009829	 0.03511	 0.0007	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26271	 26272	 3.7e-05	 0.000405	 0.00393	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26271	 26273	 4.2e-05	 0.000497	 0.00844	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26271	 26275	 2.4e-05	 0.000378	 0.00621	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26272	 84028	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26272	 84028	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26273	 26274	 3e-05	 0.000458	 0.0082	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26273	 84029	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26273	 84029	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26274	 26275	 2.3e-05	 0.000358	 0.00373	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26275	 84030	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26275	 84030	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84017	 26276	 0.000734	 0.006224	 0.00373	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26276	 84031	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26276	 84031	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84015	 26277	 0.000916	 0.013467	 0.00412	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84030	 26277	 0.001419	 0.008309	 0.00226	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26277	 84032	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26277	 84032	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84032	 26278	 0.007466	 0.024907	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26278	 84033	 0.005984	 0.016982	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26279	 84033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26279	 84033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26280	 26282	 0.021575	 0.031991	 0.00048	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26281	 26282	 0.029001	 0.022951	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84012	 26282	 0.011474	 0.029495	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84011	 26283	 0.001124	 0.005853	 0.00154	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84003	 26284	 0.008936	 0.020436	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84012	 26284	 0.003613	 0.008557	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84011	 26285	 0.000806	 0.004049	 0.00105	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26286	 26289	 0.009626	 0.019058	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26286	 84044	 0.035566	 0.028146	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26287	 26302	 0.007408	 0.019198	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26287	 84046	 0.013661	 0.027048	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26288	 26289	 0.005358	 0.015205	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26288	 26302	 0.006064	 0.020228	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26290	 26292	 0.000848	 0.002202	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26291	 26293	 0.000862	 0.00546	 0.00148	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26291	 84034	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26291	 84034	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26291	 84036	 0.001861	 0.005189	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26292	 26293	 0.001548	 0.003891	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26292	 84035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26292	 84035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26294	 26302	 0.005595	 0.0273	 0.00047	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26294	 84040	 0.002078	 0.011813	 0.00021	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26295	 26297	 6.9e-05	 0.000758	 0.00736	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26295	 26309	 0.000166	 0.002895	 0.03132	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26295	 84036	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26295	 84036	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26296	 84037	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26296	 84037	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26296	 84038	 0.000385	 0.002623	 0.00089	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26297	 84038	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26298	 26299	 0.001599	 0.004458	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84036	 26298	 0.002554	 0.006857	 0.00155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26298	 84040	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26298	 84040	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26299	 84041	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26299	 84041	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26300	 26301	 0.000522	 0.002123	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26300	 84042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26300	 84042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26302	 26303	 0.015397	 0.025715	 0.00044	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26303	 84043	 0.010649	 0.024465	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26304	 84043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26304	 84043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83998	 26305	 0.015063	 0.022048	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26306	 26308	 0.001753	 0.006014	 0.00144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83576	 26306	 0.003146	 0.008446	 0.00191	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26306	 84044	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26306	 84044	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26307	 26334	 0.009571	 0.027451	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26307	 27708	 0.020567	 0.037109	 0.00054	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26307	 84047	 0.021234	 0.054584	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26307	 84052	 0.009951	 0.02558	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26308	 84045	 0.000315	 0.004546	 0.00144	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26308	 84048	 0.001357	 0.008344	 0.00241	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26309	 26356	 0.000366	 0.004055	 0.0386	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26309	 84045	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26310	 26311	 0.016738	 0.016742	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83992	 26310	 0.006844	 0.022585	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26311	 84077	 0.016678	 0.013199	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84046	 26312	 0.004091	 0.020694	 0.00036	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26312	 84049	 0.009874	 0.028321	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26312	 84077	 0.029035	 0.019504	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26313	 26314	 0.002472	 0.006417	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26313	 84047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26313	 84047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26313	 84048	 0.001726	 0.009473	 0.0025	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26314	 26321	 0.002002	 0.005375	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26315	 26356	 0.0004	 0.004526	 0.0412	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26315	 84048	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26316	 26317	 0.000862	 0.0049	 0.00142	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26316	 26373	 0.000799	 0.002665	 0.00068	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26316	 84050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26316	 84050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26317	 26321	 0.001803	 0.008274	 0.00212	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84014	 26318	 0.014674	 0.023422	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84050	 26318	 0.01317	 0.00969	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26319	 26320	 0.023111	 0.02542	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83991	 26320	 0.002705	 0.007169	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83621	 26321	 0.011245	 0.028907	 0.00716	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26321	 84051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26321	 84051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84048	 26322	 0.001208	 0.012422	 0.00352	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26322	 84052	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26322	 84052	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26323	 26324	 0.001785	 0.006124	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26323	 84053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26323	 84053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26324	 26325	 0.000853	 0.002566	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26325	 26326	 0.000412	 0.001601	 0.00043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26326	 26327	 0.001003	 0.003631	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26326	 26330	 0.001596	 0.004219	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26328	 26329	 0.018735	 0.024623	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84052	 26328	 0.02893	 0.022895	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84052	 26329	 0.04397	 0.033728	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84053	 26329	 0.004805	 0.02141	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26330	 84054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26330	 84054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26331	 26332	 0.028499	 0.01845	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84054	 26331	 0.007332	 0.012351	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26332	 26333	 0.013512	 0.026482	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26332	 84056	 0.036253	 0.02869	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83989	 26333	 0.007571	 0.020013	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26334	 84055	 0.022019	 0.022024	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26334	 84596	 0.019098	 0.034459	 0.0005	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26335	 26336	 0.00242	 0.006395	 0.0015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26336	 26337	 0.001707	 0.007107	 0.00222	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26336	 27710	 0.001744	 0.00698	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26336	 84055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26336	 84055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26337	 26338	 0.003048	 0.017854	 0.00486	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26338	 84056	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26338	 84056	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26338	 84059	 0.002431	 0.0154	 0.00418	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26339	 26340	 0.001743	 0.004525	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26339	 84057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26339	 84057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26340	 84058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26340	 84058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26340	 84059	 0.002421	 0.008765	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26341	 26346	 0.000206	 0.002393	 0.02298	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26341	 27712	 0.000669	 0.011734	 0.12558	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26341	 84059	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26342	 26345	 0.016346	 0.032035	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84060	 26342	 0.033626	 0.02177	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26343	 26346	 9.3e-05	 0.001023	 0.00993	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26343	 84061	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26343	 84061	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26344	 84062	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26344	 84062	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26344	 84063	 0.005001	 0.013215	 0.00309	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26345	 84064	 0.011395	 0.022561	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26346	 84063	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26347	 26348	 0.007118	 0.018867	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84064	 26347	 0.007331	 0.015003	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82033	 26348	 0.024033	 0.072337	 0.00141	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26349	 26350	 0.000825	 0.002832	 0.00068	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26350	 26351	 0.000316	 0.002067	 0.00077	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26350	 84067	 0.001053	 0.010646	 0.00313	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26351	 26354	 0.0007	 0.003576	 0.00097	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26351	 84065	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26351	 84065	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84065	 26352	 0.003394	 0.008038	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83991	 26353	 0.009192	 0.026084	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83993	 26353	 0.002354	 0.011975	 0.00027	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84065	 26353	 0.004223	 0.012112	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26353	 84066	 0.004912	 0.011403	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26354	 84066	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26354	 84066	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26355	 84067	 0.00071	 0.004159	 0.00113	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26356	 84067	 0.000119	 0.009548	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26357	 26359	 0.000479	 0.006983	 0.00224	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83562	 26357	 0.001918	 0.013873	 0.00746	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26357	 84069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26357	 84069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26358	 84070	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26359	 26360	 0.003144	 0.011439	 0.0035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82156	 26359	 0.002833	 0.024167	 0.02076	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83562	 26359	 0.004293	 0.027193	 0.00738	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26359	 84072	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26359	 84072	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84016	 26360	 0.003748	 0.014579	 0.00389	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26360	 84073	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26360	 84073	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84016	 26361	 0.001036	 0.00494	 0.00143	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26361	 84074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26361	 84074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83986	 26362	 0.009975	 0.031672	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84002	 26362	 0.004273	 0.024287	 0.00044	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26363	 84076	 0.002784	 0.008927	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26365	 84075	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26365	 84075	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26368	 84076	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26368	 84076	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83622	 26372	 0.054778	 0.039599	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83625	 26372	 0.012072	 0.015866	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26373	 84077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26373	 84077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26374	 26379	 0.000524	 0.005838	 0.05505	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26374	 84078	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26375	 84081	 0.026846	 0.064033	 0.00143	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26376	 26383	 0.005371	 0.026987	 0.00702	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26376	 27257	 0.013314	 0.045677	 0.01094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26376	 84214	 0.042101	 0.14686	 0.03409	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26377	 26378	 0.013765	 0.026976	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26378	 84081	 0.004781	 0.021303	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83508	 26379	 0.002185	 0.025241	 0.22157	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26379	 84080	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84081	 26380	 0.007964	 0.026568	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26380	 84083	 0.016158	 0.040105	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26380	 84084	 0.10012	 0.14192	 0.0029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26381	 26382	 0.013757	 0.021959	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84081	 26382	 0.010379	 0.04625	 0.00079	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26383	 84082	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26383	 84082	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26384	 26385	 0.012078	 0.031923	 0.00747	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26384	 84083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26384	 84083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26385	 26386	 0.005194	 0.039125	 0.01086	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26385	 84084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26385	 84084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26387	 26388	 0.002185	 0.017133	 0.00783	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26387	 27806	 0.002608	 0.03178	 0.01051	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26388	 26392	 0.000482	 0.007015	 0.00225	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26389	 26390	 0.12168	 0.13385	 0.00179	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83506	 26390	 0.0506	 0.16699	 0.00271	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26391	 26392	 0.002158	 0.035087	 0.00995	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83507	 26391	 0.002498	 0.023986	 0.01117	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26392	 84085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26392	 84085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26393	 26591	 0.20573	 0.13322	 0.00254	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26393	 26899	 0.044658	 0.1772	 0.00506	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83521	 26393	 0.071786	 0.4416	 0.00797	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84085	 26393	 0.016785	 0.073536	 0.00158	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26394	 26398	 0.03371	 0.13115	 0.00219	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26394	 84109	 0.074766	 0.20428	 0.00347	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26395	 84572	 0.027121	 0.16675	 0.00301	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26396	 26397	 0.006592	 0.027216	 0.00644	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26396	 27663	 0.006504	 0.025563	 0.00669	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83549	 26398	 0.024265	 0.092973	 0.00263	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26399	 26754	 0.00093	 0.00939	 0.15458	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83508	 26399	 0.001946	 0.025169	 0.42353	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26399	 84086	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26400	 26401	 0.000924	 0.014329	 0.00404	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83813	 26400	 0.00296	 0.020525	 0.01203	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26402	 26403	 0.068238	 0.13511	 0.00198	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82053	 26402	 0.002894	 0.012826	 0.00039	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84087	 26402	 0.03779	 0.10839	 0.00167	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26404	 26405	 0.009501	 0.036116	 0.01011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26404	 27254	 0.009719	 0.025232	 0.00612	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26404	 27791	 0.004364	 0.034218	 0.01564	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82008	 26405	 0.003933	 0.037766	 0.01099	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26405	 84088	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26405	 84088	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26406	 26412	 0.000375	 0.00681	 0.06807	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26406	 84089	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84089	 26407	 0.004436	 0.019767	 0.00537	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26407	 84092	 0.003973	 0.023076	 0.00543	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26408	 26410	 0.003614	 0.024808	 0.00724	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84089	 26408	 0.003057	 0.026216	 0.00746	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26409	 26410	 0.00659	 0.025902	 0.00678	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26409	 26414	 0.003325	 0.024053	 0.01294	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83500	 26410	 0.026175	 0.073006	 0.01533	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26410	 84091	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26410	 84091	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84091	 26411	 0.016458	 0.042307	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26411	 84428	 0.10594	 0.30394	 0.00468	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26412	 26413	 0.000598	 0.00656	 0.06372	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26412	 84092	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26412	 84092	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26413	 27324	 0.002004	 0.023144	 0.20312	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83842	 26415	 0.006177	 0.021191	 0.00508	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26415	 84093	 0.005912	 0.020281	 0.00486	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26416	 27683	 0.019508	 0.052379	 0.01187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26416	 84426	 0.015665	 0.041402	 0.00969	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26417	 26418	 0.003492	 0.023427	 0.00566	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26417	 27684	 0.007872	 0.062853	 0.0155	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83842	 26418	 0.010427	 0.044133	 0.00993	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26418	 84093	 0.003519	 0.012802	 0.00392	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26418	 84094	 0.004391	 0.020146	 0.00516	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26419	 26420	 0.000235	 0.002734	 0.02363	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26419	 84093	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26419	 84093	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26420	 27132	 0.002101	 0.024271	 0.21303	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26420	 27685	 0.000976	 0.015859	 0.15465	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26420	 84094	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26420	 84094	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84094	 26421	 0.002085	 0.014677	 0.00834	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26422	 26428	 0.002002	 0.024838	 0.01076	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26422	 27748	 0.002147	 0.024538	 0.00748	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26422	 84095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26422	 84095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84095	 26423	 0.022935	 0.059441	 0.00112	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26423	 84489	 0.046699	 0.12104	 0.00229	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26423	 84566	 0.032409	 0.12608	 0.0021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26424	 26427	 0.001405	 0.017681	 0.00548	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26424	 27749	 0.005017	 0.025205	 0.00656	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26424	 27750	 0.014689	 0.040963	 0.0086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26424	 84096	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26424	 84096	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26425	 26426	 0.006103	 0.034558	 0.00857	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26425	 27750	 0.005691	 0.029643	 0.00777	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83659	 26425	 0.011144	 0.098784	 0.02631	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26425	 84097	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26425	 84097	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26426	 84098	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26426	 84098	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83659	 26427	 0.007445	 0.072755	 0.02042	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26427	 84099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26427	 84099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26428	 27655	 0.007012	 0.018205	 0.00442	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83659	 26428	 0.00397	 0.060668	 0.01955	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26428	 84100	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26428	 84100	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84098	 26429	 0.060915	 0.16643	 0.00283	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84099	 26429	 0.14127	 0.11181	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84100	 26429	 0.036681	 0.075066	 0.00185	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83829	 26430	 0.094544	 0.084721	 0.00173	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26431	 26433	 0.004537	 0.016429	 0.00352	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26431	 84101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26431	 84101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26432	 26441	 0.039635	 0.11248	 0.00177	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84101	 26432	 0.026256	 0.035821	 0.00064	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26432	 84102	 0.006872	 0.036614	 0.00064	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26432	 84103	 0.017284	 0.047219	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26433	 26434	 0.003315	 0.008521	 0.00211	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26433	 26436	 0.006322	 0.037032	 0.01009	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26433	 84102	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26433	 84102	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26434	 84103	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26434	 84103	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26435	 26437	 0.038004	 0.11439	 0.00224	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84102	 26435	 0.097733	 0.091654	 0.00142	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26435	 84104	 0.028222	 0.094147	 0.00149	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26436	 84104	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26436	 84104	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26436	 84435	 0.004786	 0.053865	 0.01415	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26437	 26438	 0.093782	 0.11433	 0.00183	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26437	 26439	 0.08561	 0.09325	 0.00127	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26437	 26440	 0.052475	 0.1349	 0.00209	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26438	 26439	 0.011809	 0.055536	 0.00103	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26438	 27343	 0.056677	 0.15023	 0.00381	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26439	 27286	 0.15484	 0.10025	 0.00191	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26439	 84422	 0.041341	 0.2178	 0.00391	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26440	 84422	 0.043125	 0.14232	 0.00231	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26441	 84105	 0.041009	 0.11762	 0.00181	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26442	 26671	 0.009553	 0.027401	 0.00674	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26442	 84105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26442	 84105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82017	 26443	 0.012357	 0.042393	 0.01016	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26443	 84106	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26443	 84106	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84106	 26444	 0.078248	 0.079034	 0.00105	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26445	 26446	 0.035762	 0.060244	 0.00086	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26446	 26447	 0.022255	 0.052699	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26446	 26449	 0.020938	 0.11531	 0.0026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84106	 26446	 0.070295	 0.14775	 0.00269	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26448	 26449	 0.048382	 0.13218	 0.00225	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82018	 26448	 0.21462	 0.19773	 0.00317	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26449	 27328	 0.035566	 0.13342	 0.0024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26449	 27328	 0.035566	 0.13342	 0.0024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26450	 26462	 0.000216	 0.003873	 0.03978	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26450	 26467	 0.000132	 0.001537	 0.02724	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26450	 84107	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26450	 84107	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26451	 26458	 0.001456	 0.009143	 0.0002	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84107	 26451	 0.001657	 0.010068	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26452	 26457	 0.007495	 0.011481	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26452	 26458	 0.016219	 0.027048	 0.00039	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26453	 26456	 0.006312	 0.014436	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26453	 26458	 0.004903	 0.011212	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81719	 26453	 0.009682	 0.037667	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81719	 26453	 0.009682	 0.037667	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26453	 84111	 0.007889	 0.030692	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26453	 84111	 0.007889	 0.030692	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26454	 26456	 0.011581	 0.032078	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26454	 26457	 0.007074	 0.022778	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26454	 84109	 0.010548	 0.027882	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26454	 84113	 0.030126	 0.079849	 0.00203	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26455	 26466	 0.000159	 0.001806	 0.0163	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26455	 26467	 0.000326	 0.003579	 0.03476	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26455	 84108	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26456	 26458	 0.007084	 0.015678	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82020	 26457	 0.061811	 0.17542	 0.00276	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82020	 26459	 0.091238	 0.11874	 0.00166	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84109	 26459	 0.078443	 0.22263	 0.0035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26460	 26463	 0.009454	 0.037852	 0.00954	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26461	 26462	 4e-05	 0.000751	 0.00711	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26463	 26464	 0.001095	 0.016097	 0.00492	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82019	 26463	 0.000953	 0.008748	 0.00751	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84108	 26464	 0.000992	 0.013625	 0.00491	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84109	 26465	 0.10209	 0.092115	 0.00154	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26466	 84110	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26466	 84110	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26467	 84111	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26467	 84111	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26468	 84112	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26469	 26470	 0.017414	 0.066995	 0.00114	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84113	 26469	 0.042383	 0.10895	 0.00169	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26471	 84114	 0.059788	 0.047316	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82005	 26472	 0.00733	 0.025145	 0.00602	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26472	 84114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26472	 84114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26473	 26483	 0.000858	 0.009903	 0.08683	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26473	 84115	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26474	 26475	 0.001738	 0.010885	 0.00784	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84115	 26474	 0.001182	 0.017657	 0.00522	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26474	 84117	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26474	 84117	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26475	 26478	 0.004568	 0.02893	 0.00785	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26475	 84424	 0.00159	 0.025584	 0.00836	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26476	 27288	 0.002144	 0.022029	 0.00697	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26476	 84118	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26476	 84118	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26476	 84121	 0.004453	 0.032994	 0.01691	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84118	 26477	 0.041	 0.11635	 0.00183	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26477	 84119	 0.059233	 0.070909	 0.00118	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26477	 84123	 0.046589	 0.11033	 0.00202	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26478	 84119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26478	 84119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26478	 84121	 0.00475	 0.019018	 0.00479	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84119	 26479	 0.022343	 0.024574	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84116	 26480	 0.20193	 0.15982	 0.00201	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84117	 26480	 0.01639	 0.072214	 0.00125	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26480	 84120	 0.007982	 0.039922	 0.00071	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26480	 84122	 0.036231	 0.093138	 0.00144	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26481	 26482	 0.008814	 0.031918	 0.00685	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26481	 26574	 0.012526	 0.040858	 0.01085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26482	 84120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26482	 84120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26482	 84121	 0.004961	 0.013112	 0.00307	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26483	 84121	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26484	 26575	 0.009699	 0.028595	 0.00665	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26484	 84123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26484	 84123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26485	 84124	 0.010605	 0.011766	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26485	 84125	 0.0055	 0.009173	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26486	 84124	 0.013015	 0.009575	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26486	 84149	 0.016427	 0.013	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26487	 26489	 0.001508	 0.003985	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26487	 26542	 0.002014	 0.005063	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26487	 84124	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26487	 84124	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84124	 26488	 0.006458	 0.010727	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26488	 84127	 0.011166	 0.015234	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26489	 84125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26489	 84125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26489	 84126	 0.001419	 0.003683	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26490	 26493	 4.5e-05	 0.000757	 0.00799	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26490	 26496	 6e-05	 0.000921	 0.01042	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26490	 84126	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26491	 26492	 0.007178	 0.01649	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26491	 84130	 0.005971	 0.013718	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26492	 26497	 0.012565	 0.036038	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83747	 26492	 0.014629	 0.065188	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84127	 26492	 0.002528	 0.019702	 0.00037	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26492	 84131	 0.012149	 0.069058	 0.00125	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26493	 84128	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26493	 84128	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26494	 26495	 0.000854	 0.007817	 0.00313	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26494	 84129	 0.004713	 0.012115	 0.003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26495	 26498	 0.001185	 0.011378	 0.00331	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26496	 26505	 4.8e-05	 0.000687	 0.00631	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26496	 84129	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26497	 26513	 0.010442	 0.058669	 0.00109	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84130	 26497	 0.005789	 0.013709	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26498	 26499	 0.00036	 0.003392	 0.00103	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26499	 84131	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26499	 84131	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26499	 84147	 0.002072	 0.015304	 0.00442	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26500	 26512	 0.009407	 0.02698	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84131	 26500	 0.010541	 0.024961	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26500	 84132	 0.002853	 0.015199	 0.00027	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26501	 26502	 0.000175	 0.002119	 0.00192	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26501	 26511	 0.000232	 0.003487	 0.00204	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26502	 26503	 0.000164	 0.002393	 0.00149	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26503	 84132	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26503	 84132	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26503	 84133	 0.000174	 0.002289	 0.00212	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26504	 26505	 7.6e-05	 0.001081	 0.01031	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26504	 26541	 0.000166	 0.002694	 0.04205	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26504	 84133	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26504	 84133	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26506	 26507	 0.005907	 0.013712	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26506	 84136	 0.007434	 0.019111	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26507	 84135	 0.010515	 0.01926	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26508	 84134	 0.02568	 0.020323	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26509	 26510	 0.000509	 0.007548	 0.00233	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26509	 26538	 0.000678	 0.0075	 0.00225	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26509	 84134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26509	 84134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26510	 26511	 0.000328	 0.00432	 0.00264	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26510	 84135	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26510	 84135	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26510	 84147	 0.000543	 0.006007	 0.0018	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26511	 84136	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26511	 84136	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84136	 26512	 0.007864	 0.018254	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84131	 26513	 0.01012	 0.026014	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26513	 84137	 0.004166	 0.030174	 0.00076	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26514	 26516	 0.000914	 0.010119	 0.00329	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26514	 84137	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26514	 84137	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26514	 84147	 0.000351	 0.003641	 0.00113	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26515	 26526	 0.004614	 0.020558	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84137	 26515	 0.003987	 0.019431	 0.00036	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26515	 84139	 0.012115	 0.034378	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26515	 84148	 0.004781	 0.0222	 0.00061	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26517	 26518	 0.00085	 0.00483	 0.0014	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26517	 26538	 0.000539	 0.00406	 0.00113	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26518	 84138	 0.002324	 0.006143	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26518	 84140	 0.00078	 0.00837	 0.00218	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84134	 26519	 0.010184	 0.029208	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26519	 84144	 0.010205	 0.024165	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26520	 26527	 0.031127	 0.034236	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82051	 26520	 0.009103	 0.015684	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26520	 84139	 0.009684	 0.026454	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26521	 26525	 4.7e-05	 0.000738	 0.00769	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26521	 26541	 0.000221	 0.004081	 0.03921	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26521	 84138	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26521	 84138	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84138	 26522	 0.000617	 0.002549	 0.0006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26523	 84139	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26523	 84139	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26523	 84147	 0.002004	 0.013102	 0.00333	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26524	 26525	 0.000149	 0.001581	 0.01649	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26524	 26541	 0.000331	 0.005477	 0.05134	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26524	 84140	 0.000128	 0.010206	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26525	 26530	 0.000209	 0.002322	 0.0219	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84139	 26526	 0.018523	 0.033422	 0.00048	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84139	 26528	 0.01561	 0.060729	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26529	 84145	 0.0067	 0.026823	 0.00676	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26530	 26539	 0.000171	 0.001873	 0.0182	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84141	 26531	 0.02296	 0.065852	 0.00101	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26531	 84146	 0.007804	 0.015969	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26532	 84142	 0.000128	 0.010206	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84143	 26533	 0.041955	 0.029719	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26534	 26537	 0.053591	 0.042411	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26535	 26537	 0.052327	 0.041411	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83533	 26536	 0.010475	 0.040749	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84143	 26536	 0.008626	 0.045961	 0.00081	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84143	 26537	 0.0167	 0.042928	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26538	 84144	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26538	 84144	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26539	 84145	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84131	 26540	 0.033928	 0.062143	 0.00107	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26541	 84147	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82031	 26542	 0.000586	 0.004926	 0.00146	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26542	 84149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26542	 84149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26543	 26554	 0.001332	 0.022278	 0.01263	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82026	 26543	 0.001279	 0.02028	 0.01283	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26543	 84150	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26543	 84150	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26544	 26545	 0.003346	 0.010264	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26544	 26545	 0.003346	 0.010264	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26544	 26546	 0.009137	 0.03121	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26544	 26546	 0.009137	 0.03121	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26544	 26551	 0.00987	 0.037024	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26544	 26551	 0.00987	 0.037024	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84150	 26544	 0.004199	 0.01288	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84150	 26544	 0.004199	 0.01288	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26545	 26550	 0.009317	 0.032601	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26545	 26550	 0.009317	 0.032601	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26546	 26550	 0.010382	 0.036328	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26546	 26550	 0.010382	 0.036328	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82027	 26546	 0.019598	 0.076241	 0.00127	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82027	 26546	 0.019598	 0.076241	 0.00127	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26547	 26558	 0.037882	 0.14007	 0.00259	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26547	 26558	 0.037882	 0.14007	 0.00259	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83960	 26547	 0.038877	 0.18973	 0.00328	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26547	 84151	 0.047426	 0.16596	 0.00344	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26547	 84151	 0.047426	 0.16596	 0.00344	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26548	 27329	 0.025533	 0.14515	 0.00263	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82026	 26549	 0.003791	 0.022753	 0.00689	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26549	 84151	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26549	 84151	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26549	 84445	 0.002687	 0.036601	 0.01309	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84151	 26550	 0.020007	 0.076971	 0.00131	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84151	 26550	 0.020007	 0.076971	 0.00131	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26551	 26553	 0.004414	 0.040603	 0.00081	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81844	 26551	 0.032252	 0.11522	 0.00229	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81844	 26551	 0.032252	 0.11522	 0.00229	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84150	 26551	 0.005912	 0.022178	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84150	 26551	 0.005912	 0.022178	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26552	 84152	 0.064645	 0.063253	 0.00089	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81843	 26553	 0.030889	 0.094762	 0.00257	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81843	 26553	 0.030889	 0.094762	 0.00257	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84150	 26553	 0.007549	 0.062798	 0.00119	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26554	 84152	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26554	 84152	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26555	 26556	 0.005707	 0.036821	 0.00117	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26555	 26557	 0.024544	 0.075296	 0.00204	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81723	 26555	 0.011143	 0.04287	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81723	 26555	 0.011143	 0.04287	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84152	 26555	 0.013546	 0.052697	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84152	 26555	 0.013546	 0.052697	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26556	 26558	 0.010195	 0.077458	 0.00176	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26557	 26558	 0.020385	 0.079304	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26557	 26558	 0.020385	 0.079304	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83960	 26558	 0.028201	 0.15435	 0.00302	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26559	 26560	 0.016307	 0.011788	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26559	 26561	 0.0113	 0.022374	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26559	 26589	 0.012185	 0.020526	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26559	 84154	 0.008385	 0.03262	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26560	 26569	 0.017964	 0.014216	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26560	 26589	 0.027033	 0.021393	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26561	 26562	 0.019682	 0.01988	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26562	 26570	 0.055795	 0.036122	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26562	 84153	 0.028662	 0.021088	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26563	 26564	 0.003853	 0.010002	 0.00243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26563	 26568	 0.00586	 0.020712	 0.00467	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26563	 26574	 0.01032	 0.026793	 0.0065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26563	 84153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26563	 84153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26564	 26565	 0.002717	 0.006831	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26565	 26588	 0.007954	 0.021022	 0.00492	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26566	 26567	 0.005249	 0.013628	 0.00331	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26566	 26587	 0.006173	 0.022351	 0.0048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26566	 84154	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26566	 84154	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26567	 26568	 0.000713	 0.00788	 0.00236	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26567	 26590	 0.001285	 0.009297	 0.005	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26567	 27182	 0.015466	 0.056006	 0.01202	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82028	 26567	 0.053875	 0.14477	 0.03284	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26568	 26571	 0.004095	 0.013356	 0.00355	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26568	 84155	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26568	 84155	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84155	 26569	 0.047936	 0.037936	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84155	 26570	 0.013773	 0.026377	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26571	 26572	 0.002674	 0.009171	 0.0022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26572	 26574	 0.005912	 0.017954	 0.00393	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26573	 27144	 0.23363	 0.18493	 0.00233	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26573	 84156	 0.22025	 0.14262	 0.00271	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26573	 84356	 0.33282	 0.21557	 0.0041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26574	 84156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26574	 84156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26575	 26576	 0.007841	 0.026897	 0.00644	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26576	 84157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26576	 84157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26577	 84159	 0.05134	 0.085623	 0.00125	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26578	 26581	 0.003965	 0.01048	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26579	 84158	 0.040303	 0.031895	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26579	 84160	 0.079219	 0.087134	 0.00116	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26580	 26584	 0.006752	 0.02353	 0.00546	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26580	 84158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26580	 84158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26581	 26582	 0.004795	 0.013056	 0.00288	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26582	 26590	 0.009962	 0.023126	 0.00705	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26582	 84159	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26582	 84159	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84159	 26583	 0.023605	 0.043236	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26583	 84160	 0.026835	 0.068983	 0.00107	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26583	 84162	 0.034199	 0.067711	 0.00099	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83840	 26584	 0.002829	 0.018954	 0.00581	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26584	 84160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26584	 84160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84155	 26585	 0.025145	 0.051458	 0.00127	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84156	 26585	 0.15892	 0.11693	 0.00171	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26586	 84161	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26586	 84161	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26587	 27182	 0.005446	 0.025398	 0.00629	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26588	 27143	 0.021164	 0.053208	 0.01379	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26588	 27145	 0.008447	 0.033201	 0.00869	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26589	 27144	 0.24716	 0.22155	 0.00453	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84161	 26590	 0.001648	 0.011925	 0.00642	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26590	 84162	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26590	 84162	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26591	 84166	 0.059766	 0.152	 0.0024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26592	 26595	 0.002466	 0.023678	 0.00689	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26592	 26598	 0.00281	 0.022809	 0.00726	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26593	 84163	 0.015053	 0.050214	 0.0008	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26593	 84164	 0.016709	 0.055141	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26594	 26595	 0.001063	 0.011469	 0.00328	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26594	 84163	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26594	 84163	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26595	 84164	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26595	 84164	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84164	 26596	 0.051161	 0.1013	 0.00149	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26596	 84165	 0.052909	 0.13403	 0.00265	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26596	 84457	 0.042158	 0.21328	 0.00371	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26597	 26598	 0.002349	 0.006099	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26597	 26601	 0.005958	 0.015746	 0.00369	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26597	 84165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26597	 84165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26598	 26599	 0.000663	 0.005789	 0.00159	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26599	 26600	 0.002247	 0.022261	 0.00682	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26600	 27666	 0.007561	 0.034688	 0.00889	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26600	 84166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26600	 84166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26602	 26603	 0.000295	 0.004407	 0.00148	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26602	 26674	 0.000297	 0.004443	 0.00149	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82042	 26603	 0.000268	 0.004593	 0.00132	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26604	 26606	 0.00017	 0.001888	 0.0178	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26604	 26646	 0.000597	 0.006759	 0.06154	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26604	 84167	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26604	 84167	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26605	 26660	 0.00215	 0.017163	 0.00423	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84167	 26605	 0.000963	 0.013226	 0.00477	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26605	 84168	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26605	 84168	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26606	 26631	 0.000328	 0.005726	 0.06196	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26606	 84169	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26606	 84169	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82043	 26607	 0.002907	 0.022085	 0.0005	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26607	 84170	 0.037848	 0.029667	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26608	 26609	 0.002542	 0.00639	 0.00166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26608	 84170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26608	 84170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26609	 26615	 0.001647	 0.004594	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26610	 26615	 0.001019	 0.004078	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26611	 26673	 0.008977	 0.010746	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82056	 26611	 0.002194	 0.006227	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82056	 26612	 0.004543	 0.013029	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26612	 84171	 0.005514	 0.018393	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26613	 84171	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26613	 84171	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26613	 84191	 0.00242	 0.009992	 0.00236	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26614	 26618	 0.005805	 0.014762	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82056	 26614	 0.033189	 0.021486	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84171	 26614	 0.002653	 0.015079	 0.00027	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26615	 26621	 0.002501	 0.007529	 0.00236	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26615	 84172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26615	 84172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26616	 26617	 0.001116	 0.005609	 0.00146	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26616	 26621	 0.0009	 0.003664	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82042	 26616	 0.001272	 0.020841	 0.00655	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26616	 84173	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26616	 84173	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26617	 26620	 0.000702	 0.003731	 0.00087	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26618	 26673	 0.01357	 0.012243	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26618	 84174	 0.002543	 0.008484	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26619	 26620	 0.000818	 0.003813	 0.00094	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26619	 26627	 0.000853	 0.00361	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26620	 84174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26620	 84174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26621	 26623	 0.00124	 0.004713	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26621	 26628	 0.002243	 0.007696	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26621	 84175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26621	 84175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26622	 26624	 0.026812	 0.027378	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84175	 26622	 0.016125	 0.012217	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26623	 26639	 0.00113	 0.004091	 0.00088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26624	 26625	 0.002594	 0.009077	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84173	 26624	 0.033857	 0.026794	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84175	 26624	 0.014703	 0.023586	 0.00044	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26625	 26626	 0.003545	 0.015003	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84174	 26626	 0.008443	 0.018941	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26626	 84177	 0.00473	 0.032471	 0.00059	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26627	 84176	 0.001092	 0.005092	 0.00126	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84167	 26628	 0.00525	 0.014094	 0.00319	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26629	 26666	 0.046635	 0.092335	 0.00136	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82045	 26629	 0.044363	 0.053107	 0.00088	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83829	 26629	 0.050236	 0.14409	 0.00222	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26630	 26633	 0.009785	 0.020025	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26630	 84177	 0.010441	 0.029946	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26630	 84180	 0.009697	 0.038804	 0.00082	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26631	 26672	 8.8e-05	 0.001267	 0.01162	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26631	 84176	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26632	 26633	 0.011256	 0.032285	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82045	 26632	 0.013732	 0.041331	 0.00081	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26633	 26666	 0.12518	 0.10304	 0.00209	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84177	 26633	 0.009261	 0.018336	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26634	 26646	 0.00025	 0.003153	 0.03073	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26634	 26672	 0.000358	 0.004054	 0.03691	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26634	 84178	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26634	 84178	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26635	 26669	 0.005663	 0.035868	 0.00974	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26635	 26670	 0.014207	 0.03755	 0.00879	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84178	 26635	 0.001276	 0.013253	 0.0041	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26635	 84179	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26635	 84179	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26636	 26666	 0.012367	 0.064308	 0.00139	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26636	 26667	 0.080411	 0.054016	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84179	 26636	 0.016287	 0.036944	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26637	 26638	 0.002335	 0.013273	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26637	 84180	 0.005332	 0.031565	 0.00061	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26638	 84186	 0.005374	 0.027186	 0.00047	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26639	 26640	 0.00118	 0.004172	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26640	 26641	 0.000387	 0.003915	 0.00115	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84176	 26640	 0.001706	 0.013375	 0.00611	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26640	 84180	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26640	 84180	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26641	 26642	 0.000536	 0.004564	 0.00114	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26641	 84181	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26641	 84181	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26642	 26645	 0.000494	 0.003037	 0.00088	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26643	 26644	 0.001915	 0.009198	 0.00018	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84180	 26643	 0.005915	 0.036364	 0.00066	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26644	 26651	 0.016154	 0.024746	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84168	 26644	 0.12424	 0.10227	 0.00207	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26645	 26649	 0.000934	 0.003739	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26645	 26650	 0.00086	 0.005289	 0.00153	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26645	 84182	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26645	 84182	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26646	 84183	 0.000905	 0.048849	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26646	 84183	 0.000905	 0.048849	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84181	 26647	 0.030092	 0.03166	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84183	 26647	 0.013381	 0.024509	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26648	 26653	 0.020945	 0.015141	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84182	 26648	 0.003482	 0.00895	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84183	 26648	 0.005503	 0.018359	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26649	 26650	 0.000662	 0.002734	 0.00065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26650	 26665	 0.003883	 0.025393	 0.00646	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26650	 84184	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26650	 84184	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84184	 26651	 0.00123	 0.008439	 0.00015	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26651	 84188	 0.007459	 0.039911	 0.00121	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26652	 26653	 0.011394	 0.022559	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26652	 26655	 0.068613	 0.049601	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84182	 26653	 0.008307	 0.018998	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84183	 26653	 0.008465	 0.024021	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84179	 26654	 0.049101	 0.0639	 0.00089	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84183	 26654	 0.01984	 0.031826	 0.00059	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26656	 26658	 0.000803	 0.003897	 0.00089	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26656	 84185	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26656	 84185	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26657	 26658	 0.000612	 0.003128	 0.00079	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26657	 26659	 0.001305	 0.007014	 0.00173	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84169	 26659	 0.001595	 0.013417	 0.00397	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26659	 84186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26659	 84186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26660	 26661	 0.003736	 0.009873	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26660	 84187	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26660	 84187	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26661	 26664	 0.003404	 0.008751	 0.00217	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26662	 26663	 0.01407	 0.036465	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83798	 26662	 0.013502	 0.035691	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83803	 26663	 0.086843	 0.068728	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26663	 84189	 0.021223	 0.060869	 0.00094	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26664	 84188	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26664	 84188	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26665	 26669	 0.004373	 0.014735	 0.00366	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83797	 26665	 0.007752	 0.031036	 0.00782	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26665	 84189	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26665	 84189	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84101	 26666	 0.072911	 0.21444	 0.0044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84179	 26668	 0.024987	 0.10212	 0.00207	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84189	 26668	 0.15008	 0.1516	 0.00201	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26669	 26904	 0.008268	 0.02185	 0.00511	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26670	 26671	 0.006774	 0.017587	 0.00427	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26671	 84190	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26671	 84190	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26672	 84191	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26672	 84191	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84167	 26674	 0.001115	 0.008438	 0.00414	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26675	 26745	 0.028363	 0.022446	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26675	 84192	 0.005168	 0.009465	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26676	 26677	 0.001097	 0.002945	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26676	 26766	 0.005465	 0.015239	 0.0032	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26676	 84192	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26676	 84192	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26677	 26737	 0.000937	 0.002517	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26677	 84193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26677	 84193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26678	 26680	 0.017474	 0.013697	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26679	 26688	 0.019115	 0.015127	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26679	 26745	 0.01329	 0.008604	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26680	 26690	 0.020314	 0.015923	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26680	 26744	 0.049573	 0.039232	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84193	 26680	 0.012217	 0.018529	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26680	 84201	 0.021017	 0.041613	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26681	 84194	 0.002177	 0.011013	 0.00019	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26681	 84208	 0.015187	 0.036224	 0.00081	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26681	 84211	 0.021934	 0.017359	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26682	 26683	 0.001976	 0.005131	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26682	 26685	 0.002609	 0.007005	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26682	 26707	 0.00684	 0.018078	 0.00423	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26682	 84194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26682	 84194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26683	 26693	 0.002836	 0.007909	 0.00166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26683	 84195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26683	 84195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26684	 26685	 0.001166	 0.004669	 0.00118	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26684	 84207	 0.000689	 0.003071	 0.00083	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26685	 26706	 0.002251	 0.005844	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26685	 84196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26685	 84196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26686	 26687	 0.010029	 0.007936	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26686	 26747	 0.01451	 0.014198	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26686	 26801	 0.015301	 0.015454	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26687	 26746	 0.02173	 0.021948	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26687	 84202	 0.015084	 0.032325	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26687	 84220	 0.014699	 0.024761	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26688	 26689	 0.01422	 0.011254	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26688	 84199	 0.008859	 0.01813	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26689	 26690	 0.019764	 0.015641	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26689	 26699	 0.005203	 0.013375	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26691	 84198	 0.013867	 0.010025	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26692	 26693	 0.000524	 0.001462	 0.00031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26692	 26697	 0.000796	 0.002166	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26693	 84197	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26693	 84197	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26694	 84201	 0.012814	 0.009077	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26695	 26721	 0.010227	 0.019016	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84196	 26695	 0.005924	 0.011015	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26695	 84201	 0.016011	 0.01267	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26696	 84198	 0.016087	 0.012731	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26696	 84200	 0.013694	 0.010075	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26697	 26702	 0.001708	 0.004514	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26697	 84198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26697	 84198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26698	 26703	 0.007916	 0.005997	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84198	 26698	 0.008736	 0.006914	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26699	 26700	 0.015936	 0.012612	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26699	 84202	 0.003691	 0.014413	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26700	 26708	 0.015128	 0.01113	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26700	 84199	 0.010996	 0.008702	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26701	 26702	 0.001037	 0.00274	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26701	 84199	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26701	 84199	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26702	 84200	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26702	 84200	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84198	 26703	 0.01572	 0.01244	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84200	 26703	 0.018331	 0.014368	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26703	 84230	 0.008213	 0.021711	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26704	 26705	 0.013255	 0.009752	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26704	 26710	 0.015469	 0.012242	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26705	 84201	 0.005747	 0.010527	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26706	 26722	 0.001334	 0.004496	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26706	 84201	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26706	 84201	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26707	 84202	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26707	 84202	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26707	 84214	 0.002227	 0.022902	 0.0065	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26708	 26711	 0.012672	 0.010029	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26708	 26712	 0.015377	 0.015381	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84199	 26708	 0.014338	 0.009282	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26709	 26712	 0.011255	 0.008907	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84200	 26709	 0.010563	 0.008003	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26710	 26713	 0.007434	 0.007435	 0.0001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84202	 26711	 0.007193	 0.014241	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26712	 26713	 0.007838	 0.012511	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26713	 84230	 0.001706	 0.007562	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26714	 26717	 0.017292	 0.013554	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26714	 26799	 0.008434	 0.01594	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84202	 26714	 0.017994	 0.014104	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26715	 26730	 0.018801	 0.014421	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26716	 84230	 0.016174	 0.0128	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26717	 26730	 0.025903	 0.020304	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26718	 26799	 0.01896	 0.013949	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26719	 26751	 0.004818	 0.012253	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26719	 26752	 0.005852	 0.017971	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26719	 26756	 0.010374	 0.026667	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26719	 84203	 0.005332	 0.01238	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26720	 26783	 0.010321	 0.042001	 0.01023	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26720	 27778	 0.002042	 0.007003	 0.00168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26720	 84203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26720	 84203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26721	 84226	 0.009358	 0.024802	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26722	 84204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26722	 84204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26722	 84228	 0.002634	 0.009037	 0.00216	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26723	 26726	 0.013099	 0.01323	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84204	 26723	 0.005746	 0.010859	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26723	 84227	 0.005928	 0.013558	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26724	 84205	 0.012751	 0.010091	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26725	 26726	 0.011839	 0.008969	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26725	 84205	 0.014598	 0.009451	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26727	 84205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26727	 84205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26727	 84228	 0.002244	 0.007698	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84205	 26728	 0.007906	 0.015652	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26728	 84230	 0.029207	 0.021488	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84205	 26729	 0.017763	 0.013069	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26730	 84230	 0.010285	 0.020364	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26731	 84206	 0.001717	 0.004789	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26732	 26733	 4.7e-05	 0.000537	 0.00471	 736.0	 772.8	 809.6	 0.0	 0.0	 0	 -30.0	 30.0;
	26732	 84206	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 0	 -30.0	 30.0;
	26732	 84206	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 0	 -30.0	 30.0;
	26733	 26798	 0.000331	 0.003817	 0.03346	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26733	 84207	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26733	 84207	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84207	 26734	 0.000893	 0.00463	 0.00113	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26734	 84208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26734	 84208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26735	 26736	 0.001498	 0.003958	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26735	 26739	 0.00285	 0.007758	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26735	 84209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26735	 84209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26736	 26737	 0.001347	 0.003462	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26736	 84210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26736	 84210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26737	 84211	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26737	 84211	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26738	 84212	 0.017619	 0.012963	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26739	 26741	 0.00159	 0.004128	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26739	 84212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26739	 84212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26740	 26768	 0.022923	 0.017968	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26740	 84213	 0.01377	 0.012913	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26741	 26778	 0.00614	 0.018482	 0.00578	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26741	 84213	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26741	 84213	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26742	 26743	 0.005788	 0.008866	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26742	 84220	 0.012665	 0.025076	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26743	 26744	 0.016005	 0.01157	 0.00018	 45.0	 45.0	 45.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26743	 26746	 0.018334	 0.014509	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84212	 26744	 0.008239	 0.016312	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26745	 26746	 0.013892	 0.010994	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26746	 26747	 0.01115	 0.008824	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26748	 26750	 0.008931	 0.025615	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26748	 26775	 0.10967	 0.077688	 0.00123	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84202	 26748	 0.027009	 0.021374	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26748	 84219	 0.044662	 0.030001	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26749	 26801	 0.008615	 0.015779	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84202	 26749	 0.002022	 0.007865	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26750	 26757	 0.012304	 0.02436	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26750	 26799	 0.003717	 0.013744	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84203	 26750	 0.008682	 0.028963	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26750	 84215	 0.010895	 0.048277	 0.00145	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26750	 84218	 0.029887	 0.032872	 0.00044	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26751	 26757	 0.005155	 0.013111	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26752	 26753	 0.015438	 0.012217	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26752	 84215	 0.005928	 0.026526	 0.00055	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26754	 26759	 9.4e-05	 0.001066	 0.00971	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26754	 26781	 0.000162	 0.001872	 0.01641	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26754	 84214	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26755	 26784	 0.099449	 0.070447	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26755	 27781	 0.011801	 0.033848	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84215	 26755	 0.008338	 0.019744	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26756	 84217	 0.005253	 0.013504	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26758	 84217	 0.005185	 0.014871	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26758	 84223	 0.009161	 0.019631	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26759	 27785	 0.000524	 0.005752	 0.05587	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26759	 84216	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26760	 26779	 0.000626	 0.00493	 0.00144	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84216	 26760	 0.000862	 0.007524	 0.00207	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26761	 26762	 0.000286	 0.00303	 0.0009	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26761	 26763	 0.00055	 0.003483	 0.00095	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26761	 84218	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26761	 84218	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84216	 26762	 0.000559	 0.006393	 0.00195	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26763	 26764	 0.000603	 0.003533	 0.00096	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26764	 26765	 0.000582	 0.002643	 0.00092	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26764	 84219	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26764	 84219	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26765	 26766	 0.001075	 0.004305	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26766	 84220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26766	 84220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26767	 26769	 0.023537	 0.018449	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84220	 26767	 0.010506	 0.01745	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26768	 26769	 0.017473	 0.013828	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26769	 26770	 0.025254	 0.019985	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84213	 26769	 0.014397	 0.018736	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26770	 26771	 0.017991	 0.019596	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26770	 26775	 0.023607	 0.025965	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26771	 26772	 0.009538	 0.02929	 0.00055	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26771	 26775	 0.008859	 0.022772	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26772	 26773	 0.006749	 0.013363	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26773	 26774	 0.004696	 0.015665	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26774	 26787	 0.029398	 0.035838	 0.00057	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26774	 26788	 0.006326	 0.024611	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26775	 26776	 0.006557	 0.018808	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26775	 26777	 0.01184	 0.022015	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26776	 84221	 0.008959	 0.026345	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26777	 84221	 0.004454	 0.019846	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26778	 26779	 0.000498	 0.00419	 0.00124	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26778	 84221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26778	 84221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26779	 84222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26779	 84222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26780	 26785	 0.039661	 0.031387	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84222	 26780	 0.009349	 0.0217	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26780	 84223	 0.006955	 0.029031	 0.00084	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26781	 84223	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26781	 84223	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26782	 26783	 0.001331	 0.010025	 0.00278	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26782	 26792	 0.001342	 0.015343	 0.00468	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26783	 84224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26783	 84224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84215	 26784	 0.047943	 0.073444	 0.00103	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84224	 26784	 0.013996	 0.053624	 0.00152	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26786	 26790	 0.013459	 0.060225	 0.00124	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84223	 26786	 0.010067	 0.039165	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26787	 26789	 0.089479	 0.070814	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84223	 26787	 0.018776	 0.094982	 0.00165	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84223	 26788	 0.01135	 0.069778	 0.00126	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84086	 26792	 0.001832	 0.026688	 0.00854	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26792	 84225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26792	 84225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26793	 84226	 0.17271	 0.13249	 0.00178	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26793	 84371	 0.1153	 0.090383	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26794	 26795	 0.003924	 0.01037	 0.00243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26794	 27175	 0.008103	 0.021416	 0.00501	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26795	 84226	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26795	 84226	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84226	 26796	 0.009275	 0.026603	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26796	 84227	 0.012664	 0.011876	 0.00018	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26796	 84229	 0.011853	 0.027518	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26797	 27776	 0.003497	 0.009241	 0.00216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26797	 84227	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26797	 84227	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26797	 84228	 0.001484	 0.003923	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26798	 27786	 0.000325	 0.003747	 0.03285	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26798	 84228	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26800	 27778	 0.004695	 0.016104	 0.00386	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84228	 26800	 0.003672	 0.012597	 0.00302	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26800	 84230	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26800	 84230	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26802	 26805	 0.000358	 0.004051	 0.03688	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26802	 27673	 0.000397	 0.004356	 0.04231	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26804	 84232	 0.04877	 0.074712	 0.00105	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26805	 84231	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26805	 84231	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26807	 26811	 0.040548	 0.1163	 0.00179	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26808	 26809	 0.001568	 0.008169	 0.00214	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26808	 26812	 0.02255	 0.059604	 0.01395	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84231	 26808	 0.002464	 0.019797	 0.00556	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26808	 84232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26808	 84232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26809	 26813	 0.003853	 0.03305	 0.00941	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83952	 26809	 0.008599	 0.057696	 0.01393	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84232	 26810	 0.055035	 0.043554	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26811	 84233	 0.053945	 0.13205	 0.00226	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82038	 26812	 0.006559	 0.026262	 0.00662	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26812	 84233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26812	 84233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26814	 26815	 0.000686	 0.004345	 0.00118	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26814	 26880	 0.000869	 0.005344	 0.00154	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26815	 26836	 0.00147	 0.00912	 0.00221	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26815	 27619	 0.000812	 0.00898	 0.00269	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26815	 27621	 0.002911	 0.011657	 0.00294	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26816	 84240	 0.023489	 0.018589	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26817	 84240	 0.006824	 0.019572	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26817	 84241	 0.018909	 0.037438	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26817	 84254	 0.007663	 0.014483	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26818	 26826	 0.001437	 0.005204	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26818	 26879	 0.000358	 0.00312	 0.00086	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26818	 26881	 0.002515	 0.006848	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26818	 84234	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26818	 84234	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26818	 84244	 0.004103	 0.025227	 0.00728	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26819	 26820	 0.014004	 0.011082	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26819	 26822	 0.028532	 0.022365	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26819	 26823	 0.024018	 0.018826	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26819	 84235	 0.009435	 0.011059	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26820	 26821	 0.017421	 0.013787	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26821	 84242	 0.017446	 0.015632	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26822	 84242	 0.027095	 0.019586	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26824	 26826	 0.001649	 0.004145	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26824	 84235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26824	 84235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84234	 26825	 0.006077	 0.012032	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26825	 84236	 0.004431	 0.008683	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26826	 84236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26826	 84236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26827	 26829	 0.000881	 0.002329	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26827	 84237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26827	 84237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26828	 26852	 0.002629	 0.014944	 0.00027	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84237	 26828	 0.002432	 0.010717	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26829	 26832	 0.001307	 0.003646	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26830	 26834	 0.001703	 0.004636	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26830	 26881	 0.001574	 0.004087	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26831	 26861	 0.009885	 0.056189	 0.00102	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26831	 26864	 0.005385	 0.013841	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26831	 84238	 0.002111	 0.011998	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26831	 84250	 0.015325	 0.027652	 0.0004	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26832	 84238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26832	 84238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26833	 26835	 0.003113	 0.015746	 0.00027	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84238	 26833	 0.017427	 0.029356	 0.00042	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26833	 84250	 0.004115	 0.018129	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26834	 84239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26834	 84239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84239	 26835	 0.001314	 0.005854	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26836	 26879	 0.000876	 0.006813	 0.00177	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26836	 84240	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26836	 84240	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26837	 26882	 0.00462	 0.009899	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84240	 26837	 0.005991	 0.013908	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26838	 26839	 0.017073	 0.013511	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84240	 26839	 0.007613	 0.015074	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26840	 26842	 0.007215	 0.014285	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26840	 26846	 0.046025	 0.036423	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26840	 84241	 0.02819	 0.022309	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26841	 26843	 0.000642	 0.005403	 0.0016	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26841	 26880	 0.001281	 0.009648	 0.00268	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26841	 84241	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26841	 84241	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26842	 26845	 0.004672	 0.023368	 0.00042	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84241	 26842	 0.004963	 0.012758	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26843	 84242	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26843	 84242	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26843	 84244	 0.001845	 0.015823	 0.0045	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84242	 26844	 0.005172	 0.010585	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26844	 84243	 0.010054	 0.028531	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26845	 84243	 0.003694	 0.019211	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26847	 84243	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26847	 84243	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26847	 84244	 0.001523	 0.008094	 0.00188	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26848	 26862	 0.000383	 0.006828	 0.07082	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26848	 84244	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26848	 84244	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84243	 26849	 0.035931	 0.028435	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84243	 26850	 0.048382	 0.031322	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26850	 84246	 0.02073	 0.027245	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84235	 26851	 0.005311	 0.021254	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26851	 84245	 0.009446	 0.024281	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26851	 84246	 0.002998	 0.015588	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26852	 84245	 0.003017	 0.016146	 0.00049	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26853	 84245	 0.022112	 0.036878	 0.00054	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26854	 84245	 0.026738	 0.020959	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26855	 84245	 0.009441	 0.006342	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26856	 26858	 0.001606	 0.009407	 0.00256	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26856	 84245	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26856	 84245	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26857	 26858	 0.00187	 0.007108	 0.00199	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26857	 84246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26857	 84246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26858	 26859	 0.000389	 0.005667	 0.00181	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84244	 26858	 0.003737	 0.014961	 0.00377	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26859	 26877	 0.001153	 0.012125	 0.00681	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26859	 84247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26859	 84247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26860	 26861	 0.015497	 0.035978	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26860	 26876	 0.038722	 0.11106	 0.00171	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84247	 26860	 0.009743	 0.022099	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26861	 84249	 0.005356	 0.032931	 0.00059	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26861	 84253	 0.028922	 0.096484	 0.00153	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26862	 84248	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26863	 26865	 0.000734	 0.005719	 0.00171	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26863	 26867	 0.000665	 0.004133	 0.00117	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26863	 84250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26863	 84250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26864	 26868	 0.017736	 0.017787	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26865	 27621	 0.002964	 0.018393	 0.00446	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26865	 84251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26865	 84251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26866	 27636	 0.010447	 0.032048	 0.00087	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26866	 84252	 0.005835	 0.031222	 0.00095	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26867	 26869	 0.000961	 0.008083	 0.00239	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84248	 26869	 0.000838	 0.013621	 0.00386	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26869	 84252	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26869	 84252	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84249	 26870	 0.048852	 0.11342	 0.00169	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26870	 84390	 0.070697	 0.17981	 0.00284	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26871	 26872	 0.005779	 0.021023	 0.00644	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26871	 27638	 0.004796	 0.019202	 0.00484	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26872	 27239	 0.008016	 0.030468	 0.00853	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83645	 26872	 0.008331	 0.033355	 0.0084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84248	 26872	 0.004409	 0.027923	 0.00758	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26873	 26874	 0.001918	 0.007677	 0.00193	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26873	 84465	 0.002161	 0.016432	 0.00516	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83646	 26875	 0.084796	 0.054899	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83646	 26876	 0.031337	 0.064129	 0.00158	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83641	 26877	 0.001175	 0.016139	 0.00582	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26877	 84253	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26877	 84253	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84244	 26878	 0.006212	 0.017817	 0.00438	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26879	 84254	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26879	 84254	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26882	 26883	 0.008867	 0.022794	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26882	 84556	 0.038947	 0.0349	 0.00071	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84239	 26883	 0.005077	 0.016936	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26883	 84564	 0.013366	 0.035426	 0.0009	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26884	 26888	 0.016037	 0.012692	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26885	 26893	 0.001604	 0.004646	 0.00112	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26885	 84255	 0.002615	 0.008811	 0.00219	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26886	 84256	 0.028586	 0.022622	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26887	 27308	 0.003419	 0.03955	 0.34789	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26887	 84255	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26888	 26889	 0.008459	 0.010126	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26888	 26890	 0.005543	 0.021563	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84256	 26888	 0.003228	 0.018139	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26889	 26891	 0.012942	 0.013821	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26890	 26894	 0.007171	 0.023921	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26890	 26900	 0.006249	 0.035519	 0.00064	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26891	 26892	 0.007474	 0.008221	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26892	 84257	 0.01174	 0.018318	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26893	 26895	 0.001632	 0.004195	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26893	 84257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26893	 84257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26894	 26896	 0.038649	 0.079095	 0.00195	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26895	 26898	 0.002194	 0.005889	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26896	 27138	 0.054262	 0.12467	 0.00189	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26897	 26898	 0.009684	 0.025592	 0.00599	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26897	 27666	 0.011077	 0.11892	 0.03099	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26897	 27809	 0.005846	 0.029373	 0.00764	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26899	 26901	 0.038096	 0.17295	 0.00375	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26900	 26901	 0.014498	 0.070748	 0.00122	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84256	 26900	 0.019651	 0.0351	 0.00052	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84256	 26901	 0.057355	 0.11356	 0.00167	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26902	 26907	 0.003904	 0.018607	 0.00539	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26902	 26925	 0.002248	 0.012776	 0.0037	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26903	 26905	 0.061263	 0.074685	 0.0012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83798	 26903	 0.015958	 0.07787	 0.00134	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26904	 26918	 0.007621	 0.019784	 0.0048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26905	 84258	 0.023362	 0.046254	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26906	 26912	 0.002687	 0.007492	 0.00157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26906	 26932	 0.005253	 0.014103	 0.0032	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26907	 26908	 0.004943	 0.019788	 0.00499	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26908	 26936	 0.005029	 0.01725	 0.00413	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26909	 26917	 0.003598	 0.009509	 0.00223	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26909	 26924	 0.007005	 0.019073	 0.0042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26910	 26912	 0.00186	 0.004676	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26910	 26917	 0.00307	 0.007718	 0.002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26911	 26916	 0.027949	 0.022118	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26912	 26913	 0.003512	 0.00943	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26913	 26914	 0.002583	 0.008704	 0.00216	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26913	 84258	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26913	 84258	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26914	 26919	 0.00358	 0.011678	 0.0031	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26914	 26922	 0.009155	 0.035616	 0.00951	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83808	 26914	 0.039867	 0.10541	 0.02469	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26914	 84259	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26914	 84259	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84258	 26915	 0.040299	 0.052446	 0.00073	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84259	 26915	 0.039265	 0.031074	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26915	 84261	 0.054698	 0.15523	 0.00244	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26916	 84260	 0.008649	 0.022234	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26917	 84260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26917	 84260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26918	 26922	 0.007236	 0.020177	 0.00423	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26919	 26923	 0.005806	 0.020236	 0.00469	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84190	 26920	 0.054193	 0.13783	 0.00218	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26920	 84261	 0.033791	 0.096918	 0.00149	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26921	 26922	 0.002189	 0.008319	 0.00233	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26921	 27753	 0.004204	 0.023067	 0.0061	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26922	 84261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26922	 84261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26923	 27754	 0.005983	 0.027448	 0.00703	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26923	 84262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26923	 84262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26924	 27763	 0.007989	 0.02074	 0.00503	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83797	 26925	 0.001586	 0.009352	 0.00762	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26925	 84263	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26925	 84263	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26926	 26927	 0.004199	 0.016336	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84263	 26926	 0.005705	 0.019031	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26927	 26934	 0.008587	 0.019935	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26927	 84264	 0.011304	 0.029059	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26928	 84264	 0.022977	 0.016905	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26929	 26932	 0.004553	 0.012032	 0.00282	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83797	 26929	 0.001601	 0.00834	 0.00219	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26929	 84264	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26929	 84264	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26930	 26931	 0.023043	 0.023274	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84263	 26930	 0.00632	 0.031968	 0.00056	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26935	 84265	 0.022352	 0.044255	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26935	 84267	 0.005701	 0.039133	 0.00071	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26935	 84533	 0.019017	 0.085092	 0.00175	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26936	 26937	 0.004068	 0.010921	 0.00248	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26936	 84265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26936	 84265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26937	 27758	 0.002339	 0.014148	 0.00361	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26937	 84266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26937	 84266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26938	 27764	 0.002527	 0.01233	 0.00341	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26938	 84267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26938	 84267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26939	 26943	 0.002189	 0.034069	 0.01057	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83539	 26939	 0.003413	 0.024028	 0.01366	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26940	 26942	 0.00021	 0.004121	 0.06604	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26940	 84268	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26940	 84268	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26941	 84269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26941	 84269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82000	 26942	 0.000186	 0.002952	 0.04846	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26942	 84270	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26942	 84270	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84270	 26943	 0.00114	 0.012285	 0.00657	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26943	 84271	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26943	 84271	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79641	 26944	 0.015853	 0.056634	 0.00112	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79641	 26944	 0.015853	 0.056634	 0.00112	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84271	 26944	 0.031396	 0.096319	 0.00261	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84271	 26944	 0.031396	 0.096319	 0.00261	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26945	 26946	 0.092942	 0.12096	 0.00169	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26945	 27677	 0.16755	 0.13261	 0.00167	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26945	 27682	 0.19057	 0.19116	 0.00309	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26946	 84272	 0.0208	 0.069389	 0.0011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26946	 84273	 0.16493	 0.12929	 0.00166	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26947	 26948	 0.002647	 0.01705	 0.00447	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26947	 26950	 0.0036	 0.017752	 0.0048	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26947	 84272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26947	 84272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26948	 26949	 0.002379	 0.006176	 0.0015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26948	 84273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26948	 84273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26949	 26951	 0.005957	 0.014975	 0.00388	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26949	 84274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26949	 84274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26950	 26953	 0.003028	 0.027542	 0.00695	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26950	 84275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26950	 84275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26951	 84276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26951	 84276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26952	 84277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26952	 84277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26954	 26958	 0.002047	 0.015687	 0.0042	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26954	 27361	 0.012259	 0.044392	 0.00953	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26954	 84278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26954	 84278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26955	 26957	 0.013086	 0.037534	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26955	 84279	 0.010797	 0.052685	 0.00091	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26956	 26960	 0.001421	 0.01142	 0.00321	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26956	 84279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26956	 84279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26956	 84282	 0.004226	 0.01692	 0.00426	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26957	 27366	 0.094981	 0.10447	 0.00139	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26957	 84280	 0.1009	 0.079095	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26958	 84280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26958	 84280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26958	 84282	 0.001753	 0.014936	 0.00373	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26959	 26960	 0.000965	 0.011027	 0.00336	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82050	 26961	 0.029899	 0.20289	 0.00379	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26961	 84283	 0.014374	 0.077201	 0.00183	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26962	 26963	 0.004884	 0.01879	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26962	 27123	 0.11577	 0.11694	 0.00155	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83812	 26962	 0.042303	 0.16276	 0.00278	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26963	 84343	 0.038571	 0.099154	 0.00153	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26964	 84281	 0.014686	 0.036452	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26964	 84348	 0.039733	 0.090871	 0.00222	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26965	 26966	 0.002491	 0.006403	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26965	 26972	 0.006408	 0.015443	 0.00436	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26965	 27114	 0.003839	 0.019902	 0.00486	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26965	 84281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26965	 84281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26966	 26973	 0.005843	 0.014687	 0.00381	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26967	 84282	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84283	 26968	 0.03829	 0.06909	 0.001	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26969	 26970	 0.013098	 0.023989	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26970	 84285	 0.013405	 0.034458	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26970	 84345	 0.042477	 0.13045	 0.00245	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26971	 26972	 0.003136	 0.008419	 0.00191	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26971	 84284	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26971	 84284	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84282	 26972	 0.00677	 0.017893	 0.00419	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26972	 84285	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26972	 84285	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26973	 27104	 0.004369	 0.015443	 0.00348	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26973	 84286	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26973	 84286	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84286	 26974	 0.24714	 0.19376	 0.00249	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26975	 26976	 0.11075	 0.21931	 0.00322	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81795	 26975	 0.17573	 0.17579	 0.00238	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81841	 26975	 0.28296	 0.2859	 0.00379	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81849	 26975	 0.041219	 0.079864	 0.00172	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82036	 26975	 0.071377	 0.21923	 0.00411	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26976	 26977	 0.014638	 0.065229	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26977	 26978	 0.023092	 0.10117	 0.00218	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26978	 84604	 0.032908	 0.18708	 0.00339	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26979	 26988	 0.000198	 0.002198	 0.02093	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26979	 27086	 5.9e-05	 0.000642	 0.00624	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26979	 84287	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26980	 26981	 0.011846	 0.011849	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84288	 26980	 0.011465	 0.015068	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26980	 84331	 0.008813	 0.01745	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26981	 84289	 0.005268	 0.010429	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26981	 84290	 0.008257	 0.016347	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26982	 26983	 0.000384	 0.003297	 0.00094	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26982	 27014	 0.000422	 0.003427	 0.00109	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26982	 84289	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26982	 84289	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26983	 27090	 0.000751	 0.006032	 0.0017	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26983	 84290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26983	 84290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26984	 26985	 0.012407	 0.009819	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26985	 84293	 0.016972	 0.013431	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84290	 26986	 0.015153	 0.011992	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26987	 26990	 0.003357	 0.01306	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26987	 27130	 0.011423	 0.021589	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26987	 84292	 0.003027	 0.010096	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26988	 26989	 4e-05	 0.000457	 0.00416	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26988	 84291	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26989	 27129	 4.6e-05	 0.000527	 0.00479	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26989	 84293	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26989	 84293	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26990	 26993	 0.003356	 0.008894	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26991	 26994	 0.000273	 0.003072	 0.00089	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84291	 26991	 0.000114	 0.001842	 0.0006	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26992	 26994	 0.000364	 0.005305	 0.0017	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26992	 84294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26992	 84294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26992	 84302	 0.000428	 0.006229	 0.00199	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26993	 27092	 0.00346	 0.010614	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26993	 84295	 0.035028	 0.027457	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26993	 84334	 0.003235	 0.014415	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26994	 26995	 0.000302	 0.003321	 0.00197	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26994	 84295	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26994	 84295	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26995	 27093	 0.002996	 0.008677	 0.00209	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26995	 27094	 0.001326	 0.007765	 0.00212	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26995	 27097	 0.002508	 0.008604	 0.00206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83977	 26995	 0.004035	 0.023636	 0.00644	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26996	 27013	 0.000104	 0.001748	 0.01808	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26996	 84296	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26997	 27097	 0.000368	 0.00432	 0.00115	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84296	 26997	 0.000276	 0.004346	 0.00148	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26998	 27009	 0.003266	 0.010893	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84294	 26998	 0.01834	 0.024104	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84297	 26998	 0.004766	 0.01367	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26999	 27000	 0.002732	 0.007753	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84297	 26999	 0.00344	 0.013235	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27000	 27001	 0.004666	 0.011995	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27001	 27002	 0.007672	 0.019721	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27001	 84338	 0.003207	 0.012476	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27002	 27003	 0.006664	 0.013194	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27002	 84300	 0.003711	 0.021094	 0.00038	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27003	 27101	 0.015382	 0.016919	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27004	 27101	 0.003731	 0.010586	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27004	 84308	 0.005802	 0.016071	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27005	 84298	 0.002816	 0.011271	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27005	 84307	 0.004215	 0.011142	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27006	 27009	 0.00307	 0.009419	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27006	 84298	 0.00221	 0.009736	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27007	 27008	 0.000918	 0.002426	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27007	 27033	 0.001106	 0.004004	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27007	 84298	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27007	 84298	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27008	 84299	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27008	 84299	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27009	 84300	 0.00609	 0.01151	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27010	 84300	 0.006193	 0.012262	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27010	 84301	 0.0025	 0.006426	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27011	 27012	 0.000875	 0.004396	 0.00114	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27011	 27022	 0.000539	 0.004328	 0.00122	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84296	 27011	 0.000945	 0.007348	 0.00191	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27011	 84300	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27011	 84300	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27012	 84301	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27012	 84301	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27012	 84302	 0.00034	 0.003757	 0.00113	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27013	 27129	 6.6e-05	 0.000721	 0.00708	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27013	 84302	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27013	 84302	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27014	 27015	 0.000341	 0.002739	 0.00077	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27014	 84351	 0.002651	 0.007005	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27015	 27017	 0.000287	 0.003335	 0.00098	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27015	 84351	 0.001437	 0.005754	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82047	 27016	 0.009447	 0.021933	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27016	 84303	 0.005159	 0.011978	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27017	 27018	 0.000577	 0.004062	 0.00231	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27017	 84303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27017	 84303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27018	 27047	 0.000613	 0.005426	 0.00298	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82046	 27018	 0.001652	 0.006493	 0.0017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27018	 84304	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27018	 84304	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27019	 27020	 0.002989	 0.0115	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84289	 27019	 0.012035	 0.034518	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27019	 84330	 0.014444	 0.010943	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27020	 27077	 0.006569	 0.01884	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84303	 27020	 0.009285	 0.010883	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27021	 27022	 0.000297	 0.00199	 0.00061	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27021	 27023	 0.000371	 0.002372	 0.0008	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27022	 84305	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27022	 84305	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82046	 27023	 0.000692	 0.005115	 0.00148	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27024	 27025	 0.001674	 0.004669	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27024	 27046	 0.001694	 0.004612	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27025	 27026	 0.000383	 0.004452	 0.00131	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27025	 27032	 0.000479	 0.005365	 0.00171	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27026	 27065	 0.000725	 0.005371	 0.00275	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27027	 27028	 0.000219	 0.002283	 0.00063	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27027	 27029	 0.000264	 0.002713	 0.00086	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27028	 27040	 0.000419	 0.003809	 0.00096	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27029	 27051	 0.000286	 0.002966	 0.00092	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27030	 27031	 0.013058	 0.010334	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27030	 84310	 0.012826	 0.013097	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27031	 84306	 0.008569	 0.011261	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27032	 27033	 0.000204	 0.001947	 0.00064	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27032	 84306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27032	 84306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27033	 27035	 0.000605	 0.003255	 0.00089	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27034	 27035	 0.000279	 0.003012	 0.00086	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27034	 27036	 0.000286	 0.003489	 0.00115	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27034	 84307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27034	 84307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27035	 27039	 0.000844	 0.003378	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27036	 27100	 0.000832	 0.008924	 0.00232	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27036	 84308	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27036	 84308	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27037	 27038	 0.002343	 0.008203	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84308	 27037	 0.004624	 0.014186	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27037	 84309	 0.004456	 0.015918	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27038	 84311	 0.002785	 0.013591	 0.00023	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27039	 27040	 0.000274	 0.002063	 0.00057	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27039	 84309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27039	 84309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27040	 84310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27040	 84310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27041	 84311	 0.001116	 0.00628	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27041	 84312	 0.001615	 0.009086	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27042	 27043	 0.000321	 0.003953	 0.00128	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27042	 84311	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27042	 84311	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27043	 27044	 0.000212	 0.003238	 0.00104	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27043	 84312	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27043	 84312	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27044	 84313	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27044	 84313	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27044	 84316	 0.000239	 0.003726	 0.00116	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84313	 27045	 0.013047	 0.010008	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82046	 27046	 0.001549	 0.006086	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27046	 84322	 0.002206	 0.014211	 0.00373	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27047	 27066	 0.000372	 0.003687	 0.00113	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27047	 84322	 0.001329	 0.008692	 0.00221	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27048	 27049	 0.006826	 0.017691	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27048	 84314	 0.011435	 0.014882	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27048	 84315	 0.00495	 0.015184	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27049	 84321	 0.005567	 0.017097	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27050	 27051	 0.000599	 0.003529	 0.00287	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27050	 27058	 0.000354	 0.003206	 0.00168	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27050	 84314	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27050	 84314	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27051	 84315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27051	 84315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84313	 27052	 0.009191	 0.015267	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27053	 27054	 9.7e-05	 0.001099	 0.00993	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27053	 27055	 7.6e-05	 0.001272	 0.01183	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27053	 84316	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27053	 84316	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27054	 84317	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27054	 84317	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27055	 27057	 9.9e-05	 0.001082	 0.01051	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27055	 84318	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27055	 84318	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27056	 27695	 0.002115	 0.011269	 0.00316	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27056	 84319	 0.001002	 0.004743	 0.00114	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27057	 27694	 0.000271	 0.00491	 0.04908	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27057	 84319	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27057	 84319	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27058	 27059	 0.001495	 0.006329	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27058	 27063	 0.001126	 0.008145	 0.00438	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27058	 84320	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27058	 84320	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84317	 27059	 0.000567	 0.00477	 0.00141	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84319	 27059	 0.001664	 0.008666	 0.00227	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27060	 27061	 0.002093	 0.006826	 0.00181	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27060	 27063	 0.002023	 0.006818	 0.00169	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27062	 27065	 0.000284	 0.003185	 0.00101	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27062	 84323	 0.000326	 0.002294	 0.0013	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27063	 27073	 0.000317	 0.004612	 0.00148	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27064	 84321	 0.006173	 0.016361	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27064	 84324	 0.005602	 0.02155	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27065	 84321	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27065	 84321	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27066	 27076	 0.001573	 0.011382	 0.00612	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82048	 27066	 0.001361	 0.014672	 0.00784	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27066	 84322	 0.000468	 0.004955	 0.00147	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27067	 27068	 7.3e-05	 0.000843	 0.00739	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27067	 27069	 7e-05	 0.000768	 0.00754	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27067	 27072	 8e-05	 0.001483	 0.01424	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27067	 84322	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27067	 84322	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27068	 27069	 6.8e-05	 0.000757	 0.00714	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27068	 27072	 6e-05	 0.001058	 0.01132	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27068	 84323	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27069	 84325	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27069	 84325	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27070	 27074	 0.000617	 0.006441	 0.00177	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84325	 27070	 0.000272	 0.0041	 0.00122	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27070	 84327	 0.001897	 0.006869	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27070	 84349	 0.002813	 0.018874	 0.00456	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27071	 27072	 8.8e-05	 0.000926	 0.01385	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27071	 27687	 0.000116	 0.002056	 0.02154	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27071	 27689	 0.000181	 0.001987	 0.0193	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27071	 84326	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27071	 84326	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27072	 84327	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27072	 84327	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84326	 27073	 0.000438	 0.004608	 0.00259	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84327	 27073	 0.000848	 0.006352	 0.00155	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82048	 27074	 0.000804	 0.006892	 0.00196	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27074	 84328	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27074	 84328	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27075	 27125	 0.002698	 0.030858	 0.00864	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27075	 84349	 0.001993	 0.014418	 0.00776	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27076	 27080	 0.000754	 0.005335	 0.00146	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27076	 84329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27076	 84329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84304	 27077	 0.010563	 0.027153	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84329	 27077	 0.014144	 0.025521	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27078	 27084	 0.044807	 0.03546	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27079	 27118	 0.008508	 0.024403	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27079	 84333	 0.00463	 0.022224	 0.00066	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27080	 27081	 0.000661	 0.004979	 0.00138	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27081	 27082	 0.000744	 0.005941	 0.00146	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27081	 84330	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27081	 84330	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84287	 27082	 0.001637	 0.006553	 0.00165	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27082	 84331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27082	 84331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84331	 27083	 0.047031	 0.030448	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84331	 27084	 0.018367	 0.047214	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84288	 27085	 0.030229	 0.01957	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27086	 84332	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27086	 84332	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27087	 27089	 0.001582	 0.004108	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27087	 27091	 0.001051	 0.009173	 0.00252	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84332	 27087	 0.000298	 0.003884	 0.00112	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27087	 84333	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27087	 84333	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27088	 27119	 0.03958	 0.031323	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84333	 27088	 0.006993	 0.020056	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27088	 84335	 0.009805	 0.024936	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27089	 27090	 0.001044	 0.003078	 0.00072	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27090	 84334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27090	 84334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27091	 27093	 0.001854	 0.007422	 0.00187	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27091	 84335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27091	 84335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27092	 84336	 0.008123	 0.018577	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27093	 27113	 0.00313	 0.010736	 0.00257	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27093	 84336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27093	 84336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27094	 27096	 0.001066	 0.005445	 0.00137	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83978	 27095	 0.050725	 0.049632	 0.0007	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27095	 84337	 0.008028	 0.019011	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27095	 84342	 0.018898	 0.026787	 0.00055	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27096	 27109	 0.001545	 0.005299	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27096	 84337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27096	 84337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27098	 27100	 0.000359	 0.003806	 0.00113	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27098	 27102	 0.000256	 0.002016	 0.00059	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27098	 84338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27098	 84338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84338	 27099	 0.004103	 0.011643	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27099	 84340	 0.003253	 0.006657	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27100	 84339	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27100	 84339	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84339	 27101	 0.004906	 0.012612	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83977	 27102	 0.00264	 0.017713	 0.00428	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27102	 84340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27102	 84340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27103	 27106	 0.018946	 0.018612	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84336	 27103	 0.009972	 0.044437	 0.00075	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27104	 27110	 0.003751	 0.009739	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27104	 84341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27104	 84341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84341	 27105	 0.0135	 0.013635	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27106	 84342	 0.01081	 0.014207	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27107	 27108	 0.001355	 0.004907	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27107	 84342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27107	 84342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27108	 27109	 0.001105	 0.003605	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83977	 27110	 0.004055	 0.013664	 0.0034	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27111	 27115	 0.002581	 0.010334	 0.0026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27111	 27122	 0.002747	 0.0126	 0.00323	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27111	 84343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27111	 84343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27112	 27116	 0.040558	 0.031792	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27112	 84344	 0.023824	 0.039732	 0.00058	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27113	 27115	 0.003393	 0.011318	 0.00287	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27113	 84344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27113	 84344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27114	 27115	 0.001401	 0.0061	 0.00174	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83977	 27114	 0.013524	 0.036823	 0.00811	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27114	 84345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27114	 84345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27115	 84346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27115	 84346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84343	 27116	 0.015218	 0.031143	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84346	 27116	 0.014286	 0.021667	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27117	 27121	 0.000443	 0.004962	 0.00158	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27117	 27125	 0.003125	 0.027267	 0.00749	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27117	 84347	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27117	 84347	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27118	 84348	 0.020096	 0.033852	 0.00048	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84347	 27120	 0.04098	 0.053859	 0.00074	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27121	 27122	 0.000464	 0.004599	 0.00141	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27122	 84348	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27122	 84348	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27123	 27124	 0.026735	 0.048053	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84329	 27124	 0.24397	 0.18488	 0.00255	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84347	 27124	 0.021311	 0.071093	 0.00113	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27124	 84403	 0.012474	 0.097222	 0.00182	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27126	 84350	 0.041369	 0.096045	 0.00143	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83585	 27127	 0.05239	 0.066676	 0.00098	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27127	 84350	 0.063815	 0.061659	 0.0009	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27128	 27246	 0.000371	 0.006858	 0.06589	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27128	 27687	 0.000275	 0.003014	 0.02928	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27128	 84349	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27129	 84351	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84292	 27130	 0.004052	 0.011621	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84294	 27130	 0.00601	 0.011779	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84340	 27131	 0.01809	 0.013077	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82012	 27132	 0.000361	 0.004166	 0.03652	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27132	 84353	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27132	 84353	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27133	 27134	 0.011438	 0.03023	 0.00708	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27133	 27156	 0.007379	 0.073231	 0.01992	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27133	 27185	 0.02132	 0.055356	 0.01344	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84353	 27133	 0.004552	 0.026438	 0.00623	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27134	 27185	 0.011109	 0.028841	 0.007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82022	 27135	 0.038315	 0.1099	 0.00169	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27136	 27137	 0.009037	 0.024605	 0.00542	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27136	 84354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27136	 84354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27137	 27140	 0.005716	 0.03078	 0.00846	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27137	 27288	 0.009553	 0.034591	 0.00742	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27138	 27139	 0.047519	 0.10779	 0.00215	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83819	 27138	 0.15168	 0.39009	 0.00604	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84354	 27138	 0.055919	 0.14375	 0.00222	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27140	 27141	 0.005002	 0.028738	 0.00814	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27141	 84355	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27141	 84355	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27142	 27148	 0.000553	 0.006264	 0.05703	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27142	 27160	 0.000406	 0.004193	 0.06588	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27142	 27160	 0.000406	 0.004193	 0.06588	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82028	 27143	 0.015282	 0.039287	 0.00973	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27143	 84356	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27143	 84356	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84356	 27144	 0.072432	 0.094264	 0.00132	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27145	 27156	 0.005947	 0.026055	 0.00896	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27146	 27155	 0.004386	 0.012932	 0.00301	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27146	 84357	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27146	 84357	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27146	 84358	 0.006371	 0.016837	 0.00394	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27147	 84359	 0.019499	 0.038606	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27148	 27150	 0.000179	 0.00207	 0.01815	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27148	 84358	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84356	 27149	 0.054721	 0.1495	 0.00254	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84359	 27149	 0.015581	 0.036173	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27149	 84361	 0.003014	 0.010553	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27150	 27183	 0.001083	 0.012266	 0.1117	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27150	 84360	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27151	 27159	 0.004287	 0.014302	 0.00363	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84360	 27151	 0.002357	 0.008084	 0.00194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27152	 27153	 0.00177	 0.006073	 0.00145	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27152	 27157	 0.01062	 0.0273	 0.00676	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27152	 27159	 0.005495	 0.014242	 0.00431	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84360	 27153	 0.002271	 0.00779	 0.00187	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27153	 84362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27153	 84362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27154	 27155	 0.002237	 0.005808	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27154	 84363	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27154	 84363	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27155	 27156	 0.00262	 0.008987	 0.00215	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27156	 27157	 0.007228	 0.019102	 0.00447	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27157	 27184	 0.006532	 0.026151	 0.00659	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27158	 27159	 0.003617	 0.032849	 0.0107	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84353	 27158	 0.004472	 0.048996	 0.01359	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83984	 27160	 0.000181	 0.004251	 0.0806	 1940.0	 2037.0	 2134.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27161	 84365	 0.009048	 0.035564	 0.0093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27162	 84364	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27162	 84364	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27162	 84364	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84365	 27162	 0.000178	 0.014266	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 0	 -30.0	 30.0;
	84365	 27162	 0.000178	 0.014266	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 0	 -30.0	 30.0;
	27163	 84605	 0.21822	 0.17272	 0.00217	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27164	 27166	 0.018503	 0.081525	 0.00142	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82002	 27164	 0.048858	 0.21774	 0.0037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27165	 27166	 0.008532	 0.026174	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27165	 84367	 0.010729	 0.038328	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27165	 84368	 0.026303	 0.075442	 0.00116	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27167	 27176	 0.000368	 0.004754	 0.07978	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27167	 84366	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84367	 27168	 0.081485	 0.064487	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27169	 27170	 0.001141	 0.007079	 0.00171	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84366	 27169	 0.001588	 0.016251	 0.00966	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27169	 84368	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27169	 84368	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27169	 84372	 0.001163	 0.013661	 0.00362	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27170	 84372	 0.001072	 0.006593	 0.0019	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27171	 27172	 0.035933	 0.028437	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82002	 27172	 0.039552	 0.07109	 0.00128	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27173	 27174	 0.000342	 0.003749	 0.03641	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27174	 84369	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84369	 27175	 0.006952	 0.018928	 0.00417	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27175	 84371	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27175	 84371	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27176	 84372	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27176	 84372	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27177	 84375	 0.027787	 0.1081	 0.0018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27178	 27180	 0.0117	 0.030076	 0.00745	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27178	 84373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27178	 84373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27179	 84374	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27179	 84374	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84374	 27180	 0.002864	 0.020716	 0.01115	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27180	 84375	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27180	 84375	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84375	 27181	 0.1464	 0.16104	 0.00215	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27182	 84376	 0.002603	 0.015348	 0.0125	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27183	 27186	 0.000401	 0.004379	 0.04299	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27183	 84376	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27183	 84376	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27184	 84377	 0.005118	 0.027558	 0.00757	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83536	 27185	 0.002593	 0.026529	 0.01577	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27185	 84377	 0.001643	 0.018079	 0.01074	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27186	 84377	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27186	 84377	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84094	 27187	 0.003647	 0.026387	 0.0142	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84377	 27187	 0.002161	 0.016011	 0.0082	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27188	 27191	 0.000153	 0.001734	 0.01579	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27188	 84378	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27189	 27190	 0.010056	 0.018145	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84379	 27189	 0.004103	 0.010547	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27191	 27192	 0.00022	 0.002442	 0.02325	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27191	 27198	 0.000532	 0.006349	 0.05782	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27191	 84380	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27191	 84380	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27192	 27200	 0.000359	 0.004011	 0.03748	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27192	 84381	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27192	 84381	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84381	 27193	 0.002567	 0.031188	 0.0084	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84380	 27194	 0.002502	 0.02155	 0.01251	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27195	 27196	 0.000146	 0.002282	 0.02405	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27195	 84382	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27195	 84382	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82038	 27197	 0.002617	 0.024628	 0.00746	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84380	 27197	 0.007416	 0.042611	 0.01207	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27198	 27199	 0.000221	 0.003504	 0.05753	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27199	 27292	 0.000442	 0.005455	 0.08647	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27199	 84383	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27199	 84383	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27200	 27291	 0.00025	 0.003	 0.05036	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27200	 84384	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27200	 84384	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27201	 27303	 0.000719	 0.009267	 0.17987	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27201	 27324	 0.000224	 0.004151	 0.07443	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27201	 84385	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27201	 84385	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27202	 27204	 0.001992	 0.018121	 0.00457	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84385	 27202	 0.001866	 0.021329	 0.00651	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27203	 84386	 0.01472	 0.065592	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27203	 84441	 0.056974	 0.25392	 0.00431	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27204	 27306	 0.00321	 0.026634	 0.00701	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27204	 84386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27204	 84386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27205	 27206	 0.003081	 0.029581	 0.00861	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27205	 27307	 0.001827	 0.015583	 0.01338	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83499	 27205	 0.007234	 0.052526	 0.01815	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27206	 27325	 0.003587	 0.031333	 0.01241	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27207	 27208	 0.028259	 0.080192	 0.00126	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27207	 27209	 0.029646	 0.0678	 0.00166	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27207	 84388	 0.041431	 0.11883	 0.00183	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27208	 27608	 0.012704	 0.060982	 0.00182	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83969	 27208	 0.06948	 0.17247	 0.00287	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27209	 27215	 0.017716	 0.078057	 0.00136	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27210	 27211	 0.002527	 0.009933	 0.0026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27211	 27214	 0.001385	 0.010797	 0.00323	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27211	 84537	 0.007761	 0.030502	 0.00798	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27212	 27214	 0.002973	 0.010017	 0.00249	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27212	 27532	 0.004195	 0.016321	 0.00436	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27212	 84387	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27212	 84387	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27213	 27214	 0.000911	 0.010607	 0.00312	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27213	 27227	 0.001577	 0.013778	 0.00546	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27215	 27216	 0.030113	 0.068868	 0.00168	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27215	 84393	 0.010941	 0.0751	 0.00137	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27216	 84388	 0.017443	 0.061071	 0.00169	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27216	 84389	 0.022385	 0.074674	 0.00118	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27217	 27219	 0.007565	 0.017561	 0.00535	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27217	 84388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27217	 84388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27218	 27220	 0.002016	 0.01935	 0.00563	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27218	 27222	 0.001314	 0.016536	 0.00512	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27218	 84389	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27218	 84389	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27219	 27639	 0.005523	 0.018013	 0.00478	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27219	 84390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27219	 84390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27220	 27221	 0.001985	 0.018685	 0.00566	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27221	 27239	 0.005018	 0.020089	 0.00506	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27221	 84391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27221	 84391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27222	 27223	 0.000501	 0.004713	 0.00143	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27222	 84392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27222	 84392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27223	 27224	 0.001559	 0.006242	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27223	 27226	 0.000598	 0.005846	 0.00164	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27223	 84393	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27223	 84393	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27224	 27237	 0.004268	 0.018062	 0.00406	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27225	 27236	 0.007834	 0.024033	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84392	 27225	 0.005675	 0.021834	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27226	 27233	 0.00068	 0.006529	 0.0019	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27227	 27233	 0.000536	 0.004646	 0.00167	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27227	 84394	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27227	 84394	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27227	 84397	 0.000732	 0.010568	 0.00336	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27228	 27541	 0.003392	 0.00872	 0.00216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27228	 84395	 0.002694	 0.00712	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27229	 27234	 0.000126	 0.001427	 0.01299	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27229	 27235	 0.000255	 0.002844	 0.02682	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27229	 27488	 0.000673	 0.007653	 0.06912	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27229	 27570	 0.000449	 0.007956	 0.08335	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27229	 84395	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27230	 27231	 0.002125	 0.010812	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84396	 27230	 0.00301	 0.012563	 0.00036	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27230	 84398	 0.013433	 0.028232	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27231	 27232	 0.012258	 0.012294	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84394	 27231	 0.002835	 0.012632	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27234	 27241	 0.000388	 0.004395	 0.04002	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27234	 84397	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27235	 27241	 0.000254	 0.002893	 0.02612	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27235	 27464	 0.000334	 0.003665	 0.0356	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27235	 84399	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84400	 27236	 0.016393	 0.080034	 0.00168	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27237	 27240	 0.004266	 0.017612	 0.00417	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27238	 27240	 0.00543	 0.02174	 0.00548	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27238	 27391	 0.005414	 0.020579	 0.00576	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27241	 27407	 0.000861	 0.010701	 0.10752	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27241	 84401	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27242	 27243	 0.028307	 0.075029	 0.0019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82710	 27242	 0.023156	 0.090083	 0.0015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27243	 84407	 0.13516	 0.11125	 0.00225	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27244	 84403	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27244	 84403	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27244	 84404	 0.00735	 0.025981	 0.00585	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27245	 27246	 0.00036	 0.003955	 0.03842	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27245	 27252	 0.000571	 0.007819	 0.07969	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27245	 84404	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27245	 84404	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27246	 84405	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27247	 27248	 0.090784	 0.058775	 0.00112	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27247	 84407	 0.018375	 0.032315	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27248	 27251	 0.022468	 0.064441	 0.00099	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84406	 27248	 0.039358	 0.080883	 0.00154	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27248	 84407	 0.021825	 0.043213	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84404	 27249	 0.009093	 0.024033	 0.00563	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27249	 84407	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27249	 84407	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27249	 84408	 0.011376	 0.039025	 0.00935	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27250	 27251	 0.10443	 0.082649	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27251	 84409	 0.027152	 0.063028	 0.0012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27252	 84408	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84405	 27253	 0.009777	 0.025841	 0.00605	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27254	 27256	 0.00828	 0.029266	 0.00659	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27255	 27260	 0.064311	 0.18447	 0.00284	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84088	 27255	 0.2885	 0.21865	 0.00301	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83504	 27256	 0.007973	 0.068392	 0.01947	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27256	 84410	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27256	 84410	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27258	 27259	 0.021534	 0.075398	 0.00209	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84410	 27258	 0.052882	 0.10471	 0.00154	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27259	 27260	 0.040921	 0.11737	 0.00181	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83505	 27259	 0.06535	 0.18546	 0.00291	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27260	 84578	 0.016422	 0.11273	 0.00206	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27261	 27262	 0.001258	 0.003324	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27261	 27267	 0.002432	 0.006529	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27261	 84411	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27261	 84411	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27262	 27270	 0.001404	 0.003916	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27262	 84412	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27262	 84412	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27263	 27264	 0.00567	 0.011112	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84412	 27263	 0.021003	 0.016463	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27263	 84414	 0.014832	 0.014981	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27263	 84415	 0.031603	 0.024772	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27264	 27273	 0.003332	 0.016663	 0.0003	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27264	 84415	 0.024778	 0.031135	 0.00047	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27264	 84425	 0.007088	 0.020112	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27265	 27275	 0.003096	 0.008039	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27265	 27290	 0.001742	 0.004743	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27266	 84413	 0.039777	 0.031479	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27266	 84425	 0.019665	 0.031546	 0.00058	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27267	 27275	 0.006659	 0.017287	 0.0042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27267	 84413	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27267	 84413	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27267	 84418	 0.008	 0.022309	 0.00468	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27268	 27278	 0.013673	 0.027072	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84411	 27268	 0.010105	 0.015767	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27269	 27278	 0.013095	 0.025927	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27269	 84414	 0.015072	 0.021005	 0.00036	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27270	 27271	 0.001681	 0.004442	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27270	 84414	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27270	 84414	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27271	 27282	 0.004212	 0.011132	 0.00261	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27271	 84415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27271	 84415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27272	 27273	 0.011998	 0.017563	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27273	 84416	 0.032387	 0.032395	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83522	 27274	 0.021272	 0.056226	 0.01316	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27274	 84416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27274	 84416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27275	 27276	 0.00421	 0.014184	 0.00353	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27276	 84417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27276	 84417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27277	 27289	 0.000364	 0.004227	 0.03654	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27277	 84418	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27278	 27279	 0.008129	 0.031624	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27278	 27280	 0.023921	 0.06861	 0.00106	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84419	 27279	 0.048761	 0.096544	 0.00142	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27279	 84423	 0.01969	 0.099605	 0.00173	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84118	 27280	 0.043191	 0.15124	 0.00419	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27281	 27282	 0.003185	 0.009955	 0.00288	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27281	 84420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27281	 84420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27282	 84421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27282	 84421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83666	 27283	 0.014131	 0.062969	 0.00107	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27284	 27286	 0.075382	 0.068013	 0.00114	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84416	 27285	 0.011141	 0.056015	 0.00152	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83522	 27287	 0.016516	 0.043653	 0.01022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27287	 84422	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27287	 84422	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27288	 27290	 0.007366	 0.045775	 0.01292	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27288	 84423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27288	 84423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27289	 84424	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27289	 84424	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27290	 84425	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27290	 84425	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27291	 27304	 0.000227	 0.003051	 0.05451	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27291	 84426	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27291	 84426	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27292	 27296	 0.000419	 0.004573	 0.0449	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27292	 27301	 0.000288	 0.003258	 0.02966	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27293	 27298	 0.000576	 0.005926	 0.00168	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27293	 84427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27293	 84427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27293	 84433	 0.001402	 0.005329	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84383	 27294	 0.002385	 0.025281	 0.0075	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27294	 84429	 0.002138	 0.025972	 0.007	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27295	 27307	 0.012467	 0.038771	 0.00809	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84089	 27295	 0.015432	 0.043035	 0.00903	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27295	 84428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27295	 84428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27296	 84429	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27297	 27298	 0.001876	 0.009425	 0.00245	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27297	 27306	 0.00327	 0.022684	 0.00647	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27297	 84431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27297	 84431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84429	 27298	 0.007001	 0.027516	 0.0072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27298	 84432	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27298	 84432	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27299	 27300	 0.005484	 0.010197	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82059	 27299	 0.009867	 0.025363	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84432	 27299	 0.015784	 0.02848	 0.00041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84431	 27300	 0.015835	 0.045418	 0.0007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27301	 27303	 0.000247	 0.002853	 0.02501	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27301	 84433	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27301	 84433	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82059	 27302	 0.02855	 0.020639	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27303	 27304	 0.000189	 0.002734	 0.04199	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27303	 84434	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27303	 84434	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84386	 27305	 0.10566	 0.15468	 0.00239	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84429	 27307	 0.00271	 0.032179	 0.01121	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27308	 84435	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27309	 27310	 0.005124	 0.033508	 0.00852	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27309	 27316	 0.00301	 0.015121	 0.00394	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82023	 27310	 0.003645	 0.026932	 0.00777	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27310	 84437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27310	 84437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27311	 27312	 0.033935	 0.10422	 0.00196	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27311	 84632	 0.01984	 0.095238	 0.00285	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27312	 84438	 0.05451	 0.12524	 0.0019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27312	 84452	 0.07669	 0.11632	 0.00167	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27313	 27315	 0.045632	 0.036113	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27314	 27315	 0.019139	 0.015002	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27315	 84438	 0.003804	 0.013932	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27315	 84439	 0.005225	 0.025498	 0.00044	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27316	 84438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27316	 84438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27317	 27345	 0.010176	 0.051787	 0.01878	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27317	 27349	 0.038047	 0.098817	 0.024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84435	 27317	 0.004375	 0.018517	 0.00417	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27317	 84439	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27317	 84439	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27318	 27319	 0.016605	 0.055392	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84436	 27318	 0.053615	 0.090321	 0.00129	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84439	 27318	 0.004523	 0.020973	 0.00044	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27319	 27344	 0.030082	 0.071752	 0.00161	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84435	 27320	 0.002651	 0.02411	 0.00609	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27320	 84440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27320	 84440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27321	 27322	 0.029684	 0.085138	 0.00131	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84440	 27321	 0.01814	 0.070571	 0.00118	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84104	 27322	 0.010418	 0.029564	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27323	 27327	 0.016715	 0.10159	 0.00187	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27323	 84441	 0.016588	 0.094297	 0.00171	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27324	 27333	 0.000283	 0.004464	 0.09691	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27324	 84441	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27324	 84441	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27325	 27326	 0.005579	 0.026593	 0.0077	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27325	 84442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27325	 84442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27326	 27341	 0.00274	 0.021588	 0.00631	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27326	 84443	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27326	 84443	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27327	 84448	 0.008282	 0.044478	 0.00106	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27328	 84446	 0.034942	 0.13444	 0.0023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27328	 84446	 0.034942	 0.13444	 0.0023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27329	 84446	 0.010172	 0.048825	 0.00146	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27331	 84444	 0.000126	 0.01005	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27331	 84444	 0.000126	 0.01005	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84445	 27332	 0.001385	 0.012598	 0.00318	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27332	 84447	 0.001608	 0.011671	 0.00403	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27333	 27337	 0.00019	 0.002593	 0.02643	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84444	 27333	 0.000208	 0.002863	 0.04846	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27333	 84447	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27334	 27335	 0.019129	 0.025141	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27334	 27336	 0.020637	 0.027123	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84446	 27334	 0.036634	 0.10508	 0.00162	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84448	 27334	 0.013401	 0.034449	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27335	 27336	 0.004673	 0.009603	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27335	 84451	 0.002908	 0.008922	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27336	 84450	 0.003733	 0.009597	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27337	 84449	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27338	 27342	 0.11317	 0.14605	 0.00293	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84450	 27338	 0.008207	 0.013099	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27339	 27341	 0.000878	 0.00887	 0.00261	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84449	 27339	 0.000368	 0.004064	 0.00122	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27339	 84451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27339	 84451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84451	 27340	 0.059016	 0.04626	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82004	 27342	 0.067787	 0.24221	 0.00481	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84442	 27342	 0.080648	 0.20734	 0.00321	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27343	 27344	 0.032115	 0.12494	 0.00209	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27344	 27352	 0.020832	 0.09127	 0.00196	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27344	 27356	 0.085273	 0.21923	 0.00339	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84440	 27344	 0.037685	 0.12437	 0.00201	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27345	 27346	 0.00507	 0.019928	 0.00521	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27345	 84452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27345	 84452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84078	 27346	 0.004005	 0.021212	 0.00538	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27346	 84453	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27346	 84453	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27347	 27348	 0.006988	 0.024961	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27347	 27800	 0.089026	 0.08905	 0.0012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84079	 27347	 0.007815	 0.053027	 0.00099	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84452	 27347	 0.037681	 0.10808	 0.00166	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84453	 27348	 0.03674	 0.044788	 0.00072	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27349	 27804	 0.012432	 0.041475	 0.01052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27349	 27805	 0.006225	 0.031796	 0.008	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27349	 84454	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27349	 84454	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27350	 27355	 0.027975	 0.071913	 0.00111	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84454	 27350	 0.018791	 0.073103	 0.00122	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27351	 27352	 0.028923	 0.068489	 0.00125	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27351	 27353	 0.070393	 0.050888	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84439	 27351	 0.3775	 0.29889	 0.00376	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84452	 27351	 0.024431	 0.093993	 0.0016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27352	 27355	 0.021676	 0.080148	 0.00148	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27353	 27354	 0.065765	 0.052046	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27354	 27355	 0.057808	 0.045749	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27355	 84639	 0.093848	 0.16506	 0.0031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83665	 27356	 0.1371	 0.26875	 0.00403	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83545	 27357	 0.060765	 0.14108	 0.0021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27357	 84456	 0.19129	 0.15141	 0.00191	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27358	 27360	 0.011703	 0.032636	 0.00685	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27359	 84455	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27359	 84455	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27360	 27362	 0.007599	 0.019729	 0.00479	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27360	 84456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27360	 84456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27361	 27362	 0.003709	 0.009802	 0.00229	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27361	 84457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27361	 84457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83977	 27362	 0.039596	 0.12925	 0.03435	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27362	 84458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27362	 84458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84457	 27363	 0.022147	 0.019845	 0.00041	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84458	 27363	 0.043993	 0.031802	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84456	 27364	 0.051967	 0.052489	 0.0007	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84457	 27364	 0.034745	 0.027235	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84458	 27365	 0.043275	 0.085682	 0.00126	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84455	 27366	 0.020285	 0.084676	 0.00244	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84456	 27366	 0.054179	 0.1554	 0.00239	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27367	 84462	 0.005999	 0.012277	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27367	 84463	 0.009178	 0.026323	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27368	 27420	 0.029205	 0.032122	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27368	 84463	 0.003784	 0.018161	 0.00054	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27368	 84475	 0.010993	 0.02514	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27369	 27370	 0.020139	 0.014558	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27369	 84463	 0.018209	 0.013397	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27370	 27372	 0.005989	 0.015231	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27370	 84459	 0.027194	 0.021521	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27371	 27372	 0.006949	 0.013307	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27371	 84463	 0.016702	 0.014966	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27372	 27374	 0.004589	 0.010409	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27373	 27379	 0.000881	 0.00905	 0.00286	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27373	 27411	 0.001538	 0.003992	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27373	 27421	 0.002537	 0.013971	 0.00504	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27373	 84459	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27373	 84459	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27374	 27375	 0.005436	 0.013824	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27375	 27380	 0.006727	 0.012092	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27375	 84461	 0.003455	 0.015398	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27375	 84471	 0.009772	 0.019152	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27376	 27410	 0.000454	 0.003318	 0.00085	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27376	 84460	 0.000594	 0.003148	 0.00105	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27376	 84480	 0.001182	 0.005004	 0.00113	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27377	 84461	 0.004391	 0.011166	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27377	 84462	 0.008926	 0.024384	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27377	 84481	 0.007185	 0.016681	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27378	 27384	 5.8e-05	 0.000635	 0.00617	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27378	 27433	 9.9e-05	 0.001118	 0.01017	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27378	 84460	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27379	 27382	 0.001966	 0.008002	 0.00195	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27379	 84462	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27379	 84462	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27379	 84464	 0.000326	 0.003538	 0.00217	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84462	 27380	 0.004529	 0.010357	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27380	 84463	 0.01195	 0.034274	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27381	 27382	 0.000293	 0.00346	 0.00098	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27381	 27383	 0.001484	 0.009557	 0.00251	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27381	 27421	 0.001158	 0.012028	 0.00372	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27381	 27423	 0.002673	 0.01533	 0.0051	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27381	 84463	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27381	 84463	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27382	 84478	 0.001234	 0.008928	 0.0048	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27383	 84464	 0.0007	 0.005517	 0.00161	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27384	 27430	 0.000124	 0.001489	 0.02499	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27384	 27488	 0.001159	 0.013138	 0.11966	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27384	 27735	 0.000993	 0.018368	 0.17662	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27384	 84464	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27384	 84464	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27385	 84465	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27386	 27390	 0.016897	 0.013372	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84466	 27386	 0.007404	 0.01466	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84466	 27387	 0.021179	 0.016601	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27388	 27389	 0.001203	 0.005838	 0.00133	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84465	 27388	 0.001223	 0.006249	 0.0017	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27389	 27426	 0.002795	 0.012587	 0.00335	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27391	 27392	 0.001166	 0.018754	 0.00613	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84465	 27391	 0.000663	 0.006363	 0.00296	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27392	 27393	 0.001702	 0.016867	 0.00517	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27393	 27394	 0.004542	 0.013671	 0.00428	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27393	 27396	 0.001845	 0.011688	 0.00317	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84401	 27393	 0.004333	 0.022151	 0.00604	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27394	 27395	 0.001844	 0.005141	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27394	 27550	 0.002446	 0.009792	 0.00247	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27395	 27396	 0.002889	 0.007635	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27396	 27397	 0.000849	 0.006456	 0.00203	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27396	 27578	 0.004435	 0.011514	 0.00279	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27397	 27416	 0.000532	 0.005005	 0.00152	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27398	 27760	 0.02538	 0.067092	 0.00122	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27398	 84470	 0.030743	 0.071364	 0.00136	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27399	 27400	 0.002363	 0.00946	 0.00238	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27399	 27556	 0.002083	 0.010798	 0.00264	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27399	 27558	 0.00554	 0.014383	 0.00349	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27399	 84467	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27399	 84467	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27400	 27406	 0.002774	 0.010542	 0.00295	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27401	 27436	 0.019477	 0.098509	 0.00192	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27401	 27552	 0.012344	 0.039585	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84467	 27401	 0.030463	 0.078309	 0.00121	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27402	 27405	 0.026076	 0.03955	 0.00057	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27403	 27404	 0.009584	 0.024637	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27403	 84473	 0.032753	 0.029349	 0.0006	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27404	 27408	 0.009071	 0.021479	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27405	 27408	 0.016349	 0.037956	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27405	 27435	 0.011525	 0.026479	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27405	 84468	 0.019432	 0.032735	 0.00047	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27405	 84481	 0.03459	 0.055213	 0.00127	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27406	 84468	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27406	 84468	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27406	 84469	 0.001744	 0.006982	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27407	 27433	 0.000314	 0.003556	 0.03238	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27407	 27439	 0.000116	 0.001313	 0.01195	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27407	 84469	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27408	 84471	 0.005755	 0.025645	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27409	 84471	 0.007278	 0.017359	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27409	 84472	 0.008561	 0.01958	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27410	 84471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27410	 84471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27411	 27412	 0.002443	 0.006279	 0.00155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27411	 84472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27411	 84472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27412	 84473	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27412	 84473	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84473	 27413	 0.006351	 0.024709	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27413	 84474	 0.011251	 0.022276	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27414	 27416	 0.000565	 0.005755	 0.00148	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84464	 27414	 0.002294	 0.026225	 0.008	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27414	 84474	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27414	 84474	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27415	 84475	 0.023337	 0.059349	 0.00094	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84474	 27417	 0.029749	 0.021073	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27418	 27419	 0.012576	 0.024085	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84472	 27418	 0.008426	 0.017988	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84474	 27418	 0.011833	 0.022002	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27419	 27420	 0.025393	 0.018357	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27421	 27423	 0.000501	 0.006694	 0.00183	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27421	 27424	 0.0019	 0.012426	 0.00316	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27421	 84475	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27421	 84475	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84475	 27422	 0.021476	 0.0158	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27423	 27424	 0.000842	 0.005177	 0.00149	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27423	 27425	 0.002232	 0.00978	 0.00336	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27424	 27428	 0.004163	 0.01812	 0.00516	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84465	 27424	 0.005113	 0.037774	 0.0109	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27425	 27426	 0.004033	 0.01922	 0.00557	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27427	 27430	 0.00047	 0.008246	 0.08823	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27427	 84476	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84476	 27428	 0.003824	 0.020981	 0.00555	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84463	 27429	 0.009484	 0.038762	 0.00078	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27430	 27450	 0.000117	 0.001966	 0.03565	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27430	 84478	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27430	 84478	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27431	 84479	 0.040615	 0.029361	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27432	 27444	 0.00178	 0.012803	 0.00339	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84464	 27432	 0.001403	 0.008418	 0.00255	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27432	 84479	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27432	 84479	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27433	 84480	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27434	 27452	 0.003099	 0.010842	 0.00359	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84480	 27434	 0.001249	 0.00486	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27434	 84482	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27434	 84482	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27435	 27443	 0.009301	 0.019113	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84482	 27435	 0.031251	 0.034372	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84479	 27436	 0.013129	 0.043798	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84482	 27436	 0.004666	 0.018151	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27437	 27438	 0.006525	 0.012919	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84468	 27437	 0.023203	 0.045473	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27437	 84484	 0.034865	 0.022572	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27438	 84484	 0.01766	 0.013976	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27438	 84490	 0.004884	 0.012554	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27439	 84483	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27440	 27441	 0.036958	 0.029248	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84470	 27440	 0.014885	 0.042692	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84484	 27440	 0.004523	 0.017594	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27440	 84487	 0.003084	 0.012363	 0.00032	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27440	 84488	 0.011982	 0.053392	 0.00091	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27441	 27442	 0.022726	 0.017985	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27442	 84485	 0.002258	 0.0155	 0.00028	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27442	 84490	 0.003631	 0.011138	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27443	 84490	 0.005124	 0.015736	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27444	 27445	 0.000556	 0.005992	 0.0032	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27444	 27452	 0.000623	 0.006673	 0.00213	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27444	 84485	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27444	 84485	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27445	 27449	 0.000886	 0.01003	 0.00563	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27445	 84486	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27445	 84486	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27446	 27447	 0.001112	 0.010111	 0.00255	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84483	 27446	 0.001642	 0.008014	 0.00221	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27446	 84487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27446	 84487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27447	 27448	 0.001706	 0.021028	 0.00679	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27447	 84488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27447	 84488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27448	 27643	 0.001364	 0.019292	 0.00639	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27448	 84489	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27448	 84489	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27449	 84565	 0.00133	 0.016813	 0.00868	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27450	 27645	 0.00013	 0.002296	 0.03812	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84478	 27451	 0.003365	 0.024577	 0.00632	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84483	 27452	 0.001041	 0.004532	 0.00129	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27452	 84490	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27452	 84490	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27453	 27510	 0.02116	 0.016746	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27454	 27474	 0.00309	 0.007943	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27454	 27475	 0.003423	 0.008105	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27454	 84507	 0.002692	 0.006847	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27455	 27481	 0.000977	 0.002537	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27455	 27494	 0.000728	 0.001891	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27456	 27482	 0.006007	 0.009201	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27456	 84507	 0.005216	 0.009554	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27457	 27504	 0.011862	 0.010926	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27457	 84492	 0.017654	 0.017831	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27458	 27459	 0.001503	 0.004674	 0.00098	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27458	 84491	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27458	 84491	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27459	 27460	 0.00089	 0.00455	 0.00124	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27459	 84492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27459	 84492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27460	 84493	 0.000551	 0.00328	 0.00086	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27461	 27462	 4.6e-05	 0.000514	 0.0049	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27461	 27506	 0.000112	 0.00147	 0.0133	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27461	 84493	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27462	 27464	 7e-05	 0.000782	 0.00731	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84494	 27463	 0.029824	 0.029911	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27463	 84496	 0.020135	 0.014814	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27464	 27547	 0.000135	 0.001504	 0.01419	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27464	 84495	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27465	 27474	 0.012141	 0.0086	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27466	 27468	 0.005535	 0.008478	 0.00015	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27466	 27478	 0.007001	 0.011794	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27467	 27468	 0.038802	 0.030415	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27467	 27469	 0.021594	 0.015888	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27467	 84499	 0.00959	 0.021752	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27467	 84503	 0.00845	 0.031699	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27468	 27469	 0.005521	 0.012626	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84494	 27468	 0.002347	 0.009933	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27469	 84497	 0.010178	 0.017145	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27470	 27471	 0.00127	 0.00428	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27470	 27473	 0.002739	 0.007109	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27470	 84497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27470	 84497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27471	 84498	 0.001013	 0.003582	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27472	 27547	 7e-05	 0.000781	 0.00736	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27472	 84498	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27472	 84498	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27473	 27549	 0.001793	 0.007178	 0.00181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27473	 84499	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27473	 84499	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27473	 84502	 0.002113	 0.013381	 0.00363	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27474	 27478	 0.007205	 0.014266	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27475	 27477	 0.004288	 0.008775	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27476	 27477	 0.011179	 0.008847	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27477	 27478	 0.012049	 0.007801	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27477	 27479	 0.012513	 0.009903	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27479	 27480	 0.010449	 0.010669	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27480	 84503	 0.00534	 0.017812	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27481	 27485	 0.001275	 0.003205	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27482	 27484	 0.024403	 0.019312	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27482	 84500	 0.012092	 0.007828	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27483	 27487	 0.001919	 0.005073	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27483	 27507	 0.001125	 0.002829	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27484	 27513	 0.056156	 0.036356	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27484	 84500	 0.015383	 0.011799	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27485	 84500	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27485	 84500	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27485	 84502	 0.001574	 0.004226	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27486	 27579	 0.038954	 0.02988	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27486	 84501	 0.015463	 0.012237	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27487	 27559	 0.002593	 0.006961	 0.00158	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27487	 84501	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27487	 84501	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27487	 84502	 0.001635	 0.005921	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27488	 27506	 0.000191	 0.002163	 0.01969	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27488	 84502	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27489	 27497	 0.00243	 0.006775	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27489	 27509	 0.003072	 0.007975	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27489	 84504	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27489	 84504	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84504	 27490	 0.020978	 0.016602	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27490	 84515	 0.023989	 0.018401	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27491	 27492	 0.000812	 0.002089	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27491	 27499	 0.001783	 0.004972	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27491	 84505	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27491	 84505	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27492	 27508	 0.000837	 0.002246	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27493	 27502	 0.010052	 0.013211	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27493	 84512	 0.007484	 0.011946	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27494	 27508	 0.000889	 0.002308	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27495	 27506	 5.8e-05	 0.000665	 0.00583	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27495	 84506	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27496	 27499	 0.002338	 0.006521	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27496	 27505	 0.003147	 0.008088	 0.002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27497	 27564	 0.001967	 0.005355	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27498	 27500	 0.021495	 0.015226	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27498	 84508	 0.021686	 0.014567	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27499	 84508	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27499	 84508	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27500	 27501	 0.034429	 0.026987	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27500	 84509	 0.021617	 0.013995	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27501	 27502	 0.017811	 0.011531	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84505	 27501	 0.014257	 0.011175	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27503	 27522	 0.001503	 0.003972	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27503	 84509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27503	 84509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27503	 84511	 0.004287	 0.011129	 0.0027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27504	 27523	 0.009592	 0.013977	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27505	 27566	 0.003689	 0.012653	 0.00303	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27505	 84510	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27505	 84510	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27506	 84511	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27507	 27509	 0.002063	 0.005538	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27507	 84513	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27507	 84513	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27508	 84514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27508	 84514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27509	 84515	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27509	 84515	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27510	 27511	 0.015152	 0.011991	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84503	 27510	 0.022985	 0.053363	 0.00079	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84512	 27510	 0.003291	 0.014498	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27512	 27513	 0.022879	 0.02492	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27512	 27517	 0.005525	 0.015847	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27512	 84516	 0.026955	 0.021332	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84501	 27513	 0.038135	 0.029252	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27513	 84534	 0.016078	 0.021917	 0.00049	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84502	 27514	 0.00632	 0.016245	 0.00402	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27514	 84516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27514	 84516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27515	 27579	 0.023596	 0.018673	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84516	 27515	 0.024818	 0.01964	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27516	 27517	 0.006702	 0.017229	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27516	 84533	 0.005895	 0.019666	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84516	 27517	 0.016212	 0.031772	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27517	 84533	 0.006606	 0.024781	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27518	 27521	 0.023658	 0.018723	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27518	 27523	 0.00474	 0.012948	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84491	 27518	 0.016668	 0.015631	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27518	 84517	 0.018241	 0.014298	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27519	 27526	 0.002314	 0.006007	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27519	 27544	 0.003722	 0.00864	 0.00263	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27519	 84517	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27519	 84517	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84517	 27520	 0.018876	 0.014938	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27522	 27524	 0.001824	 0.004584	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27522	 84518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27522	 84518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27523	 27525	 0.0095	 0.016003	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84518	 27523	 0.002441	 0.013876	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27524	 27577	 0.002547	 0.00796	 0.00231	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27524	 84519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27524	 84519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84519	 27525	 0.004341	 0.01333	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27525	 84520	 0.003565	 0.010117	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27526	 84520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27526	 84520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84520	 27527	 0.012862	 0.010082	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27528	 27542	 0.003481	 0.010678	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84520	 27528	 0.009596	 0.018807	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27529	 27533	 0.010862	 0.027923	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27529	 84521	 0.034031	 0.030494	 0.00062	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27530	 27531	 0.017782	 0.017468	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27530	 84538	 0.019084	 0.031828	 0.00046	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27530	 84539	 0.012101	 0.023175	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27532	 27580	 0.001477	 0.00865	 0.00236	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27532	 84521	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27532	 84521	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27532	 84537	 0.001159	 0.010127	 0.00401	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83794	 27533	 0.011756	 0.031076	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27534	 84522	 0.022603	 0.015183	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27534	 84523	 0.022598	 0.020815	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27534	 84524	 0.017188	 0.018721	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27535	 27536	 0.001369	 0.003818	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27535	 84522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27535	 84522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27536	 27539	 0.003686	 0.00974	 0.00228	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84395	 27536	 0.003854	 0.011163	 0.00269	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27536	 84523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27536	 84523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27537	 27543	 0.006388	 0.016931	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84396	 27537	 0.034537	 0.037986	 0.00051	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84523	 27537	 0.003936	 0.015313	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27538	 27539	 0.000859	 0.004171	 0.00095	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27538	 27577	 0.003539	 0.009352	 0.00219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27538	 27586	 0.001316	 0.010944	 0.00331	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27539	 84524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27539	 84524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27540	 27541	 0.002102	 0.005556	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27540	 27582	 0.002348	 0.007658	 0.00203	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27540	 84525	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27540	 84525	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27541	 84526	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27541	 84526	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84524	 27542	 0.004849	 0.020131	 0.00052	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27543	 27545	 0.027175	 0.035716	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84502	 27544	 0.007748	 0.02658	 0.00637	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27544	 84527	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27544	 84527	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27545	 27546	 0.01201	 0.022332	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84527	 27545	 0.029781	 0.027927	 0.00043	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84400	 27546	 0.03956	 0.049107	 0.00107	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27546	 84529	 0.013779	 0.031657	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27547	 84528	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27548	 27549	 0.0014	 0.004898	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27548	 27550	 0.002047	 0.008196	 0.00206	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84401	 27548	 0.004413	 0.014394	 0.00382	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27548	 84530	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27548	 84530	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27551	 27553	 0.037516	 0.024288	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84499	 27551	 0.012193	 0.031343	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27552	 27554	 0.021993	 0.039529	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84402	 27552	 0.20696	 0.16381	 0.00206	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27552	 84531	 0.024968	 0.06916	 0.00114	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27552	 84541	 0.005976	 0.028559	 0.00063	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84530	 27553	 0.071689	 0.061272	 0.00115	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27554	 84531	 0.014941	 0.034682	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27555	 27556	 0.00404	 0.011266	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27555	 27559	 0.004518	 0.012301	 0.00271	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27556	 84531	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27556	 84531	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27557	 27558	 0.003461	 0.009146	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27557	 27561	 0.006315	 0.016232	 0.00402	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27557	 84532	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27557	 84532	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84503	 27560	 0.017937	 0.041208	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84502	 27561	 0.008079	 0.027715	 0.00664	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27561	 84533	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27561	 84533	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27562	 27585	 0.017375	 0.049834	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84265	 27562	 0.008374	 0.035965	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27562	 84534	 0.008031	 0.039192	 0.00068	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27563	 27583	 0.0046	 0.012349	 0.0028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84502	 27563	 0.006595	 0.017957	 0.00396	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27563	 84534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27563	 84534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27564	 27566	 0.002161	 0.012058	 0.00308	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27564	 27583	 0.004198	 0.011707	 0.00246	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27564	 84535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27564	 84535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27565	 84536	 0.029397	 0.045034	 0.00063	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27566	 27568	 0.001029	 0.012766	 0.00553	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27566	 84536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27566	 84536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27567	 27568	 0.000656	 0.009281	 0.00307	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83732	 27567	 0.001025	 0.007214	 0.0041	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27569	 84538	 0.018031	 0.076312	 0.00144	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27569	 84544	 0.04148	 0.069878	 0.001	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83807	 27570	 0.000494	 0.006382	 0.10713	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27570	 84537	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83805	 27571	 0.006266	 0.031689	 0.00062	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27571	 84539	 0.004772	 0.026278	 0.00059	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27572	 27574	 0.008783	 0.029299	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84538	 27572	 0.006763	 0.030136	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83805	 27573	 0.019848	 0.037512	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83731	 27574	 0.022016	 0.063144	 0.00097	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84537	 27575	 0.003024	 0.008433	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27575	 84539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27575	 84539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84510	 27576	 0.053706	 0.042097	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84536	 27576	 0.040819	 0.053648	 0.00074	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84537	 27577	 0.004345	 0.037009	 0.00923	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27577	 84540	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27577	 84540	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27578	 84541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27578	 84541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84501	 27579	 0.024234	 0.019178	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27580	 27581	 0.00098	 0.005106	 0.00134	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27581	 27582	 0.001543	 0.007077	 0.00181	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27582	 84542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27582	 84542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27583	 84543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27583	 84543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84535	 27584	 0.014736	 0.034896	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84543	 27585	 0.027059	 0.036885	 0.00082	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27586	 27587	 0.001234	 0.010513	 0.00262	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27586	 84544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27586	 84544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84537	 27587	 0.001467	 0.011413	 0.00296	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27588	 27589	 0.001159	 0.003008	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27588	 27641	 0.000646	 0.003562	 0.00083	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27588	 84545	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27588	 84545	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27589	 27600	 0.002368	 0.006357	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27589	 84546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27589	 84546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84546	 27590	 0.006476	 0.016404	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27590	 84558	 0.01823	 0.041882	 0.00064	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27591	 27593	 0.000769	 0.006812	 0.00181	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83645	 27591	 0.008151	 0.057399	 0.03265	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27591	 84547	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27591	 84547	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27592	 27634	 0.014823	 0.038104	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84547	 27592	 0.020086	 0.03206	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27593	 27595	 0.000924	 0.00541	 0.00147	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27593	 27596	 0.001021	 0.005933	 0.0014	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27593	 84548	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27593	 84548	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27594	 27634	 0.010415	 0.026992	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27594	 84549	 0.00563	 0.013332	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27595	 27597	 0.000608	 0.003221	 0.00107	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27595	 84549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27595	 84549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27596	 27598	 0.002071	 0.005369	 0.00162	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27596	 27641	 0.000894	 0.003067	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27596	 84550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27596	 84550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27597	 27609	 0.001313	 0.010213	 0.00265	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27597	 84551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27597	 84551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27598	 27611	 0.007234	 0.026194	 0.00562	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27598	 84552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27598	 84552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84545	 27599	 0.007128	 0.020443	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84546	 27599	 0.002547	 0.016434	 0.00052	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27599	 84560	 0.00571	 0.022211	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27599	 84560	 0.00571	 0.022211	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27600	 27601	 0.001645	 0.004348	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27601	 27629	 0.002203	 0.006179	 0.00159	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27602	 27603	 0.05582	 0.1296	 0.00193	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27602	 27604	 0.035276	 0.078077	 0.00128	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27603	 27615	 0.03988	 0.092587	 0.00138	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27604	 84554	 0.022006	 0.11006	 0.00196	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27605	 27606	 0.11514	 0.091122	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27606	 27607	 0.024493	 0.081708	 0.0013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27606	 84553	 0.060095	 0.12299	 0.00303	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83969	 27607	 0.028261	 0.098888	 0.00205	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27608	 84553	 0.010719	 0.051452	 0.00154	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27609	 84553	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27609	 84553	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84553	 27610	 0.033023	 0.040257	 0.00065	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27611	 84554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27611	 84554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84552	 27612	 0.042987	 0.047696	 0.00093	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84554	 27613	 0.07523	 0.054384	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27614	 84559	 0.044465	 0.063122	 0.00104	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27615	 84555	 0.035241	 0.081817	 0.00122	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27616	 84555	 0.038702	 0.054941	 0.0009	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27617	 27618	 0.000454	 0.003541	 0.00106	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27617	 84555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27617	 84555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27618	 27619	 0.000387	 0.003323	 0.00095	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27620	 84556	 0.060435	 0.045788	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27621	 27623	 0.003454	 0.009129	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84244	 27621	 0.007842	 0.043031	 0.01137	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27621	 84556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27621	 84556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84554	 27622	 0.076186	 0.17505	 0.00266	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84556	 27622	 0.01961	 0.043403	 0.00071	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27622	 84564	 0.040422	 0.052605	 0.00074	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27623	 27642	 0.001661	 0.004271	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27624	 84564	 0.017625	 0.019385	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82030	 27625	 0.021517	 0.023666	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27626	 27629	 0.00179	 0.007284	 0.00177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27626	 27631	 0.001002	 0.009173	 0.00367	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27626	 84557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27626	 84557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84557	 27627	 0.012383	 0.019864	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82030	 27628	 0.007081	 0.022801	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84557	 27628	 0.008305	 0.014985	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27628	 84558	 0.00658	 0.015116	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27629	 27630	 0.001691	 0.006772	 0.00171	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27629	 84558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27629	 84558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27631	 27633	 0.00191	 0.011378	 0.00299	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27631	 84559	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27631	 84559	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27632	 84560	 0.023417	 0.02495	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27633	 84560	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27633	 84560	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27634	 27640	 0.009918	 0.056379	 0.00102	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84547	 27634	 0.029118	 0.062398	 0.00109	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82030	 27635	 0.015212	 0.031131	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82030	 27636	 0.008225	 0.021143	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84547	 27637	 0.009124	 0.051866	 0.00094	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27637	 84561	 0.014883	 0.071482	 0.00138	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27638	 27639	 0.002527	 0.008513	 0.00212	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27638	 84561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27638	 84561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27639	 84562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27639	 84562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84388	 27640	 0.020418	 0.062637	 0.0017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84562	 27640	 0.015725	 0.050636	 0.00086	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27641	 84563	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27641	 84563	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27642	 84564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27642	 84564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27643	 27647	 0.001897	 0.014872	 0.0068	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27644	 27645	 0.000102	 0.001723	 0.03124	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27644	 27648	 0.000106	 0.002032	 0.03427	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27644	 84565	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27644	 84565	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82057	 27646	 0.010852	 0.099833	 0.00198	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83598	 27646	 0.012903	 0.10057	 0.00188	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27647	 27656	 0.002857	 0.020672	 0.01112	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27647	 84566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27647	 84566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27647	 84567	 0.003926	 0.018012	 0.00461	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27648	 84567	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82057	 27649	 0.008802	 0.02703	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84568	 27649	 0.011352	 0.025962	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27650	 27652	 0.003895	 0.013574	 0.00315	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27650	 27653	 0.001885	 0.004847	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27651	 27652	 0.002719	 0.010687	 0.0028	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27651	 27653	 0.002076	 0.006772	 0.0018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27652	 27654	 0.000992	 0.010965	 0.00329	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27652	 84569	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27652	 84569	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27654	 27662	 0.001237	 0.014143	 0.00431	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27655	 27656	 0.00485	 0.016637	 0.00399	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83656	 27656	 0.002308	 0.025401	 0.01509	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27657	 27659	 0.029074	 0.16337	 0.00303	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84569	 27657	 0.017124	 0.076307	 0.0013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27657	 84571	 0.038487	 0.088423	 0.00134	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27658	 84571	 0.024705	 0.051923	 0.00095	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27658	 84572	 0.032097	 0.073407	 0.00179	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27659	 27660	 0.040881	 0.078291	 0.00123	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83660	 27659	 0.09049	 0.25959	 0.00399	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83663	 27659	 0.016194	 0.11116	 0.00203	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27660	 84570	 0.041405	 0.096129	 0.00143	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27661	 27663	 0.004376	 0.020408	 0.00505	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27661	 84570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27661	 84570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27662	 27663	 0.00148	 0.016393	 0.00533	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27662	 84571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27662	 84571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83983	 27663	 0.00745	 0.11448	 0.03206	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27663	 84572	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27663	 84572	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27664	 27665	 0.1287	 0.09304	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27664	 84573	 0.11538	 0.21136	 0.00365	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27665	 27668	 0.12984	 0.091978	 0.00145	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27666	 27669	 0.004266	 0.023802	 0.00608	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83977	 27666	 0.011508	 0.12122	 0.06823	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27666	 84573	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27666	 84573	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27667	 27668	 0.072786	 0.047123	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27667	 84574	 0.016347	 0.042366	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27667	 84576	 0.030997	 0.10341	 0.00164	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27669	 27670	 0.002706	 0.009798	 0.0021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27669	 84574	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27669	 84574	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27670	 84577	 0.004164	 0.01667	 0.0042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83953	 27671	 0.098881	 0.064018	 0.00122	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27671	 84576	 0.047457	 0.086924	 0.0015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27672	 27673	 0.000291	 0.005377	 0.05166	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27672	 84575	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27673	 84577	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27673	 84577	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27674	 27678	 0.005604	 0.030751	 0.00813	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27674	 27680	 0.004848	 0.0269	 0.00818	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82016	 27675	 0.030208	 0.055329	 0.00096	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82016	 27676	 0.18495	 0.14639	 0.00184	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27677	 84578	 0.094128	 0.15026	 0.00346	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27677	 84580	 0.024835	 0.099389	 0.0021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83502	 27678	 0.011805	 0.030648	 0.00744	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27678	 84578	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27678	 84578	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27679	 84579	 0.014211	 0.032648	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27679	 84580	 0.01825	 0.03293	 0.00048	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27680	 27681	 0.002252	 0.007512	 0.00191	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82015	 27680	 0.002287	 0.029292	 0.00874	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27680	 84579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27680	 84579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27681	 84580	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27681	 84580	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84580	 27682	 0.011524	 0.022816	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27683	 27684	 0.010262	 0.02755	 0.00624	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27684	 84581	 0.002405	 0.030804	 0.0092	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27685	 84581	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27685	 84581	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27686	 27687	 0.000102	 0.001132	 0.01077	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27686	 84582	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27686	 84582	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27687	 84583	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27687	 84583	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27688	 27717	 0.001664	 0.005707	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27688	 27718	 0.001288	 0.003463	 0.00097	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84583	 27688	 0.001195	 0.003255	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27689	 27692	 0.000153	 0.001766	 0.01548	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27689	 84584	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27690	 27691	 0.029273	 0.023166	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27690	 84599	 0.013302	 0.044373	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27691	 84588	 0.059418	 0.065353	 0.00087	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27692	 84586	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27692	 84586	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27693	 27702	 0.005103	 0.018037	 0.00406	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84586	 27693	 0.002696	 0.009395	 0.00218	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27694	 27700	 0.00026	 0.002943	 0.02679	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27694	 84587	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84587	 27695	 0.002038	 0.013987	 0.00408	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27696	 84590	 0.07492	 0.14834	 0.00218	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27697	 27698	 0.009612	 0.022313	 0.0068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27698	 84589	 0.003883	 0.010262	 0.0024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27699	 84597	 0.001622	 0.010063	 0.00244	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27700	 27712	 0.000273	 0.002992	 0.02906	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27700	 84589	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84589	 27701	 0.00129	 0.004903	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27701	 84591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27701	 84591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27702	 27703	 0.000872	 0.005192	 0.00137	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27702	 84592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27702	 84592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27703	 27705	 0.002593	 0.01943	 0.00474	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27704	 27705	 0.003214	 0.008262	 0.00205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27704	 27707	 0.00373	 0.009682	 0.00235	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27705	 27706	 0.003673	 0.009442	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27705	 84593	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27705	 84593	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27706	 27709	 0.003156	 0.007934	 0.00206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27706	 84594	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27706	 84594	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27707	 27709	 0.004388	 0.011781	 0.00267	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27709	 27710	 0.00165	 0.005833	 0.00131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27709	 84595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27709	 84595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27710	 84596	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27710	 84596	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84596	 27711	 0.013073	 0.023589	 0.00034	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27712	 84597	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27712	 84597	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84597	 27713	 0.005427	 0.014342	 0.00336	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27713	 84598	 0.004127	 0.014157	 0.00339	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27714	 84598	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27714	 84598	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27715	 27716	 0.10768	 0.069713	 0.00133	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83618	 27716	 0.015296	 0.078518	 0.00149	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83640	 27716	 0.040406	 0.080002	 0.00117	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27717	 27718	 0.0017	 0.00583	 0.0014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84326	 27717	 0.002755	 0.011658	 0.00262	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27717	 84599	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27717	 84599	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84586	 27718	 0.002443	 0.00614	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27719	 27720	 0.005058	 0.019676	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27719	 27720	 0.005058	 0.019676	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27719	 84601	 0.01393	 0.047583	 0.00103	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27719	 84601	 0.01393	 0.047583	 0.00103	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81853	 27720	 0.011075	 0.043086	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81853	 27720	 0.011075	 0.043086	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27721	 84600	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27722	 27727	 0.001787	 0.02216	 0.0096	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82021	 27722	 0.002928	 0.037025	 0.01912	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27722	 84602	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27722	 84602	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27723	 27724	 0.046386	 0.03636	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27724	 27725	 0.004096	 0.015758	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84602	 27724	 0.019521	 0.075944	 0.00127	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84602	 27724	 0.019521	 0.075944	 0.00127	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27725	 27726	 0.004585	 0.016053	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27726	 84603	 0.005258	 0.02104	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27727	 27729	 0.013027	 0.043896	 0.01091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27727	 27731	 0.001155	 0.013213	 0.0037	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79647	 27727	 0.00198	 0.022409	 0.01258	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27727	 84603	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27727	 84603	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79657	 27728	 0.017302	 0.059102	 0.00129	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79657	 27728	 0.017302	 0.059102	 0.00129	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84603	 27728	 0.014436	 0.046293	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84603	 27728	 0.014436	 0.046293	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27728	 84604	 0.060856	 0.17456	 0.00268	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27729	 84604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27729	 84604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27730	 27731	 0.002386	 0.023904	 0.00796	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82014	 27730	 0.002674	 0.033645	 0.01042	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27730	 84605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27730	 84605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84602	 27732	 0.016598	 0.081034	 0.0017	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84605	 27732	 0.018408	 0.093118	 0.00162	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27733	 27734	 0.007976	 0.035911	 0.00956	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82021	 27733	 0.004256	 0.016178	 0.00453	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27735	 27739	 0.000159	 0.002012	 0.01961	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27735	 84606	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27736	 27737	 0.012905	 0.01696	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27736	 27766	 0.007748	 0.015184	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27737	 27766	 0.004376	 0.009344	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27737	 84611	 0.028205	 0.086619	 0.00163	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27738	 27747	 0.005003	 0.020656	 0.00489	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27738	 27749	 0.004688	 0.016403	 0.00544	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27738	 84608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27738	 84608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27738	 84610	 0.006407	 0.019286	 0.00603	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27739	 27740	 0.000286	 0.003238	 0.02947	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27739	 84609	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27739	 84609	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27740	 84610	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27740	 84610	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27741	 27742	 0.001959	 0.015436	 0.00451	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27741	 27755	 0.004821	 0.024223	 0.0063	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84606	 27741	 0.000747	 0.011417	 0.00368	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27742	 27756	 0.004185	 0.021375	 0.00538	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27742	 84611	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27742	 84611	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27743	 27759	 0.002131	 0.01427	 0.00897	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27743	 84612	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27743	 84612	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27744	 27761	 0.004812	 0.01677	 0.00389	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27744	 84613	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27744	 84613	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27745	 27746	 0.001272	 0.00593	 0.00147	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27746	 27747	 0.002975	 0.013396	 0.00356	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27747	 84614	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27747	 84614	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27748	 27762	 0.001641	 0.017151	 0.00577	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27748	 84615	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27748	 84615	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27750	 27751	 0.004649	 0.020934	 0.00557	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27751	 27752	 0.005105	 0.024773	 0.00566	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27752	 27753	 0.005379	 0.023968	 0.00651	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84610	 27753	 0.010928	 0.035644	 0.00946	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27753	 84616	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27753	 84616	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84610	 27754	 0.002859	 0.024518	 0.00698	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27754	 84617	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27754	 84617	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27755	 27764	 0.003829	 0.024251	 0.00658	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27755	 84618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27755	 84618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27756	 27763	 0.002518	 0.01122	 0.00305	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84266	 27757	 0.013832	 0.035849	 0.00068	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27757	 84619	 0.013672	 0.02442	 0.00036	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27757	 84620	 0.021718	 0.062291	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27758	 27759	 0.001191	 0.009057	 0.00285	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27758	 84619	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27758	 84619	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27759	 84620	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27759	 84620	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84467	 27760	 0.042859	 0.11018	 0.00171	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84613	 27760	 0.009209	 0.036537	 0.00104	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27761	 27762	 0.002434	 0.012227	 0.00318	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27762	 84621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27762	 84621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27763	 27764	 0.002172	 0.005915	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27763	 84622	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27763	 84622	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84614	 27765	 0.028643	 0.050002	 0.00077	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84615	 27765	 0.033245	 0.076378	 0.00116	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84621	 27765	 0.049188	 0.097391	 0.00143	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84607	 27766	 0.001486	 0.006619	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27767	 27769	 0.009522	 0.025165	 0.00589	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27767	 84623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27767	 84623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27768	 27769	 0.004384	 0.024919	 0.00721	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27769	 84625	 0.014166	 0.03857	 0.0085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84623	 27770	 0.040754	 0.093206	 0.00228	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27770	 84624	 0.094209	 0.12382	 0.0017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83957	 27771	 0.004768	 0.030711	 0.00805	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27771	 84624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27771	 84624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27771	 84625	 0.003779	 0.017853	 0.00571	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27772	 84625	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27772	 84625	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27773	 27774	 0.000776	 0.008114	 0.00273	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27774	 27775	 0.002137	 0.02443	 0.00745	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84228	 27776	 0.002063	 0.005452	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27776	 84629	 0.002698	 0.009	 0.00228	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84230	 27777	 0.034688	 0.03394	 0.00048	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27777	 84626	 0.005586	 0.023316	 0.00067	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27778	 27780	 0.005949	 0.015445	 0.00375	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27778	 84626	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27778	 84626	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27778	 84629	 0.006479	 0.01764	 0.00389	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27779	 27781	 0.023518	 0.024743	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84626	 27779	 0.05167	 0.040891	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27779	 84627	 0.03828	 0.024782	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27780	 27784	 0.003009	 0.007953	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27780	 84627	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27780	 84627	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84627	 27781	 0.040712	 0.032219	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27782	 27783	 0.044076	 0.034881	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84627	 27782	 0.026568	 0.021026	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27783	 27789	 0.079664	 0.074709	 0.00115	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84215	 27783	 0.02017	 0.041276	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27784	 27787	 0.010457	 0.026882	 0.00666	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27784	 84628	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27784	 84628	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27785	 27786	 0.000156	 0.001734	 0.0165	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27785	 84629	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27786	 84631	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27786	 84631	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82023	 27787	 0.000438	 0.001138	 0.00028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27788	 27798	 0.009172	 0.033212	 0.00713	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27788	 27799	 0.012203	 0.032253	 0.00755	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82023	 27788	 0.008677	 0.022931	 0.00537	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27788	 84632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27788	 84632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27789	 84634	 0.041349	 0.081868	 0.0012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84225	 27790	 0.03082	 0.07838	 0.00124	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27790	 84634	 0.033915	 0.087899	 0.00166	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27791	 27792	 0.001996	 0.021156	 0.00628	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27791	 84633	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27791	 84633	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27792	 27797	 0.001364	 0.013037	 0.0043	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27793	 84634	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27793	 84634	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27794	 84635	 0.017145	 0.013568	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27795	 27797	 0.001914	 0.00693	 0.00149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27795	 27798	 0.001136	 0.00396	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27795	 84635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27795	 84635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27797	 27798	 0.002681	 0.009198	 0.0022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27797	 84636	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27797	 84636	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27798	 84637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27798	 84637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27799	 84638	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27799	 84638	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84079	 27800	 0.01443	 0.082027	 0.00148	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84638	 27800	 0.029641	 0.078565	 0.00199	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27801	 27802	 0.015515	 0.0445	 0.00068	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84410	 27801	 0.12537	 0.35972	 0.00553	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84633	 27801	 0.12611	 0.15097	 0.00251	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84081	 27802	 0.15899	 0.15363	 0.00223	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82024	 27803	 0.2821	 0.22331	 0.00281	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84632	 27803	 0.16022	 0.12681	 0.0016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84637	 27803	 0.01607	 0.042482	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27804	 27807	 0.010039	 0.025806	 0.00639	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27804	 84639	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27804	 84639	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27805	 27806	 0.016898	 0.046009	 0.01014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84080	 27805	 0.005982	 0.048559	 0.01546	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27806	 27807	 0.001779	 0.027315	 0.00764	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27806	 84640	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27806	 84640	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27807	 27808	 0.002103	 0.009648	 0.00247	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27808	 27809	 0.004397	 0.020809	 0.005	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27810	 29514	 0.000469	 0.005848	 0.40091	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27810	 30911	 0.0007	 0.010046	 0.69505	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27810	 84641	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27810	 84641	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27811	 27855	 0.000454	 0.011852	 1.2644	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 0	 -30.0	 30.0;
	27811	 28131	 0.000347	 0.008567	 0.63202	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27811	 28681	 0.000238	 0.005865	 0.69888	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27811	 30803	 0.00062	 0.016114	 1.476	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27811	 84644	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27811	 84644	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27811	 84644	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84645	 27811	 0.000149	 0.01193	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 0	 -30.0	 30.0;
	84645	 27811	 0.000149	 0.01193	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 0	 -30.0	 30.0;
	27812	 28820	 1e-05	 0.000115	 0.0086	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27812	 84646	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27812	 84646	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27813	 31215	 0.000568	 0.005738	 0.01302	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27813	 31215	 0.000568	 0.005738	 0.01302	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27813	 31522	 0.000245	 0.00284	 0.01009	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27813	 84647	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27813	 84647	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84648	 27813	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84648	 27813	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27814	 28178	 0.000794	 0.010276	 0.6569	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27814	 30713	 0.000413	 0.005155	 0.35337	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27814	 84649	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27814	 84649	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84650	 27814	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84650	 27814	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27815	 29434	 3.9e-05	 0.000503	 0.03289	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27815	 29867	 0.000536	 0.006925	 0.44228	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27815	 84651	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27815	 84651	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84652	 27815	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84652	 27815	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27816	 28788	 0.000452	 0.010934	 1.057	 3786.0	 3975.3	 4164.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27816	 29338	 0.000568	 0.015765	 1.1868	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27816	 84653	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27816	 84653	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27817	 28145	 0.000291	 0.004934	 0.01743	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27817	 28148	 8e-05	 0.000854	 0.00174	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27817	 28148	 8e-05	 0.000854	 0.00174	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27817	 28151	 0.000151	 0.002265	 0.0053	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27817	 84655	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27817	 84655	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27818	 27840	 6.4e-05	 0.000833	 0.05317	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27818	 31179	 0.000273	 0.003534	 0.22554	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27818	 84656	 0.000324	 0.024331	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27818	 84656	 0.000324	 0.024331	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27819	 29401	 0.005342	 0.035642	 0.06721	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27819	 31589	 0.000161	 0.001962	 0.00403	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27819	 84658	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27819	 84658	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27820	 30914	 0.000199	 0.00155	 0.00555	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27820	 84659	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27820	 84659	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84660	 27820	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84660	 27820	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27821	 28329	 0.000322	 0.007659	 0.62372	 2811.0	 2951.5	 3092.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27821	 31178	 0.000303	 0.003785	 0.25938	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27821	 31179	 0.000361	 0.004507	 0.30894	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27821	 84661	 9.1e-05	 0.007299	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27821	 84661	 9.1e-05	 0.007299	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84662	 27821	 0.00018	 0.014416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84662	 27821	 0.00018	 0.014416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27822	 28820	 1.4e-05	 0.000257	 0.02251	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27822	 28963	 0.000115	 0.001912	 0.12492	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27822	 84663	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27822	 84663	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27823	 27903	 0.000535	 0.002409	 0.00064	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27823	 28822	 0.000856	 0.005515	 0.00145	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27823	 85084	 0.001529	 0.01494	 0.00419	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27823	 85095	 0.002348	 0.009401	 0.00237	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27824	 28042	 0.003736	 0.020729	 0.0063	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27824	 28057	 0.000885	 0.010785	 0.00356	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27824	 28058	 0.004101	 0.020605	 0.00536	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27824	 28059	 0.00941	 0.041232	 0.01419	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27824	 28062	 0.002334	 0.009877	 0.00222	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27824	 28071	 0.004475	 0.028827	 0.00756	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27824	 84664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27824	 84664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27825	 29511	 0.003623	 0.023521	 0.04686	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27825	 31814	 0.000867	 0.00578	 0.01089	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27825	 84665	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27825	 84665	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84666	 27825	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84666	 27825	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27826	 29246	 0.000956	 0.006378	 0.01202	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27826	 29479	 0.001316	 0.012956	 0.02761	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27826	 31397	 0.000778	 0.008301	 0.01688	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27826	 31397	 0.000778	 0.008301	 0.01688	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27826	 31401	 0.00049	 0.005687	 0.02021	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27826	 84667	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27826	 84667	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84668	 27826	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84668	 27826	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27827	 30856	 0.001577	 0.014456	 0.05707	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27827	 84669	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27827	 84669	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27828	 29017	 0.005374	 0.022189	 0.00525	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27828	 31832	 0.002773	 0.010899	 0.00285	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27828	 31833	 0.000677	 0.005403	 0.00133	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27828	 84670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27828	 84670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27829	 28780	 0.003707	 0.039288	 0.01166	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27829	 28781	 0.001287	 0.01198	 0.00371	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27829	 28787	 0.002503	 0.03529	 0.01207	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27830	 27859	 7e-06	 8.7e-05	 0.00655	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27830	 31720	 0.000144	 0.001857	 0.11851	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27830	 84671	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27830	 84671	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27831	 28788	 0.001292	 0.023252	 1.6663	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27831	 29790	 6e-05	 0.000771	 0.04919	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27831	 30570	 0.001667	 0.028785	 2.2775	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27831	 84672	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27831	 84672	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27832	 28146	 0.000268	 0.004205	 0.00893	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27832	 28154	 0.000379	 0.002555	 0.0047	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27832	 28162	 0.000828	 0.007883	 0.014	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27832	 84674	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27832	 84674	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84675	 27832	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84675	 27832	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27833	 29084	 0.006343	 0.03779	 0.00994	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27833	 31719	 0.002922	 0.021892	 0.00534	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27833	 84676	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27833	 84676	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27833	 84705	 0.00278	 0.012963	 0.00321	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27834	 27848	 0.000166	 0.002074	 0.14211	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27834	 31720	 3.1e-05	 0.000387	 0.02651	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27834	 84677	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27834	 84677	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27835	 27850	 1.5e-05	 0.000184	 0.0006	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27835	 84678	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27835	 84678	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84679	 27835	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84679	 27835	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27836	 29223	 2.2e-05	 0.000616	 0.04616	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27836	 29430	 3.3e-05	 0.000594	 0.04213	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27836	 84680	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27836	 84680	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84681	 27836	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84681	 27836	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27837	 28730	 0.000556	 0.009288	 0.60748	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27837	 29589	 3.5e-05	 0.000458	 0.02922	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27837	 29601	 0.000122	 0.00146	 0.10951	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27837	 84682	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27837	 84682	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84683	 27837	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84683	 27837	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27838	 27855	 5.3e-05	 0.00089	 0.08653	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27838	 31950	 2e-05	 0.000527	 0.04341	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27838	 84684	 0.000182	 0.014599	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27838	 84684	 0.000182	 0.014599	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84685	 27838	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84685	 27838	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27839	 29434	 0.000295	 0.003807	 0.24301	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27839	 29911	 0.000161	 0.002301	 0.15895	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27839	 31720	 0.000489	 0.006107	 0.4187	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27839	 31929	 0.000764	 0.009128	 0.68575	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27839	 84686	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27839	 84686	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27840	 29514	 0.000784	 0.010905	 0.69704	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27840	 31178	 0.000361	 0.007138	 0.58134	 2840.0	 2982.0	 3124.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27840	 31179	 0.000272	 0.003521	 0.22475	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27840	 84689	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27840	 84689	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84690	 27840	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84690	 27840	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27841	 30522	 4.7e-05	 0.00124	 0.10212	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27841	 30524	 0.000389	 0.006493	 0.42441	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27841	 84691	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27841	 84691	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27842	 28476	 2.8e-05	 0.000328	 0.02464	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27842	 28520	 9.7e-05	 0.001153	 0.08645	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27842	 84694	 0.000229	 0.017175	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27842	 84694	 0.000229	 0.017175	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27843	 28791	 0.000219	 0.00216	 0.0046	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27843	 84697	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27843	 84697	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84698	 27843	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84698	 27843	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27844	 28842	 0.001021	 0.012333	 0.02386	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27844	 28962	 0.000595	 0.006229	 0.01172	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27844	 84699	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27844	 84699	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84700	 27844	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84700	 27844	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27845	 29594	 0.001215	 0.015198	 1.0455	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27845	 31720	 0.00031	 0.004011	 0.25602	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27845	 84701	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27845	 84701	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27846	 31941	 0.00226	 0.016507	 0.00424	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27846	 31968	 0.006887	 0.052774	 0.01414	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27846	 32151	 0.000916	 0.00659	 0.00175	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27846	 32160	 0.000626	 0.004429	 0.00122	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27847	 31271	 8.8e-05	 0.001089	 0.00218	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27847	 84703	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27847	 84703	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27848	 29440	 0.000281	 0.003328	 0.25308	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27848	 30520	 0.001992	 0.036018	 3.2555	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27848	 84704	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27848	 84704	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84705	 27848	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84705	 27848	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27849	 28088	 0.00201	 0.025595	 0.0484	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27849	 28112	 0.000651	 0.006848	 0.02968	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27849	 28127	 0.001259	 0.01158	 0.02204	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27849	 84706	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27849	 84706	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27850	 27854	 8e-06	 6.8e-05	 0.00015	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27850	 31690	 0.002035	 0.013731	 0.02528	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27850	 84707	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27850	 84707	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27851	 29103	 0.002512	 0.009094	 0.00195	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27851	 84708	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27851	 84708	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27851	 85187	 0.001868	 0.007478	 0.00188	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27852	 30544	 0.000121	 0.000947	 0.00043	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27853	 30676	 0.001862	 0.007317	 0.00191	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27853	 30776	 0.001156	 0.004705	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27853	 30784	 0.001591	 0.008423	 0.00213	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27854	 31591	 0.00051	 0.005288	 0.01015	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27854	 84709	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27854	 84709	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27855	 28133	 0.000425	 0.007596	 0.53962	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27855	 84710	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27855	 84710	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27856	 27862	 1.8e-05	 0.000325	 0.0231	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27856	 31720	 0.000668	 0.010772	 0.75762	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27856	 84713	 0.000324	 0.024331	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27856	 84713	 0.000324	 0.024331	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27857	 28979	 0.000501	 0.007554	 0.02713	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27857	 31834	 0.000532	 0.004224	 0.00813	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27857	 36286	 0.007032	 0.057291	 0.18821	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27857	 84716	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27857	 84716	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84717	 27857	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84717	 27857	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27858	 29030	 0.00315	 0.014038	 0.00381	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27858	 84718	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27858	 84718	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27859	 29440	 0.000239	 0.002851	 0.21388	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27859	 84719	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27859	 84719	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27860	 31732	 0.000373	 0.005226	 0.01002	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27860	 31733	 0.000514	 0.005549	 0.01101	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27860	 31733	 0.000514	 0.005549	 0.01101	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84710	 27860	 0.005525	 0.077602	 0.14922	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27860	 84722	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27860	 84722	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84723	 27860	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84723	 27860	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27861	 29393	 0.017789	 0.062007	 0.01438	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27861	 31702	 0.003129	 0.012734	 0.0031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84705	 27861	 0.003254	 0.016952	 0.00445	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27861	 85966	 0.003341	 0.020762	 0.00586	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27862	 30713	 0.000371	 0.005983	 0.42022	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27862	 84724	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27862	 84724	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84725	 27862	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84725	 27862	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27863	 28178	 0.000433	 0.006678	 0.51419	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27863	 28241	 9.2e-05	 0.001568	 0.12205	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27863	 84726	 0.000278	 0.020855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27863	 84726	 0.000278	 0.020855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27864	 30280	 0.003005	 0.013786	 0.00353	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27864	 30284	 0.000474	 0.001802	 0.0005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27864	 30286	 0.001797	 0.00475	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27864	 84729	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27864	 84729	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27865	 30617	 0.007724	 0.050545	 0.09929	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84641	 27865	 0.013436	 0.089835	 0.16995	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27865	 84730	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27865	 84730	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84731	 27865	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84731	 27865	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27866	 30792	 0.001998	 0.008132	 0.00198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27866	 30794	 0.004463	 0.01787	 0.0045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27866	 30796	 0.002573	 0.01293	 0.00336	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27867	 28330	 0.000559	 0.003625	 0.00722	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27867	 31009	 0.004283	 0.028571	 0.05387	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84641	 27867	 0.008201	 0.075462	 0.29952	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27867	 84732	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27867	 84732	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27868	 28515	 0.000527	 0.003137	 0.00083	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84695	 27868	 1e-05	 5.6e-05	 2e-05	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27868	 84733	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27868	 84733	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27868	 84999	 0.00086	 0.005447	 0.00148	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27869	 31189	 0.001892	 0.010055	 0.00233	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84642	 27869	 0.035541	 0.16324	 0.04189	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27869	 84734	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27869	 84734	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27870	 29080	 0.004879	 0.037798	 0.01324	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27870	 32047	 0.003689	 0.032186	 0.00884	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27870	 32049	 0.004564	 0.033333	 0.00857	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27870	 32050	 0.00744	 0.047927	 0.01256	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27870	 33683	 0.011716	 0.11034	 0.03345	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27870	 84735	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27870	 84735	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27871	 30415	 0.005509	 0.01314	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27871	 30421	 0.000787	 0.002687	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27871	 30424	 0.00763	 0.019404	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27872	 29490	 0.000212	 0.001463	 0.00258	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27872	 29495	 0.000272	 0.001835	 0.00338	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27872	 84736	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27872	 84736	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27873	 31300	 0.00128	 0.018484	 0.00587	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27873	 31303	 0.000205	 0.002216	 0.00063	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27873	 31305	 0.002825	 0.013177	 0.00326	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27873	 84737	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27873	 84737	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27874	 31340	 0.001732	 0.005942	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27874	 31567	 0.000634	 0.002136	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27874	 84738	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27874	 84738	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27875	 30836	 0.000624	 0.002175	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27875	 30852	 0.003666	 0.015135	 0.00358	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27875	 84739	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27875	 84739	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27876	 31702	 0.000934	 0.00374	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27876	 31703	 0.0005	 0.003001	 0.00091	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27876	 84740	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27876	 84740	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27877	 29704	 0.089912	 0.23402	 0.05697	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27877	 84741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27877	 84741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27877	 85024	 0.048561	 0.19475	 0.04918	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27877	 85833	 0.006896	 0.035882	 0.01057	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27878	 31615	 0.001011	 0.005874	 0.00138	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27878	 31617	 0.000736	 0.005293	 0.0014	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27878	 84742	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27878	 84742	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27879	 29062	 0.002418	 0.019302	 0.00476	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27879	 29523	 0.006007	 0.017711	 0.00412	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27880	 29941	 0.003727	 0.054344	 0.13446	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27880	 29952	 0.00193	 0.030715	 0.12384	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27880	 84743	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27880	 84743	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84744	 27880	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84744	 27880	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27880	 84876	 0.000199	 0.00206	 0.00444	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27880	 84876	 0.000199	 0.00206	 0.00444	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27881	 29538	 0.003339	 0.017695	 0.00591	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27881	 84745	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27881	 84745	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27882	 29841	 0.006242	 0.01312	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27882	 29862	 0.002733	 0.012179	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27883	 31595	 0.000535	 0.002455	 0.00063	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27883	 31596	 0.001396	 0.007693	 0.0018	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27884	 29526	 0.097571	 0.55516	 0.01006	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27884	 32053	 0.1007	 0.16796	 0.00244	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27884	 85081	 0.1376	 0.61384	 0.01044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27884	 86098	 0.010518	 0.059788	 0.00108	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27885	 30556	 0.000386	 0.002629	 0.0009	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27886	 29063	 0.078925	 0.26968	 0.00587	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27886	 85352	 0.17768	 0.37364	 0.00681	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27886	 85355	 0.02606	 0.078438	 0.00153	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27887	 28026	 0.01037	 0.016552	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27887	 28033	 0.006341	 0.015015	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27887	 28035	 0.002829	 0.010885	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27887	 28036	 0.020291	 0.016058	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27887	 28037	 0.00179	 0.004951	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27888	 28244	 0.003048	 0.046574	 0.015	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84727	 27888	 2e-06	 2.9e-05	 1e-05	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27888	 84945	 0.001515	 0.024373	 0.00796	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27889	 29252	 0.003821	 0.015906	 0.00496	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27889	 31325	 0.001315	 0.00707	 0.00174	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27889	 84746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27889	 84746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27890	 29029	 0.021474	 0.060938	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27890	 29031	 0.000681	 0.003869	 7e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27890	 85164	 0.007215	 0.044355	 0.0008	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27891	 30338	 0.001061	 0.003177	 0.00072	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27891	 30343	 0.00221	 0.005842	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27891	 84747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27891	 84747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27892	 29163	 0.00882	 0.022673	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27892	 85212	 0.013994	 0.032149	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27893	 31604	 0.079595	 0.1885	 0.00345	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27893	 85973	 0.010243	 0.039847	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27894	 29430	 3.5e-05	 0.000458	 0.02923	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27894	 29434	 5.8e-05	 0.000723	 0.04953	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27894	 84748	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27894	 84748	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27895	 28400	 0.000161	 0.001921	 0.14409	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27895	 28520	 3.4e-05	 0.000443	 0.02824	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27895	 84749	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27895	 84749	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84750	 27895	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 0	 -30.0	 30.0;
	84750	 27895	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 0	 -30.0	 30.0;
	27896	 29142	 0.001706	 0.004509	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27896	 29147	 0.010248	 0.026605	 0.00646	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27896	 29153	 0.009933	 0.049909	 0.01299	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27896	 84751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27896	 84751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27897	 31487	 0.002956	 0.020511	 0.00585	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27897	 31496	 0.002182	 0.008294	 0.00232	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27898	 29394	 0.003297	 0.021558	 0.00798	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27898	 84752	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27898	 84752	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27898	 85972	 0.007883	 0.030982	 0.00811	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27899	 85980	 0.001573	 0.007445	 0.00179	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27900	 30993	 0.000768	 0.003523	 0.0009	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84642	 27900	 0.034816	 0.1983	 0.05756	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27900	 84753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27900	 84753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27901	 29110	 0.000978	 0.014286	 0.00887	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27901	 29319	 0.013603	 0.084441	 0.02046	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27901	 31239	 0.001174	 0.008306	 0.00228	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84703	 27901	 3.5e-05	 0.000336	 0.00016	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27902	 32174	 0.00348	 0.025782	 0.01321	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27902	 32175	 0.000391	 0.003365	 0.00195	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27902	 84754	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27902	 84754	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27903	 28914	 0.001765	 0.011841	 0.00286	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27903	 85094	 0.001656	 0.013307	 0.00374	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27904	 29375	 0.02395	 0.026342	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27904	 85291	 0.002688	 0.005501	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27905	 29081	 0.022794	 0.058594	 0.00091	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27906	 31389	 0.00427	 0.014245	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27906	 31398	 0.003239	 0.019915	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27906	 85888	 0.003337	 0.01897	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27907	 28779	 0.059736	 0.10942	 0.00189	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27907	 29083	 0.079371	 0.18429	 0.00274	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27907	 85078	 0.041461	 0.11766	 0.00185	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27908	 32116	 0.013538	 0.066062	 0.00114	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27908	 86118	 0.011868	 0.022067	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27909	 29393	 0.013641	 0.051856	 0.01452	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27909	 31594	 0.002289	 0.015714	 0.00458	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84658	 27909	 2.5e-05	 0.000112	 3e-05	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27909	 84755	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27909	 84755	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27910	 85233	 0.00495	 0.010569	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27911	 30536	 0.011608	 0.017783	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27911	 30537	 0.000421	 0.000826	 1e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27912	 29079	 0.016517	 0.073602	 0.00125	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27912	 29081	 0.031293	 0.1095	 0.00227	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27912	 32995	 0.065272	 0.27913	 0.00631	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27912	 85074	 0.089944	 0.35003	 0.00585	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27913	 28110	 0.006746	 0.012355	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27914	 29687	 0.000986	 0.005666	 0.0016	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27914	 84756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27914	 84756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27914	 85414	 0.001341	 0.00713	 0.00165	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27915	 32302	 0.001572	 0.027108	 2.1407	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27915	 33017	 0.001049	 0.014108	 0.96968	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27915	 34147	 0.001143	 0.021274	 1.4152	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27915	 34244	 0.00026	 0.004138	 0.4793	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27915	 84757	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27915	 84757	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84758	 27915	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 0	 -30.0	 30.0;
	84758	 27915	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 0	 -30.0	 30.0;
	27916	 27926	 7e-06	 0.000134	 0.00965	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27916	 33252	 0.000413	 0.007668	 0.60723	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27916	 84759	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27916	 84759	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27917	 32302	 0.000162	 0.003998	 0.47619	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27917	 33724	 5.4e-05	 0.000999	 0.06597	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27917	 84762	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27917	 84762	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84763	 27917	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84763	 27917	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27918	 28860	 0.001046	 0.027905	 2.3368	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27918	 34025	 5.3e-05	 0.001253	 0.10144	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27918	 34025	 5.3e-05	 0.001253	 0.10144	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27918	 84764	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27918	 84764	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27918	 84764	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27919	 27940	 0.000509	 0.006582	 0.42032	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27919	 32817	 0.00034	 0.00897	 0.74021	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27919	 38910	 0.001343	 0.016809	 1.1573	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27919	 84766	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27919	 84766	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27920	 33331	 0.000765	 0.008447	 0.01781	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27920	 33335	 0.000307	 0.001991	 0.00397	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27920	 33336	 0.000678	 0.004621	 0.00832	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27920	 33339	 0.001151	 0.007931	 0.014	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27921	 33003	 0.007416	 0.070843	 0.25998	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84757	 27921	 0.00011	 0.001173	 0.00239	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84757	 27921	 0.00011	 0.001173	 0.00239	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27921	 84769	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27921	 84769	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84770	 27921	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84770	 27921	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27922	 33724	 0.000448	 0.008008	 0.56896	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27922	 34147	 0.000296	 0.004981	 0.48462	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27922	 84771	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27922	 84771	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27923	 32649	 0.001048	 0.015679	 0.03668	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27923	 33204	 0.000145	 0.002421	 0.0088	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27923	 84774	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27923	 84774	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84775	 27923	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84775	 27923	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27923	 86310	 0.002974	 0.020182	 0.03675	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27924	 84776	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27924	 84776	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84777	 27924	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84777	 27924	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27924	 84798	 0.0007	 0.008184	 0.02864	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27924	 88540	 0.011381	 0.076935	 0.14203	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27925	 27932	 9e-06	 0.000222	 0.01798	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27925	 34025	 0.000971	 0.017413	 1.2425	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27925	 84778	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27925	 84778	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27926	 27930	 8.6e-05	 0.001114	 0.07111	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27926	 27933	 2e-06	 2.8e-05	 0.00177	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27927	 33003	 0.000424	 0.004238	 0.00876	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27927	 33004	 0.000914	 0.009254	 0.01863	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27927	 84779	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27927	 84779	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27928	 34101	 0.000613	 0.005836	 0.02132	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27928	 84780	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27928	 84780	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84781	 27928	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84781	 27928	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27928	 86704	 0.001874	 0.022213	 0.07566	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27929	 27937	 2.8e-05	 0.000201	 0.00084	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27929	 84782	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27929	 84782	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84783	 27929	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84783	 27929	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27930	 35538	 0.000731	 0.008724	 0.65536	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27930	 84784	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27930	 84784	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84785	 27930	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84785	 27930	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27931	 27950	 7.5e-05	 0.00117	 0.00491	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27931	 27994	 0.000171	 0.002893	 0.01022	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27931	 33705	 0.002116	 0.033752	 0.06933	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27931	 84786	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27931	 84786	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27932	 27989	 2.2e-05	 0.000612	 0.04583	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27932	 32422	 0.000241	 0.005941	 0.43799	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27932	 84787	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27932	 84787	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84788	 27932	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84788	 27932	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27933	 84789	 0.000278	 0.020855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27933	 84789	 0.000278	 0.020855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27934	 33621	 0.007271	 0.068451	 0.02074	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27934	 33992	 0.008266	 0.10404	 0.03226	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27934	 34056	 0.000739	 0.005346	 0.00288	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27934	 34059	 0.002815	 0.014146	 0.00368	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27934	 34060	 0.000238	 0.002435	 0.00145	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27934	 84790	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27934	 84790	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27935	 35735	 0.015764	 0.1079	 0.1953	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84789	 27935	 1e-05	 0.000141	 0.00046	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27935	 84791	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27935	 84791	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84792	 27935	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84792	 27935	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27935	 86427	 0.003195	 0.042492	 0.09086	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27936	 32751	 0.00124	 0.019101	 0.04209	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84784	 27936	 9.3e-05	 0.000698	 0.0027	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84789	 27936	 0.000587	 0.006257	 0.01272	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27936	 84793	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27936	 84793	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27937	 33810	 0.001108	 0.014999	 0.03089	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27937	 34078	 0.0003	 0.003589	 0.00709	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27937	 84794	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27937	 84794	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84795	 27937	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84795	 27937	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27938	 33718	 0.004227	 0.018835	 0.00512	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27938	 34006	 0.020561	 0.15207	 0.04397	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27938	 84796	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27938	 84796	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27939	 34135	 0.000216	 0.002377	 0.00452	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27939	 34135	 0.000216	 0.002377	 0.00452	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27939	 34138	 0.000306	 0.004644	 0.01053	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27939	 84797	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27939	 84797	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27940	 35805	 0.001056	 0.012628	 0.95009	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27940	 84798	 0.000182	 0.014599	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27940	 84798	 0.000182	 0.014599	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84799	 27940	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84799	 27940	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27941	 32478	 0.00355	 0.037881	 0.07708	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27941	 34135	 0.002726	 0.024942	 0.04802	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27941	 84800	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27941	 84800	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27942	 33257	 0.000206	 0.004839	 0.39183	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27942	 84801	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27942	 84801	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27943	 32974	 0.012639	 0.091503	 0.04928	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27943	 33525	 0.010715	 0.069029	 0.0181	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27943	 33861	 0.001837	 0.020317	 0.00609	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27943	 33862	 0.000627	 0.008156	 0.00236	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27943	 33864	 0.008991	 0.04125	 0.01057	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27943	 84803	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27943	 84803	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27944	 32298	 0.001822	 0.021397	 0.01284	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27944	 33727	 0.000906	 0.009605	 0.00285	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27944	 84804	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27944	 84804	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27945	 84805	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27945	 84805	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84806	 27945	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84806	 27945	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27945	 87299	 0.003832	 0.043834	 0.10327	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27945	 87600	 0.004677	 0.031738	 0.05781	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27946	 27947	 0.004116	 0.026068	 0.00708	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27946	 32310	 0.007276	 0.046873	 0.01229	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27946	 32773	 0.011218	 0.14383	 0.043	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27946	 84807	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27946	 84807	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27947	 32309	 0.012034	 0.074795	 0.02112	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27947	 33571	 0.002487	 0.0116	 0.00287	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84772	 27947	 0.046561	 0.1867	 0.04713	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27947	 84808	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27947	 84808	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27948	 32515	 0.000564	 0.005158	 0.00993	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27948	 33707	 0.000608	 0.005969	 0.02047	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27948	 84809	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27948	 84809	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84810	 27948	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84810	 27948	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27949	 33324	 0.001529	 0.017605	 0.06358	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27949	 34101	 0.000688	 0.006516	 0.01168	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27949	 84811	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27949	 84811	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27949	 86704	 0.004863	 0.040616	 0.07058	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27950	 34945	 0.002271	 0.031848	 0.06109	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27950	 84812	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27950	 84812	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84813	 27950	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84813	 27950	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27951	 27953	 0.025783	 0.15376	 0.04051	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27951	 34107	 0.004507	 0.013287	 0.00309	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84779	 27951	 0.043059	 0.22937	 0.05338	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27951	 84814	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27951	 84814	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27952	 33818	 0.003119	 0.040304	 0.0914	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27952	 34521	 0.007888	 0.059513	 0.11089	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27952	 84815	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27952	 84815	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84816	 27952	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84816	 27952	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27953	 30561	 0.039158	 0.14901	 0.04177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27953	 33337	 0.001824	 0.006933	 0.00194	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27954	 33477	 0.071655	 0.18421	 0.00285	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27954	 33879	 0.026374	 0.067798	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27954	 84822	 0.005875	 0.028667	 0.00049	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27954	 86488	 0.020877	 0.064046	 0.00173	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27955	 32462	 0.000704	 0.003535	 0.00092	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27955	 32463	 0.000532	 0.002131	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27956	 32225	 0.008085	 0.050241	 0.01418	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27956	 32237	 0.004189	 0.026027	 0.00735	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27956	 33448	 0.012448	 0.072927	 0.01987	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27956	 86678	 0.000828	 0.008601	 0.00266	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27957	 33095	 0.00207	 0.00547	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84800	 27957	 0.030846	 0.17141	 0.05222	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84809	 27957	 0.048723	 0.17001	 0.03948	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27957	 84817	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27957	 84817	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27958	 33746	 0.004344	 0.010083	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27958	 86592	 0.004107	 0.018301	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27959	 33361	 0.000867	 0.008853	 0.02811	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84771	 27959	 0.001211	 0.01969	 0.03888	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27959	 84818	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27959	 84818	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84819	 27959	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84819	 27959	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27960	 32424	 0.014826	 0.053688	 0.01152	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27960	 32436	 0.001577	 0.011343	 0.00301	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27960	 32439	 0.001038	 0.012273	 0.00349	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27960	 32463	 0.001232	 0.012034	 0.00338	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27961	 29515	 0.017994	 0.061735	 0.01479	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27961	 32992	 0.012863	 0.050047	 0.01337	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27961	 84820	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27961	 84820	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27962	 33718	 0.001531	 0.006129	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27962	 33719	 0.008019	 0.053797	 0.01299	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27962	 84821	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27962	 84821	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27963	 32429	 0.004607	 0.020185	 0.00043	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27963	 32434	 0.004216	 0.027202	 0.00087	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27963	 32435	 0.00773	 0.021383	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27963	 86201	 0.006012	 0.042811	 0.00096	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27964	 32941	 0.063452	 0.16138	 0.00255	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27964	 33701	 0.009337	 0.04505	 0.0008	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27964	 33973	 0.10652	 0.13224	 0.00288	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27964	 86299	 0.13832	 0.3212	 0.00612	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27964	 86652	 0.12554	 0.32548	 0.00616	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27965	 33482	 0.01305	 0.072426	 0.02202	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27965	 34935	 0.008338	 0.051748	 0.01254	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27965	 84822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27965	 84822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27966	 32240	 0.079208	 0.13931	 0.00262	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27966	 32585	 0.030676	 0.12538	 0.00254	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27966	 86157	 0.045493	 0.093102	 0.00229	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27966	 86159	 0.005904	 0.020669	 0.00057	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27966	 86160	 0.008768	 0.059492	 0.00111	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27967	 33321	 0.007432	 0.046182	 0.01304	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27967	 33340	 0.006822	 0.028166	 0.00666	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27967	 33742	 0.005103	 0.027474	 0.00755	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84800	 27967	 5.5e-05	 0.000616	 0.0002	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27968	 33629	 0.013626	 0.065408	 0.00195	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27968	 33636	 0.011552	 0.065	 0.0014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27968	 86540	 0.031482	 0.060996	 0.00131	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27969	 34043	 0.004842	 0.019385	 0.00488	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27970	 32288	 0.003929	 0.030626	 0.00057	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27970	 32308	 0.00645	 0.036665	 0.00066	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27970	 86169	 0.013103	 0.066284	 0.00115	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27971	 32358	 0.00435	 0.015159	 0.00351	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27971	 86187	 0.000595	 0.002004	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27972	 33793	 0.001983	 0.007939	 0.002	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27972	 33795	 0.000718	 0.002151	 0.00048	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27972	 84823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27972	 84823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27973	 33916	 0.002137	 0.013261	 0.00321	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27973	 33926	 0.003156	 0.014938	 0.00359	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84811	 27973	 0.036412	 0.20965	 0.05957	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27973	 84824	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27973	 84824	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27973	 84836	 0.033181	 0.22305	 0.054	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27974	 32439	 0.004954	 0.041213	 0.01248	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27974	 33002	 0.001045	 0.006272	 0.0019	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27975	 33966	 0.028294	 0.065678	 0.00125	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27975	 34949	 0.038546	 0.11825	 0.0032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84822	 27975	 0.011107	 0.034109	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27975	 86488	 0.013342	 0.065139	 0.00137	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27976	 32209	 0.007154	 0.014639	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27976	 32210	 0.11754	 0.08497	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27976	 32215	 0.03909	 0.10049	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27977	 33024	 0.021023	 0.060298	 0.00093	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27977	 34054	 0.11758	 0.33375	 0.00525	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27978	 33059	 0.000274	 0.000807	 0.00019	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27979	 86622	 0.011965	 0.021505	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27980	 35216	 0.000126	 0.001937	 0.149	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27980	 84825	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27980	 84825	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84826	 27980	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84826	 27980	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27981	 28007	 0.00011	 0.00146	 0.00312	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27981	 34438	 0.003241	 0.04188	 0.09498	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27981	 34530	 0.001034	 0.011247	 0.02445	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27981	 35024	 0.001487	 0.020908	 0.08675	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27981	 84827	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27981	 84827	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27982	 34668	 0.000256	 0.007078	 0.53086	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27982	 84828	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27982	 84828	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27983	 34296	 0.003858	 0.025733	 0.04851	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27983	 34330	 0.000615	 0.005756	 0.02181	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27983	 84831	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27983	 84831	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84832	 27983	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84832	 27983	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27983	 86855	 0.003901	 0.061281	 0.13032	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27984	 34392	 0.000454	 0.009155	 0.61438	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27984	 34950	 0.000216	 0.002791	 0.17811	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27984	 84833	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27984	 84833	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27985	 34236	 6.7e-05	 0.001584	 0.14262	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27985	 34964	 8.6e-05	 0.002234	 0.20346	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27985	 84836	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27985	 84836	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27986	 34332	 0.003181	 0.022305	 0.03798	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27986	 34333	 0.002673	 0.021919	 0.03949	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27986	 35181	 0.001684	 0.017636	 0.03318	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27986	 84838	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27986	 84838	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84839	 27986	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84839	 27986	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27987	 34392	 0.000419	 0.011302	 0.95085	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27987	 34392	 0.000419	 0.011302	 0.95085	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27987	 34575	 6.9e-05	 0.001064	 0.08183	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27987	 84840	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27987	 84840	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84841	 27987	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84841	 27987	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27988	 28006	 0.000138	 0.001352	 0.00464	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27988	 34533	 0.002061	 0.026943	 0.08727	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27988	 35181	 0.008755	 0.067469	 0.12055	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27988	 84842	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27988	 84842	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84843	 27988	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84843	 27988	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27989	 34249	 0.000233	 0.004903	 0.54201	 3627.0	 3808.3	 3989.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27989	 84844	 0.000365	 0.029198	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27989	 84844	 0.000365	 0.029198	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27990	 34698	 0.003808	 0.010063	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27990	 34828	 0.009277	 0.039266	 0.00884	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27990	 34931	 0.014043	 0.069391	 0.02027	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27990	 84847	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27990	 84847	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27991	 28000	 0.00142	 0.01455	 0.02859	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27991	 34424	 0.000637	 0.00729	 0.01426	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27991	 35117	 0.005906	 0.039408	 0.07432	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27991	 84848	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27991	 84848	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84849	 27991	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84849	 27991	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27992	 34852	 0.000326	 0.002538	 0.0091	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27992	 34958	 0.001972	 0.032066	 0.06334	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27992	 35080	 0.000594	 0.005835	 0.02001	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27992	 84850	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27992	 84850	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27993	 34937	 0.002517	 0.01734	 0.03061	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27993	 34981	 0.001612	 0.019292	 0.0747	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27993	 38801	 0.009407	 0.094183	 0.31661	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27993	 84851	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27993	 84851	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84852	 27993	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84852	 27993	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27994	 34213	 0.002091	 0.032818	 0.06969	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27994	 34230	 0.000708	 0.010523	 0.03901	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27994	 84853	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27994	 84853	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27995	 34881	 0.002031	 0.02012	 0.00616	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27995	 34894	 0.00065	 0.004597	 0.00126	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27995	 84854	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27995	 84854	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27996	 34468	 0.002876	 0.027073	 0.0082	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27996	 34470	 0.006629	 0.052235	 0.01528	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27996	 34497	 0.008333	 0.052787	 0.01433	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27996	 34955	 0.009847	 0.10133	 0.02876	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84836	 27996	 0.016268	 0.12473	 0.03345	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84845	 27996	 0.020204	 0.20287	 0.06776	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27996	 84855	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27996	 84855	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27997	 34730	 0.001335	 0.007822	 0.00213	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27997	 84856	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27997	 84856	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27997	 86908	 0.005501	 0.027827	 0.00775	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27998	 33692	 0.003359	 0.045755	 0.0932	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27998	 34174	 0.000443	 0.004061	 0.01603	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27998	 84857	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27998	 84857	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27999	 34537	 0.003198	 0.022189	 0.00633	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27999	 34553	 0.004128	 0.017042	 0.00403	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27999	 34912	 0.007392	 0.021411	 0.00516	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28000	 34424	 0.001397	 0.009068	 0.01806	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28000	 35242	 0.000607	 0.009072	 0.02122	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28000	 35248	 0.001331	 0.017693	 0.0378	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28000	 84858	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28000	 84858	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28001	 34329	 0.001501	 0.006009	 0.00151	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28001	 34387	 0.000351	 0.003374	 0.00098	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28002	 34212	 0.000595	 0.00571	 0.01282	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28002	 34666	 0.000738	 0.009811	 0.02096	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28002	 84859	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28002	 84859	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84860	 28002	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84860	 28002	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28003	 34761	 0.001748	 0.009634	 0.00225	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28003	 84861	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28003	 84861	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28004	 34981	 0.001082	 0.015215	 0.06312	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84828	 28004	 9.4e-05	 0.00101	 0.002	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84828	 28004	 9.4e-05	 0.00101	 0.002	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28004	 84862	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28004	 84862	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84863	 28004	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84863	 28004	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28005	 34896	 0.003519	 0.027729	 0.00811	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84827	 28005	 0.002219	 0.010181	 0.00261	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28005	 84864	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28005	 84864	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28006	 34478	 0.002008	 0.013036	 0.02597	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28006	 34921	 0.00288	 0.026415	 0.10433	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80904	 28006	 0.005429	 0.065643	 0.12724	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28006	 84865	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28006	 84865	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28007	 34521	 0.004972	 0.067781	 0.13825	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28007	 34840	 0.003753	 0.033938	 0.06694	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28007	 84866	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28007	 84866	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28008	 35220	 0.007736	 0.033225	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28008	 35222	 0.007189	 0.027656	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28008	 87069	 0.007984	 0.018258	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28009	 34420	 0.002306	 0.020119	 0.00553	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28009	 34422	 0.002169	 0.014551	 0.00351	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28009	 34423	 0.001586	 0.006349	 0.0016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28009	 34427	 0.000623	 0.003078	 0.0009	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28009	 35132	 0.013721	 0.068953	 0.01795	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84848	 28009	 0.000844	 0.006104	 0.00328	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28009	 84867	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28009	 84867	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28010	 34786	 0.016357	 0.072886	 0.00124	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28010	 86912	 0.027648	 0.092233	 0.00146	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28011	 32734	 0.002974	 0.020635	 0.00589	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28011	 32735	 0.002994	 0.028744	 0.00836	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28011	 32736	 0.006667	 0.025344	 0.00709	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28011	 34525	 0.004666	 0.037875	 0.01206	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28011	 34911	 0.002603	 0.024239	 0.00751	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28011	 86558	 0.016743	 0.099785	 0.02627	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28012	 34450	 0.046231	 0.085964	 0.00201	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28012	 34920	 0.060346	 0.1235	 0.00304	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28012	 86957	 0.021435	 0.049764	 0.00074	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28013	 35085	 0.001774	 0.011024	 0.00311	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28013	 84868	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28013	 84868	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28014	 34785	 0.011903	 0.047661	 0.01201	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28014	 84869	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28014	 84869	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28015	 34441	 0.008189	 0.024647	 0.00771	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28015	 34795	 0.027432	 0.11332	 0.02683	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28015	 84870	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28015	 84870	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28016	 34801	 0.006595	 0.0191	 0.00461	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28016	 84871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28016	 84871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28017	 35020	 0.000392	 0.001616	 0.00038	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28017	 35021	 0.000683	 0.003881	 0.00112	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28017	 84872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28017	 84872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28018	 34344	 0.000939	 0.005455	 0.00128	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28018	 34414	 0.00081	 0.004496	 0.00137	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28018	 84873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28018	 84873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28019	 34291	 0.002623	 0.016894	 0.00443	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28019	 34299	 0.005206	 0.016273	 0.00471	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28019	 34300	 0.005296	 0.043281	 0.01174	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28020	 34788	 0.008112	 0.018834	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28020	 86912	 0.022829	 0.060508	 0.00153	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84869	 28021	 0.000917	 0.002376	 4e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28022	 34289	 0.000714	 0.006317	 0.02677	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28022	 35201	 0.001061	 0.011111	 0.0209	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28022	 35203	 0.001585	 0.021072	 0.04502	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28022	 84874	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28022	 84874	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28023	 34477	 0.036374	 0.028786	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28023	 34479	 0.01603	 0.037216	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28023	 86817	 0.00507	 0.024741	 0.00043	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28023	 86820	 0.00524	 0.035461	 0.00102	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28024	 34280	 0.000869	 0.00462	 0.00107	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28024	 84875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28024	 84875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28025	 34442	 0.008853	 0.025391	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84870	 28025	 0.000125	 0.000962	 2e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84871	 28025	 0.013853	 0.046212	 0.00073	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28026	 28033	 0.003181	 0.011364	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28026	 28037	 0.021036	 0.016648	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28026	 84878	 0.002413	 0.01291	 0.00039	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28027	 28065	 0.000182	 0.00235	 0.15001	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28027	 28788	 0.000614	 0.010502	 0.81914	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28027	 84876	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28028	 28029	 0.002273	 0.0059	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28028	 28042	 0.000358	 0.003366	 0.00102	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84877	 28028	 0.000938	 0.00486	 0.00119	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84877	 28029	 0.002313	 0.006928	 0.00156	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28029	 84879	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28029	 84879	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28030	 28031	 0.011392	 0.026975	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84878	 28030	 0.004444	 0.013632	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84879	 28030	 0.011357	 0.026093	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28031	 28043	 0.017507	 0.028084	 0.00052	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28032	 28066	 0.009156	 0.042006	 0.01076	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28032	 29921	 0.014994	 0.09308	 0.02256	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84743	 28032	 0.001442	 0.009135	 0.00248	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28032	 84880	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28032	 84880	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28033	 28034	 0.010357	 0.014434	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84880	 28033	 0.005187	 0.038315	 0.0008	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28035	 28045	 0.007267	 0.018682	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84878	 28037	 0.01124	 0.028893	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84877	 28038	 0.001981	 0.006675	 0.00166	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28038	 84881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28038	 84881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28039	 28051	 0.01044	 0.024235	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84881	 28039	 0.014295	 0.022305	 0.00037	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28039	 84882	 0.003947	 0.02026	 0.00038	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28040	 84882	 0.029092	 0.023023	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28040	 84883	 0.012777	 0.020394	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28041	 28042	 0.001008	 0.003921	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28041	 28057	 0.001888	 0.007422	 0.00194	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28041	 84882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28041	 84882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84743	 28042	 0.000525	 0.008327	 0.00527	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84877	 28042	 0.000668	 0.006417	 0.00187	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28044	 28045	 0.010678	 0.008789	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28045	 28046	 0.004209	 0.010447	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28046	 28047	 0.003978	 0.009236	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28047	 28048	 0.003629	 0.007426	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28047	 28081	 0.023809	 0.018842	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28048	 28050	 0.005211	 0.017384	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28049	 28050	 0.004682	 0.012037	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28049	 28052	 0.006411	 0.018388	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28050	 28079	 0.006299	 0.019325	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28050	 28080	 0.016255	 0.041339	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84878	 28050	 0.026599	 0.062987	 0.00115	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28051	 28052	 0.005984	 0.015383	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28051	 28054	 0.007657	 0.017511	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84881	 28051	 0.007709	 0.021324	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28052	 28053	 0.022559	 0.044211	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28053	 28054	 0.004646	 0.016268	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28053	 28060	 0.009152	 0.021244	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28053	 84883	 0.013873	 0.053969	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28053	 84887	 0.054404	 0.059258	 0.00081	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28054	 28077	 0.009447	 0.024284	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28055	 28058	 0.007468	 0.033626	 0.00895	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28055	 28778	 0.009678	 0.044402	 0.01138	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84664	 28056	 0.015904	 0.040884	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28056	 84884	 0.061698	 0.048362	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28057	 84883	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28057	 84883	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28059	 29069	 0.006335	 0.026374	 0.00822	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28060	 28061	 0.006574	 0.029294	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28060	 84887	 0.065653	 0.051957	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84882	 28061	 0.096798	 0.076607	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28061	 84884	 0.005946	 0.028416	 0.00062	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28062	 28071	 0.005698	 0.023188	 0.00565	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28062	 84884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28062	 84884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84879	 28063	 0.01041	 0.022224	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28064	 28695	 0.027027	 0.13189	 0.00228	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84883	 28064	 0.080959	 0.1657	 0.00408	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28064	 84907	 0.026691	 0.14998	 0.00278	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28065	 28131	 0.000155	 0.001999	 0.12756	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28066	 28697	 0.027773	 0.075632	 0.01667	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28066	 84885	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28066	 84885	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28067	 28068	 0.13084	 0.096266	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84880	 28067	 0.13115	 0.10281	 0.00132	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28069	 84887	 0.031978	 0.081326	 0.00129	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28070	 28072	 0.004726	 0.018922	 0.00477	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28070	 28075	 0.00702	 0.028108	 0.00708	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28070	 28076	 0.001895	 0.019799	 0.00544	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28070	 84886	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28070	 84886	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28071	 28072	 0.005558	 0.022617	 0.00551	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28071	 84887	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28071	 84887	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28072	 28075	 0.009056	 0.023935	 0.0056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28072	 29975	 0.016254	 0.12017	 0.03472	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28072	 84888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28072	 84888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28073	 28074	 0.035079	 0.027496	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28073	 28077	 0.008394	 0.016619	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28075	 29822	 0.003152	 0.022294	 0.00612	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28075	 84889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28075	 84889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28076	 29071	 0.002538	 0.023624	 0.00732	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28077	 28078	 0.017407	 0.013776	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84887	 28079	 0.016618	 0.069369	 0.002	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84888	 28079	 0.044976	 0.048988	 0.00067	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84889	 28079	 0.085816	 0.13147	 0.00185	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28079	 85444	 0.11031	 0.28363	 0.00439	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84699	 28082	 0.011146	 0.038236	 0.00916	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28082	 84890	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28082	 84890	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28083	 32057	 0.035006	 0.156	 0.00265	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28083	 85151	 0.049611	 0.19088	 0.00326	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84890	 28084	 0.088915	 0.18199	 0.00448	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84890	 28085	 0.053487	 0.085378	 0.00197	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28086	 32193	 0.064052	 0.15169	 0.00277	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28086	 84891	 0.044228	 0.10115	 0.00247	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84706	 28087	 0.000762	 0.004537	 0.00119	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28087	 84891	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28087	 84891	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28088	 35798	 0.006843	 0.065341	 0.23963	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28088	 84892	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84893	 28088	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28088	 85622	 0.014785	 0.096274	 0.19263	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28089	 28103	 0.005782	 0.023149	 0.00583	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84892	 28089	 0.009632	 0.039772	 0.00941	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28090	 28094	 0.031614	 0.064697	 0.00159	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28090	 29076	 0.095846	 0.24642	 0.00381	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28090	 84895	 0.031119	 0.10381	 0.00165	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28091	 84894	 0.2082	 0.1475	 0.00233	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28092	 84894	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28092	 84894	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28092	 84901	 0.011366	 0.048109	 0.01083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28093	 28099	 0.001616	 0.006576	 0.0016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28093	 84895	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28093	 84895	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28094	 28096	 0.024387	 0.032051	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84895	 28094	 0.009832	 0.02012	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28095	 28096	 0.007339	 0.017039	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84895	 28095	 0.008245	 0.022524	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84894	 28096	 0.023423	 0.080013	 0.00174	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28097	 28098	 0.009343	 0.018498	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28098	 28110	 0.006292	 0.014607	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28098	 84902	 0.014835	 0.045511	 0.00123	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28099	 28100	 0.001546	 0.006075	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28100	 28101	 0.003093	 0.012158	 0.00318	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28100	 84896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28100	 84896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28101	 28103	 0.001331	 0.006208	 0.00154	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28101	 84897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28101	 84897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28102	 28107	 0.034914	 0.045887	 0.00063	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84897	 28102	 0.010106	 0.02598	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28103	 28104	 0.001185	 0.006505	 0.00172	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84706	 28104	 0.001171	 0.011838	 0.00348	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28104	 84898	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28104	 84898	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28105	 28108	 0.004163	 0.015143	 0.00464	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84706	 28105	 0.001319	 0.01241	 0.00376	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28105	 84899	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28105	 84899	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28106	 28107	 0.009584	 0.01782	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28106	 28115	 0.06704	 0.052549	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28106	 28116	 0.034877	 0.034979	 0.00057	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84899	 28106	 0.00422	 0.021946	 0.00048	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28107	 28113	 0.027292	 0.027565	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28107	 84902	 0.009617	 0.024722	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28108	 84900	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28108	 84900	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28108	 84901	 0.000797	 0.00387	 0.00088	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28109	 28110	 0.00361	 0.013887	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28109	 28111	 0.010942	 0.017465	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84896	 28109	 0.011164	 0.022103	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84900	 28109	 0.003532	 0.016398	 0.00045	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84900	 28111	 0.011844	 0.028047	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28112	 84901	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84902	 28112	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28113	 28114	 0.017132	 0.017304	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28113	 28122	 0.10565	 0.077731	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84902	 28113	 0.003355	 0.014951	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28114	 28115	 0.01625	 0.017873	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28115	 28116	 0.007992	 0.015662	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28115	 28117	 0.056191	 0.044469	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28115	 28118	 0.091419	 0.064759	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28115	 28123	 0.041049	 0.041461	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84891	 28116	 0.039165	 0.10068	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28117	 28118	 0.013381	 0.025625	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28118	 28119	 0.006561	 0.016865	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28118	 28128	 0.009806	 0.022244	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28118	 84905	 0.009235	 0.035926	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28119	 28120	 0.015742	 0.01138	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28119	 28121	 0.031215	 0.022565	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28121	 28123	 0.051237	 0.040162	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28124	 28125	 0.004639	 0.01263	 0.00278	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28124	 30607	 0.0471	 0.12832	 0.02829	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28124	 32186	 0.013529	 0.034779	 0.00861	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84706	 28124	 0.014832	 0.058302	 0.01526	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28125	 84903	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28125	 84903	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28125	 84904	 0.009914	 0.026202	 0.00613	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84903	 28126	 0.058154	 0.046022	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28126	 84905	 0.086374	 0.068356	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28127	 30581	 0.010399	 0.068572	 0.13297	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28127	 84904	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84905	 28127	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84905	 28128	 0.009521	 0.024476	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28129	 28130	 0.045986	 0.098548	 0.00173	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28129	 28698	 0.01581	 0.080447	 0.00182	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28129	 84907	 0.021522	 0.1308	 0.00241	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28130	 32057	 0.024973	 0.12633	 0.0022	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28130	 84907	 0.013419	 0.10337	 0.00198	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28131	 84906	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28132	 28674	 0.047433	 0.11011	 0.0021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28133	 28241	 0.000142	 0.002631	 0.17373	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28133	 32120	 0.000179	 0.00223	 0.15278	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28133	 84908	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28133	 84908	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28134	 28136	 0.020856	 0.063982	 0.00173	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28134	 28136	 0.020856	 0.063982	 0.00173	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84908	 28134	 0.006047	 0.018551	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84908	 28134	 0.006047	 0.018551	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28135	 28138	 0.000207	 0.001428	 0.00252	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28135	 28229	 0.000585	 0.005015	 0.00954	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28135	 84909	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84910	 28135	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84910	 28136	 0.004457	 0.027401	 0.00049	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28136	 84912	 0.016415	 0.038109	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28137	 28140	 0.001279	 0.005025	 0.00131	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84909	 28137	 0.001013	 0.007163	 0.00197	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28137	 84911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28137	 84911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28137	 84945	 0.002735	 0.010751	 0.00281	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28138	 28139	 0.000262	 0.002823	 0.0056	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28138	 28139	 0.000262	 0.002823	 0.0056	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28138	 84912	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28138	 84912	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28138	 86120	 0.001216	 0.018606	 0.06499	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28139	 28143	 0.000211	 0.002328	 0.00442	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28139	 28143	 0.000211	 0.002328	 0.00442	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28140	 84945	 0.001476	 0.00591	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28141	 28142	 0.001959	 0.014555	 0.00035	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28141	 84946	 0.001486	 0.012363	 0.00023	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28142	 28144	 0.002157	 0.020082	 0.00039	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28143	 28145	 0.000542	 0.005619	 0.0121	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28143	 28145	 0.000542	 0.005619	 0.0121	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28144	 84913	 0.003226	 0.027398	 0.00064	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84726	 28145	 0.000248	 0.003612	 0.00892	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28145	 84913	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28145	 84913	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28146	 28149	 0.000395	 0.00357	 0.00704	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28146	 28151	 0.000421	 0.004488	 0.00913	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28147	 84915	 0.013023	 0.021631	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84726	 28148	 0.000173	 0.001938	 0.00358	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84726	 28148	 0.000173	 0.001938	 0.00358	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28149	 28151	 0.000311	 0.003058	 0.00652	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28149	 84914	 0.003027	 0.10896	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28149	 84914	 0.003027	 0.10896	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84655	 28150	 0.004728	 0.022696	 0.00068	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84728	 28150	 0.005202	 0.015959	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84728	 28150	 0.005202	 0.015959	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28150	 84915	 0.008131	 0.027773	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28150	 84915	 0.008131	 0.027773	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28151	 84915	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28151	 84915	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28152	 28156	 0.011756	 0.015451	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28153	 28242	 0.000683	 0.003883	 0.00112	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84674	 28153	 0.003079	 0.012099	 0.00317	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84914	 28153	 0.002698	 0.013782	 0.00347	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28153	 84916	 0.001936	 0.006021	 0.00126	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28154	 84916	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84917	 28154	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28155	 28158	 0.015425	 0.043773	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84675	 28155	 0.00201	 0.012045	 0.00029	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84739	 28155	 0.27353	 0.56282	 0.01075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84917	 28155	 0.03023	 0.037985	 0.00057	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28156	 28158	 0.027857	 0.022046	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84917	 28156	 0.014445	 0.037133	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28156	 84921	 0.04528	 0.040574	 0.00083	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28156	 84947	 0.01613	 0.024709	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28157	 28160	 0.000782	 0.005246	 0.00127	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28157	 28161	 0.001174	 0.006876	 0.00187	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28157	 84918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28157	 84918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28158	 28159	 0.021559	 0.027089	 0.00041	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28158	 28243	 0.01791	 0.059745	 0.00095	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84675	 28158	 0.020282	 0.04708	 0.0009	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28159	 84921	 0.030459	 0.022409	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28160	 28171	 0.003647	 0.018974	 0.00559	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28160	 28230	 0.00638	 0.021887	 0.00524	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28160	 84919	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28160	 84919	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28161	 84920	 0.000681	 0.004311	 0.00117	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28162	 84920	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84921	 28162	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28163	 28164	 0.023364	 0.023598	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28164	 28223	 0.016495	 0.037416	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84919	 28164	 0.006223	 0.038257	 0.00069	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28164	 84923	 0.018726	 0.043475	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28165	 28167	 0.013481	 0.026691	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28165	 28169	 0.027018	 0.021178	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28165	 84923	 0.010528	 0.037609	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28166	 28167	 0.025005	 0.018944	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28166	 28173	 0.026484	 0.01876	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28166	 28174	 0.006371	 0.014637	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28166	 28175	 0.010351	 0.026608	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28166	 84922	 0.023102	 0.059387	 0.00092	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28168	 28169	 0.014428	 0.028567	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28168	 84926	 0.010327	 0.024455	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28170	 28171	 0.002155	 0.006701	 0.0014	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28170	 28179	 0.0101	 0.026694	 0.00625	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28170	 84922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28170	 84922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28171	 84923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28171	 84923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28172	 28175	 0.019325	 0.024283	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28172	 28204	 0.018555	 0.047698	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28172	 84927	 0.005096	 0.025781	 0.00045	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28173	 28174	 0.019714	 0.02591	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28174	 28177	 0.005492	 0.011726	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28174	 84926	 0.010703	 0.041638	 0.0007	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28176	 28177	 0.005519	 0.014186	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28176	 84925	 0.010288	 0.036752	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28176	 84926	 0.012805	 0.031342	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28176	 84927	 0.012386	 0.025453	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28178	 28235	 6.8e-05	 0.001133	 0.07397	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28178	 84924	 0.000144	 0.011532	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84924	 28179	 0.00147	 0.006741	 0.00173	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28179	 84926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28179	 84926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28180	 28181	 0.001734	 0.007339	 0.00165	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84642	 28180	 0.082267	 0.23889	 0.0578	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84924	 28180	 0.001553	 0.009835	 0.00267	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28180	 84927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28180	 84927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28181	 84928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28181	 84928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28182	 28185	 0.001212	 0.007217	 0.0019	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28182	 28191	 0.0018	 0.006274	 0.00145	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84642	 28182	 0.066925	 0.23011	 0.05529	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28182	 84929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28182	 84929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28183	 28190	 0.004471	 0.013458	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84928	 28183	 0.007593	 0.025331	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84925	 28184	 0.033457	 0.02166	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84924	 28185	 0.000438	 0.00659	 0.00464	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28185	 84930	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28185	 84930	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28185	 84940	 0.000329	 0.005209	 0.00329	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84927	 28186	 0.022079	 0.038542	 0.0006	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84930	 28186	 0.006806	 0.015802	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28187	 28189	 0.023572	 0.046671	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28187	 28193	 0.040909	 0.03138	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28187	 84941	 0.009925	 0.025242	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28187	 84942	 0.015334	 0.030052	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28188	 28191	 0.002269	 0.006091	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28188	 84931	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28188	 84931	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28189	 28190	 0.008935	 0.025627	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84931	 28189	 0.024969	 0.02522	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28189	 84932	 0.013941	 0.025057	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28189	 84939	 0.09893	 0.14045	 0.00231	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28189	 84941	 0.026597	 0.05443	 0.00134	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84929	 28190	 0.006167	 0.016346	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28190	 84932	 0.032661	 0.05502	 0.00078	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28190	 84941	 0.024046	 0.049209	 0.00121	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28192	 28194	 0.006333	 0.016738	 0.00392	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28192	 84932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28192	 84932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28193	 84941	 0.02583	 0.04731	 0.00082	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28194	 29510	 0.009973	 0.048404	 0.01107	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28194	 84933	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28194	 84933	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28194	 84938	 0.003203	 0.017246	 0.00474	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28195	 28196	 0.024968	 0.052477	 0.00096	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28195	 28197	 0.017639	 0.046752	 0.00119	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84736	 28195	 0.076137	 0.23363	 0.00633	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28195	 85348	 0.049952	 0.08415	 0.0012	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28196	 28200	 0.03666	 0.066148	 0.00096	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28197	 28239	 0.022382	 0.059322	 0.0015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28198	 28199	 0.015341	 0.028524	 0.00067	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28198	 28201	 0.013679	 0.031758	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84932	 28199	 0.01819	 0.04223	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84933	 28200	 0.031338	 0.082843	 0.0015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28201	 28203	 0.00543	 0.02089	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84928	 28201	 0.010892	 0.042371	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28202	 28203	 0.007893	 0.026048	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28202	 28204	 0.007757	 0.017741	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28204	 28205	 0.01139	 0.020552	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28205	 28206	 0.006918	 0.010598	 0.00015	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28206	 28207	 0.011376	 0.017424	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28207	 28209	 0.01046	 0.026888	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28208	 28209	 0.019875	 0.012867	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28209	 28210	 0.038383	 0.042217	 0.00056	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84922	 28209	 0.025648	 0.065932	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28210	 28223	 0.031295	 0.061334	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28211	 28212	 0.00301	 0.00596	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28211	 28213	 0.022802	 0.041142	 0.00059	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84918	 28212	 0.033297	 0.075529	 0.00151	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28213	 28214	 0.005049	 0.013794	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28213	 28222	 0.018838	 0.03855	 0.00095	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28214	 28215	 0.009177	 0.023339	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28215	 28216	 0.019921	 0.021224	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28215	 28218	 0.041844	 0.042263	 0.00056	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28216	 28217	 0.014728	 0.011656	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28217	 28218	 0.024297	 0.017876	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28218	 84934	 0.00459	 0.010656	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28219	 28220	 0.00184	 0.015035	 0.00408	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28219	 28244	 0.003068	 0.021701	 0.00595	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28219	 84934	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28219	 84934	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28220	 28225	 0.000786	 0.005609	 0.00174	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28220	 84935	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28220	 84935	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28221	 28226	 0.030265	 0.02293	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28222	 28243	 0.011024	 0.026293	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28224	 28226	 0.004008	 0.010624	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28224	 84947	 0.007742	 0.027655	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28225	 28228	 0.000353	 0.002748	 0.00082	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28226	 28243	 0.007589	 0.019509	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84655	 28227	 0.016868	 0.1103	 0.00255	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28228	 28242	 0.000869	 0.007906	 0.002	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28229	 31970	 0.001796	 0.016003	 0.02812	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84674	 28230	 0.002628	 0.022385	 0.00559	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28231	 30865	 0.017076	 0.067128	 0.01757	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28231	 84936	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28231	 84936	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28232	 28235	 6e-05	 0.00072	 0.05401	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28232	 84937	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84938	 28232	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28233	 29513	 0.018418	 0.072405	 0.01895	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28233	 84939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28233	 84939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28233	 84940	 0.005529	 0.021732	 0.00568	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28234	 28237	 0.009022	 0.020945	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84936	 28234	 0.018298	 0.078228	 0.00177	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28234	 84941	 0.009381	 0.021279	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28234	 84942	 0.028998	 0.038111	 0.00052	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28235	 28240	 0.000117	 0.001392	 0.10444	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28235	 84940	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84938	 28236	 0.000507	 0.005467	 0.00187	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84940	 28236	 0.000562	 0.005683	 0.00167	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28236	 84942	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28236	 84942	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28237	 28238	 0.004484	 0.0157	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84925	 28237	 0.007821	 0.064947	 0.00159	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84941	 28237	 0.023463	 0.046454	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84936	 28238	 0.007143	 0.049027	 0.00089	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84939	 28238	 0.014349	 0.05693	 0.00163	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28239	 84944	 0.003525	 0.01878	 0.00033	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28240	 29488	 0.000449	 0.005806	 0.37069	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28240	 84943	 0.000118	 0.009419	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28241	 84945	 0.000216	 0.017299	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84916	 28242	 0.001378	 0.008211	 0.00216	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28242	 84947	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28242	 84947	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84935	 28243	 0.022428	 0.052069	 0.00077	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28245	 28246	 0.00711	 0.016507	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28245	 28275	 0.011987	 0.021629	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28245	 28277	 0.004455	 0.009116	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28246	 28247	 0.003211	 0.006571	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28246	 28248	 0.016528	 0.01308	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28246	 84948	 0.011968	 0.027781	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28247	 31102	 0.007377	 0.015749	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28248	 28251	 0.002776	 0.006572	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28249	 84948	 0.016783	 0.013282	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28250	 28257	 0.002555	 0.01112	 0.00317	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28250	 84948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28250	 84948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84948	 28251	 0.004885	 0.012557	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28252	 28253	 0.01456	 0.02617	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28252	 31109	 0.005741	 0.014757	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84948	 28252	 0.005362	 0.012698	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28253	 28256	 0.021455	 0.015785	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28253	 31116	 0.003474	 0.008226	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28253	 84949	 0.007481	 0.021457	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28254	 28255	 0.00088	 0.003522	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28254	 28258	 0.001195	 0.007416	 0.0018	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84659	 28254	 0.021005	 0.12712	 0.03247	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28254	 84949	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28254	 84949	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28255	 28258	 0.000838	 0.004089	 0.00113	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28255	 84950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28255	 84950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28256	 28259	 0.005019	 0.015414	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84948	 28256	 0.006291	 0.016631	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28257	 28268	 0.001281	 0.007032	 0.00186	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84732	 28257	 0.000296	 0.002248	 0.00071	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28257	 84951	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28257	 84951	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28257	 84967	 0.00121	 0.007442	 0.00215	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84732	 28258	 0.000414	 0.002625	 0.00071	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28259	 28273	 0.006592	 0.016945	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84950	 28259	 0.006561	 0.021888	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84951	 28259	 0.003047	 0.018732	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28260	 28270	 0.004728	 0.015772	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28260	 31134	 0.006473	 0.016639	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28260	 31135	 0.003059	 0.007101	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28260	 31136	 0.05941	 0.042083	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84949	 28260	 0.009912	 0.023008	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28261	 31121	 0.01371	 0.046196	 0.01148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28261	 84952	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28261	 84952	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28262	 31129	 0.008655	 0.017136	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28263	 28264	 0.006884	 0.019745	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28263	 28265	 0.013325	 0.01194	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28263	 28266	 0.011354	 0.026886	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28263	 31130	 0.063178	 0.046482	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84952	 28263	 0.043126	 0.031176	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28264	 28271	 0.006079	 0.015627	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28264	 28293	 0.023638	 0.017088	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84952	 28264	 0.023809	 0.037149	 0.00062	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28265	 28290	 0.006396	 0.016441	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28266	 84959	 0.005822	 0.014748	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28267	 28268	 0.000918	 0.004211	 0.00108	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28267	 28292	 0.00132	 0.005286	 0.00133	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28268	 84953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28268	 84953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28269	 28270	 0.011573	 0.017729	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84949	 28270	 0.00658	 0.021713	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84953	 28270	 0.00965	 0.022399	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28271	 28272	 0.00502	 0.012905	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28271	 28293	 0.012215	 0.024185	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28272	 28308	 0.009316	 0.018257	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28273	 28274	 0.004111	 0.010567	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28274	 28275	 0.011812	 0.012614	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28275	 28277	 0.021224	 0.016796	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28275	 84968	 0.008479	 0.052128	 0.00094	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28276	 28277	 0.003509	 0.00902	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28276	 28321	 0.005157	 0.013256	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28277	 28278	 0.01461	 0.011207	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28279	 28292	 0.001891	 0.006847	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28279	 28296	 0.003468	 0.015614	 0.00415	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28279	 84954	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28279	 84954	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28279	 84969	 0.001033	 0.008005	 0.0028	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28280	 28286	 0.000551	 0.002767	 0.00072	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28280	 28396	 0.002481	 0.009751	 0.00255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28280	 84955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28280	 84955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28280	 84969	 0.001477	 0.00966	 0.00246	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84954	 28281	 0.008789	 0.014029	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84955	 28281	 0.008379	 0.015347	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28281	 84956	 0.008941	 0.016069	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28282	 28283	 0.005128	 0.013592	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28282	 28285	 0.014082	 0.016507	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28282	 28297	 0.005861	 0.019553	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28282	 28305	 0.020471	 0.020676	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28282	 28306	 0.00588	 0.011641	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28282	 84959	 0.009403	 0.024172	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28283	 28284	 0.004978	 0.011557	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84954	 28283	 0.00268	 0.016477	 0.0003	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84954	 28284	 0.007922	 0.020363	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28284	 84957	 0.022278	 0.01763	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28285	 84958	 0.004627	 0.010631	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28286	 28287	 0.000385	 0.001765	 0.00045	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28286	 84956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28286	 84956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28287	 28289	 0.000738	 0.003386	 0.00087	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28287	 84957	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28287	 84957	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28288	 28289	 0.000566	 0.001887	 0.00048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28288	 28312	 0.000835	 0.002724	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28289	 28296	 0.004399	 0.011625	 0.00272	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28289	 84958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28289	 84958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28290	 28291	 0.005166	 0.010571	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28290	 28305	 0.015821	 0.017232	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84954	 28290	 0.019869	 0.051074	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28291	 84959	 0.004726	 0.015219	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28292	 84959	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28292	 84959	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28293	 84960	 0.006441	 0.016556	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28294	 28300	 0.035667	 0.026241	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28294	 28308	 0.024337	 0.017593	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28295	 28301	 0.012051	 0.017869	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28295	 28308	 0.026792	 0.020299	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28296	 84960	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28296	 84960	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28297	 28298	 0.004441	 0.011416	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28298	 28299	 0.012825	 0.010149	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28298	 28302	 0.018669	 0.020534	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28300	 28313	 0.011105	 0.025779	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84960	 28300	 0.011377	 0.037953	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28301	 28302	 0.003534	 0.013596	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28301	 28317	 0.016498	 0.026333	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28302	 28304	 0.017724	 0.017728	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84960	 28302	 0.003961	 0.01619	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28303	 28304	 0.018685	 0.014787	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28304	 28314	 0.009688	 0.018986	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28305	 28306	 0.011087	 0.008504	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84960	 28305	 0.007826	 0.013051	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28307	 28308	 0.014958	 0.014452	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84952	 28308	 0.022583	 0.058053	 0.0009	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28309	 28396	 0.00173	 0.008244	 0.00239	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28309	 84961	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28309	 84961	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28310	 28422	 0.004933	 0.008901	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84961	 28310	 0.006142	 0.009804	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28311	 28312	 0.001071	 0.004357	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28311	 84962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28311	 84962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28312	 84963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28312	 84963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28313	 28424	 0.030731	 0.02432	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84962	 28314	 0.006135	 0.012555	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28315	 28316	 0.004674	 0.006142	 8e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84963	 28315	 0.004801	 0.006996	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28316	 28440	 0.009576	 0.010074	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28316	 28441	 0.014636	 0.019236	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84961	 28316	 0.004827	 0.01878	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84962	 28316	 0.005979	 0.017148	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28317	 28318	 0.017116	 0.013545	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28318	 28424	 0.007653	 0.014465	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28318	 28425	 0.009088	 0.022555	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84956	 28319	 0.01348	 0.020445	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84961	 28319	 0.018275	 0.011831	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84955	 28320	 0.007477	 0.016961	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84961	 28320	 0.020439	 0.020644	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28321	 28324	 0.005067	 0.013024	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28321	 28342	 0.010823	 0.01658	 0.00023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28322	 28324	 0.003459	 0.007079	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28322	 28325	 0.01088	 0.021542	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28322	 84964	 0.004513	 0.011601	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28323	 28327	 0.007652	 0.0175	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28323	 28340	 0.008152	 0.016141	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28323	 28343	 0.006448	 0.014626	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28324	 28342	 0.00623	 0.014131	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28324	 28346	 0.026822	 0.032698	 0.00052	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28324	 84964	 0.005065	 0.019705	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84951	 28325	 0.008774	 0.022223	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28325	 84964	 0.004285	 0.008769	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28326	 84964	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28326	 84964	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28326	 84967	 0.00159	 0.006469	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28327	 84968	 0.004115	 0.013728	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28328	 84965	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28328	 84965	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28328	 84967	 0.001672	 0.005735	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28329	 28400	 6.9e-05	 0.001065	 0.08194	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28329	 30909	 0.000693	 0.008658	 0.59397	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28329	 84966	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84966	 28330	 0.00011	 0.001069	 0.00372	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28330	 84969	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84970	 28330	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28330	 84980	 0.000583	 0.00622	 0.01127	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28331	 28334	 0.008002	 0.011152	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28331	 28397	 0.006725	 0.015253	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84970	 28331	 0.008375	 0.021706	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28332	 28333	 0.012784	 0.014061	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84970	 28332	 0.012767	 0.025277	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28333	 28334	 0.004393	 0.007012	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84954	 28333	 0.00393	 0.016405	 0.00047	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84968	 28333	 0.012075	 0.02578	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84970	 28333	 0.003936	 0.012073	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28335	 28396	 0.00412	 0.012512	 0.00274	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84967	 28335	 0.001639	 0.009598	 0.00261	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28335	 84971	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28335	 84971	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84971	 28336	 0.008101	 0.01983	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28337	 28341	 0.003392	 0.011588	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28337	 28344	 0.006925	 0.013711	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28337	 28351	 0.006162	 0.015841	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84971	 28337	 0.012419	 0.025414	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28338	 28353	 0.006278	 0.015966	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84971	 28338	 0.002823	 0.010981	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84971	 28339	 0.010619	 0.01695	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28340	 28341	 0.001613	 0.009169	 0.00017	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84965	 28340	 0.003052	 0.018287	 0.00044	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28342	 28347	 0.012475	 0.009779	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28343	 28346	 0.002896	 0.006723	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28345	 28346	 0.004194	 0.002715	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28348	 28349	 0.004949	 0.01272	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28348	 28358	 0.006603	 0.011868	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28349	 28351	 0.003251	 0.007375	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28350	 28351	 0.009435	 0.009634	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28350	 28354	 0.018964	 0.015008	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28351	 28353	 0.018577	 0.014561	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28352	 28353	 0.005158	 0.010109	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28352	 28354	 0.015007	 0.010848	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28354	 28413	 0.012535	 0.013787	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84971	 28354	 0.012739	 0.033674	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28355	 28356	 0.010959	 0.008673	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28355	 28358	 0.007592	 0.0051	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28356	 28359	 0.022364	 0.016454	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28356	 84987	 0.01063	 0.024674	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28357	 28358	 0.028178	 0.028185	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28357	 28360	 0.007006	 0.009558	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28358	 28359	 0.004944	 0.003745	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28360	 28363	 0.003597	 0.006688	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28361	 28363	 0.009594	 0.01045	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28361	 28420	 0.011551	 0.012582	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28362	 28363	 0.010353	 0.008115	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28363	 28377	 0.003014	 0.013354	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28363	 84987	 0.014739	 0.036584	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28364	 28365	 0.010337	 0.013586	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28364	 28418	 0.005549	 0.015916	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28365	 28375	 0.007229	 0.014168	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28366	 28367	 0.012754	 0.010093	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28366	 84988	 0.006257	 0.012804	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28368	 28369	 0.000935	 0.002622	 0.00067	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28368	 28371	 0.002433	 0.00643	 0.0015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28368	 28417	 0.001128	 0.003678	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28369	 28371	 0.001471	 0.003819	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28369	 84972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28369	 84972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28370	 28371	 0.001745	 0.004612	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28370	 28417	 0.001931	 0.006623	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28370	 28458	 0.000967	 0.003318	 0.00079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28371	 28471	 0.001828	 0.004747	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28371	 84973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28371	 84973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28371	 84999	 0.006049	 0.015704	 0.00381	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28372	 28373	 0.007954	 0.015232	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28372	 28388	 0.025879	 0.016754	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84972	 28372	 0.004019	 0.012096	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28373	 28374	 0.011766	 0.008335	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28373	 28375	 0.004698	 0.013473	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28373	 84974	 0.017348	 0.044594	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28374	 28385	 0.005479	 0.011213	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28376	 28377	 0.003169	 0.010572	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28376	 28378	 0.002848	 0.011082	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28377	 28379	 0.005179	 0.012352	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28378	 28384	 0.004258	 0.009886	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28378	 28385	 0.002034	 0.009432	 0.0002	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28379	 28380	 0.016818	 0.0129	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28379	 28382	 0.004754	 0.018493	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28381	 28382	 0.024646	 0.018673	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28382	 28384	 0.003424	 0.008802	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28382	 84974	 0.001408	 0.008435	 0.0002	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28383	 28393	 0.000272	 0.001791	 0.00347	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84749	 28383	 0.00015	 0.001578	 0.0033	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28383	 84974	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28383	 84974	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28385	 28386	 0.006229	 0.014461	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84974	 28385	 0.007982	 0.026628	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28386	 28387	 0.007115	 0.013626	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28386	 84976	 0.006139	 0.016271	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28388	 28389	 0.023362	 0.016888	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28388	 28392	 0.02467	 0.019524	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28388	 84978	 0.017322	 0.041018	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84973	 28389	 0.006249	 0.012789	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28390	 28391	 0.004029	 0.011555	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28390	 85029	 0.005741	 0.016466	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28391	 28392	 0.009855	 0.016066	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28391	 84998	 0.011268	 0.017262	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28393	 28604	 0.00046	 0.003137	 0.00565	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28393	 84975	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84976	 28393	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28393	 84980	 0.001556	 0.01061	 0.0191	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84749	 28394	 0.000252	 0.001709	 0.00311	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28394	 84977	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84978	 28394	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28395	 28412	 0.004589	 0.011671	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84971	 28395	 0.008075	 0.020758	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28396	 84979	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28396	 84979	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28396	 84981	 0.000572	 0.003321	 0.00078	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28396	 84983	 0.002979	 0.010789	 0.00231	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28397	 28398	 0.004693	 0.011487	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84979	 28398	 0.006485	 0.012418	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28398	 84982	 0.008606	 0.021361	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28399	 28409	 0.000712	 0.003638	 0.00091	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28399	 84981	 0.00059	 0.003514	 0.00092	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28400	 28476	 0.000167	 0.002157	 0.13767	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28400	 84980	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28400	 84980	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84694	 28401	 0.00162	 0.010513	 0.02094	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84980	 28401	 0.000239	 0.002858	 0.00564	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28401	 84983	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84984	 28401	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28402	 28403	 0.001051	 0.003607	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28402	 28407	 0.00033	 0.002049	 0.00058	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84983	 28402	 0.000523	 0.003422	 0.00087	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28403	 28457	 0.000639	 0.003442	 0.00095	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84981	 28403	 0.001752	 0.009721	 0.00295	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84983	 28403	 0.000537	 0.003249	 0.00083	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28403	 84985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28403	 84985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84973	 28404	 0.042594	 0.033387	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84985	 28404	 0.008177	 0.00835	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28405	 28422	 0.002245	 0.007856	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84982	 28405	 0.005989	 0.029955	 0.00053	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28406	 28423	 0.004106	 0.015974	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28406	 28437	 0.004872	 0.014947	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84984	 28406	 0.002298	 0.016603	 0.00031	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28407	 28408	 0.000791	 0.002268	 0.00056	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28407	 28455	 0.000809	 0.002727	 0.00068	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28408	 28452	 0.000692	 0.001985	 0.00049	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28409	 28417	 0.00093	 0.003133	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84983	 28409	 0.001667	 0.004191	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28410	 28417	 0.002103	 0.005459	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84981	 28410	 0.001545	 0.006378	 0.00151	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28410	 84986	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28410	 84986	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28411	 28412	 0.008367	 0.009114	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28411	 84987	 0.007619	 0.010799	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28413	 28414	 0.021213	 0.016627	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28414	 28420	 0.004422	 0.010472	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28414	 84987	 0.004768	 0.01353	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84986	 28415	 0.006627	 0.012138	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84981	 28416	 0.002285	 0.010289	 0.00274	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28416	 84987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28416	 84987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84981	 28417	 0.001987	 0.009982	 0.0026	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28417	 84988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28417	 84988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28418	 28419	 0.015229	 0.011681	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84986	 28418	 0.003566	 0.021926	 0.0004	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28421	 28425	 0.003062	 0.012147	 0.00035	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28421	 28439	 0.007407	 0.013773	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84962	 28421	 0.004443	 0.016272	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28422	 28423	 0.003388	 0.016531	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28423	 28437	 0.008517	 0.013289	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28423	 28439	 0.003085	 0.013672	 0.00041	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28423	 28441	 0.005352	 0.011248	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84949	 28423	 0.089301	 0.16358	 0.00282	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28423	 84993	 0.020595	 0.042325	 0.00081	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28424	 28426	 0.006456	 0.015287	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28424	 28427	 0.011206	 0.028805	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28425	 28427	 0.016698	 0.018365	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28427	 28429	 0.012445	 0.024641	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28427	 28439	 0.005749	 0.01649	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28427	 84995	 0.020115	 0.051709	 0.0008	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28428	 28430	 0.010717	 0.030739	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28428	 28431	 0.005659	 0.014547	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28429	 28450	 0.017881	 0.011576	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28430	 28438	 0.002296	 0.010231	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28430	 84995	 0.014415	 0.037054	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28431	 28432	 0.010916	 0.013067	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28433	 28434	 0.011247	 0.023016	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28433	 28485	 0.012473	 0.034075	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28433	 28605	 0.044953	 0.030196	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28433	 84995	 0.031555	 0.090506	 0.00139	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28434	 28435	 0.022002	 0.023964	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28434	 28460	 0.004734	 0.015793	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28434	 28463	 0.009366	 0.018544	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28435	 28486	 0.034994	 0.027694	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28436	 28437	 0.002137	 0.013139	 0.00024	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28436	 28438	 0.001676	 0.007765	 0.00015	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28437	 84992	 0.003241	 0.00833	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28438	 28443	 0.008318	 0.017825	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28442	 28451	 0.001166	 0.002997	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28442	 28453	 0.000442	 0.002223	 0.00058	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28442	 28459	 0.000585	 0.003221	 0.00116	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28443	 28450	 0.005416	 0.013773	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28443	 84996	 0.006545	 0.016644	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28444	 84990	 0.010472	 0.011518	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28445	 28446	 0.00065	 0.002553	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28445	 28454	 0.000706	 0.002556	 0.00055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28445	 84989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28445	 84989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28446	 28459	 0.000798	 0.002889	 0.00062	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28446	 84990	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28446	 84990	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28447	 28448	 0.009514	 0.007529	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28448	 28450	 0.006719	 0.013303	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28449	 28450	 0.008319	 0.00915	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28449	 28461	 0.012346	 0.013579	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28451	 28452	 0.000723	 0.002016	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28451	 84991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28451	 84991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28453	 28456	 0.000327	 0.00174	 0.00049	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28454	 28455	 0.00066	 0.002263	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28455	 84992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28455	 84992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28456	 28457	 0.000625	 0.002847	 0.0009	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28456	 84993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28456	 84993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28457	 28458	 0.001349	 0.003674	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28458	 28471	 0.001629	 0.004542	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28458	 84994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28458	 84994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28459	 28462	 0.001115	 0.004465	 0.00112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28459	 84995	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28459	 84995	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28459	 84999	 0.004881	 0.019542	 0.00492	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28460	 28461	 0.00303	 0.012384	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28461	 84996	 0.002276	 0.010926	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28462	 28490	 0.011381	 0.033554	 0.00781	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28462	 84996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28462	 84996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28463	 28467	 0.00654	 0.01518	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28464	 28466	 0.002485	 0.014125	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28464	 28467	 0.003981	 0.012213	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28464	 28474	 0.00925	 0.021475	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28465	 28472	 0.009735	 0.019079	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84995	 28465	 0.029217	 0.018915	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84995	 28466	 0.00188	 0.010351	 0.00023	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28467	 28468	 0.01102	 0.008638	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28467	 28474	 0.006268	 0.016111	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28469	 84997	 0.023019	 0.018217	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28470	 28471	 0.001748	 0.004694	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28470	 28475	 0.001711	 0.00477	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84983	 28471	 0.005058	 0.013366	 0.00313	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28471	 84997	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28471	 84997	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28472	 28473	 0.006914	 0.012427	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84995	 28472	 0.029941	 0.037622	 0.00057	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28472	 84998	 0.007179	 0.025646	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28474	 85000	 0.008599	 0.032946	 0.00093	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28475	 84998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28475	 84998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28475	 84999	 0.001121	 0.006027	 0.00148	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28476	 28581	 0.000229	 0.002852	 0.19541	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28476	 84999	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28476	 84999	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84733	 28477	 0.025392	 0.025646	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84999	 28478	 0.001019	 0.005399	 0.0018	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28478	 85000	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28478	 85000	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28479	 28481	 0.009756	 0.016295	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28480	 28483	 0.008518	 0.014979	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28481	 28486	 0.014668	 0.037706	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28481	 28501	 0.013618	 0.031145	 0.00076	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85000	 28481	 0.007548	 0.041562	 0.00094	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28482	 28484	 0.010766	 0.015283	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85000	 28483	 0.008665	 0.022275	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85000	 28484	 0.007146	 0.016923	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28485	 28488	 0.022005	 0.017415	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28486	 28487	 0.042074	 0.031877	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28487	 85002	 0.020247	 0.040087	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28488	 28499	 0.012924	 0.012487	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28489	 28500	 0.005882	 0.014398	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28489	 85001	 0.00347	 0.011577	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28490	 28491	 0.002863	 0.007796	 0.00172	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28490	 85001	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28490	 85001	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28491	 85002	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28491	 85002	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28491	 85024	 0.005168	 0.024414	 0.00781	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28492	 28566	 0.018475	 0.036578	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28493	 28586	 0.020078	 0.030752	 0.00053	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28494	 28501	 0.042582	 0.031329	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28494	 28583	 0.016505	 0.02978	 0.00043	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28495	 28498	 0.040965	 0.045057	 0.0006	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85002	 28495	 0.02174	 0.055886	 0.00086	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85001	 28496	 0.011449	 0.022438	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28497	 28498	 0.016802	 0.01697	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28497	 28500	 0.020696	 0.016379	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84741	 28498	 0.23985	 0.61725	 0.00957	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28499	 28500	 0.006861	 0.013584	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28501	 28502	 0.006322	 0.014676	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28501	 28505	 0.02249	 0.018511	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28502	 28503	 0.004083	 0.013473	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28503	 28504	 0.01125	 0.011363	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28503	 85003	 0.005987	 0.031899	 0.00056	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28505	 28569	 0.017477	 0.014937	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28506	 28569	 0.027896	 0.01976	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28506	 28570	 0.008024	 0.020406	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28507	 28530	 0.005984	 0.013892	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28507	 28570	 0.003856	 0.018132	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28507	 85003	 0.003117	 0.019165	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28508	 28509	 0.000833	 0.003823	 0.00098	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84999	 28508	 0.001298	 0.006054	 0.0015	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28509	 28529	 0.003886	 0.010269	 0.0024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28509	 85003	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28509	 85003	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28510	 28511	 0.000906	 0.005307	 0.00145	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28510	 28521	 0.001068	 0.00646	 0.00165	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28510	 85004	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28510	 85004	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28511	 28513	 0.000961	 0.00421	 0.00145	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28511	 28518	 0.00177	 0.007087	 0.00179	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28511	 85008	 0.000263	 0.003415	 0.00135	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85004	 28512	 0.009433	 0.00694	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84750	 28513	 0.001385	 0.009055	 0.0023	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28513	 85028	 0.002232	 0.007445	 0.00189	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28514	 28517	 0.000343	 0.002044	 0.00054	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28514	 28527	 0.000519	 0.003089	 0.00081	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28515	 28529	 0.00088	 0.005057	 0.00143	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84695	 28515	 0.000293	 0.002961	 0.00087	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28515	 85005	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28515	 85005	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28516	 85006	 0.010442	 0.008264	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28517	 28527	 0.000861	 0.005207	 0.00133	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84695	 28517	 0.000582	 0.004992	 0.00142	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28517	 85006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28517	 85006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28517	 85028	 0.00154	 0.006054	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28518	 28527	 0.00233	 0.00605	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28518	 85007	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28518	 85007	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28519	 28550	 0.000847	 0.002994	 0.00067	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28519	 28551	 0.000935	 0.003207	 0.00077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28520	 30524	 0.000404	 0.004824	 0.36199	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28520	 85008	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28520	 85008	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28521	 28550	 0.000933	 0.005026	 0.00138	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28522	 28523	 0.000459	 0.002633	 0.00088	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28522	 28549	 0.000474	 0.003102	 0.00079	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85008	 28523	 0.001338	 0.010746	 0.00302	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28523	 85009	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28523	 85009	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28524	 28526	 0.008421	 0.010959	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28525	 28526	 0.003727	 0.011218	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28525	 85017	 0.007454	 0.014758	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85007	 28526	 0.006322	 0.020358	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85009	 28526	 0.006551	 0.012545	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28527	 28534	 0.000521	 0.003052	 0.00083	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28528	 85010	 0.017119	 0.013548	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28529	 28533	 0.000605	 0.003321	 0.00088	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28529	 28537	 0.001026	 0.005693	 0.00173	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28529	 85010	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28529	 85010	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28530	 28531	 0.00646	 0.015296	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28530	 28532	 0.004324	 0.008849	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28531	 28532	 0.005752	 0.014785	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85005	 28531	 0.005191	 0.029166	 0.00054	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28532	 28538	 0.002911	 0.010185	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28532	 28540	 0.005009	 0.01226	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85005	 28532	 0.008177	 0.043568	 0.00076	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28533	 28536	 0.002387	 0.006309	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28533	 28537	 0.000731	 0.003548	 0.00081	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28534	 28535	 0.000481	 0.002555	 0.00059	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28535	 28536	 0.000338	 0.001982	 0.00054	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28535	 85011	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28535	 85011	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28536	 28546	 0.00244	 0.008623	 0.00194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28536	 85012	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28536	 85012	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28537	 28541	 0.001038	 0.004762	 0.00122	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28537	 28543	 0.002435	 0.008605	 0.00194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28537	 28544	 0.000607	 0.003557	 0.00097	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84695	 28537	 0.001724	 0.013849	 0.00389	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28538	 28539	 0.003246	 0.007535	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28539	 28565	 0.006337	 0.016289	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28540	 28574	 0.002927	 0.006638	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28541	 28542	 0.000472	 0.003038	 0.0008	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28541	 28561	 0.002726	 0.00889	 0.00236	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84695	 28541	 0.002137	 0.019435	 0.00491	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28541	 85013	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28541	 85013	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28542	 28603	 0.000761	 0.004309	 0.00107	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28542	 85014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28542	 85014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28543	 28559	 0.000704	 0.003282	 0.00081	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28543	 85015	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28543	 85015	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28544	 28562	 0.000727	 0.004365	 0.00132	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85011	 28545	 0.0065	 0.015089	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85012	 28545	 0.001516	 0.007986	 0.00014	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	85015	 28545	 0.001667	 0.007429	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28546	 28549	 0.000541	 0.002128	 0.00056	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28546	 28558	 0.000939	 0.003569	 0.001	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28546	 85016	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28546	 85016	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85015	 28547	 0.025988	 0.02037	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85016	 28547	 0.013302	 0.010204	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28548	 85017	 0.010395	 0.007648	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28549	 28555	 0.001012	 0.003682	 0.00113	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28549	 85017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28549	 85017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28550	 85019	 0.003606	 0.00936	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28551	 85018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28551	 85018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28552	 28553	 0.004982	 0.011447	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28552	 85500	 0.004707	 0.010929	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28553	 28554	 0.003632	 0.002874	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85018	 28553	 0.004325	 0.011463	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28555	 85019	 0.00085	 0.003405	 0.00086	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85018	 28556	 0.006534	 0.010481	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84694	 28557	 0.000489	 0.007143	 0.02737	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28557	 85019	 0.000109	 0.008719	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85020	 28557	 0.000318	 0.022264	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28557	 85581	 0.002465	 0.016982	 0.02998	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28558	 28559	 0.001694	 0.004259	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85019	 28558	 0.001394	 0.003618	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28559	 28561	 0.00098	 0.003813	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28559	 85021	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28559	 85021	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85020	 28560	 0.013772	 0.016789	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28561	 28562	 0.001657	 0.004378	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28561	 30369	 0.000865	 0.002967	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28561	 30370	 0.001046	 0.005558	 0.00129	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28562	 28564	 0.000541	 0.003169	 0.00086	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28562	 85022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28562	 85022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85014	 28563	 0.005482	 0.014091	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28563	 85571	 0.007773	 0.017859	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28564	 30372	 0.000633	 0.003636	 0.00103	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28565	 28601	 0.006031	 0.015504	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28565	 85023	 0.010731	 0.027585	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28566	 28580	 0.018912	 0.048097	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28567	 28568	 0.006369	 0.014447	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28568	 28586	 0.006819	 0.017529	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28569	 28571	 0.005988	 0.014178	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28569	 28594	 0.010871	 0.011957	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28570	 85023	 0.024054	 0.019036	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28571	 85026	 0.009036	 0.022117	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28572	 28594	 0.025281	 0.020007	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28572	 85023	 0.006402	 0.014861	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28573	 30382	 0.005141	 0.017636	 0.00422	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84695	 28573	 0.002071	 0.019879	 0.00578	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28573	 85023	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28573	 85023	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85023	 28574	 0.018668	 0.014633	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28575	 28579	 0.021717	 0.017187	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28575	 28595	 0.006965	 0.016171	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28576	 28579	 0.015528	 0.017079	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28576	 28595	 0.032099	 0.020781	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28576	 28596	 0.003316	 0.012759	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28576	 28600	 0.017922	 0.013186	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28577	 28578	 0.003319	 0.01291	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28577	 28598	 0.013979	 0.018373	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28577	 85025	 0.006919	 0.038934	 0.00084	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28578	 30432	 0.018106	 0.018288	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28579	 85573	 0.008471	 0.012976	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28580	 85025	 0.006356	 0.039052	 0.00089	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28581	 30435	 8.5e-05	 0.001011	 0.07585	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28581	 31178	 0.00089	 0.011512	 0.73619	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28581	 85024	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28581	 85024	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28582	 28585	 0.021729	 0.017196	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85025	 28582	 0.012108	 0.031125	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28583	 28588	 0.015528	 0.01893	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28583	 85026	 0.012422	 0.028835	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28584	 85026	 0.010767	 0.017186	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28586	 28587	 0.011583	 0.029457	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28586	 28588	 0.022537	 0.017836	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85001	 28586	 0.075204	 0.088157	 0.00153	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85025	 28586	 0.00959	 0.040998	 0.00093	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28587	 28588	 0.008432	 0.020928	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28587	 28589	 0.007766	 0.014439	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85025	 28587	 0.003769	 0.021442	 0.00066	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28589	 28598	 0.006843	 0.016203	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28589	 85026	 0.006179	 0.014196	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85024	 28590	 0.003347	 0.013153	 0.00344	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28590	 85026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28590	 85026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85026	 28591	 0.006432	 0.016358	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28591	 85027	 0.015106	 0.019853	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28592	 28593	 0.016905	 0.013379	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28592	 28595	 0.008889	 0.015978	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28592	 85027	 0.007123	 0.016534	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28593	 28594	 0.011079	 0.008768	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85023	 28595	 0.003804	 0.020269	 0.00036	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	85023	 28596	 0.003206	 0.015647	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28597	 30382	 0.001963	 0.010772	 0.00285	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28597	 30437	 0.004093	 0.014823	 0.00318	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85024	 28597	 0.003915	 0.01796	 0.0046	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28597	 85027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28597	 85027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28599	 28601	 0.002892	 0.013402	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28599	 30376	 0.004655	 0.009526	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28600	 28601	 0.010958	 0.011068	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28601	 28602	 0.003196	 0.010663	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85014	 28602	 0.002162	 0.008835	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28603	 30374	 0.000665	 0.003277	 0.00089	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84694	 28604	 0.000309	 0.002128	 0.00376	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28604	 85028	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85029	 28604	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84893	 28606	 0.14615	 0.41494	 0.00652	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28606	 85030	 0.092496	 0.21477	 0.00319	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28606	 85177	 0.14059	 0.32646	 0.00622	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28606	 85356	 0.063394	 0.16297	 0.00252	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84893	 28607	 0.11231	 0.15312	 0.0034	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28608	 29832	 0.005998	 0.036276	 0.00926	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84892	 28608	 0.014504	 0.0805	 0.02448	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28608	 85030	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28608	 85030	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28609	 28787	 0.018525	 0.063559	 0.01523	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28609	 29668	 0.017797	 0.046208	 0.01122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28610	 28612	 0.004897	 0.019928	 0.00486	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28610	 28787	 0.008267	 0.042855	 0.01046	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28610	 85031	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28610	 85031	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28611	 28614	 0.000931	 0.00337	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28611	 28615	 0.002462	 0.008031	 0.00213	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28611	 85032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28611	 85032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28612	 28614	 0.003171	 0.008513	 0.00193	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28612	 28618	 0.010282	 0.036345	 0.00819	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28612	 85033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28612	 85033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28612	 85035	 0.010369	 0.037547	 0.00806	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28613	 28614	 0.001965	 0.00548	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28613	 28629	 0.005473	 0.01407	 0.00348	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28614	 28637	 0.005269	 0.013544	 0.00335	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28615	 28618	 0.008472	 0.026347	 0.0055	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85032	 28616	 0.026532	 0.034871	 0.00048	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28617	 28618	 0.010306	 0.027238	 0.00638	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28617	 28637	 0.007656	 0.026683	 0.00619	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28618	 29627	 0.006856	 0.02352	 0.00563	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28618	 85034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28618	 85034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28618	 85398	 0.012478	 0.032395	 0.00786	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28619	 28620	 0.00821	 0.021278	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28619	 28622	 0.022442	 0.041729	 0.00098	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28619	 28635	 0.010729	 0.02491	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28619	 28636	 0.028945	 0.031836	 0.00042	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28620	 28786	 0.013783	 0.053619	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28621	 28622	 0.029384	 0.023254	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28622	 28623	 0.015681	 0.02503	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28622	 85036	 0.032668	 0.064025	 0.00096	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28623	 28632	 0.011823	 0.025242	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28623	 85036	 0.012539	 0.032232	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28623	 86054	 0.008921	 0.074211	 0.0014	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28624	 85035	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85036	 28624	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28624	 86052	 0.000582	 0.005727	 0.0122	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28625	 28626	 0.009381	 0.018573	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28625	 28628	 0.036242	 0.047165	 0.00066	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85036	 28625	 0.005676	 0.03024	 0.00053	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28625	 85037	 0.013917	 0.049717	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28626	 28630	 0.007701	 0.017879	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85035	 28627	 0.003946	 0.017766	 0.00473	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28627	 85037	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28627	 85037	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28629	 28631	 0.001157	 0.003058	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28630	 28632	 0.007242	 0.016814	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28631	 28637	 0.002321	 0.008088	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85035	 28631	 0.00229	 0.014501	 0.00394	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28631	 85038	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28631	 85038	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28632	 28633	 0.014327	 0.015758	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85038	 28632	 0.021815	 0.023994	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28634	 28636	 0.04511	 0.033189	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85038	 28634	 0.028151	 0.030662	 0.00042	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85031	 28635	 0.015053	 0.034583	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85035	 28637	 0.00425	 0.022594	 0.00524	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28637	 85039	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28637	 85039	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28638	 28639	 0.015989	 0.036567	 0.00089	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85037	 28638	 0.014329	 0.072484	 0.00126	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28639	 28641	 0.020524	 0.040635	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28639	 28646	 0.010355	 0.023681	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28640	 28641	 0.009853	 0.012011	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28640	 31926	 0.014994	 0.025834	 0.00041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28641	 28642	 0.020085	 0.018689	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28641	 31934	 0.026696	 0.076568	 0.00118	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28643	 28645	 0.023465	 0.062193	 0.00158	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28643	 29751	 0.026604	 0.052139	 0.00078	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28644	 28645	 0.037018	 0.072549	 0.00109	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28645	 28646	 0.02371	 0.038865	 0.00069	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85037	 28645	 0.041293	 0.16065	 0.00268	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28647	 28648	 0.01596	 0.06209	 0.00104	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28647	 28650	 0.007956	 0.02654	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28647	 85046	 0.022115	 0.050576	 0.00123	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28647	 85047	 0.024642	 0.070678	 0.00109	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28648	 85040	 0.011336	 0.063694	 0.00118	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28648	 85048	 0.041031	 0.11769	 0.00181	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28649	 28650	 0.005017	 0.01593	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28649	 85043	 0.016329	 0.062822	 0.00107	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28651	 28653	 0.001388	 0.017463	 0.00541	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28651	 29975	 0.002857	 0.041251	 0.0131	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28651	 85040	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28651	 85040	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28652	 29105	 0.001641	 0.024387	 0.09043	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84653	 28652	 0.001152	 0.01257	 0.02438	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84653	 28652	 0.001152	 0.01257	 0.02438	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28652	 85041	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85042	 28652	 0.000318	 0.023855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85041	 28653	 0.001108	 0.014816	 0.00405	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28653	 85043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28653	 85043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28654	 29830	 0.028175	 0.09399	 0.00149	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84654	 28654	 0.019273	 0.068851	 0.00137	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84654	 28654	 0.019273	 0.068851	 0.00137	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85042	 28654	 0.028258	 0.10449	 0.00193	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85042	 28654	 0.028258	 0.10449	 0.00193	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84653	 28655	 0.000429	 0.007121	 0.02629	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28655	 85044	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28655	 85044	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28656	 28670	 0.000401	 0.003169	 0.011	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28656	 29952	 0.003188	 0.047717	 0.11176	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28656	 85045	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28656	 85045	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85042	 28657	 0.02074	 0.047648	 0.00072	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28658	 28659	 0.002784	 0.016306	 0.00444	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85041	 28658	 0.004639	 0.030337	 0.00771	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28658	 85046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28658	 85046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28659	 28663	 0.004376	 0.024279	 0.00738	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28659	 85047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28659	 85047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28660	 28661	 0.002971	 0.015176	 0.00382	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28660	 29934	 0.003636	 0.017964	 0.00525	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28660	 85048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28660	 85048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28661	 28662	 0.002105	 0.01091	 0.00266	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28662	 28663	 0.00233	 0.01021	 0.00351	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28663	 28665	 0.001346	 0.009339	 0.00267	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28664	 28665	 0.001928	 0.011076	 0.00314	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28664	 28667	 0.002504	 0.016127	 0.00423	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28664	 85049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28664	 85049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28665	 85050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28665	 85050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85050	 28666	 0.011501	 0.056149	 0.00118	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28666	 85051	 0.038224	 0.088744	 0.00132	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28666	 86089	 0.039516	 0.10158	 0.00157	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28667	 28668	 0.005537	 0.031814	 0.00901	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28667	 29096	 0.001998	 0.021179	 0.00629	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28667	 32037	 0.004843	 0.032493	 0.00784	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28667	 85051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28667	 85051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85041	 28668	 0.006225	 0.054321	 0.01492	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28668	 85052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28668	 85052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28669	 85054	 0.026782	 0.053026	 0.00078	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28670	 29107	 0.001723	 0.022255	 0.05044	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28670	 85053	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85054	 28670	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28671	 85055	 0.035819	 0.044463	 0.00097	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28672	 29106	 0.002934	 0.029655	 0.00872	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85045	 28672	 0.001589	 0.024407	 0.00683	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85053	 28672	 0.000992	 0.013267	 0.00363	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28672	 85055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28672	 85055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28672	 85187	 0.007791	 0.046417	 0.01221	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28673	 29137	 0.004806	 0.039008	 0.01242	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85044	 28673	 0.003653	 0.036248	 0.00986	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28674	 28675	 0.019946	 0.073751	 0.00137	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28674	 28675	 0.019946	 0.073751	 0.00137	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28674	 28676	 0.018517	 0.056807	 0.00154	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28674	 85151	 0.04377	 0.17096	 0.00379	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28675	 28677	 0.031817	 0.071383	 0.00114	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28675	 28694	 0.022142	 0.086142	 0.00144	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28675	 28694	 0.022142	 0.086142	 0.00144	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28676	 85151	 0.021215	 0.094014	 0.00282	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28677	 28679	 0.019151	 0.058812	 0.0011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28678	 85060	 0.015298	 0.031306	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28679	 85058	 0.014695	 0.082688	 0.00179	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28680	 28866	 0.001475	 0.008461	 0.00281	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28680	 85056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28680	 85056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28681	 28860	 2.6e-05	 0.000637	 0.06442	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28681	 28860	 2.6e-05	 0.000637	 0.06442	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 0	 -30.0	 30.0;
	28681	 85057	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85058	 28682	 0.007417	 0.014685	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28683	 28689	 0.006288	 0.018036	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85058	 28683	 0.004922	 0.0249	 0.00043	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85058	 28684	 0.028765	 0.022547	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85058	 28685	 0.007528	 0.016072	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28686	 31754	 0.015885	 0.055582	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28686	 31754	 0.015885	 0.055582	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28686	 85059	 0.007759	 0.027147	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28686	 85059	 0.007759	 0.027147	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28687	 28688	 0.000869	 0.00937	 0.00268	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28687	 28691	 0.003793	 0.014419	 0.00404	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28687	 28701	 0.00103	 0.011766	 0.0056	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28688	 28691	 0.005283	 0.01643	 0.00343	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85057	 28688	 0.001333	 0.017073	 0.0051	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28688	 85059	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28688	 85059	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28689	 28690	 0.015732	 0.036519	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28691	 85060	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28691	 85060	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28692	 28693	 0.006425	 0.024996	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28692	 28693	 0.006425	 0.024996	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85060	 28692	 0.00882	 0.033931	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85060	 28692	 0.00882	 0.033931	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85056	 28693	 0.00723	 0.028125	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85056	 28693	 0.00723	 0.028125	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28694	 28696	 0.2042	 0.16162	 0.00203	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28694	 28698	 0.026352	 0.094141	 0.00187	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28694	 28698	 0.026352	 0.094141	 0.00187	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28694	 28700	 0.037295	 0.094849	 0.0015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28695	 85975	 0.033971	 0.15048	 0.00343	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28697	 28699	 0.001358	 0.017086	 0.00529	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28697	 31726	 0.006437	 0.033494	 0.00986	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84645	 28697	 0.007681	 0.076123	 0.02332	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28697	 85061	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28697	 85061	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85061	 28698	 0.041241	 0.1525	 0.00282	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85061	 28698	 0.041241	 0.1525	 0.00282	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84906	 28699	 0.003581	 0.040115	 0.01275	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28700	 85062	 0.02298	 0.076659	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28701	 28702	 0.000785	 0.008886	 0.00499	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28701	 85062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28701	 85062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28702	 85063	 0.001358	 0.016805	 0.00907	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28703	 31723	 0.00124	 0.01368	 0.02599	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28703	 31723	 0.00124	 0.01368	 0.02599	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28703	 31760	 0.002705	 0.017559	 0.03498	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28703	 85063	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85064	 28703	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28703	 85114	 0.002906	 0.030996	 0.06306	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28703	 85114	 0.002906	 0.030996	 0.06306	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28704	 28711	 0.032033	 0.023156	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28704	 85068	 0.014151	 0.032363	 0.00079	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28705	 28713	 0.016191	 0.011912	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28706	 28708	 0.005654	 0.010202	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28706	 85068	 0.007705	 0.019806	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28707	 28709	 0.01124	 0.008895	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28707	 85066	 0.003945	 0.010141	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28708	 28710	 0.012629	 0.008176	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28712	 85070	 0.021985	 0.015893	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28713	 85068	 0.009266	 0.023819	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28713	 85070	 0.007715	 0.017908	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28714	 28717	 0.012358	 0.026483	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28714	 28718	 0.016637	 0.025959	 0.00043	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28714	 29734	 0.012951	 0.030062	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28714	 29736	 0.016937	 0.037486	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28715	 28716	 0.009431	 0.021569	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28715	 28718	 0.022944	 0.023428	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28715	 28720	 0.0142	 0.03043	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28716	 29735	 0.006497	 0.021673	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28717	 28727	 0.017533	 0.026859	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28718	 28722	 0.032605	 0.058239	 0.00086	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28719	 28720	 0.016815	 0.013307	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28720	 28721	 0.010309	 0.029567	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28720	 28723	 0.021516	 0.017028	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28721	 28722	 0.012433	 0.01634	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28721	 28727	 0.012524	 0.024545	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28721	 85065	 0.007389	 0.024385	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28722	 28728	 0.003412	 0.011381	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28724	 85066	 0.016683	 0.01685	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28725	 28741	 0.015434	 0.035831	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28725	 85065	 0.009133	 0.023226	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28725	 85066	 0.022363	 0.022368	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28725	 85068	 0.018182	 0.041243	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28726	 28729	 0.002877	 0.008992	 0.0026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28726	 28750	 0.009813	 0.025476	 0.00618	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28726	 29727	 0.005656	 0.040002	 0.01098	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28726	 85065	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28726	 85065	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28726	 85067	 0.002654	 0.017806	 0.0043	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28728	 85066	 0.00535	 0.033591	 0.00073	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28729	 85066	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28729	 85066	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28729	 85067	 0.002533	 0.010141	 0.00255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28730	 85067	 0.000243	 0.018209	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28731	 28739	 0.021886	 0.040086	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28731	 29734	 0.045176	 0.10489	 0.00156	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85065	 28731	 0.010116	 0.033746	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28732	 28741	 0.005647	 0.023898	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28732	 28743	 0.005507	 0.016912	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28733	 28737	 0.024617	 0.070604	 0.00109	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28733	 28743	 0.005245	 0.013592	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28733	 85069	 0.015348	 0.059707	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28734	 28742	 0.021086	 0.014164	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28734	 28744	 0.00955	 0.017491	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28734	 85069	 0.018337	 0.037524	 0.00092	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28735	 28737	 0.01459	 0.034549	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28736	 28761	 0.048302	 0.12519	 0.00237	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28736	 85069	 0.043659	 0.21307	 0.00368	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28738	 28760	 0.042107	 0.046313	 0.00062	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28738	 29728	 0.0632	 0.067493	 0.00143	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85065	 28738	 0.02247	 0.074959	 0.00119	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85065	 28740	 0.010503	 0.019236	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85068	 28741	 0.005519	 0.029748	 0.0006	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28741	 85069	 0.013819	 0.032082	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28745	 28750	 0.002434	 0.009906	 0.00241	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85067	 28745	 0.001034	 0.007792	 0.00216	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28745	 85069	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28745	 85069	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28746	 28747	 0.019499	 0.016049	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85069	 28747	 0.007644	 0.019649	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28748	 28749	 0.006623	 0.015024	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28748	 28751	 0.012663	 0.032551	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28749	 28757	 0.015248	 0.014979	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85067	 28750	 0.001494	 0.007507	 0.00195	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28750	 85070	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28750	 85070	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85069	 28751	 0.003489	 0.018592	 0.00033	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28752	 28754	 0.016515	 0.011939	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28752	 28755	 0.005281	 0.012927	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28753	 28755	 0.012839	 0.02542	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28755	 28756	 0.022052	 0.022273	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85070	 28755	 0.004935	 0.019197	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28758	 28759	 0.008428	 0.021665	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85070	 28758	 0.025851	 0.068338	 0.00124	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28760	 29728	 0.024612	 0.03355	 0.00074	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28761	 28762	 0.039525	 0.10161	 0.00157	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28761	 85071	 0.070256	 0.18062	 0.0028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28762	 28764	 0.009333	 0.026768	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28763	 85071	 0.050789	 0.066752	 0.00091	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28764	 28765	 0.01003	 0.055231	 0.00125	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28764	 85071	 0.031947	 0.081247	 0.00128	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28765	 29681	 0.081105	 0.18635	 0.00283	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28765	 29706	 0.029489	 0.11346	 0.00194	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28766	 29090	 0.013295	 0.053234	 0.01341	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28766	 85071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28766	 85071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28767	 28769	 0.019834	 0.046045	 0.01403	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28767	 28772	 0.003372	 0.019171	 0.00555	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28767	 32046	 0.007653	 0.042465	 0.01291	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28767	 85072	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28767	 85072	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28768	 29081	 0.025507	 0.145	 0.00262	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85072	 28768	 0.019422	 0.064094	 0.00104	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28768	 85073	 0.064027	 0.14711	 0.00223	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28769	 29836	 0.034765	 0.20402	 0.05573	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28769	 32583	 0.03301	 0.15159	 0.03889	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84699	 28769	 0.018051	 0.14516	 0.04086	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84906	 28769	 0.020488	 0.13741	 0.04215	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28769	 85073	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28769	 85073	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28770	 28771	 0.024079	 0.047674	 0.0007	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28771	 28774	 0.013821	 0.040642	 0.00083	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85073	 28771	 0.054959	 0.16879	 0.00317	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28771	 85074	 0.013223	 0.070456	 0.00124	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28771	 85075	 0.040658	 0.096279	 0.00176	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28772	 28773	 0.003406	 0.01492	 0.00513	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28772	 85074	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28772	 85074	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28773	 28776	 0.002959	 0.022292	 0.00618	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28773	 85075	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28773	 85075	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28774	 28775	 0.022791	 0.076029	 0.00121	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28775	 85076	 0.032699	 0.11682	 0.00232	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28776	 28778	 0.002543	 0.021812	 0.00621	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28776	 85076	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28776	 85076	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28777	 28778	 0.005236	 0.020371	 0.00544	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28777	 29069	 0.007268	 0.028277	 0.00755	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28780	 29074	 0.031147	 0.1069	 0.02562	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28780	 85077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28780	 85077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28781	 28783	 0.004222	 0.012108	 0.00298	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28781	 28785	 0.005892	 0.027031	 0.00692	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28781	 85078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28781	 85078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28782	 85079	 0.009107	 0.023411	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28783	 85079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28783	 85079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28784	 28786	 0.019426	 0.086564	 0.00147	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85079	 28784	 0.023586	 0.10305	 0.00271	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28785	 29087	 0.009322	 0.044124	 0.01061	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28788	 85080	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28788	 85080	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84876	 28789	 0.005229	 0.061689	 0.11403	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85080	 28789	 0.000719	 0.006845	 0.025	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28789	 85082	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85083	 28789	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28790	 29826	 0.017007	 0.10456	 0.00188	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85081	 28790	 0.020855	 0.10011	 0.00299	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28791	 28821	 0.000995	 0.008196	 0.01689	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28791	 28841	 0.00143	 0.009986	 0.01714	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28791	 85084	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85085	 28791	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28792	 28793	 0.00133	 0.003708	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84697	 28792	 0.000163	 0.001862	 0.00057	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28793	 85086	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28793	 85086	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28794	 28795	 0.000689	 0.0038	 0.00089	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28794	 85152	 0.001498	 0.008607	 0.00244	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28795	 28809	 0.003946	 0.016291	 0.00385	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28795	 28940	 0.001074	 0.004925	 0.00126	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28796	 28797	 0.008485	 0.021577	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28797	 28798	 0.011778	 0.007912	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28797	 28799	 0.004118	 0.016022	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28797	 28799	 0.004118	 0.016022	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28797	 85153	 0.004602	 0.016101	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28797	 85153	 0.004602	 0.016101	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85086	 28799	 0.001842	 0.016949	 0.00034	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28800	 28802	 0.005143	 0.01322	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85085	 28800	 0.009004	 0.025825	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28801	 28838	 0.001521	 0.005125	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85084	 28801	 0.000839	 0.004657	 0.00142	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28802	 28816	 0.006729	 0.012325	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28802	 28817	 0.004854	 0.013446	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28803	 28961	 0.008542	 0.012447	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28804	 28805	 0.012143	 0.00961	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28804	 28806	 0.008407	 0.016477	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28804	 85089	 0.001737	 0.006891	 0.0002	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28806	 85111	 0.013675	 0.013812	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28807	 28848	 0.00104	 0.004088	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28807	 85087	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28807	 85087	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28807	 85088	 0.000647	 0.003852	 0.00101	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28808	 28823	 0.003874	 0.026427	 0.0476	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28808	 28841	 0.000734	 0.007232	 0.01541	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28808	 28858	 5e-05	 0.000732	 0.00281	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28808	 85088	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28808	 85088	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28809	 28811	 0.001898	 0.004573	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28809	 28840	 0.005608	 0.019238	 0.00461	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28809	 85089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28809	 85089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85089	 28810	 0.004205	 0.013875	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28810	 85111	 0.021079	 0.021524	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28811	 28812	 0.00156	 0.006246	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28811	 85090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28811	 85090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28811	 85152	 0.002823	 0.012869	 0.00408	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28812	 28814	 0.001051	 0.004447	 0.001	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28812	 85091	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28812	 85091	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85089	 28813	 0.019224	 0.020529	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85090	 28813	 0.031042	 0.022838	 0.00033	 28.0	 28.0	 28.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85091	 28813	 0.007131	 0.012737	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28813	 85103	 0.024114	 0.050682	 0.00092	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28814	 28839	 0.001184	 0.004739	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28814	 85092	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28814	 85092	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28815	 28817	 0.003513	 0.008034	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28815	 28961	 0.007955	 0.02526	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85092	 28816	 0.009448	 0.013766	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28816	 85103	 0.007827	 0.019904	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28818	 28819	 0.001071	 0.007707	 0.00204	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28818	 85093	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28818	 85093	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28818	 85095	 0.001831	 0.012953	 0.00355	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28819	 30561	 0.004461	 0.031552	 0.00866	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28820	 85094	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28820	 85094	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84646	 28821	 0.000508	 0.00588	 0.01127	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28821	 85095	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28821	 85095	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28823	 32357	 0.001909	 0.028568	 0.06685	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84646	 28823	 0.001705	 0.014437	 0.02813	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28823	 85096	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85097	 28823	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28824	 28826	 0.032066	 0.025376	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28824	 85098	 0.008779	 0.029287	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28825	 28827	 0.002352	 0.008195	 0.0019	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85095	 28825	 0.001862	 0.010908	 0.00297	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85096	 28825	 0.008471	 0.022743	 0.00515	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28825	 85098	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28825	 85098	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28826	 85101	 0.030467	 0.024111	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28827	 28833	 0.002232	 0.007778	 0.0018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28828	 28829	 0.010981	 0.02851	 0.00692	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28828	 28830	 0.006658	 0.019628	 0.00457	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28828	 30564	 0.006348	 0.024129	 0.00675	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85096	 28828	 0.007745	 0.025837	 0.00655	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84699	 28829	 0.004965	 0.030849	 0.00871	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28829	 85099	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28829	 85099	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28830	 28837	 0.00175	 0.006124	 0.00203	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28830	 28840	 0.003389	 0.013568	 0.00342	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28830	 30564	 0.010991	 0.039989	 0.01224	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28830	 85100	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28830	 85100	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28831	 28832	 0.006171	 0.014176	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85100	 28831	 0.026878	 0.021271	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28831	 85621	 0.097541	 0.17424	 0.00257	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28832	 28836	 0.021128	 0.015273	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28832	 85101	 0.020822	 0.027366	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28832	 85103	 0.03773	 0.037841	 0.00061	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28833	 28835	 0.001897	 0.005163	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28833	 85101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28833	 85101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85085	 28834	 0.008304	 0.027701	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85101	 28834	 0.02054	 0.026995	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28834	 85103	 0.030477	 0.023889	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28835	 28837	 0.002547	 0.007102	 0.00149	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28835	 28838	 0.001527	 0.003927	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28835	 85102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28835	 85102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85102	 28836	 0.011912	 0.015502	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28836	 85104	 0.035505	 0.025667	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28837	 28839	 0.000755	 0.00264	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28837	 28840	 0.005677	 0.014737	 0.00358	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28838	 85103	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28838	 85103	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28839	 85104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28839	 85104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84699	 28840	 0.008013	 0.043971	 0.01162	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85096	 28840	 0.019793	 0.05139	 0.01247	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28840	 85105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28840	 85105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28840	 85106	 0.002077	 0.008316	 0.00209	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28841	 28842	 0.000902	 0.006324	 0.01077	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84646	 28841	 0.001529	 0.018912	 0.03794	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28841	 85106	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85107	 28841	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28842	 85108	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85109	 28842	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28843	 28850	 0.11036	 0.087339	 0.0011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85109	 28843	 0.013909	 0.03677	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28843	 85112	 0.013069	 0.030341	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85109	 28844	 0.011729	 0.023222	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28845	 28851	 0.006693	 0.01585	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85109	 28845	 0.016898	 0.043439	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28846	 28847	 0.001875	 0.006116	 0.00162	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85106	 28846	 0.00082	 0.005098	 0.00144	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28847	 28848	 0.000949	 0.003801	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28847	 28853	 0.006888	 0.019209	 0.00403	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28847	 85110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28847	 85110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28848	 85111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28848	 85111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28849	 28850	 0.005366	 0.01098	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85087	 28849	 0.005182	 0.014863	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28850	 28856	 0.011042	 0.024772	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28851	 28852	 0.008529	 0.013613	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28851	 28854	 0.011985	 0.023729	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85110	 28851	 0.008195	 0.019022	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85108	 28853	 0.003508	 0.015796	 0.0042	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28853	 85112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28853	 85112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28855	 28856	 0.010642	 0.018578	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28855	 28868	 0.014931	 0.049809	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85112	 28855	 0.009904	 0.025458	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28856	 28857	 0.011953	 0.015555	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28857	 28863	 0.01044	 0.015993	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28858	 28859	 9.1e-05	 0.001235	 0.00551	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28858	 85113	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28858	 85113	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28859	 85114	 0.000149	 0.002274	 0.00794	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28860	 28963	 0.000118	 0.002015	 0.15681	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28860	 85114	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28860	 85114	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28861	 28869	 0.006539	 0.01681	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28862	 28863	 0.013217	 0.022266	 0.00032	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28862	 28869	 0.012696	 0.023254	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28863	 28864	 0.004771	 0.009764	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28864	 28869	 0.016337	 0.037533	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85113	 28864	 0.005309	 0.018577	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28865	 28867	 0.003043	 0.019108	 0.00042	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28865	 28868	 0.015505	 0.027267	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28865	 28872	 0.002615	 0.02014	 0.00039	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28865	 85117	 0.007485	 0.021467	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85115	 28866	 0.003117	 0.018258	 0.00497	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28866	 85117	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28866	 85117	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85112	 28867	 0.005704	 0.027378	 0.00082	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28868	 28869	 0.004527	 0.022089	 0.00038	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85116	 28868	 0.016549	 0.064381	 0.00107	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85117	 28868	 0.004544	 0.017044	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85117	 28868	 0.004544	 0.017044	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85116	 28869	 0.006601	 0.03635	 0.00082	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84699	 28870	 0.004854	 0.027486	 0.00681	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28870	 85118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28870	 85118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28871	 28872	 0.01289	 0.033135	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28872	 28873	 0.006055	 0.023556	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28872	 28873	 0.006055	 0.023556	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85118	 28872	 0.013128	 0.074625	 0.00135	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85056	 28873	 0.009245	 0.035964	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85056	 28873	 0.009245	 0.035964	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85117	 28873	 0.009181	 0.029439	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85117	 28873	 0.009181	 0.029439	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28874	 28877	 0.001498	 0.00634	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28874	 30557	 0.011912	 0.045281	 0.01268	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28874	 85119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28874	 85119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28875	 28892	 0.012473	 0.035773	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85119	 28875	 0.014724	 0.033827	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28875	 85120	 0.015131	 0.029653	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28875	 85121	 0.016425	 0.012998	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28875	 85122	 0.026772	 0.020985	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28876	 28877	 0.003355	 0.008866	 0.00208	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28876	 28879	 0.002416	 0.00621	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28876	 28886	 0.003074	 0.016865	 0.00446	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85094	 28876	 0.005222	 0.039338	 0.01091	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28876	 85120	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28876	 85120	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28877	 28879	 0.001459	 0.003856	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28877	 85121	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28877	 85121	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28878	 85122	 0.011956	 0.011212	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28879	 85122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28879	 85122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28880	 28882	 0.0087	 0.020601	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85120	 28880	 0.005762	 0.025388	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28881	 28894	 0.011907	 0.026713	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85120	 28881	 0.006798	 0.017476	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28882	 28883	 0.008247	 0.01488	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28882	 85990	 0.039877	 0.1316	 0.00213	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28883	 28884	 0.00499	 0.015309	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85120	 28883	 0.006161	 0.03297	 0.001	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28884	 28885	 0.009192	 0.02134	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28885	 31748	 0.005812	 0.025606	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28885	 85123	 0.00877	 0.022303	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28886	 28906	 0.002226	 0.010383	 0.00257	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28886	 31746	 0.002177	 0.019289	 0.00514	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28886	 85123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28886	 85123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28887	 28901	 0.001774	 0.010392	 0.00283	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28887	 85124	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28887	 85124	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28887	 85125	 0.001811	 0.011467	 0.00311	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28888	 85127	 0.011352	 0.020403	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28889	 28899	 0.001353	 0.007283	 0.002	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28889	 28905	 0.001447	 0.007941	 0.0021	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84646	 28890	 0.00076	 0.007472	 0.02562	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28890	 85125	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85126	 28890	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28891	 28898	 0.018141	 0.019953	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28892	 28897	 0.004651	 0.015516	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28893	 28894	 0.016034	 0.016194	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85120	 28893	 0.026593	 0.052651	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28893	 85130	 0.010272	 0.02915	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28895	 28896	 0.020729	 0.016248	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85126	 28896	 0.013052	 0.033194	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28897	 28898	 0.004698	 0.020934	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85126	 28898	 0.003653	 0.025075	 0.00046	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85125	 28899	 0.001096	 0.007602	 0.00217	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28899	 85127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28899	 85127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85124	 28900	 0.006096	 0.014152	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85126	 28900	 0.012834	 0.033927	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85127	 28900	 0.003255	 0.013588	 0.00039	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28901	 28903	 0.001531	 0.01027	 0.00248	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28901	 85128	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28901	 85128	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85124	 28902	 0.020588	 0.050395	 0.00086	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28903	 28907	 0.001206	 0.007885	 0.002	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28903	 85129	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28903	 85129	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85123	 28904	 0.017291	 0.021079	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28905	 28906	 0.001111	 0.005479	 0.00148	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28906	 85130	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28906	 85130	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28907	 28908	 0.00146	 0.014487	 0.00394	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28907	 28948	 0.002182	 0.011597	 0.00269	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28907	 85131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28907	 85131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28908	 28942	 0.003886	 0.033331	 0.00949	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28908	 28957	 0.009038	 0.023886	 0.00559	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28908	 31744	 0.004012	 0.040877	 0.01053	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28908	 31749	 0.00606	 0.016899	 0.00355	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85115	 28908	 0.008364	 0.048058	 0.01362	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28908	 85993	 0.003427	 0.04792	 0.01625	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85131	 28909	 0.010934	 0.024801	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28909	 85145	 0.01149	 0.056071	 0.00097	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28909	 85149	 0.033278	 0.059814	 0.00107	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28909	 85991	 0.032122	 0.081692	 0.00129	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28910	 28913	 0.032007	 0.028681	 0.00059	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85124	 28910	 0.006538	 0.016806	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28910	 85140	 0.003085	 0.012366	 0.00032	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28911	 28918	 0.000745	 0.004086	 0.00108	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84663	 28911	 0.001239	 0.012525	 0.00368	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84697	 28911	 0.002168	 0.013454	 0.00326	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28911	 85132	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28911	 85132	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28912	 28913	 0.009621	 0.017293	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85126	 28913	 0.014479	 0.036674	 0.00073	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28913	 85138	 0.007792	 0.025992	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28914	 28916	 0.000866	 0.00507	 0.00138	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28914	 85133	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28914	 85133	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85132	 28915	 0.023808	 0.018842	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28916	 28922	 0.000812	 0.004299	 0.00109	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28916	 85134	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28916	 85134	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28917	 85135	 0.008468	 0.021769	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28917	 85136	 0.013631	 0.016616	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28918	 28919	 0.000401	 0.004084	 0.00105	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84663	 28918	 0.001539	 0.015555	 0.00457	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28918	 85135	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28918	 85135	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28919	 28920	 0.000357	 0.003356	 0.00102	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28920	 28926	 0.000323	 0.002773	 0.00079	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28921	 28922	 0.000542	 0.003231	 0.00085	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28921	 28924	 0.00064	 0.003402	 0.00079	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85125	 28921	 0.004815	 0.018923	 0.00495	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28921	 85152	 0.002702	 0.01204	 0.00327	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28922	 85136	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28922	 85136	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28923	 85137	 0.005716	 0.011202	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28924	 28925	 0.000929	 0.004591	 0.00134	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28924	 85137	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28924	 85137	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28925	 28929	 0.001277	 0.005857	 0.0015	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28926	 28930	 0.000818	 0.004506	 0.00163	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28926	 85138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28926	 85138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28927	 28928	 0.000412	 0.003593	 0.00099	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28927	 85152	 0.000863	 0.007399	 0.00211	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28928	 28930	 0.00219	 0.010046	 0.00257	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28928	 28937	 0.000594	 0.004047	 0.00138	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28929	 28933	 0.001719	 0.006879	 0.00232	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28929	 85139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28929	 85139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28930	 85140	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28930	 85140	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28931	 85146	 0.007128	 0.01688	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28932	 85141	 0.00703	 0.017206	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28933	 28936	 0.00083	 0.003379	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28933	 85141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28933	 85141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28934	 28935	 0.007403	 0.018374	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85129	 28934	 0.026826	 0.02208	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28935	 85144	 0.009167	 0.03058	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28936	 28937	 0.00088	 0.005239	 0.00138	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28936	 28942	 0.000593	 0.007456	 0.00231	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28937	 85142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28937	 85142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85142	 28938	 0.01491	 0.014588	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28938	 85143	 0.004443	 0.010313	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28939	 28940	 0.001023	 0.004097	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28939	 28941	 0.000565	 0.006358	 0.00167	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28939	 85143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28939	 85143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28939	 85152	 0.002911	 0.017048	 0.00464	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85088	 28940	 0.005658	 0.015777	 0.00331	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28941	 28944	 0.00076	 0.004892	 0.00128	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85115	 28941	 0.002817	 0.014658	 0.00432	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28942	 28944	 0.001166	 0.003999	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28942	 28948	 0.00299	 0.012167	 0.00296	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85115	 28942	 0.002024	 0.011934	 0.00972	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28942	 85144	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28942	 85144	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28943	 28944	 0.000997	 0.00465	 0.00115	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28943	 28947	 0.000797	 0.003189	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28945	 28947	 0.002166	 0.006485	 0.00146	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28945	 28949	 0.000575	 0.003096	 0.00085	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85115	 28945	 0.0024	 0.013318	 0.00405	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28946	 28947	 0.001133	 0.005047	 0.00137	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28946	 28948	 0.001653	 0.005569	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28946	 28951	 0.000599	 0.006051	 0.00178	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85115	 28946	 0.003618	 0.020786	 0.00589	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28946	 85145	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28946	 85145	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28948	 85146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28948	 85146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28949	 28959	 0.001817	 0.006234	 0.00149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28949	 85147	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28949	 85147	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28950	 28952	 0.007173	 0.023929	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85147	 28950	 0.002583	 0.013606	 0.00024	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28950	 85150	 0.015038	 0.015189	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28951	 28956	 0.000601	 0.006485	 0.00186	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28951	 85148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28951	 85148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85148	 28952	 0.008404	 0.015393	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28953	 85150	 0.008724	 0.011465	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28954	 28955	 0.013898	 0.035727	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28954	 28958	 0.00392	 0.013726	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28954	 31753	 0.005767	 0.039588	 0.00072	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85116	 28954	 0.019978	 0.097492	 0.00168	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28956	 28957	 0.000752	 0.007722	 0.00244	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28957	 31752	 0.000344	 0.004907	 0.00164	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28957	 85149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28957	 85149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28958	 85150	 0.002219	 0.011962	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28959	 85150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28959	 85150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85090	 28960	 0.006157	 0.012599	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28961	 85153	 0.00751	 0.023037	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28962	 85151	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28962	 85151	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28963	 85152	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28964	 28966	 0.002108	 0.016241	 0.00031	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28964	 85154	 0.003767	 0.016695	 0.0005	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28965	 31846	 0.00592	 0.024092	 0.00587	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28965	 85154	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28965	 85154	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28965	 85155	 0.002627	 0.014576	 0.00443	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28966	 28967	 0.01663	 0.012235	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28966	 85157	 0.002019	 0.018798	 0.00036	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28968	 28969	 0.010603	 0.01071	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28969	 28970	 0.023136	 0.014979	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28969	 28978	 0.012362	 0.035456	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28971	 28972	 0.036802	 0.027076	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28971	 28973	 0.008996	 0.022879	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28971	 28978	 0.020013	 0.030657	 0.00043	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28973	 28975	 0.002473	 0.02302	 0.00045	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28973	 28978	 0.013468	 0.035601	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28974	 29019	 0.03283	 0.025981	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28975	 85163	 0.008351	 0.029221	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28975	 85163	 0.008351	 0.029221	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28976	 28977	 0.00031	 0.003364	 0.00206	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28976	 85155	 0.000355	 0.003914	 0.002	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28977	 29018	 0.000256	 0.002965	 0.00184	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28978	 28981	 0.007469	 0.012406	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28978	 85156	 0.002149	 0.017844	 0.00044	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28978	 85157	 0.013903	 0.025085	 0.00036	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28979	 85155	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85156	 28979	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28980	 29007	 0.009884	 0.025408	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85156	 28980	 0.004097	 0.028122	 0.00051	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28981	 85157	 0.008927	 0.013237	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28982	 28983	 0.001321	 0.005589	 0.00126	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85155	 28982	 0.001336	 0.006961	 0.00183	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28982	 85157	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28982	 85157	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28983	 28986	 0.00129	 0.006829	 0.00173	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28983	 29015	 0.004551	 0.0117	 0.0029	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85155	 28983	 0.000465	 0.003865	 0.00117	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28983	 85158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28983	 85158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28984	 28985	 0.007818	 0.014972	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85157	 28984	 0.004053	 0.010307	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28986	 85159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28986	 85159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28987	 29002	 0.024596	 0.019279	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85154	 28987	 0.007804	 0.022384	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85159	 28987	 0.005758	 0.017664	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28988	 28989	 0.011177	 0.019656	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28988	 28998	 0.013969	 0.030917	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85154	 28988	 0.004565	 0.021467	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84716	 28990	 0.011269	 0.061845	 0.01635	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28990	 85160	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28990	 85160	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28991	 86028	 0.020092	 0.042896	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28991	 86030	 0.031631	 0.083618	 0.00152	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28992	 28996	 0.047898	 0.031009	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28993	 28995	 0.065797	 0.047565	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28994	 28995	 0.018559	 0.035542	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85160	 28994	 0.028273	 0.072679	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28996	 28997	 0.018127	 0.044369	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28997	 28999	 0.01605	 0.031778	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85159	 28997	 0.020929	 0.073278	 0.00203	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28998	 29001	 0.008798	 0.02012	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28998	 29003	 0.011585	 0.012618	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29000	 29001	 0.00514	 0.015786	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29000	 29004	 0.005082	 0.019771	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29004	 29005	 0.003838	 0.016911	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85159	 29005	 0.00427	 0.019383	 0.00042	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29005	 85161	 0.005502	 0.027832	 0.00048	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85158	 29006	 0.010591	 0.020756	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29007	 29009	 0.006418	 0.018409	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29008	 29010	 0.016238	 0.031824	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29008	 85162	 0.008019	 0.019628	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29009	 29014	 0.009824	 0.032773	 0.00052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29011	 29012	 0.009085	 0.030308	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29011	 29014	 0.010047	 0.033515	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29011	 35466	 0.013228	 0.11005	 0.00208	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29012	 29013	 0.018123	 0.014342	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29012	 85161	 0.011651	 0.033063	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29014	 85161	 0.015693	 0.036434	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29015	 85161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29015	 85161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84716	 29016	 0.003747	 0.019153	 0.00522	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29016	 85162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29016	 85162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29017	 29018	 0.000853	 0.006136	 0.00163	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84716	 29017	 0.001689	 0.013572	 0.00381	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29017	 85163	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29017	 85163	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84716	 29018	 0.00163	 0.014851	 0.00539	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85163	 29019	 0.009175	 0.023334	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29020	 29021	 0.00305	 0.018743	 0.00043	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29020	 29023	 0.004717	 0.024529	 0.00053	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85163	 29020	 0.013669	 0.035138	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85162	 29021	 0.007934	 0.038671	 0.00073	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85162	 29022	 0.039093	 0.088677	 0.00177	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84717	 29023	 0.003376	 0.024673	 0.00045	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29024	 29025	 0.01866	 0.029785	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84717	 29024	 0.003471	 0.015294	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29026	 29027	 0.007343	 0.022525	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84717	 29026	 0.009227	 0.046674	 0.00081	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29027	 29028	 0.008576	 0.038213	 0.00065	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29028	 29031	 0.008129	 0.039223	 0.00069	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29029	 35448	 0.091944	 0.21349	 0.00318	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84716	 29030	 0.009957	 0.02585	 0.00627	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29030	 85164	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29030	 85164	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29032	 29033	 0.048591	 0.12491	 0.00193	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29032	 35439	 0.068896	 0.14711	 0.00332	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29033	 31824	 0.12889	 0.24365	 0.00394	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29034	 31823	 0.058377	 0.1227	 0.00224	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29035	 29039	 0.000773	 0.004525	 0.00123	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29035	 29053	 0.001631	 0.009271	 0.00268	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29036	 29038	 0.001716	 0.010048	 0.00274	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29036	 29040	 0.002309	 0.009397	 0.00229	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29036	 31768	 0.002498	 0.023986	 0.00698	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29037	 29038	 0.001236	 0.007239	 0.00197	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29037	 29039	 0.001032	 0.006416	 0.00181	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29039	 85165	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29039	 85165	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29040	 29041	 0.001574	 0.011859	 0.00329	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85063	 29040	 0.02219	 0.13007	 0.03547	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29041	 29047	 0.001373	 0.007804	 0.00226	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29041	 85166	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29041	 85166	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29042	 31764	 0.028293	 0.1891	 0.00419	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29042	 32137	 0.070268	 0.3776	 0.00897	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84723	 29042	 0.035107	 0.21038	 0.00506	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29042	 85985	 0.094367	 0.2235	 0.00409	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29042	 86126	 0.058933	 0.26266	 0.00446	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29043	 29044	 0.033318	 0.11115	 0.00176	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29043	 86099	 0.029381	 0.11431	 0.00191	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29044	 85168	 0.014425	 0.063557	 0.0011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29045	 85169	 0.008592	 0.022087	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29045	 85170	 0.054559	 0.083581	 0.00117	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85166	 29046	 0.011992	 0.027202	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29046	 85167	 0.009809	 0.019223	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29047	 29050	 0.001216	 0.007124	 0.00194	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29047	 85167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29047	 85167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85167	 29048	 0.009911	 0.019424	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29049	 29050	 0.003212	 0.008073	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29049	 85168	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29049	 85168	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29050	 29051	 0.00301	 0.015123	 0.00394	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29050	 85169	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29050	 85169	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29051	 29052	 0.002709	 0.018795	 0.00536	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29051	 29053	 0.001363	 0.008468	 0.00239	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29051	 32060	 0.004618	 0.044335	 0.0129	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84645	 29051	 0.007805	 0.11014	 0.0377	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29051	 85170	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29051	 85170	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29052	 32061	 0.002244	 0.018669	 0.00565	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29052	 85171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29052	 85171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85170	 29054	 0.01831	 0.081588	 0.00139	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85171	 29054	 0.005958	 0.029073	 0.0005	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29055	 29056	 0.086002	 0.228	 0.00578	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29055	 86142	 0.059348	 0.20769	 0.0043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29056	 29078	 0.1315	 0.30537	 0.00454	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29057	 29078	 0.15231	 0.14717	 0.00214	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29058	 29078	 0.2211	 0.22336	 0.00296	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29059	 29060	 0.004574	 0.022554	 0.0061	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29059	 29795	 0.006293	 0.037493	 0.00986	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29059	 32789	 0.004829	 0.030006	 0.00847	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29059	 85172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29059	 85172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29060	 29795	 0.002731	 0.018323	 0.00442	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29060	 85173	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29060	 85173	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29060	 86302	 0.012788	 0.079373	 0.01923	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29061	 29063	 0.015875	 0.080776	 0.00183	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29061	 32788	 0.015452	 0.10707	 0.0022	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29061	 85174	 0.1054	 0.15803	 0.00287	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29062	 29067	 0.011562	 0.045448	 0.01189	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29062	 85174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29062	 85174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85172	 29063	 0.047588	 0.088488	 0.00207	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29063	 85176	 0.012365	 0.076021	 0.00137	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29064	 29066	 0.008005	 0.028986	 0.00622	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29064	 29796	 0.004913	 0.019668	 0.00496	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29064	 85175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29064	 85175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29065	 85176	 0.015166	 0.06758	 0.00115	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29065	 85177	 0.016842	 0.067399	 0.00142	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29066	 85176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29066	 85176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84892	 29067	 0.030133	 0.17976	 0.04739	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29067	 85177	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29067	 85177	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29067	 85430	 0.014393	 0.085771	 0.02258	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85083	 29068	 0.057603	 0.19011	 0.00308	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29068	 85178	 0.053034	 0.13634	 0.00211	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29069	 85178	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29069	 85178	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85083	 29070	 0.18684	 0.14788	 0.00186	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29071	 29072	 0.002415	 0.022483	 0.00696	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29072	 29530	 0.015305	 0.094134	 0.02716	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85082	 29072	 0.007849	 0.049719	 0.0135	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29073	 85641	 0.22628	 0.17147	 0.00236	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29074	 29091	 0.016677	 0.060395	 0.01296	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29074	 29161	 0.041417	 0.10758	 0.02613	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29074	 85179	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29074	 85179	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29075	 85213	 0.15607	 0.30596	 0.00459	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29077	 29078	 0.050509	 0.15512	 0.00291	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84894	 29077	 0.03779	 0.25945	 0.00473	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29079	 32995	 0.05547	 0.24722	 0.0042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84735	 29079	 0.12309	 0.25198	 0.0062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29080	 29836	 0.017976	 0.076098	 0.01713	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29080	 33686	 0.004206	 0.040385	 0.01175	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29082	 29084	 0.005488	 0.024708	 0.00657	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29082	 29147	 0.011413	 0.053235	 0.01319	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29082	 85180	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29082	 85180	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85180	 29083	 0.065022	 0.16716	 0.00259	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29084	 31719	 0.006089	 0.021523	 0.00485	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84721	 29085	 0.040107	 0.025966	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84701	 29086	 0.000476	 0.003086	 0.00615	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84719	 29086	 0.001233	 0.009393	 0.01709	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84671	 29087	 0.013204	 0.061589	 0.01526	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84720	 29087	 0.011742	 0.059004	 0.01536	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29087	 85181	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29087	 85181	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29088	 31187	 0.3499	 0.27702	 0.00349	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84731	 29088	 0.002644	 0.019649	 0.00047	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85179	 29088	 0.64653	 0.51239	 0.00645	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29088	 85182	 0.021309	 0.059025	 0.00097	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29089	 29090	 0.023292	 0.10868	 0.02694	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84662	 29089	 0.059246	 0.15675	 0.03674	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84730	 29089	 0.002901	 0.011401	 0.00298	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29089	 85182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29089	 85182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29090	 29092	 0.009732	 0.03279	 0.00815	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29090	 85833	 0.079328	 0.19155	 0.05421	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29091	 29092	 0.003119	 0.013203	 0.00297	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29091	 29673	 0.00806	 0.02809	 0.00651	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29092	 85183	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29092	 85183	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84741	 29093	 0.19435	 0.18229	 0.00282	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85182	 29093	 0.059537	 0.17077	 0.00263	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29094	 29095	 0.004663	 0.019734	 0.00444	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29094	 29098	 0.008669	 0.030334	 0.01005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29094	 29576	 0.020404	 0.068081	 0.01727	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29094	 32032	 0.003511	 0.024101	 0.00703	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29095	 29097	 0.003837	 0.024301	 0.0066	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29095	 29098	 0.004008	 0.016047	 0.00404	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29095	 31300	 0.001119	 0.014073	 0.00436	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29096	 29097	 0.002613	 0.016233	 0.00458	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29096	 85187	 0.009408	 0.037668	 0.00949	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29097	 85184	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29097	 85184	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29098	 29100	 0.003783	 0.022879	 0.00584	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29098	 31300	 0.001789	 0.017173	 0.005	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29099	 85185	 0.10092	 0.092961	 0.00149	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29100	 29102	 0.002042	 0.011734	 0.00332	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85184	 29101	 0.070242	 0.08234	 0.00143	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29101	 85185	 0.011926	 0.027684	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29101	 85186	 0.007159	 0.02785	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29102	 85185	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29102	 85185	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29102	 85187	 0.003477	 0.020363	 0.00555	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29103	 85186	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29103	 85186	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84708	 29104	 0.11229	 0.088865	 0.00112	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29105	 29107	 0.000648	 0.007148	 0.01507	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29105	 85187	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85188	 29105	 0.000262	 0.019645	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85187	 29106	 0.005161	 0.021844	 0.00492	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29106	 85189	 0.002042	 0.019605	 0.0057	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29107	 29108	 0.000169	 0.001713	 0.00389	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29107	 29108	 0.000169	 0.001713	 0.00389	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29107	 85189	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29107	 85189	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29108	 31268	 0.000691	 0.010839	 0.03598	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29108	 85190	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85191	 29108	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29109	 29115	 0.001557	 0.009675	 0.00273	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29109	 29120	 0.001562	 0.008973	 0.00254	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85187	 29109	 0.002834	 0.016597	 0.00452	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85189	 29109	 0.001365	 0.009968	 0.00256	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29109	 85192	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29109	 85192	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29110	 29115	 0.00391	 0.023645	 0.00603	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29110	 29117	 0.00683	 0.024144	 0.00544	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29110	 29125	 0.000763	 0.00642	 0.0019	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29110	 85193	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29110	 85193	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29110	 85863	 0.001332	 0.010033	 0.00278	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29111	 29112	 0.016337	 0.026076	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85193	 29111	 0.012776	 0.02966	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29112	 85194	 0.011096	 0.028219	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29112	 85197	 0.047217	 0.037367	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29113	 29114	 0.000716	 0.005392	 0.0015	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29113	 29125	 0.001186	 0.004938	 0.00154	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29113	 85194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29113	 85194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29114	 29115	 0.000892	 0.007649	 0.00218	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29114	 85195	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29114	 85195	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29115	 29120	 0.000989	 0.004877	 0.00132	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85190	 29115	 0.002662	 0.012917	 0.00295	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29115	 85196	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29115	 85196	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85196	 29116	 0.027466	 0.046268	 0.00066	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29117	 31273	 0.00449	 0.028922	 0.00758	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85187	 29117	 0.003679	 0.03341	 0.01089	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29117	 85197	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29117	 85197	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29118	 29119	 0.000957	 0.005498	 0.00156	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29118	 29120	 0.001266	 0.005152	 0.00126	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29118	 29126	 0.000705	 0.007938	 0.00208	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85189	 29118	 0.00075	 0.011203	 0.00332	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85190	 29118	 0.000699	 0.005059	 0.00272	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29119	 29121	 0.000538	 0.004321	 0.00121	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29119	 85198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29119	 85198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85190	 29120	 0.002506	 0.008597	 0.00206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29121	 29124	 0.001115	 0.007064	 0.00192	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29121	 29125	 0.001088	 0.006752	 0.00164	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29121	 85199	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29121	 85199	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29122	 29123	 0.000686	 0.00426	 0.0012	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29122	 29124	 0.000716	 0.004196	 0.00114	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29122	 29128	 0.001487	 0.006293	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29122	 85200	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29122	 85200	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29123	 29134	 0.001023	 0.005995	 0.00163	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29124	 85201	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29124	 85201	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29125	 85202	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29125	 85202	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29126	 29127	 0.001002	 0.006227	 0.00176	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29126	 29128	 0.002044	 0.010167	 0.00328	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29127	 29128	 0.001233	 0.004938	 0.00124	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29127	 85203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29127	 85203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29128	 29130	 0.000322	 0.004307	 0.00118	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29128	 85204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29128	 85204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29129	 29130	 0.00064	 0.003814	 0.001	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29129	 29133	 0.000575	 0.003157	 0.00083	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29130	 29133	 0.001058	 0.006076	 0.00172	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29130	 85205	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29130	 85205	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85204	 29131	 0.001899	 0.009076	 0.0002	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	85205	 29131	 0.001529	 0.007461	 0.00013	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85205	 29132	 0.007986	 0.00632	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29133	 29136	 0.002474	 0.014737	 0.00388	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29133	 31267	 0.000906	 0.008847	 0.00248	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84703	 29133	 0.002481	 0.024616	 0.00669	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29133	 85206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29133	 85206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29134	 85207	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29134	 85207	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29134	 85863	 0.001539	 0.007336	 0.00213	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29135	 85208	 0.030436	 0.046162	 0.00066	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85187	 29136	 0.008318	 0.048726	 0.01327	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29136	 85208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29136	 85208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85189	 29137	 0.002259	 0.022418	 0.0061	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29138	 29150	 0.032871	 0.0845	 0.00131	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29138	 85970	 0.066012	 0.15633	 0.00286	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84751	 29139	 0.038064	 0.030123	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29140	 85209	 0.025963	 0.041443	 0.00095	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29141	 85209	 0.018923	 0.046319	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29142	 29143	 0.003067	 0.01116	 0.00342	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29142	 85209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29142	 85209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84671	 29143	 0.011661	 0.10005	 0.02849	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29143	 85210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29143	 85210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85209	 29144	 0.04365	 0.040206	 0.00064	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85210	 29144	 0.018856	 0.044651	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29145	 29146	 0.02221	 0.043527	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29145	 29152	 0.059903	 0.11861	 0.00174	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85210	 29145	 0.040039	 0.094815	 0.00173	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29146	 29148	 0.006975	 0.015821	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29146	 85211	 0.006773	 0.017953	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29147	 85211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29147	 85211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29148	 29149	 0.016674	 0.038705	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85209	 29148	 0.039579	 0.084503	 0.00191	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29149	 29152	 0.013146	 0.024078	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29150	 29152	 0.031056	 0.050907	 0.0009	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29151	 29163	 0.039294	 0.080415	 0.00198	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29152	 29155	 0.030797	 0.058206	 0.00094	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29153	 29160	 0.016762	 0.045004	 0.0102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29153	 85212	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29153	 85212	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29154	 29155	 0.021025	 0.054048	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85211	 29154	 0.012245	 0.054565	 0.00093	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29155	 29156	 0.028488	 0.058299	 0.00143	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85212	 29155	 0.023117	 0.042983	 0.00101	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29156	 29159	 0.14956	 0.11837	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29157	 29161	 0.009437	 0.032375	 0.00776	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29157	 31713	 0.037239	 0.11216	 0.03512	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29157	 85213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29157	 85213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29157	 85638	 0.020543	 0.06923	 0.01721	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85077	 29158	 0.16082	 0.28915	 0.00519	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85179	 29158	 0.37881	 0.29707	 0.00381	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29158	 85215	 0.15919	 0.17003	 0.0036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29159	 85214	 0.14544	 0.11157	 0.0015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29160	 29161	 0.012109	 0.032003	 0.00749	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29160	 85214	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29160	 85214	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29161	 85215	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29161	 85215	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85211	 29162	 0.05365	 0.053808	 0.00087	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29164	 29270	 0.002239	 0.007304	 0.00194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29164	 29279	 0.001242	 0.005697	 0.00146	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29164	 85216	 0.000507	 0.002881	 0.00083	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29165	 29175	 0.000272	 0.001725	 0.00361	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29165	 85216	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85217	 29165	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29166	 29168	 0.005284	 0.013695	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29166	 29169	 0.003714	 0.012391	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29167	 29168	 0.00699	 0.013839	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29167	 85268	 0.00747	 0.012583	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85217	 29168	 0.010486	 0.026954	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29169	 29170	 0.002431	 0.010879	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29170	 29173	 0.00311	 0.008242	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29170	 29182	 0.009799	 0.023205	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29171	 29307	 0.005183	 0.017291	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29171	 85218	 0.003843	 0.014784	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29172	 29356	 0.001425	 0.004288	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29172	 85218	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29172	 85218	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85218	 29173	 0.003548	 0.01581	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29174	 29182	 0.01239	 0.027798	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29175	 29267	 0.000184	 0.001442	 0.00248	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29175	 85219	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29175	 85219	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29176	 29177	 0.00717	 0.007887	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85217	 29176	 0.011395	 0.011509	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85219	 29177	 0.006179	 0.010867	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29178	 29186	 0.000968	 0.00436	 0.00116	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29178	 85220	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29178	 85220	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29179	 29187	 0.005292	 0.013603	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85220	 29179	 0.008871	 0.017563	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29179	 85263	 0.00417	 0.012805	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29180	 29181	 0.015013	 0.011768	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29181	 29182	 0.007595	 0.015037	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29181	 85222	 0.005492	 0.012748	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29182	 85222	 0.010614	 0.024384	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29182	 85286	 0.007749	 0.040295	 0.00087	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29183	 29185	 0.001128	 0.004514	 0.00152	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29183	 29193	 0.00048	 0.003744	 0.00112	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29183	 29357	 0.001282	 0.005882	 0.00151	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29183	 29359	 0.000497	 0.002499	 0.00065	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29183	 85221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29183	 85221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85221	 29184	 0.016259	 0.010526	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29185	 29186	 0.000772	 0.003032	 0.00079	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29185	 85222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29185	 85222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29186	 29191	 0.001284	 0.00514	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29187	 85223	 0.005795	 0.014896	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29188	 29189	 0.000392	 0.002157	 0.00078	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29188	 29203	 0.000427	 0.003115	 0.0008	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29188	 85223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29188	 85223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29189	 29190	 0.000312	 0.001979	 0.00054	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29190	 29191	 0.000313	 0.002017	 0.00053	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29191	 29192	 0.000729	 0.002456	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29191	 85224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29191	 85224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29192	 29193	 0.000897	 0.002992	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29193	 29197	 0.00096	 0.004479	 0.00111	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29193	 85225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29193	 85225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29194	 29196	 0.001647	 0.004352	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29194	 29198	 0.00128	 0.007953	 0.00224	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29194	 85226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29194	 85226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29194	 85276	 0.001797	 0.013462	 0.00328	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29195	 85227	 0.016879	 0.025857	 0.00036	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29195	 85334	 0.00819	 0.021052	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29196	 85227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29196	 85227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29197	 85236	 0.000814	 0.003544	 0.00101	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29198	 29199	 0.000518	 0.00211	 0.00051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29198	 85228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29198	 85228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29198	 85236	 0.000967	 0.003259	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29199	 29201	 0.000597	 0.002527	 0.00057	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29200	 85229	 0.014491	 0.009381	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29201	 29208	 0.000699	 0.002798	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29201	 85229	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29201	 85229	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85229	 29202	 0.011752	 0.008496	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29203	 29204	 0.000317	 0.002241	 0.00061	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29204	 29207	 0.000365	 0.002507	 0.00073	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29205	 29207	 0.00135	 0.006192	 0.00159	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29205	 85230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29205	 85230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29205	 85287	 0.001711	 0.006725	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29206	 29222	 0.000291	 0.003598	 0.01299	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29206	 29361	 0.000366	 0.003306	 0.00652	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84680	 29206	 0.00028	 0.004024	 0.01601	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29206	 85231	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85232	 29206	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29207	 85233	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29207	 85233	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29207	 85244	 0.000513	 0.005014	 0.00141	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29208	 85242	 0.000765	 0.003114	 0.00076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29209	 29211	 5.9e-05	 0.000824	 0.00342	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29209	 29222	 4.2e-05	 0.000717	 0.00253	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29209	 85234	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29209	 85234	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29210	 29211	 0.000122	 0.000852	 0.00145	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29210	 85235	 0.003027	 0.10896	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29210	 85235	 0.003027	 0.10896	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29211	 29479	 0.000348	 0.004441	 0.01735	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29211	 85236	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29211	 85236	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29212	 29213	 0.000897	 0.002443	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29212	 29218	 0.000853	 0.004285	 0.00112	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85236	 29212	 0.000402	 0.001791	 0.00049	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29213	 85237	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29213	 85237	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29214	 29217	 0.018052	 0.011687	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85227	 29214	 0.006478	 0.013615	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85237	 29214	 0.00733	 0.013226	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29215	 29227	 0.000384	 0.002494	 0.00497	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29215	 85238	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85239	 29215	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85239	 29216	 0.015613	 0.012356	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29217	 29226	 0.015472	 0.010017	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29218	 29219	 0.001119	 0.003004	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29218	 29231	 0.00181	 0.00815	 0.00217	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29218	 85240	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29218	 85240	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29219	 29220	 0.000933	 0.003202	 0.00077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29219	 85241	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29219	 85241	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29220	 85242	 0.000791	 0.002714	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29221	 85245	 0.01292	 0.010128	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29222	 85242	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29222	 85242	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29222	 85243	 8.1e-05	 0.000959	 0.00327	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29223	 29338	 9.7e-05	 0.001632	 0.15868	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29223	 85243	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85244	 29223	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29224	 29231	 0.002031	 0.009318	 0.00239	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84681	 29224	 0.000453	 0.007291	 0.00238	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85242	 29224	 0.000855	 0.008713	 0.00225	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29224	 85245	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29224	 85245	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29225	 29230	 0.014844	 0.011747	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85241	 29225	 0.005526	 0.010829	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85240	 29226	 0.023677	 0.018559	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29226	 85248	 0.006146	 0.00981	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29227	 29479	 0.000744	 0.004832	 0.00962	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29227	 85246	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85247	 29227	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85239	 29228	 0.012823	 0.02513	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29228	 85249	 0.028387	 0.028672	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29229	 29231	 0.000605	 0.003357	 0.00102	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85238	 29229	 0.002517	 0.010654	 0.0024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85246	 29229	 0.001302	 0.004246	 0.00113	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29229	 85248	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29229	 85248	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29231	 29232	 0.00095	 0.00229	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29231	 29240	 0.001594	 0.008895	 0.00227	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29232	 29233	 0.00115	 0.00304	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29233	 85249	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29233	 85249	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85247	 29234	 0.010612	 0.022303	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85249	 29234	 0.018015	 0.014121	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29234	 85250	 0.009284	 0.019895	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29235	 29237	 0.01467	 0.011609	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29235	 85250	 0.010099	 0.008312	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29236	 29238	 0.002122	 0.008761	 0.00207	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84667	 29236	 0.005194	 0.020414	 0.00534	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29236	 85250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29236	 85250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29237	 85251	 0.008003	 0.015845	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29238	 29240	 0.000717	 0.004408	 0.00127	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85246	 29238	 0.002489	 0.009967	 0.00251	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29238	 85251	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29238	 85251	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29239	 29242	 0.004878	 0.012539	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29239	 85252	 0.004973	 0.012783	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84652	 29240	 0.003692	 0.03358	 0.00848	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84681	 29240	 0.003686	 0.017889	 0.00409	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29240	 85252	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29240	 85252	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29240	 85255	 0.003112	 0.012458	 0.00314	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29241	 29243	 0.010618	 0.019158	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85252	 29241	 0.006753	 0.013819	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29242	 29244	 0.018074	 0.016949	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29243	 85254	 0.031849	 0.020619	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29244	 29245	 0.003274	 0.005227	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84668	 29244	 0.085002	 0.085856	 0.00114	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29244	 85254	 0.013501	 0.02436	 0.00035	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85250	 29245	 0.007661	 0.017783	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29246	 85253	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85254	 29246	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84651	 29247	 0.000618	 0.009522	 0.02098	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29247	 85255	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29247	 85255	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29247	 85275	 0.001042	 0.015586	 0.03646	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84746	 29248	 0.022714	 0.074958	 0.00121	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29248	 85256	 0.035416	 0.082224	 0.00122	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29249	 29263	 0.003293	 0.011521	 0.00382	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29249	 29379	 0.002869	 0.010905	 0.00305	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29249	 85256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29249	 85256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29250	 29386	 0.023714	 0.039606	 0.00067	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29251	 29252	 0.003505	 0.01578	 0.0042	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29251	 29388	 0.001903	 0.008729	 0.00224	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29252	 85257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29252	 85257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29253	 29254	 0.001504	 0.005852	 0.00156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29253	 29264	 0.001911	 0.00789	 0.00187	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29254	 29270	 0.001364	 0.005551	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29255	 31291	 0.002573	 0.016294	 0.00442	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29255	 85258	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29255	 85258	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29256	 31292	 0.003412	 0.011939	 0.00396	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29256	 85259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29256	 85259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29257	 29259	 0.008416	 0.019091	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29257	 29261	 0.075233	 0.059539	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29257	 29477	 0.054851	 0.041557	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85259	 29257	 0.005573	 0.020608	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29258	 29259	 0.014864	 0.032897	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29258	 29292	 0.030177	 0.022202	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29258	 29476	 0.039088	 0.030934	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29258	 85270	 0.022712	 0.053782	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29260	 29262	 0.002313	 0.007935	 0.0019	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29260	 29294	 0.004772	 0.014068	 0.00327	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29262	 29263	 0.002537	 0.008703	 0.00208	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29263	 85260	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29263	 85260	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29264	 29363	 0.002888	 0.011563	 0.00291	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29264	 85261	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29264	 85261	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29265	 29266	 0.001035	 0.00414	 0.0014	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29265	 29269	 0.00087	 0.003992	 0.00102	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29266	 29363	 0.004037	 0.011256	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29266	 85262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29266	 85262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29266	 85264	 0.001633	 0.006741	 0.0016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29267	 29268	 0.000135	 0.000913	 0.00166	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29267	 29361	 0.000486	 0.003079	 0.00645	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29267	 85263	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29267	 85263	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29268	 85264	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29268	 85264	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85216	 29269	 0.001622	 0.007441	 0.00191	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29270	 29294	 0.003465	 0.009938	 0.00245	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29270	 85265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29270	 85265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85265	 29271	 0.01212	 0.012376	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29272	 29281	 0.000664	 0.002891	 0.00082	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29272	 29302	 0.00137	 0.006286	 0.00161	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29272	 85266	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29272	 85266	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29273	 85267	 0.008009	 0.015857	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29274	 85269	 0.015545	 0.011778	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29275	 29276	 0.015446	 0.018491	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85265	 29276	 0.00344	 0.013383	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29276	 85270	 0.009196	 0.026096	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29277	 85269	 0.008645	 0.013111	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29278	 29287	 0.027736	 0.079552	 0.00122	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29278	 29290	 0.009682	 0.022477	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29278	 85269	 0.003223	 0.015726	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29279	 29281	 0.000401	 0.001743	 0.0005	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29279	 85267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29279	 85267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85267	 29280	 0.011271	 0.00892	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29281	 85268	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29281	 85268	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29282	 29283	 0.006613	 0.007203	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85266	 29283	 0.004972	 0.012781	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85216	 29284	 0.001316	 0.007707	 0.0021	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29284	 85269	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29284	 85269	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29285	 29288	 0.03754	 0.024303	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29285	 29290	 0.008802	 0.020223	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29285	 85272	 0.011043	 0.022599	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29286	 29287	 0.016861	 0.023936	 0.00039	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29287	 29289	 0.015216	 0.034957	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29289	 29291	 0.013369	 0.040238	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29291	 29293	 0.003778	 0.014474	 0.00041	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85258	 29293	 0.003091	 0.016282	 0.00029	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29294	 85270	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29294	 85270	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85270	 29295	 0.023472	 0.025817	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29296	 29300	 0.013781	 0.031993	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29296	 29324	 0.012318	 0.025888	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29297	 29336	 0.005205	 0.012084	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29297	 85271	 0.007758	 0.018012	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29298	 29302	 0.001913	 0.007659	 0.00193	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29298	 85271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29298	 85271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29299	 85272	 0.025805	 0.020421	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85271	 29300	 0.012595	 0.023418	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29301	 29305	 0.005572	 0.014324	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29301	 85272	 0.007111	 0.016507	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29302	 29317	 0.004426	 0.018012	 0.00439	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29302	 85272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29302	 85272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29303	 29304	 0.005561	 0.014142	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29303	 29307	 0.007205	 0.023776	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85266	 29304	 0.01245	 0.012713	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29305	 85274	 0.011351	 0.027785	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29306	 29310	 0.023474	 0.015197	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29307	 29354	 0.010396	 0.026943	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29308	 85274	 0.010091	 0.013021	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29309	 85273	 0.024067	 0.018865	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29310	 85273	 0.00969	 0.015467	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29311	 29315	 0.019393	 0.049852	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29311	 29325	 0.038504	 0.027274	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29311	 29326	 0.015799	 0.03668	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29312	 29314	 0.023015	 0.016637	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29313	 29315	 0.014076	 0.0185	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29314	 29316	 0.014086	 0.026976	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29315	 85281	 0.004335	 0.024639	 0.00045	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29316	 85273	 0.015911	 0.020911	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29316	 85281	 0.00856	 0.019871	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29317	 29318	 0.00278	 0.008441	 0.00185	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29317	 85273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29317	 85273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29317	 85280	 0.000632	 0.005475	 0.00197	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29318	 29319	 0.001092	 0.003395	 0.00071	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29319	 85274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29319	 85274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29319	 85276	 0.003228	 0.018349	 0.00531	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29320	 29330	 0.057993	 0.042667	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29321	 29322	 0.008716	 0.020234	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29321	 29330	 0.019156	 0.049242	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29321	 85281	 0.01862	 0.057123	 0.00155	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29322	 29332	 0.005881	 0.010935	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29323	 29333	 0.008673	 0.028932	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29323	 85858	 0.010965	 0.033672	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29324	 31259	 0.009742	 0.022617	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29326	 29327	 0.004485	 0.012864	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29326	 29333	 0.010314	 0.040126	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29326	 29335	 0.026769	 0.019695	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29326	 29336	 0.008508	 0.020147	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29327	 29328	 0.012305	 0.016172	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85274	 29327	 0.004258	 0.01638	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29329	 29330	 0.027153	 0.035688	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29329	 31533	 0.045413	 0.049464	 0.00067	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29329	 85919	 0.087576	 0.069308	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29331	 85278	 0.047916	 0.032187	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29332	 29340	 0.005891	 0.013674	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29333	 29334	 0.025426	 0.02294	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29335	 29480	 0.021935	 0.017359	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29337	 85277	 0.0137	 0.018006	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29338	 31459	 0.000298	 0.003715	 0.25458	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29338	 85275	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29338	 85275	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29339	 29341	 0.000822	 0.00348	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29339	 29350	 0.001429	 0.005722	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29339	 85278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29339	 85278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85278	 29340	 0.01643	 0.025168	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29340	 85279	 0.00404	 0.010681	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29341	 29346	 0.000853	 0.003803	 0.00103	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29341	 85279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29341	 85279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29342	 85282	 0.009141	 0.017505	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29343	 32038	 0.007969	 0.097736	 0.2017	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85275	 29343	 0.000192	 0.001909	 0.00637	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29343	 85280	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85281	 29343	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29344	 29346	 0.000822	 0.004817	 0.00131	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85276	 29344	 0.001161	 0.008209	 0.00225	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29344	 85282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29344	 85282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85282	 29345	 0.006288	 0.015991	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29346	 85283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29346	 85283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85283	 29347	 0.012811	 0.014091	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29348	 29352	 0.000756	 0.003846	 0.00139	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85276	 29348	 0.001079	 0.006695	 0.00162	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29348	 85284	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29348	 85284	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85284	 29349	 0.018595	 0.016662	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29350	 31531	 0.001269	 0.004618	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29351	 85285	 0.014072	 0.027578	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29352	 29478	 0.001221	 0.005168	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29352	 85285	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29352	 85285	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29353	 29358	 0.000518	 0.002978	 0.00084	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85276	 29353	 0.000887	 0.006646	 0.00162	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29353	 85286	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29353	 85286	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85273	 29354	 0.003343	 0.012809	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29355	 29357	 0.000825	 0.00499	 0.00127	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85276	 29355	 0.000962	 0.006447	 0.00197	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29356	 29357	 0.000973	 0.003824	 0.001	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29358	 29360	 0.00042	 0.002003	 0.00058	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29359	 29360	 0.000402	 0.00198	 0.00054	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29361	 29373	 0.000692	 0.004851	 0.00826	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29361	 85287	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29361	 85287	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85232	 29362	 0.009364	 0.024071	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29363	 85288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29363	 85288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29363	 85290	 0.000918	 0.007032	 0.00188	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29364	 29367	 0.011886	 0.030108	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29364	 29368	 0.007246	 0.02679	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85288	 29364	 0.007197	 0.027999	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29365	 29367	 0.014361	 0.028144	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29366	 29367	 0.006852	 0.013121	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29367	 29369	 0.007905	 0.026372	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29368	 85292	 0.00401	 0.021368	 0.00037	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29369	 29370	 0.019945	 0.020145	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29369	 85292	 0.011799	 0.038937	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29370	 29371	 0.011084	 0.025732	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29371	 29380	 0.047053	 0.037237	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29371	 85289	 0.004788	 0.018344	 0.00052	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29372	 29379	 0.005043	 0.019168	 0.00537	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29372	 29397	 0.001893	 0.008012	 0.0018	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29372	 85289	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29372	 85289	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29373	 29376	 0.00052	 0.004279	 0.00882	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29373	 85290	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85291	 29373	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29374	 29409	 0.011798	 0.016748	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29374	 85292	 0.01788	 0.023269	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29376	 29404	 0.000274	 0.002347	 0.00447	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29376	 85292	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29376	 85292	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29377	 29378	 0.00869	 0.017205	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85292	 29377	 0.010467	 0.017456	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29378	 85300	 0.008519	 0.019324	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29379	 29382	 0.004163	 0.011176	 0.00253	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29381	 29384	 0.048156	 0.034111	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85289	 29381	 0.082378	 0.064573	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29382	 29383	 0.001842	 0.006419	 0.00149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29382	 29392	 0.003611	 0.014194	 0.00371	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29382	 85293	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29382	 85293	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29383	 29388	 0.003522	 0.012813	 0.00392	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29383	 29392	 0.001476	 0.007511	 0.00272	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29383	 85294	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29383	 85294	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85294	 29384	 0.010621	 0.020074	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29385	 29389	 0.012048	 0.018798	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85293	 29385	 0.02665	 0.044894	 0.00064	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29385	 85295	 0.013085	 0.033278	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29386	 29387	 0.013154	 0.026044	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85293	 29386	 0.011424	 0.027053	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29387	 85295	 0.004602	 0.015352	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29388	 29390	 0.003424	 0.010096	 0.00235	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29388	 85295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29388	 85295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29389	 29391	 0.007702	 0.034319	 0.00058	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29390	 31611	 0.005312	 0.018514	 0.00429	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29390	 31617	 0.003301	 0.011323	 0.00271	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29390	 85296	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29390	 85296	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29391	 85297	 0.004881	 0.033507	 0.00061	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29392	 29393	 0.002054	 0.011396	 0.00346	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29392	 29394	 0.003532	 0.01714	 0.00392	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29393	 29394	 0.005773	 0.014988	 0.00364	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29393	 85297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29393	 85297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29395	 29405	 0.017662	 0.019426	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29395	 85298	 0.018489	 0.018543	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85289	 29396	 0.007619	 0.015657	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29396	 85298	 0.006453	 0.016588	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29397	 29398	 0.000714	 0.003631	 0.00132	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29397	 85298	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29397	 85298	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29398	 29400	 0.001744	 0.006981	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29398	 85304	 0.002214	 0.007459	 0.00185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85298	 29399	 0.045456	 0.041012	 0.00069	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29400	 29452	 0.00165	 0.006605	 0.00166	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29401	 29404	 0.000366	 0.003155	 0.00593	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29401	 29423	 0.000223	 0.002403	 0.00477	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29401	 85299	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29401	 85299	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29402	 29409	 0.008467	 0.019657	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29402	 85301	 0.005272	 0.013937	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29403	 29413	 0.021531	 0.013939	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29403	 85302	 0.014491	 0.010661	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29404	 85300	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29404	 85300	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85300	 29405	 0.012	 0.021434	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29406	 29407	 0.013194	 0.01734	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85300	 29406	 0.027189	 0.021517	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85299	 29407	 0.011383	 0.022537	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29408	 29409	 0.028111	 0.022247	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29408	 29428	 0.004409	 0.013526	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29410	 29411	 0.026931	 0.021313	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29410	 29412	 0.012925	 0.013197	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29410	 29432	 0.008043	 0.015201	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29412	 29413	 0.012908	 0.012911	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29412	 85301	 0.04437	 0.035114	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29412	 85309	 0.011922	 0.036612	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29414	 29415	 0.001855	 0.004979	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29414	 85301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29414	 85301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29415	 29417	 0.002635	 0.009038	 0.00217	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29415	 85302	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29415	 85302	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29416	 29420	 0.02064	 0.015637	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29416	 85303	 0.028717	 0.022726	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29417	 29450	 0.003869	 0.010224	 0.00239	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29417	 85303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29417	 85303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29417	 85304	 0.002326	 0.006147	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29418	 85305	 0.019804	 0.026029	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29419	 29420	 0.016808	 0.013175	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29419	 29421	 0.031781	 0.025151	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29419	 85310	 0.003934	 0.013438	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29421	 29422	 0.02954	 0.021733	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85303	 29422	 0.02864	 0.022665	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29422	 85320	 0.024093	 0.024334	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29423	 29453	 0.000477	 0.00509	 0.01035	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29423	 85304	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85305	 29423	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85305	 29424	 0.024329	 0.017588	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29425	 29429	 0.000616	 0.006404	 0.00198	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84681	 29425	 0.000811	 0.008589	 0.00255	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85231	 29425	 0.000342	 0.004283	 0.00291	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29425	 85306	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29425	 85306	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29425	 85308	 0.000734	 0.01012	 0.00453	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29426	 29427	 0.009192	 0.016585	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29426	 29428	 0.0073	 0.016947	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85306	 29426	 0.003914	 0.026867	 0.00049	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29428	 85307	 0.007821	 0.033098	 0.00062	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29429	 85307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29429	 85307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29429	 85308	 0.000526	 0.00648	 0.00209	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29430	 29451	 0.000269	 0.003476	 0.22187	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29430	 85308	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29430	 85308	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29431	 29433	 0.001485	 0.00447	 0.0014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85308	 29431	 0.001112	 0.007866	 0.00216	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29431	 85309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29431	 85309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85307	 29432	 0.005389	 0.026269	 0.00049	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29433	 29442	 0.004786	 0.013424	 0.00346	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29433	 85310	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29433	 85310	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29434	 85311	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29435	 29438	 0.02113	 0.023241	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85309	 29435	 0.01436	 0.028432	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84748	 29436	 0.043666	 0.034557	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29437	 29439	 0.001209	 0.005545	 0.00142	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85311	 29437	 0.000877	 0.00446	 0.00162	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29438	 85314	 0.018629	 0.023708	 0.00035	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29439	 29446	 0.001514	 0.006251	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29440	 29451	 0.000121	 0.001513	 0.10368	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29440	 85313	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29440	 85313	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29441	 29903	 0.22312	 0.15808	 0.0025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29441	 85315	 0.14027	 0.090818	 0.00173	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29442	 29448	 0.002073	 0.01006	 0.0023	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29442	 29450	 0.003081	 0.007999	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29442	 85314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29442	 85314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29443	 85318	 0.060749	 0.043032	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29443	 85319	 0.050289	 0.035622	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29444	 29445	 0.007979	 0.020716	 0.00503	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29444	 29447	 0.003267	 0.011206	 0.00268	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29444	 85315	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29444	 85315	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29445	 29466	 0.00274	 0.007641	 0.0016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84687	 29445	 0.005016	 0.019065	 0.00534	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29446	 29447	 0.003309	 0.008318	 0.00216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29446	 29448	 0.001113	 0.00388	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29446	 85316	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29446	 85316	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29447	 29448	 0.00226	 0.005868	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29447	 85317	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29447	 85317	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29448	 85318	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29448	 85318	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29449	 29450	 0.002138	 0.005495	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29449	 29454	 0.0033	 0.010764	 0.00286	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29449	 85319	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29449	 85319	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29450	 85320	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29450	 85320	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29451	 85321	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29451	 85321	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29452	 85322	 0.001111	 0.005096	 0.00131	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29453	 31698	 0.003222	 0.020411	 0.04275	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	85313	 29453	 0.002074	 0.014143	 0.02547	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	85321	 29453	 0.00042	 0.004801	 0.01038	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29453	 85322	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29453	 85322	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85322	 29454	 0.001479	 0.005354	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29455	 29890	 0.003896	 0.022147	 0.00641	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29455	 29901	 0.004322	 0.014825	 0.00355	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29455	 85323	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29455	 85323	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29455	 85329	 0.002733	 0.014687	 0.00361	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29456	 29470	 0.000648	 0.004396	 0.008	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84686	 29456	 0.001131	 0.007714	 0.01389	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29457	 29458	 0.002615	 0.008972	 0.00215	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29457	 29473	 0.002508	 0.007838	 0.00227	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29458	 29460	 0.001284	 0.003845	 0.00087	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29458	 85324	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29458	 85324	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29459	 29461	 0.034554	 0.027085	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29459	 85332	 0.018013	 0.034495	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29460	 29464	 0.001834	 0.005114	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29461	 29462	 0.027344	 0.02164	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29462	 85326	 0.024914	 0.018876	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29463	 85330	 0.035742	 0.028286	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29464	 29466	 0.002214	 0.005851	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29464	 85325	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29464	 85325	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85325	 29465	 0.018659	 0.013488	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29466	 85326	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29466	 85326	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85323	 29467	 0.03813	 0.030175	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29468	 29473	 0.001651	 0.005663	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84652	 29468	 0.000836	 0.004899	 0.00133	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29468	 85327	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29468	 85327	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29469	 29470	 0.000217	 0.001895	 0.00345	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84651	 29469	 0.00074	 0.008555	 0.01639	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29469	 85328	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29469	 85328	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29470	 85329	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85330	 29470	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29471	 29472	 0.00138	 0.005423	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84652	 29471	 0.000971	 0.004594	 0.0011	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29472	 29474	 0.002292	 0.008917	 0.00238	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29472	 85331	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29472	 85331	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85328	 29474	 0.002579	 0.008412	 0.00223	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84652	 29475	 0.003218	 0.019971	 0.00484	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85328	 29475	 0.002458	 0.006496	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85329	 29475	 0.002699	 0.009405	 0.00218	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29475	 85332	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29475	 85332	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29478	 31394	 0.007506	 0.030053	 0.00757	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85275	 29479	 0.000278	 0.002881	 0.0062	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85275	 29479	 0.000278	 0.002881	 0.0062	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29479	 85333	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85334	 29479	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29481	 29483	 0.07085	 0.12461	 0.00234	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29481	 85335	 0.22218	 0.17045	 0.00229	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29481	 85353	 0.20182	 0.20388	 0.0027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29482	 29483	 0.058604	 0.1681	 0.00259	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29482	 86143	 0.03334	 0.16867	 0.00293	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29483	 85335	 0.17323	 0.1371	 0.00173	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29484	 85335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29484	 85335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29484	 85623	 0.042263	 0.19744	 0.04901	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29485	 29501	 0.016734	 0.023755	 0.00039	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29485	 85339	 0.010218	 0.026266	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29486	 85351	 0.009349	 0.016869	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29487	 29494	 0.016571	 0.030351	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29487	 85338	 0.01305	 0.026705	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29488	 29514	 3.5e-05	 0.000441	 0.03021	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29488	 85336	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29489	 29496	 0.00144	 0.005944	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29489	 85339	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29489	 85339	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29489	 85340	 0.000743	 0.003409	 0.00087	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29490	 85340	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29490	 85340	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29490	 85350	 0.000444	 0.003055	 0.00539	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29491	 85347	 0.037512	 0.068707	 0.00119	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84736	 29492	 0.031561	 0.062488	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29492	 85342	 0.051878	 0.039305	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29493	 29494	 0.014511	 0.03369	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84736	 29493	 0.00994	 0.0213	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29495	 29498	 0.000305	 0.001981	 0.00395	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29496	 29497	 0.001314	 0.005259	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29497	 85341	 0.002442	 0.006647	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29497	 85343	 0.00263	 0.006815	 0.00206	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29498	 29500	 0.000493	 0.003361	 0.00605	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29498	 85341	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29498	 85341	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29499	 31790	 0.003391	 0.009997	 0.00233	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85341	 29499	 0.00257	 0.007993	 0.00167	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29499	 85342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29499	 85342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29500	 31778	 0.002037	 0.013745	 0.02531	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29500	 85343	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85344	 29500	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85344	 29502	 0.017543	 0.045097	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29503	 29504	 0.000142	 0.001929	 0.00662	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29503	 29511	 0.000517	 0.003403	 0.00658	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29503	 85350	 0.000488	 0.003859	 0.01339	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84943	 29504	 0.002075	 0.032556	 0.06914	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85336	 29504	 0.000408	 0.004515	 0.01045	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29505	 29509	 0.016267	 0.037767	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29505	 29512	 0.025309	 0.050109	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29505	 85346	 0.021303	 0.035578	 0.0006	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29506	 29507	 0.002674	 0.015927	 0.00419	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85337	 29506	 0.001282	 0.010643	 0.0028	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29506	 85345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29506	 85345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29507	 29508	 0.001738	 0.008281	 0.0024	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29507	 85346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29507	 85346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29508	 29510	 0.001827	 0.008326	 0.00264	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29508	 85347	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29508	 85347	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29509	 85348	 0.017903	 0.035446	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29510	 85348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29510	 85348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84944	 29512	 0.1192	 0.2768	 0.00412	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85345	 29512	 0.021327	 0.071146	 0.00113	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29512	 85349	 0.17478	 0.17532	 0.00283	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29513	 30608	 0.023845	 0.092802	 0.0248	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29513	 85349	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29513	 85349	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29514	 85350	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29515	 29516	 0.01922	 0.051604	 0.0117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29515	 85352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29515	 85352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29516	 29517	 0.015129	 0.038892	 0.00963	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29517	 29523	 0.04434	 0.16071	 0.03453	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29517	 85353	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29517	 85353	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29517	 85623	 0.038487	 0.22596	 0.06176	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29518	 29519	 0.048464	 0.12326	 0.00195	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29518	 32190	 0.054233	 0.10738	 0.00158	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85353	 29518	 0.061694	 0.1586	 0.00245	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29519	 85354	 0.051247	 0.091537	 0.00135	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29520	 29524	 0.015827	 0.041092	 0.00997	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29520	 85354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29520	 85354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29521	 29522	 0.029805	 0.11467	 0.00196	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85354	 29521	 0.064712	 0.11677	 0.00169	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29522	 33953	 0.072326	 0.18594	 0.00288	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85352	 29522	 0.020973	 0.11175	 0.00196	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29523	 29524	 0.013259	 0.03078	 0.00938	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29523	 29795	 0.025878	 0.15173	 0.04139	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29523	 85355	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29523	 85355	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29524	 85356	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29524	 85356	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29525	 32194	 0.13811	 0.22229	 0.00348	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85354	 29525	 0.075804	 0.1277	 0.00182	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29526	 29810	 0.083143	 0.21376	 0.00331	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29526	 33354	 0.17234	 0.43855	 0.00694	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29526	 34008	 0.16669	 0.38715	 0.00576	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29526	 85357	 0.050577	 0.10351	 0.00255	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29527	 29834	 0.011907	 0.059834	 0.01557	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29527	 34007	 0.018025	 0.073363	 0.01788	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29527	 85357	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29527	 85357	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29527	 85440	 0.016573	 0.10289	 0.02494	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29528	 29819	 0.001496	 0.011429	 0.04248	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29528	 32054	 0.001672	 0.016306	 0.05679	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29528	 85358	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29528	 85358	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85083	 29529	 0.14732	 0.5268	 0.01047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29529	 85445	 0.10033	 0.31867	 0.00559	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29529	 86096	 0.086545	 0.15459	 0.00228	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29530	 29836	 0.030598	 0.16324	 0.04589	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29530	 32048	 0.014578	 0.061709	 0.01389	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29530	 32052	 0.006105	 0.025839	 0.00581	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85082	 29530	 0.008157	 0.066223	 0.02109	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29531	 29532	 0.088528	 0.13562	 0.0019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29531	 85359	 0.05622	 0.16126	 0.00248	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29531	 86126	 0.051225	 0.20502	 0.00433	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29532	 29533	 0.089427	 0.083216	 0.00157	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84745	 29533	 0.004718	 0.01557	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29534	 29535	 0.004572	 0.023355	 0.00587	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84711	 29534	 0.004227	 0.021236	 0.00553	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29535	 29926	 0.012764	 0.064139	 0.0167	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29535	 85359	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29535	 85359	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29536	 85368	 0.071527	 0.076386	 0.00162	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29537	 29539	 0.016683	 0.038731	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84745	 29537	 0.023042	 0.076867	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29538	 29541	 0.000651	 0.00381	 0.00104	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29538	 29545	 0.00415	 0.022343	 0.00614	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29538	 85360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29538	 85360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85360	 29539	 0.011109	 0.023805	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84745	 29540	 0.034375	 0.055141	 0.00102	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29541	 29569	 0.001032	 0.006041	 0.00165	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85360	 29542	 0.007077	 0.018193	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29543	 29549	 0.017513	 0.053726	 0.00146	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29543	 85362	 0.011893	 0.041612	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29544	 29545	 0.001809	 0.015012	 0.00395	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29544	 29553	 0.002647	 0.015888	 0.00481	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29544	 29926	 0.010769	 0.035927	 0.00911	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29545	 29546	 0.001171	 0.007082	 0.00181	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29545	 85361	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29545	 85361	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29546	 29547	 0.00141	 0.006347	 0.00169	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29547	 29565	 0.002126	 0.012454	 0.00339	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29547	 85362	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29547	 85362	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29548	 29549	 0.008313	 0.040585	 0.00085	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29548	 29550	 0.004913	 0.030188	 0.00069	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29548	 29551	 0.020237	 0.055982	 0.0013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29548	 85364	 0.006232	 0.035019	 0.00065	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29549	 29558	 0.009874	 0.043505	 0.00076	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29549	 86092	 0.01919	 0.08504	 0.00255	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29550	 29554	 0.018094	 0.038774	 0.00068	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29550	 86092	 0.023909	 0.055499	 0.00106	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29550	 86095	 0.021283	 0.082799	 0.00138	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29551	 29552	 0.01042	 0.020188	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29551	 29554	 0.006989	 0.026779	 0.00076	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29551	 86090	 0.004867	 0.021443	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29552	 85465	 0.017417	 0.035643	 0.00088	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29553	 29929	 0.003284	 0.020382	 0.00494	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29553	 85363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29553	 85363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85363	 29554	 0.009732	 0.029854	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29555	 85364	 0.006851	 0.047028	 0.00086	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29555	 85365	 0.030156	 0.048529	 0.00076	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29555	 85366	 0.007679	 0.029541	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29556	 85364	 0.006484	 0.025224	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29556	 85365	 0.008866	 0.034111	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29557	 85364	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29557	 85364	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29557	 86091	 0.003695	 0.022179	 0.00672	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29558	 85365	 0.00507	 0.019722	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29559	 29560	 0.001781	 0.006999	 0.00183	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29559	 85365	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29559	 85365	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29560	 29573	 0.00376	 0.01797	 0.00629	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29560	 85366	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29560	 85366	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29561	 29564	 0.030952	 0.065054	 0.00119	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85365	 29561	 0.012644	 0.049189	 0.00082	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29562	 29563	 0.005634	 0.014483	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29562	 29566	 0.007834	 0.024057	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85364	 29562	 0.060178	 0.20077	 0.00318	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29563	 85367	 0.009958	 0.025599	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29564	 85367	 0.016616	 0.026654	 0.00049	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29564	 85373	 0.050266	 0.1167	 0.00174	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29565	 29571	 0.004614	 0.021165	 0.00542	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29565	 85367	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29565	 85367	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29566	 29568	 0.006898	 0.022211	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29567	 29570	 0.007728	 0.030067	 0.00803	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29567	 30810	 0.005422	 0.021092	 0.00563	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29567	 85368	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29567	 85368	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29568	 85369	 0.005494	 0.021138	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29569	 29570	 0.000584	 0.004842	 0.00127	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29569	 85369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29569	 85369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29570	 30815	 0.005154	 0.018033	 0.00598	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29571	 30808	 0.010373	 0.042832	 0.01013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29571	 85370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29571	 85370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29572	 29576	 0.003844	 0.023885	 0.00674	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29572	 85371	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29572	 85371	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29572	 86091	 0.008251	 0.052265	 0.01419	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29573	 29574	 0.002606	 0.014301	 0.00378	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29573	 85372	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29573	 85372	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29574	 29579	 0.004808	 0.027926	 0.00658	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29574	 85373	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29574	 85373	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29575	 31633	 0.009873	 0.047059	 0.01363	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29575	 32045	 0.006789	 0.030252	 0.00822	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29575	 85374	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29575	 85374	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29576	 29577	 0.003284	 0.020802	 0.00565	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29576	 85375	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29576	 85375	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29577	 29584	 0.003677	 0.018131	 0.0049	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29577	 85376	 0.001773	 0.016226	 0.0065	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29577	 86091	 0.012632	 0.094692	 0.02311	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85375	 29578	 0.060036	 0.076407	 0.00112	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29579	 29584	 0.002617	 0.0127	 0.0029	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29580	 29585	 0.000694	 0.004503	 0.00897	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29580	 85376	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85377	 29580	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29581	 29583	 0.022666	 0.052621	 0.00078	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29581	 85378	 0.011227	 0.03705	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29582	 29584	 0.001271	 0.012144	 0.004	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29582	 30698	 0.012612	 0.053384	 0.01201	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29582	 85378	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29582	 85378	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29582	 85379	 0.002626	 0.015763	 0.00477	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29583	 85716	 0.032424	 0.075276	 0.00112	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29585	 29586	 0.00107	 0.00927	 0.01724	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29585	 85379	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29585	 85379	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29586	 31636	 0.001248	 0.010979	 0.0229	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29586	 85380	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29586	 85380	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29587	 29588	 0.002764	 0.009219	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29587	 29591	 0.011661	 0.029656	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29588	 29592	 0.009416	 0.008673	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29588	 85382	 0.00632	 0.030838	 0.00053	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29589	 29594	 7.9e-05	 0.000939	 0.07045	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29589	 29601	 9.1e-05	 0.001168	 0.0764	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29589	 85381	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84683	 29590	 0.001295	 0.005037	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29590	 85383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29590	 85383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29590	 85409	 0.004808	 0.012909	 0.00293	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29591	 85386	 0.002222	 0.01124	 0.0002	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29591	 85422	 0.018055	 0.023729	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85383	 29593	 0.009264	 0.036039	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29593	 85386	 0.013662	 0.031245	 0.00076	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29594	 31929	 0.000708	 0.009162	 0.58548	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29594	 85384	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29595	 29599	 0.000476	 0.003824	 0.00107	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29595	 29750	 0.001032	 0.004056	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85385	 29595	 0.000703	 0.005644	 0.00159	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29595	 85387	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29595	 85387	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85387	 29596	 0.008233	 0.011223	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29597	 29598	 0.000456	 0.002885	 0.00078	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29597	 29652	 0.001723	 0.010093	 0.00275	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29598	 29600	 0.000705	 0.003914	 0.00119	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29599	 29600	 0.000632	 0.003929	 0.00111	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29600	 29603	 0.000481	 0.006055	 0.00188	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85385	 29600	 0.00082	 0.009233	 0.00267	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29601	 85388	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85388	 29602	 0.00034	 0.003474	 0.01103	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29602	 85390	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85391	 29602	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29602	 85581	 0.023041	 0.16214	 0.2815	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29603	 29607	 0.001277	 0.005112	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29603	 29609	 0.002471	 0.013788	 0.00352	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85390	 29603	 0.001655	 0.006626	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29603	 85392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29603	 85392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29604	 29605	 0.009851	 0.01282	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85389	 29604	 0.009134	 0.056158	 0.00101	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85392	 29604	 0.005509	 0.014564	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29606	 29610	 0.003137	 0.016311	 0.00035	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85392	 29606	 0.00946	 0.026168	 0.00061	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29606	 85393	 0.001692	 0.011615	 0.00021	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29607	 85393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29607	 85393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85391	 29608	 0.013165	 0.033842	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29609	 29611	 0.001239	 0.004961	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29609	 29727	 0.009069	 0.047241	 0.01239	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85390	 29609	 0.002243	 0.012885	 0.00365	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29609	 85394	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29609	 85394	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29610	 29614	 0.008313	 0.02137	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29610	 85395	 0.010168	 0.023605	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29611	 29618	 0.002803	 0.013819	 0.00374	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29611	 29715	 0.001654	 0.009404	 0.00272	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85390	 29611	 0.001554	 0.01377	 0.00367	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29611	 85395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29611	 85395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85395	 29612	 0.023034	 0.018055	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29613	 29614	 0.009488	 0.014535	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29615	 29616	 0.023766	 0.023835	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85393	 29615	 0.011414	 0.029027	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29617	 29623	 0.016143	 0.037088	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29617	 29624	 0.006587	 0.025624	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29617	 29626	 0.085789	 0.067247	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29617	 29653	 0.011597	 0.051095	 0.00089	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29617	 29656	 0.012109	 0.028113	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29618	 85396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29618	 85396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29619	 29620	 0.019485	 0.035157	 0.00051	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29620	 29737	 0.010549	 0.023928	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85396	 29620	 0.008549	 0.038093	 0.00065	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29621	 29623	 0.008423	 0.011492	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29621	 29624	 0.006344	 0.013544	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29622	 29623	 0.02682	 0.021225	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29623	 29753	 0.014181	 0.036454	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29624	 29625	 0.009915	 0.015826	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85396	 29624	 0.00609	 0.023693	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29627	 29639	 0.006606	 0.026449	 0.00666	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29627	 85397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29627	 85397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29627	 85398	 0.004564	 0.016133	 0.00364	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29628	 29630	 0.009147	 0.051471	 0.00111	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29628	 29631	 0.011413	 0.044401	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29628	 29644	 0.007365	 0.037807	 0.00072	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29628	 29744	 0.038085	 0.098706	 0.00187	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29629	 29630	 0.027269	 0.078213	 0.0012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85034	 29629	 0.024117	 0.080452	 0.00128	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85397	 29630	 0.030814	 0.079211	 0.00123	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29631	 85399	 0.009265	 0.048178	 0.00104	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29632	 29634	 0.007242	 0.02332	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29632	 85399	 0.011014	 0.036743	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29632	 85408	 0.015696	 0.036434	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29633	 29667	 0.000594	 0.004093	 0.00722	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29633	 85398	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85399	 29633	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29633	 86052	 0.006303	 0.042553	 0.07841	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29634	 29637	 0.006669	 0.025943	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29634	 29666	 0.006064	 0.020229	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29635	 29639	 0.001555	 0.006814	 0.00234	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29635	 29652	 0.002321	 0.007742	 0.00196	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29635	 85400	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29635	 85400	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29636	 29637	 0.007574	 0.021723	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29636	 85401	 0.011928	 0.024409	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29636	 85404	 0.010943	 0.042573	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29638	 85401	 0.011289	 0.018019	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85398	 29639	 0.003387	 0.018587	 0.00491	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29639	 85401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29639	 85401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29640	 29641	 0.006933	 0.017821	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85400	 29641	 0.00776	 0.019947	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29641	 85402	 0.018101	 0.02379	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29642	 29643	 0.017367	 0.030541	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29643	 85403	 0.016296	 0.037826	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29644	 29645	 0.01321	 0.037888	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29645	 29745	 0.026084	 0.067602	 0.00128	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85400	 29645	 0.022298	 0.07802	 0.00162	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29646	 85403	 0.024884	 0.027103	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29647	 85403	 0.00985	 0.015089	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29648	 29649	 0.001174	 0.005473	 0.00136	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29648	 29650	 0.000619	 0.00311	 0.00081	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29648	 85402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29648	 85402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29649	 85403	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29649	 85403	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29650	 29652	 0.000739	 0.0044	 0.00116	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29650	 85404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29650	 85404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29651	 29655	 0.003992	 0.013173	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85403	 29651	 0.003111	 0.013864	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85403	 29653	 0.011189	 0.025978	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85404	 29653	 0.003526	 0.020043	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29654	 29656	 0.031359	 0.024581	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29655	 29656	 0.004536	 0.01053	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29657	 29659	 0.063266	 0.046547	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85399	 29657	 0.041183	 0.053595	 0.00075	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85398	 29658	 0.00463	 0.01291	 0.00271	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29658	 85405	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29658	 85405	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29658	 85406	 0.001807	 0.006198	 0.00148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29659	 29660	 0.056069	 0.044373	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29659	 85407	 0.012071	 0.024702	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29661	 29662	 0.000412	 0.003397	 0.007	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29661	 29667	 0.00054	 0.0036	 0.00678	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29661	 85406	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85407	 29661	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84682	 29662	 0.000643	 0.004175	 0.00832	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	85381	 29662	 0.000454	 0.002876	 0.00602	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29663	 29664	 0.020872	 0.013512	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85405	 29663	 0.016849	 0.028141	 0.00048	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29664	 29665	 0.010009	 0.023238	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29664	 85422	 0.005869	 0.033364	 0.0006	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29665	 29666	 0.004023	 0.01644	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85399	 29665	 0.091846	 0.071995	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29665	 85408	 0.007289	 0.021435	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85384	 29667	 0.000962	 0.007726	 0.01676	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29667	 85408	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29667	 85408	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84683	 29668	 0.006722	 0.015604	 0.00475	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29668	 85409	 0.004239	 0.01138	 0.00258	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29669	 29671	 0.081766	 0.064709	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29669	 29695	 0.025856	 0.068351	 0.00124	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29669	 29696	 0.050844	 0.036015	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29669	 85410	 0.00179	 0.01489	 0.00028	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29669	 85415	 0.014263	 0.045927	 0.00078	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84682	 29670	 0.000435	 0.002824	 0.00563	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29670	 85409	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85410	 29670	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29671	 29672	 0.023359	 0.018486	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85409	 29673	 0.010255	 0.032057	 0.00929	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29674	 29679	 0.000918	 0.00682	 0.0026	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85390	 29674	 0.001073	 0.010102	 0.00306	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29675	 29688	 0.011272	 0.014669	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84756	 29676	 0.047248	 0.037036	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29677	 29683	 0.050675	 0.039721	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29678	 29685	 0.00357	 0.014822	 0.00039	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29678	 85412	 0.020854	 0.022937	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29678	 85423	 0.023748	 0.068113	 0.00105	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29679	 29722	 0.000893	 0.006839	 0.00183	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29679	 85411	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29679	 85411	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29680	 29687	 0.00251	 0.011517	 0.00295	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29680	 29752	 0.003509	 0.01405	 0.00354	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85390	 29680	 0.006215	 0.018001	 0.00434	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29680	 85412	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29680	 85412	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29681	 29730	 0.022447	 0.10954	 0.00189	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29681	 85423	 0.010039	 0.060779	 0.0019	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29682	 29688	 0.010497	 0.020573	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85412	 29682	 0.020569	 0.030499	 0.00046	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85391	 29683	 0.01671	 0.030606	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29684	 29717	 0.041177	 0.026658	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85389	 29685	 0.004833	 0.039736	 0.00077	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85391	 29685	 0.005448	 0.029813	 0.00058	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29686	 29708	 0.04993	 0.037829	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29687	 29701	 0.003853	 0.011598	 0.00363	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29687	 85413	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29687	 85413	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85413	 29688	 0.007263	 0.02329	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84682	 29689	 0.000622	 0.0044	 0.00932	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29689	 85414	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85415	 29689	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29690	 29693	 0.017508	 0.031468	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84756	 29690	 0.007305	 0.028104	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85413	 29690	 0.00899	 0.016716	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29691	 85416	 0.032728	 0.035997	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29692	 29693	 0.034031	 0.025783	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29694	 29697	 0.023375	 0.045811	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29694	 29700	 0.012285	 0.027866	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29694	 29705	 0.014992	 0.020436	 0.00045	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29694	 29707	 0.017778	 0.046995	 0.00085	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85415	 29694	 0.040535	 0.13523	 0.00214	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29695	 29698	 0.020207	 0.041353	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29697	 29699	 0.0634	 0.050175	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29698	 29700	 0.011749	 0.027821	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85183	 29698	 0.25527	 0.20014	 0.00257	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29701	 29704	 0.004	 0.010571	 0.00247	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29701	 85416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29701	 85416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85416	 29702	 0.036294	 0.026702	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29703	 85417	 0.01841	 0.020249	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85385	 29704	 0.010328	 0.046508	 0.01238	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29704	 85417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29704	 85417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29706	 29707	 0.012858	 0.05255	 0.00106	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29707	 29708	 0.019578	 0.029991	 0.00042	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29707	 29709	 0.003645	 0.01446	 0.00041	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29707	 29711	 0.025237	 0.019782	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29707	 29712	 0.054915	 0.043459	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29708	 29710	 0.028339	 0.02085	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85417	 29709	 0.004361	 0.026809	 0.00048	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29713	 29714	 0.026123	 0.020476	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29713	 29719	 0.025622	 0.01815	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29714	 29716	 0.01303	 0.034536	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29714	 29719	 0.049501	 0.032047	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29714	 85421	 0.021265	 0.094758	 0.00161	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29715	 29727	 0.010555	 0.04226	 0.01065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29715	 85418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29715	 85418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85418	 29716	 0.006067	 0.026733	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29717	 29721	 0.009947	 0.023092	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29717	 29725	 0.023765	 0.018807	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29717	 29726	 0.028356	 0.043006	 0.00062	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29717	 29729	 0.032737	 0.044625	 0.00099	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29717	 85420	 0.009126	 0.026176	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29718	 85419	 0.024642	 0.019501	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85394	 29719	 0.016827	 0.065463	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29719	 85420	 0.01563	 0.029063	 0.00068	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29720	 29722	 0.000405	 0.002592	 0.00087	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29720	 29723	 0.000539	 0.003875	 0.00103	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29720	 85419	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29720	 85419	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29721	 85420	 0.004038	 0.010379	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29723	 29727	 0.006333	 0.026146	 0.00619	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29723	 85420	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29723	 85420	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29724	 29732	 0.014924	 0.034647	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29724	 29735	 0.005349	 0.025563	 0.00056	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29724	 29742	 0.018389	 0.042693	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85067	 29727	 0.011573	 0.058153	 0.01514	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29727	 85421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29727	 85421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29728	 29730	 0.020958	 0.081533	 0.00136	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29731	 29732	 0.011743	 0.039172	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85420	 29731	 0.012413	 0.055313	 0.00094	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29733	 29734	 0.012046	 0.027967	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29733	 29736	 0.011278	 0.02308	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85421	 29733	 0.004567	 0.027758	 0.00051	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85421	 29734	 0.014251	 0.055442	 0.00093	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29735	 29736	 0.012071	 0.023899	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29737	 29738	 0.003956	 0.011633	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29737	 29753	 0.008749	 0.018389	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29738	 29741	 0.016292	 0.046727	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29739	 29741	 0.015247	 0.009871	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29740	 29741	 0.010101	 0.021231	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29740	 29742	 0.025461	 0.058496	 0.00089	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29743	 29744	 0.032435	 0.020998	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29743	 29751	 0.16943	 0.18637	 0.00249	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29745	 29749	 0.047427	 0.11231	 0.00205	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29747	 29749	 0.08414	 0.11059	 0.00152	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29748	 29749	 0.076342	 0.055188	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85385	 29750	 0.001129	 0.006613	 0.0018	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85406	 29750	 0.006884	 0.016588	 0.00468	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29750	 85422	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29750	 85422	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29752	 85423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29752	 85423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29754	 29761	 0.000835	 0.004266	 0.00107	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29754	 29764	 0.001396	 0.00559	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29754	 85424	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29754	 85424	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29755	 29756	 0.000984	 0.003579	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29755	 29758	 0.000936	 0.00396	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29756	 29757	 0.000883	 0.003534	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29757	 29766	 0.000789	 0.003339	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29758	 29783	 0.002331	 0.01399	 0.00424	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29758	 85425	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29758	 85425	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29759	 29772	 0.007222	 0.011063	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29760	 29773	 0.003898	 0.011062	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29760	 85426	 0.007246	 0.011099	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29761	 29774	 0.000929	 0.006226	 0.00191	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29761	 85426	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29761	 85426	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29762	 29776	 0.024037	 0.026438	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85426	 29762	 0.012726	 0.015514	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85424	 29763	 0.014738	 0.034217	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29763	 85439	 0.01517	 0.034853	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29764	 29765	 0.001085	 0.004264	 0.00112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29765	 29811	 0.001266	 0.005068	 0.00128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29766	 29811	 0.001212	 0.004716	 0.00126	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29767	 29768	 0.012497	 0.009034	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85425	 29767	 0.008575	 0.015412	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29769	 29771	 0.019648	 0.014204	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85425	 29769	 0.019634	 0.014876	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85425	 29770	 0.015885	 0.026039	 0.00046	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29771	 29786	 0.008874	 0.013459	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85425	 29771	 0.017624	 0.013518	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29772	 29784	 0.025261	 0.023689	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29772	 29785	 0.004435	 0.011401	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29773	 85427	 0.001826	 0.008001	 0.00017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29774	 29789	 0.000475	 0.004563	 0.00133	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29774	 85427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29774	 85427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29775	 29776	 0.006633	 0.017051	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29775	 85429	 0.010117	 0.026814	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29776	 29777	 0.005888	 0.021032	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29777	 85438	 0.010509	 0.040882	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85426	 29778	 0.009771	 0.03801	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29778	 85435	 0.007488	 0.02809	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29779	 29782	 0.010971	 0.037476	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29779	 29816	 0.01406	 0.057464	 0.00116	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85425	 29780	 0.018458	 0.047447	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29781	 29782	 0.009523	 0.017706	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29781	 29786	 0.008532	 0.019142	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29782	 85428	 0.006119	 0.034781	 0.00063	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29783	 85428	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29783	 85428	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29783	 85430	 0.000618	 0.006663	 0.00191	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29784	 29785	 0.01845	 0.014152	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29784	 29786	 0.005677	 0.016281	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85428	 29784	 0.003663	 0.019293	 0.00035	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	85427	 29785	 0.005164	 0.013275	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29787	 85429	 0.00418	 0.01229	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29787	 85431	 0.006966	 0.023237	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85427	 29788	 0.00648	 0.007127	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29789	 85429	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29789	 85429	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29789	 85430	 0.000581	 0.004201	 0.00226	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29790	 85430	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29790	 85430	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29791	 29792	 0.001686	 0.007134	 0.00161	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85430	 29791	 0.000982	 0.005231	 0.00147	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29791	 85431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29791	 85431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29792	 29796	 0.001654	 0.006624	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29792	 85432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29792	 85432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29793	 29794	 0.011079	 0.025131	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85431	 29793	 0.008995	 0.020572	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85432	 29794	 0.004599	 0.017891	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29794	 85433	 0.013577	 0.068262	 0.00186	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29795	 29802	 0.004062	 0.016256	 0.00549	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29795	 29807	 0.002996	 0.01644	 0.00435	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29795	 29836	 0.03573	 0.20971	 0.05729	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85430	 29795	 0.003096	 0.032808	 0.00974	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29795	 85433	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29795	 85433	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84672	 29797	 0.000559	 0.004138	 0.00212	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85430	 29797	 0.000484	 0.006202	 0.00185	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29797	 85434	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29797	 85434	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29798	 29808	 0.003724	 0.009842	 0.0023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29798	 85435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29798	 85435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29799	 29805	 0.01818	 0.042207	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29799	 29810	 0.034932	 0.11653	 0.00185	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85173	 29799	 0.031284	 0.16866	 0.0034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29800	 29806	 0.00304	 0.009917	 0.00263	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29800	 29807	 0.003425	 0.017206	 0.00448	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29800	 29813	 0.002272	 0.009098	 0.00229	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29800	 85436	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29800	 85436	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29801	 33354	 0.014815	 0.079279	 0.0024	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85433	 29801	 0.029019	 0.096806	 0.00153	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29801	 85437	 0.014525	 0.055883	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29802	 29807	 0.002412	 0.009658	 0.00243	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29802	 85437	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29802	 85437	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85437	 29803	 0.020342	 0.079137	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29803	 86659	 0.059156	 0.19051	 0.00325	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29804	 29805	 0.019439	 0.017418	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85435	 29805	 0.02038	 0.033406	 0.00059	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85436	 29805	 0.008103	 0.019189	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29806	 29807	 0.002449	 0.011885	 0.00272	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29806	 85438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29806	 85438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29808	 29813	 0.001838	 0.007359	 0.00185	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29808	 85439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29808	 85439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29808	 85440	 0.003667	 0.01468	 0.0037	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29809	 29815	 0.09162	 0.072508	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29811	 85440	 0.001391	 0.011177	 0.00314	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29812	 29819	 0.000559	 0.004629	 0.0146	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29812	 32787	 0.003963	 0.054564	 0.10888	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29812	 85440	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85441	 29812	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29813	 85442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29813	 85442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29814	 29815	 0.010728	 0.02299	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85442	 29814	 0.017459	 0.040533	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85441	 29815	 0.013539	 0.031432	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29816	 32176	 0.013448	 0.10481	 0.00196	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29817	 29818	 0.04391	 0.078925	 0.00142	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85441	 29818	 0.018161	 0.046684	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84673	 29820	 0.029908	 0.091849	 0.00172	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29821	 32176	 0.083582	 0.21259	 0.00336	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85177	 29821	 0.081992	 0.2352	 0.00362	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29822	 29829	 0.002841	 0.021763	 0.00583	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29823	 29824	 0.040862	 0.1511	 0.0028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84889	 29823	 0.028812	 0.16379	 0.00296	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85178	 29823	 0.21096	 0.38081	 0.00551	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29824	 29826	 0.04657	 0.11972	 0.00185	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85081	 29824	 0.073755	 0.31224	 0.00589	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29825	 29826	 0.02931	 0.12914	 0.00224	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84654	 29825	 0.13406	 0.52195	 0.00872	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84654	 29825	 0.13406	 0.52195	 0.00872	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85081	 29825	 0.050299	 0.29343	 0.00589	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84654	 29826	 0.16333	 0.63616	 0.01064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84654	 29826	 0.16333	 0.63616	 0.01064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85081	 29826	 0.035227	 0.19825	 0.00428	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85083	 29826	 0.11081	 0.2573	 0.00383	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29827	 29830	 0.012851	 0.10935	 0.00286	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29827	 85443	 0.019029	 0.17717	 0.00343	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29828	 29829	 0.002566	 0.021313	 0.00834	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29828	 29975	 0.005274	 0.042102	 0.01038	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29828	 85443	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29828	 85443	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29829	 85444	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29829	 85444	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84654	 29830	 0.020563	 0.12913	 0.00282	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29831	 29832	 0.008784	 0.048206	 0.01274	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29831	 32173	 0.014915	 0.068437	 0.01754	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29833	 33684	 0.033332	 0.14853	 0.00252	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29833	 85445	 0.035111	 0.15646	 0.00266	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29834	 29836	 0.010242	 0.046992	 0.01204	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29835	 85445	 0.041983	 0.083123	 0.00122	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29836	 85445	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29836	 85445	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84735	 29837	 0.070881	 0.13181	 0.00309	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85445	 29837	 0.040504	 0.11618	 0.00179	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29838	 29883	 0.013795	 0.024891	 0.00036	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29838	 85446	 0.006214	 0.015424	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29839	 29840	 0.001261	 0.004205	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29839	 85446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29839	 85446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29840	 29845	 0.001638	 0.009595	 0.00261	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29840	 29865	 0.001535	 0.00882	 0.0025	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29840	 29888	 0.006272	 0.016282	 0.00395	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29840	 85447	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29840	 85447	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29841	 29843	 0.010745	 0.019681	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29842	 29844	 0.005123	 0.010485	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29842	 29850	 0.004631	 0.011904	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85447	 29842	 0.008994	 0.016473	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29843	 85448	 0.007623	 0.01866	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29844	 29846	 0.002649	 0.009268	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29845	 85448	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29845	 85448	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29845	 85450	 0.001259	 0.007375	 0.00201	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29846	 29872	 0.007029	 0.014772	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29846	 29873	 0.022071	 0.037181	 0.00053	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85448	 29846	 0.003134	 0.016506	 0.0003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	29847	 29848	 0.013626	 0.00985	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29848	 29850	 0.017963	 0.021056	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29848	 29874	 0.006846	 0.013554	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85448	 29848	 0.007101	 0.031775	 0.00065	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29849	 29850	 0.003841	 0.00786	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29849	 29861	 0.016309	 0.014614	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29849	 29876	 0.005184	 0.010608	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29851	 29854	 0.01757	 0.011375	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29852	 29854	 0.006383	 0.014816	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29852	 29856	 0.005894	 0.01493	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29853	 29858	 0.01546	 0.018846	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29854	 29881	 0.010949	 0.020359	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29855	 29858	 0.012389	 0.035533	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29855	 29877	 0.015187	 0.017803	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29855	 29878	 0.018782	 0.037187	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29856	 29857	 0.01489	 0.01504	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85446	 29856	 0.010753	 0.027643	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29857	 29858	 0.006013	 0.011905	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29858	 29861	 0.003821	 0.012133	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85447	 29858	 0.006777	 0.026071	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85446	 29859	 0.020018	 0.015691	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29860	 29861	 0.008044	 0.01355	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85446	 29860	 0.006136	 0.014098	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85447	 29861	 0.003136	 0.012548	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29862	 29863	 0.019128	 0.019319	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29862	 29895	 0.060211	 0.066226	 0.00088	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29863	 29864	 0.008457	 0.019429	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29863	 85453	 0.053786	 0.04216	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29864	 85449	 0.008321	 0.023864	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29865	 29866	 0.000625	 0.006321	 0.00186	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29865	 85449	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29865	 85449	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29866	 29909	 0.000514	 0.004481	 0.00123	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29866	 85450	 0.003372	 0.013119	 0.0035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29867	 29868	 3.8e-05	 0.000494	 0.03153	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29867	 31866	 5.7e-05	 0.000682	 0.05119	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29867	 85450	 0.000216	 0.017299	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29868	 29910	 5.8e-05	 0.000746	 0.04763	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29868	 85452	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29868	 85452	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85452	 29869	 0.014486	 0.020564	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29870	 31868	 0.001245	 0.005894	 0.00142	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85450	 29870	 0.001858	 0.009068	 0.0025	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29871	 29907	 0.016209	 0.037625	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29871	 29915	 0.021072	 0.026156	 0.00057	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85451	 29871	 0.008329	 0.055041	 0.00108	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29871	 86039	 0.009711	 0.032395	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29872	 29873	 0.010927	 0.019639	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85451	 29873	 0.0076	 0.029568	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85451	 29873	 0.0076	 0.029568	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29873	 86037	 0.011984	 0.046622	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29873	 86037	 0.011984	 0.046622	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29875	 29876	 0.023848	 0.024351	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29878	 29879	 0.011693	 0.01286	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29879	 29892	 0.053514	 0.037907	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29880	 29883	 0.015969	 0.031616	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29881	 29882	 0.013565	 0.034871	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29881	 29884	 0.043779	 0.034646	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29881	 85453	 0.023111	 0.077096	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29882	 29891	 0.073879	 0.054356	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29882	 29894	 0.041943	 0.064253	 0.0009	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29883	 29885	 0.006397	 0.016443	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29885	 29886	 0.009706	 0.019863	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29886	 29889	 0.016961	 0.03324	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29886	 85453	 0.045113	 0.030304	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29886	 85454	 0.029212	 0.074291	 0.00117	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29887	 29889	 0.042917	 0.033964	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29887	 29895	 0.009105	 0.023404	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29887	 85453	 0.014079	 0.025403	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29888	 29890	 0.005365	 0.024614	 0.00631	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29888	 85453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29888	 85453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29889	 85454	 0.006349	 0.043581	 0.00079	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85255	 29890	 0.010889	 0.063791	 0.01738	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29890	 85454	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29890	 85454	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29893	 31863	 0.053429	 0.03459	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29895	 29897	 0.011281	 0.037227	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29895	 29904	 0.015174	 0.050076	 0.00081	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85454	 29895	 0.04482	 0.088742	 0.0013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29896	 29897	 0.006502	 0.012742	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29897	 85456	 0.006462	 0.033604	 0.00073	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29898	 85455	 0.026267	 0.019326	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29899	 29900	 0.001863	 0.004923	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29899	 85455	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29899	 85455	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29899	 85460	 0.005476	 0.013765	 0.00357	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85328	 29900	 0.00904	 0.042161	 0.01044	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29900	 85456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29900	 85456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29900	 85460	 0.007105	 0.019074	 0.00432	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29901	 85457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29901	 85457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84688	 29902	 0.12302	 0.097361	 0.00123	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84688	 29903	 0.2036	 0.14721	 0.00223	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84702	 29903	 0.29462	 0.32418	 0.00433	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29904	 85458	 0.010398	 0.027558	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85452	 29905	 0.025646	 0.032225	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29906	 29912	 0.049325	 0.052675	 0.00111	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29906	 29913	 0.025703	 0.041026	 0.00094	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84688	 29906	 0.02972	 0.14747	 0.00352	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29907	 29914	 0.023214	 0.037357	 0.00059	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85181	 29908	 0.073982	 0.24418	 0.00396	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29908	 86055	 0.073107	 0.18795	 0.00291	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29909	 85458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29909	 85458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29909	 85459	 0.000466	 0.003918	 0.00116	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29909	 85460	 0.002813	 0.013872	 0.00375	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29910	 29911	 6.1e-05	 0.000732	 0.0549	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29910	 85459	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29910	 85459	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29911	 85460	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29911	 85460	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85444	 29916	 0.063502	 0.12573	 0.00185	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29917	 29918	 0.003087	 0.02562	 0.00674	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84743	 29917	 0.009586	 0.070838	 0.02045	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29918	 29919	 0.003013	 0.01382	 0.00354	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29918	 29948	 0.004586	 0.022611	 0.00611	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29919	 29948	 0.002349	 0.008544	 0.00262	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29919	 85461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29919	 85461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29920	 29921	 0.004387	 0.026329	 0.00797	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29920	 29949	 0.003744	 0.023716	 0.00644	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29921	 31727	 0.010013	 0.032659	 0.00867	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29921	 85462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29921	 85462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29922	 29923	 0.005746	 0.033017	 0.00935	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29922	 31728	 0.006321	 0.032165	 0.01166	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29923	 29924	 0.004495	 0.026326	 0.00717	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29924	 29977	 0.005833	 0.036198	 0.00877	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29924	 85463	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29924	 85463	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29925	 29927	 0.026676	 0.070704	 0.00179	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85463	 29925	 0.051184	 0.11759	 0.00179	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29925	 85471	 0.057814	 0.13691	 0.0025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29926	 29977	 0.003547	 0.020162	 0.00584	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29926	 85464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29926	 85464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29927	 29928	 0.024294	 0.055561	 0.00136	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85464	 29928	 0.072112	 0.1618	 0.00258	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29928	 85465	 0.032358	 0.059267	 0.00102	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29929	 29930	 0.00365	 0.021745	 0.00572	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29929	 29931	 0.004445	 0.027587	 0.00668	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29929	 85465	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29929	 85465	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29930	 29931	 0.00572	 0.016864	 0.00392	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29930	 29942	 0.008219	 0.029763	 0.00639	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29930	 29956	 0.01057	 0.05866	 0.01784	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29930	 32043	 0.001416	 0.010773	 0.00339	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29930	 32044	 0.001919	 0.011238	 0.00306	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29930	 85468	 0.003087	 0.028133	 0.01022	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29931	 29933	 0.00856	 0.022004	 0.00545	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29931	 85468	 0.001796	 0.017824	 0.00485	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29932	 85470	 0.037708	 0.074659	 0.0011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29933	 29942	 0.005141	 0.01954	 0.00547	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29933	 32027	 0.005418	 0.021693	 0.00547	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29934	 29936	 0.003121	 0.01653	 0.00419	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29935	 85466	 0.027543	 0.070804	 0.0011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29935	 85470	 0.1623	 0.14952	 0.0024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29936	 29938	 0.001904	 0.009243	 0.00211	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29936	 85466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29936	 85466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29937	 29938	 0.001655	 0.007592	 0.00194	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29937	 29965	 0.004633	 0.021606	 0.00535	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29937	 85467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29937	 85467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29939	 29974	 0.009029	 0.02138	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85466	 29939	 0.016968	 0.039393	 0.00059	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29940	 85470	 0.046965	 0.037168	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29941	 29952	 0.001275	 0.01646	 0.0373	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29941	 32038	 0.00151	 0.020552	 0.04183	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29941	 85468	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85469	 29941	 0.000318	 0.023855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85468	 29942	 0.001933	 0.010609	 0.0028	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29942	 85470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29942	 85470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85469	 29943	 0.007509	 0.019095	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29944	 29945	 0.064263	 0.050857	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29944	 85471	 0.029364	 0.052983	 0.00077	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29946	 29947	 0.001827	 0.010024	 0.00265	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85468	 29946	 0.00255	 0.010211	 0.00257	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29946	 85471	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29946	 85471	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29947	 29962	 0.000908	 0.005316	 0.00145	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29948	 29950	 0.001191	 0.009282	 0.00278	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29948	 85472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29948	 85472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29949	 29960	 0.002811	 0.017468	 0.00493	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29949	 85473	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29949	 85473	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29950	 29956	 0.002198	 0.009302	 0.00209	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29950	 29958	 0.00139	 0.007625	 0.00202	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29950	 85474	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29950	 85474	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29950	 85475	 0.002446	 0.011868	 0.00271	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85474	 29951	 0.017681	 0.039132	 0.00064	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29951	 85479	 0.012396	 0.028778	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29952	 85475	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85476	 29952	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29953	 29956	 0.003143	 0.010591	 0.00263	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29953	 29965	 0.002104	 0.010267	 0.00284	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29953	 29967	 0.005485	 0.014934	 0.00329	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29953	 29969	 0.002737	 0.007234	 0.00169	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85475	 29953	 0.002464	 0.014432	 0.00393	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29953	 85477	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29953	 85477	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29954	 29955	 0.015155	 0.015945	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85477	 29954	 0.017122	 0.016819	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85461	 29955	 0.031088	 0.093571	 0.00183	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29955	 85478	 0.005795	 0.013454	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29956	 29957	 0.001436	 0.005075	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85475	 29956	 0.002683	 0.014221	 0.00475	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29956	 85478	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29956	 85478	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29957	 29959	 0.002307	 0.006282	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29958	 29959	 0.00093	 0.004224	 0.00147	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29959	 29961	 0.001609	 0.006261	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29959	 29963	 0.000906	 0.005305	 0.00145	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29960	 29961	 0.000731	 0.004539	 0.00128	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29960	 85479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29960	 85479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29961	 29962	 0.000999	 0.006434	 0.00169	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29962	 85480	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29962	 85480	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29963	 29964	 0.001777	 0.008991	 0.0025	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85468	 29964	 0.004084	 0.017284	 0.00389	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29964	 85481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29964	 85481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29965	 85482	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29965	 85482	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85481	 29966	 0.02428	 0.043641	 0.00078	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29967	 29969	 0.003742	 0.012608	 0.00313	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29967	 29973	 0.003335	 0.017371	 0.00456	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29967	 85483	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29967	 85483	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29968	 29971	 0.042216	 0.10852	 0.00168	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85476	 29968	 0.025479	 0.038621	 0.0008	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85475	 29969	 0.002829	 0.01445	 0.00363	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29970	 29971	 0.03324	 0.09534	 0.00147	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29970	 85485	 0.024161	 0.093996	 0.00157	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29971	 85484	 0.039922	 0.091304	 0.00223	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29972	 29973	 0.002123	 0.011309	 0.00317	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29972	 29976	 0.002965	 0.02133	 0.00565	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29972	 85484	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29972	 85484	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85467	 29974	 0.061798	 0.050866	 0.00103	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85484	 29974	 0.018365	 0.061266	 0.00097	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85044	 29975	 0.004932	 0.073698	 0.02182	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85082	 29975	 0.018702	 0.18937	 0.05583	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29975	 85485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29975	 85485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85041	 29976	 0.007442	 0.056061	 0.01556	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29978	 85487	 0.051308	 0.056434	 0.00075	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29979	 29981	 0.013193	 0.021058	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29979	 31804	 0.018414	 0.025663	 0.00044	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29980	 29988	 0.03895	 0.051191	 0.0007	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29980	 31804	 0.010973	 0.0392	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29981	 85487	 0.008235	 0.021169	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29982	 30009	 0.002471	 0.015652	 0.03278	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84641	 29982	 0.001171	 0.012484	 0.02539	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29982	 85486	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85487	 29982	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29983	 85489	 0.038766	 0.030679	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29984	 29985	 0.00234	 0.005431	 0.00165	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29984	 85488	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29984	 85488	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29985	 29995	 0.002428	 0.006303	 0.00153	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29986	 29987	 0.038853	 0.030748	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29986	 31808	 0.028666	 0.045757	 0.00105	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29987	 29988	 0.022877	 0.017932	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85488	 29987	 0.016797	 0.016965	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29988	 85491	 0.098861	 0.078239	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29988	 85830	 0.24823	 0.63888	 0.0099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29988	 86010	 0.042656	 0.091073	 0.00206	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29989	 85490	 0.007884	 0.01561	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29990	 85489	 0.01979	 0.01456	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29991	 29992	 0.00055	 0.004276	 0.00111	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29991	 29993	 0.001955	 0.006523	 0.00165	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29991	 29998	 0.001033	 0.006152	 0.00162	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84642	 29992	 0.0072	 0.044683	 0.01082	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85486	 29992	 0.000938	 0.00853	 0.00215	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29992	 85489	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29992	 85489	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29993	 29996	 0.003378	 0.009196	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29993	 85490	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29993	 85490	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29994	 31168	 0.03805	 0.14639	 0.0025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29994	 85491	 0.010652	 0.062124	 0.00125	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29995	 29996	 0.002179	 0.007476	 0.00179	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29995	 85497	 0.003635	 0.020883	 0.00592	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	29996	 85491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29996	 85491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85490	 29997	 0.009395	 0.041866	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	29997	 85492	 0.0061	 0.01568	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29997	 85493	 0.009437	 0.024258	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	29998	 29999	 0.001029	 0.005648	 0.00149	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29998	 85492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29998	 85492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29999	 30005	 0.001333	 0.007346	 0.00172	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29999	 85493	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29999	 85493	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30000	 30003	 0.00138	 0.007335	 0.0017	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30000	 30869	 0.006085	 0.037761	 0.00915	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84662	 30000	 0.045653	 0.12264	 0.02782	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30000	 85494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30000	 85494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30000	 85497	 0.007959	 0.048138	 0.01229	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30001	 30006	 0.011147	 0.021068	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30001	 85495	 0.004172	 0.010609	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30002	 30003	 0.001252	 0.008066	 0.00211	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30002	 30005	 0.001425	 0.007855	 0.00184	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30003	 85495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30003	 85495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30004	 85496	 0.019881	 0.015733	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30005	 85496	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30005	 85496	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85494	 30006	 0.031293	 0.034085	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30007	 30008	 0.013041	 0.058112	 0.00099	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30007	 30875	 0.009425	 0.033668	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85494	 30008	 0.013631	 0.058541	 0.00107	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84656	 30009	 0.002594	 0.01708	 0.03305	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84689	 30009	 0.002849	 0.020656	 0.04159	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30009	 85497	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30009	 85497	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84657	 30010	 0.029312	 0.075351	 0.00117	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30011	 31815	 0.013898	 0.05883	 0.01324	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84690	 30011	 0.002892	 0.013267	 0.0034	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84730	 30011	 0.054651	 0.15254	 0.03205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30012	 30028	 0.001002	 0.004011	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30012	 30033	 0.000451	 0.001909	 0.00043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30013	 30018	 0.008875	 0.022815	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30013	 85499	 0.00968	 0.029135	 0.00057	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30013	 85504	 0.012723	 0.022725	 0.00034	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30014	 30030	 0.000778	 0.003026	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30014	 30033	 0.001415	 0.006373	 0.0017	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85019	 30014	 0.001008	 0.008097	 0.00228	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30014	 85498	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30014	 85498	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30015	 30020	 0.008834	 0.005719	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30016	 85501	 0.00449	 0.002907	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30017	 30019	 0.010984	 0.00778	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85498	 30017	 0.002406	 0.0106	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30017	 85500	 0.001754	 0.010659	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30018	 30022	 0.015116	 0.010927	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30018	 30156	 0.013737	 0.025161	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30020	 85500	 0.004896	 0.009694	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30021	 30024	 0.00429	 0.009959	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85498	 30021	 0.006362	 0.01579	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30022	 30102	 0.005486	 0.011531	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30022	 85505	 0.005416	 0.011083	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30023	 30024	 0.002489	 0.004491	 6e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30023	 85501	 0.004368	 0.004757	 6e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30025	 85499	 0.010198	 0.01073	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30026	 85499	 0.007635	 0.012862	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30027	 30029	 0.011407	 0.009028	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30028	 30157	 0.002084	 0.005507	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30028	 30158	 0.003673	 0.009707	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85498	 30029	 0.005015	 0.006591	 9e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30030	 30038	 0.001104	 0.003433	 0.00072	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30030	 85499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30030	 85499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85019	 30031	 0.001065	 0.004885	 0.00125	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30031	 85500	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30031	 85500	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85500	 30032	 0.007192	 0.014095	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30033	 85501	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30033	 85501	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30034	 30367	 0.000592	 0.002717	 0.0007	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30034	 85502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30034	 85502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30035	 30048	 0.000611	 0.00379	 0.00092	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30035	 30364	 0.000893	 0.003981	 0.00108	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85019	 30035	 0.00289	 0.016602	 0.0047	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30035	 85503	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30035	 85503	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30036	 30037	 0.000654	 0.003627	 0.0011	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30036	 30039	 0.00065	 0.003807	 0.00104	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30036	 85504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30036	 85504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30037	 30047	 0.000916	 0.003668	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30037	 85505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30037	 85505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30038	 30039	 0.000428	 0.002509	 0.00068	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30038	 30366	 0.000671	 0.003856	 0.00109	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85503	 30040	 0.00728	 0.01162	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30041	 30043	 0.004534	 0.013005	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85502	 30041	 0.001729	 0.008439	 0.00015	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85503	 30041	 0.037158	 0.029126	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30041	 85568	 0.007562	 0.017552	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30042	 30043	 0.002412	 0.0062	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30042	 30044	 0.004805	 0.012219	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85504	 30043	 0.010053	 0.012479	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85505	 30044	 0.011777	 0.012953	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30045	 85507	 0.014563	 0.014709	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30046	 30047	 0.000584	 0.002063	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30046	 30051	 0.001209	 0.003109	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30046	 85506	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30046	 85506	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30048	 30050	 0.000791	 0.003975	 0.00103	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30048	 30064	 0.001995	 0.005015	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30049	 85510	 0.024786	 0.019615	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30050	 30051	 0.001142	 0.004834	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30050	 85507	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30050	 85507	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30051	 30097	 0.00109	 0.003407	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30051	 85508	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30051	 85508	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30052	 30053	 0.010823	 0.008565	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30052	 30057	 0.01804	 0.013273	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85508	 30053	 0.004752	 0.009314	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30054	 30055	 0.001232	 0.003634	 0.00085	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30054	 30362	 0.001097	 0.003762	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30055	 30064	 0.00205	 0.005716	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30055	 85509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30055	 85509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30056	 30057	 0.006902	 0.016343	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30056	 85511	 0.007207	 0.018526	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30057	 30060	 0.003448	 0.008864	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30057	 30063	 0.004226	 0.010747	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30058	 30061	 0.010993	 0.010126	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30058	 30092	 0.008516	 0.013044	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30058	 85517	 0.014862	 0.024229	 0.00037	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30059	 30060	 0.003445	 0.007997	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30059	 30061	 0.003165	 0.008135	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30059	 30062	 0.008203	 0.021087	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30059	 85517	 0.010584	 0.017255	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30062	 85511	 0.008912	 0.022665	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85509	 30063	 0.003193	 0.014069	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30064	 30066	 0.005038	 0.013078	 0.00317	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30064	 30363	 0.001178	 0.004163	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30064	 85510	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30064	 85510	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30065	 30360	 0.031659	 0.025055	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30065	 30381	 0.006385	 0.01237	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30065	 85512	 0.013869	 0.031459	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30066	 30111	 0.007742	 0.02159	 0.00453	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30066	 85511	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30066	 85511	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30066	 85603	 0.008067	 0.028515	 0.00643	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85511	 30067	 0.013686	 0.024694	 0.00036	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30068	 30072	 0.001656	 0.007838	 0.00188	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30068	 30382	 0.007279	 0.019542	 0.00443	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30068	 85512	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30068	 85512	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30068	 85563	 0.000547	 0.00553	 0.00163	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30068	 85603	 0.007952	 0.028108	 0.00633	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30069	 30070	 0.004784	 0.011874	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85512	 30069	 0.006105	 0.013849	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30069	 85513	 0.003848	 0.011805	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30070	 30071	 0.003541	 0.011814	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30070	 30349	 0.001331	 0.009726	 0.00018	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85512	 30070	 0.019489	 0.019494	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30071	 30074	 0.005797	 0.009253	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30072	 85513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30072	 85513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30073	 30085	 0.009026	 0.017871	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30073	 30091	 0.008319	 0.021157	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85513	 30073	 0.005046	 0.014473	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30074	 30075	 0.007865	 0.007095	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30075	 30086	 0.009612	 0.00964	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30075	 85515	 0.007896	 0.01833	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30076	 30077	 0.002961	 0.008493	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30076	 30359	 0.002625	 0.010211	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30077	 30078	 0.003207	 0.008243	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30077	 30080	 0.002001	 0.008766	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30078	 85514	 0.002046	 0.005805	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30079	 30082	 0.001673	 0.004343	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30079	 30193	 0.005441	 0.014608	 0.00331	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30079	 30355	 0.000828	 0.004314	 0.00113	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30079	 85514	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30079	 85514	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30080	 30081	 0.004926	 0.009753	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30080	 85560	 0.030044	 0.046879	 0.00078	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30082	 30194	 0.004146	 0.009624	 0.00293	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30082	 30449	 0.004773	 0.012994	 0.00286	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30082	 85515	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30082	 85515	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30083	 30088	 0.005928	 0.009539	 0.00015	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85515	 30083	 0.004694	 0.011489	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30084	 30085	 0.014919	 0.010568	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30084	 30086	 0.015238	 0.012059	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30084	 30087	 0.003031	 0.007708	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30085	 85527	 0.00818	 0.027289	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30087	 30088	 0.007574	 0.005572	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30087	 30113	 0.00958	 0.007582	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30087	 30192	 0.003968	 0.015437	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85513	 30089	 0.005679	 0.013183	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30090	 30092	 0.01154	 0.029347	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30090	 30093	 0.008172	 0.016179	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85513	 30090	 0.007818	 0.020097	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30090	 85527	 0.015931	 0.053146	 0.00084	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30091	 30110	 0.006198	 0.017778	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30091	 85518	 0.005616	 0.027403	 0.00047	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30092	 30094	 0.007362	 0.012402	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30092	 30095	 0.004623	 0.008736	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30094	 30106	 0.015936	 0.040965	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30094	 30109	 0.003497	 0.008892	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30094	 30115	 0.020335	 0.040262	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30095	 30099	 0.01351	 0.013549	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30096	 30099	 0.006702	 0.01327	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30096	 30107	 0.017571	 0.013905	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30097	 30098	 0.000931	 0.003194	 0.00077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30097	 85516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30097	 85516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30098	 85517	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30098	 85517	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30099	 30100	 0.007281	 0.013136	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85517	 30100	 0.005269	 0.017388	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30101	 30102	 0.003498	 0.010529	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30101	 30104	 0.004505	 0.020073	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85506	 30101	 0.004486	 0.009577	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30102	 85522	 0.054257	 0.042938	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30102	 85608	 0.052817	 0.13433	 0.00212	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85516	 30103	 0.012004	 0.010757	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30104	 30106	 0.00987	 0.028308	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30105	 30106	 0.006727	 0.012321	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30106	 30108	 0.006608	 0.013083	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30106	 30124	 0.01986	 0.014357	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30107	 30121	 0.005225	 0.013432	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30107	 30124	 0.003612	 0.009286	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30109	 30110	 0.004939	 0.011696	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30109	 30122	 0.006952	 0.007424	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30110	 30118	 0.009546	 0.009748	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30111	 30194	 0.000888	 0.002991	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30111	 85518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30111	 85518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85518	 30112	 0.007425	 0.011375	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30113	 30114	 0.004401	 0.008714	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30114	 85527	 0.005009	 0.014365	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30115	 30116	 0.012703	 0.009957	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30115	 85519	 0.004389	 0.016073	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30117	 30133	 0.001961	 0.005338	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30117	 30136	 0.004836	 0.012983	 0.00294	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30117	 85519	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30117	 85519	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30117	 85603	 0.00173	 0.010134	 0.00276	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30119	 30120	 0.00324	 0.008329	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30119	 30122	 0.007391	 0.011797	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30120	 30132	 0.004939	 0.012695	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30121	 30123	 0.006171	 0.012218	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30121	 85520	 0.013687	 0.033502	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30122	 30123	 0.005602	 0.008582	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30123	 30129	 0.005893	 0.01206	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30124	 30126	 0.006912	 0.008995	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30125	 30129	 0.012807	 0.010541	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30127	 30128	 0.012715	 0.010063	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30128	 30129	 0.00466	 0.009227	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30129	 85521	 0.002069	 0.011623	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30130	 30134	 0.008091	 0.01363	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30131	 30144	 0.004324	 0.008561	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85519	 30132	 0.002922	 0.010223	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30133	 85520	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30133	 85520	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30134	 30135	 0.004833	 0.00686	 0.00011	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85520	 30134	 0.005464	 0.010819	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30135	 85521	 0.005251	 0.013498	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30136	 30139	 0.000515	 0.003196	 0.00077	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30136	 85521	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30136	 85521	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30137	 30138	 0.003675	 0.007277	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30137	 30140	 0.008527	 0.006461	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30137	 30141	 0.003116	 0.007068	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30137	 30150	 0.008793	 0.017233	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30139	 30177	 0.002157	 0.012633	 0.00344	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30141	 30146	 0.007134	 0.007619	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85521	 30141	 0.003106	 0.007409	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30142	 30145	 0.016223	 0.012839	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85521	 30142	 0.007346	 0.015034	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30143	 30145	 0.012158	 0.008789	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30143	 30146	 0.015279	 0.012091	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30143	 30147	 0.006022	 0.009612	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30144	 30197	 0.009813	 0.019429	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30144	 30201	 0.005564	 0.008524	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30145	 30199	 0.00752	 0.009787	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85519	 30145	 0.018167	 0.030176	 0.00064	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30147	 30148	 0.003194	 0.007927	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30148	 30149	 0.002399	 0.006167	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30148	 30154	 0.004275	 0.007714	 0.00011	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30149	 85529	 0.003025	 0.007404	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30150	 85538	 0.009001	 0.020418	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30151	 30152	 0.004368	 0.003456	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30152	 30153	 0.005456	 0.004185	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30153	 30154	 0.002898	 0.005931	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30153	 85538	 0.003506	 0.008302	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30154	 30155	 0.005514	 0.004364	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30156	 30162	 0.012822	 0.018202	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30156	 85522	 0.005594	 0.014227	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30157	 30158	 0.00159	 0.004202	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30158	 85522	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30158	 85522	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30159	 30169	 0.0095	 0.006729	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30160	 30161	 0.003424	 0.002626	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30161	 30163	 0.007862	 0.006719	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85522	 30161	 0.006047	 0.014036	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30162	 30166	 0.007357	 0.004942	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30163	 30164	 0.009385	 0.009479	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30163	 30165	 0.018837	 0.014907	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30164	 30170	 0.004767	 0.011067	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30165	 30166	 0.008208	 0.006296	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30165	 30167	 0.008661	 0.01856	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30165	 30172	 0.016088	 0.041355	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30167	 30168	 0.004703	 0.003563	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30169	 30170	 0.004785	 0.009793	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30169	 30171	 0.005047	 0.003994	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30169	 30172	 0.003913	 0.017435	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30172	 30173	 0.004928	 0.012232	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30172	 85608	 0.012899	 0.057476	 0.00098	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30173	 30174	 0.001769	 0.004549	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30174	 30175	 0.003525	 0.009765	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30175	 30179	 0.002099	 0.008882	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30176	 30179	 0.013999	 0.012895	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30176	 85523	 0.002296	 0.004546	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30177	 30182	 0.000302	 0.001766	 0.00048	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30177	 85523	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30177	 85523	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30178	 30179	 0.002486	 0.00577	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30178	 30181	 0.002127	 0.00541	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30179	 85608	 0.008627	 0.033562	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30180	 85524	 0.005711	 0.004476	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30181	 30184	 0.002843	 0.007231	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30182	 30185	 0.000404	 0.002322	 0.00066	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30182	 85524	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30182	 85524	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30183	 30184	 0.000928	 0.002634	 4e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30183	 85525	 0.001895	 0.004061	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30183	 85608	 0.006068	 0.015598	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30185	 85525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30185	 85525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30185	 85607	 0.000422	 0.003161	 0.00077	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85525	 30186	 0.005345	 0.00419	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85525	 30187	 0.004847	 0.011251	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30187	 85608	 0.001532	 0.00406	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30188	 30190	 0.004112	 0.008141	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30188	 30191	 0.00579	 0.004539	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30188	 85608	 0.036158	 0.091958	 0.00145	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30189	 30190	 0.014098	 0.011157	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30192	 85526	 0.002921	 0.015562	 0.00027	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30193	 85526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30193	 85526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30193	 85603	 0.001117	 0.005125	 0.00131	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30194	 85527	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30194	 85527	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30194	 85603	 0.000787	 0.00546	 0.00156	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30195	 30515	 0.002141	 0.007141	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30195	 85531	 0.002555	 0.014355	 0.00027	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30196	 30213	 0.00104	 0.004293	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30196	 85528	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30196	 85528	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30196	 85603	 0.001401	 0.008047	 0.00228	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30197	 30198	 0.003398	 0.008736	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85519	 30197	 0.024415	 0.017649	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30198	 30207	 0.009021	 0.013819	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30198	 30515	 0.003003	 0.010257	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30199	 30202	 0.003376	 0.008678	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30200	 30201	 0.002493	 0.005787	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30200	 30208	 0.002618	 0.006408	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30202	 30203	 0.002681	 0.006949	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30202	 30209	 0.005903	 0.007683	 0.00011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30203	 85529	 0.002401	 0.007059	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30204	 30213	 0.002821	 0.009833	 0.00228	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30204	 30241	 0.001069	 0.002775	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30204	 30242	 0.00122	 0.003402	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30204	 85529	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30204	 85529	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30205	 30206	 0.00436	 0.004452	 7e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30205	 30211	 0.005878	 0.008192	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85529	 30205	 0.002389	 0.006331	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30207	 30208	 0.007799	 0.005738	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30208	 30209	 0.00294	 0.0063	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30208	 30210	 0.012404	 0.009816	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30208	 85530	 0.00304	 0.014089	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30209	 30211	 0.008683	 0.005621	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30210	 30235	 0.011729	 0.009282	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30211	 30212	 0.00581	 0.004554	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30212	 30235	 0.014777	 0.011694	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30212	 30236	 0.008815	 0.006373	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30213	 30217	 0.001515	 0.008055	 0.00187	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30213	 85530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30213	 85530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30214	 30215	 0.010661	 0.017959	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30214	 30233	 0.003189	 0.007552	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85530	 30214	 0.00317	 0.008147	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30215	 30229	 0.003556	 0.009043	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85528	 30215	 0.00203	 0.007809	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30216	 85534	 0.004839	 0.011234	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30217	 30218	 0.000644	 0.001729	 0.00039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30217	 30219	 0.001089	 0.003734	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30217	 85531	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30217	 85531	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30217	 85603	 0.000811	 0.004984	 0.00144	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30218	 30219	 0.000609	 0.002089	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30218	 85532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30218	 85532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30219	 85533	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30219	 85533	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30220	 30316	 0.001776	 0.006749	 0.00189	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30220	 85534	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30220	 85534	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30220	 85603	 0.000777	 0.008333	 0.00266	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85533	 30221	 0.01038	 0.016651	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30222	 30223	 0.000821	 0.002131	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30222	 85535	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30222	 85535	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30223	 30270	 0.00372	 0.009831	 0.0023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30223	 85536	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30223	 85536	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30224	 30225	 0.00683	 0.011507	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85534	 30224	 0.007135	 0.018341	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30225	 30226	 0.010001	 0.012191	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30226	 30269	 0.028031	 0.022184	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85534	 30226	 0.012314	 0.031318	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30226	 85542	 0.018444	 0.022895	 0.0005	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30227	 30228	 0.0059	 0.013694	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85533	 30227	 0.00305	 0.009821	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30228	 30262	 0.008223	 0.019472	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30229	 30231	 0.002452	 0.005017	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30230	 30232	 0.002971	 0.007555	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30230	 30261	 0.007394	 0.018805	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30231	 30232	 0.010044	 0.010144	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30231	 30233	 0.015765	 0.012476	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85533	 30232	 0.009425	 0.024426	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30233	 30235	 0.004969	 0.012774	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30234	 30238	 0.007852	 0.013096	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30234	 85540	 0.003231	 0.008306	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30235	 30238	 0.011986	 0.009486	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30236	 30237	 0.005315	 0.008293	 0.00014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30237	 30240	 0.006961	 0.008858	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30237	 85537	 0.002185	 0.008744	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30238	 30239	 0.011817	 0.009352	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30238	 30253	 0.009751	 0.009074	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30239	 30240	 0.011653	 0.009222	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30241	 30243	 0.000301	 0.001853	 0.00053	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30241	 30254	 0.004076	 0.011366	 0.00239	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30241	 85537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30241	 85537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30242	 30243	 0.000578	 0.002313	 0.00058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30242	 85538	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30242	 85538	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30243	 85539	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30243	 85539	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30243	 85607	 0.001656	 0.014674	 0.00391	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30244	 30245	 0.001996	 0.007987	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30244	 30249	 0.002349	 0.006038	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30244	 30250	 0.00463	 0.002998	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85539	 30244	 0.008634	 0.00872	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30245	 30519	 0.005997	 0.029229	 0.00055	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30246	 30247	 0.00189	 0.001481	 2e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30246	 30248	 0.001998	 0.00459	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85538	 30246	 0.008066	 0.012355	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30248	 30249	 0.001277	 0.003283	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30251	 30258	 0.007624	 0.008386	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30252	 30253	 0.011858	 0.012108	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85537	 30253	 0.010305	 0.024403	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30254	 30263	 0.002805	 0.011025	 0.00288	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30254	 85540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30254	 85540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30254	 85603	 0.004391	 0.017581	 0.00443	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30255	 30256	 0.01128	 0.008299	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30255	 30258	 0.003585	 0.009216	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30255	 30259	 0.011994	 0.015071	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30255	 30261	 0.021278	 0.018185	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85540	 30255	 0.001421	 0.008638	 0.00016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30257	 30258	 0.009104	 0.007205	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30259	 85541	 0.019656	 0.023962	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30260	 30261	 0.013615	 0.020857	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30261	 85541	 0.008239	 0.018928	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30262	 30518	 0.005963	 0.011807	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30263	 30278	 0.000565	 0.002333	 0.00055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30263	 30280	 0.002985	 0.012632	 0.00284	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30263	 85541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30263	 85541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30264	 30268	 0.016651	 0.012251	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30265	 30266	 0.007977	 0.01852	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30265	 30518	 0.006961	 0.011112	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85541	 30266	 0.01683	 0.033323	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30266	 85542	 0.023796	 0.039686	 0.00058	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30266	 85543	 0.003174	 0.021211	 0.00047	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30267	 30268	 0.002595	 0.005309	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30267	 85542	 0.006909	 0.01776	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85536	 30269	 0.011091	 0.017703	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30269	 85542	 0.014372	 0.023559	 0.00042	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30269	 85554	 0.017734	 0.011912	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30270	 85542	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30270	 85542	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30270	 85603	 0.005849	 0.023418	 0.0059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30271	 30274	 0.008382	 0.017225	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85542	 30271	 0.01222	 0.023402	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30272	 30274	 0.016968	 0.015205	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30273	 85545	 0.020362	 0.014981	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30274	 30275	 0.005473	 0.014069	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30274	 30277	 0.003791	 0.011642	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30275	 30295	 0.004616	 0.020571	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30276	 30281	 0.00148	 0.005758	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30276	 85543	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30276	 85543	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85543	 30277	 0.005291	 0.01765	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30278	 30280	 0.002421	 0.009692	 0.00244	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30278	 85544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30278	 85544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85544	 30279	 0.01754	 0.012425	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30280	 85545	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30280	 85545	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30281	 30284	 0.001153	 0.004615	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84729	 30282	 0.014623	 0.032807	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30283	 30288	 0.015023	 0.015067	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30285	 30290	 0.016492	 0.025264	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30286	 85546	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30286	 85546	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30287	 30288	 0.007206	 0.017886	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30287	 30291	 0.007664	 0.01779	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30287	 30294	 0.007366	 0.014585	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30288	 30401	 0.006834	 0.022798	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85546	 30288	 0.005258	 0.020456	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30289	 30290	 0.008192	 0.019016	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30289	 30292	 0.007748	 0.01534	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30289	 30294	 0.02019	 0.032387	 0.0006	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30289	 85549	 0.006033	 0.023471	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30289	 85601	 0.002473	 0.017614	 0.0004	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30290	 30301	 0.012831	 0.021615	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30291	 85601	 0.014598	 0.041424	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30293	 30514	 0.006624	 0.011158	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30294	 30394	 0.007985	 0.018536	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30295	 85547	 0.003702	 0.022757	 0.00041	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30296	 30305	 0.007163	 0.016457	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30296	 30307	 0.005122	 0.017087	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30296	 85547	 0.011212	 0.043619	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30297	 85547	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30297	 85547	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30297	 85600	 0.002604	 0.013877	 0.00389	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30298	 30303	 0.002506	 0.008951	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30298	 85549	 0.003863	 0.018544	 0.00055	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30299	 30300	 0.001612	 0.01021	 0.00277	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30299	 30309	 0.000829	 0.005561	 0.00134	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30299	 85548	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30299	 85548	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30300	 85549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30300	 85549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30300	 85600	 0.000754	 0.006276	 0.0019	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30302	 30303	 0.004517	 0.011612	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30302	 30305	 0.007774	 0.014888	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85548	 30304	 0.012427	 0.009143	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30306	 30309	 0.003026	 0.007857	 0.00191	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30306	 30314	 0.001773	 0.004945	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30306	 85550	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30306	 85550	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85542	 30307	 0.034514	 0.027054	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30307	 85551	 0.008293	 0.014906	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30308	 30309	 0.001595	 0.004343	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30308	 85551	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30308	 85551	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30309	 30310	 0.000826	 0.003936	 0.00114	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30310	 30312	 0.00146	 0.00492	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30310	 30318	 0.003509	 0.00942	 0.00213	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30310	 85552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30310	 85552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85552	 30311	 0.006236	 0.012346	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30312	 30318	 0.001602	 0.004234	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30312	 85553	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30312	 85553	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30313	 30319	 0.004374	 0.011335	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85551	 30313	 0.010258	 0.026369	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85553	 30313	 0.007448	 0.015307	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30313	 85555	 0.033249	 0.024036	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30314	 85554	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30314	 85554	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85554	 30315	 0.006784	 0.008829	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30316	 30317	 0.001005	 0.00395	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30317	 30318	 0.003261	 0.008466	 0.00205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30317	 85555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30317	 85555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30318	 30328	 0.001117	 0.003391	 0.00074	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30319	 30320	 0.003654	 0.008482	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30320	 30326	 0.004835	 0.008725	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30321	 30323	 0.007502	 0.012637	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30321	 30324	 0.007161	 0.01292	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85534	 30321	 0.010133	 0.033802	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85555	 30321	 0.009379	 0.015799	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30322	 30348	 0.002114	 0.01062	 0.00276	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30322	 85556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30322	 85556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30323	 30336	 0.00633	 0.008238	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30325	 30330	 0.003209	 0.009204	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85556	 30325	 0.015302	 0.035526	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30325	 85557	 0.002398	 0.008	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30326	 30327	 0.00452	 0.009289	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30326	 30335	 0.00353	 0.008196	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85555	 30326	 0.005205	 0.015966	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85556	 30326	 0.021018	 0.037923	 0.00055	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30327	 85557	 0.002741	 0.005873	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30328	 85557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30328	 85557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30329	 30459	 0.007215	 0.014284	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85557	 30329	 0.002289	 0.004887	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30330	 30457	 0.003902	 0.010032	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30331	 30333	 0.002858	 0.005602	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30331	 30334	 0.010039	 0.013696	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85556	 30331	 0.007991	 0.018922	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30332	 30333	 0.007656	 0.006059	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30334	 30335	 0.003962	 0.007844	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30336	 30337	 0.003949	 0.003096	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30336	 30339	 0.028029	 0.055496	 0.00081	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85550	 30337	 0.051549	 0.067751	 0.00093	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30338	 85558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30338	 85558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85558	 30339	 0.00972	 0.024986	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30339	 85560	 0.009918	 0.028143	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30340	 30341	 0.005477	 0.012715	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30340	 30344	 0.004357	 0.011903	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30341	 30342	 0.006863	 0.008366	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85558	 30341	 0.006731	 0.017119	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30343	 30453	 0.001785	 0.005822	 0.00155	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30343	 85559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30343	 85559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30343	 85603	 0.00713	 0.025201	 0.00568	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30344	 30345	 0.013476	 0.010563	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30344	 30347	 0.005819	 0.008261	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84747	 30344	 0.009677	 0.024876	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30346	 30347	 0.005671	 0.004173	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85559	 30347	 0.008776	 0.022559	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30348	 85560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30348	 85560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30348	 85603	 0.000901	 0.007985	 0.00213	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30349	 85564	 0.001614	 0.010553	 0.00024	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30349	 85565	 0.004943	 0.011475	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30350	 30352	 0.00011	 0.001301	 0.0024	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30350	 85561	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30350	 85561	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30350	 85581	 0.000182	 0.002221	 0.00828	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30351	 30443	 0.000941	 0.003697	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30351	 30449	 0.000808	 0.004211	 0.0011	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85561	 30351	 0.000452	 0.003665	 0.00117	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30351	 85562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30351	 85562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30352	 30353	 7.1e-05	 0.000748	 0.00141	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30353	 30426	 0.007207	 0.046811	 0.09334	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30353	 85563	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85564	 30353	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30353	 85599	 0.004141	 0.027949	 0.05148	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30354	 30358	 0.003047	 0.007832	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85562	 30354	 0.003699	 0.011745	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30354	 85565	 0.004923	 0.01143	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85563	 30355	 0.000574	 0.003564	 0.00101	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30355	 85565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30355	 85565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30356	 30380	 0.005825	 0.02266	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30356	 85582	 0.004341	 0.021191	 0.00044	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30357	 85582	 0.005999	 0.01542	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30357	 85586	 0.010062	 0.025589	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30358	 30359	 0.00114	 0.003021	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30358	 85591	 0.009914	 0.008944	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30359	 85591	 0.002616	 0.006726	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30360	 30375	 0.036683	 0.02903	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30360	 30384	 0.008378	 0.016587	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30360	 85566	 0.023461	 0.01839	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85503	 30361	 0.007768	 0.015225	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30361	 85567	 0.016215	 0.012832	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30362	 30363	 0.001495	 0.004072	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30362	 30382	 0.002591	 0.010079	 0.00269	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30362	 85566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30362	 85566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30363	 30377	 0.001387	 0.004834	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30363	 85567	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30363	 85567	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30364	 30373	 0.000433	 0.002415	 0.00062	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85020	 30365	 0.020338	 0.014963	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30366	 30367	 0.001438	 0.003734	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85019	 30366	 0.001079	 0.006702	 0.00189	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30367	 30370	 0.000657	 0.003737	 0.00108	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30367	 30373	 0.002537	 0.006378	 0.00165	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30367	 85568	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30367	 85568	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85568	 30368	 0.001954	 0.005178	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30368	 85569	 0.002669	 0.008189	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30369	 30370	 0.000734	 0.002518	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30370	 85569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30370	 85569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85569	 30371	 0.004227	 0.010009	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30371	 85570	 0.002668	 0.006785	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30372	 30373	 0.000612	 0.002757	 0.00073	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30373	 85570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30373	 85570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30374	 30378	 0.000632	 0.003632	 0.00103	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30374	 85571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30374	 85571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30375	 30376	 0.010577	 0.017666	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30375	 85572	 0.008923	 0.017668	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30377	 30378	 0.00034	 0.001991	 0.00054	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30377	 85572	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30377	 85572	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30379	 30382	 0.001345	 0.003611	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30379	 85573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30379	 85573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30380	 30381	 0.006486	 0.016672	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30381	 30383	 0.005494	 0.012756	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30382	 85574	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30382	 85574	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85574	 30383	 0.004504	 0.012782	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30384	 30385	 0.004047	 0.009181	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85573	 30385	 0.009595	 0.015316	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85574	 30385	 0.00512	 0.012213	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30386	 30388	 0.004802	 0.008664	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30387	 30388	 0.014191	 0.010752	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30388	 30431	 0.00404	 0.013331	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85574	 30388	 0.009073	 0.017963	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30389	 30496	 0.013053	 0.01033	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30390	 30506	 0.019572	 0.0144	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30390	 30508	 0.023282	 0.021445	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30391	 30398	 0.034061	 0.052178	 0.00073	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30391	 30399	 0.010896	 0.037219	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30391	 30509	 0.011521	 0.027281	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30392	 30510	 0.00998	 0.020423	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30392	 85575	 0.014196	 0.041746	 0.00086	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30393	 30395	 0.004442	 0.006473	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30394	 85575	 0.010729	 0.047809	 0.00081	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30395	 30397	 0.006616	 0.016826	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30395	 30514	 0.007976	 0.018517	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30396	 30397	 0.008288	 0.013823	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30397	 85575	 0.004679	 0.026288	 0.00049	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30398	 30415	 0.033258	 0.085495	 0.00132	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30398	 30429	 0.04387	 0.10185	 0.00151	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30399	 85578	 0.005116	 0.021353	 0.00062	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30400	 30404	 0.003269	 0.008487	 0.00206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30400	 30408	 0.001795	 0.004888	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30400	 85575	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30400	 85575	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30400	 85605	 0.001759	 0.013622	 0.00477	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30401	 30402	 0.003854	 0.017175	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30401	 30403	 0.009771	 0.019345	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30401	 30405	 0.012069	 0.015862	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30402	 85576	 0.002777	 0.013329	 0.0004	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30403	 30406	 0.006727	 0.01332	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30404	 30408	 0.001959	 0.005177	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30404	 85576	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30404	 85576	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30404	 85600	 0.004921	 0.019343	 0.00506	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30404	 85605	 0.003771	 0.022463	 0.00591	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30406	 30407	 0.015804	 0.028516	 0.00041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85575	 30406	 0.009626	 0.043073	 0.00089	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30408	 85577	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30408	 85577	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30409	 30521	 0.030339	 0.02401	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85577	 30409	 0.010887	 0.017377	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30410	 85578	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30410	 85578	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30410	 85605	 0.002015	 0.01071	 0.00248	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30411	 85606	 0.015535	 0.039508	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84692	 30412	 0.004151	 0.030316	 0.00779	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30412	 85579	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30412	 85579	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30412	 85600	 0.009393	 0.037608	 0.00948	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30412	 85605	 0.002172	 0.008697	 0.00219	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85578	 30413	 0.015941	 0.031562	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85579	 30413	 0.005484	 0.014097	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30414	 30415	 0.014048	 0.027813	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30414	 30417	 0.004149	 0.012741	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30414	 30422	 0.010049	 0.02333	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30415	 30416	 0.012392	 0.016287	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30415	 30422	 0.038217	 0.029315	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30415	 85580	 0.008218	 0.039448	 0.00118	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85579	 30417	 0.0041	 0.015949	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30418	 30420	 0.006243	 0.017714	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30418	 85580	 0.016034	 0.029813	 0.0007	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30419	 30420	 0.002818	 0.010963	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30419	 85606	 0.005362	 0.021914	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30421	 30425	 0.008072	 0.015009	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30423	 30424	 0.008121	 0.014596	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30425	 30427	 0.011218	 0.02221	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30425	 30428	 0.041376	 0.10636	 0.00165	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30425	 85580	 0.014466	 0.056496	 0.00125	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30426	 30535	 0.014009	 0.091186	 0.18237	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84691	 30426	 0.000639	 0.008498	 0.01815	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30426	 85580	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30426	 85580	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30430	 30431	 0.003543	 0.013783	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30430	 30434	 0.002413	 0.012207	 0.00021	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30431	 30432	 0.003618	 0.008312	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30432	 30433	 0.005638	 0.013351	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30433	 85583	 0.004936	 0.016465	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30434	 85582	 0.001171	 0.006266	 0.00019	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30435	 30520	 0.000191	 0.002475	 0.15793	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30435	 30524	 0.000315	 0.003757	 0.28193	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30435	 85581	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30436	 30437	 0.001429	 0.004903	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30436	 30442	 0.002494	 0.008135	 0.00216	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85024	 30437	 0.001725	 0.010717	 0.00302	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30437	 85583	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30437	 85583	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30438	 30439	 0.002313	 0.009791	 0.0022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85024	 30438	 0.001864	 0.010918	 0.00297	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30438	 85584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30438	 85584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30439	 30445	 0.004191	 0.011686	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30439	 85585	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30439	 85585	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30440	 85586	 0.014816	 0.023843	 0.00037	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30440	 85588	 0.012695	 0.009951	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85584	 30441	 0.013972	 0.046109	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30441	 85586	 0.021735	 0.021953	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30442	 30445	 0.001127	 0.003867	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30442	 85586	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30442	 85586	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30443	 30444	 0.000566	 0.001888	 0.00048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30443	 85587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30443	 85587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30444	 30446	 0.000963	 0.002544	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30444	 30448	 0.000615	 0.002227	 0.00048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30444	 30449	 0.001155	 0.003052	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30445	 30446	 0.000509	 0.002154	 0.00048	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30445	 85588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30445	 85588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30446	 30453	 0.001203	 0.004194	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30446	 85589	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30446	 85589	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85589	 30447	 0.004972	 0.008937	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30447	 85592	 0.012866	 0.010182	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30448	 30450	 0.001244	 0.003287	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30448	 30453	 0.001047	 0.002524	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30449	 30450	 0.000816	 0.002342	 0.00058	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30449	 85590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30449	 85590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30450	 85591	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30450	 85591	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30451	 30452	 0.017594	 0.011818	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85559	 30451	 0.03819	 0.025653	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85591	 30451	 0.004083	 0.010495	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85590	 30452	 0.004536	 0.011661	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30453	 85592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30453	 85592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85559	 30454	 0.027185	 0.05267	 0.00113	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85585	 30454	 0.006193	 0.038888	 0.00085	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85556	 30455	 0.01729	 0.036914	 0.00083	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30456	 30457	 0.014909	 0.010015	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30457	 30458	 0.010256	 0.013479	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30459	 30460	 0.011131	 0.008809	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30460	 30461	 0.003688	 0.008472	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85556	 30460	 0.071197	 0.068793	 0.001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30461	 30462	 0.002159	 0.008399	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30462	 30464	 0.012589	 0.024924	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30462	 30465	 0.003348	 0.011169	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30463	 30464	 0.002679	 0.007412	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30463	 30472	 0.006646	 0.009059	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30463	 30473	 0.002123	 0.006512	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30463	 30479	 0.013596	 0.026646	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30464	 30471	 0.005831	 0.009307	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30465	 30469	 0.010486	 0.017665	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30465	 85594	 0.015326	 0.046128	 0.0009	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85553	 30466	 0.008733	 0.017115	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85548	 30467	 0.007546	 0.014941	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30468	 30482	 0.005918	 0.009446	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85552	 30468	 0.021655	 0.023818	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30469	 30470	 0.011664	 0.008432	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30469	 30482	 0.005973	 0.013661	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30473	 85593	 0.00181	 0.006338	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30474	 30477	 0.000944	 0.003336	 0.00075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30474	 85593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30474	 85593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30475	 30476	 0.005932	 0.013628	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85593	 30475	 0.004264	 0.012834	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30476	 30490	 0.006932	 0.016093	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30477	 30485	 0.001964	 0.006845	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30477	 30489	 0.00075	 0.002948	 0.00077	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30478	 30479	 0.00507	 0.00854	 0.00012	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30479	 30480	 0.008433	 0.009275	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30479	 85594	 0.002785	 0.015651	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30481	 30482	 0.004742	 0.00847	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30482	 30483	 0.006293	 0.014607	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30482	 85594	 0.007896	 0.026058	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30483	 30484	 0.002703	 0.007754	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30484	 30501	 0.003238	 0.012595	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30485	 85594	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30485	 85594	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30485	 85597	 0.001002	 0.006349	 0.00172	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85594	 30486	 0.01757	 0.013772	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30487	 30489	 0.000708	 0.002781	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30487	 30497	 0.000696	 0.003556	 0.00089	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30487	 85595	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30487	 85595	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85595	 30488	 0.005721	 0.008677	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30490	 30491	 0.00799	 0.020539	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30490	 85598	 0.010559	 0.042257	 0.00089	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30491	 30493	 0.019093	 0.013802	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30492	 85596	 0.005492	 0.009658	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30494	 85596	 0.009847	 0.019495	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30495	 30496	 0.012796	 0.008284	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30496	 85598	 0.007021	 0.016297	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30497	 85596	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30497	 85596	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30497	 85597	 0.000498	 0.003091	 0.00075	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30498	 30517	 0.005193	 0.017323	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30498	 85598	 0.004994	 0.011472	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30499	 30505	 0.000274	 0.002838	 0.00611	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30499	 85597	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85598	 30499	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85598	 30500	 0.00542	 0.012581	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85598	 30501	 0.002333	 0.013126	 0.00028	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30502	 30503	 0.005092	 0.016985	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85548	 30502	 0.009091	 0.018604	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30503	 85602	 0.005191	 0.018176	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30504	 30520	 0.000256	 0.003266	 0.21367	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30504	 30522	 0.000193	 0.002299	 0.17248	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30504	 85599	 0.000118	 0.009419	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85599	 30505	 0.000105	 0.001471	 0.00282	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30505	 85602	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30505	 85602	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30506	 30507	 0.029177	 0.052646	 0.00076	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30506	 30512	 0.018577	 0.018763	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30506	 30517	 0.004885	 0.01612	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85602	 30506	 0.005873	 0.026171	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30508	 30509	 0.009087	 0.017991	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30509	 30510	 0.051477	 0.040738	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30510	 30511	 0.005757	 0.014641	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85601	 30510	 0.017635	 0.045332	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30511	 30512	 0.006197	 0.010349	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30513	 30514	 0.006731	 0.017794	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85601	 30513	 0.009758	 0.024816	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85602	 30513	 0.016009	 0.034305	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85528	 30515	 0.003505	 0.00901	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84693	 30516	 0.16982	 0.12277	 0.00186	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85541	 30518	 0.00389	 0.006209	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30519	 85608	 0.004877	 0.025985	 0.00046	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30520	 85603	 0.000173	 0.013839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30520	 85603	 0.000173	 0.013839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30522	 85605	 0.000135	 0.010812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85512	 30523	 0.009862	 0.018063	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30524	 85607	 0.000173	 0.013839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84692	 30525	 0.018993	 0.050995	 0.01156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30525	 85609	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30525	 85609	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85609	 30526	 0.054325	 0.13484	 0.00224	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30526	 85610	 0.050253	 0.055273	 0.00074	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84692	 30527	 0.02731	 0.093718	 0.02246	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30527	 85610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30527	 85610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30527	 85611	 0.077569	 0.20539	 0.04818	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30528	 30529	 0.068933	 0.048829	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30528	 30530	 0.040451	 0.082781	 0.00204	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30528	 30532	 0.099629	 0.23134	 0.00344	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85610	 30528	 0.014799	 0.049369	 0.00078	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30530	 30531	 0.037035	 0.066152	 0.00098	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30532	 30534	 0.11733	 0.27247	 0.00405	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30533	 30534	 0.075739	 0.20694	 0.00352	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30533	 85612	 0.01604	 0.044371	 0.00103	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30535	 85611	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85612	 30535	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85612	 30536	 0.050672	 0.039719	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30537	 85613	 0.38535	 0.30511	 0.00384	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30538	 30541	 0.007577	 0.025994	 0.00623	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85611	 30538	 0.031135	 0.086847	 0.01823	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30538	 85613	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30538	 85613	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85613	 30539	 0.08901	 0.063052	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30540	 30541	 0.003654	 0.012533	 0.003	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30540	 30542	 0.013359	 0.034624	 0.01048	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30540	 30544	 0.020612	 0.070722	 0.01695	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85611	 30540	 0.045284	 0.12636	 0.02654	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30542	 30543	 0.008763	 0.030974	 0.00698	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30543	 30544	 0.004105	 0.013831	 0.00344	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30544	 30545	 0.001158	 0.004402	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30545	 30546	 0.001019	 0.005772	 0.00143	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30546	 85614	 0.001077	 0.00619	 0.00175	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30547	 85614	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85613	 30548	 0.24688	 0.48915	 0.00718	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85615	 30548	 0.004195	 0.010784	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85615	 30549	 0.012737	 0.010079	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30550	 30552	 0.007315	 0.004736	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85615	 30550	 0.006247	 0.01606	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30550	 85616	 0.30049	 0.23561	 0.00302	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85614	 30551	 0.021768	 0.057538	 0.01347	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30551	 85616	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30551	 85616	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85610	 30553	 0.070608	 0.055879	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30555	 30556	 0.002419	 0.008552	 0.00193	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30555	 30558	 0.00234	 0.007007	 0.00158	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30556	 32359	 0.011942	 0.048598	 0.01184	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30557	 30559	 0.00322	 0.015019	 0.00372	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30558	 30559	 0.001834	 0.009771	 0.00274	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30558	 85617	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30558	 85617	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30558	 86187	 0.007454	 0.050009	 0.01207	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30560	 30564	 0.010175	 0.039585	 0.01057	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30560	 32356	 0.008274	 0.028834	 0.00669	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30560	 85618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30560	 85618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30561	 32358	 0.008766	 0.035098	 0.00884	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30561	 85619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30561	 85619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85617	 30562	 0.030736	 0.05715	 0.00134	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85619	 30562	 0.023401	 0.060155	 0.00093	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30563	 30565	 0.008481	 0.037795	 0.01027	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30563	 32350	 0.019849	 0.09109	 0.02335	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30563	 85620	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30563	 85620	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30564	 30565	 0.00655	 0.030048	 0.0077	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30564	 85621	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30564	 85621	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84700	 30566	 0.12195	 0.13414	 0.00179	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30567	 31822	 0.10221	 0.22626	 0.00371	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30567	 85625	 0.038689	 0.12907	 0.00205	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30568	 85624	 0.21234	 0.16807	 0.00212	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30569	 30571	 0.033965	 0.061049	 0.0011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30570	 35253	 0.000569	 0.01055	 0.69782	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30570	 85622	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30570	 85622	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85624	 30571	 0.0265	 0.067393	 0.00107	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85623	 30572	 0.009156	 0.032364	 0.00729	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30572	 85625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30572	 85625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30573	 30574	 0.000792	 0.005139	 0.01024	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30573	 31837	 0.003855	 0.02503	 0.04987	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30573	 85626	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30573	 85626	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85622	 30574	 0.001506	 0.010221	 0.01861	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30575	 30586	 0.012453	 0.032912	 0.0077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30575	 30588	 0.012996	 0.035384	 0.0078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85623	 30575	 0.009663	 0.068355	 0.01876	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30576	 85627	 0.012128	 0.02751	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30577	 30578	 0.012133	 0.021892	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30577	 30579	 0.1185	 0.085669	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30577	 85627	 0.029188	 0.057791	 0.00085	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30577	 86144	 0.32951	 0.26087	 0.00328	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30579	 85627	 0.011684	 0.027668	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30580	 30583	 0.009363	 0.032632	 0.00757	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85623	 30580	 0.013593	 0.082227	 0.02099	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30580	 85627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30580	 85627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30580	 85628	 0.004263	 0.011267	 0.00264	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85622	 30581	 0.002439	 0.029065	 0.06293	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30581	 85628	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85629	 30581	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30582	 30584	 0.03185	 0.023433	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85628	 30583	 0.004124	 0.022734	 0.00531	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30583	 85630	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30583	 85630	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30584	 30585	 0.037378	 0.02702	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85630	 30584	 0.004932	 0.009764	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30586	 30588	 0.001753	 0.004633	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30586	 30591	 0.003179	 0.008254	 0.002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30586	 85631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30586	 85631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30587	 85633	 0.01024	 0.026041	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30588	 85632	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30588	 85632	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30589	 30591	 0.002029	 0.005362	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30589	 85633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30589	 85633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30590	 30592	 0.015953	 0.016112	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30590	 85634	 0.006561	 0.009951	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30591	 85634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30591	 85634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30592	 30593	 0.003634	 0.007437	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85630	 30593	 0.006278	 0.028091	 0.00058	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85631	 30593	 0.014128	 0.025491	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30594	 30596	 0.00824	 0.01481	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30595	 30596	 0.007977	 0.020505	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30595	 30597	 0.006462	 0.012376	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85630	 30595	 0.007594	 0.052127	 0.00095	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30598	 85635	 0.022878	 0.018105	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30599	 30607	 0.023888	 0.065047	 0.01433	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30599	 31845	 0.010787	 0.0424	 0.01109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85155	 30599	 0.03027	 0.14338	 0.03452	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85628	 30599	 0.012896	 0.044242	 0.0106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30599	 85635	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30599	 85635	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85635	 30600	 0.039181	 0.080183	 0.00197	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30600	 86029	 0.043151	 0.07786	 0.00113	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85630	 30601	 0.067889	 0.053727	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30602	 30606	 0.018467	 0.014615	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30603	 30604	 0.002999	 0.008363	 0.00176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30603	 30607	 0.0029	 0.006988	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30604	 30607	 0.005844	 0.015688	 0.00356	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85628	 30604	 0.006935	 0.027259	 0.00713	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30604	 85636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30604	 85636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30605	 30606	 0.017193	 0.013606	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85636	 30606	 0.00848	 0.021799	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30607	 32187	 0.009396	 0.025226	 0.00572	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84892	 30607	 0.09116	 0.23728	 0.05777	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84690	 30608	 0.027569	 0.096518	 0.03201	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30608	 85637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30608	 85637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30608	 85638	 0.014175	 0.037464	 0.00877	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85213	 30609	 0.42441	 0.30702	 0.00466	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85637	 30609	 0.1481	 0.23113	 0.00386	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30609	 85962	 0.31695	 0.62829	 0.00923	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85637	 30610	 0.13861	 0.10199	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30610	 85639	 0.017372	 0.045922	 0.00083	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30611	 30617	 0.000703	 0.004927	 0.00839	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84701	 30611	 0.014841	 0.10045	 0.18581	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30611	 85638	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85639	 30611	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30612	 85640	 0.024664	 0.044503	 0.00064	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30613	 30615	 0.10508	 0.074438	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30614	 30615	 0.042879	 0.031547	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30615	 85640	 0.014874	 0.038235	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30616	 30617	 0.000502	 0.003421	 0.00616	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84689	 30616	 0.003899	 0.029557	 0.05439	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30616	 85640	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30616	 85640	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30617	 85641	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30617	 85641	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85641	 30618	 0.076622	 0.060639	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30619	 30620	 0.018892	 0.013657	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30619	 30624	 0.006427	 0.014578	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30619	 30627	 0.014457	 0.028624	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30619	 85731	 0.008072	 0.020528	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30619	 85732	 0.005612	 0.015545	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30621	 30622	 0.00032	 0.001256	 0.00033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30621	 30679	 0.003308	 0.009224	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30621	 30821	 0.001169	 0.003446	 0.0008	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30622	 30663	 0.007035	 0.019619	 0.00412	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30622	 30824	 0.000588	 0.003328	 0.00082	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30623	 85647	 0.005948	 0.013807	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30623	 85731	 0.005759	 0.013369	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30624	 30626	 0.009375	 0.014361	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30625	 30626	 0.019617	 0.013896	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30625	 85650	 0.023696	 0.018753	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30627	 30673	 0.007605	 0.018008	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30627	 85728	 0.006509	 0.017207	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30628	 30629	 0.001962	 0.006936	 0.00156	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30628	 30630	 0.000941	 0.002832	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30628	 30681	 0.000794	 0.004925	 0.00119	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30629	 30630	 0.001022	 0.003505	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30629	 30631	 0.001762	 0.009488	 0.00261	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30629	 85726	 0.001022	 0.003611	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30631	 30632	 0.001139	 0.002927	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30631	 30642	 0.001298	 0.005956	 0.00153	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30632	 30634	 0.000428	 0.002151	 0.00056	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30632	 30689	 0.000849	 0.005694	 0.00137	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30632	 85642	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30632	 85642	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85642	 30633	 0.023972	 0.018971	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30633	 85666	 0.004769	 0.01226	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30634	 30639	 0.00105	 0.005968	 0.00173	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30635	 30710	 0.001091	 0.00548	 0.00143	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30635	 85669	 0.001282	 0.00751	 0.00205	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30636	 30637	 0.000921	 0.004895	 0.00114	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30636	 30705	 0.000729	 0.004888	 0.00118	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30636	 30710	 0.001373	 0.005588	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30636	 85643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30636	 85643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30637	 30639	 0.000682	 0.003804	 0.00097	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30637	 85669	 0.00086	 0.008253	 0.0024	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30638	 85671	 0.013826	 0.017373	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30640	 30641	 0.000809	 0.003713	 0.00095	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30640	 30714	 0.000974	 0.005344	 0.00141	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30641	 30642	 0.000868	 0.004212	 0.00096	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30642	 85644	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30642	 85644	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30643	 85674	 0.012595	 0.016553	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30644	 85645	 0.005537	 0.01133	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30644	 85730	 0.009581	 0.019607	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30645	 30717	 0.001377	 0.006681	 0.00153	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30645	 30823	 0.000907	 0.003837	 0.00086	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30645	 85645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30645	 85645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30646	 30647	 0.001268	 0.005366	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30646	 30730	 0.001091	 0.004505	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30646	 85646	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30646	 85646	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30647	 30650	 0.003848	 0.010476	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30647	 30820	 0.001741	 0.004475	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30647	 85647	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30647	 85647	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30648	 30652	 0.000835	 0.003344	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30648	 30734	 0.001525	 0.006105	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30648	 85648	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30648	 85648	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30649	 30735	 0.003428	 0.009059	 0.00212	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30649	 85649	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30649	 85649	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30649	 85690	 0.001515	 0.003932	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30650	 30663	 0.000882	 0.003085	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30650	 30820	 0.00211	 0.005423	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30650	 85650	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30650	 85650	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30651	 30653	 0.009907	 0.008877	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30651	 30758	 0.004654	 0.013347	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30652	 30654	 0.000588	 0.002355	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30653	 85651	 0.012042	 0.009237	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30654	 30655	 0.000933	 0.002506	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30654	 30656	 0.001478	 0.006101	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30654	 85651	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30654	 85651	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30655	 30660	 0.000588	 0.001602	 0.00035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30656	 30661	 0.001311	 0.005154	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30656	 30663	 0.002604	 0.007677	 0.00179	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30656	 30753	 0.001677	 0.004216	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30656	 85652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30656	 85652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30657	 30666	 0.044354	 0.032633	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30657	 85696	 0.008639	 0.017679	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30657	 85700	 0.056998	 0.074913	 0.00103	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30658	 30659	 0.007577	 0.005996	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85652	 30658	 0.018655	 0.014763	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30658	 85653	 0.016581	 0.012719	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30658	 85656	 0.024943	 0.02053	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85652	 30659	 0.008561	 0.008647	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30659	 85653	 0.015235	 0.012056	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30660	 85653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30660	 85653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30661	 30662	 0.000748	 0.002722	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30661	 30769	 0.001665	 0.005711	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84674	 30661	 0.022922	 0.12351	 0.03396	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30662	 30665	 0.002098	 0.005546	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30662	 30667	 0.001483	 0.003574	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30663	 30664	 0.000771	 0.002724	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30664	 30665	 0.000668	 0.002673	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30664	 85654	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30664	 85654	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30665	 30667	 0.001387	 0.003775	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30665	 85655	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30665	 85655	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30666	 85656	 0.038307	 0.028184	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30667	 85656	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30667	 85656	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30668	 30669	 0.006769	 0.006837	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30668	 30671	 0.011912	 0.010972	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30668	 30672	 0.017496	 0.016116	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85654	 30669	 0.040508	 0.031752	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30669	 85728	 0.015845	 0.036781	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30670	 30671	 0.014758	 0.009554	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30670	 30673	 0.019913	 0.015609	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85654	 30672	 0.016242	 0.014554	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85655	 30672	 0.015687	 0.015844	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30674	 30675	 0.02529	 0.033238	 0.00046	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85656	 30674	 0.008127	 0.02331	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30675	 85657	 0.010104	 0.025973	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30676	 30678	 0.001108	 0.003877	 0.00128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30676	 85657	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30676	 85657	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30677	 30678	 0.001011	 0.004048	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30677	 30679	 0.002274	 0.005716	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30677	 30681	 0.003233	 0.008545	 0.002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30677	 30821	 0.004318	 0.012041	 0.00253	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30679	 30680	 0.001545	 0.004011	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30679	 30821	 0.002054	 0.00543	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30680	 30681	 0.000788	 0.00221	 0.00057	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30680	 30779	 0.000684	 0.002784	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30681	 30682	 0.001471	 0.004005	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30682	 30685	 0.0015	 0.005229	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30682	 30777	 0.001243	 0.004974	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30683	 30687	 0.015638	 0.015968	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30683	 85659	 0.017665	 0.029461	 0.00043	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30683	 85727	 0.006003	 0.026859	 0.00055	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30684	 30685	 0.002044	 0.005566	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30684	 85726	 0.002654	 0.009248	 0.00214	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30685	 30688	 0.001369	 0.003441	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30685	 85658	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30685	 85658	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30685	 85664	 0.003549	 0.00938	 0.0022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85658	 30686	 0.021088	 0.015977	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30686	 85665	 0.023585	 0.025689	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30688	 30691	 0.00143	 0.004907	 0.00118	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30688	 85659	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30688	 85659	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30689	 30690	 0.000947	 0.003909	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30689	 30696	 0.003465	 0.009159	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30689	 85660	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30689	 85660	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30690	 30691	 0.001025	 0.003516	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30691	 30692	 0.002354	 0.00611	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30692	 30696	 0.001626	 0.005747	 0.0013	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30692	 85661	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30692	 85661	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30692	 85664	 0.001925	 0.007706	 0.00194	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85643	 30693	 0.026813	 0.049856	 0.00117	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30694	 30695	 0.001144	 0.004657	 0.00113	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30694	 30703	 0.000497	 0.002631	 0.00067	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30695	 30696	 0.001171	 0.004016	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30695	 30697	 0.002564	 0.006656	 0.00162	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30697	 30698	 0.003242	 0.008568	 0.00201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30697	 85662	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30697	 85662	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30698	 30699	 0.001627	 0.006887	 0.00155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30699	 30797	 0.001989	 0.007965	 0.00201	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30699	 85663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30699	 85663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85663	 30700	 0.006234	 0.015855	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30700	 85665	 0.007212	 0.016568	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30701	 30781	 0.000631	 0.004157	 0.00804	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30701	 85664	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85665	 30701	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30702	 85718	 0.019003	 0.024975	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30703	 30705	 0.000649	 0.0038	 0.00103	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30704	 30709	 0.009411	 0.024191	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30705	 85666	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30705	 85666	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85666	 30706	 0.013384	 0.011993	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30707	 85720	 0.034617	 0.027135	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30708	 30709	 0.003806	 0.016345	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30708	 85667	 0.004261	 0.017082	 0.00044	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30709	 30817	 0.003635	 0.014855	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30709	 85721	 0.009459	 0.053767	 0.00097	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30710	 85667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30710	 85667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30711	 30712	 0.006787	 0.016071	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30711	 32005	 0.002281	 0.02098	 0.00042	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30711	 85670	 0.002937	 0.028778	 0.00056	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30712	 85672	 0.01074	 0.019303	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30713	 30803	 1.5e-05	 0.000321	 0.03081	 3450.0	 3622.5	 3795.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30713	 85668	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30713	 85668	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85669	 30714	 0.000668	 0.003882	 0.00091	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30714	 85671	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30714	 85671	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30715	 30716	 0.001362	 0.005452	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30715	 32004	 0.001297	 0.005278	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30715	 85672	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30715	 85672	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30716	 30717	 0.001102	 0.006045	 0.0016	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30716	 85673	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30716	 85673	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30716	 86075	 0.004372	 0.023543	 0.00647	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30717	 85674	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30717	 85674	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85674	 30718	 0.0053	 0.013625	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30718	 85676	 0.023309	 0.018446	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30719	 30816	 0.010289	 0.018493	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30719	 86083	 0.015483	 0.031685	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30720	 30722	 0.000529	 0.003153	 0.00083	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30720	 32007	 0.000884	 0.005599	 0.00152	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30721	 30723	 0.000689	 0.002806	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30721	 32016	 0.000882	 0.00353	 0.00119	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30722	 30724	 0.000607	 0.003072	 0.00086	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30723	 30725	 0.000906	 0.003156	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30723	 85675	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30723	 85675	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30724	 30726	 0.000698	 0.004053	 0.00095	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30725	 30729	 0.00124	 0.004254	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30726	 30728	 0.000864	 0.002962	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30726	 85676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30726	 85676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85676	 30727	 0.0059	 0.009939	 0.00014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30728	 30730	 0.001088	 0.003792	 0.00088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30728	 85677	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30728	 85677	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30729	 30732	 0.001303	 0.004469	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30729	 85678	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30729	 85678	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30730	 85679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30730	 85679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30731	 30732	 0.001805	 0.005033	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30731	 30734	 0.002415	 0.005605	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30732	 85680	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30732	 85680	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30733	 30736	 0.001421	 0.004874	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30733	 32025	 0.000984	 0.003938	 0.00099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30734	 30735	 0.001792	 0.004736	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30735	 30736	 0.001183	 0.003298	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30735	 32025	 0.002819	 0.009499	 0.00236	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30735	 85681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30735	 85681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30735	 85690	 0.003515	 0.010526	 0.00237	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30736	 85682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30736	 85682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30737	 32026	 0.028699	 0.022712	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30738	 30741	 0.001779	 0.006198	 0.00144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30738	 32024	 0.002366	 0.007894	 0.002	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30739	 30740	 0.020452	 0.016031	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85682	 30739	 0.008256	 0.01618	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30740	 85683	 0.00494	 0.011697	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30741	 30744	 0.001315	 0.005266	 0.00133	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30741	 85683	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30741	 85683	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30742	 31979	 0.001753	 0.006197	 0.0014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30742	 85684	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30742	 85684	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85683	 30743	 0.019417	 0.019612	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85684	 30743	 0.00787	 0.020014	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30744	 30761	 0.001102	 0.004411	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30744	 85685	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30744	 85685	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30745	 30746	 0.001737	 0.006956	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30745	 31977	 0.001786	 0.007374	 0.00174	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30745	 85686	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30745	 85686	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30746	 30747	 0.00146	 0.00574	 0.0015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30746	 85687	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30746	 85687	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30747	 30765	 0.001532	 0.006019	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30748	 30749	 0.009612	 0.016054	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85684	 30748	 0.005322	 0.017754	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85685	 30749	 0.025826	 0.020438	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85687	 30749	 0.013226	 0.023864	 0.00034	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84650	 30750	 0.010632	 0.045001	 0.01013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84727	 30750	 0.012593	 0.058739	 0.01455	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84650	 30751	 0.004294	 0.021933	 0.00552	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30751	 85688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30751	 85688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84944	 30752	 0.19741	 0.65937	 0.01047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85688	 30752	 0.038408	 0.099543	 0.00188	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30752	 85693	 0.24656	 0.26864	 0.00366	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30752	 86069	 0.17213	 0.39068	 0.0078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30753	 85689	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30753	 85689	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30753	 85697	 0.003181	 0.011243	 0.00253	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85689	 30754	 0.017639	 0.018836	 0.0004	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30755	 30757	 0.00024	 0.001598	 0.00301	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30755	 85690	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85691	 30755	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85691	 30756	 0.023544	 0.025895	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30756	 85693	 0.015823	 0.036351	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30756	 85694	 0.010593	 0.018251	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30757	 30759	 0.000307	 0.001995	 0.00397	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30757	 85692	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30757	 85692	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85692	 30758	 0.030192	 0.030495	 0.0004	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30758	 85693	 0.003426	 0.016529	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30759	 30760	 0.000175	 0.001517	 0.00282	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30759	 85693	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30759	 85693	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30760	 30768	 0.000688	 0.004531	 0.00877	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30760	 31969	 0.002156	 0.014549	 0.02679	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30761	 30762	 0.000917	 0.003195	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30761	 85694	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30761	 85694	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30762	 30763	 0.00101	 0.004044	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30763	 30765	 0.002619	 0.010487	 0.00264	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30763	 85695	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30763	 85695	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85695	 30764	 0.018854	 0.02433	 0.00049	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30765	 30766	 0.000944	 0.008042	 0.00201	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30766	 30767	 0.001107	 0.008005	 0.00431	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84650	 30767	 0.000134	 0.002054	 0.00066	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30768	 30770	 0.000501	 0.00434	 0.00807	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30768	 30771	 0.001711	 0.011543	 0.02125	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84649	 30768	 0.00018	 0.003008	 0.01093	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30769	 85696	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30769	 85696	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30769	 85697	 0.000828	 0.005146	 0.00145	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30770	 30774	 0.001873	 0.012638	 0.02327	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30770	 85697	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85698	 30770	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30771	 30775	 0.000994	 0.007491	 0.01393	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30771	 30819	 0.00283	 0.018632	 0.03606	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84684	 30771	 0.003556	 0.043501	 0.08942	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30771	 85699	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85700	 30771	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85699	 30772	 0.005995	 0.024001	 0.00605	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30772	 85701	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30772	 85701	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85699	 30773	 0.005123	 0.017091	 0.00433	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30773	 85702	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30773	 85702	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30773	 85703	 0.002741	 0.00959	 0.00318	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30774	 30775	 0.000322	 0.002174	 0.004	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30774	 85703	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30774	 85703	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30775	 30845	 0.000257	 0.002002	 0.00717	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30775	 85704	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85705	 30775	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30776	 30777	 0.001792	 0.006812	 0.00191	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30776	 30780	 0.001581	 0.006329	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30776	 85707	 0.00124	 0.008508	 0.00248	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30778	 85706	 0.010218	 0.011129	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30779	 30780	 0.000703	 0.002459	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30780	 85706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30780	 85706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30781	 30819	 0.000947	 0.010951	 0.02098	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84713	 30781	 0.002263	 0.021535	 0.03827	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84724	 30781	 0.001819	 0.018424	 0.03709	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30781	 85707	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85708	 30781	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30782	 30783	 0.002185	 0.008894	 0.00217	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85707	 30782	 0.002097	 0.008397	 0.00212	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30783	 30790	 0.001934	 0.007351	 0.00206	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30783	 85709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30783	 85709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30784	 30785	 0.001467	 0.006055	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30785	 30787	 0.001037	 0.004756	 0.00122	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30785	 85710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30785	 85710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30786	 30787	 0.001409	 0.004155	 0.00097	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30786	 30788	 0.001804	 0.005225	 0.00126	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30787	 30788	 0.002641	 0.008615	 0.00229	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30787	 85711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30787	 85711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30788	 30843	 0.001997	 0.009452	 0.00227	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30789	 30790	 0.001854	 0.007285	 0.00191	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30789	 30830	 0.002193	 0.00878	 0.00221	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30790	 85712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30790	 85712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30791	 30795	 0.002607	 0.011617	 0.00316	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30791	 30827	 0.004824	 0.022498	 0.00557	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30791	 85713	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30791	 85713	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30792	 30826	 0.006413	 0.025206	 0.00659	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30792	 85714	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30792	 85714	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30793	 30794	 0.003386	 0.014331	 0.00322	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30793	 30799	 0.003096	 0.009628	 0.00201	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85669	 30793	 0.010364	 0.041495	 0.01046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30793	 85715	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30793	 85715	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30794	 85716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30794	 85716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30795	 30796	 0.002148	 0.00957	 0.0026	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30795	 85717	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30795	 85717	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30796	 30797	 0.001827	 0.007314	 0.00184	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30797	 85718	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30797	 85718	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30798	 85719	 0.046806	 0.037041	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30799	 30800	 0.002925	 0.007518	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30799	 85719	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30799	 85719	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30800	 85720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30800	 85720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30801	 85721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30801	 85721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30801	 85722	 0.00254	 0.011317	 0.00307	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30802	 30812	 0.007008	 0.018015	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30802	 32002	 0.005425	 0.021106	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30802	 32002	 0.005425	 0.021106	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30802	 85723	 0.006064	 0.02333	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30802	 85723	 0.006064	 0.02333	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30803	 31950	 0.000298	 0.003553	 0.26659	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30803	 85722	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30804	 30807	 0.000802	 0.003954	 0.00107	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85722	 30804	 0.001504	 0.008086	 0.00199	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30805	 30807	 0.001152	 0.005678	 0.00154	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30805	 30808	 0.001077	 0.005409	 0.00141	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30806	 85724	 0.026322	 0.020831	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30807	 85724	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30807	 85724	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30808	 30809	 0.003805	 0.015482	 0.00377	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85722	 30808	 0.003245	 0.02014	 0.00488	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30808	 85725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30808	 85725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30809	 30815	 0.003218	 0.01362	 0.00306	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30810	 31995	 0.003693	 0.014787	 0.00373	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30811	 30812	 0.010153	 0.016207	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30811	 30813	 0.010619	 0.016105	 0.00023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30813	 31992	 0.005271	 0.012237	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85370	 30814	 0.036694	 0.075094	 0.00185	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85725	 30814	 0.0257	 0.073711	 0.00113	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85720	 30817	 0.018075	 0.031788	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85647	 30818	 0.02034	 0.022154	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85681	 30818	 0.013423	 0.031163	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30819	 30822	 0.000107	 0.00167	 0.00359	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30819	 85726	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85727	 30819	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85726	 30821	 0.001578	 0.00947	 0.00287	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30821	 85728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30821	 85728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30822	 31989	 0.002085	 0.014619	 0.02489	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	85668	 30822	 0.000735	 0.005506	 0.0213	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30822	 85729	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85730	 30822	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30823	 30824	 0.001354	 0.005324	 0.00139	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30823	 85731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30823	 85731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85729	 30824	 0.001696	 0.008107	 0.00284	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30824	 85732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30824	 85732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84715	 30825	 0.038701	 0.030628	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84714	 30826	 0.004451	 0.020421	 0.00523	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30826	 85733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30826	 85733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84725	 30827	 0.001473	 0.009878	 0.00238	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30828	 30830	 0.001834	 0.011617	 0.00315	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84725	 30828	 0.001608	 0.009722	 0.00248	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30829	 85734	 0.04685	 0.061576	 0.00084	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30829	 85738	 0.019793	 0.024569	 0.00054	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30830	 30841	 0.002401	 0.008367	 0.00194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30831	 30832	 0.001951	 0.011428	 0.00311	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30831	 30835	 0.002404	 0.009138	 0.00256	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84714	 30832	 0.00155	 0.014876	 0.00433	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30832	 85734	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30832	 85734	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30833	 31646	 0.005434	 0.024927	 0.00639	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30833	 85735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30833	 85735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30833	 85952	 0.00314	 0.014403	 0.00369	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30834	 30835	 0.005399	 0.021616	 0.00545	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30834	 31722	 0.004371	 0.018498	 0.00416	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30834	 85736	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30834	 85736	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30835	 85737	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30835	 85737	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30836	 30838	 0.000983	 0.002897	 0.00067	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30837	 30838	 0.001735	 0.005024	 0.00121	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30837	 30840	 0.002195	 0.007321	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84725	 30837	 0.002799	 0.021812	 0.00652	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30837	 85738	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30837	 85738	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30839	 30842	 0.001637	 0.004564	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30839	 85739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30839	 85739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30840	 85740	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30840	 85740	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30841	 85741	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30841	 85741	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30842	 30843	 0.001583	 0.004183	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30842	 85742	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30842	 85742	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30843	 30844	 0.001184	 0.004819	 0.00117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84725	 30843	 0.005086	 0.035973	 0.00987	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30843	 85743	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30843	 85743	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30844	 30849	 0.001312	 0.005252	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30845	 30848	 0.000163	 0.002473	 0.00561	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30845	 85744	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85745	 30845	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85704	 30846	 0.001202	 0.005087	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85744	 30846	 0.001015	 0.004296	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85700	 30847	 0.041202	 0.095657	 0.00142	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85745	 30847	 0.011041	 0.025365	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30848	 30851	 0.000184	 0.002679	 0.00662	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30848	 85746	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30848	 85746	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85746	 30849	 0.000726	 0.002907	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30850	 30864	 0.006499	 0.027508	 0.00619	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85699	 30850	 0.005065	 0.021439	 0.00482	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30851	 30856	 0.000617	 0.007446	 0.01567	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84713	 30851	 0.002163	 0.018923	 0.0345	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30851	 85747	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30851	 85747	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30852	 30854	 0.002356	 0.012524	 0.00291	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30852	 85748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30852	 85748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30853	 85749	 0.042596	 0.03371	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30854	 85749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30854	 85749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30854	 85751	 0.001525	 0.008748	 0.00291	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30855	 30863	 0.004227	 0.016923	 0.00426	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30855	 85750	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30855	 85750	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30855	 85751	 0.002658	 0.010447	 0.00273	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30856	 85751	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85752	 30856	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30857	 30858	 0.071407	 0.052537	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30857	 30860	 0.10328	 0.069379	 0.00122	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30859	 30860	 0.039717	 0.043684	 0.00058	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85752	 30860	 0.010835	 0.036143	 0.00057	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85750	 30861	 0.010159	 0.016296	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85750	 30862	 0.018058	 0.034128	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30863	 30864	 0.003093	 0.012155	 0.00318	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84669	 30865	 0.004086	 0.035048	 0.00997	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30866	 30867	 0.005114	 0.013145	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30866	 30868	 0.009785	 0.028064	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30868	 85753	 0.002657	 0.012389	 0.00029	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30869	 85753	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30869	 85753	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30870	 30879	 0.005055	 0.012857	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85753	 30870	 0.009428	 0.026079	 0.00061	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30871	 30877	 0.013905	 0.024453	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85753	 30871	 0.004931	 0.01254	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30872	 30873	 0.013843	 0.017394	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30873	 30878	 0.029009	 0.037433	 0.00075	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30873	 31174	 0.012429	 0.024609	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30874	 30875	 0.005612	 0.018521	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30874	 31161	 0.027411	 0.029272	 0.00062	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85753	 30874	 0.007744	 0.023756	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85753	 30876	 0.013131	 0.025999	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30877	 30878	 0.025833	 0.017353	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30877	 31173	 0.031939	 0.035129	 0.00047	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30878	 30881	 0.0616	 0.067754	 0.0009	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85753	 30878	 0.014543	 0.037385	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30879	 30882	 0.024457	 0.015834	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30879	 30883	 0.013323	 0.030932	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30879	 30885	 0.011361	 0.022266	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30880	 30881	 0.020514	 0.020574	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30881	 30887	 0.031084	 0.031175	 0.0005	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30881	 30895	 0.006501	 0.015093	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30883	 30886	 0.010911	 0.020287	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30884	 30885	 0.023194	 0.018356	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30886	 30888	 0.049005	 0.038782	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30886	 30891	 0.007359	 0.019505	 0.00049	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30887	 30891	 0.004299	 0.011892	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30887	 85754	 0.002268	 0.008306	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30889	 30890	 0.023193	 0.015015	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30890	 85758	 0.016525	 0.025063	 0.00036	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30892	 30893	 0.001568	 0.004696	 0.00106	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30892	 30905	 0.001454	 0.004522	 0.00094	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30893	 85754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30893	 85754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30894	 30896	 0.002311	 0.007892	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30894	 85755	 0.002503	 0.012418	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30895	 30896	 0.004645	 0.01228	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85754	 30896	 0.005869	 0.011371	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30897	 30899	 0.008541	 0.016911	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30897	 85755	 0.00462	 0.013586	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30898	 30907	 0.00129	 0.005808	 0.00155	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30898	 85755	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30898	 85755	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30899	 30900	 0.01573	 0.017133	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30899	 31169	 0.029705	 0.02445	 0.0005	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30901	 31175	 0.005869	 0.015755	 0.00357	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30901	 85756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30901	 85756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30901	 85762	 0.002262	 0.009055	 0.00228	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30902	 30903	 0.010461	 0.020712	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85755	 30903	 0.010195	 0.023669	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30903	 85763	 0.004512	 0.025354	 0.00047	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30904	 30908	 0.005585	 0.018631	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30904	 85757	 0.012267	 0.01239	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30904	 85764	 0.021243	 0.032542	 0.00046	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30905	 30906	 0.00149	 0.004394	 0.00102	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30905	 85757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30905	 85757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30906	 30912	 0.000239	 0.003381	 0.00112	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30906	 85758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30906	 85758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30906	 85762	 0.000504	 0.005766	 0.00176	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30907	 85762	 0.000912	 0.005434	 0.00143	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30908	 85763	 0.00228	 0.010102	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30909	 30911	 2.4e-05	 0.000302	 0.02091	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30909	 85759	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85761	 30910	 0.002896	 0.011266	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85761	 30910	 0.002896	 0.011266	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30910	 85763	 0.002269	 0.008106	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30910	 85763	 0.002269	 0.008106	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30911	 85762	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84659	 30912	 0.000163	 0.00263	 0.00086	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30912	 85764	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30912	 85764	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84660	 30913	 0.007453	 0.009485	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85759	 30914	 0.000354	 0.002399	 0.00437	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30914	 85765	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85766	 30914	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30915	 30930	 0.002852	 0.009303	 0.00247	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85760	 30915	 0.000564	 0.003302	 0.0009	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85765	 30915	 0.001022	 0.003883	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30915	 85767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30915	 85767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30916	 30925	 0.010943	 0.013583	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85767	 30916	 0.004886	 0.016299	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30917	 30926	 0.003996	 0.013188	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85761	 30917	 0.004109	 0.018206	 0.00055	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30918	 30919	 0.01819	 0.014395	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30919	 30926	 0.012537	 0.011548	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30919	 30928	 0.038119	 0.030167	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85756	 30919	 0.010758	 0.028512	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30920	 30921	 0.013428	 0.010627	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30920	 30922	 0.012964	 0.010259	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30920	 30923	 0.006961	 0.014245	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30920	 30928	 0.011776	 0.011894	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30922	 30941	 0.018785	 0.014866	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30923	 85768	 0.003154	 0.00802	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30924	 31175	 0.001378	 0.005237	 0.00147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30924	 85768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30924	 85768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30925	 30926	 0.006673	 0.009301	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30925	 30927	 0.017569	 0.019324	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30927	 30928	 0.014429	 0.01131	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30929	 30930	 0.001095	 0.003756	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30929	 30938	 0.001206	 0.003131	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30930	 85769	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30930	 85769	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30931	 30932	 0.005887	 0.011537	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85769	 30931	 0.018178	 0.011768	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85766	 30932	 0.005986	 0.01369	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30932	 85770	 0.006368	 0.006801	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30932	 85771	 0.012581	 0.031995	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30933	 30934	 0.000506	 0.002582	 0.00065	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85765	 30933	 0.000747	 0.004733	 0.00128	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30933	 85770	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30933	 85770	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30934	 30935	 0.000568	 0.002532	 0.00069	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30935	 30936	 0.000533	 0.002486	 0.00062	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30936	 30945	 0.001229	 0.007136	 0.00168	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30936	 85771	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30936	 85771	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85771	 30937	 0.006022	 0.011803	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30938	 30939	 0.000557	 0.002358	 0.00053	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85760	 30938	 0.004938	 0.017455	 0.00393	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30938	 85772	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30938	 85772	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30939	 31192	 0.000924	 0.003222	 0.00075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85768	 30940	 0.003031	 0.01479	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85772	 30940	 0.067645	 0.048901	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30940	 85773	 0.026835	 0.021237	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85768	 30941	 0.004687	 0.014377	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30941	 85774	 0.009311	 0.016042	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30942	 30943	 0.001693	 0.004904	 0.00118	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30942	 30953	 0.000411	 0.002601	 0.00071	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30942	 31172	 0.000998	 0.006134	 0.00177	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30942	 85773	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30942	 85773	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30943	 85774	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30943	 85774	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30944	 85775	 0.006646	 0.011945	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30945	 30951	 0.001686	 0.005625	 0.00143	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30945	 85775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30945	 85775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85775	 30946	 0.023046	 0.01666	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85766	 30947	 0.023796	 0.016856	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85771	 30948	 0.020656	 0.020661	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30949	 85795	 0.025113	 0.017789	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30950	 85776	 0.006333	 0.012412	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30951	 30968	 0.002015	 0.005326	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30951	 85776	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30951	 85776	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30952	 31009	 0.001798	 0.012262	 0.02208	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30952	 31165	 0.000788	 0.011041	 0.02117	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85759	 30952	 0.001251	 0.009432	 0.01755	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30952	 85777	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85778	 30952	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30953	 30955	 0.000773	 0.004116	 0.00116	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85774	 30954	 0.007561	 0.024953	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30954	 85780	 0.023119	 0.018296	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30955	 30956	 0.000449	 0.00206	 0.00053	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30955	 85779	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30955	 85779	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30956	 30960	 0.000513	 0.002017	 0.00053	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30956	 85780	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30956	 85780	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30957	 30958	 0.002866	 0.007575	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85779	 30957	 0.003969	 0.013241	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30958	 30959	 0.00513	 0.011907	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30958	 85782	 0.017206	 0.022391	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30959	 85781	 0.004531	 0.008144	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30960	 30961	 0.000442	 0.001989	 0.00053	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30960	 30983	 0.000869	 0.003416	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30961	 30962	 0.001054	 0.004351	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30962	 30975	 0.000513	 0.002844	 0.00086	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30962	 85781	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30962	 85781	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30963	 30966	 0.000514	 0.002952	 0.00084	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85777	 30963	 0.000653	 0.004055	 0.00114	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30963	 85782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30963	 85782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85782	 30964	 0.017622	 0.013813	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30965	 30966	 0.000435	 0.001906	 0.00066	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30965	 30972	 0.000481	 0.002592	 0.00071	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30965	 85783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30965	 85783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30966	 85784	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30966	 85784	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85784	 30967	 0.018623	 0.014285	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30968	 30969	 0.001715	 0.004311	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30968	 85785	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30968	 85785	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30969	 30996	 0.000879	 0.002283	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30970	 30971	 0.006165	 0.015849	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30970	 30992	 0.004213	 0.010831	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30970	 30997	 0.004616	 0.0131	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84753	 30970	 0.002438	 0.008535	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85771	 30970	 0.076783	 0.10092	 0.00138	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85778	 30971	 0.015981	 0.052737	 0.00085	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30971	 85792	 0.012199	 0.027368	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30971	 85793	 0.014752	 0.024638	 0.00042	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30972	 30973	 0.000532	 0.002129	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30973	 30990	 0.000788	 0.002705	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30974	 85786	 0.00645	 0.016404	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30974	 85816	 0.089785	 0.098756	 0.00132	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30975	 30982	 0.00137	 0.007601	 0.00231	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30975	 31018	 0.003986	 0.01596	 0.00402	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85777	 30975	 0.002361	 0.014067	 0.0037	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30975	 85786	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30975	 85786	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30976	 30977	 0.012025	 0.007785	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30976	 30987	 0.013462	 0.014807	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85786	 30976	 0.004933	 0.010094	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30978	 30987	 0.004398	 0.012166	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30978	 85791	 0.003761	 0.011539	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30979	 30980	 0.000669	 0.004151	 0.00101	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30979	 31157	 0.001112	 0.006516	 0.00177	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30979	 85787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30979	 85787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30980	 31018	 0.000703	 0.004041	 0.00114	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30980	 85788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30980	 85788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30981	 30986	 0.005033	 0.011417	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85788	 30981	 0.007769	 0.018035	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30981	 85789	 0.00588	 0.015543	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30982	 31020	 0.000701	 0.004581	 0.00117	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30982	 85789	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30982	 85789	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30983	 30985	 0.00224	 0.007548	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30983	 31188	 0.000627	 0.003893	 0.00094	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30983	 85790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30983	 85790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30984	 85791	 0.011939	 0.008784	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30985	 85791	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30985	 85791	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30986	 30987	 0.003285	 0.006722	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30988	 30990	 0.001395	 0.004199	 0.00131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30988	 31014	 0.001338	 0.004064	 0.00089	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30989	 85792	 0.006353	 0.009635	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	30990	 85792	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30990	 85792	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30991	 31008	 0.002391	 0.006011	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85777	 30991	 0.004849	 0.019414	 0.00489	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30991	 85793	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30991	 85793	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84753	 30992	 0.00073	 0.002984	 6e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30992	 85796	 0.008349	 0.027553	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30993	 31002	 0.001281	 0.003891	 0.00085	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30993	 85794	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30993	 85794	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30994	 30999	 0.02746	 0.021731	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85794	 30994	 0.005382	 0.010655	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30995	 30997	 0.005705	 0.005762	 8e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30996	 85795	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30996	 85795	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85795	 30997	 0.006688	 0.012435	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30998	 30999	 0.003539	 0.002801	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31000	 31005	 0.021687	 0.016999	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31001	 31061	 0.016957	 0.013419	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31002	 85796	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31002	 85796	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31003	 31004	 0.002721	 0.014892	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85793	 31003	 0.022262	 0.030372	 0.00054	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85796	 31003	 0.001614	 0.008666	 0.00021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31004	 31005	 0.012492	 0.009464	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31004	 31006	 0.005644	 0.012662	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31006	 85797	 0.004773	 0.011082	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31006	 85800	 0.042381	 0.039037	 0.00063	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31007	 31059	 0.000458	 0.002953	 0.00077	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31007	 85797	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31007	 85797	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31007	 85798	 0.000789	 0.004526	 0.0015	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31008	 31016	 0.002228	 0.00598	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31009	 31165	 0.001287	 0.017516	 0.03565	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84661	 31009	 0.001686	 0.022297	 0.08124	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31009	 85798	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85799	 31009	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31010	 31011	 0.004396	 0.009421	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31010	 85816	 0.004706	 0.010926	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31011	 85801	 0.006043	 0.015535	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31012	 31013	 0.000424	 0.002482	 0.00068	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31012	 31057	 0.001722	 0.004988	 0.0012	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31012	 31058	 0.000818	 0.003216	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31012	 85800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31012	 85800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31013	 31016	 0.000582	 0.003308	 0.00096	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31013	 85801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31013	 85801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31014	 31015	 0.00077	 0.002	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31015	 31017	 0.001319	 0.003487	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85798	 31016	 0.001034	 0.004209	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31016	 85802	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31016	 85802	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31017	 85803	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31017	 85803	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31018	 31041	 0.000624	 0.00433	 0.00124	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31018	 85804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31018	 85804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31019	 31028	 0.004071	 0.015662	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31019	 31037	 0.010426	 0.01563	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31019	 31038	 0.012291	 0.008885	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31019	 31081	 0.012002	 0.020218	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31019	 85826	 0.043707	 0.0726	 0.00154	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31020	 31022	 0.000762	 0.004981	 0.00127	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31020	 85805	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31020	 85805	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85805	 31021	 0.011757	 0.017832	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31022	 31023	 0.000837	 0.004002	 0.0014	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31023	 31024	 0.000647	 0.004022	 0.00114	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31023	 85806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31023	 85806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31024	 31045	 0.000424	 0.002731	 0.00072	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31025	 31040	 0.000621	 0.003819	 0.0011	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31025	 31044	 0.000495	 0.003073	 0.00087	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31026	 31045	 0.000873	 0.005016	 0.00142	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31026	 31048	 0.000927	 0.004324	 0.00107	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31026	 85807	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31026	 85807	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31027	 31031	 0.001149	 0.004004	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31027	 31048	 0.000748	 0.003889	 0.00115	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31027	 85808	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31027	 85808	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31028	 31032	 0.002121	 0.011299	 0.0002	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31029	 31030	 0.005773	 0.010416	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31029	 31035	 0.003854	 0.011601	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31029	 85809	 0.008692	 0.015286	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31029	 85813	 0.005756	 0.019201	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31030	 31034	 0.004694	 0.016034	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31030	 85813	 0.002735	 0.013915	 0.00032	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31031	 85809	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31031	 85809	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85809	 31032	 0.001128	 0.005414	 0.00016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31033	 31034	 0.024388	 0.019116	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31034	 31083	 0.013205	 0.037875	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31035	 31036	 0.011528	 0.009123	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31035	 31039	 0.004256	 0.00871	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31037	 31039	 0.005395	 0.013867	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31037	 31083	 0.004702	 0.018292	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31040	 31041	 0.000655	 0.004912	 0.0012	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31041	 85810	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31041	 85810	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31042	 31044	 0.001032	 0.004599	 0.00125	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31042	 31047	 0.000909	 0.004092	 0.00109	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31043	 85811	 0.014379	 0.014524	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31044	 85811	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31044	 85811	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31045	 85812	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31045	 85812	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85812	 31046	 0.011897	 0.009415	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31047	 31049	 0.001095	 0.004384	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31049	 85813	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31049	 85813	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85808	 31050	 0.017679	 0.013991	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31051	 31055	 0.000314	 0.003222	 0.00102	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31051	 31069	 0.001062	 0.006589	 0.0016	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31051	 31082	 0.00489	 0.027131	 0.00825	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31051	 85814	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31051	 85814	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31052	 31054	 0.003361	 0.017905	 0.00031	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31052	 85816	 0.002017	 0.013688	 0.00026	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31053	 31054	 0.007911	 0.020119	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31053	 85815	 0.004466	 0.012809	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31054	 85821	 0.002452	 0.017923	 0.00033	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31055	 31058	 0.000869	 0.004114	 0.00099	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85798	 31055	 0.000864	 0.00932	 0.00267	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31055	 85815	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31055	 85815	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85815	 31056	 0.004398	 0.00702	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31057	 85816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31057	 85816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31059	 31060	 0.000586	 0.003251	 0.00099	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31060	 31062	 0.000472	 0.003163	 0.00076	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31060	 85817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31060	 85817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85817	 31061	 0.005144	 0.010184	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31062	 31063	 0.000505	 0.002956	 0.00081	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31063	 31066	 0.000894	 0.005546	 0.00134	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31063	 85818	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31063	 85818	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31064	 31066	 0.000324	 0.001599	 0.00043	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31064	 31097	 0.000784	 0.003598	 0.00092	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31065	 31098	 0.001521	 0.008871	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31065	 85822	 0.004889	 0.01118	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31066	 85819	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31066	 85819	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31067	 31097	 0.000894	 0.003691	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31067	 85820	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31067	 85820	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85819	 31068	 0.011065	 0.010192	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31069	 85821	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31069	 85821	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31070	 31071	 0.015028	 0.013558	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85808	 31070	 0.016751	 0.016755	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31071	 31079	 0.002259	 0.011746	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85821	 31071	 0.002391	 0.013589	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31072	 31074	 0.005526	 0.014205	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85821	 31072	 0.012458	 0.030493	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31073	 31074	 0.004984	 0.009767	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31073	 31076	 0.008819	 0.018047	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31073	 31080	 0.006654	 0.021129	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85820	 31073	 0.005603	 0.015306	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85821	 31073	 0.017042	 0.038975	 0.00095	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31075	 31094	 0.001505	 0.007122	 0.00171	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31075	 85822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31075	 85822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31076	 31077	 0.003245	 0.010827	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31076	 31079	 0.006064	 0.014842	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31077	 31081	 0.005995	 0.013772	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31078	 31079	 0.00916	 0.015431	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85822	 31080	 0.005103	 0.014135	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31081	 85823	 0.01094	 0.02892	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31082	 31090	 0.00161	 0.008222	 0.00207	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31082	 85823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31082	 85823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31083	 31084	 0.007473	 0.017091	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31083	 31085	 0.011147	 0.02207	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31084	 31086	 0.003671	 0.014336	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85823	 31084	 0.010325	 0.026541	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31085	 31138	 0.029711	 0.026623	 0.00054	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31086	 31087	 0.004402	 0.014686	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31086	 31089	 0.02856	 0.01849	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31087	 31110	 0.004724	 0.01355	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31088	 31142	 0.022934	 0.014847	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31090	 85824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31090	 85824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31091	 85825	 0.008117	 0.012434	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31092	 31095	 0.008873	 0.011014	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85824	 31092	 0.007941	 0.018244	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31092	 85825	 0.012833	 0.032987	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31093	 31103	 0.018448	 0.013573	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85824	 31093	 0.010253	 0.02428	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31094	 85825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31094	 85825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31095	 31096	 0.00973	 0.025013	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31095	 31100	 0.007799	 0.015285	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85825	 31096	 0.004063	 0.010444	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85820	 31098	 0.002503	 0.01539	 0.00028	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85825	 31099	 0.01496	 0.009685	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31100	 31103	 0.017124	 0.017296	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31101	 31105	 0.013844	 0.010956	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31102	 31104	 0.013488	 0.008732	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31102	 31105	 0.01988	 0.020079	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31103	 31105	 0.00918	 0.014726	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84948	 31105	 0.020349	 0.052311	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85824	 31105	 0.029227	 0.042783	 0.00066	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31106	 31107	 0.009092	 0.009999	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31106	 31108	 0.030885	 0.019995	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31106	 31110	 0.010118	 0.02601	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85824	 31106	 0.003161	 0.012671	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31108	 31109	 0.005716	 0.013271	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31110	 31112	 0.005284	 0.008434	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31111	 31112	 0.009803	 0.020061	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31111	 31118	 0.007839	 0.016042	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31111	 85827	 0.042465	 0.043361	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31112	 31113	 0.010975	 0.007934	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31113	 31115	 0.007292	 0.013106	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31114	 31115	 0.006506	 0.016724	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31114	 31116	 0.004541	 0.011673	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31114	 31118	 0.011297	 0.020384	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31117	 31118	 0.003813	 0.012719	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84949	 31117	 0.002918	 0.009733	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31119	 85831	 0.020329	 0.020757	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31120	 31149	 0.005871	 0.025868	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31120	 85830	 0.00624	 0.035471	 0.00064	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31121	 31122	 0.005894	 0.025656	 0.00731	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31121	 85826	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31121	 85826	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31121	 85833	 0.016268	 0.089627	 0.03238	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31122	 85827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31122	 85827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31123	 31125	 0.001758	 0.011326	 0.00297	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84662	 31123	 0.002795	 0.019769	 0.00542	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31124	 31125	 0.000584	 0.002984	 0.00081	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31124	 31163	 0.000905	 0.00573	 0.00156	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31125	 31126	 0.000441	 0.003121	 0.00086	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31125	 85828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31125	 85828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31126	 31145	 0.000907	 0.00608	 0.00186	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31127	 31131	 0.026803	 0.021212	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31127	 31191	 0.024576	 0.024046	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85827	 31127	 0.012468	 0.031709	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31128	 31130	 0.02692	 0.017428	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31128	 31131	 0.024987	 0.019586	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31128	 31160	 0.0291	 0.020613	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85827	 31128	 0.01455	 0.037402	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31129	 31160	 0.00443	 0.011387	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84952	 31129	 0.044001	 0.05364	 0.00086	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31132	 31191	 0.041541	 0.032875	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84952	 31132	 0.043109	 0.031163	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31133	 31134	 0.00639	 0.011703	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31133	 31136	 0.019044	 0.020743	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31133	 31159	 0.006997	 0.013853	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31135	 31159	 0.00468	 0.011901	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31136	 31137	 0.013775	 0.01649	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85827	 31136	 0.027641	 0.027045	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31137	 31140	 0.013892	 0.02107	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84949	 31137	 0.017356	 0.044615	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31138	 31139	 0.007736	 0.013818	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31138	 31140	 0.011527	 0.026762	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31138	 31142	 0.008001	 0.014437	 0.00021	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31138	 31144	 0.024372	 0.027041	 0.00053	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85826	 31139	 0.030573	 0.075884	 0.00126	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85827	 31139	 0.014643	 0.033996	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31141	 31142	 0.008079	 0.006394	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31143	 31144	 0.013905	 0.014849	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85826	 31144	 0.023609	 0.062574	 0.00159	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31145	 31146	 0.000412	 0.00256	 0.00072	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31146	 31147	 0.000858	 0.00515	 0.00156	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31147	 31158	 0.001097	 0.006815	 0.00192	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85804	 31148	 0.023036	 0.047141	 0.00116	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31149	 31150	 0.0141	 0.036246	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31149	 31151	 0.006584	 0.015058	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31150	 31151	 0.006813	 0.015816	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85810	 31150	 0.018894	 0.037409	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85826	 31150	 0.0314	 0.079857	 0.00126	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31152	 31153	 0.03179	 0.025158	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85828	 31152	 0.010559	 0.022193	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31154	 31155	 0.000695	 0.004313	 0.00104	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31154	 31167	 0.000642	 0.003981	 0.00096	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31155	 31188	 0.001004	 0.005768	 0.00163	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31155	 85829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31155	 85829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31156	 31158	 0.001749	 0.009416	 0.00259	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31156	 85832	 0.000878	 0.005313	 0.00136	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31157	 31158	 0.00072	 0.004562	 0.00124	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31158	 85830	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31158	 85830	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31159	 31160	 0.002903	 0.007384	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31161	 31168	 0.015234	 0.03484	 0.00085	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31161	 31190	 0.016917	 0.043487	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31162	 31163	 0.001121	 0.00689	 0.00199	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31162	 31177	 0.002279	 0.014437	 0.00392	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84662	 31162	 0.001259	 0.013154	 0.00443	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31164	 31176	 0.000575	 0.003366	 0.00092	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31164	 85831	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31164	 85831	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31164	 85832	 0.000641	 0.003818	 0.001	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84661	 31165	 0.00114	 0.011117	 0.03871	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84689	 31165	 0.003541	 0.047092	 0.10072	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31165	 85832	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31165	 85832	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31166	 31169	 0.008569	 0.022028	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31166	 31170	 0.011473	 0.029179	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85832	 31167	 0.000761	 0.00387	 0.0014	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31169	 31174	 0.009125	 0.025277	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84734	 31170	 0.002019	 0.014376	 0.00032	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85756	 31170	 0.010309	 0.0265	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31171	 31172	 0.001917	 0.004969	 0.0015	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31171	 31175	 0.002149	 0.007371	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85832	 31172	 0.000987	 0.005821	 0.00474	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31173	 31174	 0.015738	 0.023869	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31173	 31190	 0.008102	 0.019832	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31175	 31189	 0.000661	 0.003442	 0.0009	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31176	 31177	 0.000641	 0.004059	 0.0011	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31178	 85833	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31179	 85835	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31179	 85835	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31180	 31182	 0.005111	 0.023837	 0.0059	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85835	 31180	 0.005668	 0.022694	 0.00572	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31181	 31185	 0.051718	 0.1024	 0.0015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31181	 85836	 0.005711	 0.027556	 0.00049	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31182	 85836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31182	 85836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31183	 31184	 0.003747	 0.007344	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31183	 31187	 0.016643	 0.037753	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85836	 31183	 0.009088	 0.02788	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85834	 31184	 0.12566	 0.12832	 0.002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31185	 31187	 0.12782	 0.10116	 0.00127	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85834	 31185	 0.030563	 0.070957	 0.00106	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31186	 31187	 0.10152	 0.080347	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85777	 31192	 0.001645	 0.004349	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31192	 85837	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31192	 85837	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31193	 31194	 0.013033	 0.034544	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31193	 85862	 0.010956	 0.048821	 0.00083	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31193	 85864	 0.035477	 0.046627	 0.00064	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31194	 31234	 0.006518	 0.019617	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84654	 31194	 0.09047	 0.62175	 0.01135	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31194	 85841	 0.030263	 0.14528	 0.00434	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31195	 31232	 0.008781	 0.017386	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31196	 31226	 0.028136	 0.022266	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31197	 85848	 0.018638	 0.019031	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31198	 85845	 0.00678	 0.013874	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31199	 31200	 0.001026	 0.00434	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31199	 31217	 0.001518	 0.005968	 0.00156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31200	 31216	 0.000743	 0.002975	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31201	 85844	 0.030031	 0.023766	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84648	 31202	 0.003206	 0.005785	 8e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31203	 31205	 0.013848	 0.010855	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31204	 85844	 0.016295	 0.011989	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31205	 31206	 0.005776	 0.00805	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31206	 31207	 0.00776	 0.009459	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31206	 85838	 0.007693	 0.015232	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31207	 85839	 0.009585	 0.017294	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31208	 31210	 0.000253	 0.002972	 0.00079	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31208	 31214	 0.000296	 0.003276	 0.00098	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31208	 85838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31208	 85838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31209	 31210	 0.000328	 0.002312	 0.00131	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84647	 31209	 0.000355	 0.005313	 0.00179	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31209	 85839	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31209	 85839	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31210	 31212	 0.001038	 0.00528	 0.00191	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31210	 85916	 0.000697	 0.003198	 0.00082	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85838	 31211	 0.010988	 0.014442	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31211	 85840	 0.004413	 0.007044	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31211	 85842	 0.003673	 0.009442	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31212	 31250	 0.000747	 0.004289	 0.00121	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31212	 85840	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31212	 85840	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31213	 31214	 0.000243	 0.002724	 0.00087	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31213	 31249	 0.00081	 0.003835	 0.00092	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31213	 85841	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31213	 85841	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31214	 85842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31214	 85842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31215	 31271	 0.001541	 0.021611	 0.04144	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31215	 85843	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85844	 31215	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31216	 31244	 0.000626	 0.002583	 0.00061	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85843	 31216	 0.000655	 0.005961	 0.0015	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31217	 31218	 0.001821	 0.006626	 0.00203	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31217	 31242	 0.001057	 0.004232	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84703	 31217	 0.004734	 0.046252	 0.01298	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31217	 85845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31217	 85845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31218	 31220	 0.000652	 0.003463	 0.0008	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31218	 31222	 0.000464	 0.003109	 0.00095	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85845	 31219	 0.024693	 0.019542	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31220	 31246	 0.000981	 0.005111	 0.00134	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31221	 31230	 0.000571	 0.004037	 0.00111	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31221	 31233	 0.001078	 0.007622	 0.00209	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31221	 85846	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31221	 85846	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31222	 31230	 0.000501	 0.003358	 0.00103	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31222	 85847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31222	 85847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85847	 31223	 0.009366	 0.007341	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31224	 31231	 0.003135	 0.012197	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85847	 31224	 0.003054	 0.009697	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31224	 85859	 0.02411	 0.055974	 0.00083	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31225	 31229	 0.003521	 0.006971	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31225	 85852	 0.011103	 0.025186	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31226	 31227	 0.006197	 0.011181	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31227	 31228	 0.019874	 0.015578	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31227	 85849	 0.005764	 0.011796	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85846	 31229	 0.012313	 0.018862	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31230	 85848	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31230	 85848	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85848	 31231	 0.002649	 0.010307	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31232	 31235	 0.006129	 0.015756	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31232	 85849	 0.007003	 0.013568	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31233	 31270	 0.00199	 0.0181	 0.00457	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31233	 85849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31233	 85849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31234	 31236	 0.008821	 0.020174	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31235	 31236	 0.005294	 0.01747	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31236	 85850	 0.008704	 0.022375	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31237	 31241	 0.002526	 0.014796	 0.00403	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31237	 85850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31237	 85850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31237	 85865	 0.002643	 0.016743	 0.00454	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31238	 85851	 0.038425	 0.03012	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31239	 31261	 0.001747	 0.012759	 0.00328	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31239	 85851	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31239	 85851	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85850	 31240	 0.033062	 0.031004	 0.00048	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31241	 31261	 0.002751	 0.009962	 0.00214	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31241	 31262	 0.001156	 0.007749	 0.00237	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31241	 85852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31241	 85852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31242	 31244	 0.001175	 0.004466	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31242	 85853	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31242	 85853	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31243	 31247	 0.000485	 0.002913	 0.00088	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85843	 31243	 0.000651	 0.00419	 0.0011	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31244	 85854	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31244	 85854	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85853	 31245	 0.015343	 0.012027	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31246	 31247	 0.00127	 0.006614	 0.00173	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31247	 85855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31247	 85855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85855	 31248	 0.003716	 0.012694	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31248	 85860	 0.005819	 0.014739	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31249	 31251	 0.000963	 0.004417	 0.00113	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31250	 31253	 0.001118	 0.006657	 0.00175	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31251	 31253	 0.001631	 0.006531	 0.00165	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31251	 31263	 0.0009	 0.008643	 0.00251	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31251	 85856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31251	 85856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31252	 31254	 0.012535	 0.031752	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85856	 31252	 0.006601	 0.017496	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31253	 85857	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31253	 85857	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31254	 31255	 0.016973	 0.039405	 0.00059	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31254	 31264	 0.011273	 0.023069	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31255	 85858	 0.023429	 0.054393	 0.00081	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31256	 31260	 0.004125	 0.018923	 0.00485	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31256	 85858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31256	 85858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31257	 31258	 0.017918	 0.03766	 0.00069	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31257	 31259	 0.008212	 0.031949	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85858	 31257	 0.009043	 0.044127	 0.00076	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31258	 31279	 0.01318	 0.027086	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31260	 31261	 0.003097	 0.016996	 0.00449	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31262	 31265	 0.000843	 0.006016	 0.00186	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31262	 85859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31262	 85859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31263	 31266	 0.00052	 0.003987	 0.00107	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31263	 85860	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31263	 85860	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31264	 85861	 0.008081	 0.020551	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31265	 31266	 0.000855	 0.006438	 0.00179	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31266	 85861	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31266	 85861	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31267	 31270	 0.000994	 0.008357	 0.00248	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31267	 85862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31267	 85862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31268	 31271	 0.000421	 0.004594	 0.00891	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31268	 31271	 0.000421	 0.004594	 0.00891	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31268	 85863	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31268	 85863	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31269	 31272	 0.027177	 0.045782	 0.00065	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85193	 31269	 0.017858	 0.045906	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31270	 85864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31270	 85864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31271	 85865	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85866	 31271	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31273	 31277	 0.003956	 0.025479	 0.00668	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31274	 31276	 0.003239	 0.013706	 0.00308	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84703	 31274	 0.005098	 0.028072	 0.01013	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31274	 85867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31274	 85867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85867	 31275	 0.028925	 0.054667	 0.00088	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31276	 31278	 0.003063	 0.013332	 0.0038	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31277	 31278	 0.001938	 0.011544	 0.00304	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31277	 85868	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31277	 85868	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31278	 31283	 0.001415	 0.007501	 0.0025	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31278	 85869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31278	 85869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31279	 31280	 0.005163	 0.013271	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31280	 85870	 0.00678	 0.016827	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31281	 31282	 0.001094	 0.003827	 0.00127	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31281	 85870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31281	 85870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31282	 31283	 0.001349	 0.006188	 0.00159	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31283	 31284	 0.001854	 0.005466	 0.00127	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31284	 85871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31284	 85871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31285	 31286	 0.020091	 0.039779	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85271	 31285	 0.021346	 0.09512	 0.00162	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85870	 31285	 0.004918	 0.032016	 0.00065	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31286	 31293	 0.040592	 0.040999	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31287	 31288	 0.00228	 0.01444	 0.00392	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31287	 31298	 0.002362	 0.013837	 0.00377	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31288	 31291	 0.001507	 0.009852	 0.00251	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31288	 85872	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31288	 85872	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31289	 31310	 0.012847	 0.042856	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85872	 31289	 0.017127	 0.057136	 0.00091	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85871	 31290	 0.0096	 0.015322	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31292	 31312	 0.002589	 0.011658	 0.0031	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31293	 31294	 0.03178	 0.038044	 0.00063	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31294	 31296	 0.005875	 0.009759	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31295	 31297	 0.020065	 0.014505	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85258	 31296	 0.00835	 0.017087	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85259	 31297	 0.012461	 0.01989	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31298	 31299	 0.002465	 0.014437	 0.00393	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31298	 85873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31298	 85873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31299	 31300	 0.003375	 0.018521	 0.0049	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84737	 31301	 0.05759	 0.085397	 0.00128	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84737	 31302	 0.004883	 0.024698	 0.00043	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85873	 31302	 0.019339	 0.064514	 0.00102	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31303	 31304	 0.000516	 0.005701	 0.00171	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31304	 31306	 0.002594	 0.013967	 0.00384	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31304	 31309	 0.003997	 0.023412	 0.00638	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31305	 31307	 0.003166	 0.012676	 0.00319	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31306	 31308	 0.001617	 0.008873	 0.00235	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31307	 31324	 0.003642	 0.015415	 0.00347	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31308	 31309	 0.000853	 0.004682	 0.00124	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31309	 31314	 0.001724	 0.007014	 0.00171	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31309	 31318	 0.000874	 0.005019	 0.00142	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31309	 85874	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31309	 85874	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85874	 31310	 0.009259	 0.036018	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31311	 85875	 0.025684	 0.020326	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31312	 31317	 0.002165	 0.009932	 0.00254	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31312	 85875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31312	 85875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85875	 31313	 0.043065	 0.02788	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31314	 31618	 0.008082	 0.029403	 0.009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85874	 31315	 0.002107	 0.011602	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31315	 85876	 0.002993	 0.015765	 0.00028	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31316	 85876	 0.019746	 0.012783	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31317	 85876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31317	 85876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31318	 31322	 0.001012	 0.005169	 0.0013	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31318	 85877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31318	 85877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85877	 31319	 0.004701	 0.013338	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31319	 85878	 0.007804	 0.022384	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31320	 31321	 0.006647	 0.017086	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85875	 31320	 0.010275	 0.021596	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31321	 85878	 0.004358	 0.01032	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31322	 31323	 0.001888	 0.008918	 0.00285	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31322	 85878	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31322	 85878	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31323	 31325	 0.002086	 0.010665	 0.00291	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31324	 85879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31324	 85879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31324	 85930	 0.016747	 0.070894	 0.01596	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31326	 31341	 0.003739	 0.013091	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31326	 31566	 0.010847	 0.014256	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31326	 85881	 0.005452	 0.014412	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31327	 31329	 0.032781	 0.025942	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31327	 31332	 0.006543	 0.01519	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31327	 85881	 0.010041	 0.038629	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31328	 31556	 0.026724	 0.021149	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31330	 31334	 0.007299	 0.018763	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31330	 31336	 0.010289	 0.020165	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84738	 31330	 0.006658	 0.037845	 0.00068	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31331	 31336	 0.029309	 0.023195	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31332	 31333	 0.012208	 0.008825	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31332	 31335	 0.011066	 0.019066	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31334	 31335	 0.003544	 0.00911	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31337	 31338	 0.030816	 0.024388	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84738	 31338	 0.005147	 0.01019	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84738	 31339	 0.016172	 0.012798	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31340	 85880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31340	 85880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85880	 31341	 0.002857	 0.011336	 0.00032	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31342	 31363	 0.002376	 0.00967	 0.00236	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31342	 85881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31342	 85881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31343	 31568	 0.003386	 0.008577	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85880	 31343	 0.003268	 0.010903	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31344	 31371	 0.004111	 0.010568	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31344	 85921	 0.004421	 0.010263	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31345	 31369	 0.004207	 0.009766	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31345	 31568	 0.006163	 0.015843	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31345	 85921	 0.005109	 0.017042	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31346	 31347	 0.004102	 0.009521	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31346	 31568	 0.004037	 0.010671	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31346	 85883	 0.005476	 0.018072	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31347	 31348	 0.008113	 0.015899	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31348	 31349	 0.005491	 0.010871	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31349	 31360	 0.004634	 0.011912	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31350	 31360	 0.007991	 0.022918	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85881	 31350	 0.010776	 0.024756	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31351	 31352	 0.005591	 0.011069	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31351	 31562	 0.00553	 0.012839	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31352	 31353	 0.016521	 0.016229	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31352	 31355	 0.005213	 0.012103	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31354	 31355	 0.00712	 0.023753	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31354	 31356	 0.005256	 0.010755	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31354	 31426	 0.007698	 0.015753	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31354	 31553	 0.01663	 0.035637	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31354	 85899	 0.023624	 0.08735	 0.00162	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31356	 31357	 0.006072	 0.015442	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31357	 85893	 0.012472	 0.041607	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31358	 31359	 0.022032	 0.014264	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31359	 85882	 0.009052	 0.017336	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31360	 85882	 0.003697	 0.018702	 0.00033	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31361	 31404	 0.000983	 0.003473	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31361	 85882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31361	 85882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85882	 31362	 0.013265	 0.009589	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31363	 85883	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31363	 85883	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31363	 85891	 0.001593	 0.00902	 0.00224	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31364	 31365	 0.008273	 0.009099	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31364	 85892	 0.008522	 0.021907	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31366	 31367	 0.011022	 0.008723	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31367	 31368	 0.00496	 0.012749	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31367	 31374	 0.005097	 0.012071	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31368	 31369	 0.003259	 0.008378	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31369	 31370	 0.00632	 0.012513	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85883	 31369	 0.007022	 0.016132	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31370	 31371	 0.006317	 0.011399	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31370	 31375	 0.010771	 0.025506	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31371	 31372	 0.003074	 0.007817	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31371	 31375	 0.007974	 0.018236	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84738	 31371	 0.004349	 0.022129	 0.0005	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31372	 31373	 0.003004	 0.009225	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31373	 31374	 0.002112	 0.007389	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31374	 31379	 0.005594	 0.010401	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31374	 85884	 0.007145	 0.034865	 0.0006	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31375	 31376	 0.004118	 0.01835	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31376	 31385	 0.017337	 0.026558	 0.00037	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31376	 85884	 0.003761	 0.020038	 0.00035	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84667	 31377	 0.000962	 0.009899	 0.00281	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31377	 85884	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31377	 85884	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85884	 31378	 0.01491	 0.011687	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31379	 31383	 0.008027	 0.020635	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31380	 85892	 0.010422	 0.015186	 0.00034	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31381	 31383	 0.008289	 0.008313	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31382	 31383	 0.014451	 0.018992	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31383	 31385	 0.002419	 0.006151	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31383	 85885	 0.008475	 0.024307	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31384	 31389	 0.012673	 0.015731	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31384	 31396	 0.005871	 0.012015	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31385	 31386	 0.011568	 0.008511	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31385	 85885	 0.00953	 0.022121	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31387	 31388	 0.000614	 0.005776	 0.00175	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31387	 31390	 0.000415	 0.002847	 0.00083	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31387	 85885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31387	 85885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84667	 31388	 0.000327	 0.003621	 0.00118	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31388	 85886	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31388	 85886	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31390	 31400	 0.000858	 0.005151	 0.00156	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31391	 31416	 0.000599	 0.004153	 0.00119	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31391	 85887	 0.000744	 0.006494	 0.00178	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31392	 31462	 0.02351	 0.018606	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31393	 85889	 0.007347	 0.018886	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31394	 85887	 0.002005	 0.007881	 0.00206	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31395	 31399	 0.000876	 0.003707	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31395	 85887	 0.00191	 0.007773	 0.00189	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85886	 31396	 0.009216	 0.026431	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31397	 31522	 0.00452	 0.030153	 0.05685	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31397	 85887	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85888	 31397	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85888	 31398	 0.003958	 0.021176	 0.00064	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31398	 85890	 0.010688	 0.022463	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31398	 85895	 0.001907	 0.018683	 0.00037	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31399	 31458	 0.001649	 0.004145	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31399	 85889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31399	 85889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31400	 31410	 0.000803	 0.004822	 0.00146	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31400	 85890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31400	 85890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31401	 85891	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85892	 31401	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31402	 31404	 0.000777	 0.003022	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31402	 85893	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31402	 85893	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31403	 31405	 0.004704	 0.012093	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31403	 85894	 0.003448	 0.00989	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85891	 31404	 0.000481	 0.003228	 0.00078	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31404	 85894	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31404	 85894	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31405	 31407	 0.004714	 0.016102	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31405	 31408	 0.015777	 0.012485	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85893	 31405	 0.006343	 0.018193	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31406	 31409	 0.017206	 0.013616	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31407	 31425	 0.002046	 0.007961	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31409	 31421	 0.007427	 0.024509	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31409	 85895	 0.003112	 0.01954	 0.00043	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31410	 31413	 0.00068	 0.003604	 0.0012	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85887	 31410	 0.002844	 0.011388	 0.00287	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31410	 85895	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31410	 85895	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31411	 31413	 0.000779	 0.003981	 0.00108	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31411	 31414	 0.000819	 0.003689	 0.00098	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31411	 85896	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31411	 85896	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85896	 31412	 0.008292	 0.015188	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31414	 31419	 0.001291	 0.00517	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31414	 85897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31414	 85897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31415	 31432	 0.007141	 0.014612	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31415	 85900	 0.008051	 0.019204	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31416	 85898	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31416	 85898	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31416	 85905	 0.001429	 0.007445	 0.00195	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31417	 85906	 0.003673	 0.009443	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31418	 31419	 0.001171	 0.004833	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31418	 85899	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31418	 85899	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31418	 85905	 0.000622	 0.005795	 0.00179	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31419	 85900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31419	 85900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31420	 31423	 0.004436	 0.015848	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85900	 31420	 0.003298	 0.016682	 0.00029	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31421	 31422	 0.00528	 0.012257	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31421	 31427	 0.018861	 0.040418	 0.00071	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31422	 31424	 0.003794	 0.008808	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31423	 31428	 0.004487	 0.014968	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31424	 31426	 0.002984	 0.007067	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31425	 31426	 0.006209	 0.01762	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31427	 31428	 0.00636	 0.016175	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31427	 31552	 0.03723	 0.024103	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31429	 31430	 0.01462	 0.017823	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31429	 31551	 0.025032	 0.018096	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31430	 31432	 0.005891	 0.014982	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31431	 31440	 0.006438	 0.016549	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31431	 31548	 0.026948	 0.027218	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31431	 31550	 0.029093	 0.021405	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31433	 31435	 0.017611	 0.013937	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31434	 31435	 0.027776	 0.019675	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31435	 31436	 0.018967	 0.013711	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31435	 31437	 0.013285	 0.009774	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85899	 31435	 0.011153	 0.022824	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31438	 31448	 0.011283	 0.022339	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31439	 31440	 0.017192	 0.013476	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31440	 31441	 0.008784	 0.020393	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85899	 31440	 0.010457	 0.053206	 0.00121	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31441	 31442	 0.017811	 0.013961	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31441	 31549	 0.0127	 0.009343	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31443	 31445	 0.014665	 0.037296	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31443	 31544	 0.027426	 0.019427	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31443	 31546	 0.037521	 0.02941	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31443	 85901	 0.004353	 0.013368	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31443	 85903	 0.006882	 0.033034	 0.00099	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31444	 85901	 0.01383	 0.027382	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31446	 31451	 0.002878	 0.008949	 0.00187	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31446	 85901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31446	 85901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31447	 31448	 0.006892	 0.012622	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31447	 31547	 0.014837	 0.011742	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85901	 31448	 0.005175	 0.014685	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31449	 31451	 0.000552	 0.003077	 0.00079	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31449	 85902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31449	 85902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31449	 85905	 0.000659	 0.004963	 0.00138	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31450	 85903	 0.018392	 0.011907	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31451	 85903	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31451	 85903	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31452	 31454	 0.01248	 0.009876	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85901	 31453	 0.011857	 0.015089	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85903	 31454	 0.009477	 0.018764	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31455	 31457	 0.0043	 0.01673	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31455	 31460	 0.004875	 0.013983	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31455	 31485	 0.013656	 0.035105	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31456	 31462	 0.01353	 0.034781	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31456	 31499	 0.006427	 0.014921	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31457	 31462	 0.008082	 0.018763	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31457	 85907	 0.001993	 0.013522	 0.00025	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31458	 85904	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31458	 85904	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31459	 85905	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31460	 31461	 0.006505	 0.015922	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31460	 31485	 0.058367	 0.042942	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85895	 31460	 0.054371	 0.12623	 0.00188	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31461	 31488	 0.009792	 0.019191	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85906	 31462	 0.007283	 0.025498	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85904	 31463	 0.006769	 0.013403	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31464	 31465	 0.000624	 0.002176	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31464	 85907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31464	 85907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85905	 31465	 0.000518	 0.002076	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31466	 31469	 0.019922	 0.019249	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85907	 31467	 0.014223	 0.02396	 0.00034	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31468	 31470	 0.014915	 0.010782	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31469	 31470	 0.005188	 0.010616	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31469	 31474	 0.00943	 0.017272	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85902	 31469	 0.003816	 0.026194	 0.00048	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31470	 31473	 0.009997	 0.015958	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31471	 31472	 0.019778	 0.015652	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85902	 31472	 0.008921	 0.017663	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31473	 31545	 0.040319	 0.031908	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31475	 31482	 0.006057	 0.015569	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85906	 31475	 0.020226	 0.077816	 0.00133	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31476	 31477	 0.00484	 0.007341	 0.00011	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31477	 31480	 0.01451	 0.0373	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31478	 31480	 0.005725	 0.007525	 0.0001	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31479	 31481	 0.006425	 0.014761	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31479	 85910	 0.013213	 0.028314	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31480	 31481	 0.004271	 0.010978	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31480	 31482	 0.00984	 0.022075	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31480	 31485	 0.012524	 0.031084	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31481	 31486	 0.006144	 0.012574	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31483	 31485	 0.005829	 0.011423	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31484	 31488	 0.012205	 0.022023	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85906	 31485	 0.020638	 0.08029	 0.00134	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31485	 85908	 0.007888	 0.018039	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31485	 85912	 0.081728	 0.16183	 0.00238	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31486	 85908	 0.009141	 0.021645	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31487	 85908	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31487	 85908	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85908	 31488	 0.007603	 0.019335	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31489	 31498	 0.003813	 0.012108	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31489	 85909	 0.005913	 0.026348	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31490	 31498	 0.025818	 0.018664	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31491	 31492	 0.006156	 0.016317	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31491	 31494	 0.005504	 0.015618	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31491	 31502	 0.009521	 0.024474	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31491	 85919	 0.019624	 0.056285	 0.00087	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31492	 31493	 0.016781	 0.017135	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31492	 31509	 0.007621	 0.017692	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31494	 31501	 0.032939	 0.027111	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31494	 85917	 0.002768	 0.014746	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31495	 31497	 0.00728	 0.014105	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31495	 85917	 0.012649	 0.029059	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31496	 85909	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31496	 85909	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85909	 31497	 0.00388	 0.012944	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31498	 31499	 0.003997	 0.00928	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31500	 31502	 0.007291	 0.011169	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31501	 31529	 0.016078	 0.012724	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31502	 31504	 0.023716	 0.017449	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31503	 31506	 0.006399	 0.016449	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31503	 31510	 0.009946	 0.017945	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31504	 85911	 0.008896	 0.015989	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31505	 31506	 0.006695	 0.017026	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31505	 31512	 0.009994	 0.020453	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31505	 85919	 0.036937	 0.094952	 0.00147	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31506	 31507	 0.006644	 0.013022	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31507	 31509	 0.005211	 0.013251	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31508	 31509	 0.006561	 0.011793	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85908	 31508	 0.00575	 0.014781	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31511	 31513	 0.002732	 0.008495	 0.00177	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31511	 85910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31511	 85910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85910	 31512	 0.010401	 0.015933	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31512	 85911	 0.006462	 0.01661	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31513	 31521	 0.001043	 0.003966	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31513	 85911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31513	 85911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31514	 85913	 0.01396	 0.027639	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31515	 31516	 0.002017	 0.005625	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31515	 85912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31515	 85912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31516	 31517	 0.000892	 0.00565	 0.00153	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31516	 31538	 0.010743	 0.028392	 0.00665	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31516	 31539	 0.001686	 0.012025	 0.00373	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31516	 31543	 0.001425	 0.008189	 0.00232	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31516	 85913	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31516	 85913	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31517	 31518	 0.000578	 0.003466	 0.00105	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31518	 31521	 0.000981	 0.005744	 0.00156	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31518	 85914	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31518	 85914	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85911	 31519	 0.012647	 0.027102	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85914	 31519	 0.005989	 0.013697	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31520	 85915	 0.018665	 0.013732	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31521	 85915	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31521	 85915	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31522	 85916	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31522	 85916	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31523	 31532	 0.007003	 0.023361	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85857	 31523	 0.009406	 0.031376	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85857	 31524	 0.02792	 0.080079	 0.00123	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31524	 85919	 0.048593	 0.080715	 0.00171	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31524	 85920	 0.021332	 0.031083	 0.0007	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31525	 31526	 0.013325	 0.010967	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31525	 31534	 0.013093	 0.010362	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31526	 31527	 0.00253	 0.012091	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31526	 31528	 0.006025	 0.012329	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85914	 31526	 0.007763	 0.025617	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31526	 85919	 0.03645	 0.072169	 0.00106	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85912	 31527	 0.003118	 0.013816	 0.00041	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31528	 31529	 0.006475	 0.008826	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31530	 31538	 0.001615	 0.006467	 0.00163	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31530	 85917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31530	 85917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31531	 85918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31531	 85918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31532	 31533	 0.008807	 0.025259	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31533	 31535	 0.060222	 0.04766	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31534	 31536	 0.022813	 0.018054	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85917	 31534	 0.015959	 0.034198	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31535	 85919	 0.055893	 0.043812	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85917	 31537	 0.022259	 0.017615	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85276	 31538	 0.00595	 0.033199	 0.00848	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31538	 85919	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31538	 85919	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31539	 31541	 0.001552	 0.004495	 0.00108	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85916	 31539	 0.00037	 0.004162	 0.0012	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85913	 31540	 0.012094	 0.031089	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31540	 85920	 0.003766	 0.009981	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31541	 85920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31541	 85920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31542	 31543	 0.001075	 0.006926	 0.00182	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84647	 31542	 0.000615	 0.005905	 0.00275	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31553	 31554	 0.014044	 0.011009	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31553	 31555	 0.018207	 0.014409	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31556	 31557	 0.017506	 0.034659	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31557	 31561	 0.011768	 0.023299	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85881	 31557	 0.018289	 0.055049	 0.00108	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31558	 31561	 0.006591	 0.005166	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31559	 31560	 0.018266	 0.011825	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31559	 31563	 0.00935	 0.018512	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31562	 31563	 0.004345	 0.011169	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85881	 31563	 0.005143	 0.017157	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31564	 31565	 0.005951	 0.004665	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31564	 31566	 0.019654	 0.015076	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31567	 85921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31567	 85921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31569	 31571	 0.000536	 0.003329	 0.00081	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84658	 31569	 0.000945	 0.00865	 0.00346	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31569	 85922	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31569	 85922	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31570	 31579	 0.008293	 0.010294	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31570	 85923	 0.006452	 0.012774	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31571	 31573	 0.000769	 0.004222	 0.00112	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31571	 85923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31571	 85923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31572	 85924	 0.011045	 0.011155	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31572	 85936	 0.009573	 0.018761	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31573	 31576	 0.000799	 0.004387	 0.00116	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31573	 85924	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31573	 85924	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31574	 31606	 0.001822	 0.006599	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31574	 85925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31574	 85925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31575	 31576	 0.001616	 0.0044	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31575	 31600	 0.002108	 0.005877	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31576	 85926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31576	 85926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31577	 31578	 0.004899	 0.012984	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85923	 31577	 0.004012	 0.02651	 0.00052	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31578	 85940	 0.013361	 0.026454	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31579	 31580	 0.003459	 0.015411	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31579	 31721	 0.007319	 0.017331	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31580	 31616	 0.004223	 0.023726	 0.00044	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31580	 85927	 0.006859	 0.017632	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31581	 31615	 0.001144	 0.006574	 0.00186	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84658	 31581	 0.001166	 0.014938	 0.00446	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31581	 85927	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31581	 85927	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85927	 31582	 0.005843	 0.019283	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31582	 85928	 0.003587	 0.019111	 0.00034	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31583	 31586	 0.018348	 0.01452	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31584	 85928	 0.00942	 0.010059	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31585	 31587	 0.001688	 0.006113	 0.00131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31585	 85928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31585	 85928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31586	 31721	 0.006592	 0.016765	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31586	 85929	 0.004266	 0.01869	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84658	 31587	 0.001137	 0.0083	 0.00213	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31587	 85929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31587	 85929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31588	 31590	 0.026954	 0.040881	 0.00059	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84755	 31588	 0.012765	 0.029326	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31589	 31591	 0.001324	 0.008597	 0.01712	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31589	 85930	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85931	 31589	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84679	 31590	 0.032349	 0.064048	 0.00094	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31591	 31641	 0.000289	 0.002849	 0.00607	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31591	 85932	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31591	 85932	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31592	 85951	 0.069767	 0.050435	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85931	 31593	 0.075919	 0.055857	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85932	 31593	 0.036462	 0.047921	 0.00066	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31594	 31598	 0.001132	 0.003815	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31594	 85933	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31594	 85933	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84678	 31595	 0.00056	 0.008069	 0.00293	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31595	 85934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31595	 85934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84658	 31596	 0.00457	 0.020965	 0.00537	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31596	 85935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31596	 85935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85922	 31597	 0.007635	 0.015624	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31598	 85936	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31598	 85936	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31599	 31600	 0.001419	 0.003863	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31599	 31697	 0.004478	 0.013597	 0.00298	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31599	 85937	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31599	 85937	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31600	 85938	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31600	 85938	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85934	 31601	 0.01287	 0.053722	 0.00155	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31601	 85939	 0.016569	 0.038467	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31602	 31696	 0.004848	 0.013518	 0.00284	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31602	 85939	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31602	 85939	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85935	 31603	 0.008585	 0.046982	 0.00092	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85938	 31603	 0.010105	 0.021237	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85939	 31603	 0.015274	 0.03546	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85937	 31604	 0.018169	 0.031305	 0.0005	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85939	 31604	 0.023855	 0.061323	 0.00095	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31604	 85942	 0.035659	 0.060071	 0.00086	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31604	 85944	 0.013862	 0.027167	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85937	 31605	 0.007139	 0.01461	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31605	 85940	 0.028847	 0.021223	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31606	 31613	 0.002447	 0.006352	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31606	 85940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31606	 85940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31607	 31609	 0.002164	 0.007424	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31607	 31617	 0.003793	 0.01064	 0.00274	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31607	 31699	 0.007717	 0.020394	 0.00477	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31607	 85941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31607	 85941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31608	 31611	 0.002233	 0.007285	 0.00193	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31608	 85942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31608	 85942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31608	 85968	 0.001984	 0.007798	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31609	 85943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31609	 85943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85297	 31610	 0.060495	 0.047875	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85942	 31610	 0.038235	 0.030258	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31612	 31613	 0.001269	 0.004823	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31612	 85944	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31612	 85944	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31612	 85968	 0.001822	 0.007524	 0.00178	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31613	 85945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31613	 85945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85257	 31614	 0.040397	 0.08657	 0.00152	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85927	 31614	 0.016265	 0.053676	 0.00087	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84742	 31616	 0.008461	 0.01935	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85943	 31616	 0.037568	 0.056323	 0.00102	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31618	 31625	 0.004538	 0.019208	 0.00432	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31618	 85946	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31618	 85946	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31619	 85947	 0.012527	 0.022944	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31620	 31621	 0.056638	 0.044823	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31620	 85947	 0.015849	 0.040741	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85928	 31622	 0.011176	 0.020166	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31622	 85947	 0.012908	 0.021745	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31623	 31625	 0.003102	 0.014466	 0.00358	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84658	 31623	 0.004034	 0.018814	 0.00466	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31623	 85947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31623	 85947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31624	 31625	 0.001794	 0.005289	 0.00123	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31624	 31627	 0.004008	 0.011816	 0.00275	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31626	 31627	 0.001642	 0.006573	 0.00166	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31626	 31630	 0.001645	 0.006963	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85930	 31627	 0.002296	 0.009191	 0.00232	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31627	 85948	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31627	 85948	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85929	 31628	 0.0107	 0.017164	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85948	 31629	 0.011843	 0.01995	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31630	 31631	 0.001696	 0.007177	 0.00161	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31630	 31634	 0.003218	 0.015335	 0.00444	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85930	 31631	 0.003163	 0.013386	 0.00301	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31632	 31635	 0.073261	 0.053901	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85365	 31632	 0.16744	 0.59891	 0.01191	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31632	 85950	 0.018847	 0.052206	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31632	 85958	 0.031851	 0.19584	 0.00353	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31633	 31634	 0.004609	 0.022728	 0.00615	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31636	 31637	 0.000779	 0.008304	 0.01505	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31636	 85949	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31636	 85949	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31637	 31640	 0.000672	 0.006181	 0.01513	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31638	 31648	 0.053561	 0.076036	 0.00125	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85733	 31639	 0.060815	 0.051977	 0.00097	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31640	 31641	 0.000568	 0.005222	 0.01279	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31640	 85950	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31640	 85950	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31641	 85951	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31641	 85951	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31642	 31643	 0.084639	 0.056856	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31643	 31644	 0.014591	 0.056762	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31643	 31656	 0.013739	 0.053448	 0.00089	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31644	 31647	 0.078382	 0.059386	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31644	 31650	 0.10849	 0.076855	 0.00122	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31644	 85955	 0.027561	 0.056402	 0.00139	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84713	 31645	 0.001043	 0.008591	 0.01771	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84724	 31645	 0.001152	 0.01028	 0.02082	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31645	 85952	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85953	 31645	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31646	 85954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31646	 85954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31647	 85955	 0.012638	 0.05165	 0.00104	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31647	 85956	 0.063216	 0.082271	 0.00115	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84715	 31648	 0.015579	 0.044683	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84714	 31649	 0.006567	 0.022126	 0.0055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31649	 85955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31649	 85955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31650	 31651	 0.010163	 0.021359	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31650	 85956	 0.013781	 0.0305	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85953	 31651	 0.018281	 0.070329	 0.0012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85952	 31652	 0.005483	 0.024994	 0.00793	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31652	 85956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31652	 85956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31653	 31673	 0.003174	 0.012707	 0.0032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85952	 31653	 0.011615	 0.046506	 0.01172	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31653	 85957	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31653	 85957	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31654	 31655	 0.009835	 0.032456	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31654	 31666	 0.014226	 0.047456	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85956	 31655	 0.009748	 0.037502	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31656	 31658	 0.014377	 0.040797	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31656	 31665	 0.021864	 0.050759	 0.00075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31657	 31658	 0.028979	 0.02132	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31658	 31662	 0.006476	 0.021604	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31659	 31660	 0.007606	 0.02959	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85932	 31659	 0.005143	 0.019785	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84709	 31660	 0.00508	 0.018782	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84679	 31661	 0.003928	 0.008983	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84709	 31662	 0.004182	 0.022284	 0.00039	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31662	 85958	 0.003754	 0.015887	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31663	 31670	 0.002212	 0.010908	 0.00295	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84707	 31663	 0.001123	 0.00711	 0.00193	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31663	 85958	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31663	 85958	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85958	 31664	 0.012673	 0.014855	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31665	 31666	 0.010209	 0.023454	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31665	 31667	 0.047732	 0.037415	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85958	 31665	 0.007087	 0.031577	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31666	 31668	 0.021928	 0.023416	 0.0005	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85957	 31666	 0.061275	 0.047002	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31667	 31668	 0.013651	 0.024383	 0.00036	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31667	 85959	 0.011941	 0.030367	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31668	 31672	 0.009929	 0.018463	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85957	 31668	 0.015829	 0.036748	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85958	 31669	 0.014182	 0.033582	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31669	 85959	 0.022267	 0.017454	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31669	 85960	 0.011409	 0.028318	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31670	 31692	 0.003927	 0.010194	 0.00247	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31670	 85959	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31670	 85959	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31671	 31675	 0.002928	 0.008166	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31671	 85960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31671	 85960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85960	 31672	 0.006621	 0.021232	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31672	 85961	 0.009941	 0.028512	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31673	 31674	 0.001108	 0.004822	 0.00137	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31673	 85961	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31673	 85961	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31674	 31676	 0.000949	 0.004425	 0.0011	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31675	 31691	 0.003781	 0.009816	 0.00238	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31676	 85964	 0.003691	 0.017214	 0.00426	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31677	 31678	 0.085801	 0.065816	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31677	 31679	 0.071356	 0.046197	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31677	 31684	 0.083945	 0.1286	 0.00181	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85954	 31677	 0.019854	 0.065519	 0.00106	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31679	 31681	 0.054133	 0.10718	 0.00157	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31680	 31682	 0.010935	 0.022982	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85956	 31680	 0.025554	 0.059327	 0.00088	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31681	 31683	 0.015249	 0.039198	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85961	 31681	 0.005531	 0.022605	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85961	 31682	 0.030113	 0.069912	 0.00104	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31683	 31684	 0.012669	 0.048738	 0.00083	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85956	 31683	 0.025974	 0.11574	 0.00197	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31683	 85963	 0.044224	 0.094772	 0.00166	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31684	 31688	 0.017905	 0.046027	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31685	 31688	 0.028986	 0.056808	 0.00085	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31685	 85962	 0.082972	 0.13311	 0.00246	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31686	 31711	 0.005722	 0.02422	 0.00545	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31686	 31722	 0.011077	 0.044353	 0.01118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31686	 85962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31686	 85962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31687	 31688	 0.024664	 0.030067	 0.00048	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31687	 31710	 0.014006	 0.03251	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31687	 85963	 0.014126	 0.035925	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31688	 85963	 0.025381	 0.064549	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31689	 85963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31689	 85963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31689	 85964	 0.0068	 0.027673	 0.00674	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84704	 31690	 0.001698	 0.019333	 0.03827	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84719	 31690	 0.00563	 0.038798	 0.06853	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84724	 31690	 0.00358	 0.039498	 0.07509	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31690	 85964	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31690	 85964	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31691	 31692	 0.002986	 0.00775	 0.00188	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85964	 31691	 0.00125	 0.004863	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31692	 85965	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31692	 85965	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31693	 31694	 0.070034	 0.053721	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85965	 31693	 0.030692	 0.02429	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31694	 31704	 0.060484	 0.12713	 0.00232	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84679	 31694	 0.014094	 0.075096	 0.00132	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31695	 31698	 0.00092	 0.00621	 0.01143	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84704	 31695	 0.001123	 0.009007	 0.03032	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85313	 31695	 0.00258	 0.017599	 0.03169	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31695	 85966	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85967	 31695	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31696	 31700	 0.003097	 0.008331	 0.00234	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84658	 31697	 0.008102	 0.044461	 0.01175	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85966	 31697	 0.002758	 0.01435	 0.00423	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31698	 85968	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31698	 85968	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85968	 31699	 0.001859	 0.007443	 0.00188	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31700	 31703	 0.002081	 0.007572	 0.00232	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31701	 31716	 0.054673	 0.12694	 0.00189	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84740	 31701	 0.009343	 0.028122	 0.00055	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85939	 31701	 0.041436	 0.0962	 0.00143	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31704	 31705	 0.031647	 0.08366	 0.00152	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31704	 31716	 0.023278	 0.074646	 0.00185	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84740	 31704	 0.008169	 0.039211	 0.00117	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31705	 31709	 0.033023	 0.084891	 0.00131	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31706	 31707	 0.083903	 0.084746	 0.00112	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31706	 31710	 0.017649	 0.034944	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31707	 31709	 0.11712	 0.12882	 0.00172	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31707	 85969	 0.13704	 0.14928	 0.00203	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31708	 31709	 0.021665	 0.040283	 0.00094	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31708	 31712	 0.022693	 0.052686	 0.00078	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85963	 31709	 0.043602	 0.10325	 0.00189	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31711	 31713	 0.006947	 0.033716	 0.00771	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31711	 85969	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31711	 85969	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31712	 31714	 0.033266	 0.024475	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31712	 31715	 0.033073	 0.070876	 0.00124	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84669	 31713	 0.021452	 0.13322	 0.0323	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31713	 85970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31713	 85970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85210	 31715	 0.043553	 0.12492	 0.00192	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31715	 85971	 0.066175	 0.15672	 0.00287	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31716	 31717	 0.011796	 0.027385	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84676	 31716	 0.017808	 0.062309	 0.00129	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31717	 31718	 0.00924	 0.017903	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84676	 31718	 0.015646	 0.049678	 0.00087	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31719	 85971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31719	 85971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31720	 85972	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85922	 31721	 0.00854	 0.017477	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84644	 31723	 0.000504	 0.005222	 0.01125	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84644	 31723	 0.000504	 0.005222	 0.01125	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31723	 85974	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31723	 85974	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31724	 31728	 0.005628	 0.028638	 0.01038	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31724	 85975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31724	 85975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85974	 31725	 0.042685	 0.14087	 0.00228	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85975	 31725	 0.027164	 0.07791	 0.0012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31725	 85976	 0.070141	 0.1717	 0.00294	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31726	 31727	 0.013068	 0.040642	 0.00848	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31726	 85976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31726	 85976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31727	 85977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31727	 85977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31728	 85978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31728	 85978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84645	 31729	 0.003456	 0.028683	 0.00755	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31729	 85979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31729	 85979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31729	 85983	 0.001838	 0.012997	 0.00357	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31730	 31731	 0.000214	 0.002319	 0.00455	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31730	 31731	 0.000214	 0.002319	 0.00455	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84644	 31730	 0.000621	 0.006624	 0.01347	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84644	 31730	 0.000621	 0.006624	 0.01347	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31730	 85980	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85981	 31730	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31731	 31732	 0.000148	 0.002576	 0.00865	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31731	 85982	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31731	 85982	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31732	 31735	 0.000464	 0.006233	 0.022	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31732	 85983	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31732	 85983	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31733	 31765	 0.001411	 0.015052	 0.03061	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31733	 31765	 0.001411	 0.015052	 0.03061	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84723	 31734	 0.026657	 0.048824	 0.00084	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31735	 31737	 0.001132	 0.010961	 0.03877	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31735	 32038	 0.011188	 0.072748	 0.14527	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31735	 85984	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85985	 31735	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31736	 31738	 0.014127	 0.067811	 0.00203	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85985	 31736	 0.011896	 0.057102	 0.00171	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31737	 32132	 0.001639	 0.015611	 0.05704	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31737	 85986	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31737	 85986	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31738	 32133	 0.067596	 0.22553	 0.00358	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85986	 31738	 0.017381	 0.067616	 0.00113	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31739	 85987	 0.004142	 0.025466	 0.00046	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31739	 85990	 0.059537	 0.29785	 0.0053	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31740	 31741	 0.000403	 0.003038	 0.00084	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31740	 31759	 0.004089	 0.035075	 0.00998	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31740	 31761	 0.001236	 0.005232	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31740	 85987	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31740	 85987	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31741	 31775	 0.002169	 0.016868	 0.00438	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31741	 85988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31741	 85988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31742	 31777	 0.020981	 0.016446	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85988	 31742	 0.011231	 0.022236	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31743	 31744	 0.001271	 0.011543	 0.00376	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31743	 31746	 0.003867	 0.0364	 0.01103	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31744	 31759	 0.001562	 0.014237	 0.00517	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31744	 31762	 0.004417	 0.043154	 0.01211	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31745	 31747	 0.024637	 0.019311	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31745	 31751	 0.012978	 0.025695	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31746	 85989	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31746	 85989	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31748	 31750	 0.003296	 0.014689	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31749	 85990	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31749	 85990	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85989	 31750	 0.008173	 0.03642	 0.00062	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85989	 31751	 0.010604	 0.02726	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31752	 31756	 0.000436	 0.004456	 0.00265	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31752	 85991	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31752	 85991	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85991	 31753	 0.005331	 0.02697	 0.00047	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31754	 31755	 0.014888	 0.027268	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31754	 85992	 0.01173	 0.045631	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31754	 85992	 0.01173	 0.045631	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31755	 31758	 0.049633	 0.032132	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31756	 31757	 0.000648	 0.006814	 0.00383	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31756	 85992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31756	 85992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31757	 85993	 0.001722	 0.01896	 0.0097	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31759	 85993	 0.004047	 0.022204	 0.00587	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31760	 31763	 0.000514	 0.006854	 0.02457	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31760	 85993	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31760	 85993	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31761	 31762	 0.002165	 0.008667	 0.00218	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31762	 31766	 0.001596	 0.009652	 0.00246	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31762	 85994	 0.002631	 0.03062	 0.009	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31763	 31765	 0.000608	 0.007765	 0.03034	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31764	 31767	 0.014908	 0.13347	 0.0028	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84723	 31764	 0.023147	 0.1589	 0.0029	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85166	 31764	 0.08566	 0.22023	 0.00341	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85991	 31764	 0.061238	 0.47763	 0.00893	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31765	 85994	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31765	 85994	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31766	 31771	 0.00153	 0.008537	 0.00218	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31767	 31770	 0.019543	 0.040163	 0.00077	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31767	 85995	 0.007065	 0.055066	 0.00103	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31768	 31769	 0.001044	 0.009482	 0.00309	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31769	 31774	 0.001695	 0.016558	 0.00465	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31770	 85997	 0.012962	 0.030092	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31771	 31772	 0.001506	 0.005075	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31771	 85995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31771	 85995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31772	 85996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31772	 85996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31773	 85997	 0.01159	 0.008527	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31774	 31775	 0.001632	 0.012413	 0.0039	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31774	 85997	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31774	 85997	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31775	 85998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31775	 85998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85996	 31776	 0.004916	 0.027662	 0.0006	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85997	 31776	 0.009042	 0.051401	 0.00093	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85998	 31776	 0.006685	 0.015521	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31778	 31782	 0.000333	 0.002273	 0.00409	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31778	 85999	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86000	 31778	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86000	 31779	 0.012522	 0.009815	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86000	 31780	 0.011785	 0.023096	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31781	 31784	 0.029427	 0.019767	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31781	 86002	 0.008048	 0.023083	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84641	 31782	 0.001707	 0.011237	 0.02174	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31782	 86001	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86002	 31782	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31783	 31794	 0.002416	 0.009183	 0.00257	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86001	 31783	 0.001142	 0.004717	 0.00112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84944	 31784	 0.28906	 0.53825	 0.01261	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86002	 31784	 0.023778	 0.039713	 0.00067	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31784	 86007	 0.012986	 0.032894	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31784	 86010	 0.24688	 0.19355	 0.00248	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31785	 31788	 0.004548	 0.015172	 0.00385	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84665	 31785	 0.006131	 0.021032	 0.00504	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31786	 31821	 0.003439	 0.007984	 0.00243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85999	 31786	 0.002604	 0.006882	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31786	 86003	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31786	 86003	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86000	 31787	 0.030163	 0.037442	 0.00082	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31787	 86018	 0.027678	 0.03602	 0.0005	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31788	 31789	 0.004259	 0.011255	 0.00263	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31788	 86004	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31788	 86004	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85343	 31789	 0.002816	 0.009953	 0.00224	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31789	 86005	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31789	 86005	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31790	 31821	 0.004697	 0.013098	 0.00275	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31790	 86006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31790	 86006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86003	 31791	 0.068883	 0.053994	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86002	 31792	 0.043306	 0.047631	 0.00064	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31793	 31797	 0.053157	 0.037654	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86002	 31793	 0.019516	 0.045309	 0.00067	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84665	 31794	 0.00101	 0.005156	 0.0013	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31794	 86007	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31794	 86007	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31795	 31796	 0.00233	 0.007994	 0.00192	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84665	 31795	 0.002702	 0.011436	 0.00257	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31796	 31810	 0.00157	 0.006287	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31796	 86008	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31796	 86008	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31797	 31798	 0.010455	 0.029985	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84643	 31797	 0.019871	 0.061023	 0.00115	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31798	 31806	 0.021815	 0.043193	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31799	 31802	 0.002214	 0.011124	 0.00289	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84642	 31799	 0.0011	 0.01035	 0.00313	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31799	 86009	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31799	 86009	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84643	 31800	 0.035126	 0.027798	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84643	 31801	 0.031719	 0.025102	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31802	 86010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31802	 86010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31803	 31804	 0.006702	 0.012275	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86010	 31803	 0.005891	 0.016895	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86010	 31804	 0.011165	 0.025916	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31805	 31808	 0.019393	 0.034991	 0.00051	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31805	 31811	 0.013947	 0.027614	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31805	 86011	 0.030975	 0.047451	 0.00067	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31806	 31812	 0.030118	 0.030753	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31806	 31820	 0.15274	 0.20826	 0.00462	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86008	 31806	 0.01115	 0.026403	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31806	 86011	 0.017827	 0.027309	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31807	 31809	 0.002394	 0.006328	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31807	 86011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31807	 86011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31808	 86017	 0.01403	 0.040239	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31809	 31819	 0.00417	 0.011628	 0.00244	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31810	 86016	 0.002339	 0.008185	 0.00271	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86010	 31811	 0.003751	 0.012813	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86010	 31812	 0.009729	 0.01809	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86011	 31812	 0.027521	 0.022652	 0.00046	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31813	 31817	 0.0007	 0.004547	 0.00906	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84656	 31813	 0.003494	 0.024507	 0.04173	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31813	 86012	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86013	 31813	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31814	 31817	 0.000754	 0.005029	 0.00948	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31814	 86014	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31814	 86014	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31815	 31816	 0.002987	 0.010246	 0.00245	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31815	 86015	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31815	 86015	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31816	 86016	 0.001682	 0.00561	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31817	 86016	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31817	 86016	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31818	 86017	 0.018827	 0.037276	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86012	 31819	 0.002087	 0.008355	 0.0021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31819	 86017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31819	 86017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84944	 31820	 0.27874	 0.61771	 0.01014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86014	 31820	 0.052935	 0.15568	 0.00319	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31821	 86018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31821	 86018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31823	 86020	 0.098475	 0.25048	 0.00396	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84717	 31824	 0.083575	 0.13341	 0.00307	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31824	 86020	 0.15245	 0.15399	 0.00204	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31825	 86020	 0.04358	 0.08541	 0.00128	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31826	 31834	 0.002194	 0.014239	 0.02836	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31826	 31837	 0.002542	 0.017829	 0.03036	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31826	 86019	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86020	 31826	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31827	 86021	 0.016731	 0.033125	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31827	 86022	 0.05638	 0.062012	 0.00083	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31828	 31835	 0.007198	 0.019023	 0.00445	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86019	 31828	 0.003973	 0.009986	 0.00259	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31828	 86021	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31828	 86021	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31829	 31833	 0.00564	 0.018396	 0.00488	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31829	 31838	 0.006432	 0.018631	 0.00449	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84670	 31830	 0.014689	 0.057143	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31830	 86026	 0.12168	 0.10979	 0.00184	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31831	 86022	 0.012508	 0.028736	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31832	 31835	 0.002276	 0.007808	 0.00187	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31833	 86022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31833	 86022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31834	 86023	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86024	 31834	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86023	 31835	 0.002459	 0.012811	 0.00336	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31836	 86029	 0.081908	 0.11166	 0.00248	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31837	 86025	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31837	 86025	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86025	 31838	 0.00858	 0.028909	 0.00718	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31838	 86026	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31838	 86026	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31839	 31843	 0.005227	 0.01514	 0.00365	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31839	 31845	 0.008583	 0.025702	 0.00579	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31840	 31841	 0.001865	 0.005499	 0.00128	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31840	 86027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31840	 86027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31841	 31842	 0.002245	 0.007491	 0.0019	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31842	 31843	 0.005227	 0.017048	 0.00453	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31842	 86028	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31842	 86028	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31844	 86029	 0.026157	 0.041752	 0.00096	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31845	 86029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31845	 86029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31846	 86030	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31846	 86030	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31847	 31848	 0.001993	 0.011623	 0.00023	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31847	 31849	 0.004147	 0.016133	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31847	 31849	 0.004147	 0.016133	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31847	 31861	 0.014302	 0.029268	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31848	 31891	 0.01387	 0.04255	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31848	 86032	 0.00224	 0.009927	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31849	 31850	 0.002482	 0.009309	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31849	 86037	 0.004729	 0.026043	 0.00059	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31850	 86037	 0.003234	 0.019654	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31851	 86031	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86032	 31851	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31851	 86035	 0.000341	 0.00247	 0.01025	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31851	 86052	 0.00657	 0.045286	 0.08001	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31852	 86034	 0.016983	 0.01344	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31853	 31875	 0.003451	 0.010587	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31853	 86033	 0.004689	 0.01804	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31854	 31855	 0.000335	 0.002788	 0.00084	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31854	 31858	 0.000614	 0.003567	 0.00084	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31854	 86033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31854	 86033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31855	 31867	 0.000446	 0.004052	 0.00132	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31855	 86034	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31855	 86034	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31856	 31857	 0.004004	 0.012295	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31856	 31859	 0.00617	 0.014323	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86032	 31857	 0.005315	 0.020677	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31858	 31884	 0.000586	 0.002996	 0.00082	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31859	 31860	 0.007443	 0.013429	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31859	 31891	 0.008455	 0.02425	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31860	 86043	 0.009788	 0.022723	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31861	 31862	 0.053799	 0.042576	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31863	 31864	 0.091947	 0.072074	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31864	 31865	 0.005471	 0.009833	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31865	 86037	 0.003776	 0.020792	 0.00047	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31866	 86035	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86036	 31867	 0.000487	 0.005221	 0.00136	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31867	 86038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31867	 86038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31868	 31870	 0.001694	 0.005811	 0.00139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31868	 86039	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31868	 86039	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86038	 31869	 0.01719	 0.021877	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31870	 86040	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31870	 86040	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31871	 31876	 0.016084	 0.062571	 0.00104	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86039	 31871	 0.007981	 0.031169	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31872	 31873	 0.002179	 0.015928	 0.00029	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86040	 31872	 0.002889	 0.022257	 0.00043	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31873	 31874	 0.002818	 0.014842	 0.00027	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	86032	 31873	 0.022477	 0.057779	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31874	 31881	 0.005776	 0.014849	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31875	 31879	 0.003364	 0.011221	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86032	 31876	 0.041533	 0.10563	 0.00167	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31876	 86042	 0.018409	 0.043593	 0.0008	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31877	 31878	 0.003042	 0.008166	 0.00185	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31877	 86041	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31877	 86041	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31878	 31930	 0.014661	 0.038064	 0.00924	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31878	 86042	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31878	 86042	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31879	 31880	 0.003336	 0.008645	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31880	 31882	 0.006603	 0.022027	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31880	 86044	 0.00816	 0.016698	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86041	 31881	 0.010536	 0.027083	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31882	 31883	 0.006265	 0.016562	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31882	 31886	 0.006994	 0.016561	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31882	 86048	 0.00898	 0.027548	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86041	 31883	 0.009436	 0.021678	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31884	 31885	 0.000437	 0.002765	 0.00075	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31884	 86043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31884	 86043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31885	 31888	 0.000961	 0.004002	 0.00125	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31885	 86044	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31885	 86044	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31886	 31899	 0.022728	 0.044543	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86032	 31886	 0.017577	 0.064991	 0.0012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31886	 86045	 0.00972	 0.019049	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31887	 31888	 0.000901	 0.003606	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31887	 31898	 0.000903	 0.003616	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31887	 86045	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31887	 86045	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31889	 31891	 0.003022	 0.00969	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31889	 31894	 0.013384	 0.018653	 0.00032	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31889	 31895	 0.008161	 0.020979	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31890	 31891	 0.003751	 0.008709	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31890	 31892	 0.02657	 0.021027	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31893	 31894	 0.024615	 0.017436	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31895	 31897	 0.008201	 0.021082	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31896	 31897	 0.014424	 0.027622	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31896	 31900	 0.009423	 0.018467	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31898	 86046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31898	 86046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31899	 31900	 0.007838	 0.022242	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86046	 31899	 0.005547	 0.014665	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31900	 31902	 0.005515	 0.018396	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31901	 31904	 0.001977	 0.010511	 0.00244	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31901	 31905	 0.001651	 0.007815	 0.00188	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31901	 86047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31901	 86047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86047	 31902	 0.005376	 0.015419	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86047	 31903	 0.012516	 0.02478	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86031	 31904	 0.004344	 0.026958	 0.00653	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31904	 86048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31904	 86048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31905	 31906	 0.00267	 0.01015	 0.00284	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31906	 31907	 0.001347	 0.004619	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31906	 86049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31906	 86049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31907	 31908	 0.003391	 0.009233	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31908	 86050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31908	 86050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31909	 31910	 0.011499	 0.020748	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31909	 31912	 0.014556	 0.014863	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86050	 31909	 0.011361	 0.026903	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31909	 86056	 0.026798	 0.029474	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31910	 31931	 0.01598	 0.045345	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31910	 86056	 0.014144	 0.028003	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31911	 31912	 0.021544	 0.01705	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31911	 31913	 0.005846	 0.0195	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86050	 31911	 0.003696	 0.021011	 0.00038	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31913	 31914	 0.005699	 0.016173	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31914	 31917	 0.011293	 0.02903	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31914	 86056	 0.014254	 0.036249	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31915	 31916	 0.003604	 0.008535	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31915	 31921	 0.009649	 0.019104	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31915	 86056	 0.00602	 0.023421	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31916	 31917	 0.006605	 0.016978	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31917	 31918	 0.010257	 0.026365	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31918	 31919	 0.008748	 0.014531	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31919	 31920	 0.013641	 0.032303	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31919	 31922	 0.013425	 0.034511	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31919	 31923	 0.022008	 0.046986	 0.00106	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31920	 31921	 0.021093	 0.016692	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31920	 31936	 0.00843	 0.015674	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31920	 86056	 0.015139	 0.043419	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31922	 31923	 0.01426	 0.023686	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31923	 31924	 0.017455	 0.012364	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31923	 31925	 0.011655	 0.023852	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31925	 31926	 0.009395	 0.019745	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31927	 31939	 0.005869	 0.026154	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31927	 86051	 0.005202	 0.027716	 0.00049	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31928	 86051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31928	 86051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31928	 86053	 0.004006	 0.016038	 0.00404	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31929	 86052	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86053	 31930	 0.020236	 0.046978	 0.01431	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31930	 86055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31930	 86055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86049	 31931	 0.008465	 0.025479	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86031	 31932	 0.012412	 0.07133	 0.02021	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31932	 86056	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31932	 86056	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86056	 31933	 0.024102	 0.040034	 0.00085	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31933	 86057	 0.028709	 0.0518	 0.00075	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86054	 31934	 0.040253	 0.17938	 0.00305	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31934	 86057	 0.027749	 0.071332	 0.0011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31935	 31940	 0.005563	 0.016401	 0.00382	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31935	 86057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31935	 86057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86057	 31936	 0.013872	 0.035138	 0.0007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31937	 31938	 0.00716	 0.025067	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86057	 31937	 0.03011	 0.069904	 0.00104	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31937	 86058	 0.012988	 0.025454	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86051	 31938	 0.016584	 0.04263	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86054	 31938	 0.020121	 0.082233	 0.00166	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31939	 86058	 0.003773	 0.018412	 0.00032	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31940	 86058	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31940	 86058	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31941	 31945	 0.001231	 0.005009	 0.00122	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31941	 86059	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31941	 86059	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86059	 31942	 0.011504	 0.008316	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86059	 31943	 0.020867	 0.016513	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31944	 31967	 0.012836	 0.029801	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86059	 31944	 0.009977	 0.023626	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31944	 86069	 0.026479	 0.047295	 0.0007	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31945	 31964	 0.001133	 0.004611	 0.00112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31946	 31947	 0.005786	 0.008213	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31946	 86067	 0.006391	 0.011487	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31947	 31949	 0.012213	 0.016051	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31948	 31958	 0.001565	 0.008412	 0.00207	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31948	 31963	 0.001243	 0.006245	 0.00163	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31948	 86060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31948	 86060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31948	 86062	 0.00071	 0.005668	 0.0014	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86059	 31949	 0.006727	 0.015455	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	31950	 86061	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31951	 31953	 0.002204	 0.013677	 0.00331	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84685	 31951	 0.001515	 0.012171	 0.00342	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31952	 31953	 0.001357	 0.007798	 0.00221	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31952	 31995	 0.001898	 0.010531	 0.0032	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31954	 31959	 0.020019	 0.015843	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	31955	 31958	 0.001428	 0.007564	 0.00192	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31955	 31987	 0.001754	 0.008667	 0.00253	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31955	 86064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31955	 86064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31956	 31962	 0.00076	 0.005375	 0.00147	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86062	 31956	 0.001835	 0.0114	 0.00322	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31956	 86065	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31956	 86065	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86060	 31957	 0.031902	 0.023471	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86063	 31957	 0.014957	 0.038447	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86065	 31957	 0.011369	 0.029225	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31959	 31990	 0.018271	 0.02931	 0.00054	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86065	 31959	 0.013039	 0.04658	 0.00092	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31959	 86066	 0.013295	 0.020366	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31959	 86076	 0.017657	 0.036134	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31960	 31961	 0.00074	 0.004249	 0.0012	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31960	 31991	 0.000768	 0.005154	 0.00124	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31960	 86066	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31960	 86066	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31961	 31962	 0.000461	 0.00277	 0.00084	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31963	 31964	 0.001411	 0.004087	 0.00099	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31963	 86067	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31963	 86067	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31964	 31966	 0.001546	 0.009052	 0.00247	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31965	 31975	 0.003888	 0.023516	 0.006	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86062	 31965	 0.002543	 0.017041	 0.00522	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31965	 86068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31965	 86068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31966	 31971	 0.00326	 0.017949	 0.00648	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31966	 86069	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31966	 86069	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31967	 32171	 0.026725	 0.052912	 0.00078	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31968	 86071	 0.006756	 0.027047	 0.00681	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31969	 31970	 0.000941	 0.006273	 0.01182	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	31969	 86070	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31969	 86070	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31970	 86071	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31970	 86071	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31971	 31972	 0.001031	 0.006401	 0.00155	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31972	 31980	 0.001272	 0.007452	 0.00203	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31973	 31974	 0.00081	 0.004979	 0.00144	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31973	 31975	 0.001075	 0.006808	 0.00185	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31974	 31981	 0.001583	 0.004584	 0.00111	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31974	 31983	 0.000958	 0.00347	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31974	 86072	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31974	 86072	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31976	 31982	 0.002435	 0.008205	 0.00204	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31976	 31984	 0.006719	 0.026903	 0.00678	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31976	 86073	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31976	 86073	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31977	 31978	 0.001804	 0.004535	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31977	 31982	 0.000908	 0.003634	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86070	 31978	 0.002415	 0.006383	 0.00149	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31979	 31980	 0.002151	 0.007791	 0.00167	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31979	 31982	 0.002775	 0.007463	 0.00209	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31980	 86074	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31980	 86074	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86070	 31981	 0.003663	 0.010506	 0.00258	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31982	 31983	 0.001214	 0.004166	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86070	 31982	 0.004446	 0.012472	 0.00321	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31984	 31985	 0.001902	 0.009378	 0.00254	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31984	 31987	 0.001002	 0.005119	 0.00129	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31984	 32017	 0.001139	 0.006672	 0.00182	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86062	 31984	 0.00309	 0.026506	 0.00754	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31985	 32020	 0.00244	 0.010871	 0.00295	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31986	 86084	 0.011247	 0.021539	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31988	 86077	 0.008397	 0.019492	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85668	 31989	 0.000893	 0.010985	 0.02229	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86061	 31989	 0.000559	 0.008708	 0.03658	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	31989	 86075	 8.8e-05	 0.007032	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86076	 31989	 0.000247	 0.018554	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86075	 31991	 0.001232	 0.006293	 0.00158	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31991	 86077	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31991	 86077	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31992	 86078	 0.005631	 0.012633	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85723	 31993	 0.011068	 0.054007	 0.00093	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	31993	 86078	 0.015008	 0.022762	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31993	 86080	 0.006999	 0.035404	 0.00062	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	31994	 31998	 0.009477	 0.015126	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31994	 31999	 0.008017	 0.01441	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31994	 32011	 0.008323	 0.015018	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86076	 31994	 0.009804	 0.029507	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	31995	 32000	 0.000774	 0.006097	 0.00178	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31996	 31997	 0.001606	 0.004169	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31996	 86078	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31996	 86078	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31997	 32000	 0.001054	 0.004353	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	31997	 86079	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31997	 86079	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86079	 31998	 0.003741	 0.016671	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	31999	 32006	 0.01983	 0.030377	 0.00043	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32000	 32001	 0.000365	 0.003505	 0.00102	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86075	 32001	 0.000726	 0.006972	 0.00203	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32002	 32006	 0.004407	 0.015418	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32002	 32006	 0.004407	 0.015418	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32003	 32004	 0.000645	 0.002957	 0.00076	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86075	 32003	 0.002541	 0.012402	 0.00343	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32003	 86080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32003	 86080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32005	 32006	 0.001708	 0.014045	 0.00027	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32007	 32012	 0.000993	 0.005814	 0.00158	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32007	 86081	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32007	 86081	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32008	 32010	 0.018224	 0.014422	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32009	 32010	 0.017559	 0.013896	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86081	 32010	 0.006498	 0.016703	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86075	 32012	 0.000728	 0.004613	 0.00125	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32013	 32016	 0.001114	 0.007471	 0.0018	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86075	 32013	 0.001338	 0.006658	 0.00215	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32013	 86082	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32013	 86082	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86082	 32014	 0.008815	 0.017452	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32014	 86085	 0.016567	 0.016733	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32015	 86083	 0.023292	 0.018433	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32016	 86083	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32016	 86083	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32017	 32018	 0.001642	 0.006683	 0.00163	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32017	 86084	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32017	 86084	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32018	 32019	 0.001437	 0.005079	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32018	 86085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32018	 86085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32019	 32020	 0.001014	 0.003671	 0.00079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32020	 32022	 0.000418	 0.002646	 0.00072	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85675	 32021	 0.007549	 0.014946	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32021	 86087	 0.009134	 0.015232	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32022	 32024	 0.000906	 0.00497	 0.00131	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32023	 86087	 0.01086	 0.019596	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32024	 86086	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32024	 86086	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86075	 32025	 0.002395	 0.017325	 0.00932	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32025	 86087	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32025	 86087	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86087	 32026	 0.007827	 0.012493	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32027	 32040	 0.003663	 0.016804	 0.0043	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32027	 86088	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32027	 86088	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32028	 32036	 0.012895	 0.025531	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32028	 86093	 0.017083	 0.043444	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32029	 32030	 0.003514	 0.018213	 0.00445	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32029	 32040	 0.005269	 0.025112	 0.00727	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32030	 32033	 0.005255	 0.024106	 0.00618	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32030	 86089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32030	 86089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32031	 32034	 0.006748	 0.031472	 0.00779	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32031	 32039	 0.005805	 0.034	 0.00926	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32032	 32037	 0.001678	 0.011643	 0.00332	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32033	 32037	 0.002106	 0.009384	 0.00255	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32034	 32045	 0.010291	 0.046337	 0.01233	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32035	 32044	 0.00111	 0.005671	 0.00143	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32035	 86090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32035	 86090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32035	 86091	 0.002721	 0.014173	 0.00372	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84653	 32038	 0.003848	 0.05933	 0.13097	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32038	 86091	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86092	 32038	 0.000318	 0.022264	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32039	 32041	 0.002482	 0.009031	 0.00276	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32039	 86093	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32039	 86093	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32040	 86094	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32040	 86094	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86091	 32041	 0.002749	 0.013342	 0.00305	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86088	 32042	 0.14777	 0.11584	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86091	 32043	 0.001526	 0.012259	 0.00345	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32043	 86095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32043	 86095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32046	 32047	 0.005955	 0.03488	 0.0095	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32048	 32049	 0.007289	 0.035376	 0.00809	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32049	 86096	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32049	 86096	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32050	 32051	 0.006894	 0.039038	 0.00968	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32051	 32052	 0.012026	 0.047269	 0.01237	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32052	 86097	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32052	 86097	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32054	 32055	 0.001484	 0.014787	 0.04935	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32055	 32056	 0.00129	 0.012672	 0.04346	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32055	 86098	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32055	 86098	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85080	 32056	 0.003876	 0.037544	 0.13294	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32058	 32059	 0.052304	 0.12143	 0.00181	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84907	 32058	 0.078178	 0.20725	 0.00526	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85076	 32059	 0.049795	 0.18681	 0.00336	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32060	 32067	 0.003254	 0.015792	 0.00361	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32060	 32126	 0.003046	 0.019916	 0.00506	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32060	 86099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32060	 86099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32061	 32062	 0.001685	 0.014172	 0.0042	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32062	 32063	 0.000736	 0.006421	 0.00176	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32063	 32064	 0.000536	 0.006971	 0.00201	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32063	 32067	 0.001184	 0.00482	 0.00117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32064	 32065	 0.001017	 0.007053	 0.00201	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32064	 32066	 0.001107	 0.006694	 0.00171	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32064	 86100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32064	 86100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32065	 32076	 0.00063	 0.004599	 0.00118	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32066	 32068	 0.000722	 0.003674	 0.00133	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32067	 86101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32067	 86101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32068	 32070	 0.000723	 0.004487	 0.00109	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32069	 32071	 0.001126	 0.007555	 0.00182	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32069	 32089	 0.001993	 0.011875	 0.00312	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32069	 86102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32069	 86102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32070	 32082	 0.001429	 0.008212	 0.00233	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32070	 86103	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32070	 86103	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32071	 32126	 0.00151	 0.009287	 0.00268	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86100	 32072	 0.006095	 0.033565	 0.00076	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86101	 32072	 0.004863	 0.024746	 0.00056	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32072	 86125	 0.023252	 0.053983	 0.0008	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86099	 32073	 0.040932	 0.13655	 0.00216	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32073	 86104	 0.006318	 0.016373	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32073	 86109	 0.02452	 0.056927	 0.00085	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32074	 32075	 0.000919	 0.00368	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32074	 32081	 0.000945	 0.004001	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32075	 32076	 0.00137	 0.005208	 0.00146	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32075	 86104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32075	 86104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32076	 32077	 0.000983	 0.003934	 0.00099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32077	 32078	 0.001403	 0.005618	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32078	 32080	 0.00118	 0.004801	 0.00117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32079	 32087	 0.03251	 0.025483	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32080	 32085	 0.00079	 0.003623	 0.00093	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32081	 32083	 0.00116	 0.004644	 0.00117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32081	 86105	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32081	 86105	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32082	 32083	 0.000851	 0.00489	 0.00139	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32083	 86106	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32083	 86106	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32083	 86140	 0.000812	 0.007375	 0.0024	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86105	 32084	 0.002907	 0.009593	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32084	 86107	 0.007583	 0.012773	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32084	 86108	 0.00456	 0.017808	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32085	 32086	 0.000747	 0.003361	 0.00089	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32085	 86107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32085	 86107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32086	 32088	 0.000786	 0.003949	 0.00103	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32086	 86108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32086	 86108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32087	 32107	 0.028464	 0.018428	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86108	 32087	 0.006058	 0.014346	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32088	 32091	 0.000578	 0.002635	 0.00084	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32089	 86109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32089	 86109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32089	 86140	 0.001118	 0.007789	 0.00293	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32090	 32108	 0.017365	 0.022823	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32090	 86112	 0.016966	 0.035658	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32090	 86141	 0.009602	 0.049932	 0.00108	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32091	 32092	 0.000647	 0.003084	 0.00089	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32092	 32093	 0.000529	 0.003097	 0.00084	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32092	 32099	 0.001513	 0.005349	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32093	 32098	 0.000982	 0.004504	 0.00115	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32093	 32100	 0.000488	 0.005286	 0.00165	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32094	 86113	 0.010116	 0.019825	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32095	 32097	 0.008763	 0.017173	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32095	 86141	 0.013948	 0.035854	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32096	 86111	 0.016017	 0.012676	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32097	 86110	 0.028739	 0.022743	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32098	 32099	 0.000916	 0.004123	 0.0011	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32098	 86110	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32098	 86110	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32099	 86111	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32099	 86111	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32099	 86140	 0.001141	 0.006681	 0.00182	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32100	 32106	 0.000878	 0.003574	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32100	 32109	 0.002384	 0.01686	 0.00463	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32100	 86112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32100	 86112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32101	 32105	 0.001889	 0.011723	 0.00284	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32101	 86113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32101	 86113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32101	 86140	 0.002865	 0.015719	 0.00416	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32102	 32103	 0.009464	 0.017596	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86112	 32102	 0.008429	 0.023918	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32103	 86114	 0.012333	 0.025346	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32104	 32105	 0.001464	 0.005861	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32104	 32115	 0.001741	 0.007987	 0.00205	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32104	 86114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32104	 86114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32105	 32106	 0.001575	 0.006304	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32105	 32115	 0.002819	 0.013679	 0.00313	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32105	 86115	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32105	 86115	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32108	 32110	 0.025075	 0.031126	 0.00068	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32109	 32112	 0.003086	 0.022533	 0.00579	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86115	 32110	 0.019007	 0.031699	 0.00046	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32111	 32116	 0.008028	 0.035773	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32111	 86116	 0.005332	 0.023758	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32112	 32114	 0.000696	 0.005142	 0.00148	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32113	 86122	 0.093006	 0.060214	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32114	 32124	 0.000961	 0.00724	 0.00201	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32115	 32119	 0.000673	 0.006806	 0.002	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32115	 86116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32115	 86116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32117	 32118	 0.000547	 0.003733	 0.00672	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32117	 32125	 0.000427	 0.002894	 0.00527	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32118	 86117	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86118	 32118	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86117	 32119	 0.000605	 0.006544	 0.00275	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32119	 86119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32119	 86119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32120	 86120	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32121	 32122	 0.000916	 0.004203	 0.00108	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32121	 86124	 0.002731	 0.010382	 0.00291	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32122	 32123	 0.000459	 0.00446	 0.00294	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32122	 86124	 0.000703	 0.007586	 0.00217	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86121	 32123	 0.001416	 0.015592	 0.00798	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32123	 86123	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32123	 86123	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32124	 86124	 0.000635	 0.004783	 0.00133	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32125	 32172	 0.001445	 0.022798	 0.04783	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86120	 32125	 0.000609	 0.008564	 0.03552	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32125	 86124	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32125	 86124	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32126	 86125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32126	 86125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86109	 32127	 0.047768	 0.042804	 0.00088	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86125	 32128	 0.076138	 0.14923	 0.00224	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32129	 32130	 0.03992	 0.074228	 0.00174	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32129	 86141	 0.027211	 0.11122	 0.00225	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86119	 32130	 0.018426	 0.056586	 0.00106	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86123	 32131	 0.12281	 0.13509	 0.0018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32131	 86138	 0.070166	 0.2341	 0.00371	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32132	 32135	 0.000891	 0.009906	 0.03836	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32132	 86126	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32132	 86126	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86126	 32133	 0.024899	 0.088948	 0.00177	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32134	 32135	 0.000238	 0.003738	 0.01241	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32134	 32142	 0.000169	 0.002587	 0.00903	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32134	 86127	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32134	 86127	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32135	 32172	 0.002071	 0.023505	 0.05162	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32135	 86128	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32135	 86128	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32136	 32145	 0.012895	 0.079276	 0.00143	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86128	 32136	 0.012977	 0.060255	 0.00165	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32137	 32138	 0.009882	 0.042247	 0.00095	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84712	 32137	 0.096939	 0.18028	 0.00422	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86127	 32137	 0.009619	 0.04694	 0.00081	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32137	 86139	 0.096254	 0.18866	 0.00283	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32138	 32139	 0.036346	 0.038814	 0.00082	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84712	 32138	 0.074795	 0.16556	 0.00271	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32138	 86130	 0.006565	 0.02297	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32138	 86138	 0.080249	 0.18633	 0.00277	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32140	 32141	 0.00131	 0.006823	 0.00179	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32140	 32149	 0.002791	 0.011811	 0.00266	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32140	 32154	 0.003196	 0.010963	 0.00263	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32141	 32144	 0.001104	 0.005147	 0.00127	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32141	 86129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32141	 86129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32142	 32143	 0.000147	 0.000954	 0.0019	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32142	 32146	 0.000229	 0.002589	 0.01122	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32142	 86130	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32142	 86130	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32143	 86131	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32143	 86131	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86131	 32144	 0.000473	 0.002449	 0.0006	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32145	 32147	 0.013495	 0.053539	 0.00153	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32145	 86133	 0.007407	 0.025934	 0.00072	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84710	 32146	 0.00059	 0.006913	 0.02788	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32146	 86132	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86133	 32146	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32147	 32148	 0.010172	 0.026148	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84712	 32147	 0.00533	 0.036192	 0.0009	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85359	 32147	 0.038207	 0.11721	 0.00317	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32148	 86134	 0.019707	 0.031456	 0.00072	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32149	 32150	 0.001645	 0.007408	 0.00197	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32149	 86134	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32149	 86134	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32150	 32165	 0.001898	 0.0076	 0.00191	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32150	 86135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32150	 86135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32151	 32160	 0.001432	 0.007461	 0.00196	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84711	 32151	 0.000857	 0.009245	 0.00317	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84712	 32152	 0.01657	 0.018048	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84684	 32153	 0.000146	 0.002285	 0.00758	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84710	 32153	 0.000317	 0.003426	 0.0068	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84710	 32153	 0.000317	 0.003426	 0.0068	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86061	 32153	 0.000353	 0.004699	 0.01685	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32154	 32163	 0.002641	 0.009061	 0.00217	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32154	 86136	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32154	 86136	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32155	 32156	 0.11371	 0.089131	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32156	 32168	 0.019688	 0.017641	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32156	 32169	 0.044906	 0.047246	 0.00069	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32156	 32171	 0.02361	 0.039376	 0.00057	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32156	 86138	 0.024502	 0.070276	 0.00108	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32157	 32158	 0.000885	 0.003445	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32157	 32165	 0.001265	 0.005148	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32158	 32160	 0.001573	 0.005977	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32158	 86137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32158	 86137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32159	 86138	 0.022911	 0.018131	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32160	 86138	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32160	 86138	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32161	 32169	 0.005937	 0.018212	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32161	 86139	 0.004819	 0.021877	 0.00047	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32162	 32163	 0.002131	 0.00731	 0.00175	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32162	 86139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32162	 86139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86135	 32164	 0.021701	 0.04253	 0.00064	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86136	 32164	 0.096479	 0.076354	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32166	 32167	 0.020505	 0.022553	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86138	 32166	 0.057947	 0.11473	 0.00168	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86139	 32166	 0.032773	 0.055208	 0.00079	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32168	 32169	 0.02879	 0.028797	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86137	 32170	 0.018351	 0.028112	 0.00039	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84644	 32172	 0.004635	 0.073262	 0.15408	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32172	 86140	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86141	 32172	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32173	 32174	 0.011272	 0.046545	 0.01101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32173	 86142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32173	 86142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85358	 32175	 0.011844	 0.073512	 0.01781	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85440	 32175	 0.017896	 0.071666	 0.01806	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84754	 32176	 0.04785	 0.14681	 0.00398	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84754	 32176	 0.04785	 0.14681	 0.00398	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32177	 32178	 0.24375	 0.15785	 0.003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85624	 32177	 0.06276	 0.12844	 0.00316	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32179	 32180	 0.005769	 0.01979	 0.00474	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32179	 86143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32179	 86143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85623	 32180	 0.019014	 0.072292	 0.02024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32181	 32184	 0.009062	 0.039444	 0.01124	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85623	 32181	 0.015449	 0.070888	 0.01816	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32182	 32183	 0.072849	 0.18728	 0.0029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32182	 32191	 0.112	 0.22178	 0.00326	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32183	 86144	 0.060883	 0.14134	 0.00269	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32184	 86144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32184	 86144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32185	 32186	 0.015255	 0.041535	 0.00915	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32185	 32187	 0.01001	 0.026455	 0.00619	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32185	 86145	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32185	 86145	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32188	 32189	 0.11256	 0.079735	 0.00126	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32189	 32194	 0.067614	 0.16551	 0.00283	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85335	 32189	 0.02664	 0.088869	 0.00141	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85335	 32190	 0.064596	 0.15813	 0.0027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32191	 32193	 0.14637	 0.1716	 0.00298	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85335	 32191	 0.28954	 0.2292	 0.00289	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84893	 32192	 0.23254	 0.18406	 0.00232	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84765	 32195	 0.13668	 0.10817	 0.00136	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32196	 32197	 0.003369	 0.019149	 0.00554	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84764	 32196	 0.003295	 0.035356	 0.0092	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84764	 32196	 0.003295	 0.035356	 0.0092	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32196	 86146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32196	 86146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32197	 32199	 0.002899	 0.018954	 0.00482	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32198	 34106	 0.03585	 0.15976	 0.00271	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86146	 32198	 0.03965	 0.1935	 0.00334	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32198	 86147	 0.097844	 0.20111	 0.00384	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32199	 32203	 0.005822	 0.032304	 0.00982	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32200	 32262	 0.059282	 0.11023	 0.00258	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32200	 32709	 0.17538	 0.21384	 0.00343	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32201	 32263	 0.46965	 0.37195	 0.00468	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32201	 86280	 0.10238	 0.20273	 0.00298	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32202	 32582	 0.010405	 0.059156	 0.01713	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32202	 32711	 0.006227	 0.039441	 0.0107	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32203	 33852	 0.010802	 0.049559	 0.0127	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32203	 86147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32203	 86147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32204	 32705	 0.034345	 0.15048	 0.00324	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32204	 86148	 0.03192	 0.14224	 0.00242	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32205	 34090	 0.00809	 0.034242	 0.00771	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32205	 86148	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32205	 86148	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32206	 33720	 0.21006	 0.16116	 0.00216	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32207	 32990	 0.26696	 0.19303	 0.00293	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32208	 32215	 0.022089	 0.072894	 0.00118	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84781	 32208	 0.0375	 0.13122	 0.00272	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32209	 32211	 0.016347	 0.041573	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32210	 32211	 0.025341	 0.060008	 0.0011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84773	 32210	 0.015853	 0.061672	 0.00103	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32211	 32214	 0.017633	 0.041755	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32212	 32216	 0.025174	 0.11265	 0.00232	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84773	 32212	 0.012423	 0.092313	 0.0022	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32212	 86536	 0.08141	 0.15139	 0.00354	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32213	 32215	 0.050961	 0.03909	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32214	 32215	 0.006131	 0.015007	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32216	 86706	 0.041127	 0.18122	 0.00315	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32217	 86149	 0.077454	 0.1018	 0.0014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32217	 86490	 0.092129	 0.10035	 0.00137	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32218	 32219	 0.010395	 0.026131	 0.00677	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32218	 86149	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32218	 86149	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32219	 86150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32219	 86150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32220	 33114	 0.005477	 0.032081	 0.00874	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32220	 33593	 0.003582	 0.019875	 0.00604	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32221	 86151	 0.030966	 0.06337	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32221	 86483	 0.027291	 0.063359	 0.00094	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32222	 32226	 0.001629	 0.008941	 0.00236	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32222	 33455	 0.003423	 0.017197	 0.00448	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32223	 86151	 0.017712	 0.045529	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32223	 86483	 0.030153	 0.069994	 0.00133	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32224	 33452	 0.091017	 0.066966	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32224	 86151	 0.060887	 0.061498	 0.00081	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32225	 33589	 0.007825	 0.044486	 0.01288	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32225	 86151	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32225	 86151	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32226	 32236	 0.001806	 0.010759	 0.00283	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32227	 32230	 0.003102	 0.010965	 0.00247	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32227	 86152	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32227	 86152	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86152	 32228	 0.008861	 0.023424	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32228	 86153	 0.012393	 0.035543	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32229	 32236	 0.004108	 0.013399	 0.00356	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32229	 86153	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32229	 86153	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32230	 32233	 0.002867	 0.009658	 0.0024	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32231	 32237	 0.002672	 0.01416	 0.00473	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32231	 86154	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32231	 86154	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32232	 33599	 0.019546	 0.065204	 0.00103	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86154	 32232	 0.014319	 0.047254	 0.00077	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32233	 33590	 0.00503	 0.01457	 0.00351	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32234	 32235	 0.013563	 0.037052	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86154	 32234	 0.015589	 0.04121	 0.00075	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32235	 86224	 0.032252	 0.082023	 0.0013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32236	 32238	 0.001704	 0.010585	 0.00299	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32236	 86155	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32236	 86155	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32238	 34075	 0.001956	 0.012391	 0.00336	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32239	 32240	 0.024117	 0.073987	 0.002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32239	 33348	 0.024509	 0.064961	 0.00165	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32240	 32241	 0.068255	 0.17547	 0.00272	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32240	 32476	 0.023459	 0.11261	 0.00337	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32240	 86156	 0.031032	 0.063506	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32241	 32242	 0.042466	 0.10917	 0.00169	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32241	 86456	 0.054978	 0.1425	 0.00269	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32242	 33053	 0.043114	 0.12366	 0.0019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32242	 86157	 0.048565	 0.11158	 0.00169	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32243	 32244	 0.001528	 0.008383	 0.00222	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32243	 32245	 0.00125	 0.007757	 0.00188	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32244	 32247	 0.004562	 0.02214	 0.00506	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32244	 86156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32244	 86156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32245	 32252	 0.001763	 0.011525	 0.00293	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32245	 86157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32245	 86157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32246	 32250	 0.002132	 0.013504	 0.00367	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84767	 32246	 0.002577	 0.024738	 0.0072	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32246	 86158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32246	 86158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32247	 32599	 0.009668	 0.053299	 0.01246	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32247	 33345	 0.021524	 0.089646	 0.02797	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32247	 86159	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32247	 86159	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32248	 32249	 0.000568	 0.003599	 0.00098	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32248	 32500	 0.001746	 0.011416	 0.0029	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32248	 86160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32248	 86160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32249	 32250	 0.002983	 0.020014	 0.00483	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32249	 86161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32249	 86161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32251	 33820	 0.003335	 0.028047	 0.00831	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84767	 32251	 0.001109	 0.011523	 0.00356	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84767	 32252	 0.001781	 0.015277	 0.00435	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84768	 32253	 0.02942	 0.052879	 0.00095	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32254	 86162	 0.16421	 0.11872	 0.0018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32255	 32256	 0.003283	 0.024257	 0.007	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32255	 34142	 0.004471	 0.033679	 0.00934	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32256	 32257	 0.002059	 0.014564	 0.004	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32257	 86162	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32257	 86162	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32257	 86163	 0.001545	 0.010718	 0.00306	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32258	 33663	 0.011447	 0.078997	 0.13983	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32258	 86163	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86164	 32258	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32259	 32260	 0.21215	 0.15611	 0.00228	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32259	 32262	 0.087785	 0.17382	 0.00255	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32259	 33588	 0.1232	 0.22234	 0.00321	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32260	 32261	 0.026296	 0.14011	 0.00246	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32260	 32262	 0.12785	 0.23421	 0.00404	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32260	 32743	 0.20455	 0.1619	 0.00204	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32260	 34015	 0.039782	 0.11974	 0.00234	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32260	 86660	 0.085929	 0.22092	 0.00342	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32261	 32263	 0.028452	 0.12678	 0.00215	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32261	 32745	 0.18354	 0.14527	 0.00183	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32262	 32995	 0.18399	 0.54165	 0.01112	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86164	 32262	 0.21962	 0.51027	 0.00759	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32263	 32264	 0.056325	 0.099058	 0.00186	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32263	 33625	 0.1602	 0.14909	 0.00282	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32264	 33625	 0.18766	 0.14853	 0.00187	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32264	 33662	 0.11053	 0.090983	 0.00184	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32264	 86551	 0.32468	 0.25704	 0.00324	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32265	 32266	 0.015197	 0.012027	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32266	 32267	 0.012746	 0.009991	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32267	 32268	 0.020513	 0.016079	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32267	 32282	 0.009472	 0.018753	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32269	 32273	 0.015368	 0.010886	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32269	 32286	 0.00291	 0.012897	 0.00039	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32269	 86173	 0.002558	 0.012277	 0.00037	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32270	 32277	 0.018663	 0.01993	 0.00042	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32270	 86173	 0.014455	 0.0146	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32271	 32277	 0.010136	 0.026056	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32271	 32307	 0.020165	 0.032187	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32272	 32274	 0.025505	 0.018765	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32272	 32307	 0.019208	 0.020922	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32275	 32293	 0.00894	 0.045489	 0.00103	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32275	 32307	 0.016111	 0.037398	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32275	 33617	 0.012015	 0.040081	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32276	 32277	 0.006834	 0.020986	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32276	 32282	 0.009409	 0.021844	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32276	 86166	 0.004665	 0.019067	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32278	 86165	 0.037382	 0.024201	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32279	 86165	 0.031792	 0.02492	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32280	 32281	 0.002087	 0.008357	 0.00211	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32280	 32294	 0.001176	 0.005603	 0.00162	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32280	 86165	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32280	 86165	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32281	 86166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32281	 86166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32282	 32284	 0.005364	 0.019834	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32282	 32291	 0.02304	 0.043544	 0.0007	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32282	 86168	 0.020505	 0.081352	 0.00232	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32283	 32284	 0.002694	 0.019463	 0.00037	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86166	 32283	 0.001983	 0.015456	 0.00029	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32284	 32285	 0.004874	 0.019918	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32284	 32292	 0.004273	 0.024043	 0.00052	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32285	 32287	 0.007326	 0.014992	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32285	 32290	 0.003887	 0.022094	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32285	 86173	 0.011478	 0.044653	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32286	 32287	 0.002574	 0.013712	 0.00024	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32287	 32288	 0.001207	 0.011108	 0.00022	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32288	 32290	 0.01315	 0.030525	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32289	 86167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32289	 86167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32289	 86171	 0.002814	 0.011268	 0.00284	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86167	 32290	 0.003007	 0.017094	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32291	 32297	 0.01645	 0.063997	 0.00107	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86167	 32291	 0.008694	 0.04892	 0.00106	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86167	 32292	 0.004982	 0.028318	 0.00051	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32293	 32308	 0.018291	 0.058653	 0.00145	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32293	 34047	 0.086274	 0.15568	 0.00225	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32294	 32298	 0.001828	 0.008147	 0.00221	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32295	 86168	 0.034174	 0.027045	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32296	 32297	 0.019291	 0.038195	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32296	 32304	 0.032184	 0.02547	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32297	 32305	 0.16796	 0.13293	 0.00167	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32297	 86168	 0.008559	 0.041083	 0.00123	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32298	 32306	 0.006716	 0.033743	 0.00878	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32298	 86168	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32298	 86168	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32299	 33571	 0.004552	 0.028834	 0.00783	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32299	 86169	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32299	 86169	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32299	 86171	 0.002204	 0.026067	 0.00742	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86167	 32300	 0.042296	 0.027382	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32301	 33565	 0.002916	 0.01651	 0.00409	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32301	 33581	 0.006325	 0.040066	 0.01087	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32301	 86170	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32301	 86170	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32301	 86171	 0.000863	 0.013433	 0.00417	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32302	 33017	 0.001136	 0.021148	 1.4066	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32302	 36032	 0.001051	 0.018025	 1.4118	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32302	 86171	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32302	 86171	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86172	 32303	 0.085396	 0.066939	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32306	 86173	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32306	 86173	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32307	 33617	 0.056987	 0.07775	 0.00139	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86173	 32307	 0.007643	 0.02427	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86172	 32308	 0.043503	 0.14513	 0.0023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32309	 32934	 0.008443	 0.029542	 0.00979	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32309	 86174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32309	 86174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32310	 32311	 0.005156	 0.026827	 0.0079	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32311	 33866	 0.004298	 0.025798	 0.00781	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32311	 86175	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32311	 86175	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32312	 32350	 0.011747	 0.064765	 0.01514	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32312	 34111	 0.010336	 0.057358	 0.01744	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32312	 86176	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32312	 86176	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32313	 32314	 0.065033	 0.18654	 0.00287	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86176	 32313	 0.066972	 0.15387	 0.00234	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32313	 86453	 0.11194	 0.32116	 0.00494	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32314	 86616	 0.05554	 0.14395	 0.00272	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32315	 32316	 0.010223	 0.040934	 0.01031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32315	 86177	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32315	 86177	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32316	 32746	 0.010794	 0.042425	 0.0111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32316	 33682	 0.007455	 0.042834	 0.01213	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32316	 86178	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32316	 86178	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32317	 32318	 0.018452	 0.070989	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86178	 32317	 0.025962	 0.079646	 0.00216	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32318	 32319	 0.041204	 0.10479	 0.00166	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32318	 86553	 0.058016	 0.13739	 0.00251	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85357	 32319	 0.084086	 0.24121	 0.00371	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32320	 32326	 0.006427	 0.040706	 0.01105	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32320	 33005	 0.003462	 0.020779	 0.00629	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32320	 86179	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32320	 86179	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32321	 33020	 0.24886	 0.2049	 0.00415	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86179	 32321	 0.1378	 0.13785	 0.00186	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32322	 32323	 0.003073	 0.013836	 0.00368	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32322	 33656	 0.006599	 0.026853	 0.00654	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32323	 32324	 0.001462	 0.007872	 0.00216	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32324	 32445	 0.003785	 0.019018	 0.00495	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32324	 86180	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32324	 86180	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32325	 32423	 0.008008	 0.042446	 0.01417	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32325	 33655	 0.006453	 0.034302	 0.00796	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32326	 33644	 0.005313	 0.030856	 0.00727	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32327	 32360	 0.058797	 0.17699	 0.00346	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32327	 33611	 0.066854	 0.19177	 0.00295	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32327	 86640	 0.07273	 0.18698	 0.00289	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32328	 32333	 0.004714	 0.026154	 0.00795	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32328	 33950	 0.005635	 0.03569	 0.00969	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32329	 32361	 0.10778	 0.27713	 0.00429	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32329	 86181	 0.10098	 0.083119	 0.00168	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32330	 86181	 0.024366	 0.036955	 0.00053	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32331	 32332	 0.013098	 0.018254	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32331	 32337	 0.19759	 0.14972	 0.00206	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32331	 86181	 0.010677	 0.027446	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84779	 32333	 0.030691	 0.12497	 0.03047	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32333	 86181	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32333	 86181	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32334	 32335	 0.021221	 0.054551	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32334	 32336	 0.04313	 0.10013	 0.00149	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32335	 33949	 0.1744	 0.17617	 0.00233	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32335	 86640	 0.060771	 0.20275	 0.00321	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32336	 32338	 0.056917	 0.13215	 0.00197	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86181	 32336	 0.044141	 0.090334	 0.00222	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32337	 32362	 0.17356	 0.12771	 0.00187	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32338	 86353	 0.11225	 0.21752	 0.00468	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32339	 33926	 0.006626	 0.029836	 0.00794	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84758	 32339	 0.005406	 0.033236	 0.00959	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32339	 86182	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32339	 86182	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32340	 32341	 0.09495	 0.17134	 0.00248	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32340	 33606	 0.084725	 0.16606	 0.00249	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32341	 32342	 0.074602	 0.14621	 0.00219	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32341	 32344	 0.061641	 0.17681	 0.00272	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86182	 32341	 0.29856	 0.22627	 0.00312	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32343	 33946	 0.007849	 0.048713	 0.0118	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84769	 32343	 0.003463	 0.025731	 0.00981	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32344	 33608	 0.078173	 0.17881	 0.00437	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32345	 33602	 0.001836	 0.015542	 0.03029	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32345	 33806	 0.001284	 0.015508	 0.03	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32345	 86183	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32345	 86183	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32345	 86570	 0.001984	 0.020056	 0.04551	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32346	 32347	 0.12251	 0.096954	 0.00122	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86183	 32346	 0.034118	 0.087705	 0.00136	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32346	 86518	 0.14574	 0.18968	 0.00265	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32347	 33723	 0.055563	 0.15937	 0.00245	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32347	 86518	 0.052959	 0.11131	 0.00203	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32348	 32990	 0.13994	 0.27714	 0.00407	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32348	 86657	 0.15682	 0.1947	 0.00424	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32349	 32990	 0.052304	 0.2035	 0.0034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32349	 86624	 0.050634	 0.21432	 0.00404	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32351	 32357	 0.001718	 0.011654	 0.02122	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32351	 33338	 0.002353	 0.02426	 0.04713	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32351	 86184	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86185	 32351	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32352	 32353	 0.094266	 0.071421	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85109	 32352	 0.2306	 0.48509	 0.00885	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85621	 32352	 0.093678	 0.24283	 0.00459	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86176	 32352	 0.13444	 0.48066	 0.00955	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32352	 86186	 0.14676	 0.10798	 0.00158	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32352	 86188	 0.26827	 0.19009	 0.00301	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86185	 32353	 0.13587	 0.20817	 0.00292	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32354	 32355	 0.004002	 0.014493	 0.00311	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32354	 32356	 0.003257	 0.010181	 0.00295	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32354	 86186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32354	 86186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86184	 32355	 0.009757	 0.025288	 0.00765	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32355	 86187	 0.004448	 0.012404	 0.0026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32357	 86187	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86188	 32357	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86184	 32359	 0.006381	 0.022327	 0.0074	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32360	 32361	 0.017198	 0.13405	 0.00251	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32360	 33012	 0.010342	 0.078212	 0.0026	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32361	 33985	 0.013541	 0.12606	 0.00244	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32363	 32364	 0.009769	 0.04971	 0.00113	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32363	 86189	 0.011113	 0.034091	 0.00092	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32363	 86348	 0.019938	 0.055153	 0.00128	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32363	 86610	 0.051327	 0.1545	 0.00302	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32364	 32374	 0.024673	 0.082307	 0.0013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32364	 86190	 0.036407	 0.067696	 0.00158	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32365	 32366	 0.00544	 0.021163	 0.00565	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32365	 33830	 0.008219	 0.034788	 0.00783	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32365	 86189	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32365	 86189	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32366	 32370	 0.010572	 0.04233	 0.01067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32366	 86190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32366	 86190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32367	 32369	 0.005061	 0.020897	 0.00494	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32367	 33525	 0.005882	 0.023551	 0.00593	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32367	 86191	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32367	 86191	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86191	 32368	 0.14421	 0.11413	 0.00144	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32369	 32370	 0.001496	 0.006977	 0.00173	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84791	 32369	 0.006438	 0.05484	 0.01369	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32369	 86192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32369	 86192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32370	 86193	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32370	 86193	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86190	 32371	 0.025092	 0.11181	 0.0019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86192	 32371	 0.012933	 0.05993	 0.00115	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86193	 32371	 0.028394	 0.052007	 0.0009	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32372	 32373	 0.00367	 0.017909	 0.00495	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32372	 32377	 0.002785	 0.015999	 0.00453	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32373	 32977	 0.004989	 0.020302	 0.00495	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86193	 32374	 0.026754	 0.080528	 0.00157	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84802	 32375	 0.086345	 0.067683	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84791	 32376	 0.007197	 0.021217	 0.00494	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32376	 86194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32376	 86194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84760	 32377	 0.004349	 0.032587	 0.00795	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32377	 86195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32377	 86195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86192	 32378	 0.006623	 0.053004	 0.00109	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86194	 32378	 0.008345	 0.077685	 0.0015	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32379	 33537	 0.097111	 0.1636	 0.00233	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32380	 86695	 0.056291	 0.089855	 0.00207	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32381	 32382	 0.041159	 0.041571	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32381	 32383	 0.01304	 0.030274	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32381	 32388	 0.063976	 0.098007	 0.00138	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32383	 32384	 0.051319	 0.056445	 0.00075	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32383	 32386	 0.082707	 0.065454	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32383	 86695	 0.058485	 0.16597	 0.00261	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32384	 32385	 0.025387	 0.049755	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32385	 32386	 0.067624	 0.1036	 0.00145	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32385	 34070	 0.059049	 0.11692	 0.00172	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32385	 34130	 0.035942	 0.083445	 0.00124	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32386	 34063	 0.074144	 0.12491	 0.00178	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32386	 34069	 0.099375	 0.1093	 0.00146	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32387	 32390	 0.028984	 0.074507	 0.00115	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32388	 32389	 0.005832	 0.025696	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32388	 88453	 0.004844	 0.024228	 0.00043	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32389	 34063	 0.009228	 0.035501	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32390	 34062	 0.023234	 0.035593	 0.0005	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32390	 34064	 0.045638	 0.090361	 0.00133	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32390	 34067	 0.076512	 0.077281	 0.00102	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32390	 86695	 0.063153	 0.24573	 0.0041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32391	 86452	 0.04836	 0.13495	 0.02835	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85620	 32392	 0.35669	 0.25279	 0.004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32393	 32394	 0.000857	 0.002998	 0.00099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32393	 32395	 0.000683	 0.003314	 0.00076	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32394	 86196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32394	 86196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32395	 32462	 0.000922	 0.005081	 0.00119	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32395	 86197	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32395	 86197	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32396	 32397	 0.001864	 0.010595	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32396	 32399	 0.008399	 0.006584	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32396	 32438	 0.008511	 0.01976	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86196	 32396	 0.001179	 0.007251	 0.00013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32397	 32416	 0.002849	 0.013745	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32398	 32403	 0.002979	 0.008453	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32398	 32460	 0.00288	 0.010083	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86197	 32398	 0.00517	 0.0143	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32400	 32404	 0.012009	 0.009504	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32401	 32405	 0.011815	 0.00935	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32402	 32415	 0.020359	 0.016111	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32403	 32429	 0.008389	 0.020009	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32404	 32408	 0.004651	 0.010637	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32404	 32460	 0.002374	 0.007643	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32405	 32407	 0.022996	 0.017639	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32406	 32407	 0.009202	 0.012094	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32406	 32430	 0.006275	 0.020933	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32406	 32460	 0.00394	 0.009398	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32408	 32412	 0.004264	 0.01096	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32409	 32410	 0.003806	 0.007999	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86197	 32409	 0.004956	 0.009215	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32410	 32430	 0.008035	 0.018654	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32411	 32429	 0.006813	 0.017514	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32411	 32430	 0.045501	 0.036009	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32412	 32413	 0.003545	 0.009112	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32413	 32415	 0.004562	 0.025931	 0.00047	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32413	 32417	 0.014622	 0.011461	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32413	 32432	 0.00415	 0.022714	 0.00044	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32413	 86198	 0.010598	 0.041228	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32413	 86198	 0.010598	 0.041228	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32414	 32415	 0.003251	 0.016259	 0.00029	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32414	 32416	 0.004451	 0.019835	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32414	 32431	 0.001702	 0.015781	 0.00035	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32418	 32433	 0.026454	 0.017126	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32419	 86198	 0.013144	 0.018318	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32420	 86198	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32420	 86198	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32420	 86200	 0.001429	 0.008369	 0.00228	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32421	 32425	 0.022101	 0.01749	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32422	 86199	 9.6e-05	 0.007684	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86200	 32423	 0.000493	 0.003308	 0.0008	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32423	 86202	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32423	 86202	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32424	 86203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32424	 86203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86198	 32425	 0.002492	 0.017105	 0.00031	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86201	 32425	 0.006173	 0.020593	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86203	 32425	 0.007659	 0.015673	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32426	 32427	 0.004788	 0.015971	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86202	 32426	 0.008652	 0.020087	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86203	 32426	 0.003158	 0.017949	 0.00032	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32427	 32447	 0.004207	 0.022413	 0.00039	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	86202	 32427	 0.009981	 0.020425	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32428	 32435	 0.006615	 0.020293	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86201	 32428	 0.002512	 0.019582	 0.00037	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32428	 86206	 0.037559	 0.087187	 0.00166	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86201	 32430	 0.0071	 0.054689	 0.00105	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32431	 32455	 0.034461	 0.064078	 0.0015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32431	 34264	 0.04281	 0.16656	 0.00278	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32431	 34264	 0.04281	 0.16656	 0.00278	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86201	 32431	 0.01559	 0.12009	 0.0023	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32432	 32454	 0.006258	 0.035575	 0.00064	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86198	 32433	 0.02092	 0.028517	 0.00063	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32434	 33006	 0.082871	 0.21306	 0.0033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32434	 86353	 0.068937	 0.24143	 0.00669	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32434	 86548	 0.18009	 0.46322	 0.00717	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32436	 32462	 0.001416	 0.007117	 0.00185	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32436	 86204	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32436	 86204	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86204	 32437	 0.014575	 0.024552	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32438	 34268	 0.024874	 0.23161	 0.00448	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86196	 32438	 0.001821	 0.011194	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32439	 32442	 0.003568	 0.022596	 0.00613	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32439	 86205	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32439	 86205	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32439	 86357	 0.003571	 0.030032	 0.0089	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32440	 86358	 0.12569	 0.092476	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32441	 33654	 0.01524	 0.075162	 0.02033	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84779	 32441	 0.009522	 0.062269	 0.01584	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32442	 32446	 0.002468	 0.014453	 0.00394	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32443	 32444	 0.013064	 0.033224	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32443	 32447	 0.00763	 0.029681	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86180	 32444	 0.023405	 0.04587	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32445	 32446	 0.003059	 0.014267	 0.00353	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32445	 86206	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32445	 86206	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32448	 32461	 0.206	 0.1384	 0.00244	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86201	 32448	 0.034977	 0.06311	 0.00091	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32449	 32451	 0.021491	 0.038387	 0.00057	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32449	 32457	 0.01814	 0.063471	 0.00131	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86198	 32449	 0.010901	 0.044553	 0.0009	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32450	 32451	 0.087531	 0.056669	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32452	 32457	 0.13046	 0.10325	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32453	 32455	 0.007316	 0.024407	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32453	 32456	 0.011154	 0.033573	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32454	 32455	 0.008345	 0.034834	 0.00101	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32455	 34263	 0.029791	 0.11015	 0.00204	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32455	 34263	 0.029791	 0.11015	 0.00204	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32456	 32457	 0.009991	 0.032971	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32458	 32459	 0.001365	 0.00733	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86196	 32458	 0.001807	 0.010982	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32459	 32460	 0.001002	 0.006879	 0.00013	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32462	 86207	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32462	 86207	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32463	 86208	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32463	 86208	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32464	 32466	 0.18696	 0.14657	 0.00188	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32465	 33764	 0.002823	 0.023743	 0.00703	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32465	 33881	 0.035393	 0.18841	 0.0438	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32465	 33972	 0.014566	 0.07763	 0.02179	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32465	 86209	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32465	 86209	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32466	 33790	 0.1918	 0.12419	 0.00236	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32467	 33796	 0.005567	 0.04339	 0.00081	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86209	 32467	 0.003461	 0.028795	 0.00054	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32468	 33792	 0.14874	 0.099919	 0.00176	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32469	 32473	 0.038577	 0.099169	 0.00153	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32469	 33048	 0.036331	 0.074349	 0.00183	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32470	 34073	 0.006937	 0.027773	 0.007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84776	 32470	 0.005353	 0.051399	 0.01495	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32471	 32472	 0.10242	 0.081053	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32472	 32473	 0.031525	 0.052364	 0.00111	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84777	 32473	 0.02299	 0.1225	 0.00215	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84777	 32474	 0.14754	 0.11677	 0.00147	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32475	 86211	 0.029833	 0.068228	 0.00167	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32475	 86212	 0.064545	 0.14286	 0.00234	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32475	 86614	 0.021883	 0.084189	 0.00144	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32476	 32477	 0.029464	 0.090389	 0.00245	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32477	 32483	 0.028366	 0.072917	 0.00113	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32478	 32649	 0.004474	 0.029049	 0.05788	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32478	 33385	 0.0035	 0.039336	 0.07202	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84798	 32478	 0.005329	 0.069994	 0.15417	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32478	 86210	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32478	 86210	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32479	 32480	 0.002635	 0.015431	 0.0042	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86210	 32479	 0.002927	 0.026583	 0.00866	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32479	 86211	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32479	 86211	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32480	 33077	 0.00371	 0.021315	 0.00604	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32480	 86212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32480	 86212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32481	 86213	 0.040149	 0.048945	 0.00078	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32482	 32486	 0.004693	 0.015308	 0.00406	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86210	 32482	 0.002308	 0.014321	 0.00347	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32482	 86213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32482	 86213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32483	 32497	 0.019782	 0.045919	 0.00087	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86213	 32483	 0.050142	 0.093237	 0.00218	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86213	 32484	 0.029684	 0.085138	 0.00131	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32484	 86215	 0.083342	 0.10954	 0.0015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32485	 86214	 0.06177	 0.061952	 0.001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32486	 32487	 0.003174	 0.009358	 0.00218	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32486	 86214	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32486	 86214	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32487	 32488	 0.002538	 0.00691	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32488	 32489	 0.003343	 0.008835	 0.00207	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32489	 32621	 0.002357	 0.00676	 0.00166	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32489	 86215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32489	 86215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32490	 32491	 0.009264	 0.023559	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32490	 32492	 0.007182	 0.023958	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32491	 32620	 0.010306	 0.012564	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32491	 32635	 0.034791	 0.03514	 0.00047	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32492	 32494	 0.011278	 0.028992	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32492	 86216	 0.013371	 0.044123	 0.00071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32493	 32499	 0.001562	 0.006841	 0.00235	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32493	 86216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32493	 86216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32494	 32495	 0.037702	 0.024408	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32494	 32497	 0.008657	 0.02888	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86216	 32494	 0.008079	 0.018753	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32494	 86217	 0.008003	 0.03905	 0.00067	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32496	 32498	 0.043453	 0.03406	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32498	 86217	 0.025733	 0.059743	 0.00089	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32499	 32500	 0.001618	 0.008879	 0.00235	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32499	 86217	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32499	 86217	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32500	 86218	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32500	 86218	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32501	 32504	 0.004828	 0.012412	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32501	 32514	 0.007213	 0.016744	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32502	 32512	 0.015031	 0.011059	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32503	 32511	 0.001125	 0.00337	 0.00076	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32503	 86219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32503	 86219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32504	 32509	 0.013184	 0.013462	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32504	 86220	 0.005871	 0.01556	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32505	 32511	 0.002048	 0.005874	 0.00145	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32505	 86220	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32505	 86220	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32505	 86222	 0.001954	 0.011817	 0.00302	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32506	 32510	 0.013756	 0.008906	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86220	 32506	 0.026676	 0.019627	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86220	 32507	 0.026001	 0.020577	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32508	 32509	 0.006944	 0.015953	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86220	 32508	 0.003572	 0.008102	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32509	 32520	 0.008161	 0.050173	 0.0009	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86220	 32509	 0.010135	 0.020829	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32511	 86221	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32511	 86221	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86221	 32512	 0.021887	 0.017321	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32513	 32514	 0.029615	 0.019173	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32514	 32527	 0.013074	 0.025884	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32514	 86225	 0.015067	 0.034979	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32515	 32516	 0.000281	 0.002995	 0.00543	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32515	 86222	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32515	 86222	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32516	 32517	 0.000439	 0.004526	 0.00879	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32516	 86223	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32516	 86223	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32517	 33810	 0.000644	 0.00712	 0.01647	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32517	 86224	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32517	 86224	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32518	 32519	 0.002113	 0.019903	 0.00042	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32518	 33811	 0.006876	 0.057206	 0.00108	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86223	 32518	 0.008047	 0.035856	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86224	 32519	 0.010544	 0.041019	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86224	 32519	 0.010544	 0.041019	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32520	 32521	 0.014776	 0.037983	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32520	 33595	 0.065821	 0.11088	 0.00158	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84810	 32520	 0.006828	 0.038813	 0.0007	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32521	 86225	 0.017623	 0.037766	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84809	 32522	 0.003492	 0.026169	 0.00638	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32522	 86225	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32522	 86225	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86225	 32523	 0.048932	 0.035373	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32524	 33811	 0.003873	 0.023445	 0.00073	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86220	 32524	 0.003276	 0.025238	 0.00048	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86219	 32525	 0.019164	 0.045379	 0.00083	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32526	 32527	 0.011933	 0.01862	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86219	 32526	 0.015481	 0.02471	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32528	 32529	 0.009411	 0.024193	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86225	 32528	 0.021356	 0.055348	 0.00105	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32529	 32530	 0.011937	 0.024427	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32530	 33814	 0.022639	 0.12869	 0.00233	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32530	 33817	 0.013554	 0.077049	 0.00139	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86225	 32530	 0.030492	 0.091777	 0.00179	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32531	 32991	 0.007374	 0.042292	 0.01406	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32531	 33874	 0.017996	 0.074319	 0.01759	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32531	 33881	 0.014136	 0.047631	 0.01184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32532	 32559	 0.002233	 0.006583	 0.00153	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32532	 86226	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32532	 86226	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32533	 32534	 0.015366	 0.012044	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32534	 33256	 0.036683	 0.040346	 0.00054	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32535	 32536	 0.007713	 0.017496	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32535	 86229	 0.004519	 0.020136	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32536	 86229	 0.009987	 0.034943	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32536	 86230	 0.010835	 0.036145	 0.00057	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32537	 32539	 0.001553	 0.006043	 0.00161	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32537	 32562	 0.001441	 0.00661	 0.00169	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32537	 86227	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32537	 86227	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32538	 32540	 0.003232	 0.009012	 0.00189	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32538	 86228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32538	 86228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32539	 33178	 0.002487	 0.01371	 0.0032	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32539	 86229	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32539	 86229	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32539	 86423	 0.005409	 0.045496	 0.01348	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32540	 32541	 0.001176	 0.004709	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32540	 32543	 0.001123	 0.007113	 0.00193	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32540	 86230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32540	 86230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32541	 32549	 0.001452	 0.005521	 0.00155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86230	 32542	 0.044197	 0.034644	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32543	 32916	 0.002918	 0.011875	 0.00289	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32543	 86231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32543	 86231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32544	 33543	 0.052811	 0.038855	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86231	 32544	 0.01815	 0.042979	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32545	 32916	 0.007026	 0.027335	 0.0073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32545	 86232	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32545	 86232	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32545	 86234	 0.000529	 0.006781	 0.00202	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32546	 32575	 0.022395	 0.017723	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32547	 32548	 0.006048	 0.01538	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86227	 32547	 0.010118	 0.026009	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86228	 32547	 0.006503	 0.015916	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32548	 32561	 0.016055	 0.012706	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32548	 32564	 0.007685	 0.025637	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86227	 32548	 0.02025	 0.040093	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32548	 86235	 0.005651	 0.021742	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32549	 86233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32549	 86233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32549	 86234	 0.000995	 0.004564	 0.00117	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32550	 33802	 0.005296	 0.036495	 0.06446	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32550	 33804	 0.005998	 0.040023	 0.07549	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32550	 86234	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86235	 32550	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32550	 86427	 0.001556	 0.016594	 0.03007	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32551	 32552	 0.000811	 0.004297	 0.00143	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32551	 33263	 0.001136	 0.006653	 0.00181	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32552	 32559	 0.000343	 0.00217	 0.00059	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32552	 86236	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32552	 86236	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32553	 32563	 0.006933	 0.019179	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86236	 32553	 0.010097	 0.019991	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32553	 86237	 0.004353	 0.013353	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32554	 33263	 0.002108	 0.009669	 0.00248	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32554	 86237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32554	 86237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32555	 32563	 0.015543	 0.030773	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86237	 32555	 0.004599	 0.024506	 0.00043	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32555	 86238	 0.004273	 0.01496	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32555	 86361	 0.025125	 0.058331	 0.00087	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32555	 86431	 0.024218	 0.062256	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32556	 32557	 0.00076	 0.004596	 0.00117	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32556	 33027	 0.002757	 0.015612	 0.00387	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32556	 86238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32556	 86238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32557	 32570	 0.001164	 0.006815	 0.00186	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32558	 32566	 0.001908	 0.005793	 0.00127	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32558	 32577	 0.001135	 0.003399	 0.00077	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32559	 32562	 0.000998	 0.004445	 0.00121	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86226	 32560	 0.021533	 0.01394	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32563	 32564	 0.004288	 0.015003	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32565	 86239	 0.005041	 0.012957	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32565	 86242	 0.008385	 0.021554	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32566	 33027	 0.001726	 0.010281	 0.0027	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32566	 86239	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32566	 86239	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32567	 32572	 0.053123	 0.043725	 0.00089	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32567	 32579	 0.011042	 0.036835	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32567	 33553	 0.021914	 0.055731	 0.00088	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32568	 33043	 0.010707	 0.037463	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32568	 86519	 0.019038	 0.047253	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32569	 33553	 0.068665	 0.12265	 0.00181	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86232	 32569	 0.009885	 0.025618	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86235	 32569	 0.008383	 0.031446	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86234	 32570	 0.000852	 0.00499	 0.00136	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32570	 86240	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32570	 86240	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32571	 32577	 0.002199	 0.005902	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32571	 86241	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32571	 86241	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32572	 32573	 0.007193	 0.01849	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86241	 32572	 0.014288	 0.034973	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32573	 32574	 0.01459	 0.028593	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32574	 32575	 0.011708	 0.021044	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32575	 32576	 0.035579	 0.028157	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86232	 32575	 0.018274	 0.036181	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32577	 86242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32577	 86242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32578	 32580	 0.005662	 0.014398	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86242	 32578	 0.008532	 0.019354	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32579	 32580	 0.016149	 0.024738	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32579	 33042	 0.028218	 0.072537	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32581	 33266	 0.002443	 0.009779	 0.00246	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32581	 86243	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32581	 86243	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32582	 32583	 0.014302	 0.065621	 0.01681	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32582	 86244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32582	 86244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32584	 32593	 0.001709	 0.011465	 0.00277	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32584	 33820	 0.001812	 0.011596	 0.0039	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32585	 32586	 0.00818	 0.02512	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32585	 32587	 0.030401	 0.031985	 0.00047	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32585	 32590	 0.013317	 0.038194	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32585	 32597	 0.025295	 0.027012	 0.00057	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32585	 86251	 0.033746	 0.095763	 0.0015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86161	 32586	 0.012149	 0.03727	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32588	 32598	 0.007344	 0.016795	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86218	 32588	 0.010042	 0.039067	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32589	 32603	 0.001995	 0.008442	 0.0019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32589	 32604	 0.001905	 0.007627	 0.00192	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32590	 86245	 0.014871	 0.033363	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32591	 32592	 0.001607	 0.008073	 0.0021	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32591	 32599	 0.001553	 0.007803	 0.00203	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32592	 32593	 0.002042	 0.012689	 0.00358	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32592	 32603	 0.001271	 0.006466	 0.00234	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32592	 86245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32592	 86245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32593	 86246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32593	 86246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32594	 32595	 0.026314	 0.017036	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32595	 32596	 0.01656	 0.016909	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86217	 32596	 0.014443	 0.037128	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32598	 86247	 0.01227	 0.028486	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32599	 32601	 0.001277	 0.005857	 0.0015	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32599	 86247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32599	 86247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32600	 32601	 0.001198	 0.006343	 0.00161	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32600	 32614	 0.001112	 0.005299	 0.00154	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32602	 32603	 0.002184	 0.008744	 0.0022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32602	 86248	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32602	 86248	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32604	 32607	 0.001374	 0.008448	 0.00244	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32604	 32698	 0.001437	 0.007014	 0.00194	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32604	 86249	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32604	 86249	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32605	 32658	 0.008016	 0.031186	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86249	 32605	 0.006953	 0.027826	 0.00059	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32606	 32702	 0.007858	 0.028071	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32606	 86251	 0.047859	 0.062902	 0.00086	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32606	 86608	 0.006762	 0.034711	 0.00066	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32607	 32610	 0.00205	 0.010478	 0.00286	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86246	 32608	 0.012676	 0.029123	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32608	 86250	 0.014667	 0.033696	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32609	 32610	 0.001371	 0.007265	 0.00242	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32609	 33825	 0.001258	 0.007229	 0.00205	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32609	 86250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32609	 86250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32610	 86251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32610	 86251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86216	 32611	 0.004308	 0.023051	 0.0007	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32611	 86253	 0.006988	 0.03114	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32612	 32620	 0.01526	 0.016931	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32612	 86252	 0.017972	 0.030275	 0.00043	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32613	 32614	 0.001525	 0.006997	 0.00179	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32613	 32653	 0.001584	 0.006344	 0.0016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32613	 86252	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32613	 86252	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32614	 86253	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32614	 86253	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32615	 32634	 0.001457	 0.006685	 0.00171	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32615	 86254	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32615	 86254	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32615	 86261	 0.002631	 0.011994	 0.00381	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32616	 32651	 0.018513	 0.072023	 0.0012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32616	 33243	 0.038508	 0.030475	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32616	 86259	 0.032096	 0.032104	 0.00043	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32616	 86419	 0.013314	 0.043936	 0.00071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32617	 32629	 0.001526	 0.007525	 0.00203	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32617	 33248	 0.001077	 0.005097	 0.00123	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32618	 32642	 0.029415	 0.019043	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32618	 32647	 0.03443	 0.025331	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32619	 32621	 0.001629	 0.005897	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32619	 32634	 0.001218	 0.004264	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32619	 86255	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32619	 86255	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86254	 32622	 0.034185	 0.027054	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32623	 32626	 0.00113	 0.00662	 0.0018	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32623	 33288	 0.002737	 0.0113	 0.00267	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32623	 86256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32623	 86256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32624	 86257	 0.024645	 0.019504	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32625	 32628	 0.001612	 0.008398	 0.0022	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32625	 86257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32625	 86257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32625	 86261	 0.001553	 0.00965	 0.00272	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32626	 86258	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32626	 86258	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32626	 86261	 0.002514	 0.014727	 0.00401	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86258	 32627	 0.028126	 0.022046	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32628	 32629	 0.000984	 0.006108	 0.00148	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32629	 86259	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32629	 86259	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86256	 32630	 0.029347	 0.023224	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32631	 32632	 0.028535	 0.022582	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32631	 33238	 0.022903	 0.06569	 0.00101	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86258	 32631	 0.006129	 0.032655	 0.00057	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32633	 32639	 0.006673	 0.01526	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32633	 33245	 0.035257	 0.036001	 0.00056	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32633	 86418	 0.015044	 0.034927	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86252	 32635	 0.049545	 0.050591	 0.00079	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86255	 32636	 0.005893	 0.015149	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86256	 32636	 0.011538	 0.029659	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86256	 32637	 0.03089	 0.02233	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32638	 32647	 0.01682	 0.011914	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32639	 32673	 0.008217	 0.019077	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32639	 86264	 0.01739	 0.053403	 0.001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32640	 32645	 0.010393	 0.010396	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32641	 32642	 0.00788	 0.018295	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32641	 32644	 0.006515	 0.018687	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32642	 32647	 0.012147	 0.018608	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32643	 32644	 0.025066	 0.018442	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32644	 32651	 0.003664	 0.017878	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86258	 32644	 0.01513	 0.058861	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32644	 86260	 0.019416	 0.03225	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32645	 86260	 0.00294	 0.007557	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32646	 32657	 0.002041	 0.007001	 0.00168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32646	 86260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32646	 86260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32647	 86267	 0.009687	 0.02294	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86260	 32648	 0.002976	 0.018296	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32648	 86267	 0.001907	 0.010204	 0.00031	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84766	 32649	 0.00341	 0.036376	 0.07401	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84766	 32649	 0.00341	 0.036376	 0.07401	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32649	 86261	 0.000105	 0.008384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86262	 32649	 0.000298	 0.020873	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32650	 32651	 0.002849	 0.013905	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86262	 32650	 0.002231	 0.015313	 0.00028	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32651	 32652	 0.019549	 0.049716	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86262	 32651	 0.005078	 0.028863	 0.00052	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32651	 86264	 0.01645	 0.052971	 0.0009	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86253	 32652	 0.011309	 0.043996	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86262	 32652	 0.018833	 0.02885	 0.00041	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86261	 32653	 0.001306	 0.005134	 0.00134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86262	 32654	 0.019245	 0.044674	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32655	 32658	 0.015662	 0.035983	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86247	 32655	 0.032595	 0.083791	 0.0013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86262	 32655	 0.072644	 0.068125	 0.00105	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32656	 32659	 0.002114	 0.007369	 0.00171	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86261	 32656	 0.003097	 0.010624	 0.00255	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86261	 32657	 0.00276	 0.014674	 0.0034	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32658	 86265	 0.013595	 0.038993	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32659	 32663	 0.003445	 0.00866	 0.00224	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32659	 86263	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32659	 86263	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86263	 32660	 0.022491	 0.020153	 0.00041	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32661	 32665	 0.018297	 0.01925	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32661	 86265	 0.012319	 0.031667	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32662	 32667	 0.003224	 0.018882	 0.00514	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86261	 32662	 0.005235	 0.021302	 0.00519	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32662	 86264	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32662	 86264	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32663	 86265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32663	 86265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86265	 32664	 0.001815	 0.016899	 0.00033	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32664	 86268	 0.001488	 0.012664	 0.00033	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32666	 32669	 0.008267	 0.019192	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86264	 32666	 0.006676	 0.025971	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32666	 86266	 0.012853	 0.021436	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32666	 86268	 0.007103	 0.01649	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32667	 32685	 0.001655	 0.010484	 0.00285	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32668	 32672	 0.001336	 0.004356	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32668	 86266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32668	 86266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32669	 32671	 0.017879	 0.019664	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32669	 32677	 0.010159	 0.023338	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86266	 32669	 0.013501	 0.02436	 0.00035	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32670	 32671	 0.023321	 0.017158	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86266	 32670	 0.00383	 0.014899	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32670	 86271	 0.005896	 0.016731	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32671	 32679	 0.018066	 0.034598	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32671	 86271	 0.026589	 0.026856	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32672	 86267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32672	 86267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86264	 32673	 0.0139	 0.040875	 0.00084	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86267	 32673	 0.004499	 0.017501	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32673	 86271	 0.003872	 0.018894	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32674	 86268	 0.018953	 0.014999	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32675	 32676	 0.001914	 0.006961	 0.00213	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32675	 86268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32675	 86268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32676	 32686	 0.001383	 0.00659	 0.00191	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32676	 86269	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32676	 86269	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32677	 32679	 0.019773	 0.026953	 0.0006	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86269	 32677	 0.010339	 0.023196	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32678	 32683	 0.001857	 0.007223	 0.00193	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32678	 33223	 0.001363	 0.006933	 0.00251	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84774	 32678	 0.000136	 0.002075	 0.00067	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32678	 86270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32678	 86270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86270	 32679	 0.008181	 0.02729	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32680	 86271	 0.022372	 0.014484	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32681	 32683	 0.001134	 0.003968	 0.00131	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32681	 86271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32681	 86271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32682	 86272	 0.025374	 0.019889	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32683	 86272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32683	 86272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86272	 32684	 0.016244	 0.011951	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32685	 32688	 0.001273	 0.007909	 0.00223	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32685	 86273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32685	 86273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32686	 32687	 0.001986	 0.009692	 0.00268	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32687	 32690	 0.001526	 0.00795	 0.00209	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32688	 86345	 0.001242	 0.008331	 0.00201	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32689	 86274	 0.009145	 0.023507	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32690	 86274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32690	 86274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32690	 86406	 0.001197	 0.009618	 0.0027	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32691	 32692	 0.006853	 0.021022	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86249	 32691	 0.034527	 0.14829	 0.00271	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86274	 32691	 0.006276	 0.023545	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32691	 86409	 0.006009	 0.034155	 0.00062	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84775	 32692	 0.011367	 0.040606	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86273	 32693	 0.00578	 0.01928	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32693	 86275	 0.012489	 0.041215	 0.00067	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32694	 32695	 0.001231	 0.00521	 0.00117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32694	 32698	 0.001291	 0.006152	 0.00178	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32694	 86275	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32694	 86275	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32695	 32697	 0.002458	 0.010404	 0.00234	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32696	 32697	 0.001705	 0.006825	 0.00172	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32696	 32703	 0.003136	 0.012326	 0.00322	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32696	 86345	 0.000817	 0.007847	 0.00228	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32699	 32701	 0.003571	 0.009721	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32699	 32703	 0.0023	 0.00813	 0.00183	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86249	 32700	 0.009414	 0.041948	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32700	 86276	 0.004109	 0.018386	 0.00038	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32701	 86276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32701	 86276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86275	 32702	 0.032811	 0.084344	 0.00131	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32703	 33836	 0.001336	 0.00808	 0.00206	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32704	 32708	 0.00525	 0.03955	 0.01097	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32704	 86277	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32704	 86277	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32704	 86653	 0.0058	 0.04975	 0.01416	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86277	 32705	 0.036691	 0.16419	 0.00338	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32706	 86281	 0.13497	 0.10682	 0.00134	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32707	 32712	 0.007459	 0.025589	 0.00613	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32707	 86278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32707	 86278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32708	 32710	 0.003883	 0.024597	 0.00668	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32708	 86279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32708	 86279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86279	 32709	 0.079842	 0.10884	 0.00241	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32710	 32711	 0.004582	 0.024266	 0.00615	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32710	 86280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32710	 86280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32711	 32712	 0.003742	 0.012838	 0.00308	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32712	 86281	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32712	 86281	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32713	 32716	 0.080269	 0.12297	 0.00173	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32713	 32717	 0.064057	 0.16468	 0.00255	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32713	 34018	 0.071997	 0.12991	 0.00188	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32713	 34152	 0.091197	 0.21599	 0.00395	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32714	 32715	 0.050005	 0.12717	 0.00201	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32714	 34154	 0.039491	 0.11327	 0.00174	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32715	 32716	 0.083665	 0.083913	 0.00136	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84821	 32716	 0.10371	 0.38364	 0.00711	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32716	 86283	 0.027002	 0.076626	 0.0012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86178	 32717	 0.076355	 0.25202	 0.00408	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32717	 86291	 0.040163	 0.093231	 0.00178	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32717	 86661	 0.18453	 0.30784	 0.00448	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32718	 32719	 0.004916	 0.0141	 0.00347	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32718	 86282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32718	 86282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32719	 86283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32719	 86283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32720	 32721	 0.008162	 0.021576	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86283	 32720	 0.017895	 0.036622	 0.0009	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86283	 32721	 0.022029	 0.056628	 0.00088	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32721	 86284	 0.03502	 0.11683	 0.00185	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32722	 33719	 0.009341	 0.038012	 0.00926	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32722	 86284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32722	 86284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32723	 33897	 0.008039	 0.029441	 0.00074	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32723	 86285	 0.006621	 0.034431	 0.00075	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32724	 32725	 0.000887	 0.005024	 0.00125	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32724	 32735	 0.000673	 0.005961	 0.00159	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32724	 86285	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32724	 86285	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32725	 32742	 0.000815	 0.004773	 0.0013	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32726	 86290	 0.00956	 0.018927	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32727	 32733	 0.006165	 0.028992	 0.00054	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32727	 86290	 0.00621	 0.024157	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32728	 86290	 0.029708	 0.02351	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32729	 86290	 0.017951	 0.035181	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32730	 32732	 0.00233	 0.006049	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32730	 32740	 0.001539	 0.006698	 0.00191	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32730	 86286	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32730	 86286	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32731	 86288	 0.066533	 0.060028	 0.001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32732	 86287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32732	 86287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86287	 32733	 0.006209	 0.021739	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32733	 86289	 0.007563	 0.042993	 0.00078	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32734	 32735	 0.001626	 0.0103	 0.0028	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32734	 86288	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32734	 86288	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32735	 86289	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32735	 86289	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32736	 32737	 0.005892	 0.021434	 0.00656	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32736	 33659	 0.007098	 0.033833	 0.0098	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32737	 86556	 0.009571	 0.03762	 0.00984	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32738	 32739	 0.00315	 0.017287	 0.00457	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32738	 32741	 0.00314	 0.017229	 0.00455	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32738	 33923	 0.006116	 0.024488	 0.00617	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32739	 86556	 0.005243	 0.02477	 0.00793	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32740	 32741	 0.001664	 0.009284	 0.00237	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32742	 33898	 0.001299	 0.007857	 0.002	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32742	 86290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32742	 86290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32744	 32746	 0.007546	 0.031156	 0.00737	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32744	 34019	 0.010443	 0.053144	 0.01927	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32744	 86291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32744	 86291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86291	 32745	 0.043318	 0.10056	 0.00191	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32747	 32748	 0.002705	 0.01877	 0.00536	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84793	 32747	 0.002852	 0.018651	 0.00474	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32747	 86292	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32747	 86292	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32748	 32750	 0.001621	 0.015254	 0.00462	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84801	 32748	 0.00138	 0.017679	 0.00528	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32749	 86293	 0.080699	 0.063865	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32750	 86293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32750	 86293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32750	 86294	 0.000896	 0.007457	 0.00226	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32751	 86294	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86295	 32751	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32751	 86422	 0.003193	 0.035228	 0.06696	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32752	 32756	 0.007473	 0.042482	 0.00077	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86295	 32752	 0.004236	 0.027571	 0.00056	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32753	 86363	 0.03151	 0.050296	 0.00116	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32754	 32755	 0.090609	 0.071025	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32755	 32756	 0.012805	 0.033851	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32755	 32757	 0.011965	 0.024589	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32756	 86364	 0.037738	 0.095977	 0.00152	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32757	 86363	 0.027691	 0.046648	 0.00066	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32758	 32759	 0.003152	 0.020306	 0.00532	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32758	 32762	 0.004487	 0.020369	 0.00707	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32759	 32760	 0.002579	 0.015104	 0.00411	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32760	 33959	 0.00617	 0.030426	 0.00823	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32760	 86296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32760	 86296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32761	 32762	 0.003689	 0.015612	 0.00351	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32761	 32764	 0.002325	 0.014292	 0.00412	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32761	 32766	 0.007812	 0.027613	 0.00622	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86294	 32762	 0.003024	 0.010581	 0.00351	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32762	 86297	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32762	 86297	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86297	 32763	 0.046091	 0.036476	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84793	 32764	 0.003056	 0.029344	 0.00854	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32764	 86298	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32764	 86298	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86298	 32765	 0.084551	 0.092999	 0.00124	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32766	 33713	 0.011163	 0.038296	 0.00918	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32767	 32769	 0.044439	 0.17098	 0.00292	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32767	 86676	 0.045201	 0.15817	 0.00328	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32768	 32769	 0.10033	 0.15217	 0.00218	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86172	 32768	 0.055535	 0.14277	 0.00221	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32769	 33842	 0.018581	 0.072287	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32769	 33991	 0.22113	 0.14319	 0.00273	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32770	 32773	 0.003328	 0.020675	 0.00584	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32770	 32942	 0.004185	 0.026003	 0.00734	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32771	 34150	 0.037499	 0.18971	 0.0033	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32771	 86299	 0.01794	 0.1103	 0.00199	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32772	 32942	 0.014296	 0.037784	 0.00884	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32772	 86299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32772	 86299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32773	 32969	 0.058986	 0.15179	 0.03763	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32773	 34013	 0.020309	 0.13092	 0.03436	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32773	 34045	 0.009818	 0.056416	 0.01598	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32773	 86300	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32773	 86300	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86300	 32774	 0.062385	 0.086946	 0.00149	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86300	 32775	 0.065817	 0.089721	 0.00199	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32775	 86338	 0.069109	 0.22166	 0.00549	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32775	 86660	 0.17819	 0.40446	 0.00807	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32776	 32778	 0.038338	 0.082158	 0.00144	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32776	 32779	 0.20234	 0.16015	 0.00202	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32776	 86695	 0.63789	 0.50552	 0.00636	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32777	 32779	 0.051914	 0.050998	 0.00086	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32777	 34072	 0.15056	 0.15208	 0.00201	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32778	 32779	 0.12476	 0.13325	 0.00282	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32778	 88542	 0.064415	 0.13183	 0.00324	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32780	 86614	 0.12534	 0.16475	 0.00226	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32781	 33074	 0.025991	 0.068888	 0.00175	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32781	 33491	 0.029989	 0.092098	 0.00173	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32781	 86555	 0.063525	 0.13352	 0.00243	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32782	 33071	 0.003249	 0.020795	 0.007	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32782	 33850	 0.005835	 0.032016	 0.00846	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32783	 32786	 0.019233	 0.074822	 0.00125	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32783	 86303	 0.034302	 0.11443	 0.00181	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32784	 33951	 0.072416	 0.14193	 0.00213	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32784	 86301	 0.029654	 0.060686	 0.00149	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32785	 32787	 0.0004	 0.006122	 0.02138	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32785	 86301	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32785	 86301	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32785	 87376	 0.003411	 0.0416	 0.15541	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32786	 33354	 0.088069	 0.34273	 0.00572	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86301	 32786	 0.020193	 0.077689	 0.00133	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86301	 32786	 0.020193	 0.077689	 0.00133	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32786	 86303	 0.014418	 0.053311	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32786	 86303	 0.014418	 0.053311	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32786	 86568	 0.17151	 0.31907	 0.00747	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32787	 86302	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86303	 32787	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86301	 32788	 0.022211	 0.15474	 0.00364	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86302	 32789	 0.005451	 0.035116	 0.00921	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32790	 86325	 0.016832	 0.01332	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32791	 32793	 0.008083	 0.012382	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32791	 86325	 0.013225	 0.016122	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32792	 32795	 0.015691	 0.012418	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32793	 32794	 0.006848	 0.015897	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32793	 32795	 0.004929	 0.011441	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32793	 86389	 0.004188	 0.00857	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32794	 32795	 0.001979	 0.0077	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32794	 33141	 0.013798	 0.018135	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86230	 32794	 0.073261	 0.1701	 0.00253	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32794	 86392	 0.00479	 0.010748	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32795	 32796	 0.015581	 0.010087	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32795	 32871	 0.009997	 0.028672	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32796	 32797	 0.012207	 0.008647	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32798	 32927	 0.006081	 0.014119	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32798	 86327	 0.009773	 0.02269	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32799	 33156	 0.023515	 0.018609	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32800	 32823	 0.007638	 0.02299	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32800	 86307	 0.003482	 0.015514	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32801	 32803	 0.002555	 0.010042	 0.00263	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32801	 33220	 0.002773	 0.01054	 0.00295	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32801	 86304	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32801	 86304	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32802	 32811	 0.016275	 0.01738	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32803	 32838	 0.002874	 0.016035	 0.0041	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32803	 86305	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32803	 86305	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32803	 86311	 0.001579	 0.011166	 0.00306	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32804	 32805	 0.001705	 0.005303	 0.00111	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32804	 32814	 0.000806	 0.003629	 0.00097	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32804	 86306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32804	 86306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32805	 86307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32805	 86307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32806	 32813	 0.027213	 0.019276	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32807	 32816	 0.026593	 0.021045	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32808	 33241	 0.015593	 0.01234	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32809	 32813	 0.015416	 0.039205	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32809	 33277	 0.018152	 0.046663	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32810	 32811	 0.004728	 0.013562	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32810	 33242	 0.004085	 0.019609	 0.00059	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86306	 32810	 0.021661	 0.05029	 0.00075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32811	 32813	 0.00656	 0.017386	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32812	 32816	 0.020017	 0.01569	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32813	 86312	 0.003819	 0.02552	 0.00056	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32814	 86308	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32814	 86308	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32814	 86311	 0.000701	 0.004443	 0.00121	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32815	 86309	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32815	 86309	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32815	 86311	 0.000841	 0.005415	 0.00142	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32816	 33231	 0.030982	 0.040719	 0.00056	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32816	 86312	 0.007186	 0.018473	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32817	 33252	 0.000305	 0.005657	 0.37366	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32817	 33383	 5.3e-05	 0.000638	 0.04784	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32817	 86310	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32817	 86310	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32818	 32819	 0.004364	 0.017836	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86308	 32818	 0.003652	 0.020521	 0.00038	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32819	 32821	 0.004794	 0.014707	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32820	 32823	 0.004272	 0.010458	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32820	 32825	 0.003183	 0.008183	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32821	 32822	 0.003733	 0.012452	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32822	 32826	 0.010316	 0.015803	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32822	 86317	 0.00493	 0.012672	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86304	 32823	 0.00731	 0.012315	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32824	 32825	 0.016905	 0.023998	 0.00039	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86305	 32824	 0.004697	 0.018274	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32824	 86314	 0.034038	 0.044736	 0.00061	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32825	 32826	 0.004052	 0.007283	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32825	 32828	 0.004943	 0.011475	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32827	 32829	 0.001033	 0.002398	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32827	 86313	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32827	 86313	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86313	 32828	 0.003699	 0.012339	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32828	 86314	 0.013448	 0.010642	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32829	 86314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32829	 86314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32830	 33213	 0.008197	 0.021072	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32830	 86315	 0.029943	 0.023696	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32831	 32834	 0.013059	 0.013062	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32832	 32833	 0.002444	 0.006653	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32832	 32870	 0.001334	 0.003525	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32832	 86315	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32832	 86315	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32833	 32835	 0.001386	 0.004173	 0.00131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32833	 86316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32833	 86316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86314	 32834	 0.00832	 0.019316	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32835	 32836	 0.001486	 0.005097	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32836	 86317	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32836	 86317	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32837	 32840	 0.006317	 0.016743	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32837	 32845	 0.021015	 0.028647	 0.00064	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32837	 86318	 0.005795	 0.016621	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32838	 86318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32838	 86318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32839	 32840	 0.004623	 0.020598	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86309	 32839	 0.004147	 0.022836	 0.00052	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86312	 32840	 0.024267	 0.062382	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86317	 32840	 0.004651	 0.023663	 0.00054	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32841	 32845	 0.004199	 0.025518	 0.00047	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32841	 32862	 0.004378	 0.019179	 0.00041	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32842	 34078	 0.005886	 0.041293	 0.07035	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	86310	 32842	 0.000582	 0.006823	 0.02752	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32842	 86319	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86320	 32842	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32842	 86468	 0.000611	 0.007686	 0.01837	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32843	 32844	 0.009412	 0.019261	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32843	 32848	 0.007612	 0.018026	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32844	 32845	 0.012076	 0.028035	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86309	 32845	 0.008974	 0.055171	 0.00099	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32846	 32848	 0.010435	 0.008004	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32847	 32848	 0.001602	 0.010585	 0.00021	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86309	 32847	 0.003376	 0.014433	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86312	 32847	 0.003488	 0.026376	 0.00088	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32847	 86470	 0.006631	 0.029547	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32848	 33401	 0.003175	 0.01059	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32848	 86324	 0.040026	 0.092913	 0.00177	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32848	 86470	 0.015313	 0.038008	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32849	 32851	 0.023793	 0.018027	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32850	 32856	 0.00279	 0.011172	 0.00281	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32850	 86321	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32850	 86321	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32851	 32852	 0.006193	 0.015921	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32851	 86322	 0.0074	 0.022725	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32852	 32858	 0.0067	 0.017365	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32852	 32887	 0.029811	 0.02155	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32852	 32889	 0.008605	 0.028706	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32853	 32854	 0.007138	 0.01288	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32853	 32858	 0.006781	 0.018526	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86320	 32853	 0.00548	 0.031151	 0.00056	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32853	 86323	 0.019225	 0.040407	 0.00074	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32854	 86322	 0.006869	 0.010522	 0.00015	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32855	 33412	 0.012683	 0.042309	 0.00067	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86320	 32855	 0.008576	 0.033363	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86319	 32856	 0.001444	 0.007923	 0.00209	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32856	 86322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32856	 86322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32857	 32860	 0.002709	 0.010421	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86318	 32857	 0.00374	 0.01734	 0.00036	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32858	 86324	 0.008646	 0.017767	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32859	 32861	 0.001129	 0.003428	 0.00075	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32859	 32886	 0.001589	 0.005618	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32859	 86323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32859	 86323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32860	 86324	 0.003334	 0.012971	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32861	 86324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32861	 86324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32862	 32863	 0.002447	 0.008163	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86324	 32863	 0.005271	 0.012482	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32864	 32865	 0.009879	 0.019559	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32864	 32866	 0.003753	 0.014891	 0.00043	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32864	 32884	 0.008539	 0.015407	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32864	 86328	 0.023247	 0.025569	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32865	 32878	 0.01915	 0.043438	 0.00087	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32865	 86326	 0.00687	 0.042238	 0.00076	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32866	 32867	 0.02029	 0.026667	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32866	 32868	 0.006057	 0.012932	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86318	 32866	 0.00538	 0.030227	 0.00056	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32867	 32873	 0.018793	 0.01684	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86316	 32868	 0.00569	 0.014469	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32869	 32870	 0.001043	 0.004865	 0.0012	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32869	 33129	 0.001269	 0.004441	 0.00147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32869	 86325	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32869	 86325	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86311	 32870	 0.005855	 0.036338	 0.0088	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32870	 86326	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32870	 86326	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32871	 32872	 0.006234	 0.016024	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86326	 32871	 0.007736	 0.019885	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32872	 32873	 0.00648	 0.015044	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32874	 86327	 0.020039	 0.015859	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32875	 32876	 0.000706	 0.002773	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32875	 32930	 0.002742	 0.010424	 0.00292	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32875	 86327	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32875	 86327	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32876	 32877	 0.000953	 0.003709	 0.00099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32877	 32879	 0.000924	 0.003266	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32878	 32922	 0.014248	 0.011276	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32878	 32923	 0.009769	 0.020934	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32879	 32886	 0.001563	 0.005362	 0.00128	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32880	 32881	 0.007295	 0.014928	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32880	 86328	 0.010218	 0.029305	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32881	 32925	 0.00867	 0.021519	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32882	 32883	 0.005123	 0.01419	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32882	 32888	 0.007777	 0.021245	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86323	 32883	 0.01651	 0.032689	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32883	 86328	 0.003069	 0.01024	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32884	 86328	 0.011996	 0.012116	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86323	 32885	 0.020636	 0.015829	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32886	 86328	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32886	 86328	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32888	 32894	 0.012332	 0.031363	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32889	 32890	 0.020343	 0.015945	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32889	 32891	 0.009589	 0.024386	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32891	 32892	 0.025011	 0.019605	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32891	 32893	 0.011609	 0.021262	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32893	 32903	 0.010793	 0.02067	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32893	 86329	 0.010651	 0.024728	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32894	 32910	 0.013209	 0.030667	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32894	 32926	 0.017269	 0.01881	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32894	 86329	 0.009845	 0.022618	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32895	 32911	 0.002244	 0.008985	 0.00226	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86319	 32895	 0.005812	 0.038989	 0.00941	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32895	 86329	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32895	 86329	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32896	 32902	 0.003326	 0.011207	 0.00279	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32896	 33931	 0.002819	 0.00881	 0.00255	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32897	 32901	 0.010306	 0.023569	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32897	 86330	 0.005927	 0.019773	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32898	 32899	 0.008166	 0.013035	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32899	 32921	 0.0068	 0.01748	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86329	 32899	 0.007226	 0.030891	 0.0007	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32900	 32905	 0.031811	 0.025175	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86321	 32901	 0.009775	 0.025909	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32902	 86330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32902	 86330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86330	 32903	 0.025155	 0.025686	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32904	 32905	 0.0125	 0.035852	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32904	 33929	 0.019008	 0.063409	 0.00101	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32905	 33399	 0.00712	 0.015202	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32905	 33466	 0.020203	 0.051934	 0.0008	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86321	 32905	 0.019167	 0.054973	 0.00085	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32906	 32907	 0.021316	 0.015409	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32906	 32914	 0.020821	 0.031578	 0.00045	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32906	 32929	 0.006041	 0.017141	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32906	 86333	 0.025175	 0.058447	 0.00087	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32908	 32909	 0.007968	 0.018498	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32908	 32925	 0.012042	 0.020002	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32909	 32914	 0.009425	 0.021654	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32910	 86331	 0.020625	 0.053019	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32911	 32919	 0.001322	 0.005023	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32912	 33932	 0.08245	 0.05338	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32912	 33939	 0.024358	 0.055961	 0.00085	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86329	 32912	 0.016652	 0.073371	 0.00127	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32913	 32918	 0.0016	 0.006406	 0.00161	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32913	 33541	 0.002324	 0.009458	 0.0023	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32913	 86331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32913	 86331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32914	 86332	 0.00948	 0.021681	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32915	 32916	 0.004711	 0.012451	 0.00291	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32915	 86332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32915	 86332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86311	 32916	 0.009635	 0.066859	 0.01909	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32916	 86333	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32916	 86333	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86333	 32917	 0.032405	 0.020979	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32918	 32919	 0.00149	 0.005966	 0.0015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32920	 32921	 0.025028	 0.019806	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32923	 32924	 0.004871	 0.012522	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32923	 32929	 0.005944	 0.013799	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32924	 32925	 0.009556	 0.01892	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32925	 32926	 0.006783	 0.017437	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32927	 32928	 0.004636	 0.011508	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32927	 86334	 0.007424	 0.015192	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32928	 32929	 0.005582	 0.01435	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32930	 32931	 0.001597	 0.005811	 0.00178	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32930	 86334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32930	 86334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32931	 33176	 0.00178	 0.00623	 0.00206	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32932	 32933	 0.033343	 0.024531	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32932	 33173	 0.00887	 0.034507	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86333	 32932	 0.015151	 0.034807	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32934	 32935	 0.004484	 0.024146	 0.00663	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32934	 86335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32934	 86335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32935	 32936	 0.004651	 0.029461	 0.008	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32936	 32939	 0.00847	 0.045608	 0.01253	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32936	 86336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32936	 86336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32937	 32938	 0.18832	 0.14905	 0.00188	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86336	 32937	 0.07617	 0.15082	 0.00221	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32939	 34139	 0.006115	 0.032509	 0.00754	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32939	 86337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32939	 86337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32940	 32942	 0.005097	 0.039648	 0.0103	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32940	 33584	 0.007416	 0.059589	 0.01675	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32941	 86338	 0.07252	 0.18002	 0.00299	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32942	 86338	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32942	 86338	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32943	 86341	 0.030826	 0.040514	 0.00056	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32944	 32956	 0.012559	 0.018828	 0.00034	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32944	 32968	 0.008161	 0.031748	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32944	 86341	 0.009177	 0.020988	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32945	 32947	 0.00118	 0.006025	 0.00152	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32945	 33643	 0.002154	 0.013643	 0.0037	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32946	 32957	 0.01282	 0.024839	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32946	 86339	 0.009572	 0.022221	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32947	 32952	 0.001511	 0.00547	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32947	 86339	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32947	 86339	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32948	 32949	 0.010371	 0.018713	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32948	 32951	 0.007565	 0.019447	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86339	 32948	 0.007182	 0.014697	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32949	 32950	 0.007079	 0.015113	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32949	 86342	 0.007324	 0.015694	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32950	 32968	 0.004934	 0.012683	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32951	 32968	 0.006369	 0.015809	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32951	 86340	 0.012925	 0.030007	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32951	 86342	 0.018975	 0.034238	 0.00049	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32952	 32953	 0.001613	 0.005435	 0.00135	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	32953	 86340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32953	 86340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32954	 32961	 0.022964	 0.016895	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32954	 32968	 0.021011	 0.017294	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32955	 32968	 0.017631	 0.013953	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32957	 32958	 0.016919	 0.034623	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32957	 32959	 0.13474	 0.13611	 0.0018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32957	 86543	 0.005742	 0.035301	 0.00064	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32958	 32960	 0.03159	 0.066394	 0.00121	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32960	 32962	 0.008644	 0.044948	 0.00097	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86340	 32960	 0.021958	 0.050978	 0.00076	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84796	 32962	 0.011219	 0.063776	 0.00115	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32963	 32967	 0.003449	 0.016087	 0.00398	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	32963	 86341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32963	 86341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86341	 32964	 0.020729	 0.048117	 0.00092	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84796	 32965	 0.012019	 0.042936	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84796	 32965	 0.012019	 0.042936	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86341	 32965	 0.023626	 0.091914	 0.00153	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32965	 86343	 0.014567	 0.064911	 0.0011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32966	 86343	 0.038932	 0.079674	 0.00196	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32967	 33642	 0.002022	 0.013022	 0.00341	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32967	 86342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32967	 86342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32969	 86343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32969	 86343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32970	 32971	 0.00026	 0.003401	 0.01101	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32970	 86344	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32970	 86344	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32970	 86422	 0.000318	 0.003976	 0.01619	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84798	 32971	 0.005433	 0.072343	 0.15497	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32971	 86345	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86346	 32971	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32972	 32973	 0.015392	 0.032351	 0.00059	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32972	 32975	 0.013869	 0.034423	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86346	 32973	 0.015082	 0.034649	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32974	 32976	 0.002119	 0.008749	 0.00207	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32974	 33834	 0.002718	 0.009509	 0.00315	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32974	 86347	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32974	 86347	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32975	 32988	 0.026728	 0.032583	 0.00052	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86347	 32975	 0.005319	 0.02834	 0.0005	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	32976	 32983	 0.001534	 0.005969	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32977	 32982	 0.004162	 0.016191	 0.00432	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32978	 32979	 0.004903	 0.012959	 0.00303	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32978	 86348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32978	 86348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32979	 86349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32979	 86349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32980	 86350	 0.005962	 0.033891	 0.00061	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32980	 86351	 0.005598	 0.02911	 0.00063	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32981	 32982	 0.003055	 0.011115	 0.0034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32981	 86350	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32981	 86350	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32983	 86351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32983	 86351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86351	 32984	 0.031406	 0.024854	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86351	 32985	 0.033566	 0.036919	 0.00049	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32986	 33251	 0.015774	 0.060436	 0.00171	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86351	 32986	 0.011091	 0.063048	 0.00114	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86344	 32987	 0.059351	 0.04697	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	32989	 86424	 0.054259	 0.090623	 0.00154	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32990	 33716	 0.037114	 0.12679	 0.00276	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32991	 32992	 0.009224	 0.03904	 0.00879	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	32991	 86352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32991	 86352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32993	 32994	 0.066806	 0.19163	 0.00295	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86352	 32993	 0.044955	 0.14997	 0.00238	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84820	 32994	 0.017327	 0.068744	 0.00196	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86301	 32994	 0.40774	 0.51947	 0.00762	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32994	 86568	 0.15034	 0.19762	 0.00271	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	32995	 32996	 0.024189	 0.10779	 0.00183	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32996	 33674	 0.033317	 0.13334	 0.00282	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32997	 33000	 0.061744	 0.14336	 0.00213	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32997	 33949	 0.07811	 0.17526	 0.00279	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	32998	 86355	 0.10885	 0.10027	 0.00161	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84779	 32999	 0.007625	 0.020471	 0.00464	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	32999	 86353	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	32999	 86353	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86353	 33000	 0.038238	 0.085789	 0.00137	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84779	 33001	 0.001017	 0.008554	 0.00253	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33001	 86354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33001	 86354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84778	 33002	 0.00045	 0.007996	 0.00402	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33002	 86355	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33002	 86355	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33002	 86356	 0.001222	 0.014514	 0.00506	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33003	 86356	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33003	 86356	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84787	 33004	 0.00065	 0.00706	 0.01385	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84787	 33004	 0.00065	 0.00706	 0.01385	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84844	 33004	 0.000794	 0.008919	 0.01632	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84844	 33004	 0.000794	 0.008919	 0.01632	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86199	 33004	 0.002736	 0.028379	 0.06114	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86199	 33004	 0.002736	 0.028379	 0.06114	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33004	 86357	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33004	 86357	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84779	 33005	 0.005714	 0.038335	 0.00925	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33005	 86358	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33005	 86358	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86179	 33006	 0.056594	 0.13138	 0.0025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86354	 33006	 0.013459	 0.06494	 0.00115	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86358	 33006	 0.037413	 0.063025	 0.0009	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33007	 33534	 0.004424	 0.030693	 0.00876	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33007	 86560	 0.004523	 0.033894	 0.00827	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33008	 33010	 0.002112	 0.021349	 0.00628	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84786	 33008	 0.003853	 0.039638	 0.01124	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33009	 33010	 0.002518	 0.017472	 0.00499	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33009	 33816	 0.006113	 0.033662	 0.01215	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33010	 33011	 0.008896	 0.03461	 0.00924	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33011	 86359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33011	 86359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33012	 86360	 0.038489	 0.14808	 0.00253	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33012	 86360	 0.038489	 0.14808	 0.00253	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33013	 33014	 0.043565	 0.11199	 0.00173	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33013	 33609	 0.079793	 0.18897	 0.00346	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33014	 33015	 0.060723	 0.11629	 0.00183	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33015	 33016	 0.044722	 0.11497	 0.00178	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33015	 33608	 0.20095	 0.41324	 0.00789	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33015	 86360	 0.031177	 0.13817	 0.00415	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33016	 33612	 0.023328	 0.13261	 0.0024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33016	 34029	 0.031659	 0.1218	 0.00208	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33017	 34021	 0.000183	 0.003019	 0.26475	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33017	 86360	 0.00209	 0.091976	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33017	 86360	 0.00209	 0.091976	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33018	 33019	 0.16165	 0.11894	 0.00174	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33019	 33020	 0.043323	 0.11137	 0.00172	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33019	 33986	 0.028585	 0.10569	 0.00196	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33019	 33988	 0.032196	 0.12526	 0.00209	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86181	 33019	 0.072196	 0.28654	 0.00819	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33021	 33022	 0.042027	 0.10689	 0.00169	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33021	 34049	 0.04648	 0.11949	 0.00185	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33022	 33023	 0.027197	 0.14327	 0.00257	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	33022	 33024	 0.044807	 0.094175	 0.00172	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33023	 33737	 0.027881	 0.13835	 0.0033	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33024	 33025	 0.048825	 0.12942	 0.00328	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33024	 39306	 0.087553	 0.20326	 0.00387	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33024	 86443	 0.032159	 0.19763	 0.00452	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33025	 33066	 0.24833	 0.46223	 0.01083	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33025	 33319	 0.025334	 0.15577	 0.00281	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33025	 33688	 0.072122	 0.27753	 0.00474	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33025	 33690	 0.12758	 0.25265	 0.00371	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33025	 34051	 0.032692	 0.14041	 0.00257	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33025	 34053	 0.072079	 0.13805	 0.00217	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33025	 39306	 0.16419	 0.33757	 0.00644	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33026	 33262	 0.042942	 0.031594	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33026	 86361	 0.014272	 0.047099	 0.00076	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33026	 86429	 0.021161	 0.060692	 0.00093	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33026	 86430	 0.052132	 0.079851	 0.00139	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33027	 33038	 0.001166	 0.007623	 0.00194	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33027	 86361	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33027	 86361	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33027	 86428	 0.004025	 0.026316	 0.00669	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33028	 33029	 0.015044	 0.0462	 0.00087	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33028	 86363	 0.015553	 0.059837	 0.00102	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33029	 86366	 0.033094	 0.052825	 0.00122	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33030	 86362	 0.037555	 0.02763	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33031	 33032	 0.001245	 0.005713	 0.00146	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33031	 33034	 0.002396	 0.010143	 0.00228	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33031	 86362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33031	 86362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86294	 33032	 0.006003	 0.035161	 0.00958	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33032	 86363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33032	 86363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33033	 33034	 0.002418	 0.009841	 0.0024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33033	 33965	 0.020978	 0.084012	 0.02117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86294	 33033	 0.00659	 0.043094	 0.01096	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33033	 86364	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33033	 86364	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33034	 33035	 0.001379	 0.008731	 0.00237	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33035	 33039	 0.00168	 0.01127	 0.00272	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33035	 86365	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33035	 86365	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33036	 33037	 0.036197	 0.023434	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33036	 33044	 0.052321	 0.092015	 0.00173	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86296	 33036	 0.03904	 0.082054	 0.00149	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86364	 33036	 0.007462	 0.03339	 0.00069	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33038	 33039	 0.001879	 0.009739	 0.00238	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33038	 86366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33038	 86366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33039	 86367	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33039	 86367	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33040	 33043	 0.011131	 0.040769	 0.00103	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86365	 33040	 0.007819	 0.044446	 0.0008	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33041	 33042	 0.035033	 0.035042	 0.00047	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86361	 33042	 0.051351	 0.077884	 0.00112	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86367	 33042	 0.010248	 0.039264	 0.00111	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33044	 33045	 0.09901	 0.078358	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33046	 33047	 0.005342	 0.02325	 0.00662	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33046	 33345	 0.010544	 0.042217	 0.01064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33047	 33049	 0.004349	 0.02472	 0.00716	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33047	 86368	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33047	 86368	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33048	 33346	 0.073786	 0.12257	 0.0026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84776	 33049	 0.001173	 0.00729	 0.00206	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33050	 33058	 0.010425	 0.026798	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84777	 33050	 0.012578	 0.067304	 0.00204	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33050	 86369	 0.012686	 0.041863	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33051	 33056	 0.001119	 0.00709	 0.00192	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84776	 33051	 0.002548	 0.029649	 0.00872	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33051	 86369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33051	 86369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33052	 33054	 0.00867	 0.026596	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86369	 33052	 0.011623	 0.049919	 0.00091	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33053	 33054	 0.012954	 0.049837	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33054	 86370	 0.01284	 0.049952	 0.00083	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33055	 86372	 0.022257	 0.02448	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33056	 33060	 0.001441	 0.007996	 0.00243	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33056	 86370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33056	 86370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33057	 33058	 0.02877	 0.021797	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33059	 33064	 0.003345	 0.023303	 0.00876	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84799	 33059	 0.00037	 0.003737	 0.0011	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33059	 86371	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33059	 86371	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33060	 33063	 0.001747	 0.010854	 0.00306	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33060	 86372	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33060	 86372	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33061	 33063	 0.003828	 0.01994	 0.00523	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33061	 33860	 0.004905	 0.024646	 0.00641	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33061	 86373	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33061	 86373	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33062	 33859	 0.055831	 0.16014	 0.00246	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33062	 86374	 0.032365	 0.076641	 0.0014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33063	 86374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33063	 86374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33064	 33861	 0.004983	 0.040033	 0.01125	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33064	 86375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33064	 86375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86374	 33065	 0.011694	 0.030061	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33066	 33067	 0.047409	 0.044459	 0.00069	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33066	 33068	 0.019337	 0.049707	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33066	 33069	 0.026953	 0.069287	 0.00107	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84817	 33066	 0.024494	 0.1506	 0.00271	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33066	 86380	 0.032112	 0.082549	 0.00128	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33067	 33070	 0.008758	 0.025118	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33067	 86502	 0.041671	 0.085278	 0.0021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33068	 33490	 0.034985	 0.088973	 0.00141	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33069	 33488	 0.031995	 0.074269	 0.00141	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33070	 33075	 0.015097	 0.045439	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33071	 33073	 0.005856	 0.01696	 0.00409	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33071	 33083	 0.005749	 0.024334	 0.00548	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33071	 86376	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33071	 86376	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33072	 33075	 0.009069	 0.02785	 0.00052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33072	 86377	 0.009428	 0.036272	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33073	 86377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33073	 86377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86377	 33074	 0.017836	 0.053683	 0.00105	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33075	 33093	 0.037106	 0.033249	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33076	 33078	 0.050718	 0.039756	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86376	 33076	 0.038277	 0.058637	 0.00082	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33077	 33079	 0.002262	 0.007759	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33077	 86378	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33077	 86378	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33079	 33098	 0.001953	 0.007071	 0.00152	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86378	 33080	 0.047184	 0.037341	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33081	 33084	 0.025293	 0.02755	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33081	 33086	 0.024929	 0.03039	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33082	 33085	 0.009275	 0.026603	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86378	 33082	 0.011275	 0.033936	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33083	 33088	 0.002105	 0.010217	 0.00234	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33083	 86379	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33083	 86379	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33084	 33085	 0.032053	 0.032147	 0.00052	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86379	 33085	 0.012962	 0.039806	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33086	 33089	 0.01832	 0.028586	 0.00048	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33086	 33102	 0.016036	 0.045994	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33087	 33089	 0.03183	 0.020607	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33088	 33092	 0.003812	 0.017165	 0.00457	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33089	 33096	 0.010343	 0.026303	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86211	 33089	 0.032361	 0.1683	 0.00365	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33090	 33092	 0.003172	 0.013425	 0.00302	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33090	 33508	 0.004957	 0.019847	 0.005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33091	 33093	 0.017519	 0.029511	 0.00042	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33091	 33096	 0.017808	 0.045776	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33091	 86380	 0.013555	 0.034472	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33092	 86380	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33092	 86380	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33094	 33096	 0.009348	 0.024712	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33094	 33309	 0.048648	 0.12895	 0.00327	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84817	 33094	 0.004375	 0.024868	 0.00045	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86380	 33094	 0.020339	 0.062461	 0.00117	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33095	 86381	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33095	 86381	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33097	 33104	 0.025125	 0.022513	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86381	 33097	 0.013832	 0.032114	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33097	 86382	 0.033887	 0.087112	 0.00135	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33098	 33100	 0.002644	 0.009216	 0.00214	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33099	 33301	 0.015249	 0.030191	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33100	 86382	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33100	 86382	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33100	 86471	 0.010069	 0.040316	 0.01016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33101	 33109	 0.013087	 0.030383	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86382	 33101	 0.010781	 0.027713	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33102	 33109	 0.024422	 0.033291	 0.00074	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33102	 33110	 0.009242	 0.023758	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33103	 33311	 0.018287	 0.01924	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86382	 33103	 0.023554	 0.054683	 0.00081	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33104	 33106	 0.016907	 0.022221	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33105	 33107	 0.0083	 0.021336	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33105	 33309	 0.010208	 0.023695	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33106	 33108	 0.014972	 0.019677	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33107	 33108	 0.01361	 0.034612	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33108	 33366	 0.012294	 0.028541	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86382	 33110	 0.013045	 0.03028	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33111	 33112	 0.001572	 0.014279	 0.00465	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33111	 33115	 0.003162	 0.024049	 0.00756	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33111	 86383	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33111	 86383	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33112	 34946	 0.003227	 0.030375	 0.0092	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86149	 33113	 0.073389	 0.18867	 0.00292	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86383	 33113	 0.059263	 0.15235	 0.00236	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33114	 33115	 0.005056	 0.031375	 0.0076	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33115	 33533	 0.005642	 0.023881	 0.00537	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86325	 33116	 0.009813	 0.019429	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33116	 86384	 0.00474	 0.011765	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33117	 33118	 0.00134	 0.003648	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33117	 86384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33117	 86384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33118	 33124	 0.000655	 0.001521	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33119	 86414	 0.014239	 0.012759	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33120	 33122	 0.00302	 0.012607	 0.00036	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	33120	 86385	 0.005222	 0.01742	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33120	 86412	 0.00755	 0.017526	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33121	 33202	 0.001268	 0.005161	 0.00126	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33121	 86385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33121	 86385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33122	 86387	 0.001005	 0.004427	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33123	 33126	 0.001015	 0.003387	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33123	 33314	 0.000477	 0.002701	 0.00067	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33123	 86386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33123	 86386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33124	 33126	 0.00076	 0.00224	 0.00052	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33125	 33127	 0.003224	 0.008002	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33125	 86387	 0.001623	 0.004604	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33126	 86387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33126	 86387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33127	 33128	 0.003456	 0.008885	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33127	 33133	 0.015521	 0.017221	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86384	 33128	 0.009814	 0.017708	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33128	 86388	 0.003096	 0.007579	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33128	 86389	 0.010393	 0.013526	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33129	 33130	 0.000637	 0.002502	 0.00065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33129	 86388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33129	 86388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33130	 33131	 0.000696	 0.002785	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33130	 86389	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33130	 86389	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33131	 33315	 0.001243	 0.004887	 0.00128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33132	 33133	 0.01235	 0.00968	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33133	 33134	 0.010144	 0.007951	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86386	 33133	 0.005757	 0.016511	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33135	 33136	 0.000847	 0.002855	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33135	 33314	 0.000754	 0.002517	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33135	 86390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33135	 86390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33136	 33201	 0.001054	 0.002737	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33136	 86391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33136	 86391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33137	 33138	 0.013485	 0.009748	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86390	 33137	 0.004794	 0.010076	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33137	 86393	 0.001834	 0.008206	 0.00017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33137	 86439	 0.006168	 0.014319	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33139	 33140	 0.003709	 0.00759	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33139	 86440	 0.00199	 0.005709	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33140	 33141	 0.004414	 0.011225	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86388	 33141	 0.00893	 0.020516	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33141	 86392	 0.003942	 0.009153	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33142	 33143	 0.00114	 0.00306	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33142	 86392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33142	 86392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33143	 33155	 0.000859	 0.002307	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33144	 33145	 0.004201	 0.010799	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33144	 86440	 0.004044	 0.0085	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33145	 86394	 0.003323	 0.009531	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33146	 33151	 0.000507	 0.001769	 0.00041	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33146	 86393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33146	 86393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86391	 33147	 0.004479	 0.010398	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86393	 33147	 0.004233	 0.009827	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33148	 33162	 0.002276	 0.012454	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33148	 86410	 0.002208	 0.012551	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33149	 33150	 0.002381	 0.009158	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33149	 33162	 0.002717	 0.010571	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33150	 86394	 0.004956	 0.011385	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33150	 86396	 0.009027	 0.011748	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33151	 33161	 0.001151	 0.004067	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33151	 86394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33151	 86394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33152	 86441	 0.014162	 0.010238	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33153	 33154	 0.000358	 0.001433	 0.00036	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33153	 33316	 0.00078	 0.002729	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33154	 33315	 0.000941	 0.003766	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33155	 33157	 0.000781	 0.003225	 0.00076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33155	 86395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33155	 86395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86395	 33156	 0.004885	 0.012424	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33157	 33166	 0.000956	 0.003825	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33158	 33159	 0.004711	 0.015717	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33158	 86441	 0.002778	 0.008523	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33159	 86399	 0.003857	 0.009915	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33160	 33161	 0.000431	 0.001509	 0.0005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33160	 33316	 0.000682	 0.00268	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33161	 33164	 0.000457	 0.0026	 0.00075	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33161	 86396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33161	 86396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33162	 33195	 0.003042	 0.011141	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33162	 86397	 0.005209	 0.012093	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33163	 33164	 0.000592	 0.003525	 0.00093	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33163	 33194	 0.000732	 0.00454	 0.0011	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33163	 86397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33163	 86397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33165	 33167	 0.000918	 0.003571	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33165	 33316	 0.000965	 0.003982	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33166	 33170	 0.000837	 0.003349	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33167	 33168	 0.000744	 0.00298	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33168	 33182	 0.000796	 0.004139	 0.00122	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33168	 86398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33168	 86398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86397	 33169	 0.018573	 0.014698	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33170	 33174	 0.000864	 0.005358	 0.0013	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33170	 86399	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33170	 86399	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33171	 33172	 0.002338	 0.009094	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86399	 33171	 0.00319	 0.012273	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33172	 86401	 0.003228	 0.009491	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86399	 33173	 0.003616	 0.022231	 0.0004	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33174	 33179	 0.001194	 0.005475	 0.0014	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33174	 86400	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33174	 86400	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33175	 33176	 0.000795	 0.003125	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33175	 33178	 0.001723	 0.006773	 0.00177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33176	 86401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33176	 86401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33177	 86402	 0.025019	 0.02527	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33178	 86402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33178	 86402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33179	 33268	 0.000953	 0.004652	 0.00128	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86400	 33180	 0.005415	 0.021064	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33180	 86434	 0.002737	 0.015556	 0.00028	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33181	 33185	 0.000942	 0.005653	 0.00171	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33181	 33194	 0.000634	 0.003897	 0.00112	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33181	 86403	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33181	 86403	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33182	 33270	 0.000539	 0.003236	 0.00098	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33183	 33272	 0.006404	 0.014527	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86403	 33183	 0.004536	 0.009283	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33184	 33185	 0.000918	 0.004611	 0.0012	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33184	 33188	 0.000957	 0.005605	 0.00153	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33184	 86404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33184	 86404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33185	 33188	 0.001516	 0.009321	 0.00269	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86404	 33186	 0.003738	 0.02566	 0.00047	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33186	 86436	 0.003698	 0.017242	 0.0004	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	33187	 33253	 0.016668	 0.04617	 0.00076	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33187	 86405	 0.010886	 0.042351	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33187	 86436	 0.00846	 0.037273	 0.00065	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33188	 86405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33188	 86405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33188	 86423	 0.001164	 0.01031	 0.00274	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33189	 33198	 0.000161	 0.002734	 0.00966	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33189	 86406	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33189	 86406	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33189	 86422	 0.000499	 0.005447	 0.01056	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33189	 86422	 0.000499	 0.005447	 0.01056	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33190	 33192	 0.000506	 0.00331	 0.00123	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86406	 33190	 0.000625	 0.005197	 0.00157	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33190	 86407	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33190	 86407	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33191	 33192	 0.000399	 0.002945	 0.00085	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33191	 33197	 0.000538	 0.00403	 0.00098	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86407	 33193	 0.008242	 0.027494	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33193	 86408	 0.012375	 0.032071	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33194	 86408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33194	 86408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86408	 33195	 0.002549	 0.0123	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33196	 33200	 0.007072	 0.020283	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33196	 86409	 0.01381	 0.047172	 0.00103	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33197	 33203	 0.000771	 0.004884	 0.00133	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33198	 33204	 9.7e-05	 0.001516	 0.00637	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33198	 86409	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33198	 86409	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33199	 33200	 0.003885	 0.009019	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33199	 86411	 0.008111	 0.020849	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33200	 86410	 0.003557	 0.014233	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33201	 86410	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33201	 86410	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33202	 33203	 0.001158	 0.005162	 0.0014	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33203	 33205	 0.000816	 0.003891	 0.00113	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33203	 86411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33203	 86411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33205	 33206	 0.00083	 0.004238	 0.00107	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33206	 33209	 0.001079	 0.006019	 0.00154	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84774	 33206	 0.00057	 0.005304	 0.00164	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33207	 33210	 0.001806	 0.004193	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33207	 33211	 0.001297	 0.005399	 0.00168	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33207	 33315	 0.002964	 0.014893	 0.00388	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84774	 33207	 0.000888	 0.013289	 0.00447	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33207	 86412	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33207	 86412	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33208	 86413	 0.009127	 0.010039	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33209	 33224	 0.001175	 0.005807	 0.0017	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33209	 86413	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33209	 86413	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33210	 33218	 0.001991	 0.005766	 0.00139	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33211	 33212	 0.000633	 0.002535	 0.00064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33212	 33214	 0.001151	 0.003947	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33212	 86414	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33212	 86414	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86326	 33213	 0.023249	 0.045563	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86384	 33213	 0.0087	 0.024688	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33213	 86415	 0.001906	 0.008444	 0.00019	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33214	 33215	 0.001076	 0.003894	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33215	 86415	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33215	 86415	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86313	 33216	 0.007949	 0.018454	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86415	 33216	 0.005267	 0.011286	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33217	 33221	 0.004152	 0.008497	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86313	 33217	 0.003188	 0.007804	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33218	 33219	 0.001576	 0.004563	 0.0011	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33219	 33220	 0.000382	 0.002274	 0.0006	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33219	 33224	 0.001488	 0.007337	 0.00198	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33220	 86416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33220	 86416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86416	 33221	 0.006094	 0.015498	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86415	 33222	 0.003728	 0.016614	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86416	 33222	 0.001865	 0.00998	 0.0003	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33223	 33225	 0.001255	 0.006649	 0.00222	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33223	 86417	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33223	 86417	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33225	 33249	 0.002485	 0.008524	 0.00204	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33225	 86418	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33225	 86418	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33226	 33227	 0.008044	 0.020679	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86418	 33226	 0.010275	 0.029471	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33227	 33228	 0.006204	 0.015947	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33228	 33234	 0.023293	 0.030313	 0.00042	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33229	 33238	 0.025621	 0.020083	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33230	 33231	 0.033181	 0.023504	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33232	 33235	 0.011604	 0.026941	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33232	 33240	 0.004375	 0.014437	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33233	 86421	 0.026722	 0.019661	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33234	 33235	 0.012386	 0.020866	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86307	 33235	 0.007933	 0.03052	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33236	 33247	 0.003478	 0.010669	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33236	 86420	 0.004778	 0.017499	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33237	 33238	 0.02867	 0.022689	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33238	 33239	 0.020024	 0.014184	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33238	 33246	 0.007475	 0.019214	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33238	 33247	 0.009204	 0.028265	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33238	 33278	 0.004708	 0.028942	 0.00052	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33240	 86419	 0.005751	 0.01766	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33241	 33242	 0.006948	 0.013757	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33242	 86420	 0.002717	 0.014593	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33244	 33250	 0.002762	 0.007298	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33244	 86419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33244	 86419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33246	 86437	 0.005204	 0.017173	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33248	 86420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33248	 86420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33249	 33250	 0.001781	 0.006109	 0.00146	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33250	 86421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33250	 86421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33251	 33261	 0.020726	 0.080631	 0.00135	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33251	 86425	 0.01395	 0.10873	 0.00203	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33252	 33257	 0.000169	 0.002825	 0.18455	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	33252	 86422	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33252	 86422	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33253	 33260	 0.014662	 0.065336	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86424	 33253	 0.0134	 0.046918	 0.0013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84801	 33254	 0.017226	 0.05159	 0.01162	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33254	 86425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33254	 86425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33255	 33259	 0.002545	 0.014908	 0.00406	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33255	 33266	 0.000845	 0.00525	 0.00148	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33255	 86426	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33255	 86426	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86426	 33256	 0.010086	 0.01997	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33256	 86431	 0.008635	 0.016056	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33257	 33724	 0.000995	 0.012881	 0.8242	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33257	 86427	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33257	 86427	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33258	 33259	 0.001561	 0.009299	 0.00245	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33258	 33275	 0.001325	 0.007614	 0.00216	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86428	 33259	 0.001017	 0.009768	 0.00284	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33259	 86430	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33259	 86430	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86429	 33260	 0.00869	 0.038508	 0.00116	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86430	 33260	 0.007601	 0.020147	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86429	 33261	 0.025777	 0.052752	 0.0013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86428	 33263	 0.00244	 0.018287	 0.00446	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33263	 86431	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33263	 86431	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33264	 33273	 0.000836	 0.005192	 0.00147	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33264	 33317	 0.000689	 0.004036	 0.0011	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33264	 86432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33264	 86432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33265	 33266	 0.00152	 0.005374	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33265	 33273	 0.002007	 0.006884	 0.00165	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33267	 33318	 0.00762	 0.019588	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86229	 33267	 0.036572	 0.047594	 0.00067	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33268	 33317	 0.000882	 0.004506	 0.00123	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33268	 86433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33268	 86433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33269	 33270	 0.001349	 0.00406	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33269	 86434	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33269	 86434	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86423	 33270	 0.003413	 0.029269	 0.00833	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33270	 86435	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33270	 86435	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86432	 33271	 0.008644	 0.019394	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86435	 33271	 0.00383	 0.015194	 0.00043	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33271	 86442	 0.009189	 0.017086	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86435	 33272	 0.010348	 0.0266	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33273	 33274	 0.001108	 0.006276	 0.00156	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33273	 86436	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33273	 86436	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33274	 33275	 0.000596	 0.003489	 0.00095	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33276	 33286	 0.007121	 0.027702	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33276	 86437	 0.005022	 0.022255	 0.00067	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33277	 33289	 0.012222	 0.031083	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33278	 33279	 0.005557	 0.019458	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33279	 33280	 0.018189	 0.028381	 0.00047	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33279	 33292	 0.005858	 0.024793	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33279	 86438	 0.020801	 0.041183	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33280	 33289	 0.006707	 0.013278	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33281	 33282	 0.00772	 0.019633	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33281	 33286	 0.013155	 0.030541	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33281	 33293	 0.011452	 0.04007	 0.00083	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33281	 33297	 0.013923	 0.035791	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33282	 33284	 0.006076	 0.015619	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33283	 33284	 0.024568	 0.019442	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86256	 33284	 0.013008	 0.053164	 0.00108	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33285	 33286	 0.015701	 0.012923	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33286	 86438	 0.009343	 0.026512	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33287	 33288	 0.001098	 0.003995	 0.00122	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33287	 86437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33287	 86437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33290	 33307	 0.028158	 0.072384	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33290	 33384	 0.013866	 0.034416	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33291	 33292	 0.010069	 0.025884	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33291	 33300	 0.010652	 0.025223	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33292	 33305	 0.018402	 0.026815	 0.00061	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86215	 33293	 0.016115	 0.078638	 0.00136	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33294	 33302	 0.023587	 0.048473	 0.00092	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86212	 33294	 0.040883	 0.080125	 0.0012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33295	 33296	 0.040754	 0.029461	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86215	 33296	 0.024601	 0.043265	 0.00081	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33297	 33303	 0.012531	 0.031869	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86311	 33298	 0.010014	 0.04075	 0.00993	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33298	 86438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33298	 86438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33299	 33384	 0.035575	 0.028154	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33300	 33312	 0.00573	 0.017248	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33300	 86472	 0.027861	 0.07162	 0.00111	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33301	 33302	 0.011341	 0.02633	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33301	 33303	 0.017424	 0.034497	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86438	 33301	 0.021862	 0.062702	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33304	 33305	 0.005031	 0.013335	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86438	 33304	 0.008241	 0.031706	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33305	 33306	 0.006317	 0.018118	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33306	 33308	 0.010512	 0.026734	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33307	 33308	 0.025943	 0.024328	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86382	 33307	 0.022409	 0.052024	 0.00077	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86382	 33308	 0.014986	 0.037195	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33309	 33310	 0.033227	 0.036546	 0.00049	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33309	 33375	 0.023931	 0.031452	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33309	 33380	 0.019851	 0.056332	 0.00089	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33309	 86466	 0.012839	 0.049193	 0.00139	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33310	 33312	 0.007615	 0.017274	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33310	 33313	 0.011648	 0.029942	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33311	 33313	 0.009304	 0.016787	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33314	 86439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33314	 86439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33315	 33316	 0.0012	 0.005595	 0.00139	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33315	 86440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33315	 86440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33316	 86441	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33316	 86441	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33317	 86442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33317	 86442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86243	 33318	 0.004331	 0.0193	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86442	 33318	 0.003294	 0.016073	 0.00028	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33319	 86443	 0.022226	 0.12507	 0.0027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33320	 86443	 0.15389	 0.12179	 0.00153	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33321	 86443	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33321	 86443	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33322	 33847	 0.005373	 0.030872	 0.00875	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84800	 33322	 0.003083	 0.021808	 0.00598	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86443	 33323	 0.16577	 0.1312	 0.00165	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33324	 34099	 0.000829	 0.012403	 0.02901	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33324	 86444	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33324	 86444	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33325	 33326	 0.032381	 0.025626	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33326	 33327	 0.040811	 0.032298	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33327	 33328	 0.04989	 0.097777	 0.00147	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33328	 86447	 0.062076	 0.15788	 0.0025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86176	 33329	 0.071313	 0.23793	 0.00377	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33329	 86447	 0.024976	 0.083319	 0.00132	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33330	 33333	 0.001764	 0.014834	 0.00439	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33330	 33698	 0.004274	 0.039795	 0.01233	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33330	 86445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33330	 86445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86199	 33331	 0.005622	 0.073862	 0.16274	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33331	 86446	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86447	 33331	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33332	 33336	 0.000308	 0.002853	 0.00537	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33332	 33338	 0.00059	 0.004023	 0.00724	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	33333	 86450	 0.000928	 0.008225	 0.00219	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85617	 33334	 0.25766	 0.5989	 0.01142	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86185	 33334	 0.12619	 0.35823	 0.00563	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86188	 33334	 0.16945	 0.38781	 0.00948	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86445	 33334	 0.012301	 0.047856	 0.0008	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86445	 33334	 0.012301	 0.047856	 0.0008	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86447	 33334	 0.039046	 0.090651	 0.00135	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33334	 86449	 0.005647	 0.046974	 0.00089	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33334	 86548	 0.10948	 0.50779	 0.00975	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33335	 86448	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86449	 33335	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33336	 86450	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33336	 86450	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86450	 33337	 0.002327	 0.009469	 0.00231	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33337	 86451	 0.001932	 0.010269	 0.00238	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33338	 86451	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33338	 86451	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33339	 86452	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86453	 33339	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33340	 33743	 0.008289	 0.03866	 0.00958	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33340	 86454	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33340	 86454	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33341	 86455	 0.03996	 0.072102	 0.00104	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33342	 86455	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33342	 86455	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33342	 86699	 0.007594	 0.037445	 0.01013	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33343	 33344	 0.066834	 0.048315	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86455	 33344	 0.016193	 0.042919	 0.00109	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33344	 86456	 0.009754	 0.037947	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33345	 86456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33345	 86456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33345	 86699	 0.012038	 0.05523	 0.01415	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86456	 33346	 0.02906	 0.067468	 0.001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86456	 33347	 0.089454	 0.082399	 0.00132	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33348	 33848	 0.055321	 0.15868	 0.00244	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86454	 33348	 0.029093	 0.11318	 0.00189	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86455	 33348	 0.033327	 0.17759	 0.00312	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	33349	 33351	 0.18615	 0.14593	 0.00187	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33349	 33722	 0.19752	 0.14967	 0.00206	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33350	 33351	 0.11621	 0.091967	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33351	 33352	 0.093458	 0.093483	 0.00126	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33352	 33353	 0.028973	 0.10869	 0.00195	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33352	 33722	 0.28973	 0.3188	 0.00426	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33352	 34001	 0.050142	 0.12446	 0.00207	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33353	 33354	 0.026691	 0.081883	 0.00222	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86303	 33353	 0.065617	 0.26042	 0.00744	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33354	 33720	 0.51671	 0.68024	 0.00933	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33355	 33814	 0.024655	 0.13854	 0.00257	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33355	 86459	 0.017271	 0.09818	 0.00178	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33356	 33360	 0.000613	 0.007171	 0.0251	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33356	 33819	 0.00152	 0.01138	 0.04404	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33356	 86457	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86458	 33356	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33357	 33358	 0.004481	 0.020424	 0.00648	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33357	 33870	 0.003183	 0.016923	 0.00393	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33358	 33359	 0.004484	 0.02211	 0.00598	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33359	 86459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33359	 86459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33360	 33361	 0.000762	 0.007593	 0.02534	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33360	 86460	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33360	 86460	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33362	 33512	 0.019589	 0.050356	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84817	 33362	 0.012443	 0.050855	 0.00103	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33363	 33364	 0.001827	 0.010387	 0.00301	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33363	 33517	 0.001919	 0.010172	 0.00339	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33363	 86461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33363	 86461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33364	 33374	 0.001792	 0.011119	 0.00269	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33364	 86462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33364	 86462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33365	 33366	 0.014696	 0.03361	 0.00082	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84817	 33365	 0.010865	 0.028722	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33366	 33373	 0.018496	 0.042941	 0.00064	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33367	 86464	 0.040262	 0.04038	 0.00065	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33368	 86466	 0.020552	 0.021947	 0.00046	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33369	 33428	 0.008425	 0.018901	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33369	 86464	 0.016258	 0.037746	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33370	 33372	 0.007783	 0.0178	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33370	 33379	 0.006917	 0.016378	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33371	 33374	 0.001696	 0.008378	 0.00245	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33371	 86463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33371	 86463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33371	 86471	 0.00655	 0.032299	 0.00873	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33372	 33389	 0.006414	 0.017522	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33372	 33442	 0.002876	 0.018059	 0.00039	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33372	 86473	 0.009565	 0.048385	 0.00084	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86463	 33373	 0.013352	 0.030994	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33374	 86464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33374	 86464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33376	 33419	 0.002802	 0.0114	 0.00278	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33376	 86465	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33376	 86465	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33376	 86471	 0.003875	 0.017777	 0.00455	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33377	 33378	 0.010367	 0.029735	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86463	 33377	 0.013547	 0.033624	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86465	 33378	 0.007614	 0.024415	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33379	 33380	 0.00682	 0.015833	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33380	 33389	 0.014096	 0.047023	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33380	 86466	 0.004221	 0.016419	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33381	 86466	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33381	 86466	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33381	 86471	 0.001646	 0.006798	 0.00161	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86311	 33382	 0.001459	 0.005938	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33382	 86467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33382	 86467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33383	 86468	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33384	 33396	 0.002566	 0.016112	 0.00035	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33384	 86472	 0.006962	 0.026783	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86468	 33385	 0.000548	 0.004101	 0.01587	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33385	 86471	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86472	 33385	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33386	 33392	 0.003645	 0.014178	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33386	 33395	 0.002428	 0.016225	 0.00036	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86470	 33386	 0.008654	 0.038561	 0.00065	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86470	 33387	 0.015079	 0.027102	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33388	 33389	 0.00371	 0.014216	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33388	 86473	 0.002808	 0.015464	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33390	 33391	 0.027428	 0.021706	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33391	 33392	 0.002846	 0.007544	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86467	 33391	 0.004469	 0.020708	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33393	 33405	 0.002685	 0.013487	 0.00351	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86469	 33393	 0.000964	 0.008271	 0.00235	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33393	 86473	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33393	 86473	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86470	 33394	 0.004881	 0.017435	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86470	 33394	 0.004881	 0.017435	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86473	 33394	 0.003582	 0.013934	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86473	 33394	 0.003582	 0.013934	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33395	 33396	 0.00237	 0.014883	 0.00033	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33397	 33402	 0.002365	 0.009623	 0.00234	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33397	 86474	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33397	 86474	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33398	 33399	 0.012479	 0.032079	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33398	 33412	 0.017335	 0.024608	 0.0004	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86321	 33398	 0.015955	 0.041015	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33400	 33402	 0.00137	 0.006649	 0.00152	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33400	 33416	 0.001143	 0.005412	 0.0013	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86469	 33400	 0.001092	 0.006918	 0.00188	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33400	 86475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33400	 86475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86475	 33401	 0.004031	 0.009358	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33402	 86476	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33402	 86476	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33403	 33404	 0.019645	 0.019703	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33403	 33406	 0.006558	 0.028895	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86473	 33403	 0.004116	 0.015771	 0.00045	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86476	 33403	 0.004743	 0.017792	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33405	 86477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33405	 86477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86477	 33406	 0.00565	 0.014975	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33407	 33408	 0.006424	 0.018425	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33407	 33410	 0.00704	 0.018098	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86321	 33408	 0.022958	 0.058387	 0.00092	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33408	 86478	 0.005992	 0.026701	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33409	 33410	 0.027715	 0.021933	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33410	 33459	 0.008028	 0.039192	 0.00082	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	86474	 33410	 0.007477	 0.036074	 0.00064	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33411	 33412	 0.011005	 0.02829	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33411	 33459	 0.008516	 0.021658	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33413	 33414	 0.001573	 0.004557	 0.0011	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33413	 86478	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33413	 86478	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33414	 33416	 0.001754	 0.005911	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33415	 86479	 0.01376	 0.010554	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33416	 86479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33416	 86479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33417	 33418	 0.007507	 0.025044	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86474	 33417	 0.004818	 0.018744	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33418	 33431	 0.006555	 0.024237	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33418	 33433	 0.019271	 0.032463	 0.00046	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33418	 33457	 0.015494	 0.044438	 0.00068	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86477	 33418	 0.004453	 0.023827	 0.00072	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33419	 86480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33419	 86480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33420	 33421	 0.006773	 0.016578	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33420	 33436	 0.008991	 0.023767	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33421	 33422	 0.011535	 0.020813	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33422	 33443	 0.010027	 0.022745	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33422	 33445	 0.015146	 0.035866	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33423	 33440	 0.01075	 0.027633	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33423	 86482	 0.01751	 0.041464	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33424	 33426	 0.003453	 0.01685	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33424	 33439	 0.004236	 0.016478	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33424	 33441	 0.013739	 0.015111	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33425	 33427	 0.010284	 0.021045	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33425	 33428	 0.008472	 0.020062	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33425	 33429	 0.010243	 0.02605	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86463	 33425	 0.018649	 0.050948	 0.00087	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33426	 33442	 0.005512	 0.015247	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86477	 33426	 0.001318	 0.010275	 0.00019	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33427	 86481	 0.013378	 0.026487	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33428	 86481	 0.013808	 0.032057	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33429	 33430	 0.006964	 0.017045	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86480	 33430	 0.007018	 0.024555	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33431	 33432	 0.011016	 0.02912	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33432	 33444	 0.01156	 0.029717	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33434	 33435	 0.016298	 0.016461	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33435	 33436	 0.009987	 0.025399	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33435	 33437	 0.011979	 0.03996	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33436	 33440	 0.010613	 0.022743	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33436	 33444	 0.022888	 0.038225	 0.00065	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86465	 33436	 0.032096	 0.082507	 0.00128	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33437	 33439	 0.005362	 0.014175	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86465	 33437	 0.009068	 0.02331	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33438	 33440	 0.006654	 0.013617	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33438	 33449	 0.030468	 0.024112	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86480	 33438	 0.007557	 0.023206	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33441	 33442	 0.007265	 0.014239	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86465	 33442	 0.004093	 0.020704	 0.00036	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33443	 33444	 0.004824	 0.027419	 0.0005	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33443	 86486	 0.041696	 0.087635	 0.0016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33445	 33446	 0.013025	 0.036962	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33445	 86482	 0.014943	 0.034175	 0.00083	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33446	 33453	 0.053314	 0.067852	 0.00099	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33446	 33470	 0.014559	 0.033448	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33447	 33448	 0.002704	 0.006797	 0.00176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33447	 86481	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33447	 86481	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33448	 86482	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33448	 86482	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33450	 33451	 0.021876	 0.050788	 0.00076	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86482	 33450	 0.019573	 0.053473	 0.00091	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33451	 33515	 0.022367	 0.057497	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86462	 33451	 0.01914	 0.052287	 0.00089	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86482	 33452	 0.017296	 0.045722	 0.00083	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33452	 86484	 0.020706	 0.053227	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86155	 33453	 0.037216	 0.0692	 0.00162	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33453	 86486	 0.029638	 0.076188	 0.00118	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33454	 33455	 0.002129	 0.012365	 0.00291	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33454	 33518	 0.001608	 0.008923	 0.00271	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33454	 86483	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33454	 86483	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33455	 86484	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33455	 86484	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33456	 33471	 0.017838	 0.040461	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86321	 33456	 0.037264	 0.095792	 0.00148	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33457	 33458	 0.010692	 0.027484	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33458	 33461	 0.014267	 0.028248	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33459	 33460	 0.025008	 0.025014	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33459	 33468	 0.010158	 0.026924	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33461	 33462	 0.019227	 0.038067	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33461	 33463	 0.010225	 0.023734	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86477	 33461	 0.028858	 0.10098	 0.00209	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33462	 33464	 0.01224	 0.031464	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33462	 33468	 0.006892	 0.019768	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33463	 33464	 0.014253	 0.033091	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33464	 33473	 0.010478	 0.023768	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33465	 33468	 0.009783	 0.023165	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33465	 33471	 0.01724	 0.034134	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33466	 33472	 0.011034	 0.016542	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33467	 33474	 0.004413	 0.013009	 0.00303	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33467	 86485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33467	 86485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33468	 33472	 0.016986	 0.01814	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33469	 34081	 0.004376	 0.015469	 0.00349	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33469	 86486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33469	 86486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86485	 33470	 0.00879	 0.0325	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33471	 34082	 0.024691	 0.056008	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86485	 33473	 0.016153	 0.033056	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33473	 86487	 0.007562	 0.020042	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33474	 34083	 0.003723	 0.015151	 0.00369	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33474	 86487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33474	 86487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33475	 33478	 0.006578	 0.025854	 0.00676	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33475	 86488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33475	 86488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33476	 33477	 0.067145	 0.12859	 0.00202	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33476	 34118	 0.035772	 0.087563	 0.0015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33477	 34116	 0.15803	 0.13009	 0.00264	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33477	 86673	 0.23929	 0.25565	 0.00541	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33478	 33480	 0.00388	 0.015247	 0.00399	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33479	 86489	 0.074426	 0.074445	 0.00101	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33480	 33482	 0.002919	 0.017095	 0.00466	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33480	 86489	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33480	 86489	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33481	 33482	 0.001878	 0.012279	 0.00312	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33481	 33483	 0.003777	 0.023219	 0.0067	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33481	 86490	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33481	 86490	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33482	 34120	 0.004331	 0.024162	 0.00617	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33482	 86491	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33482	 86491	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33483	 33484	 0.004376	 0.025631	 0.00698	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33483	 86492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33483	 86492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33484	 33496	 0.002555	 0.015332	 0.00464	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33484	 86493	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33484	 86493	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33485	 33494	 0.053108	 0.13653	 0.00211	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86492	 33485	 0.03022	 0.076856	 0.00122	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33486	 33487	 0.003418	 0.01668	 0.00461	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33486	 34117	 0.004007	 0.024235	 0.00618	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33486	 86494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33486	 86494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33487	 33493	 0.002983	 0.016059	 0.00441	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33488	 33499	 0.02991	 0.06121	 0.00151	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33489	 33491	 0.021707	 0.050395	 0.00075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33489	 33687	 0.030597	 0.064308	 0.00117	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33490	 33491	 0.01516	 0.038971	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33491	 33492	 0.017182	 0.048757	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33491	 86495	 0.037348	 0.094984	 0.0015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33491	 86555	 0.068959	 0.15644	 0.00312	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33492	 86495	 0.021492	 0.049889	 0.00095	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33493	 33498	 0.003005	 0.01203	 0.00303	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33493	 86495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33493	 86495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33494	 33497	 0.014504	 0.038342	 0.0007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33495	 33497	 0.012479	 0.038282	 0.00104	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86493	 33495	 0.019745	 0.065159	 0.00106	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33496	 33505	 0.00235	 0.013503	 0.00383	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33496	 86496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33496	 86496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86495	 33497	 0.015836	 0.048579	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86496	 33497	 0.047646	 0.11062	 0.00165	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33497	 86497	 0.010522	 0.024425	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33497	 86498	 0.009296	 0.03101	 0.00049	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33497	 86500	 0.029773	 0.085393	 0.00131	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33498	 33502	 0.001333	 0.007312	 0.00193	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33498	 86497	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33498	 86497	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33499	 33501	 0.007697	 0.019787	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33499	 86499	 0.014124	 0.020581	 0.00047	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33500	 33501	 0.010264	 0.020321	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33500	 86498	 0.024378	 0.019292	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33502	 33503	 0.00219	 0.007306	 0.00185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33502	 33504	 0.00469	 0.018433	 0.00482	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33502	 86498	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33502	 86498	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33503	 33509	 0.001946	 0.00779	 0.00196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33503	 86499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33503	 86499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33504	 33505	 0.001628	 0.010105	 0.00245	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33504	 33507	 0.00227	 0.014378	 0.0039	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33504	 33510	 0.006368	 0.021846	 0.00523	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84809	 33504	 0.032042	 0.10997	 0.02636	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33504	 86500	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33504	 86500	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86500	 33506	 0.037898	 0.041683	 0.00056	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33506	 86503	 0.015272	 0.039259	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33507	 33513	 0.001641	 0.009609	 0.00262	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33507	 86501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33507	 86501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33508	 33509	 0.002136	 0.008552	 0.00215	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33508	 86502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33508	 86502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33509	 86503	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33509	 86503	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33510	 33516	 0.002074	 0.012353	 0.00325	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33510	 86504	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33510	 86504	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33511	 86505	 0.038646	 0.038655	 0.00052	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86380	 33512	 0.039444	 0.082903	 0.00151	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86462	 33512	 0.042352	 0.097303	 0.00148	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33512	 86506	 0.016403	 0.046547	 0.00073	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33513	 33518	 0.001649	 0.009656	 0.00263	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33514	 33515	 0.012737	 0.036532	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33514	 86505	 0.010883	 0.031215	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86483	 33515	 0.014869	 0.049601	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33516	 33517	 0.00182	 0.009646	 0.00322	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33516	 86505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33516	 86505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33517	 86506	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33517	 86506	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84780	 33519	 0.002409	 0.036323	 0.01083	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84818	 33519	 0.003363	 0.04231	 0.01311	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33520	 34100	 0.088273	 0.25322	 0.0039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84819	 33520	 0.051677	 0.20106	 0.00336	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33521	 33523	 0.018136	 0.096634	 0.00169	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	33521	 86618	 0.022688	 0.12749	 0.00236	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84803	 33522	 0.15074	 0.15227	 0.00202	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86190	 33523	 0.016753	 0.065428	 0.00145	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33524	 86507	 0.037483	 0.086115	 0.00131	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33525	 86507	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33525	 86507	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33526	 86671	 0.19614	 0.15047	 0.00202	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33527	 33530	 0.014546	 0.040565	 0.00851	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33527	 33712	 0.013577	 0.035883	 0.0084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33528	 33773	 0.005515	 0.036999	 0.00893	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33528	 34043	 0.008807	 0.064328	 0.01654	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33528	 86508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33528	 86508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33529	 33771	 0.011763	 0.03109	 0.00728	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33529	 33774	 0.005978	 0.020506	 0.00491	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33529	 34042	 0.013529	 0.10196	 0.02831	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33530	 33772	 0.008514	 0.029206	 0.007	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33530	 86509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33530	 86509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33531	 33532	 0.020569	 0.09063	 0.00157	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84813	 33531	 0.040533	 0.122	 0.00239	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33531	 86969	 0.074256	 0.213	 0.00328	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86383	 33532	 0.01657	 0.071165	 0.0013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33533	 33534	 0.004051	 0.022332	 0.00522	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33533	 33708	 0.002916	 0.029714	 0.00766	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84786	 33534	 0.003435	 0.035332	 0.01002	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33534	 86510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33534	 86510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84813	 33535	 0.032487	 0.059503	 0.00103	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33536	 34032	 0.004554	 0.036586	 0.01028	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84785	 33536	 0.002094	 0.017614	 0.00522	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33536	 86511	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33536	 86511	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84792	 33537	 0.018712	 0.10514	 0.00195	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86511	 33538	 0.22605	 0.17721	 0.00228	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33539	 33545	 0.021191	 0.026305	 0.00057	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33539	 33553	 0.02198	 0.056502	 0.00087	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86232	 33539	 0.014167	 0.080533	 0.00146	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86328	 33539	 0.13144	 0.27633	 0.00504	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86331	 33539	 0.070942	 0.14911	 0.00272	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33539	 86514	 0.014398	 0.04234	 0.00087	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33539	 86519	 0.02861	 0.13962	 0.00241	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33540	 33544	 0.002859	 0.010003	 0.00332	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33540	 33546	 0.001121	 0.004628	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33540	 86512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33540	 86512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33541	 33544	 0.002803	 0.011223	 0.00283	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86332	 33542	 0.040787	 0.041648	 0.00065	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33544	 86513	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33544	 86513	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33546	 33547	 0.001861	 0.007239	 0.00193	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33547	 33556	 0.002142	 0.008576	 0.00216	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33547	 86514	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33547	 86514	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33548	 33549	 0.035192	 0.081705	 0.00122	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33548	 33551	 0.035409	 0.063246	 0.00093	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33548	 33941	 0.028025	 0.065064	 0.00097	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33549	 33552	 0.065643	 0.10056	 0.00141	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33549	 33559	 0.015449	 0.068843	 0.00117	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33549	 33807	 0.089034	 0.09793	 0.00131	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86513	 33550	 0.07079	 0.055489	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33551	 86516	 0.013868	 0.02838	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33552	 86515	 0.024487	 0.069487	 0.00109	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33553	 86646	 0.061964	 0.27617	 0.00469	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33554	 33558	 0.002524	 0.010272	 0.0025	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33554	 33561	 0.004372	 0.026043	 0.00685	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86234	 33554	 0.009794	 0.054649	 0.01396	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33554	 86515	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33554	 86515	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33555	 86517	 0.065884	 0.042654	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33556	 33557	 0.002193	 0.00853	 0.00228	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33556	 86516	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33556	 86516	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33557	 33558	 0.001571	 0.006647	 0.0015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33558	 86517	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33558	 86517	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33559	 86599	 0.028592	 0.11442	 0.00242	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33560	 86518	 0.027215	 0.053883	 0.00079	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33561	 33955	 0.003481	 0.018505	 0.00429	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33561	 86518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33561	 86518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33562	 33954	 0.005533	 0.017293	 0.00501	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33562	 86519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33562	 86519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86519	 33563	 0.030919	 0.063273	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33564	 86521	 0.031917	 0.035105	 0.00047	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33565	 33566	 0.001265	 0.007652	 0.00195	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33565	 86520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33565	 86520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33566	 33568	 0.001929	 0.006748	 0.00224	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33566	 86521	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33566	 86521	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33567	 33840	 0.082487	 0.064658	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86521	 33567	 0.014658	 0.029022	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33568	 33575	 0.001953	 0.006104	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33569	 33574	 0.01056	 0.035226	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86169	 33569	 0.028124	 0.06432	 0.00157	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86520	 33569	 0.028774	 0.052703	 0.00091	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33570	 33574	 0.024746	 0.027217	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33571	 86522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33571	 86522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33572	 33573	 0.019624	 0.014868	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33572	 33574	 0.007408	 0.02882	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84808	 33572	 0.006865	 0.030249	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33574	 33577	 0.025651	 0.040944	 0.00094	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86170	 33574	 0.025482	 0.1058	 0.00275	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86520	 33574	 0.027424	 0.070498	 0.00109	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33574	 86523	 0.007514	 0.017264	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33574	 86524	 0.01302	 0.027365	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33575	 33578	 0.00234	 0.006283	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33575	 86523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33575	 86523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84807	 33576	 0.016006	 0.062266	 0.00104	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84807	 33576	 0.016006	 0.062266	 0.00104	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84808	 33576	 0.011072	 0.042597	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84808	 33576	 0.011072	 0.042597	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33578	 86524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33578	 86524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33579	 33580	 0.011863	 0.039574	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86523	 33579	 0.009323	 0.041076	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33580	 33582	 0.018566	 0.043104	 0.00064	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84807	 33580	 0.007855	 0.065349	 0.00124	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33581	 33583	 0.005381	 0.024229	 0.00645	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33581	 86525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33581	 86525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86525	 33582	 0.019357	 0.054928	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33582	 86526	 0.020297	 0.052177	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33583	 86526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33583	 86526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33584	 33841	 0.004016	 0.031241	 0.00812	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33584	 86527	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33584	 86527	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33585	 33586	 0.022159	 0.079161	 0.00157	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86526	 33585	 0.010367	 0.058249	 0.00108	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33586	 33867	 0.036294	 0.15992	 0.00278	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84807	 33586	 0.024406	 0.12346	 0.00215	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33587	 86672	 0.22777	 0.16137	 0.00255	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86164	 33588	 0.044877	 0.12735	 0.002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33589	 33592	 0.004495	 0.02633	 0.00717	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33590	 86528	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33590	 86528	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86501	 33591	 0.026433	 0.061368	 0.00091	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86528	 33591	 0.01695	 0.065212	 0.00111	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33592	 86529	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33592	 86529	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33593	 33594	 0.003032	 0.017756	 0.00484	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33593	 86530	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33593	 86530	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84809	 33594	 0.005151	 0.036434	 0.01	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33594	 86531	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33594	 86531	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84810	 33595	 0.015544	 0.047684	 0.00129	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86530	 33595	 0.038986	 0.14416	 0.00267	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33596	 33598	 0.10517	 0.12591	 0.0021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84810	 33596	 0.042387	 0.10896	 0.00169	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33597	 33598	 0.021847	 0.07288	 0.00116	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86531	 33597	 0.038488	 0.098939	 0.00153	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33598	 33599	 0.022301	 0.067122	 0.00131	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86528	 33598	 0.050227	 0.12912	 0.002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33600	 33871	 0.092027	 0.18222	 0.00267	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33600	 86593	 0.074	 0.19024	 0.00294	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33601	 33798	 0.006043	 0.030365	 0.0079	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33601	 86532	 0.008569	 0.042254	 0.01143	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84762	 33602	 0.001935	 0.022805	 0.04209	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84771	 33602	 0.003828	 0.033679	 0.07029	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33602	 86532	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33602	 86532	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84764	 33603	 0.011691	 0.0521	 0.01416	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84764	 33603	 0.011691	 0.0521	 0.01416	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33603	 86533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33603	 86533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33604	 33605	 0.019137	 0.15921	 0.00301	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86533	 33604	 0.011027	 0.091575	 0.00224	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33605	 86654	 0.023023	 0.19155	 0.00363	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33606	 33607	 0.02586	 0.14701	 0.00266	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33606	 86632	 0.063388	 0.16803	 0.00426	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86444	 33607	 0.026093	 0.132	 0.0023	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33607	 86535	 0.14976	 0.39722	 0.01008	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33608	 86686	 0.16233	 0.4175	 0.00647	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33609	 34104	 0.066233	 0.22098	 0.0035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84758	 33610	 0.017439	 0.093769	 0.02308	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33610	 86534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33610	 86534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86534	 33611	 0.04162	 0.14218	 0.00309	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33612	 86535	 0.018203	 0.11192	 0.00202	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33613	 34103	 0.020422	 0.08434	 0.01996	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33613	 86535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33613	 86535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33614	 33626	 0.04205	 0.1081	 0.00167	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86535	 33614	 0.20306	 0.16072	 0.00202	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33614	 86687	 0.13225	 0.3001	 0.00599	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33615	 33616	 0.11514	 0.081561	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86168	 33615	 0.085362	 0.067556	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33617	 86536	 0.025195	 0.11274	 0.00232	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33618	 33619	 0.004265	 0.027014	 0.00733	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84763	 33618	 0.004889	 0.049816	 0.01284	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33619	 33620	 0.004427	 0.026371	 0.00694	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33620	 34148	 0.006626	 0.03977	 0.01204	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33620	 86536	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33620	 86536	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33621	 33963	 0.00308	 0.021139	 0.00617	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33621	 86537	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33621	 86537	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33622	 33623	 0.049174	 0.11298	 0.00172	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33622	 33725	 0.046524	 0.10801	 0.00161	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84790	 33623	 0.029571	 0.12344	 0.00356	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	33624	 33625	 0.14337	 0.11346	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33625	 86550	 0.082725	 0.14927	 0.00216	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33626	 33629	 0.025574	 0.089484	 0.00185	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86535	 33626	 0.099447	 0.19692	 0.00289	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33627	 33630	 0.010793	 0.027745	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33627	 34149	 0.10026	 0.25777	 0.00399	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33628	 33631	 0.006823	 0.027318	 0.00688	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33628	 34105	 0.015223	 0.077779	 0.01957	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33628	 86538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33628	 86538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33629	 33630	 0.022792	 0.038066	 0.00065	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33630	 33635	 0.032331	 0.03556	 0.00047	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33630	 86540	 0.032027	 0.059551	 0.00139	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33631	 86539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33631	 86539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86538	 33632	 0.20185	 0.15976	 0.00201	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86335	 33633	 0.091972	 0.15077	 0.00266	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86539	 33633	 0.054438	 0.12639	 0.00188	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33634	 33637	 0.004283	 0.025085	 0.00683	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33634	 86540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33634	 86540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33634	 86705	 0.020416	 0.11737	 0.03328	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33636	 34030	 0.077535	 0.19934	 0.00309	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33637	 34115	 0.012663	 0.078701	 0.02222	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33637	 86541	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33637	 86541	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86541	 33638	 0.16673	 0.12268	 0.00179	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33639	 86542	 0.054104	 0.16617	 0.00312	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33639	 86651	 0.058715	 0.29709	 0.00517	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33640	 86650	 0.21711	 0.15382	 0.00243	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33641	 33642	 0.004335	 0.025821	 0.00679	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33641	 33977	 0.011283	 0.071478	 0.01941	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33642	 86542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33642	 86542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33643	 33999	 0.005164	 0.028337	 0.00749	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33643	 86543	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33643	 86543	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33644	 33646	 0.003717	 0.020397	 0.00539	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33645	 33988	 0.084553	 0.20989	 0.00349	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33645	 86544	 0.057364	 0.14747	 0.00228	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33646	 34111	 0.031133	 0.13186	 0.0297	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86200	 33646	 0.034698	 0.12572	 0.02699	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33646	 86544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33646	 86544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33647	 33649	 0.024224	 0.023702	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33647	 86545	 0.021318	 0.041779	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33648	 33652	 0.048523	 0.0384	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33649	 33650	 0.091765	 0.072623	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33649	 33651	 0.013245	 0.026224	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86544	 33649	 0.02027	 0.055377	 0.00094	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33651	 33652	 0.025464	 0.016486	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33652	 33661	 0.2017	 0.15812	 0.00203	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33652	 86545	 0.041947	 0.07683	 0.00133	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33653	 33654	 0.004747	 0.016283	 0.0039	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33653	 86545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33653	 86545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33654	 86546	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33654	 86546	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33655	 33697	 0.014108	 0.070896	 0.01846	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33656	 33657	 0.00864	 0.033616	 0.00898	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33656	 86547	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33656	 86547	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33657	 33696	 0.009667	 0.037995	 0.00994	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33657	 86548	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33657	 86548	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33658	 86953	 0.18692	 0.13514	 0.00205	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33659	 34909	 0.013011	 0.064168	 0.01736	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33660	 33989	 0.047485	 0.19005	 0.00401	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84814	 33660	 0.020377	 0.12937	 0.00368	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86544	 33660	 0.078483	 0.22513	 0.00346	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33662	 33666	 0.13052	 0.1033	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33662	 86551	 0.10621	 0.12949	 0.00208	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33663	 33995	 0.0092	 0.076455	 0.24228	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33663	 86549	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86550	 33663	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 0	 -30.0	 30.0;
	33664	 33667	 0.011079	 0.034022	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86550	 33664	 0.022997	 0.060953	 0.00155	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33665	 33666	 0.10434	 0.082576	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86550	 33666	 0.050954	 0.12473	 0.00213	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33667	 33672	 0.006677	 0.023851	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33668	 33669	 0.028351	 0.019044	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33669	 33678	 0.006926	 0.013713	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33670	 33671	 0.003508	 0.012972	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33670	 33671	 0.003508	 0.012972	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33670	 33672	 0.00352	 0.012576	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33670	 86551	 0.007428	 0.033101	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33671	 86552	 0.003903	 0.013942	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33671	 86552	 0.003903	 0.013942	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86549	 33673	 0.004559	 0.021578	 0.00519	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33673	 86551	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33673	 86551	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86550	 33674	 0.021547	 0.10777	 0.00192	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33675	 33677	 0.001907	 0.007494	 0.00196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33675	 33683	 0.002705	 0.011449	 0.00258	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33675	 33685	 0.002034	 0.019532	 0.00568	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86549	 33675	 0.005777	 0.035521	 0.01024	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33676	 33678	 0.013403	 0.034452	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33676	 33680	 0.015606	 0.016998	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33677	 86552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33677	 86552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33678	 33679	 0.034106	 0.026734	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33678	 33681	 0.002478	 0.01701	 0.00031	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86551	 33678	 0.009452	 0.041886	 0.00126	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86552	 33681	 0.004975	 0.012602	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33681	 86554	 0.014858	 0.049032	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33682	 33683	 0.004013	 0.023907	 0.00629	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33682	 86553	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33682	 86553	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33683	 86554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33683	 86554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86554	 33684	 0.026304	 0.1012	 0.00173	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33685	 33686	 0.002143	 0.020173	 0.00611	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86494	 33687	 0.021863	 0.067071	 0.00182	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33687	 86555	 0.019101	 0.12434	 0.00253	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33688	 33690	 0.058491	 0.11971	 0.00295	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33688	 34119	 0.030221	 0.10796	 0.00214	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86494	 33688	 0.093406	 0.1737	 0.00407	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33689	 33850	 0.015134	 0.063016	 0.01966	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33689	 86555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33689	 86555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86555	 33690	 0.032586	 0.10347	 0.00181	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33691	 86557	 0.013464	 0.091432	 0.00226	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33691	 86703	 0.023477	 0.14215	 0.00445	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33692	 33694	 0.000753	 0.009003	 0.01778	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33692	 86556	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86557	 33692	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33693	 34100	 0.027906	 0.15864	 0.00287	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86557	 33693	 0.016412	 0.083022	 0.00144	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33694	 34099	 0.000743	 0.005563	 0.02153	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33694	 86558	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33694	 86558	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86557	 33695	 0.18153	 0.14367	 0.00181	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33696	 33697	 0.008408	 0.034216	 0.00834	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33697	 33698	 0.002724	 0.026614	 0.00747	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33699	 33702	 0.079353	 0.15198	 0.00239	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33699	 33844	 0.053273	 0.10203	 0.0016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33700	 33991	 0.25594	 0.20259	 0.00255	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33700	 34055	 0.23222	 0.59119	 0.00936	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33700	 86651	 0.089039	 0.39694	 0.00675	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33700	 86652	 0.076311	 0.15618	 0.00384	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33701	 33702	 0.17714	 0.17894	 0.00237	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33701	 86652	 0.079536	 0.3095	 0.00517	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86531	 33703	 0.02288	 0.093512	 0.00189	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33703	 86563	 0.037605	 0.1463	 0.00244	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33704	 33708	 0.002939	 0.020785	 0.0057	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33704	 86559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33704	 86559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33704	 86562	 0.004001	 0.031521	 0.00922	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33705	 33707	 0.001342	 0.017333	 0.03928	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33705	 33818	 0.001166	 0.015282	 0.03358	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33705	 86560	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86561	 33705	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86560	 33706	 0.006091	 0.034495	 0.00855	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33706	 86562	 0.003628	 0.019907	 0.00526	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33707	 86562	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33707	 86562	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33708	 86563	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33708	 86563	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84806	 33709	 0.33955	 0.24063	 0.0038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33710	 34112	 0.00645	 0.038717	 0.01173	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84805	 33710	 0.012046	 0.096818	 0.02723	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33710	 86564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33710	 86564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33711	 33981	 0.17723	 0.12813	 0.00194	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84790	 33711	 0.043916	 0.24968	 0.00452	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33711	 86567	 0.067342	 0.13782	 0.00339	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33712	 33714	 0.013404	 0.035988	 0.00816	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33712	 86565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33712	 86565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33713	 33714	 0.010912	 0.036766	 0.00914	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33713	 86566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33713	 86566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33714	 86567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33714	 86567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33715	 33716	 0.18944	 0.14994	 0.00189	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33716	 86568	 0.028245	 0.10444	 0.00193	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33717	 33952	 0.013976	 0.036285	 0.00881	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33717	 86568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33717	 86568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33719	 86569	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33719	 86569	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33720	 33721	 0.022051	 0.073561	 0.00117	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84796	 33720	 0.031701	 0.16486	 0.00357	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84821	 33720	 0.068407	 0.14	 0.00345	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33721	 33722	 0.084247	 0.14071	 0.00239	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84796	 33722	 0.11875	 0.39632	 0.00629	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86537	 33723	 0.050127	 0.16543	 0.00268	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33723	 86571	 0.030549	 0.10913	 0.00217	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33724	 86570	 0.000182	 0.014599	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86571	 33725	 0.034988	 0.13612	 0.00227	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84804	 33726	 0.19195	 0.15192	 0.00191	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84763	 33727	 0.00187	 0.020487	 0.00568	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33728	 33729	 0.015885	 0.11176	 0.00223	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33728	 34030	 0.015917	 0.10407	 0.00241	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33729	 33730	 0.06063	 0.12993	 0.00228	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33729	 86662	 0.030719	 0.11951	 0.002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33729	 86662	 0.030719	 0.11951	 0.002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33730	 34114	 0.068861	 0.1545	 0.00246	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33731	 34076	 0.053989	 0.13731	 0.00217	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33731	 86572	 0.020939	 0.12726	 0.00235	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33731	 86603	 0.015365	 0.086459	 0.00187	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33732	 33735	 0.009379	 0.036866	 0.00964	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33732	 34089	 0.006851	 0.028286	 0.00669	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33733	 33735	 0.011224	 0.033614	 0.00757	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33733	 86572	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33733	 86572	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86572	 33734	 0.18572	 0.14559	 0.00187	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33735	 33872	 0.011221	 0.051484	 0.01319	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33736	 86573	 0.18289	 0.13222	 0.00201	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33737	 86573	 0.017064	 0.096019	 0.00207	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33738	 33740	 0.004945	 0.020124	 0.0049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33738	 86573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33738	 86573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33739	 86575	 0.11072	 0.071686	 0.00136	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84797	 33740	 0.002478	 0.029424	 0.01025	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33740	 86574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33740	 86574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33741	 34134	 0.009425	 0.032998	 0.00091	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86574	 33741	 0.010531	 0.046926	 0.0008	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33742	 33743	 0.002453	 0.02005	 0.00544	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33742	 86575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33742	 86575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84797	 33743	 0.001243	 0.014601	 0.00876	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33744	 33748	 0.001191	 0.004311	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33744	 33780	 0.000829	 0.002845	 0.00068	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33744	 86576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33744	 86576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86576	 33745	 0.004729	 0.013906	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33745	 86592	 0.003432	 0.013352	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33747	 33752	 0.007121	 0.014098	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33747	 86577	 0.005459	 0.011699	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33748	 33750	 0.001311	 0.004418	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33748	 86577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33748	 86577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33749	 33781	 0.0077	 0.025687	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33749	 86578	 0.006834	 0.019601	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33750	 33757	 0.001824	 0.006603	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33750	 86578	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33750	 86578	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33751	 33794	 0.010401	 0.007367	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86578	 33751	 0.013897	 0.013938	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33752	 86591	 0.012775	 0.023049	 0.00033	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84823	 33753	 0.018945	 0.014532	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33754	 33794	 0.01039	 0.007511	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33755	 33763	 0.005119	 0.013567	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33755	 33783	 0.009887	 0.023411	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33755	 86579	 0.006233	 0.0131	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86578	 33756	 0.031776	 0.02297	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33757	 33762	 0.000684	 0.002382	 0.00055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33757	 86579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33757	 86579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33758	 33759	 0.006033	 0.008408	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86579	 33758	 0.008374	 0.010395	 0.00023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33759	 86591	 0.009041	 0.017718	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33760	 33761	 0.012272	 0.014386	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33760	 86591	 0.003717	 0.019327	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33761	 86581	 0.007308	 0.01679	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33762	 33765	 0.001355	 0.004908	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33763	 86580	 0.007634	 0.017723	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33764	 33765	 0.001075	 0.003893	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33764	 33782	 0.004815	 0.023744	 0.00642	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33764	 86580	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33764	 86580	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33765	 86581	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33765	 86581	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86580	 33766	 0.021286	 0.015388	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33767	 33768	 0.015462	 0.011714	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33768	 33769	 0.005484	 0.012985	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33768	 33790	 0.00887	 0.024232	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33769	 33791	 0.035771	 0.023158	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33769	 33796	 0.002451	 0.019099	 0.00036	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86580	 33769	 0.008564	 0.029254	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33770	 86582	 0.022596	 0.022823	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33770	 86589	 0.031317	 0.023041	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33771	 33782	 0.002572	 0.006906	 0.00157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33771	 86582	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33771	 86582	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84805	 33772	 0.003775	 0.020789	 0.00751	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33772	 86583	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33772	 86583	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33773	 33778	 0.001879	 0.012103	 0.00317	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33773	 86584	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33773	 86584	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33774	 33775	 0.004338	 0.010904	 0.00282	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33774	 86585	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33774	 86585	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33775	 86586	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33775	 86586	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33776	 33779	 0.010626	 0.020825	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86585	 33776	 0.012755	 0.033058	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86584	 33777	 0.063799	 0.05049	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33778	 33780	 0.001612	 0.007393	 0.00189	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33778	 86587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33778	 86587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33779	 86588	 0.024372	 0.017618	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33780	 86588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33780	 86588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33781	 86589	 0.005231	 0.025538	 0.00054	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	33782	 33784	 0.001431	 0.005625	 0.00147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84805	 33782	 0.004667	 0.033763	 0.01816	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33782	 86589	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33782	 86589	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33783	 33788	 0.00964	 0.017925	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33783	 86590	 0.007854	 0.034999	 0.00059	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33784	 86590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33784	 86590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33785	 33792	 0.006863	 0.05349	 0.001	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86590	 33785	 0.002555	 0.018457	 0.00035	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33786	 33787	 0.019062	 0.012341	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33786	 33788	 0.00451	 0.017546	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86590	 33786	 0.003905	 0.019373	 0.00046	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33788	 33789	 0.007609	 0.018018	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33788	 33790	 0.013631	 0.035039	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33789	 33790	 0.006286	 0.016159	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86583	 33792	 0.01068	 0.088847	 0.00168	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33793	 86591	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33793	 86591	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33795	 86592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33795	 86592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33797	 33801	 0.003103	 0.013972	 0.00372	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33797	 34087	 0.005058	 0.021057	 0.00657	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33798	 33799	 0.009452	 0.024981	 0.00585	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33798	 33800	 0.004636	 0.023294	 0.00606	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33798	 86593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33798	 86593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33799	 34089	 0.01019	 0.028416	 0.00596	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33800	 33801	 0.002448	 0.011158	 0.00354	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33800	 33805	 0.002644	 0.00882	 0.00224	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84782	 33800	 0.02576	 0.075964	 0.01768	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33800	 86597	 0.004114	 0.017412	 0.00392	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33801	 86594	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33801	 86594	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33802	 33804	 0.001019	 0.006954	 0.01252	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	33802	 86595	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86596	 33802	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33803	 33805	 0.005188	 0.015295	 0.00356	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33803	 33808	 0.004736	 0.013284	 0.00342	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33804	 33806	 0.000836	 0.008917	 0.01813	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33804	 86597	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86598	 33804	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86597	 33805	 0.00131	 0.007672	 0.00209	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33806	 86599	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33806	 86599	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86598	 33807	 0.033895	 0.087132	 0.00135	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33808	 33809	 0.003543	 0.009362	 0.00219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33809	 33942	 0.002388	 0.008646	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33809	 86600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33809	 86600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33810	 86601	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33810	 86601	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86601	 33812	 0.11268	 0.088331	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33813	 33815	 0.008227	 0.022941	 0.00482	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33813	 86602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33813	 86602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33814	 86603	 0.027758	 0.079614	 0.00122	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33815	 86603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33815	 86603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33816	 34144	 0.006467	 0.050308	 0.01307	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33816	 86604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33816	 86604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33817	 86605	 0.019938	 0.10623	 0.00186	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	33818	 33819	 0.000904	 0.014703	 0.02903	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33818	 86605	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33818	 86605	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33820	 86606	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33820	 86606	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33821	 33822	 0.001389	 0.012304	 0.00328	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33821	 33825	 0.001123	 0.009445	 0.0028	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33821	 86607	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33821	 86607	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33822	 33823	 0.001986	 0.016702	 0.00495	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84767	 33823	 0.002712	 0.026869	 0.00823	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33824	 33826	 0.0012	 0.008233	 0.0024	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33824	 33831	 0.001892	 0.012692	 0.00306	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33824	 86608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33824	 86608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33825	 33826	 0.001755	 0.006827	 0.00182	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33826	 33828	 0.003877	 0.02053	 0.0052	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33827	 86609	 0.056539	 0.042836	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33828	 33829	 0.002407	 0.011043	 0.00283	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84767	 33828	 0.007	 0.056241	 0.01581	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33828	 86609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33828	 86609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33829	 33830	 0.004942	 0.022251	 0.00592	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33830	 86610	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33830	 86610	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33831	 33836	 0.002471	 0.01287	 0.00338	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33832	 33833	 0.068832	 0.050642	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33832	 33838	 0.016338	 0.053917	 0.00087	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86609	 33832	 0.015224	 0.081116	 0.00142	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	33834	 33836	 0.003039	 0.012168	 0.00307	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33834	 86611	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33834	 86611	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33835	 33838	 0.013617	 0.045426	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86347	 33835	 0.028853	 0.068324	 0.00125	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86349	 33835	 0.016866	 0.046719	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86611	 33837	 0.047239	 0.037028	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86610	 33838	 0.047496	 0.1208	 0.00191	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33839	 33840	 0.045175	 0.089445	 0.00131	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86525	 33839	 0.03259	 0.054901	 0.00078	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86170	 33840	 0.025888	 0.10071	 0.00168	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86171	 33841	 0.006574	 0.056391	 0.01605	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33841	 86612	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33841	 86612	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33842	 33843	 0.095337	 0.07545	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86612	 33842	 0.02547	 0.070458	 0.00164	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86527	 33844	 0.032833	 0.093171	 0.00146	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86612	 33844	 0.016925	 0.069172	 0.0014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33845	 86613	 0.10548	 0.076253	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33846	 33847	 0.003662	 0.024563	 0.00593	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33846	 33850	 0.002322	 0.024919	 0.00649	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84800	 33846	 0.00818	 0.065726	 0.01848	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33846	 86613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33846	 86613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33848	 33849	 0.046233	 0.094615	 0.00233	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86613	 33849	 0.036525	 0.086492	 0.00158	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33850	 86614	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33850	 86614	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33851	 34109	 0.062592	 0.16091	 0.00249	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33851	 86615	 0.051215	 0.13166	 0.00204	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33852	 33853	 0.00856	 0.033645	 0.0088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33852	 86615	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33852	 86615	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33853	 33854	 0.008506	 0.033092	 0.00884	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33854	 86616	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33854	 86616	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33855	 33858	 0.002519	 0.024606	 0.00691	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33855	 33965	 0.002492	 0.025393	 0.00654	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33856	 86644	 0.13733	 0.10869	 0.00137	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33857	 34058	 0.066929	 0.15537	 0.00296	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86566	 33857	 0.082416	 0.23642	 0.00364	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33858	 34056	 0.004857	 0.028448	 0.00775	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33858	 34057	 0.003285	 0.01924	 0.00524	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86373	 33859	 0.056439	 0.13104	 0.00195	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86609	 33859	 0.090108	 0.23167	 0.00359	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33859	 86617	 0.055138	 0.12611	 0.00308	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33860	 33863	 0.002594	 0.020709	 0.0051	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33860	 86617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33860	 86617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33862	 33863	 0.00248	 0.015973	 0.00419	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33862	 86618	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33862	 86618	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33863	 86619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33863	 86619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33864	 86620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33864	 86620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86620	 33865	 0.035498	 0.065019	 0.00112	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33866	 34140	 0.010526	 0.058028	 0.01357	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33867	 33868	 0.18978	 0.12288	 0.00234	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86336	 33867	 0.11049	 0.28409	 0.0044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84819	 33869	 0.051974	 0.11941	 0.00181	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33869	 86621	 0.048491	 0.11258	 0.00167	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84818	 33870	 0.005661	 0.028939	 0.00789	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33870	 86621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33870	 86621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86621	 33871	 0.088326	 0.14479	 0.00256	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84772	 33872	 0.00959	 0.048189	 0.01254	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84773	 33873	 0.13777	 0.14069	 0.00219	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33874	 33972	 0.016683	 0.058384	 0.01935	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33875	 33876	 0.008721	 0.034917	 0.0088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84851	 33875	 0.015647	 0.097267	 0.02747	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33875	 86622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33875	 86622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33876	 34028	 0.011167	 0.040438	 0.00868	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33876	 86623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33876	 86623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86622	 33877	 0.15784	 0.12109	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33878	 33879	 0.054795	 0.11214	 0.00276	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86623	 33878	 0.045075	 0.11587	 0.00179	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33880	 86624	 0.10027	 0.16724	 0.00243	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33880	 86648	 0.14472	 0.32842	 0.00655	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33880	 86692	 0.086004	 0.24671	 0.00379	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33881	 86624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33881	 86624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33882	 33883	 0.029175	 0.022869	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33882	 33889	 0.01989	 0.015257	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33883	 86625	 0.011784	 0.012032	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33884	 33896	 0.002496	 0.008563	 0.00205	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33884	 33928	 0.001063	 0.004501	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33884	 86625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33884	 86625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33885	 33886	 0.021622	 0.017111	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33886	 33887	 0.013391	 0.00968	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33886	 33893	 0.024904	 0.018003	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33886	 86633	 0.003251	 0.008357	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33888	 33891	 0.01713	 0.013427	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86625	 33888	 0.012714	 0.013577	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33889	 33890	 0.019769	 0.015645	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33890	 33894	 0.006298	 0.022038	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33890	 33904	 0.006657	 0.015455	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33890	 86633	 0.053172	 0.053329	 0.00086	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33891	 33904	 0.027475	 0.021743	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33892	 33893	 0.013748	 0.0089	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33894	 33895	 0.003994	 0.014269	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33894	 33908	 0.007683	 0.032996	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33894	 86627	 0.004971	 0.02075	 0.0006	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	33895	 86627	 0.004254	 0.016548	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33896	 86626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33896	 86626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33897	 33899	 0.005718	 0.019074	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33897	 86627	 0.018577	 0.041117	 0.00067	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33898	 33901	 0.000827	 0.004115	 0.00133	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86626	 33899	 0.006836	 0.017572	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86626	 33900	 0.012047	 0.030967	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33900	 86627	 0.008008	 0.020585	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33901	 86627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33901	 86627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33902	 33903	 0.031253	 0.047877	 0.00067	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86627	 33902	 0.027327	 0.027904	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33903	 33906	 0.01656	 0.042115	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86286	 33903	 0.013064	 0.050053	 0.00141	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33903	 86629	 0.069359	 0.13733	 0.00202	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33904	 33905	 0.005811	 0.017846	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33905	 86629	 0.011965	 0.042743	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33906	 33913	 0.010361	 0.023803	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33907	 86628	 0.037661	 0.029805	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33908	 33913	 0.016869	 0.030131	 0.00044	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33908	 86628	 0.013205	 0.043577	 0.00071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33909	 86628	 0.023903	 0.018736	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33910	 33914	 0.009755	 0.018137	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33910	 33919	 0.008789	 0.020405	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33910	 86628	 0.012533	 0.022527	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33911	 33912	 0.001824	 0.004736	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33911	 86628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33911	 86628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33912	 33916	 0.001765	 0.011177	 0.00303	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33912	 86629	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33912	 86629	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33913	 33914	 0.009927	 0.0204	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33913	 33917	 0.043183	 0.033849	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84857	 33915	 0.00125	 0.009041	 0.00486	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33915	 86630	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33915	 86630	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84758	 33916	 0.012513	 0.081843	 0.02082	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33916	 86631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33916	 86631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33917	 33918	 0.029113	 0.02304	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86629	 33918	 0.079829	 0.074863	 0.00116	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33919	 33920	 0.00881	 0.023289	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86629	 33919	 0.049542	 0.05004	 0.00066	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33920	 33922	 0.012002	 0.027447	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33921	 33922	 0.007981	 0.021152	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33921	 86632	 0.022092	 0.085946	 0.00143	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33922	 33925	 0.02447	 0.04845	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86631	 33922	 0.041918	 0.097321	 0.00145	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84758	 33923	 0.03098	 0.11784	 0.03302	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33923	 86632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33923	 86632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33924	 33925	 0.085119	 0.065293	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84824	 33927	 0.087825	 0.069505	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84857	 33928	 0.003089	 0.017748	 0.00503	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33928	 86633	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33928	 86633	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33929	 33938	 0.014535	 0.041689	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33929	 86634	 0.046899	 0.047037	 0.00076	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33930	 86637	 0.033815	 0.059469	 0.00112	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33930	 86682	 0.051327	 0.080089	 0.00134	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33931	 33937	 0.004003	 0.015731	 0.00412	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33931	 86634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33931	 86634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33932	 86635	 0.022824	 0.033258	 0.00075	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33933	 33940	 0.003499	 0.014011	 0.00353	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86319	 33933	 0.013023	 0.066533	 0.01674	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33933	 86635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33933	 86635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33934	 33935	 0.001469	 0.006613	 0.00176	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33934	 33937	 0.001583	 0.006157	 0.00164	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33934	 86636	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33934	 86636	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86595	 33935	 0.002575	 0.011474	 0.00312	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86596	 33936	 0.016645	 0.044001	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33936	 86638	 0.017042	 0.039152	 0.00059	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33937	 86637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33937	 86637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86635	 33938	 0.012914	 0.029533	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86637	 33938	 0.012887	 0.023962	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33939	 33941	 0.02846	 0.06099	 0.00107	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33940	 33942	 0.00272	 0.007801	 0.00192	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33940	 86638	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33940	 86638	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86600	 33941	 0.079032	 0.086928	 0.00116	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86600	 33943	 0.025445	 0.020137	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33944	 33945	 0.021728	 0.10608	 0.00222	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	33944	 86652	 0.034178	 0.19935	 0.004	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33945	 33975	 0.023265	 0.081457	 0.00226	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	33946	 33947	 0.007468	 0.04592	 0.01324	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33946	 86639	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33946	 86639	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33947	 33950	 0.004849	 0.025703	 0.00858	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33948	 33949	 0.090298	 0.1788	 0.00262	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86353	 33948	 0.23583	 0.50583	 0.00886	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33948	 86726	 0.066588	 0.32504	 0.00561	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33950	 86640	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33950	 86640	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33951	 86641	 0.067681	 0.12212	 0.00177	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33952	 86641	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33952	 86641	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86641	 33953	 0.030539	 0.10188	 0.00161	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33954	 33958	 0.004983	 0.016624	 0.00422	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33955	 33963	 0.004686	 0.020394	 0.00581	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33955	 86642	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33955	 86642	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33956	 86643	 0.034045	 0.026686	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33957	 33958	 0.002923	 0.010332	 0.00233	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	33957	 33962	 0.003445	 0.012053	 0.00399	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33957	 86643	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33957	 86643	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33959	 33960	 0.004333	 0.01988	 0.00509	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33959	 86644	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33959	 86644	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33960	 33965	 0.003081	 0.012719	 0.00301	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86642	 33961	 0.011713	 0.066584	 0.0012	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33961	 86645	 0.002822	 0.014362	 0.00033	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	33962	 33965	 0.002836	 0.015734	 0.00478	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33962	 86645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33962	 86645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33963	 86646	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33963	 86646	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86645	 33964	 0.015795	 0.036287	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86646	 33964	 0.028329	 0.06577	 0.00098	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33964	 86647	 0.011076	 0.040952	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33965	 86647	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33965	 86647	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33966	 33968	 0.024844	 0.063864	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86488	 33966	 0.038679	 0.091593	 0.00167	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86383	 33967	 0.13192	 0.20211	 0.00284	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33968	 33969	 0.014043	 0.035715	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33969	 33970	 0.050503	 0.050515	 0.00068	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86489	 33970	 0.064172	 0.2141	 0.00339	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33970	 86970	 0.098688	 0.25373	 0.00393	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33971	 86691	 0.21915	 0.14191	 0.0027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33972	 86648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33972	 86648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33973	 86649	 0.05083	 0.091717	 0.00133	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33974	 33979	 0.001123	 0.013279	 0.00378	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33974	 33992	 0.013395	 0.099601	 0.03802	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33974	 86649	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33974	 86649	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33975	 33976	 0.061429	 0.12912	 0.00235	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33975	 33978	 0.022976	 0.054407	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86564	 33975	 0.038653	 0.21995	 0.00677	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86649	 33975	 0.036198	 0.093053	 0.00144	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33976	 86655	 0.099241	 0.22803	 0.00346	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	33977	 33979	 0.004508	 0.023963	 0.00556	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33977	 86650	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33977	 86650	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86649	 33978	 0.024719	 0.063542	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33979	 86651	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33979	 86651	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86651	 33980	 0.18102	 0.14327	 0.0018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	33982	 33983	 0.008716	 0.034257	 0.00896	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33982	 34059	 0.012753	 0.058513	 0.01499	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84805	 33983	 0.005253	 0.031767	 0.00811	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33984	 34100	 0.027197	 0.15474	 0.00476	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86458	 33984	 0.049789	 0.1661	 0.00263	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33984	 86702	 0.061757	 0.22065	 0.00438	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33985	 33986	 0.035373	 0.13762	 0.0023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33985	 33986	 0.035373	 0.13762	 0.0023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33985	 34020	 0.015707	 0.13067	 0.00247	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33986	 33987	 0.03471	 0.10649	 0.00288	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33986	 33987	 0.03471	 0.10649	 0.00288	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33987	 33989	 0.038075	 0.16967	 0.00288	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84765	 33987	 0.052431	 0.16086	 0.00436	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84765	 33987	 0.052431	 0.16086	 0.00436	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33988	 33989	 0.044871	 0.14808	 0.0024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33990	 33992	 0.007428	 0.043513	 0.01185	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33990	 34061	 0.005848	 0.036337	 0.01026	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33992	 86652	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33992	 86652	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33993	 34115	 0.005305	 0.031602	 0.00831	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33993	 86653	 0.007569	 0.039386	 0.0116	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86337	 33994	 0.045396	 0.13927	 0.00377	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33994	 86654	 0.055361	 0.17003	 0.00319	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84771	 33995	 0.010474	 0.10499	 0.35359	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	33995	 86653	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86654	 33995	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33996	 33997	 0.001953	 0.013099	 0.00316	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33996	 34113	 0.007514	 0.047598	 0.01292	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33996	 86655	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33996	 86655	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33997	 33998	 0.004178	 0.026915	 0.00706	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	33997	 86656	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33997	 86656	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33998	 33999	 0.005022	 0.028853	 0.00817	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	33998	 86657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	33998	 86657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34000	 34001	 0.058509	 0.10557	 0.00153	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86569	 34000	 0.10448	 0.17452	 0.00296	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34001	 86658	 0.033999	 0.097516	 0.0015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34002	 34003	 0.040461	 0.093922	 0.00179	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34002	 34004	 0.057334	 0.11352	 0.00167	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86284	 34002	 0.037836	 0.18465	 0.00319	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86177	 34003	 0.042951	 0.09743	 0.00194	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34004	 86658	 0.032276	 0.08297	 0.00128	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34005	 34008	 0.005565	 0.024901	 0.00051	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34005	 86658	 0.011525	 0.050777	 0.00088	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34006	 34007	 0.00885	 0.036543	 0.00865	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34006	 86658	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34006	 86658	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34007	 86659	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34007	 86659	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34008	 34009	 0.034975	 0.080354	 0.00122	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34009	 34010	 0.16397	 0.12978	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86659	 34009	 0.036899	 0.084389	 0.00206	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34011	 34013	 0.003607	 0.020947	 0.00493	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34011	 34046	 0.007478	 0.044553	 0.01172	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34012	 34017	 0.10398	 0.07517	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34013	 34016	 0.002706	 0.014419	 0.00405	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34013	 86660	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34013	 86660	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34014	 34015	 0.016768	 0.065233	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86660	 34014	 0.007107	 0.038309	 0.00077	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34016	 34019	 0.002621	 0.013337	 0.00483	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34017	 34018	 0.065575	 0.089392	 0.00198	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86660	 34017	 0.007271	 0.0324	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34019	 86661	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34019	 86661	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34020	 86663	 0.012206	 0.10137	 0.00248	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34021	 34022	 9.6e-05	 0.001288	 0.08824	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34021	 34023	 7.7e-05	 0.001378	 0.09782	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34022	 34023	 5.4e-05	 0.000718	 0.04921	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34022	 86662	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34022	 86662	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34023	 34024	 4.8e-05	 0.000796	 0.06976	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34023	 86663	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34023	 86663	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34024	 34025	 0.000115	 0.001893	 0.16602	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34026	 34054	 0.14528	 0.11498	 0.00145	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34027	 34028	 0.007461	 0.028363	 0.00794	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34027	 34052	 0.008392	 0.03053	 0.00935	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34029	 34030	 0.030967	 0.10836	 0.00224	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34031	 34037	 0.005379	 0.026107	 0.00597	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84785	 34031	 0.006322	 0.05751	 0.01452	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34031	 86664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34031	 86664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34032	 34035	 0.002681	 0.021125	 0.00618	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34032	 86665	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34032	 86665	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86665	 34033	 0.18695	 0.12105	 0.0023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34034	 86669	 0.032671	 0.035585	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34035	 34041	 0.002513	 0.014717	 0.00401	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34035	 86666	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34035	 86666	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86666	 34036	 0.014455	 0.021064	 0.00048	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34037	 34038	 0.004187	 0.014107	 0.00351	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34037	 86667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34037	 86667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34038	 34039	 0.005603	 0.018879	 0.00469	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34039	 86668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34039	 86668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86667	 34040	 0.039142	 0.11108	 0.00175	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34040	 86669	 0.013811	 0.027067	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34040	 86670	 0.098813	 0.078202	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34041	 34042	 0.003828	 0.013862	 0.00297	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34041	 86669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34041	 86669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34042	 34043	 0.007341	 0.021054	 0.00518	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84785	 34042	 0.010042	 0.069657	 0.04086	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34042	 86670	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34042	 86670	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34043	 86671	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34043	 86671	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86565	 34044	 0.07221	 0.16766	 0.00249	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86668	 34044	 0.016453	 0.08029	 0.00139	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34045	 34046	 0.005694	 0.035338	 0.00856	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34046	 86672	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34046	 86672	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86522	 34048	 0.18371	 0.1454	 0.00183	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34049	 34050	 0.036396	 0.10328	 0.00162	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34049	 34053	 0.060834	 0.086231	 0.00176	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34050	 34054	 0.042851	 0.10636	 0.00177	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34051	 86673	 0.042341	 0.16291	 0.00278	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34052	 86673	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34052	 86673	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86673	 34054	 0.020183	 0.098492	 0.0017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86646	 34055	 0.084286	 0.32437	 0.00554	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34055	 86675	 0.032938	 0.078564	 0.00176	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34056	 34057	 0.001918	 0.010902	 0.00316	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34056	 86674	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34056	 86674	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86674	 34058	 0.046044	 0.1069	 0.00159	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34060	 34061	 0.004105	 0.031933	 0.0083	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34060	 86675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34060	 86675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34061	 86676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34061	 86676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34063	 34064	 0.013999	 0.03315	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34063	 38843	 0.012688	 0.064182	 0.00112	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34064	 34065	 0.058393	 0.042212	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34066	 34068	 0.087527	 0.069269	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34067	 34068	 0.023549	 0.05845	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34068	 86677	 0.062621	 0.17962	 0.00276	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34069	 34070	 0.033121	 0.084233	 0.00133	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34070	 86677	 0.029352	 0.060068	 0.00148	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34071	 34073	 0.004039	 0.014133	 0.00468	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34071	 86677	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34071	 86677	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86677	 34072	 0.058633	 0.1074	 0.00185	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34074	 34131	 0.16877	 0.13357	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84794	 34075	 0.00304	 0.017436	 0.0058	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34076	 34077	 0.029501	 0.069859	 0.00128	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84783	 34077	 0.004725	 0.016141	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84783	 34077	 0.004725	 0.016141	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84795	 34077	 0.005341	 0.020034	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84795	 34077	 0.005341	 0.020034	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34078	 86678	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34078	 86678	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34079	 34081	 0.003979	 0.014063	 0.00317	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34079	 34084	 0.003152	 0.011412	 0.00245	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86678	 34079	 0.00281	 0.015418	 0.00408	 212.0	 212.0	 212.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34079	 86679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34079	 86679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34080	 86681	 0.068803	 0.05445	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34082	 86680	 0.036259	 0.047655	 0.00065	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34083	 34084	 0.003529	 0.012107	 0.0029	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34083	 34087	 0.00337	 0.016356	 0.00374	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34083	 86680	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34083	 86680	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34084	 86681	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34084	 86681	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86679	 34085	 0.07494	 0.059307	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34086	 86683	 0.13418	 0.097005	 0.00147	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34087	 86682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34087	 86682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34088	 34089	 0.005575	 0.022321	 0.00562	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84782	 34088	 0.002718	 0.015616	 0.00442	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34088	 86683	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34088	 86683	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34090	 34091	 0.00892	 0.035716	 0.009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34091	 34111	 0.073671	 0.19812	 0.04499	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34091	 86684	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34091	 86684	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34092	 34093	 0.028825	 0.022812	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34092	 34094	 0.039566	 0.031013	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34092	 34095	 0.016694	 0.064946	 0.00108	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86616	 34092	 0.066199	 0.15677	 0.00287	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86684	 34092	 0.054507	 0.15634	 0.0024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34093	 34096	 0.033175	 0.026004	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34095	 86685	 0.047051	 0.09316	 0.00137	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86244	 34097	 0.11038	 0.2838	 0.00439	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34097	 86685	 0.083354	 0.19152	 0.00291	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34098	 34111	 0.060546	 0.1602	 0.03755	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34098	 86685	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34098	 86685	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86444	 34100	 0.038148	 0.2101	 0.00474	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84771	 34101	 0.003609	 0.035555	 0.07582	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34102	 34105	 0.006299	 0.034562	 0.00914	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84780	 34102	 0.00344	 0.035737	 0.01105	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34102	 86686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34102	 86686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84811	 34103	 0.006126	 0.036771	 0.01113	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34103	 86687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34103	 86687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86687	 34104	 0.037356	 0.14533	 0.00243	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34106	 86688	 0.043119	 0.14385	 0.00228	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34107	 34108	 0.005676	 0.018934	 0.0048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34107	 86688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34107	 86688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34108	 86689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34108	 86689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86689	 34109	 0.059094	 0.10988	 0.00257	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34109	 86690	 0.085451	 0.21735	 0.00344	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86689	 34110	 0.0095	 0.050617	 0.00089	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34110	 86690	 0.045336	 0.15125	 0.0024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34111	 86690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34111	 86690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34112	 34113	 0.005565	 0.033154	 0.00872	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34112	 86691	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34112	 86691	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34113	 86692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34113	 86692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34114	 86693	 0.054782	 0.12586	 0.00191	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34115	 86693	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34115	 86693	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86673	 34116	 0.14759	 0.16235	 0.00217	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34117	 34120	 0.004091	 0.023964	 0.00653	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34118	 34119	 0.04196	 0.10786	 0.00167	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86491	 34119	 0.099857	 0.24447	 0.00418	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34121	 34124	 0.023388	 0.090986	 0.00152	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86573	 34121	 0.03029	 0.092926	 0.00252	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34121	 88288	 0.076038	 0.20103	 0.00365	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34122	 34125	 0.047912	 0.094864	 0.00139	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86574	 34122	 0.10751	 0.24965	 0.00371	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34122	 88451	 0.101	 0.19796	 0.00297	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34123	 86694	 0.084589	 0.062236	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34124	 86694	 0.014815	 0.060548	 0.00122	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34125	 86695	 0.013288	 0.034159	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34126	 34133	 0.001587	 0.006717	 0.00151	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34126	 86694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34126	 86694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34127	 34128	 0.0025	 0.013025	 0.00342	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34127	 86695	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34127	 86695	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34128	 86696	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34128	 86696	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34128	 86697	 0.002977	 0.019468	 0.00495	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86695	 34129	 0.053469	 0.038653	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34130	 34137	 0.032227	 0.097001	 0.0019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34131	 86700	 0.037007	 0.059071	 0.00136	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34132	 34137	 0.007424	 0.0228	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86695	 34132	 0.030818	 0.071549	 0.00106	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86696	 34132	 0.010887	 0.020849	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34133	 34136	 0.001113	 0.004455	 0.00112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34134	 86698	 0.012558	 0.048854	 0.00082	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34135	 38846	 0.006203	 0.040286	 0.08031	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34135	 38861	 0.007091	 0.050194	 0.10641	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34135	 86697	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86698	 34135	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86697	 34136	 0.001572	 0.008146	 0.00199	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86698	 34137	 0.009029	 0.045941	 0.00104	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34138	 86699	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86700	 34138	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34139	 34142	 0.007145	 0.029074	 0.00708	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34140	 34142	 0.006859	 0.043446	 0.01179	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86300	 34141	 0.16522	 0.13077	 0.00165	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34142	 86701	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34142	 86701	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34143	 34145	 0.048255	 0.13694	 0.00215	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86359	 34143	 0.061632	 0.17491	 0.00275	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86457	 34144	 0.007519	 0.052173	 0.01489	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34144	 86702	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34144	 86702	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34145	 86703	 0.035073	 0.1006	 0.00155	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84815	 34146	 0.024767	 0.10083	 0.02458	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86556	 34146	 0.012695	 0.070456	 0.02142	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34146	 86703	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34146	 86703	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34147	 86704	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34147	 86704	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86705	 34148	 0.004812	 0.029862	 0.00723	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86706	 34149	 0.060006	 0.14895	 0.00248	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34150	 34151	 0.034213	 0.13362	 0.00296	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34151	 34153	 0.037748	 0.087625	 0.00167	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34152	 34153	 0.061764	 0.17716	 0.00272	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34153	 34154	 0.039762	 0.13265	 0.0021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86343	 34153	 0.026673	 0.10675	 0.00225	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34155	 34226	 0.006936	 0.023369	 0.00581	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34155	 86707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34155	 86707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34156	 34157	 0.00735	 0.04379	 0.01152	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34156	 34227	 0.004892	 0.027146	 0.00825	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34156	 86708	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34156	 86708	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34157	 34160	 0.002883	 0.032439	 0.00852	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34157	 34228	 0.005342	 0.025237	 0.00808	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34158	 34159	 0.00444	 0.025242	 0.00731	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34158	 34690	 0.00661	 0.037433	 0.00928	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34158	 86709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34158	 86709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34159	 34695	 0.010868	 0.042282	 0.01129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84815	 34159	 0.004604	 0.049702	 0.01703	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84815	 34160	 0.002692	 0.030293	 0.00796	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34161	 34904	 0.003268	 0.04028	 0.01301	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34161	 86710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34161	 86710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34161	 86711	 0.002544	 0.033106	 0.00957	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34162	 34185	 0.000904	 0.008905	 0.01898	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34162	 86711	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34162	 86711	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34163	 34164	 0.006703	 0.018692	 0.00392	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34163	 34165	 0.004615	 0.022057	 0.00772	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34163	 86832	 0.009748	 0.061752	 0.01676	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34164	 86712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34164	 86712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34165	 86713	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34165	 86713	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34165	 86717	 0.004994	 0.030991	 0.00751	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34166	 34168	 0.003904	 0.013024	 0.0033	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34166	 34525	 0.006378	 0.024243	 0.00679	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34166	 86714	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34166	 86714	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86713	 34167	 0.017402	 0.057427	 0.00093	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86714	 34167	 0.009328	 0.036288	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34168	 34169	 0.002215	 0.007721	 0.00179	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34169	 86715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34169	 86715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34170	 34172	 0.014144	 0.02552	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86633	 34170	 0.017398	 0.040392	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86715	 34170	 0.006497	 0.032495	 0.00058	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34170	 86718	 0.010215	 0.034077	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86626	 34171	 0.008463	 0.024273	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86715	 34171	 0.00832	 0.023862	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86633	 34172	 0.008406	 0.019515	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84857	 34173	 0.006073	 0.015766	 0.00383	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34173	 86716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34173	 86716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34174	 34185	 0.002485	 0.020747	 0.03604	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34174	 86717	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34174	 86717	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34175	 86718	 0.004581	 0.034807	 0.00079	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34175	 86719	 0.005188	 0.035198	 0.00066	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84857	 34176	 0.004259	 0.017042	 0.00576	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34176	 86718	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34176	 86718	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34177	 34178	 0.001889	 0.007561	 0.0019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86717	 34177	 0.004667	 0.015725	 0.00391	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34177	 86719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34177	 86719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34178	 34182	 0.003945	 0.015793	 0.00398	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34179	 34180	 0.001974	 0.00665	 0.00165	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86717	 34179	 0.004798	 0.026329	 0.00696	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34179	 86720	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34179	 86720	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34180	 34184	 0.003481	 0.009984	 0.00246	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34181	 34184	 0.003475	 0.016209	 0.00401	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34181	 34193	 0.005395	 0.049077	 0.01239	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34181	 86721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34181	 86721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34182	 86722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34182	 86722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86720	 34183	 0.036183	 0.071639	 0.00105	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86722	 34183	 0.012961	 0.030089	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34183	 86723	 0.02549	 0.034747	 0.00077	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34184	 86723	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34184	 86723	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34184	 86724	 0.003392	 0.013578	 0.00342	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34185	 34521	 0.00312	 0.0384	 0.07156	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84757	 34185	 0.002791	 0.029383	 0.12747	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34185	 86724	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86725	 34185	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34186	 34190	 0.051969	 0.073775	 0.00121	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86721	 34186	 0.012749	 0.039109	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86725	 34186	 0.020457	 0.067509	 0.00109	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34187	 34188	 0.16127	 0.10834	 0.00191	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86710	 34187	 0.068606	 0.17638	 0.00273	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34189	 34240	 0.038357	 0.13422	 0.00278	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86725	 34189	 0.031548	 0.14117	 0.00291	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86721	 34191	 0.012642	 0.071864	 0.0013	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34191	 86726	 0.081717	 0.50278	 0.00907	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84824	 34192	 0.089396	 0.11098	 0.00242	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84758	 34193	 0.004354	 0.04815	 0.01444	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84769	 34194	 0.007871	 0.080212	 0.02068	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34194	 86726	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34194	 86726	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34195	 34238	 0.003913	 0.029076	 0.01109	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34195	 34703	 0.004194	 0.035271	 0.01045	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86639	 34196	 0.065298	 0.25126	 0.00429	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86726	 34196	 0.031946	 0.17951	 0.00332	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34196	 86898	 0.040195	 0.15638	 0.00261	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34196	 86898	 0.040195	 0.15638	 0.00261	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34197	 34198	 0.009771	 0.015597	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34197	 34201	 0.015296	 0.032778	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34197	 34203	 0.007693	 0.019775	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34199	 34231	 0.012362	 0.031777	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34199	 86743	 0.009713	 0.024701	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34200	 86740	 0.011626	 0.042986	 0.0008	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34200	 86743	 0.009029	 0.025011	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34201	 34231	 0.029381	 0.058173	 0.00085	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34201	 86727	 0.012081	 0.028608	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34201	 86740	 0.018617	 0.034617	 0.00081	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34202	 34204	 0.002095	 0.007185	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34202	 34232	 0.001198	 0.007015	 0.00191	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34202	 86727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34202	 86727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86727	 34203	 0.005998	 0.013922	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34204	 34220	 0.002184	 0.00644	 0.0015	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34205	 86735	 0.015822	 0.040672	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34206	 34207	 0.002832	 0.013966	 0.00378	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34206	 34669	 0.004339	 0.019905	 0.0051	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34206	 86728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34206	 86728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34206	 86730	 0.002903	 0.02787	 0.00811	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34207	 34987	 0.002941	 0.010651	 0.00229	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34208	 34985	 0.024642	 0.056357	 0.00138	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86728	 34208	 0.028666	 0.066551	 0.00099	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86728	 34209	 0.013461	 0.038609	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34209	 86884	 0.012459	 0.039951	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34210	 34211	 0.001808	 0.010499	 0.00247	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34210	 86730	 0.003581	 0.020799	 0.0049	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34210	 86883	 0.001714	 0.013135	 0.00352	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34211	 34222	 0.005361	 0.0308	 0.00872	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34211	 86729	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34211	 86729	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34212	 34224	 0.000513	 0.006507	 0.01241	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34213	 34665	 0.000859	 0.011556	 0.02408	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34213	 86730	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86731	 34213	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34214	 34992	 0.005977	 0.023931	 0.00603	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34214	 86732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34214	 86732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34215	 34216	 0.000837	 0.007082	 0.0138	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34215	 34941	 0.002735	 0.01918	 0.03266	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34215	 86733	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34215	 86733	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34216	 34230	 0.002446	 0.015496	 0.03246	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34216	 86734	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34216	 86734	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34217	 34218	 0.09903	 0.10893	 0.00145	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34218	 34234	 0.041684	 0.10601	 0.00168	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34218	 86742	 0.032936	 0.054707	 0.00116	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34219	 86741	 0.011576	 0.029756	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86734	 34220	 0.006677	 0.023272	 0.0054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34220	 86735	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34220	 86735	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86731	 34221	 0.03551	 0.09031	 0.00143	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86732	 34221	 0.047239	 0.093532	 0.00137	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34221	 86736	 0.017439	 0.050018	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34222	 34235	 0.002414	 0.013869	 0.00393	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34222	 86736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34222	 86736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34223	 34227	 0.003859	 0.022604	 0.00616	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34223	 86737	 0.001846	 0.014541	 0.00425	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34223	 86739	 0.005485	 0.027557	 0.00717	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34224	 34230	 0.00116	 0.014181	 0.02912	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34224	 86737	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86738	 34224	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84860	 34225	 0.013348	 0.082063	 0.00148	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86738	 34225	 0.007197	 0.056094	 0.00105	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86737	 34226	 0.005584	 0.024304	 0.00692	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84853	 34228	 0.004963	 0.024936	 0.00649	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34229	 86740	 0.022335	 0.052888	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34230	 86739	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86740	 34230	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86708	 34231	 0.061508	 0.23667	 0.00404	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86740	 34231	 0.017203	 0.044221	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34232	 34233	 0.00145	 0.007987	 0.00288	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34232	 86741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34232	 86741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84812	 34233	 0.006433	 0.039553	 0.01141	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34233	 86742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34233	 86742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84813	 34234	 0.014262	 0.078052	 0.00153	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86739	 34235	 0.002953	 0.01759	 0.00463	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34235	 86743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34235	 86743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34236	 34243	 0.000116	 0.001957	 0.20258	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34236	 86744	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34236	 86744	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84836	 34237	 0.009542	 0.038206	 0.00963	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34237	 86745	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34237	 86745	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86744	 34238	 0.004794	 0.041835	 0.01149	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34239	 34465	 0.02495	 0.1404	 0.00303	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86745	 34239	 0.02185	 0.10488	 0.00313	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34240	 34241	 0.029266	 0.11385	 0.0019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34240	 34241	 0.029266	 0.11385	 0.0019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34240	 34245	 0.068671	 0.2672	 0.00446	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34240	 34245	 0.068671	 0.2672	 0.00446	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34241	 34242	 0.035972	 0.12851	 0.00255	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34241	 34242	 0.035972	 0.12851	 0.00255	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84837	 34241	 0.058593	 0.18792	 0.00465	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84837	 34241	 0.058593	 0.18792	 0.00465	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34242	 86746	 0.026877	 0.10456	 0.00175	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34242	 86746	 0.026877	 0.10456	 0.00175	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34243	 34244	 8.8e-05	 0.001474	 0.15255	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34244	 86746	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34244	 86746	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84770	 34245	 0.04182	 0.13411	 0.00332	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84770	 34245	 0.04182	 0.13411	 0.00332	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34246	 34466	 0.003288	 0.04158	 0.02148	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34246	 86747	 0.001813	 0.021288	 0.01278	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34247	 34248	 0.020994	 0.05339	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34247	 86748	 0.015094	 0.04329	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34249	 34472	 0.000141	 0.003789	 0.31805	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34249	 34472	 0.000141	 0.003789	 0.31805	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 0	 -30.0	 30.0;
	34249	 86747	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34250	 34251	 0.019182	 0.037979	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34251	 34252	 0.009906	 0.038538	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34251	 34252	 0.009906	 0.038538	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34251	 86749	 0.010365	 0.040323	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34251	 86749	 0.010365	 0.040323	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34252	 34271	 0.037163	 0.13741	 0.00254	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34252	 34271	 0.037163	 0.13741	 0.00254	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34252	 34272	 0.009991	 0.089265	 0.00211	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34252	 86750	 0.008719	 0.032706	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34252	 86750	 0.008719	 0.032706	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34253	 34254	 0.001017	 0.007789	 0.00209	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86747	 34253	 0.001132	 0.008673	 0.00232	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34254	 34255	 0.002083	 0.009065	 0.00258	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34254	 86749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34254	 86749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34255	 86750	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34255	 86750	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34256	 34257	 0.013189	 0.051307	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34256	 34257	 0.013189	 0.051307	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34256	 86816	 0.053494	 0.18275	 0.00397	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34256	 86816	 0.053494	 0.18275	 0.00397	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34257	 34260	 0.086977	 0.077941	 0.00159	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34257	 34261	 0.058896	 0.11661	 0.00171	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86748	 34257	 0.020005	 0.077825	 0.0013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86748	 34257	 0.020005	 0.077825	 0.0013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86749	 34258	 0.008447	 0.041911	 0.001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86750	 34258	 0.007288	 0.032293	 0.00097	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34259	 34279	 0.002337	 0.023416	 0.0078	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86747	 34259	 0.002219	 0.036368	 0.01144	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34259	 86751	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34259	 86751	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34261	 34262	 0.092227	 0.05971	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34263	 34274	 0.023687	 0.092152	 0.00154	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34263	 34274	 0.023687	 0.092152	 0.00154	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34264	 34277	 0.015269	 0.14047	 0.00279	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34264	 86752	 0.024967	 0.083288	 0.00132	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34265	 34266	 0.057058	 0.040418	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34266	 34267	 0.007346	 0.045162	 0.00081	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34266	 34782	 0.011277	 0.082424	 0.00152	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34267	 34268	 0.005039	 0.030626	 0.00056	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34268	 86752	 0.010366	 0.040326	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34268	 86752	 0.010366	 0.040326	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84845	 34269	 0.013278	 0.070333	 0.01783	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34269	 86752	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34269	 86752	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86752	 34270	 0.023087	 0.045711	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86752	 34271	 0.012909	 0.050219	 0.00084	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86752	 34271	 0.012909	 0.050219	 0.00084	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34272	 34780	 0.010178	 0.099736	 0.00195	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34273	 34274	 0.04958	 0.039237	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34274	 34275	 0.005698	 0.030014	 0.00054	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34274	 34276	 0.010125	 0.055759	 0.00126	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34274	 34285	 0.031054	 0.020104	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34275	 34276	 0.007091	 0.031067	 0.00067	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34275	 34284	 0.038981	 0.030849	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34276	 34277	 0.006693	 0.020533	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34276	 34283	 0.003801	 0.027357	 0.0009	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86752	 34276	 0.012886	 0.1072	 0.00203	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34276	 86753	 0.00597	 0.055575	 0.00108	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34277	 34278	 0.007672	 0.029516	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34277	 34278	 0.007672	 0.029516	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86751	 34278	 0.027437	 0.10674	 0.00178	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86751	 34278	 0.027437	 0.10674	 0.00178	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34278	 86753	 0.004182	 0.020408	 0.00035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34279	 34280	 0.001165	 0.006039	 0.00147	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34279	 86753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34279	 86753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34280	 86754	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34280	 86754	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86754	 34281	 0.02246	 0.015087	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34282	 34283	 0.002359	 0.019588	 0.00048	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84875	 34282	 0.002037	 0.014662	 0.00048	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84835	 34286	 0.11475	 0.090812	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34287	 86760	 0.024132	 0.10689	 0.00244	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34287	 86823	 0.030432	 0.173	 0.00313	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34287	 86972	 0.15402	 0.20246	 0.00277	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34288	 34291	 0.006998	 0.028016	 0.00706	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84874	 34288	 0.004641	 0.018241	 0.00477	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34288	 86755	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34288	 86755	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84833	 34289	 0.0006	 0.006535	 0.02636	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34289	 86756	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34289	 86756	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86755	 34290	 0.15818	 0.10242	 0.00195	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34291	 86757	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34291	 86757	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34292	 34410	 0.088744	 0.20603	 0.00392	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86757	 34292	 0.073729	 0.22195	 0.00434	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34293	 34415	 0.024769	 0.043559	 0.00082	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34294	 34404	 0.004077	 0.019896	 0.00549	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84831	 34294	 0.003767	 0.02664	 0.00731	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84831	 34295	 0.002603	 0.023679	 0.00598	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34295	 86758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34295	 86758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84833	 34296	 0.001443	 0.015689	 0.0341	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34296	 86759	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86760	 34296	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86757	 34297	 0.11506	 0.11749	 0.00183	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34297	 86762	 0.016112	 0.02896	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34298	 34304	 0.00368	 0.023702	 0.00621	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86759	 34298	 0.004644	 0.022133	 0.00641	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34298	 86761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34298	 86761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34299	 86762	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34299	 86762	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84831	 34300	 0.003225	 0.022809	 0.00626	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34300	 86763	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34300	 86763	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34301	 34304	 0.003211	 0.015195	 0.00365	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34301	 86764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34301	 86764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34302	 34303	 0.003551	 0.020799	 0.00567	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34302	 34503	 0.004693	 0.016994	 0.00365	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34302	 86765	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34302	 86765	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34303	 34304	 0.002721	 0.011844	 0.00337	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86759	 34303	 0.00232	 0.020555	 0.00547	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34304	 34305	 0.00161	 0.00925	 0.00262	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34305	 34307	 0.00161	 0.009429	 0.00257	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34305	 86766	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34305	 86766	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34306	 34307	 0.001434	 0.004676	 0.00124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34306	 34507	 0.002505	 0.008441	 0.0021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34307	 86767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34307	 86767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34308	 34311	 0.013575	 0.038934	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34308	 34376	 0.019107	 0.034475	 0.0005	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34309	 34310	 0.007203	 0.018517	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34309	 34311	 0.012827	 0.025396	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34309	 34313	 0.012788	 0.02617	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86767	 34309	 0.009685	 0.024896	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86764	 34310	 0.021235	 0.046999	 0.00077	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86766	 34310	 0.019285	 0.049575	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34311	 34312	 0.026896	 0.021082	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86764	 34311	 0.008131	 0.041123	 0.0008	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34312	 34314	 0.018371	 0.01328	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34313	 34314	 0.025985	 0.016823	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34313	 34384	 0.019674	 0.035499	 0.00051	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34314	 34315	 0.014662	 0.016268	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34315	 34321	 0.010358	 0.026627	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84831	 34316	 0.00118	 0.00979	 0.00258	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34316	 86768	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34316	 86768	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86768	 34317	 0.007291	 0.033809	 0.0007	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34317	 86769	 0.005181	 0.01985	 0.00056	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34318	 34322	 0.006845	 0.012728	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34318	 86769	 0.005141	 0.015117	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34319	 34320	 0.025279	 0.019815	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86764	 34319	 0.055655	 0.055669	 0.00075	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34320	 34321	 0.010077	 0.028901	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86768	 34320	 0.01238	 0.047628	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34321	 34322	 0.005178	 0.012021	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34323	 86769	 0.013906	 0.015429	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34324	 34325	 0.001907	 0.005712	 0.00129	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34324	 86769	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34324	 86769	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34325	 34327	 0.001932	 0.006509	 0.00162	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34325	 86770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34325	 86770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34326	 34327	 0.000958	 0.003385	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34326	 34386	 0.001957	 0.006384	 0.00169	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34327	 86771	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34327	 86771	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86770	 34328	 0.023902	 0.023908	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34329	 86772	 0.001261	 0.007512	 0.00198	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34330	 34781	 0.004383	 0.065298	 0.24297	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34330	 86772	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86773	 34330	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34330	 86791	 0.001271	 0.011008	 0.02048	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34331	 34855	 0.007071	 0.020847	 0.00485	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84838	 34331	 0.028815	 0.072451	 0.01877	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34331	 86774	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34331	 86774	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34331	 86775	 0.00949	 0.033546	 0.00756	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34332	 34333	 0.002198	 0.01466	 0.02763	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34332	 34958	 0.001299	 0.015693	 0.03036	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34332	 86775	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34332	 86775	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34333	 34957	 0.001277	 0.014462	 0.02896	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34334	 86776	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34334	 86776	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34334	 86777	 0.001319	 0.003888	 0.0009	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34335	 34411	 0.012772	 0.011523	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86776	 34335	 0.004363	 0.008639	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34336	 34339	 0.004931	 0.008897	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34336	 34411	 0.004961	 0.007043	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86776	 34336	 0.003875	 0.008903	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34337	 86778	 0.010049	 0.007953	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34338	 86777	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86778	 34338	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34338	 86791	 0.001171	 0.00901	 0.01607	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34339	 34341	 0.002764	 0.006418	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34340	 34341	 0.015631	 0.012252	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34341	 34413	 0.007769	 0.010211	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86778	 34341	 0.00189	 0.007354	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86778	 34342	 0.003367	 0.008655	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34343	 34344	 0.000301	 0.001482	 0.0004	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34343	 34412	 0.000518	 0.002307	 0.00063	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34345	 34346	 0.003351	 0.025461	 0.00058	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34345	 34371	 0.003197	 0.030952	 0.00062	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34346	 34347	 0.011116	 0.023822	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86778	 34346	 0.005818	 0.035768	 0.00064	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34348	 34349	 0.050451	 0.039546	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86778	 34348	 0.043088	 0.10002	 0.0019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34350	 34352	 0.012811	 0.025365	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34351	 34352	 0.01061	 0.018951	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86776	 34352	 0.009465	 0.025087	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34353	 86779	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34353	 86779	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34353	 86796	 0.005102	 0.017782	 0.00412	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34354	 34355	 0.086372	 0.055919	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34354	 34357	 0.025705	 0.1	 0.00167	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34354	 34357	 0.025705	 0.1	 0.00167	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86779	 34354	 0.021119	 0.081251	 0.00139	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86779	 34354	 0.021119	 0.081251	 0.00139	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34356	 34357	 0.11806	 0.093433	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34357	 34358	 0.040129	 0.15439	 0.00264	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34357	 34358	 0.040129	 0.15439	 0.00264	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34358	 86816	 0.050326	 0.18881	 0.00339	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34358	 86816	 0.050326	 0.18881	 0.00339	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34359	 86781	 0.086036	 0.11103	 0.00223	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34360	 34416	 8.4e-05	 0.001902	 0.19	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34360	 34472	 0.000146	 0.003578	 0.36194	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34360	 34472	 0.000146	 0.003578	 0.36194	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 0	 -30.0	 30.0;
	34360	 86780	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34361	 34363	 0.004511	 0.015793	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34361	 86782	 0.003408	 0.01663	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34362	 34372	 0.024652	 0.01596	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34362	 86785	 0.006563	 0.016691	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84873	 34363	 0.004773	 0.021267	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34364	 86783	 0.004651	 0.018092	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34364	 86783	 0.004651	 0.018092	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34364	 86793	 0.006455	 0.024833	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34364	 86793	 0.006455	 0.024833	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34365	 34366	 0.000218	 0.00365	 0.00207	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34365	 34369	 0.002266	 0.007898	 0.00183	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34365	 86782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34365	 86782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34365	 86792	 0.000327	 0.005474	 0.0031	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34366	 34367	 0.000203	 0.003609	 0.00181	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34366	 86783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34366	 86783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34367	 86784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34367	 86784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34367	 86796	 0.000351	 0.006228	 0.00313	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34368	 34370	 0.01036	 0.018975	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34368	 34371	 0.006563	 0.032028	 0.00055	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86784	 34368	 0.002639	 0.01539	 0.00031	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34369	 86785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34369	 86785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86785	 34371	 0.003709	 0.018099	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86778	 34373	 0.039944	 0.031611	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34374	 34375	 0.002291	 0.005948	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34374	 86786	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34374	 86786	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34375	 34385	 0.001446	 0.005883	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34375	 86787	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34375	 86787	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34376	 34513	 0.009653	 0.02241	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34376	 86827	 0.012633	 0.042142	 0.00067	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34377	 34382	 0.007152	 0.021939	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34377	 34513	 0.023028	 0.045594	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34377	 86788	 0.025728	 0.055133	 0.00097	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34377	 86829	 0.011305	 0.037714	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34378	 34385	 0.001562	 0.007167	 0.00184	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34378	 86788	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34378	 86788	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34379	 86789	 0.019541	 0.028474	 0.00064	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34380	 34381	 0.000259	 0.004101	 0.00259	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34380	 34417	 0.000448	 0.007309	 0.00436	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34381	 34386	 0.001664	 0.006871	 0.00163	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34381	 86792	 0.000347	 0.005671	 0.0028	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34382	 34383	 0.004349	 0.013341	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34382	 34384	 0.007726	 0.028566	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86786	 34383	 0.005672	 0.027676	 0.00048	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84832	 34384	 0.020013	 0.11849	 0.00231	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34385	 86789	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34385	 86789	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34385	 86792	 0.001527	 0.015133	 0.00463	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34387	 34388	 0.001232	 0.003309	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34387	 86792	 0.002711	 0.015878	 0.00432	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34388	 34389	 0.001243	 0.003663	 0.00085	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34389	 34390	 0.001104	 0.003165	 0.00078	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34390	 86790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34390	 86790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34390	 86792	 0.00158	 0.009804	 0.00237	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34391	 34393	 0.004113	 0.015823	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34391	 86793	 0.003568	 0.02005	 0.00037	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34392	 34416	 5.8e-05	 0.000978	 0.10123	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34392	 86791	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34393	 34394	 0.006218	 0.018284	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34394	 34395	 0.003684	 0.018637	 0.00032	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34394	 34415	 0.001974	 0.007679	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86790	 34394	 0.005712	 0.022307	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34395	 34415	 0.011624	 0.026986	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84873	 34395	 0.001027	 0.005223	 0.00012	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34396	 34397	 0.007567	 0.021473	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34396	 34401	 0.019574	 0.04978	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86778	 34396	 0.016713	 0.066881	 0.00141	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34396	 86794	 0.001586	 0.015541	 0.0003	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34397	 34405	 0.011564	 0.027382	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34397	 34406	 0.025499	 0.01876	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34397	 34411	 0.016456	 0.047199	 0.00073	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34398	 34399	 0.016292	 0.041433	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84832	 34398	 0.05763	 0.177	 0.00332	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86758	 34398	 0.025312	 0.13334	 0.00239	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34398	 86795	 0.034564	 0.072645	 0.00132	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34399	 34409	 0.063397	 0.064736	 0.00101	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34400	 34402	 0.074208	 0.08083	 0.0011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34400	 34409	 0.032923	 0.025254	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34401	 34408	 0.057478	 0.045488	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34402	 86795	 0.008452	 0.027893	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34403	 34404	 0.002022	 0.007867	 0.0021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34403	 86794	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34403	 86794	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34404	 86795	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34404	 86795	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34405	 34407	 0.040504	 0.032054	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34410	 86858	 0.12385	 0.28761	 0.00428	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86778	 34411	 0.00352	 0.017176	 0.0003	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86777	 34412	 0.001121	 0.00456	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86793	 34415	 0.009048	 0.050837	 0.00094	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34416	 86796	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34416	 86796	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34417	 34418	 0.000891	 0.0139	 0.00908	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34417	 34519	 0.001776	 0.010094	 0.00292	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86780	 34418	 0.001001	 0.017109	 0.00928	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34419	 34420	 0.003582	 0.020804	 0.0049	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34419	 86797	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34419	 86797	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34420	 34422	 0.001193	 0.006989	 0.0019	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34420	 35127	 0.005492	 0.030475	 0.00926	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84849	 34421	 0.040566	 0.10276	 0.00204	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84867	 34421	 0.05103	 0.10104	 0.00148	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84848	 34423	 0.001479	 0.008209	 0.0025	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34423	 86798	 0.008341	 0.021654	 0.00526	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79564	 34424	 0.001658	 0.020021	 0.03873	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34424	 86798	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34424	 86798	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84858	 34425	 0.030218	 0.064517	 0.00146	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34426	 86799	 0.055589	 0.035989	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34427	 34429	 0.00453	 0.018137	 0.00457	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34427	 86799	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34427	 86799	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34428	 34430	 0.11994	 0.088251	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84849	 34428	 0.013287	 0.038109	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84867	 34428	 0.064745	 0.065395	 0.00087	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34429	 86800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34429	 86800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34431	 35191	 0.018144	 0.092327	 0.00209	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86800	 34431	 0.013063	 0.0699	 0.00212	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34432	 34434	 0.000879	 0.005661	 0.00148	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34432	 34437	 0.005631	 0.026837	 0.00777	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34432	 86801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34432	 86801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86801	 34433	 0.031251	 0.024731	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34434	 34435	 0.002848	 0.017509	 0.00505	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34435	 35236	 0.009895	 0.034624	 0.01147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34435	 86802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34435	 86802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34436	 35235	 0.27652	 0.21216	 0.00285	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34437	 34527	 0.009736	 0.048922	 0.01273	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34438	 86803	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86804	 34438	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34438	 87065	 0.00212	 0.021524	 0.06915	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34439	 34440	 0.008507	 0.068832	 0.00177	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86804	 34439	 0.021184	 0.075678	 0.0015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86804	 34439	 0.021184	 0.075678	 0.0015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34440	 87073	 0.012714	 0.08203	 0.00261	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86803	 34441	 0.012127	 0.041603	 0.00997	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84871	 34442	 0.013315	 0.030913	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34443	 34444	 0.006426	 0.025727	 0.00648	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34443	 86805	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34443	 86805	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34443	 86919	 0.020078	 0.07634	 0.02138	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34444	 34445	 0.009327	 0.039476	 0.00888	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34444	 86806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34444	 86806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34445	 34452	 0.011181	 0.043947	 0.0115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86806	 34446	 0.031656	 0.1056	 0.00167	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34446	 86807	 0.053553	 0.13767	 0.00213	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34447	 34449	 0.010076	 0.041005	 0.00999	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34447	 86807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34447	 86807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34448	 86808	 0.093615	 0.074088	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34449	 86808	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34449	 86808	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86808	 34450	 0.021144	 0.1202	 0.00217	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34450	 86957	 0.059924	 0.13445	 0.00214	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84865	 34451	 0.011533	 0.046178	 0.01163	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34451	 86809	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34451	 86809	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84865	 34452	 0.006657	 0.029976	 0.00798	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34453	 34454	 0.025631	 0.094771	 0.00175	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34453	 34560	 0.050724	 0.11777	 0.00175	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34453	 35166	 0.025661	 0.10488	 0.00212	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34454	 34455	 0.02885	 0.11224	 0.00187	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34455	 86810	 0.021059	 0.10951	 0.00237	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34456	 86810	 0.016768	 0.094215	 0.00174	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34456	 87054	 0.01797	 0.095748	 0.00168	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34457	 34459	 0.004489	 0.021786	 0.00498	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34457	 86810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34457	 86810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34458	 35200	 0.004541	 0.026599	 0.00725	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86756	 34458	 0.009329	 0.055582	 0.01462	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34458	 86811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34458	 86811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84834	 34459	 0.012386	 0.071048	 0.02362	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34459	 86812	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34459	 86812	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34460	 34461	 0.023953	 0.062079	 0.00117	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84835	 34460	 0.050902	 0.15617	 0.00423	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86811	 34460	 0.017883	 0.089917	 0.00244	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86812	 34461	 0.041809	 0.092536	 0.00152	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34461	 86813	 0.020227	 0.090132	 0.00153	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34462	 34463	 0.004649	 0.027232	 0.00742	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34462	 87053	 0.008331	 0.049632	 0.01306	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34463	 86813	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34463	 86813	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34463	 86971	 0.007787	 0.045611	 0.01243	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34464	 34467	 0.058054	 0.13479	 0.002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34464	 34966	 0.113	 0.23754	 0.00433	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34465	 34704	 0.023494	 0.14445	 0.0026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34466	 34469	 0.004297	 0.034522	 0.0097	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34466	 34470	 0.002614	 0.040154	 0.01123	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34466	 34705	 0.003779	 0.040054	 0.01189	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34467	 86814	 0.037319	 0.086642	 0.00129	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34468	 34469	 0.002009	 0.016138	 0.00454	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34468	 86814	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34468	 86814	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34470	 34471	 0.003426	 0.033473	 0.00939	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34471	 34498	 0.007962	 0.041478	 0.01088	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34471	 86815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34471	 86815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34472	 86816	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34472	 86816	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34473	 34474	 0.058846	 0.13661	 0.0026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34473	 34926	 0.14726	 0.19166	 0.00268	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34474	 86817	 0.025864	 0.073394	 0.00115	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84865	 34475	 0.006578	 0.023819	 0.00511	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34475	 86817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34475	 86817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34476	 34487	 0.009748	 0.044723	 0.01146	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84842	 34476	 0.001763	 0.016923	 0.00492	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34476	 86818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34476	 86818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34478	 86819	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86820	 34478	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86818	 34479	 0.031864	 0.056915	 0.00084	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86818	 34480	 0.015329	 0.087136	 0.00158	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34480	 86821	 0.018292	 0.08151	 0.00138	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86819	 34481	 0.004354	 0.025287	 0.00595	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34481	 86821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34481	 86821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34482	 34483	 0.022252	 0.044058	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34483	 34484	 0.005607	 0.028362	 0.00049	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34483	 34486	 0.008193	 0.025132	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34483	 34486	 0.008193	 0.025132	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86821	 34483	 0.007367	 0.053018	 0.00174	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86821	 34484	 0.007227	 0.044428	 0.0008	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86821	 34485	 0.067334	 0.1731	 0.00268	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34486	 86838	 0.020202	 0.070732	 0.00196	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34486	 86842	 0.021782	 0.076264	 0.00211	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34487	 86822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34487	 86822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34488	 34834	 0.059309	 0.13307	 0.00212	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86822	 34488	 0.050934	 0.089577	 0.00168	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34489	 34491	 0.031415	 0.083048	 0.00151	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34489	 34925	 0.039533	 0.13189	 0.00209	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34490	 34491	 0.033991	 0.13224	 0.00221	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34490	 34493	 0.030502	 0.13592	 0.00231	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34491	 34492	 0.046004	 0.088103	 0.00139	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34491	 86957	 0.043006	 0.23019	 0.00698	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34493	 34915	 0.021828	 0.097266	 0.00165	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34494	 34913	 0.057467	 0.14773	 0.00229	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34494	 86840	 0.034375	 0.15227	 0.00347	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34495	 34966	 0.10463	 0.26511	 0.00525	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84855	 34495	 0.041611	 0.096608	 0.00144	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84855	 34496	 0.022584	 0.13886	 0.0025	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34496	 86823	 0.024175	 0.098805	 0.002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34497	 86823	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34497	 86823	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34498	 86824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34498	 86824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86824	 34499	 0.019603	 0.068591	 0.00142	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86824	 34499	 0.019603	 0.068591	 0.00142	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34499	 86825	 0.004081	 0.036462	 0.00086	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34500	 34501	 0.045446	 0.041861	 0.00067	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34501	 34502	 0.00609	 0.026835	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34501	 34508	 0.012624	 0.092274	 0.0017	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34501	 86825	 0.026603	 0.075493	 0.00119	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34502	 34505	 0.007521	 0.025089	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34502	 34510	 0.008587	 0.02637	 0.00049	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34503	 34504	 0.001629	 0.006339	 0.00169	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84834	 34503	 0.005898	 0.085181	 0.02706	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34503	 86825	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34503	 86825	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34504	 86826	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34504	 86826	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86825	 34505	 0.017585	 0.044721	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86826	 34505	 0.003481	 0.018549	 0.00033	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34506	 34511	 0.009157	 0.023288	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86826	 34506	 0.010923	 0.028078	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34507	 86827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34507	 86827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86815	 34508	 0.025348	 0.15348	 0.00481	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34509	 34510	 0.009755	 0.017601	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34510	 86828	 0.006953	 0.012928	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86827	 34511	 0.014333	 0.032929	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34511	 86828	 0.006076	 0.023377	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34512	 34514	 0.002111	 0.005479	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34512	 86828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34512	 86828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34514	 34515	 0.001778	 0.004698	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34515	 34516	 0.001529	 0.006473	 0.00146	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34515	 86829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34515	 86829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34516	 34517	 0.001436	 0.00608	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34516	 86830	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34516	 86830	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34517	 34519	 0.001039	 0.006447	 0.00156	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34517	 86831	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34517	 86831	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86830	 34518	 0.021683	 0.028498	 0.00039	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34520	 86954	 0.16563	 0.13109	 0.00165	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34521	 86832	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86833	 34521	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34522	 34523	 0.041252	 0.12417	 0.00243	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86833	 34522	 0.059466	 0.17057	 0.00262	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34522	 87024	 0.026113	 0.11685	 0.00241	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34523	 34524	 0.023273	 0.090538	 0.00151	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34524	 86834	 0.012927	 0.073486	 0.00133	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34525	 86834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34525	 86834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34526	 35189	 0.009976	 0.059434	 0.01564	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84866	 34526	 0.005477	 0.034693	 0.00942	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34527	 34529	 0.005854	 0.032481	 0.00987	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34528	 34529	 0.007414	 0.029685	 0.00748	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34528	 35026	 0.008153	 0.032642	 0.00822	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34529	 86835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34529	 86835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34529	 86836	 0.00559	 0.036554	 0.0093	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34530	 86836	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34530	 86836	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34531	 86838	 0.011731	 0.027779	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34532	 34547	 0.011248	 0.041588	 0.00077	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34532	 86838	 0.017635	 0.045705	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34533	 86837	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86838	 34533	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86837	 34534	 0.00349	 0.009222	 0.00216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34534	 86839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34534	 86839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34535	 34540	 0.011592	 0.026911	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86837	 34536	 0.00962	 0.044134	 0.01131	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34536	 86840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34536	 86840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34537	 34539	 0.003469	 0.021972	 0.00596	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34538	 34551	 0.020186	 0.039966	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34538	 86844	 0.009224	 0.025549	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34539	 34541	 0.002078	 0.00926	 0.00252	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34539	 86841	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34539	 86841	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86841	 34540	 0.007009	 0.019389	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86837	 34541	 0.001672	 0.009708	 0.00229	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34541	 86842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34541	 86842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86841	 34542	 0.00221	 0.015172	 0.00028	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86842	 34542	 0.004763	 0.023243	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34542	 86844	 0.007894	 0.038521	 0.00066	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34543	 34545	 0.001623	 0.006606	 0.00161	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86837	 34543	 0.001514	 0.007348	 0.00168	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34543	 86843	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34543	 86843	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86843	 34544	 0.013622	 0.012206	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34545	 34546	 0.00176	 0.005741	 0.00152	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34546	 86844	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34546	 86844	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86822	 34547	 0.011087	 0.10734	 0.00215	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34547	 86845	 0.019579	 0.065313	 0.00104	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34548	 34549	 0.004517	 0.018087	 0.00456	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34548	 86845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34548	 86845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34549	 86846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34549	 86846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86846	 34550	 0.017473	 0.058289	 0.00092	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34550	 87057	 0.089776	 0.27577	 0.00518	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86846	 34552	 0.039197	 0.11243	 0.00173	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34552	 86847	 0.038699	 0.09842	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34553	 86847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34553	 86847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34553	 86856	 0.051491	 0.20654	 0.05217	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34554	 34555	 0.058568	 0.15056	 0.00233	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34554	 86849	 0.057085	 0.15091	 0.00274	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34555	 35195	 0.051049	 0.10447	 0.00257	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84861	 34555	 0.13919	 0.33215	 0.00745	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34556	 34558	 0.057882	 0.063664	 0.00085	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34557	 34559	 0.011749	 0.035186	 0.00793	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34557	 35193	 0.004028	 0.017532	 0.005	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34557	 86848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34557	 86848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86848	 34558	 0.02927	 0.067943	 0.00129	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34559	 86849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34559	 86849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86848	 34560	 0.049689	 0.096274	 0.00207	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34561	 34562	 0.019185	 0.046959	 0.0008	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34561	 35166	 0.059661	 0.15338	 0.00237	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86838	 34562	 0.1487	 0.16199	 0.00221	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86841	 34563	 0.035841	 0.026369	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34564	 35195	 0.12886	 0.13016	 0.00172	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34565	 35203	 0.001007	 0.015897	 0.03334	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84840	 34565	 0.000647	 0.009099	 0.03774	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34565	 86850	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34565	 86850	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34565	 86855	 0.00123	 0.012757	 0.02748	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34565	 86855	 0.00123	 0.012757	 0.02748	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34566	 35196	 0.19366	 0.15328	 0.00193	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34566	 86851	 0.033171	 0.10682	 0.00182	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34566	 87064	 0.042114	 0.18768	 0.00319	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34567	 86851	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34567	 86851	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34567	 86856	 0.006752	 0.023164	 0.00555	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34568	 34572	 0.003072	 0.037869	 0.01223	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34568	 86852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34568	 86852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34568	 86856	 0.000836	 0.011388	 0.00407	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34569	 86857	 0.29981	 0.23734	 0.00299	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34570	 34572	 0.003775	 0.026929	 0.00835	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34570	 34741	 0.001338	 0.010081	 0.0028	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34570	 86853	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34570	 86853	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86853	 34571	 0.012738	 0.047098	 0.00087	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34571	 86854	 0.014653	 0.065295	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34572	 86854	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34572	 86854	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86852	 34573	 0.048753	 0.096529	 0.00142	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86852	 34574	 0.10213	 0.084067	 0.0017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34575	 86855	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84841	 34576	 0.000894	 0.005996	 0.00145	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84841	 34577	 0.009551	 0.025243	 0.00591	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34577	 86858	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34577	 86858	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34578	 34585	 0.003978	 0.011409	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34578	 34590	 0.005221	 0.013421	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34579	 34580	 0.00726	 0.0131	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34579	 34582	 0.006731	 0.015627	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34580	 34613	 0.004473	 0.017403	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34580	 34686	 0.004052	 0.008291	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34581	 34613	 0.015247	 0.009871	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34582	 34585	 0.003337	 0.014931	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34582	 86864	 0.006314	 0.031747	 0.00086	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34583	 34610	 0.004234	 0.012143	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34583	 34615	 0.004328	 0.014437	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34584	 34585	 0.002667	 0.00707	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34584	 34618	 0.003426	 0.013179	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34585	 34587	 0.017383	 0.013756	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34586	 34619	 0.001064	 0.004261	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34586	 86859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34586	 86859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34588	 34603	 0.007312	 0.018149	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86859	 34588	 0.005565	 0.015961	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34589	 34590	 0.003961	 0.010181	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34589	 34688	 0.009469	 0.017019	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34591	 34592	 0.006952	 0.023192	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34591	 34688	 0.006676	 0.016978	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34592	 34593	 0.003811	 0.016981	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34592	 86877	 0.013008	 0.050046	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34593	 34594	 0.00873	 0.020672	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34593	 34608	 0.00841	 0.015637	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34594	 34607	 0.006174	 0.024019	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34594	 34607	 0.006174	 0.024019	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34594	 34608	 0.01258	 0.02008	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34594	 86862	 0.010798	 0.036884	 0.0008	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34595	 34596	 0.006229	 0.012746	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34596	 34599	 0.005487	 0.018305	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86859	 34596	 0.0044	 0.027627	 0.0006	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34597	 34599	 0.008366	 0.027908	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34597	 34628	 0.007833	 0.017337	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34598	 86860	 0.015672	 0.017237	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34599	 34602	 0.008767	 0.017357	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34599	 34688	 0.009608	 0.036964	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34600	 34601	 0.002137	 0.007475	 0.00248	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34600	 34632	 0.002483	 0.010104	 0.00246	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34600	 86860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34600	 86860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34601	 34604	 0.001234	 0.007231	 0.00197	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34601	 86861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34601	 86861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34602	 34603	 0.004034	 0.010258	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86860	 34602	 0.009266	 0.018962	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86861	 34603	 0.014038	 0.025232	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34604	 86862	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34604	 86862	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34604	 86876	 0.001227	 0.010521	 0.00299	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34605	 34607	 0.006489	 0.021646	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34605	 86863	 0.005665	 0.02125	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34606	 34669	 0.001183	 0.006601	 0.00169	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34606	 86863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34606	 86863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34607	 86887	 0.004705	 0.034393	 0.00063	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34608	 86864	 0.004566	 0.020344	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34609	 34610	 0.00705	 0.013959	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34610	 86864	 0.010371	 0.026659	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34611	 34670	 0.009344	 0.023762	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34611	 86864	 0.006382	 0.014814	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34612	 86864	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34612	 86864	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34612	 86886	 0.003415	 0.022908	 0.00553	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86864	 34613	 0.003392	 0.014156	 0.00041	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34614	 34617	 0.000714	 0.005053	 0.00139	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34614	 34979	 0.002236	 0.022597	 0.00664	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34614	 86865	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34614	 86865	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86865	 34615	 0.004193	 0.012862	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86865	 34616	 0.011968	 0.025551	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34617	 34619	 0.001162	 0.00567	 0.00157	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34617	 86866	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34617	 86866	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86866	 34618	 0.002365	 0.010158	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34620	 34621	 0.019356	 0.064572	 0.00102	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34620	 86869	 0.011298	 0.046173	 0.00093	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34621	 86867	 0.032935	 0.070317	 0.00159	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34622	 34683	 0.008429	 0.034801	 0.00823	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34622	 35137	 0.006777	 0.028683	 0.00645	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34622	 86867	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34622	 86867	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34623	 34631	 0.001173	 0.00608	 0.00148	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34623	 86868	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34623	 86868	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34624	 34625	 0.006172	 0.009851	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34625	 34627	 0.010564	 0.03524	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34625	 35149	 0.00875	 0.020311	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34626	 34627	 0.005835	 0.026002	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34626	 86869	 0.00909	 0.05167	 0.00093	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34628	 34629	 0.003726	 0.020938	 0.00039	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34628	 34633	 0.010692	 0.030665	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34629	 86870	 0.008399	 0.029386	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34630	 34679	 0.004388	 0.016678	 0.00467	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34630	 86869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34630	 86869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34631	 34632	 0.000728	 0.004262	 0.00116	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34631	 86870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34631	 86870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34632	 34637	 0.000935	 0.003804	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34633	 34634	 0.007775	 0.025656	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86869	 34634	 0.011668	 0.038923	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34634	 86871	 0.008101	 0.028347	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34635	 34636	 0.002666	 0.010674	 0.00269	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34635	 34678	 0.001968	 0.00788	 0.00199	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34636	 86871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34636	 86871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34637	 86872	 0.002224	 0.009048	 0.0022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34638	 34639	 0.007893	 0.020289	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86860	 34638	 0.005386	 0.013845	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34639	 86873	 0.014036	 0.029499	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34640	 34651	 0.000771	 0.010441	 0.0215	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34640	 35117	 0.00171	 0.022729	 0.04857	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34640	 35147	 0.000676	 0.0091	 0.01896	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34640	 86872	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86873	 34640	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34640	 86885	 0.000786	 0.010265	 0.03323	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34641	 86874	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34641	 86874	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34641	 86886	 0.005806	 0.023246	 0.00586	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34642	 34645	 0.014054	 0.02526	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86874	 34642	 0.012296	 0.03127	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86873	 34643	 0.01812	 0.027758	 0.00039	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34644	 35154	 0.002608	 0.010767	 0.00255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86872	 34644	 0.002273	 0.011422	 0.00297	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34646	 34652	 0.002902	 0.013311	 0.00341	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34646	 35154	 0.003121	 0.01214	 0.00324	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34646	 86875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34646	 86875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34647	 86876	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86877	 34647	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34647	 86885	 0.000363	 0.003937	 0.00772	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86877	 34648	 0.005462	 0.045442	 0.00086	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34648	 87046	 0.05664	 0.18896	 0.003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34649	 34650	 0.008082	 0.024326	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86877	 34649	 0.003795	 0.014541	 0.00041	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34650	 34658	 0.00769	 0.025376	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34651	 86878	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86879	 34651	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34651	 86885	 0.000712	 0.007094	 0.02367	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34652	 34654	 0.001491	 0.006711	 0.00179	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34653	 86880	 0.028798	 0.057018	 0.00084	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86878	 34654	 0.001263	 0.006345	 0.00165	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86878	 34655	 0.002567	 0.007569	 0.00176	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34655	 86880	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34655	 86880	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34656	 34659	 0.001814	 0.010313	 0.00299	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86878	 34656	 0.000712	 0.003908	 0.00103	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86879	 34657	 0.02123	 0.042033	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34657	 86881	 0.007272	 0.02829	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34657	 86920	 0.048557	 0.12483	 0.00193	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86879	 34658	 0.006768	 0.032657	 0.00058	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34659	 34663	 0.003026	 0.02177	 0.00577	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34659	 86881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34659	 86881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34660	 34661	 0.004869	 0.015142	 0.00316	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34660	 34812	 0.004536	 0.01724	 0.00483	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86878	 34660	 0.004004	 0.015738	 0.00412	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34661	 34662	 0.002488	 0.014294	 0.00405	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34661	 86882	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34661	 86882	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34662	 34663	 0.003386	 0.022138	 0.00563	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34662	 34815	 0.003779	 0.015996	 0.0036	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84859	 34663	 0.001315	 0.01122	 0.00964	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34664	 34816	 0.011977	 0.030108	 0.0078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84859	 34664	 0.00838	 0.029205	 0.00677	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34665	 34666	 0.000392	 0.004251	 0.00834	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34665	 86883	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86884	 34665	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34666	 86885	 0.000275	 0.004321	 0.01434	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	86881	 34667	 0.019079	 0.048522	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34667	 86887	 0.015612	 0.060061	 0.00103	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34668	 86885	 0.000104	 0.008342	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34668	 86885	 0.000104	 0.008342	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34670	 34674	 0.017372	 0.034045	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86864	 34670	 0.012222	 0.034682	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34670	 86992	 0.007323	 0.043879	 0.00106	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86863	 34671	 0.011893	 0.045756	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86864	 34671	 0.00761	 0.020168	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34672	 34676	 0.007256	 0.027218	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34672	 86988	 0.014075	 0.070395	 0.00125	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34673	 34674	 0.020122	 0.02453	 0.00039	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34673	 34675	 0.008396	 0.016624	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86865	 34673	 0.009495	 0.017392	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34675	 34676	 0.005245	 0.017308	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86865	 34675	 0.010059	 0.024622	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34677	 34678	 0.001687	 0.007868	 0.00195	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34677	 34978	 0.00471	 0.023825	 0.00663	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34678	 86888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34678	 86888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34679	 34681	 0.003247	 0.013406	 0.00317	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34679	 86889	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34679	 86889	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34680	 34684	 0.021942	 0.051959	 0.00095	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34680	 86890	 0.016561	 0.038448	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34681	 86890	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34681	 86890	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34681	 86989	 0.010624	 0.058301	 0.01541	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86889	 34682	 0.076797	 0.04972	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34683	 34685	 0.008469	 0.038852	 0.00995	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34684	 34976	 0.037467	 0.094906	 0.00188	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84851	 34685	 0.013242	 0.076101	 0.02157	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34686	 34687	 0.005889	 0.014977	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86862	 34687	 0.03165	 0.037887	 0.00063	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86862	 34688	 0.01146	 0.031744	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34689	 34817	 0.025694	 0.099958	 0.00167	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34689	 86891	 0.012098	 0.068771	 0.00124	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34689	 86892	 0.014227	 0.071966	 0.00125	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34690	 86891	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34690	 86891	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34691	 34697	 0.003772	 0.022813	 0.00582	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34691	 34819	 0.011628	 0.062508	 0.01538	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34691	 86892	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34691	 86892	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34692	 34693	 0.010762	 0.020611	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34692	 34696	 0.0054	 0.025922	 0.00077	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86892	 34692	 0.009496	 0.048034	 0.00084	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34694	 86893	 0.01887	 0.042802	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34695	 86893	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34695	 86893	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34696	 86894	 0.008187	 0.047747	 0.00096	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34697	 34700	 0.002985	 0.025421	 0.00634	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84853	 34697	 0.009644	 0.15025	 0.04669	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34697	 86894	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34697	 86894	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34698	 86895	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34698	 86895	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34699	 34702	 0.18551	 0.14682	 0.00185	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86894	 34699	 0.014633	 0.064472	 0.00112	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86895	 34699	 0.01668	 0.064172	 0.0011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34700	 34701	 0.002548	 0.025957	 0.00669	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34701	 34910	 0.003664	 0.031426	 0.00894	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34703	 34706	 0.004728	 0.039267	 0.01536	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34703	 86896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34703	 86896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84855	 34704	 0.15847	 0.44995	 0.00707	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86896	 34704	 0.014292	 0.13148	 0.00261	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34704	 86897	 0.053977	 0.17814	 0.00289	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34704	 86911	 0.10873	 0.36283	 0.00575	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34705	 86897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34705	 86897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34705	 86910	 0.00585	 0.047	 0.01321	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84788	 34706	 0.011691	 0.11232	 0.0327	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34706	 86898	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34706	 86898	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34707	 34779	 0.08512	 0.19764	 0.00294	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86898	 34707	 0.068898	 0.15997	 0.00238	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34708	 34709	 0.066376	 0.12861	 0.00277	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34708	 34775	 0.063647	 0.13026	 0.00321	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34708	 34915	 0.02018	 0.11472	 0.00208	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34709	 34710	 0.056812	 0.11941	 0.00218	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34710	 34712	 0.082012	 0.082837	 0.0011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34710	 86909	 0.12158	 0.25966	 0.00586	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34711	 34765	 0.047966	 0.11135	 0.00212	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34712	 34713	 0.096644	 0.097617	 0.00129	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34713	 34714	 0.10307	 0.1031	 0.00139	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34713	 86909	 0.080971	 0.20817	 0.00322	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34715	 34716	 0.016295	 0.037267	 0.00091	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34715	 34717	 0.013085	 0.034682	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34715	 86909	 0.039135	 0.26869	 0.0049	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34716	 34721	 0.008898	 0.028534	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34717	 34718	 0.052581	 0.041612	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34717	 34719	 0.043433	 0.034373	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34717	 34720	 0.054889	 0.049185	 0.00101	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34721	 34722	 0.007405	 0.032444	 0.0007	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34722	 34759	 0.005939	 0.03376	 0.00061	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34723	 34726	 0.009969	 0.068427	 0.00125	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34723	 34759	 0.006126	 0.031856	 0.00069	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34724	 34728	 0.004324	 0.017302	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34724	 34755	 0.016524	 0.039128	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34724	 86899	 0.005041	 0.022464	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34725	 34726	 0.043237	 0.031811	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34726	 34727	 0.007359	 0.019504	 0.00049	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34726	 86899	 0.015169	 0.067594	 0.00115	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34727	 34728	 0.004721	 0.018164	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34729	 34730	 0.001675	 0.006707	 0.00169	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34729	 86899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34729	 86899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34730	 86900	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34730	 86900	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86899	 34731	 0.042635	 0.043063	 0.00057	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86900	 34731	 0.009264	 0.018343	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34732	 34778	 0.031552	 0.020427	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84856	 34732	 0.001959	 0.018239	 0.00035	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34732	 86904	 0.010805	 0.063971	 0.00125	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34733	 34749	 0.038605	 0.030552	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34733	 86905	 0.013194	 0.023204	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34734	 34735	 0.025107	 0.01968	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34735	 86902	 0.014188	 0.018647	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34736	 34737	 0.028773	 0.022554	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34737	 86903	 0.012739	 0.013604	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34738	 34739	 0.001379	 0.007425	 0.00204	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34738	 34743	 0.001538	 0.007864	 0.00214	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34739	 34740	 0.000849	 0.005468	 0.00143	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34739	 86901	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34739	 86901	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34740	 34741	 0.000862	 0.006462	 0.00158	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34740	 86902	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34740	 86902	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34741	 86903	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34741	 86903	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34742	 34743	 0.001773	 0.006082	 0.00146	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34742	 34744	 0.001952	 0.006901	 0.00155	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34743	 86904	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34743	 86904	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34744	 86905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34744	 86905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34745	 34747	 0.017831	 0.079456	 0.00135	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34745	 34764	 0.017939	 0.091282	 0.00207	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86904	 34745	 0.016584	 0.038101	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34746	 34747	 0.050255	 0.051316	 0.0008	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34747	 34748	 0.017735	 0.039252	 0.00064	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86854	 34747	 0.016642	 0.1282	 0.00245	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86901	 34748	 0.018801	 0.043649	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34750	 34763	 0.019575	 0.038363	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34750	 34772	 0.041161	 0.086511	 0.00158	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34751	 34752	 0.082048	 0.064314	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34752	 34764	 0.013549	 0.034458	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34753	 34764	 0.019247	 0.056599	 0.00116	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84856	 34753	 0.007973	 0.030674	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86905	 34753	 0.004363	 0.017308	 0.00049	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34754	 34755	 0.010434	 0.040141	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34754	 34756	 0.038663	 0.030597	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34754	 86906	 0.004349	 0.029851	 0.00054	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34755	 34760	 0.035914	 0.064148	 0.00095	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34757	 86906	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34757	 86906	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34757	 86908	 0.003314	 0.011369	 0.00272	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34758	 34766	 0.11328	 0.088798	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34761	 86907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34761	 86907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86855	 34762	 0.004961	 0.05028	 0.10132	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34762	 86908	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86909	 34762	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86909	 34763	 0.011723	 0.033624	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86906	 34764	 0.021947	 0.056417	 0.00087	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86909	 34764	 0.014688	 0.05714	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86909	 34764	 0.014688	 0.05714	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34765	 34767	 0.030117	 0.061634	 0.00152	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86909	 34766	 0.05223	 0.091856	 0.00173	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34767	 34768	 0.016107	 0.020961	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84861	 34767	 0.005819	 0.033077	 0.0006	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86907	 34767	 0.022454	 0.05213	 0.00078	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34769	 34774	 0.029874	 0.070743	 0.00129	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84861	 34769	 0.014978	 0.04296	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84861	 34770	 0.027777	 0.029224	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34771	 34772	 0.049425	 0.11475	 0.00171	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34771	 34774	 0.042133	 0.070977	 0.00101	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34771	 34919	 0.037314	 0.13331	 0.00265	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34773	 34775	 0.053889	 0.12762	 0.00233	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84861	 34773	 0.036178	 0.10008	 0.00233	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34774	 34777	 0.058688	 0.1075	 0.00186	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34775	 34776	 0.037189	 0.073631	 0.00108	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34776	 34777	 0.029293	 0.067997	 0.00129	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34777	 34918	 0.0709	 0.17356	 0.00297	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84846	 34779	 0.025977	 0.21614	 0.00409	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86897	 34779	 0.033568	 0.22779	 0.00425	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84846	 34780	 0.04434	 0.13603	 0.00368	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84846	 34780	 0.04434	 0.13603	 0.00368	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34780	 86911	 0.042235	 0.15845	 0.00285	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34780	 86911	 0.042235	 0.15845	 0.00285	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84787	 34781	 0.002694	 0.029417	 0.05707	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84787	 34781	 0.002694	 0.029417	 0.05707	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34781	 86910	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86911	 34781	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34781	 86981	 0.005802	 0.091818	 0.19342	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84846	 34782	 0.019699	 0.13522	 0.00247	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86205	 34782	 0.018893	 0.1283	 0.00318	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34783	 34799	 0.016146	 0.064656	 0.01629	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84842	 34783	 0.011083	 0.049904	 0.01328	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34784	 86915	 0.17767	 0.14062	 0.00177	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34785	 34791	 0.009157	 0.037265	 0.00908	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34786	 34787	 0.027883	 0.079972	 0.00123	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34787	 34788	 0.027182	 0.041226	 0.00059	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34787	 34797	 0.036864	 0.037233	 0.00049	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34788	 34797	 0.076447	 0.059924	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34788	 86913	 0.02786	 0.064007	 0.00097	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34788	 86914	 0.059738	 0.14147	 0.00259	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34789	 34791	 0.003131	 0.012305	 0.00322	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34789	 34793	 0.005108	 0.020077	 0.00525	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34789	 86912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34789	 86912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86912	 34790	 0.029028	 0.067394	 0.001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34792	 34793	 0.004722	 0.019216	 0.00468	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34792	 35161	 0.006779	 0.028694	 0.00646	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34793	 86913	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34793	 86913	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34794	 87015	 0.041779	 0.1074	 0.00166	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34795	 35068	 0.00201	 0.012158	 0.0031	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34795	 86914	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34795	 86914	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34796	 34797	 0.017453	 0.042721	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86914	 34796	 0.016545	 0.043852	 0.00111	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34798	 34807	 0.053313	 0.099133	 0.00232	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86805	 34798	 0.041601	 0.089151	 0.00156	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34799	 34808	 0.014668	 0.057069	 0.01525	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34799	 86915	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34799	 86915	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84869	 34800	 0.026949	 0.094358	 0.00261	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34800	 86917	 0.057615	 0.15232	 0.00277	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34801	 86916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34801	 86916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86916	 34802	 0.007506	 0.053456	 0.0012	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34802	 86917	 0.004243	 0.025421	 0.00061	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34803	 34807	 0.026763	 0.068063	 0.00108	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34803	 86917	 0.022896	 0.046855	 0.00115	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34804	 86917	 0.00985	 0.016361	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34805	 34806	 0.001828	 0.007184	 0.00188	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34805	 86917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34805	 86917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34806	 86919	 0.002791	 0.010609	 0.00297	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34807	 86918	 0.033167	 0.0762	 0.00116	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34808	 86918	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34808	 86918	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34808	 86919	 0.007089	 0.028846	 0.00703	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34809	 35232	 0.00145	 0.013267	 0.02554	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34809	 86919	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34809	 86919	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34810	 87070	 0.052436	 0.0871	 0.00185	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34810	 87071	 0.025876	 0.065808	 0.00104	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34811	 87072	 0.04817	 0.12383	 0.00192	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34812	 86920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34812	 86920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86920	 34813	 0.13079	 0.10351	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34814	 86921	 0.029011	 0.071013	 0.00121	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34815	 34822	 0.01144	 0.047238	 0.01118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86886	 34815	 0.011187	 0.056213	 0.01463	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34815	 86921	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34815	 86921	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34816	 86922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34816	 86922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86922	 34817	 0.030717	 0.11358	 0.0021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86922	 34818	 0.021252	 0.11941	 0.00221	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34818	 86924	 0.014513	 0.056458	 0.00094	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34819	 34820	 0.002202	 0.015574	 0.00427	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34819	 34827	 0.004985	 0.028955	 0.00682	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34819	 86923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34819	 86923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34820	 34822	 0.002029	 0.011636	 0.00387	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34820	 86924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34820	 86924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34821	 34822	 0.003242	 0.018991	 0.00517	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34821	 35157	 0.00438	 0.026095	 0.00687	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34822	 86925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34822	 86925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34823	 34930	 0.076594	 0.17782	 0.00339	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34823	 35190	 0.060477	 0.15547	 0.00241	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34824	 34825	 0.016794	 0.055421	 0.0009	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86923	 34824	 0.014766	 0.060347	 0.00122	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86925	 34824	 0.024849	 0.11686	 0.00217	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34825	 34826	 0.024432	 0.070075	 0.00108	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34826	 86960	 0.049202	 0.19143	 0.0032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34827	 34828	 0.006627	 0.026969	 0.00657	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34827	 86926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34827	 86926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34829	 34831	 0.13543	 0.1368	 0.00181	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86818	 34829	 0.10616	 0.11169	 0.00164	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34830	 34832	 0.009921	 0.034716	 0.01151	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84842	 34830	 0.015633	 0.052157	 0.01323	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34831	 34833	 0.04112	 0.095468	 0.00142	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84843	 34831	 0.1534	 0.29386	 0.00462	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86913	 34831	 0.14157	 0.36406	 0.00564	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34832	 35161	 0.009931	 0.039761	 0.01002	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34833	 35165	 0.046923	 0.10894	 0.00162	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34834	 35166	 0.04765	 0.10947	 0.00166	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34835	 86927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34835	 86927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34835	 87022	 0.002132	 0.007757	 0.00237	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34836	 34838	 0.005359	 0.013776	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84872	 34836	 0.006049	 0.015548	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34837	 34846	 0.001038	 0.004284	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34837	 34848	 0.001513	 0.005948	 0.00156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34838	 86933	 0.007461	 0.029024	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34839	 34842	 0.002081	 0.00535	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34839	 34846	 0.001956	 0.005251	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34840	 34852	 0.001384	 0.01273	 0.03117	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34840	 86928	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86929	 34840	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86928	 34841	 0.002906	 0.007803	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34841	 86930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34841	 86930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86928	 34842	 0.001207	 0.007067	 0.00193	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34842	 86931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34842	 86931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34843	 87008	 0.012694	 0.02399	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34844	 34845	 0.001217	 0.004059	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34844	 86932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34844	 86932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34845	 34886	 0.0011	 0.003985	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86928	 34846	 0.003747	 0.015857	 0.00357	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34846	 86933	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34846	 86933	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86930	 34847	 0.014595	 0.033884	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34847	 86952	 0.010937	 0.022987	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34848	 34849	 0.001282	 0.005131	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34848	 86934	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34848	 86934	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34849	 86935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34849	 86935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34849	 86937	 0.001005	 0.009653	 0.00281	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34850	 34854	 0.002708	 0.007372	 0.00162	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34850	 34908	 0.003446	 0.008662	 0.00224	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34851	 34853	 0.004347	 0.014913	 0.00357	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34851	 34856	 0.006238	 0.025754	 0.00609	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84850	 34851	 0.003312	 0.014019	 0.00315	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34851	 86936	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34851	 86936	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34852	 86937	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34852	 86937	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34853	 34854	 0.002831	 0.008347	 0.00194	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34855	 34856	 0.006476	 0.019394	 0.00437	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34856	 86938	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34856	 86938	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34857	 34969	 0.003035	 0.034154	 0.00897	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84850	 34857	 0.006663	 0.04713	 0.01293	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34857	 86939	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34857	 86939	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34858	 34859	 0.068753	 0.053892	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34859	 34862	 0.024825	 0.057635	 0.00086	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86936	 34859	 0.017034	 0.054851	 0.00093	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34860	 34863	 0.006065	 0.023839	 0.00624	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34860	 34904	 0.005912	 0.025024	 0.00563	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34860	 86940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34860	 86940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86939	 34861	 0.038548	 0.069287	 0.00124	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34862	 34865	 0.035148	 0.064378	 0.00111	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34863	 34864	 0.003021	 0.012787	 0.00288	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34864	 86941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34864	 86941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34865	 34868	 0.032288	 0.063279	 0.00095	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86941	 34866	 0.007366	 0.03264	 0.00098	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34866	 86944	 0.008671	 0.042315	 0.00073	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34867	 34883	 0.009667	 0.025622	 0.00065	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34867	 34887	 0.018324	 0.034632	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86929	 34867	 0.028219	 0.051686	 0.00089	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34868	 34884	 0.010721	 0.02489	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34868	 86945	 0.01175	 0.03731	 0.00065	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34869	 34884	 0.010737	 0.042967	 0.00091	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86941	 34869	 0.01266	 0.055778	 0.00097	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34870	 34871	 0.022411	 0.016201	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34871	 34885	 0.037019	 0.029296	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86930	 34871	 0.038413	 0.03011	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34872	 86942	 0.042882	 0.030999	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34873	 34874	 0.002102	 0.008895	 0.002	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34873	 34895	 0.007767	 0.028259	 0.00865	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34873	 86942	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34873	 86942	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34874	 34875	 0.00175	 0.00803	 0.00206	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34874	 86943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34874	 86943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34875	 34902	 0.00249	 0.015771	 0.00428	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34875	 86944	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34875	 86944	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34876	 34879	 0.027617	 0.05135	 0.0012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84854	 34876	 0.010946	 0.053439	 0.00112	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34877	 34878	 0.012234	 0.025035	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86942	 34877	 0.01244	 0.02845	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34878	 34883	 0.011216	 0.028832	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34879	 34880	 0.006568	 0.025553	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86943	 34879	 0.008302	 0.033931	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34880	 86945	 0.015959	 0.029674	 0.00069	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34881	 86945	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34881	 86945	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34882	 34883	 0.006749	 0.019845	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86945	 34882	 0.003978	 0.015476	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34884	 34885	 0.01243	 0.024611	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86930	 34884	 0.054494	 0.048831	 0.001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34886	 34889	 0.000582	 0.003339	 0.00111	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34886	 86946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34886	 86946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34887	 86947	 0.011877	 0.029479	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34888	 34890	 0.000573	 0.003354	 0.00091	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34888	 34894	 0.000754	 0.004333	 0.00123	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34889	 34890	 0.000774	 0.004987	 0.00131	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34890	 35029	 0.001867	 0.009675	 0.00236	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34890	 86947	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34890	 86947	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34891	 87005	 0.023233	 0.017093	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34892	 34893	 0.010318	 0.023706	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34892	 87006	 0.027649	 0.064191	 0.00095	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84854	 34893	 0.00339	 0.010398	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84854	 34893	 0.00339	 0.010398	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34895	 34896	 0.00375	 0.015482	 0.00366	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34895	 86948	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34895	 86948	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34896	 86949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34896	 86949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34897	 34899	 0.041489	 0.09532	 0.00145	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86948	 34897	 0.019896	 0.046192	 0.00069	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86949	 34898	 0.088194	 0.064888	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34899	 34900	 0.012065	 0.068585	 0.00124	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34899	 34932	 0.067446	 0.19141	 0.00301	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34900	 34907	 0.013549	 0.067226	 0.0016	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34901	 34902	 0.002799	 0.017393	 0.00491	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34901	 34903	 0.002114	 0.012144	 0.00344	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34901	 86950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34901	 86950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34903	 34904	 0.002752	 0.014589	 0.00487	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34905	 35091	 0.008876	 0.03554	 0.00895	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34905	 86951	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34905	 86951	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86951	 34906	 0.10133	 0.080191	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86950	 34907	 0.015183	 0.067654	 0.00115	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86951	 34907	 0.006601	 0.060719	 0.0012	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34908	 86952	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34908	 86952	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84815	 34909	 0.006769	 0.027091	 0.00915	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34909	 86953	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34909	 86953	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34910	 34911	 0.004812	 0.047746	 0.01299	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84815	 34910	 0.013358	 0.080195	 0.0243	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34911	 86954	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34911	 86954	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34912	 86955	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34912	 86955	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34913	 34914	 0.034044	 0.079039	 0.00118	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34914	 34915	 0.035868	 0.082032	 0.002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34915	 34917	 0.069789	 0.16528	 0.00302	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34916	 34917	 0.049363	 0.08907	 0.00129	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86847	 34917	 0.059268	 0.19009	 0.0047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34918	 34919	 0.20758	 0.22614	 0.00308	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86955	 34918	 0.070961	 0.16476	 0.00245	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34919	 35195	 0.044646	 0.17178	 0.00293	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34921	 86956	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86957	 34921	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86956	 34922	 0.007027	 0.027339	 0.0073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34922	 86958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34922	 86958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86957	 34923	 0.057932	 0.15828	 0.00269	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86958	 34924	 0.049351	 0.078775	 0.00181	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86958	 34925	 0.021597	 0.10802	 0.00192	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34927	 34929	 0.011979	 0.035875	 0.00808	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84866	 34927	 0.008268	 0.027859	 0.00692	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34928	 34930	 0.031091	 0.08823	 0.00139	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34928	 86960	 0.018265	 0.071056	 0.00119	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34929	 86959	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34929	 86959	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34931	 86960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34931	 86960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34932	 34933	 0.14131	 0.1084	 0.00146	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86959	 34932	 0.023927	 0.083723	 0.00173	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86949	 34933	 0.057213	 0.11213	 0.00168	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84847	 34934	 0.033771	 0.1488	 0.00258	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86960	 34934	 0.042482	 0.1402	 0.00227	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34935	 34938	 0.004818	 0.028221	 0.00769	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84852	 34936	 0.034062	 0.067441	 0.00099	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34937	 34941	 0.001738	 0.011855	 0.02135	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84828	 34937	 0.000996	 0.008202	 0.01691	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34937	 86961	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34937	 86961	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84851	 34938	 0.011275	 0.063854	 0.01583	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34938	 86962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34938	 86962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34939	 34940	 0.003781	 0.015137	 0.00381	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86961	 34939	 0.002853	 0.014333	 0.00373	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34939	 86963	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34939	 86963	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34940	 34948	 0.002807	 0.023354	 0.00707	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34940	 86964	 0.005543	 0.019014	 0.00456	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34941	 34945	 0.000492	 0.005587	 0.01227	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84828	 34941	 0.001017	 0.011052	 0.02402	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34941	 86964	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86965	 34941	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34942	 34996	 0.001828	 0.010065	 0.00363	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84829	 34942	 0.001696	 0.012777	 0.00354	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34942	 86966	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34942	 86966	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34943	 34944	 0.007757	 0.031042	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86965	 34943	 0.022729	 0.050305	 0.00082	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34943	 86968	 0.010068	 0.032285	 0.0008	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34944	 86995	 0.021888	 0.057861	 0.00105	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84828	 34945	 0.00174	 0.015731	 0.03101	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34945	 86967	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86968	 34945	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34946	 34947	 0.002635	 0.018279	 0.00522	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34946	 86969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34946	 86969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86967	 34947	 0.003562	 0.022942	 0.00601	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84812	 34948	 0.025384	 0.10485	 0.02482	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34948	 86970	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34948	 86970	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86970	 34949	 0.025643	 0.085544	 0.00136	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34950	 34964	 0.000716	 0.008936	 0.61311	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34950	 86971	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34950	 86971	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84834	 34951	 0.020125	 0.071149	 0.01604	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34951	 86972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34951	 86972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86971	 34952	 0.016631	 0.043958	 0.01029	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34952	 86973	 0.009414	 0.024879	 0.00582	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34953	 34956	 0.002355	 0.01571	 0.02961	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84833	 34953	 0.006029	 0.040227	 0.07587	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34953	 86973	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86974	 34953	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86974	 34954	 0.10391	 0.17506	 0.00249	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34955	 34962	 0.002895	 0.023259	 0.00654	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34955	 86975	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34955	 86975	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34956	 34961	 0.001305	 0.008702	 0.0164	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34956	 86976	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34956	 86976	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34957	 34960	 0.000281	 0.003051	 0.00663	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	34958	 34961	 0.001065	 0.009123	 0.01736	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	34958	 86981	 0.000361	 0.005999	 0.02215	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34959	 34963	 0.001609	 0.008139	 0.00227	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34959	 86977	 0.001381	 0.00716	 0.00175	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34960	 86977	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34960	 86977	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34960	 86981	 0.000899	 0.008856	 0.01887	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34961	 86978	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86979	 34961	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34962	 34963	 0.000871	 0.005608	 0.00147	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34962	 86980	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34962	 86980	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34963	 86982	 0.00208	 0.012582	 0.00321	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34964	 86981	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34964	 86981	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95340	 34964	 0.000365	 0.012708	 1.0903	 4217.0	 4427.8	 4638.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86983	 34965	 0.027555	 0.043984	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84837	 34966	 0.014912	 0.13884	 0.00269	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34967	 34968	 0.001519	 0.023205	 0.00748	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84836	 34967	 0.002775	 0.043736	 0.01492	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34968	 34969	 0.001528	 0.023351	 0.00752	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34969	 86984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34969	 86984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34970	 34973	 0.033259	 0.078758	 0.00144	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84852	 34970	 0.024194	 0.13043	 0.00263	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34970	 86986	 0.05558	 0.11375	 0.0028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84830	 34971	 0.038575	 0.1273	 0.00206	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84852	 34971	 0.1564	 0.11998	 0.00161	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34972	 34988	 0.00283	 0.021318	 0.00591	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84862	 34972	 0.001929	 0.01884	 0.00529	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34972	 86985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34972	 86985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34973	 86986	 0.024556	 0.063124	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34974	 34977	 0.002468	 0.014457	 0.00394	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84851	 34974	 0.005538	 0.049073	 0.01307	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34974	 86986	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34974	 86986	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86986	 34975	 0.023425	 0.060216	 0.00093	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34975	 86993	 0.012377	 0.035499	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34976	 86987	 0.025196	 0.080006	 0.0014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34977	 34978	 0.003849	 0.021122	 0.00558	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34977	 86987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34977	 86987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34979	 34982	 0.001357	 0.010024	 0.00289	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34979	 86988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34979	 86988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34979	 86989	 0.002103	 0.019793	 0.006	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34980	 86990	 0.014243	 0.033728	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86885	 34981	 0.001106	 0.017352	 0.05761	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	34981	 86989	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86990	 34981	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86989	 34982	 0.001101	 0.009537	 0.00342	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	34982	 86991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34982	 86991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34983	 34985	 0.00884	 0.034389	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34983	 34989	 0.030615	 0.0787	 0.00122	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86990	 34983	 0.004022	 0.024729	 0.00045	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34984	 34986	 0.015617	 0.02594	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86991	 34984	 0.00915	 0.021667	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34987	 86992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34987	 86992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86989	 34988	 0.003253	 0.01938	 0.0051	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34988	 86993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34988	 86993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34989	 34990	 0.016356	 0.033471	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86990	 34989	 0.029048	 0.096904	 0.00154	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34989	 86994	 0.013054	 0.056062	 0.00103	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	34990	 86994	 0.032937	 0.070321	 0.00159	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34991	 34992	 0.002245	 0.012319	 0.00326	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34991	 34996	 0.001906	 0.011162	 0.00304	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34992	 34993	 0.002488	 0.012958	 0.0034	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86733	 34992	 0.003377	 0.019403	 0.0055	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34993	 86994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34993	 86994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34994	 34997	 0.000841	 0.003367	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84862	 34994	 0.009317	 0.032604	 0.0108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34994	 86995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34994	 86995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	34995	 34997	 0.00169	 0.006766	 0.0017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86733	 34995	 0.002984	 0.01232	 0.00291	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	34998	 35044	 0.012947	 0.01424	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34998	 35052	 0.007101	 0.008656	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	34999	 35000	 0.000782	 0.004659	 0.00123	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	34999	 35002	 0.000525	 0.002734	 0.00072	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35000	 35042	 0.001053	 0.006667	 0.00181	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35000	 86996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35000	 86996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35001	 35043	 0.005277	 0.01342	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86996	 35001	 0.005852	 0.015043	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35001	 86998	 0.012506	 0.015916	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35002	 35005	 0.00114	 0.00384	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35002	 86997	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35002	 86997	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35003	 35004	 0.000636	 0.003195	 0.00083	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35003	 35041	 0.001421	 0.005527	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35003	 86998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35003	 86998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35004	 35023	 0.000905	 0.003624	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35005	 35006	 0.000983	 0.003373	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35005	 86999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35005	 86999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35006	 35023	 0.000973	 0.003958	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35007	 35008	 0.005722	 0.013283	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86999	 35007	 0.003477	 0.011878	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35008	 35012	 0.004223	 0.009805	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35008	 35013	 0.019322	 0.013968	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35008	 87012	 0.006607	 0.015644	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35009	 35012	 0.004634	 0.011344	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35009	 87002	 0.004958	 0.015964	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35010	 87002	 0.008887	 0.016276	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35011	 35015	 0.003047	 0.013577	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35011	 35019	 0.002198	 0.010726	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35012	 35015	 0.007024	 0.014763	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35014	 35056	 0.001434	 0.003851	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35014	 35075	 0.002645	 0.00614	 0.00187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35014	 87000	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35014	 87000	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35015	 35016	 0.006204	 0.017605	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35015	 87019	 0.084451	 0.066835	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35016	 35017	 0.011533	 0.015158	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35017	 35018	 0.010288	 0.007794	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35017	 87020	 0.008248	 0.021201	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35019	 87001	 0.002973	 0.016898	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35020	 87001	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35020	 87001	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35020	 87022	 0.001432	 0.011507	 0.00323	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35021	 35023	 0.000726	 0.004111	 0.00102	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35022	 87002	 0.006809	 0.012286	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35023	 87002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35023	 87002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35024	 35080	 0.003638	 0.024265	 0.04575	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35024	 87003	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87004	 35024	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87004	 35025	 0.007569	 0.040649	 0.00097	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35025	 87017	 0.01319	 0.034959	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35026	 35069	 0.004054	 0.017157	 0.00386	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87004	 35027	 0.035981	 0.091506	 0.00145	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86929	 35028	 0.026357	 0.075595	 0.00116	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86947	 35028	 0.003222	 0.019308	 0.00046	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35028	 87007	 0.00683	 0.031848	 0.00073	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35029	 35030	 0.002606	 0.016194	 0.00457	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35029	 87005	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35029	 87005	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35030	 35031	 0.00221	 0.012172	 0.00439	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35030	 87006	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35030	 87006	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84827	 35031	 0.004773	 0.033116	 0.00945	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87005	 35032	 0.016909	 0.033479	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35033	 35036	 0.002728	 0.014687	 0.00403	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86836	 35033	 0.00548	 0.045592	 0.01381	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35033	 87007	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35033	 87007	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35034	 35041	 0.000603	 0.002766	 0.00071	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35034	 87008	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35034	 87008	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35035	 35039	 0.004399	 0.016502	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35035	 35040	 0.006108	 0.015533	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35036	 35042	 0.001151	 0.006744	 0.00184	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35036	 87009	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35036	 87009	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35037	 35038	 0.004174	 0.01073	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87009	 35037	 0.005564	 0.014149	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86946	 35038	 0.004317	 0.017127	 0.00049	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87009	 35038	 0.009533	 0.024244	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86932	 35039	 0.004016	 0.020312	 0.00035	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87008	 35040	 0.009902	 0.019604	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35041	 87010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35041	 87010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87010	 35043	 0.00445	 0.011316	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35044	 35045	 0.00815	 0.031355	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35044	 35049	 0.018997	 0.037612	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87007	 35045	 0.020636	 0.072252	 0.002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35046	 87011	 0.038757	 0.042628	 0.00057	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35047	 35049	 0.007383	 0.014469	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35048	 35055	 0.031385	 0.024838	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35048	 87011	 0.009828	 0.018	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35049	 35053	 0.008073	 0.016521	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35049	 35054	 0.010156	 0.018602	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35049	 87011	 0.016674	 0.031002	 0.00073	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35050	 35062	 0.001724	 0.00791	 0.00203	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35050	 87011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35050	 87011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87011	 35051	 0.025075	 0.019844	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35052	 35053	 0.004126	 0.010099	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86999	 35052	 0.004548	 0.015173	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35054	 87013	 0.006575	 0.015105	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35055	 35058	 0.019676	 0.019874	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35056	 35057	 0.001074	 0.003684	 0.00088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35056	 87012	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35056	 87012	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35057	 87013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35057	 87013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87011	 35058	 0.0746	 0.057224	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87013	 35058	 0.006852	 0.02636	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35059	 35060	 0.009115	 0.018046	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35059	 35065	 0.017328	 0.034308	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35060	 35061	 0.008895	 0.016291	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87011	 35060	 0.012719	 0.032346	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87003	 35062	 0.003191	 0.019152	 0.0058	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35062	 87014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35062	 87014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35063	 35071	 0.008452	 0.02492	 0.0058	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35063	 87015	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35063	 87015	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35064	 35065	 0.013038	 0.029953	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87014	 35064	 0.01172	 0.032018	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35064	 87018	 0.007277	 0.016643	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35066	 87016	 0.011344	 0.02431	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35066	 87019	 0.041851	 0.099105	 0.00181	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35067	 35071	 0.002701	 0.010269	 0.00287	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35067	 35086	 0.004567	 0.020951	 0.00537	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35067	 87016	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35067	 87016	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35068	 35071	 0.001627	 0.009841	 0.00251	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35069	 35070	 0.001847	 0.007021	 0.00197	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35069	 87017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35069	 87017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35070	 35071	 0.001256	 0.005314	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35071	 35072	 0.00129	 0.00341	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87003	 35071	 0.005266	 0.02371	 0.00631	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35072	 87018	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35072	 87018	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35073	 35079	 0.003663	 0.01425	 0.00381	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87003	 35073	 0.014034	 0.047289	 0.01175	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35073	 87019	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35073	 87019	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87019	 35074	 0.042995	 0.030456	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35075	 35076	 0.001654	 0.005674	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35076	 35081	 0.001628	 0.009534	 0.0026	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35076	 87020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35076	 87020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35077	 35079	 0.001551	 0.006313	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35077	 35083	 0.002053	 0.007987	 0.00213	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35078	 87021	 0.006427	 0.016522	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35078	 87023	 0.010256	 0.026083	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35079	 87021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35079	 87021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35080	 87022	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35080	 87022	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84838	 35081	 0.018079	 0.082962	 0.02126	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87022	 35081	 0.002241	 0.012693	 0.00315	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35081	 87023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35081	 87023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35082	 35084	 0.004058	 0.030564	 0.00848	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86775	 35082	 0.005451	 0.042233	 0.0148	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35083	 35084	 0.004283	 0.016662	 0.00445	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35084	 35085	 0.007695	 0.029936	 0.008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35084	 35086	 0.005304	 0.025101	 0.00604	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84847	 35087	 0.23734	 0.15369	 0.00293	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35088	 35089	 0.025204	 0.098435	 0.00218	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35088	 35090	 0.16566	 0.26665	 0.00418	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84847	 35088	 0.052003	 0.20233	 0.00338	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35089	 87024	 0.02117	 0.10118	 0.00221	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	86832	 35091	 0.009957	 0.058331	 0.01589	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35091	 87024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35091	 87024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35092	 35104	 0.00952	 0.024473	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35092	 87028	 0.005189	 0.023123	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35093	 35094	 0.012825	 0.010053	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35094	 35097	 0.006227	 0.016006	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35094	 35100	 0.005326	 0.01369	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35095	 35096	 0.003704	 0.014408	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35095	 35097	 0.002038	 0.018972	 0.00037	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35095	 35113	 0.005352	 0.020822	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35096	 87032	 0.007638	 0.026726	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35097	 35098	 0.002838	 0.011042	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35098	 35099	 0.004709	 0.014174	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35099	 35102	 0.036975	 0.029261	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35099	 35119	 0.01154	 0.029664	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35099	 35123	 0.010877	 0.025756	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35099	 87034	 0.10461	 0.082793	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35100	 35101	 0.010691	 0.007728	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35100	 35104	 0.020454	 0.026883	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35101	 35102	 0.011065	 0.011068	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35102	 87025	 0.022654	 0.017928	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35103	 87025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35103	 87025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35103	 87033	 0.004346	 0.011667	 0.00264	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87025	 35104	 0.016806	 0.030324	 0.00044	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35105	 35107	 0.002063	 0.005355	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35105	 35110	 0.002598	 0.00653	 0.00169	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35106	 87035	 0.041035	 0.032474	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35107	 35124	 0.002169	 0.008828	 0.00215	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35107	 35126	 0.002304	 0.009225	 0.00232	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35108	 35128	 0.036349	 0.08351	 0.00127	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35108	 87027	 0.010188	 0.039195	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35108	 87035	 0.046612	 0.092289	 0.00135	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35109	 35132	 0.005151	 0.014364	 0.00301	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35109	 87026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35109	 87026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35110	 87027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35110	 87027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87027	 35111	 0.003331	 0.018932	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35111	 87028	 0.00276	 0.021262	 0.00041	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35112	 87028	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35112	 87028	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35112	 87030	 0.002791	 0.014782	 0.00375	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35113	 87031	 0.007095	 0.039868	 0.00074	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35114	 35134	 0.029829	 0.062693	 0.00114	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87026	 35114	 0.019194	 0.049341	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87028	 35114	 0.005608	 0.023735	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35114	 87031	 0.005602	 0.050155	 0.00105	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35115	 35135	 0.0058	 0.022222	 0.00063	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35115	 87029	 0.003986	 0.024508	 0.00044	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35116	 87029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35116	 87029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35116	 87030	 0.002417	 0.009501	 0.00249	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35117	 35120	 0.001001	 0.013306	 0.02843	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35117	 35147	 0.001056	 0.013844	 0.03042	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35117	 87030	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87031	 35117	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87030	 35118	 0.003088	 0.010071	 0.00267	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35118	 87032	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35118	 87032	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35119	 35158	 0.020458	 0.050075	 0.00086	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35119	 87034	 0.0314	 0.06217	 0.00091	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84825	 35120	 0.010315	 0.068895	 0.13013	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35120	 87033	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87034	 35120	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87032	 35121	 0.014777	 0.02863	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35122	 35123	 0.009416	 0.031412	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87025	 35122	 0.034673	 0.070957	 0.00175	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87034	 35122	 0.045013	 0.10211	 0.00204	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35122	 87045	 0.010852	 0.042218	 0.0007	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35122	 87045	 0.010852	 0.042218	 0.0007	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87033	 35124	 0.000965	 0.005931	 0.00171	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35124	 87035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35124	 87035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35125	 87036	 0.057612	 0.042388	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35126	 35127	 0.002514	 0.009146	 0.0028	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35126	 87036	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35126	 87036	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86797	 35128	 0.012934	 0.063114	 0.00109	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35128	 87037	 0.041363	 0.063355	 0.0011	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35129	 35130	 0.039722	 0.06085	 0.00085	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86797	 35129	 0.023442	 0.091198	 0.00152	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35130	 35131	 0.10993	 0.11104	 0.00147	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35131	 35139	 0.038454	 0.089263	 0.0017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35132	 87037	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35132	 87037	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35133	 35139	 0.04172	 0.059225	 0.00097	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87037	 35133	 0.086469	 0.071174	 0.00144	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35134	 35135	 0.011387	 0.029272	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35134	 35139	 0.017332	 0.057817	 0.00092	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87026	 35135	 0.018614	 0.047848	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35136	 87038	 0.004738	 0.044106	 0.00085	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35136	 87039	 0.020127	 0.11442	 0.00207	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35137	 87038	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35137	 87038	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35138	 35142	 0.038973	 0.083519	 0.00146	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35139	 87039	 0.004362	 0.033996	 0.00064	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35140	 87039	 0.015127	 0.038886	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35140	 87040	 0.013912	 0.05412	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87030	 35141	 0.008509	 0.028671	 0.00713	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35141	 87039	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35141	 87039	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35142	 87041	 0.016017	 0.071373	 0.00121	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35143	 35145	 0.001675	 0.008257	 0.00223	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87030	 35143	 0.003414	 0.013417	 0.00351	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35143	 87040	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35143	 87040	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35144	 87041	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35144	 87041	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35144	 87043	 0.002579	 0.012955	 0.00337	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35145	 87042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35145	 87042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35145	 87043	 0.002479	 0.01992	 0.0056	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35146	 35148	 0.033288	 0.031216	 0.00048	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86885	 35147	 0.001631	 0.022085	 0.04548	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35147	 87043	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87044	 35147	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35148	 35149	 0.010668	 0.027131	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87041	 35149	 0.018644	 0.072531	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87044	 35149	 0.00847	 0.042847	 0.00075	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35150	 35152	 0.015339	 0.03901	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87031	 35150	 0.089953	 0.066183	 0.00097	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87032	 35150	 0.015902	 0.040877	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87042	 35150	 0.011341	 0.050534	 0.00086	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35151	 35153	 0.005345	 0.021008	 0.0055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35151	 87045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35151	 87045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87031	 35152	 0.065062	 0.10961	 0.00156	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35152	 87046	 0.005512	 0.035562	 0.00113	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35153	 35154	 0.002241	 0.014651	 0.00373	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35153	 87046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35153	 87046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35155	 35156	 0.018671	 0.057279	 0.00155	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87045	 35155	 0.034941	 0.081109	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86920	 35156	 0.015016	 0.092319	 0.00166	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35157	 87047	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35157	 87047	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87034	 35159	 0.036417	 0.1301	 0.00258	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87047	 35159	 0.027391	 0.12206	 0.00207	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35160	 35191	 0.024002	 0.084037	 0.00233	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87034	 35160	 0.016824	 0.065449	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87034	 35160	 0.016824	 0.065449	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35161	 35162	 0.006142	 0.028646	 0.0071	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35161	 35163	 0.006227	 0.026357	 0.00593	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35162	 35180	 0.003739	 0.017871	 0.00626	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35163	 35164	 0.002677	 0.011328	 0.00255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84838	 35164	 0.008588	 0.056164	 0.01428	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35164	 87048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35164	 87048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35165	 35169	 0.027578	 0.070892	 0.0011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35165	 87049	 0.053529	 0.10599	 0.00156	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35167	 87049	 0.04177	 0.075078	 0.00135	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35168	 87049	 0.019079	 0.037391	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35169	 35170	 0.004635	 0.020419	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35169	 35183	 0.011793	 0.02738	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35170	 35171	 0.012411	 0.022394	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87048	 35170	 0.009414	 0.087642	 0.0017	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35171	 35176	 0.005329	 0.023847	 0.00049	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35171	 35183	 0.005484	 0.027738	 0.00048	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35172	 35174	 0.002419	 0.012823	 0.00428	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84842	 35172	 0.034474	 0.13115	 0.03675	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35172	 87049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35172	 87049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35173	 35183	 0.001311	 0.012157	 0.00027	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35173	 87050	 0.00279	 0.011164	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35173	 87051	 0.009088	 0.035353	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35173	 87051	 0.009088	 0.035353	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35174	 35175	 0.00092	 0.005287	 0.0015	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35174	 87050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35174	 87050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35175	 87051	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35175	 87051	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35175	 87053	 0.003527	 0.028828	 0.00782	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35176	 35177	 0.020976	 0.037847	 0.00055	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35176	 87052	 0.01522	 0.10447	 0.0019	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87051	 35178	 0.0192	 0.038015	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84838	 35179	 0.004651	 0.022935	 0.0062	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84838	 35180	 0.005341	 0.03583	 0.00865	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35180	 87052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35180	 87052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35181	 87053	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87054	 35181	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87054	 35182	 0.037134	 0.059274	 0.00137	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87049	 35183	 0.008289	 0.039788	 0.00119	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35184	 35185	 0.010022	 0.023268	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35184	 87056	 0.013996	 0.029994	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35185	 35188	 0.079415	 0.060169	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35185	 87055	 0.013783	 0.039532	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35186	 35189	 0.006418	 0.039828	 0.00965	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35186	 87055	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35186	 87055	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84848	 35187	 0.023191	 0.094407	 0.02301	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35187	 87056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35187	 87056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87056	 35190	 0.045887	 0.15308	 0.00243	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35192	 35249	 0.07336	 0.1886	 0.00292	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87055	 35192	 0.037208	 0.12279	 0.00199	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35193	 35199	 0.00509	 0.029814	 0.00812	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86856	 35193	 0.062656	 0.16579	 0.03886	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35193	 87057	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35193	 87057	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35194	 35195	 0.049462	 0.15928	 0.00271	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35194	 87059	 0.035045	 0.12263	 0.00254	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86851	 35195	 0.041594	 0.22263	 0.00675	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35197	 35198	 0.006617	 0.021582	 0.00573	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35197	 35202	 0.006542	 0.035899	 0.00949	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35197	 87058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35197	 87058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35198	 87059	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35198	 87059	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35199	 35200	 0.006719	 0.040029	 0.01053	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35200	 87060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35200	 87060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35201	 87061	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35201	 87061	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87061	 35202	 0.006109	 0.028024	 0.00718	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35202	 87062	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35202	 87062	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35203	 87063	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87064	 35203	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35204	 35205	 0.006823	 0.013963	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35204	 35211	 0.006155	 0.011444	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35204	 35213	 0.003536	 0.018837	 0.00033	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35205	 35206	 0.028567	 0.020651	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35206	 35207	 0.005292	 0.013458	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35206	 35209	 0.038539	 0.030209	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35206	 87067	 0.015785	 0.06141	 0.00103	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35207	 35208	 0.013049	 0.018524	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35208	 35233	 0.018714	 0.018769	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35209	 35210	 0.025839	 0.020253	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35209	 35211	 0.004089	 0.009276	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35211	 35212	 0.009853	 0.025328	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35212	 35214	 0.006878	 0.012788	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35212	 87068	 0.009498	 0.02249	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35213	 35215	 0.00802	 0.018425	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35213	 87067	 0.006113	 0.022604	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35214	 87067	 0.014777	 0.042382	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35215	 35220	 0.006995	 0.01854	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35216	 87065	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35216	 87065	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35217	 35219	 0.00318	 0.012087	 0.00338	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35217	 35236	 0.005099	 0.021054	 0.00498	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35218	 35219	 0.005596	 0.015606	 0.00328	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35218	 87068	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35218	 87068	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84826	 35219	 0.00117	 0.011234	 0.00327	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35220	 87075	 0.23519	 0.17823	 0.00245	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84826	 35221	 0.004302	 0.014031	 0.00372	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35221	 87069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35221	 87069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35222	 87070	 0.040113	 0.082435	 0.00157	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35222	 87071	 0.027372	 0.057529	 0.00105	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87069	 35223	 0.015732	 0.040009	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35224	 87070	 0.017551	 0.021786	 0.00047	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84826	 35225	 0.008656	 0.035739	 0.00846	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35225	 87070	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35225	 87070	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35226	 35227	 0.047048	 0.036878	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87070	 35226	 0.014372	 0.034033	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35227	 35229	 0.05598	 0.056542	 0.00075	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87066	 35228	 0.002845	 0.009956	 0.0033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35228	 87071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35228	 87071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87071	 35229	 0.011265	 0.028959	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87066	 35230	 0.003282	 0.013892	 0.00313	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35230	 87072	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35230	 87072	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87072	 35231	 0.050358	 0.064089	 0.00094	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87065	 35232	 0.00081	 0.010902	 0.02272	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35232	 87073	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35232	 87073	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35233	 35234	 0.024041	 0.050529	 0.00092	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87067	 35233	 0.019422	 0.090005	 0.00173	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86802	 35234	 0.051277	 0.14708	 0.00226	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86802	 35235	 0.048786	 0.090715	 0.00212	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35235	 87075	 0.057388	 0.12299	 0.00215	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87068	 35237	 0.032793	 0.030752	 0.00047	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35238	 87074	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35238	 87074	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35238	 87079	 0.007647	 0.02053	 0.00465	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84826	 35239	 0.010438	 0.036897	 0.00831	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35239	 87075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35239	 87075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35240	 35241	 0.01153	 0.029639	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35240	 35249	 0.068868	 0.15823	 0.0024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87074	 35240	 0.006318	 0.030829	 0.00053	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87075	 35241	 0.012982	 0.030134	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87065	 35242	 0.002379	 0.030971	 0.06909	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35242	 87076	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35242	 87076	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35243	 35244	 0.033949	 0.066535	 0.001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35243	 35247	 0.011896	 0.029117	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35244	 87077	 0.071785	 0.05681	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35244	 87078	 0.075517	 0.059194	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84826	 35245	 0.008214	 0.021709	 0.00508	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35245	 87077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35245	 87077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84826	 35246	 0.002116	 0.005592	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35246	 87078	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35246	 87078	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35247	 87080	 0.012883	 0.036558	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84825	 35248	 0.00086	 0.009564	 0.03703	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35248	 87079	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87080	 35248	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35250	 36044	 0.000129	 0.001544	 0.11585	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35250	 36372	 0.000109	 0.001436	 0.13751	 2385.0	 2504.2	 2623.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35250	 38721	 0.000836	 0.022676	 1.9237	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35250	 38721	 0.000836	 0.022676	 1.9237	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35250	 87081	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35250	 87081	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87082	 35250	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87082	 35250	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35251	 35650	 0.0004	 0.00963	 0.6956	 2500.0	 2500.0	 2500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35251	 35799	 5.4e-05	 0.000697	 0.04451	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35251	 36419	 0.001632	 0.021201	 1.3628	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35251	 87083	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35251	 87083	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35252	 35269	 0.000104	 0.001672	 0.15588	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35252	 87085	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35252	 87085	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35253	 35613	 0.000125	 0.002093	 0.13669	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35253	 35650	 0.000836	 0.009988	 0.75063	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35253	 87088	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35253	 87088	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35254	 35436	 0.0003	 0.003874	 0.24725	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35254	 36253	 4.4e-05	 0.001082	 0.10941	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35254	 36254	 0.000105	 0.001314	 0.09006	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35254	 87091	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35254	 87091	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35255	 35529	 0.000403	 0.008617	 0.77053	 3084.0	 3238.2	 3392.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35255	 35953	 0.000565	 0.006748	 0.50664	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35255	 87092	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35255	 87092	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35256	 36563	 0.000782	 0.009341	 0.70182	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35256	 87095	 0.000324	 0.024331	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35256	 87095	 0.000324	 0.024331	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87096	 35256	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87096	 35256	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35257	 35538	 0.000362	 0.009753	 0.82	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35257	 35547	 0.000606	 0.010359	 0.80787	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35257	 87097	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35257	 87097	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35258	 35463	 0.00979	 0.1038	 0.03084	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35258	 36282	 0.002067	 0.011392	 0.00266	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35258	 87555	 0.001237	 0.006099	 0.00165	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35259	 36363	 0.000914	 0.005787	 0.01212	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35259	 87100	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35259	 87100	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35259	 87582	 0.000335	 0.003423	 0.01087	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35260	 36044	 0.000229	 0.002863	 0.1962	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35260	 36053	 0.000133	 0.001654	 0.11333	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35260	 87101	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35260	 87101	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35261	 35538	 0.000248	 0.004149	 0.2711	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35261	 36032	 8.3e-05	 0.001425	 0.1109	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35261	 87102	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35261	 87102	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87103	 35261	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87103	 35261	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35262	 38603	 0.00092	 0.024004	 2.215	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35262	 38975	 0.001707	 0.022182	 1.4268	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35262	 87104	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35262	 87104	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87105	 35262	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87105	 35262	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35263	 35899	 0.007899	 0.053922	 0.09721	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35263	 87106	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35263	 87106	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35263	 87293	 0.000641	 0.006574	 0.01292	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35263	 87299	 0.00777	 0.077663	 0.26045	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35264	 35275	 0.002979	 0.032347	 0.06348	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35264	 35431	 0.000335	 0.003653	 0.01474	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35264	 35434	 0.002131	 0.020634	 0.073	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35264	 36361	 0.000775	 0.009445	 0.03523	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35264	 87107	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35264	 87107	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35265	 35266	 3e-06	 3.5e-05	 0.00242	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35265	 35553	 0.000165	 0.001974	 0.1481	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35266	 35953	 0.0011	 0.014251	 0.91239	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35266	 87108	 0.000324	 0.024331	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35266	 87108	 0.000324	 0.024331	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87109	 35266	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87109	 35266	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35267	 35539	 0.001437	 0.013292	 0.02501	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35267	 36031	 0.000726	 0.008624	 0.01723	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35267	 87110	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 1.0	 1	 -30.0	 30.0;
	35267	 87110	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 1.0	 1	 -30.0	 30.0;
	87111	 35267	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 0	 -30.0	 30.0;
	87111	 35267	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 0	 -30.0	 30.0;
	35268	 35805	 9.2e-05	 0.001185	 0.07559	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35268	 38543	 0.000777	 0.009277	 0.697	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35268	 87112	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35268	 87112	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87113	 35268	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87113	 35268	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35269	 35953	 0.000303	 0.005422	 0.38502	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35269	 35979	 0.001034	 0.012279	 0.93637	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35269	 36372	 0.001061	 0.015313	 1.228	 2385.0	 2504.2	 2623.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35269	 87114	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35269	 87114	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87115	 35269	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87115	 35269	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35270	 35273	 1.8e-05	 0.000228	 0.01458	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35270	 87116	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35270	 87116	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87117	 35270	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87117	 35270	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35271	 87118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35271	 87118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35271	 87257	 0.007292	 0.029195	 0.00736	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35271	 87576	 0.003202	 0.026169	 0.0071	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35272	 35641	 0.008506	 0.07066	 0.02765	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35272	 35649	 0.006494	 0.023514	 0.00505	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35272	 36575	 0.003722	 0.014901	 0.00375	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35272	 36598	 0.012155	 0.048668	 0.01226	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35273	 36590	 6.3e-05	 0.00078	 0.05344	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35273	 87119	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35273	 87119	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87120	 35273	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87120	 35273	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35274	 36148	 0.008618	 0.039124	 0.01358	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35274	 36149	 0.007784	 0.056001	 0.01484	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35275	 35428	 0.002668	 0.017566	 0.03399	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87097	 35275	 0.005877	 0.053819	 0.10373	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35275	 87121	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35275	 87121	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35276	 35728	 0.001388	 0.003869	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35276	 35739	 0.014643	 0.038702	 0.00906	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35276	 35746	 0.001269	 0.003353	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35277	 36408	 0.00808	 0.028161	 0.00653	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35277	 36411	 0.011563	 0.030559	 0.00715	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35277	 87122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35277	 87122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35278	 35565	 0.000368	 0.003068	 0.00957	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35278	 87123	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35278	 87123	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35279	 35435	 0.008588	 0.031242	 0.00957	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35279	 35664	 0.004054	 0.024149	 0.00635	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35280	 35962	 0.02975	 0.078645	 0.01841	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35280	 36523	 0.007516	 0.025324	 0.00629	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87102	 35281	 0.000412	 0.005787	 0.024	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35281	 87124	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35281	 87124	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35281	 87452	 7.1e-05	 0.001238	 0.00416	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35282	 36024	 0.01124	 0.11459	 0.02955	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35282	 36519	 0.005832	 0.030377	 0.00797	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35282	 87125	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35282	 87125	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35283	 36506	 0.005784	 0.023158	 0.00583	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35283	 36508	 0.002765	 0.009484	 0.00227	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35283	 36510	 0.000147	 0.000742	 0.00021	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35284	 35563	 0.015864	 0.053456	 0.01329	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35284	 36292	 0.012626	 0.043315	 0.01038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35284	 36293	 0.013614	 0.05451	 0.01374	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35284	 87126	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35284	 87126	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35285	 36538	 0.001913	 0.013046	 0.02349	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35285	 87127	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35285	 87127	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87128	 35285	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87128	 35285	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35285	 87648	 0.002946	 0.0194	 0.03754	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35286	 36431	 0.004456	 0.041947	 0.01271	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35286	 36432	 0.004865	 0.013245	 0.00292	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35286	 36503	 0.00699	 0.019031	 0.00419	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35286	 87129	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35286	 87129	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35287	 35708	 0.1171	 0.22953	 0.00344	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35287	 35710	 0.092285	 0.12581	 0.00279	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35287	 35711	 0.028258	 0.065605	 0.00098	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35288	 35696	 0.004341	 0.022988	 0.00583	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35288	 36060	 0.006506	 0.039979	 0.01462	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35289	 87130	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35289	 87130	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35289	 87256	 0.001736	 0.006951	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87103	 35290	 0.001225	 0.00383	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35291	 36592	 0.009627	 0.049216	 0.01342	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35291	 36594	 0.003596	 0.01933	 0.00476	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35291	 87131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35291	 87131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35292	 36288	 0.001237	 0.004812	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35292	 87513	 0.001867	 0.006404	 0.00153	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35293	 36002	 0.001188	 0.007821	 0.01513	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35293	 87132	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35293	 87132	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87133	 35293	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87133	 35293	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35294	 36392	 0.027636	 0.11417	 0.02703	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35294	 36592	 0.003376	 0.013738	 0.00335	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35294	 87134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35294	 87134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35295	 36149	 0.003578	 0.018288	 0.00498	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35295	 36488	 0.010396	 0.05416	 0.01421	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35296	 35306	 0.018756	 0.05036	 0.01142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35296	 35548	 0.011861	 0.031349	 0.00734	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35296	 35549	 0.005572	 0.021678	 0.00579	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35296	 36473	 0.021891	 0.079285	 0.01702	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35296	 36482	 0.012076	 0.043729	 0.00938	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35297	 35544	 0.008617	 0.024958	 0.00602	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35297	 35687	 0.014756	 0.059087	 0.01489	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35297	 87135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35297	 87135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35298	 36160	 0.002979	 0.022443	 0.00623	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35298	 36164	 0.010787	 0.028509	 0.00667	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35298	 87136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35298	 87136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35299	 35819	 0.001755	 0.004895	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35299	 35862	 0.000369	 0.001006	 0.00022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35300	 35694	 0.010358	 0.026627	 0.00659	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35300	 35698	 0.005745	 0.019708	 0.00472	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35300	 35701	 0.004228	 0.016927	 0.00426	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35300	 87137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35300	 87137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35301	 35696	 0.008236	 0.029822	 0.0064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35301	 36521	 0.004174	 0.021742	 0.0057	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35302	 36421	 0.00211	 0.013696	 0.02728	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35302	 36424	 0.001701	 0.011599	 0.02089	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35303	 35528	 0.001343	 0.006122	 0.00194	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35303	 35729	 0.008741	 0.050131	 0.01667	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35303	 35736	 0.007203	 0.034092	 0.0082	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35304	 35596	 0.002042	 0.012041	 0.0098	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35304	 35599	 0.010304	 0.030379	 0.00707	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35304	 35981	 0.001149	 0.009233	 0.0026	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35304	 35988	 0.000826	 0.010391	 0.00322	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35304	 35995	 0.003022	 0.015286	 0.00426	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35304	 35999	 0.004761	 0.036213	 0.01138	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35304	 87138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35304	 87138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35305	 35435	 0.006498	 0.037337	 0.01058	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35305	 35678	 0.00422	 0.024248	 0.00687	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35305	 87139	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35305	 87139	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35306	 35548	 0.011501	 0.029566	 0.00732	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35306	 35554	 0.007096	 0.023673	 0.006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35306	 35610	 0.024223	 0.067559	 0.01418	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35306	 35611	 0.010769	 0.057038	 0.01446	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35306	 87140	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35306	 87140	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35307	 35842	 0.00192	 0.005074	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35307	 35882	 0.000755	 0.002518	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35308	 36650	 0.001048	 0.009977	 0.03645	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35308	 36653	 0.001683	 0.014901	 0.06315	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35308	 87141	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35308	 87141	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87142	 35308	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87142	 35308	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35308	 87792	 0.001351	 0.01264	 0.04791	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35309	 37507	 0.000109	 0.001409	 0.08989	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35309	 37511	 0.000191	 0.002276	 0.17073	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35309	 37513	 7.3e-05	 0.000917	 0.0628	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35309	 37532	 3.9e-05	 0.000966	 0.09769	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35309	 87143	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35309	 87143	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87144	 35309	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87144	 35309	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35310	 36774	 0.000336	 0.004292	 0.28087	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35310	 37109	 0.000422	 0.007208	 0.56153	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35310	 37659	 0.000102	 0.001208	 0.09188	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35310	 87145	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35310	 87145	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35311	 36648	 0.000256	 0.006553	 0.44883	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35311	 36773	 0.000103	 0.001326	 0.08466	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35311	 36774	 0.000134	 0.001727	 0.11022	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35311	 36974	 6.3e-05	 0.001794	 0.12478	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35311	 87148	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35311	 87148	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87149	 35311	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87149	 35311	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35312	 37529	 0.000209	 0.00337	 0.2366	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35312	 37533	 5.3e-05	 0.000685	 0.05138	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35312	 87150	 0.000229	 0.017175	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35312	 87150	 0.000229	 0.017175	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35313	 37254	 9e-06	 0.000156	 0.01261	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35313	 37256	 8.8e-05	 0.001103	 0.07555	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35313	 37257	 2.4e-05	 0.00049	 0.03282	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35313	 37281	 0.000104	 0.002883	 0.21607	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35313	 37479	 0.000131	 0.003127	 0.25437	 2811.0	 2951.5	 3092.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35313	 87153	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35313	 87153	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87154	 35313	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87154	 35313	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35314	 36930	 0.001071	 0.012797	 0.96287	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35314	 87155	 0.000278	 0.020855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35314	 87155	 0.000278	 0.020855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87156	 35314	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87156	 35314	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35315	 35326	 2e-06	 2.7e-05	 0.0017	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35315	 37533	 0.000585	 0.0073	 0.5006	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35315	 87157	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35315	 87157	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35316	 35317	 3.2e-05	 0.00038	 0.02854	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35316	 37467	 0.000491	 0.005857	 0.43965	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35316	 87158	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35316	 87158	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35317	 36685	 0.000191	 0.002278	 0.17088	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35318	 37181	 0.001901	 0.013332	 0.0227	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35318	 37632	 0.002406	 0.021757	 0.0429	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35318	 87159	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35318	 87159	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87160	 35318	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87160	 35318	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35319	 37069	 0.002588	 0.020795	 0.04511	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35319	 87168	 1.1e-05	 0.000105	 0.00022	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35320	 37013	 0.000114	 0.00169	 0.1087	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35320	 87161	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35320	 87161	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35321	 37421	 9.9e-05	 0.001369	 0.11835	 2385.0	 2504.2	 2623.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35321	 37422	 4.6e-05	 0.000719	 0.06983	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35322	 37275	 4.2e-05	 0.0007	 0.07249	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35322	 37277	 2.7e-05	 0.000453	 0.0441	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35322	 87162	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35322	 87162	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35323	 36833	 0.002352	 0.016318	 0.00466	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35323	 36835	 0.001309	 0.010451	 0.00258	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35323	 36845	 0.000346	 0.004992	 0.00181	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35323	 87744	 0.000796	 0.00859	 0.00294	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35324	 37282	 0.000193	 0.002687	 0.17143	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35324	 37458	 0.000451	 0.008061	 0.57276	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35324	 87163	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35324	 87163	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35325	 37365	 0.003024	 0.039073	 0.08861	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35325	 37592	 0.001047	 0.007209	 0.01273	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35325	 87166	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35325	 87166	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87167	 35325	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87167	 35325	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35326	 87168	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35326	 87168	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35327	 36814	 3.9e-05	 0.000475	 0.03396	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35327	 87169	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35327	 87169	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87170	 35327	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87170	 35327	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35328	 36706	 0.001768	 0.01317	 0.02508	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35328	 87807	 0.000689	 0.005219	 0.0096	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35329	 37408	 0.000224	 0.002893	 0.18466	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35329	 37460	 6e-06	 0.000167	 0.01154	 2893.0	 3037.6	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35330	 37091	 0.000646	 0.003472	 0.00085	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35331	 37507	 0.000109	 0.001297	 0.09732	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35331	 37533	 0.000127	 0.001514	 0.11359	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35331	 87171	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35331	 87171	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35332	 36616	 0.002473	 0.011784	 0.00341	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35332	 36618	 0.005165	 0.017718	 0.00424	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35332	 37710	 0.00437	 0.01529	 0.00507	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35333	 37357	 0.11924	 0.23613	 0.00347	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35333	 37366	 0.015165	 0.070276	 0.00135	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35333	 37703	 0.059171	 0.13738	 0.00204	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35333	 88032	 0.097841	 0.16483	 0.00235	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35334	 37415	 0.001274	 0.0051	 0.00128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35334	 37418	 0.004355	 0.017981	 0.00425	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35334	 87957	 0.002133	 0.009026	 0.00203	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35335	 36824	 0.017603	 0.054748	 0.01143	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35335	 37609	 0.012271	 0.044646	 0.01367	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35335	 37612	 0.011175	 0.061327	 0.01621	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35335	 87172	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35335	 87172	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35336	 35338	 5.4e-05	 0.000642	 0.04816	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35336	 37460	 0.000128	 0.0016	 0.10963	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35336	 87173	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35336	 87173	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87174	 35336	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87174	 35336	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35337	 37100	 0.001173	 0.00554	 0.00177	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35337	 37101	 0.001098	 0.005415	 0.00146	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35337	 87903	 0.00091	 0.003577	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35338	 37460	 0.00018	 0.002327	 0.14853	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35338	 87175	 0.000229	 0.017175	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35338	 87175	 0.000229	 0.017175	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87176	 35338	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87176	 35338	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35339	 37488	 0.023115	 0.036897	 0.00085	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87165	 35339	 0.003531	 0.008763	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35340	 36809	 0.005145	 0.026298	 0.00717	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35340	 37431	 0.004012	 0.01899	 0.00457	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35340	 37432	 0.003446	 0.016307	 0.00392	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35340	 87177	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35340	 87177	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35341	 37397	 0.000593	 0.004533	 0.01685	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35341	 87977	 0.000294	 0.003503	 0.00758	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35342	 36876	 0.002361	 0.006239	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35342	 36887	 0.00112	 0.003006	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35342	 87768	 0.001159	 0.003974	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35343	 37970	 0.0111	 0.072177	 0.14413	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35343	 48003	 0.010055	 0.089526	 0.38256	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35343	 87178	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35343	 87178	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87179	 35343	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87179	 35343	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35343	 87182	 0.002598	 0.030618	 0.05652	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35343	 91825	 0.008353	 0.081173	 0.28875	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35344	 38339	 0.000792	 0.010899	 0.02172	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35344	 38343	 0.00015	 0.001702	 0.00635	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35344	 38351	 0.002862	 0.018578	 0.03701	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35345	 36281	 0.000472	 0.005633	 0.42283	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35345	 37896	 0.000397	 0.007103	 0.50456	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35345	 87180	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35345	 87180	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87181	 35345	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 0	 -30.0	 30.0;
	87181	 35345	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 0	 -30.0	 30.0;
	35346	 38325	 0.00023	 0.003834	 0.25048	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35346	 87182	 0.000365	 0.029198	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35346	 87182	 0.000365	 0.029198	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87183	 35346	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87183	 35346	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35347	 38099	 0.01482	 0.097884	 0.19026	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35347	 87184	 6.8e-05	 0.000854	 0.00168	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35348	 37766	 7.6e-05	 0.001218	 0.08551	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35348	 38201	 0.000434	 0.005388	 0.37325	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35348	 87184	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35348	 87184	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35349	 38054	 0.004017	 0.0142	 0.0032	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35349	 38056	 0.001894	 0.011993	 0.00326	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35349	 38057	 0.007723	 0.031888	 0.00754	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35349	 38058	 0.001663	 0.019011	 0.0058	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35349	 87187	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35349	 87187	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35350	 35352	 0.001531	 0.019871	 1.2761	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35350	 38208	 2.6e-05	 0.000319	 0.02186	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35350	 39643	 0.000641	 0.01097	 0.8558	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35350	 87188	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35350	 87188	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87189	 35350	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87189	 35350	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35351	 37803	 0.00011	 0.001835	 0.00667	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35351	 39642	 0.000379	 0.004935	 0.01858	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35351	 39644	 0.00023	 0.001883	 0.00339	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35351	 87190	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35351	 87190	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87191	 35351	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87191	 35351	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35352	 37765	 0.00021	 0.002503	 0.18774	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35352	 38325	 0.001918	 0.024092	 1.6674	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35352	 87192	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35352	 87192	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35353	 38237	 0.008542	 0.057692	 0.10638	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35353	 38759	 0.002785	 0.037922	 0.07722	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35353	 87193	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35353	 87193	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35354	 37920	 0.002091	 0.011527	 0.00269	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35354	 37925	 0.001353	 0.014663	 0.00458	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35354	 37947	 0.002644	 0.013773	 0.00361	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35354	 37949	 0.000151	 0.000595	 0.00016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35354	 38144	 0.006932	 0.03611	 0.00947	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35354	 38149	 0.008722	 0.063763	 0.01882	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35354	 87194	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35354	 87194	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35355	 37739	 0.002101	 0.02105	 0.00701	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35355	 37740	 0.012505	 0.049153	 0.01286	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35355	 37742	 0.004648	 0.021324	 0.00546	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35355	 38182	 0.044403	 0.14975	 0.03727	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35355	 38367	 0.036304	 0.14787	 0.03607	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87192	 35355	 0.021124	 0.10256	 0.02346	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35355	 87195	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35355	 87195	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35356	 38015	 0.000912	 0.00733	 0.00206	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35356	 38016	 0.001637	 0.01842	 0.00484	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35357	 35979	 0.000257	 0.003062	 0.22975	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35357	 38198	 0.000646	 0.008348	 0.53335	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35357	 87196	 0.000281	 0.02246	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35357	 87196	 0.000281	 0.02246	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35358	 38289	 0.000213	 0.002719	 0.1779	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35358	 38325	 0.001784	 0.023193	 1.493	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35358	 47011	 0.000881	 0.01132	 0.85097	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35358	 87198	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35358	 87198	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35359	 38041	 0.005996	 0.025376	 0.00571	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35359	 38042	 0.008662	 0.045122	 0.01183	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35359	 38072	 0.014122	 0.079991	 0.01983	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35359	 38134	 0.045554	 0.15365	 0.03824	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35359	 38192	 0.027905	 0.10108	 0.0217	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35360	 37793	 0.017469	 0.088401	 0.02462	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35360	 38024	 0.00891	 0.030566	 0.00732	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35360	 38026	 0.006583	 0.034293	 0.00899	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35360	 38080	 0.005	 0.020018	 0.00504	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35361	 35374	 0.000133	 0.000483	 0.0001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35361	 37783	 0.001017	 0.007437	 0.00219	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35361	 38207	 0.036608	 0.12566	 0.03013	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35361	 38313	 0.02829	 0.14463	 0.03643	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35361	 87201	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35361	 87201	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35362	 38316	 0.000423	 0.004816	 0.00953	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35362	 87202	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35362	 87202	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87203	 35362	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87203	 35362	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35363	 37721	 0.004944	 0.01346	 0.00297	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35363	 87204	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35363	 87204	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35364	 38027	 0.023156	 0.091044	 0.02383	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35364	 38034	 0.012497	 0.05086	 0.01239	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35364	 38038	 0.008117	 0.030855	 0.00864	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35364	 38039	 0.000581	 0.00452	 0.00117	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35364	 87205	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35364	 87205	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35365	 37984	 0.019434	 0.079104	 0.01928	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35365	 38376	 0.029084	 0.079202	 0.01745	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35365	 88252	 0.004264	 0.017073	 0.0043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35366	 38019	 0.013319	 0.037143	 0.0078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35366	 38283	 0.017015	 0.049288	 0.01189	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35366	 38284	 0.016624	 0.043162	 0.01048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35366	 38285	 0.004189	 0.020697	 0.00604	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35367	 38130	 0.010599	 0.035714	 0.00888	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35367	 38134	 0.004279	 0.014418	 0.00358	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35368	 38065	 0.002077	 0.011931	 0.00338	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35368	 38075	 0.006779	 0.023256	 0.00557	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35368	 38076	 0.004568	 0.017365	 0.00486	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35369	 37896	 7e-06	 8.7e-05	 0.0065	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35369	 87206	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 -1.0	 1	 -30.0	 30.0;
	35369	 87206	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 -1.0	 1	 -30.0	 30.0;
	87207	 35369	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 0	 -30.0	 30.0;
	87207	 35369	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 0	 -30.0	 30.0;
	35370	 38375	 0.00201	 0.008047	 0.00203	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35370	 38377	 0.000356	 0.001505	 0.00034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35371	 38080	 0.004413	 0.015137	 0.00363	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35371	 38081	 0.00634	 0.022096	 0.00512	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35372	 37842	 0.0017	 0.004564	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35372	 87208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35372	 87208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35373	 37838	 0.011122	 0.038155	 0.00914	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35373	 38218	 0.015922	 0.040026	 0.01037	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35373	 38219	 0.002523	 0.010502	 0.00327	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35374	 37779	 0.009127	 0.050926	 0.01301	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35374	 87209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35374	 87209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35375	 38112	 0.014494	 0.028697	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35376	 37771	 0.025562	 0.07538	 0.01754	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35376	 38018	 0.010883	 0.028254	 0.00686	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35376	 38021	 0.011674	 0.034418	 0.00801	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35377	 35388	 0.000472	 0.007275	 0.56021	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35377	 36804	 0.000176	 0.004558	 0.41523	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35377	 39259	 0.000132	 0.002182	 0.19133	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35377	 39655	 0.000117	 0.001512	 0.09647	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35377	 87210	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35377	 87210	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87211	 35377	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87211	 35377	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35378	 35379	 0.0003	 0.007395	 0.54535	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35378	 35392	 7e-06	 0.000144	 0.01687	 3627.0	 3808.3	 3989.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35378	 38543	 0.000991	 0.017786	 1.2694	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35378	 39338	 0.000305	 0.00724	 0.65259	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35378	 87212	 0.00016	 0.012814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35378	 87212	 0.00016	 0.012814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35379	 38910	 0.000189	 0.003381	 0.24001	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35379	 87214	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35379	 87214	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35380	 37365	 0.007497	 0.073892	 0.25456	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35380	 87217	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35380	 87217	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87218	 35380	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87218	 35380	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35380	 88273	 0.0012	 0.010342	 0.01946	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35381	 38910	 0.000152	 0.001901	 0.13027	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35381	 39201	 0.00034	 0.004398	 0.28076	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35381	 87219	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35381	 87219	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87220	 35381	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87220	 35381	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35382	 39635	 6.2e-05	 0.000743	 0.05573	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35382	 39646	 2.8e-05	 0.000471	 0.04581	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35382	 87221	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35382	 87221	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35383	 38801	 0.002428	 0.021956	 0.04329	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35383	 38930	 0.00051	 0.00425	 0.01326	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35383	 87222	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35383	 87222	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87223	 35383	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87223	 35383	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35384	 38801	 0.004703	 0.042541	 0.08393	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35384	 39795	 0.002443	 0.02474	 0.04981	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35384	 87224	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35384	 87224	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87225	 35384	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87225	 35384	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35384	 88725	 0.000128	 0.00155	 0.003	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35385	 38955	 0.003962	 0.041411	 0.01394	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35385	 38956	 0.005529	 0.054869	 0.01492	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35385	 39807	 0.002963	 0.023649	 0.00583	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35385	 39808	 0.001447	 0.01072	 0.00549	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35385	 87798	 0.016542	 0.10824	 0.04012	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35386	 37458	 0.002316	 0.030236	 1.9584	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35386	 38396	 0.000207	 0.003707	 0.26312	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35386	 39334	 6.6e-05	 0.000789	 0.05917	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35386	 87226	 0.000101	 0.00811	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35386	 87226	 0.000101	 0.00811	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35387	 38745	 0.00042	 0.005752	 0.43538	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35387	 39643	 0.000793	 0.0128	 0.90096	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35387	 87229	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35387	 87229	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35388	 38406	 0.000236	 0.003377	 0.2333	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35388	 38975	 4.2e-05	 0.000702	 0.04582	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35388	 87232	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35388	 87232	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87233	 35388	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87233	 35388	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35389	 39182	 0.001899	 0.02663	 0.05107	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35389	 87234	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35389	 87234	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87235	 35389	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87235	 35389	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35389	 88398	 0.007662	 0.052021	 0.09482	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35390	 38572	 0.00365	 0.02515	 0.04441	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35390	 39333	 0.022215	 0.15414	 0.27496	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35390	 39342	 0.003894	 0.050338	 0.11421	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35390	 39720	 0.000278	 0.002731	 0.00937	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35390	 87236	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35390	 87236	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87237	 35390	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87237	 35390	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35391	 38454	 0.00298	 0.018874	 0.00512	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35391	 39158	 0.003133	 0.019467	 0.00549	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35392	 35407	 6e-06	 0.000135	 0.01352	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35392	 87238	 0.000365	 0.029198	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35392	 87238	 0.000365	 0.029198	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87239	 35392	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87239	 35392	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35393	 38521	 0.011351	 0.029179	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35393	 39293	 0.051133	 0.13145	 0.00203	 77.0	 77.0	 77.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35393	 87995	 0.098664	 0.18348	 0.0043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35394	 36419	 0.001305	 0.046868	 4.2152	 4217.0	 4427.8	 4638.7	 0.0	 0.0	 0	 -30.0	 30.0;
	35394	 39021	 0.000648	 0.00774	 0.58123	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35394	 39427	 0.000416	 0.007713	 0.50974	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35394	 87240	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35394	 87240	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87241	 35394	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 0	 -30.0	 30.0;
	87241	 35394	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35394	 95333	 0.001487	 0.026818	 1.9282	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 0	 -30.0	 30.0;
	35395	 39660	 0.004464	 0.016506	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35395	 88727	 0.00506	 0.016226	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35396	 38433	 0.004907	 0.014901	 0.00326	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35396	 38435	 0.012675	 0.035348	 0.00742	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35396	 87242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35396	 87242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35397	 38766	 0.007344	 0.024743	 0.00615	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35397	 38773	 0.008983	 0.041214	 0.01056	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35397	 39275	 0.005977	 0.019493	 0.00518	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35397	 87243	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35397	 87243	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35398	 38730	 0.015722	 0.042211	 0.00957	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35398	 38731	 0.009608	 0.032372	 0.00805	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35398	 39318	 0.005714	 0.029209	 0.00796	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35398	 39319	 0.006832	 0.042455	 0.01198	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35398	 39653	 0.013166	 0.035848	 0.0079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35398	 87244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35398	 87244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35399	 39235	 0.007486	 0.03965	 0.01005	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35399	 39302	 0.005022	 0.016921	 0.00421	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35400	 38309	 0.017497	 0.043987	 0.0114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35400	 38925	 0.005833	 0.032121	 0.0116	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35400	 38926	 0.003437	 0.025892	 0.00718	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35400	 38927	 0.00367	 0.01284	 0.00426	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35401	 38869	 0.001522	 0.009065	 0.00238	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35401	 38895	 0.000771	 0.003741	 0.00086	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35401	 87245	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35401	 87245	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35402	 39686	 0.023044	 0.076875	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35402	 39688	 0.090278	 0.091186	 0.00121	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35402	 39690	 0.045465	 0.056436	 0.00123	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35403	 38505	 0.0036	 0.019842	 0.00464	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35403	 39261	 0.004633	 0.042221	 0.01534	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35403	 39262	 0.014207	 0.03755	 0.00879	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35404	 39139	 0.003301	 0.015397	 0.00381	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35404	 39142	 0.003071	 0.013941	 0.00484	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35405	 39141	 0.002006	 0.008161	 0.00199	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35405	 39143	 0.001058	 0.008502	 0.00239	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35406	 39764	 0.003231	 0.023867	 0.00689	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35406	 39816	 0.002716	 0.017761	 0.00658	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35407	 39334	 0.000195	 0.004872	 0.39769	 2893.0	 3037.6	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35407	 87246	 0.000229	 0.017175	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35407	 87246	 0.000229	 0.017175	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35408	 39649	 0.003127	 0.016805	 0.00413	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35408	 39650	 0.002849	 0.00753	 0.00176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35408	 87248	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35408	 87248	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35409	 38798	 0.00449	 0.022953	 0.00626	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35409	 38982	 0.002063	 0.008517	 0.00201	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35410	 38986	 0.005619	 0.035593	 0.00966	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35410	 38987	 0.003125	 0.016277	 0.00427	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35410	 39411	 0.004228	 0.012727	 0.00398	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35410	 39417	 0.002838	 0.017973	 0.00488	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35411	 39665	 0.001525	 0.006106	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35411	 39666	 0.001934	 0.005545	 0.00136	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35411	 87249	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35411	 87249	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35412	 39695	 0.003474	 0.013908	 0.0035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35412	 39784	 0.004405	 0.022948	 0.00602	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35412	 39785	 0.002855	 0.010091	 0.00227	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35412	 87250	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35412	 87250	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35413	 39306	 0.013114	 0.058435	 0.00099	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35413	 87252	 0.003294	 0.010114	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35414	 38487	 0.011165	 0.037244	 0.00059	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35414	 38499	 0.29378	 0.23256	 0.00293	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35414	 38992	 0.077574	 0.30186	 0.00504	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35415	 38628	 0.006948	 0.017861	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35415	 38629	 0.006594	 0.025264	 0.00071	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35415	 38640	 0.005955	 0.015143	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35416	 88270	 0.014262	 0.055483	 0.00093	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35417	 39733	 0.000609	 0.004859	 0.0012	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35417	 88317	 0.002876	 0.00848	 0.00197	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35418	 88719	 0.007292	 0.021949	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35419	 39199	 0.001496	 0.010202	 0.01837	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35419	 87251	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35419	 87251	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35419	 88540	 0.000893	 0.006093	 0.01097	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35420	 39302	 0.010384	 0.036706	 0.00827	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35420	 39304	 0.011515	 0.032111	 0.00674	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35420	 87252	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35420	 87252	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35421	 38927	 0.002939	 0.011961	 0.00291	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35422	 88456	 0.058884	 0.12619	 0.00221	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35423	 39764	 0.003693	 0.018245	 0.00533	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35423	 39768	 0.000946	 0.004836	 0.00132	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35424	 35432	 0.003232	 0.017815	 0.00416	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35424	 87253	 0.001347	 0.007018	 0.00184	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35425	 87254	 0.018077	 0.0133	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35426	 35427	 0.000138	 0.000999	 0.00415	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35426	 35429	 0.000471	 0.003859	 0.00695	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35426	 35431	 0.00061	 0.007878	 0.01785	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35426	 87253	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87254	 35426	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35427	 35428	 0.000212	 0.001763	 0.0055	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35428	 87255	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35428	 87255	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35429	 36361	 0.000723	 0.009336	 0.02115	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35429	 87256	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35429	 87256	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87130	 35430	 0.007714	 0.029677	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35431	 87257	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35431	 87257	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35432	 35433	 0.00768	 0.032505	 0.00731	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87107	 35432	 0.011456	 0.045871	 0.01156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35433	 35554	 0.008182	 0.033297	 0.00811	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87108	 35434	 0.000348	 0.004085	 0.00912	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35434	 87258	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35434	 87258	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87107	 35435	 0.010813	 0.042069	 0.01124	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87258	 35435	 0.004775	 0.041667	 0.01144	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35436	 35713	 0.000375	 0.004478	 0.33606	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35437	 35440	 0.11193	 0.11197	 0.00151	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35438	 87259	 0.018848	 0.091978	 0.00159	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35438	 87534	 0.018409	 0.13456	 0.00248	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35439	 87259	 0.063171	 0.21076	 0.00334	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35440	 87259	 0.021733	 0.044476	 0.00109	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87091	 35441	 0.015882	 0.06914	 0.0197	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35441	 87259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35441	 87259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35442	 35444	 0.005638	 0.029367	 0.0077	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35442	 87533	 0.00531	 0.029139	 0.0077	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35443	 35445	 0.00305	 0.012696	 0.00396	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35443	 35447	 0.003326	 0.017879	 0.0044	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35443	 87557	 0.01739	 0.062978	 0.01352	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35444	 35445	 0.001027	 0.005519	 0.00136	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35445	 87260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35445	 87260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35446	 35454	 0.034244	 0.064721	 0.00105	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87260	 35446	 0.008345	 0.03656	 0.00079	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35447	 35449	 0.003874	 0.021353	 0.00499	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35447	 35452	 0.011088	 0.030922	 0.00649	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35448	 87263	 0.072145	 0.18547	 0.00287	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35449	 35463	 0.006587	 0.034312	 0.009	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35450	 35451	 0.11888	 0.087469	 0.00128	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35451	 87263	 0.026522	 0.068179	 0.00106	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35452	 35456	 0.007951	 0.028791	 0.00618	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35453	 87262	 0.057803	 0.063577	 0.00085	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35454	 87261	 0.026949	 0.044944	 0.00065	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35455	 35456	 0.008145	 0.022714	 0.00477	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35455	 87261	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35455	 87261	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35456	 36282	 0.015904	 0.06188	 0.01653	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35456	 87262	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35456	 87262	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35457	 87263	 0.030002	 0.099008	 0.0016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35458	 35460	 0.023335	 0.059345	 0.00094	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35458	 35461	 0.11723	 0.10994	 0.0017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35458	 87264	 0.011864	 0.067443	 0.00122	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35459	 35460	 0.1911	 0.14061	 0.00206	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35462	 36290	 0.28866	 0.22633	 0.00291	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35463	 35464	 0.003135	 0.013643	 0.00389	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35463	 87263	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35463	 87263	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35464	 87264	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35464	 87264	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35465	 35466	 0.028881	 0.095308	 0.00154	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87263	 35465	 0.025968	 0.11442	 0.00199	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87264	 35466	 0.051979	 0.2	 0.00341	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35467	 35473	 0.001368	 0.010567	 0.0215	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35467	 36424	 0.002997	 0.019457	 0.03876	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35467	 87265	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35467	 87265	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35468	 35469	 0.015709	 0.047046	 0.0106	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35468	 35472	 0.017951	 0.046608	 0.01131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35468	 87266	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35468	 87266	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35469	 35651	 0.025507	 0.075217	 0.0175	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35470	 87329	 0.22478	 0.17792	 0.00224	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35471	 35475	 0.002106	 0.014886	 0.02492	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35471	 35776	 0.002634	 0.01847	 0.03145	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35472	 87267	 0.00726	 0.017496	 0.00494	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35473	 35475	 0.001833	 0.012505	 0.02252	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35473	 87267	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35473	 87267	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86209	 35474	 0.2104	 0.49866	 0.00913	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35474	 87269	 0.024855	 0.063894	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35474	 87368	 0.17798	 0.37426	 0.00682	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35475	 87268	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87269	 35475	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35476	 35479	 0.017891	 0.047288	 0.01107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35476	 87270	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35476	 87270	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35477	 36472	 0.016476	 0.042357	 0.01049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35477	 87638	 0.014096	 0.036596	 0.00888	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35478	 35479	 0.02479	 0.069142	 0.01452	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35478	 87271	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35478	 87271	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35478	 87615	 0.017991	 0.046252	 0.01145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35479	 36391	 0.020221	 0.069378	 0.01663	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35479	 87272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35479	 87272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35480	 35481	 0.005427	 0.021728	 0.00547	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35480	 36436	 0.004692	 0.029718	 0.00807	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35480	 87273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35480	 87273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35481	 35483	 0.007318	 0.037018	 0.01031	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35481	 87274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35481	 87274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87274	 35482	 0.016071	 0.074933	 0.00172	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35482	 87276	 0.017757	 0.073724	 0.00192	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35483	 36173	 0.007498	 0.033763	 0.00898	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35483	 87275	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35483	 87275	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35484	 35632	 0.11579	 0.12366	 0.00261	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35484	 87276	 0.031123	 0.17514	 0.00378	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35484	 87508	 0.061847	 0.1514	 0.00259	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35485	 35646	 0.004332	 0.034129	 0.00998	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35485	 36162	 0.011539	 0.077337	 0.0237	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35485	 87276	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35485	 87276	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35486	 35487	 0.006648	 0.030497	 0.00781	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35486	 35912	 0.003679	 0.019484	 0.00494	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35487	 35646	 0.008873	 0.03044	 0.00729	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35487	 87277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35487	 87277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35488	 35910	 0.045191	 0.11493	 0.00182	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87276	 35488	 0.073953	 0.17641	 0.00395	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87277	 35488	 0.13945	 0.14673	 0.00215	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35488	 87414	 0.082598	 0.16905	 0.00416	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87266	 35489	 0.31976	 0.23535	 0.00344	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35490	 35491	 0.008127	 0.036591	 0.00974	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35490	 36070	 0.007033	 0.043701	 0.01233	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35490	 87278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35490	 87278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35491	 36399	 0.011404	 0.04566	 0.0115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35492	 87279	 0.062124	 0.1121	 0.00162	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35493	 87279	 0.068085	 0.048229	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35494	 35495	 0.00555	 0.028367	 0.00773	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35494	 87279	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35494	 87279	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35494	 87281	 0.007627	 0.03899	 0.01063	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35495	 36057	 0.009292	 0.057743	 0.0163	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35495	 36291	 0.020793	 0.084637	 0.02063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87279	 35496	 0.089398	 0.07075	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35497	 35628	 0.062991	 0.14623	 0.00278	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87279	 35497	 0.065428	 0.1339	 0.0033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35498	 35499	 0.00017	 0.002026	 0.15198	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35498	 87280	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87281	 35498	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35499	 35613	 0.000383	 0.004945	 0.31571	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35499	 87282	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87283	 35499	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87090	 35500	 0.34603	 0.27135	 0.00348	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35501	 35504	 0.001402	 0.006366	 0.00221	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35501	 35506	 0.002242	 0.010684	 0.00309	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35501	 87284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35501	 87284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35502	 87285	 0.028839	 0.022605	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35503	 35504	 0.001298	 0.004935	 0.00138	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35503	 35505	 0.004129	 0.010912	 0.00255	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35503	 35516	 0.000762	 0.00732	 0.00213	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35503	 87294	 0.002473	 0.025437	 0.00721	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35504	 35513	 0.002541	 0.008715	 0.00209	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35504	 87285	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35504	 87285	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35505	 35511	 0.002786	 0.009556	 0.00229	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35505	 87286	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35505	 87286	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35506	 35509	 0.006654	 0.020798	 0.00602	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35506	 35518	 0.002916	 0.015441	 0.00391	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35506	 87287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35506	 87287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87286	 35507	 0.00495	 0.014197	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87284	 35508	 0.021702	 0.038764	 0.00057	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35508	 87288	 0.017613	 0.019542	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35509	 35510	 0.003292	 0.011091	 0.00276	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87106	 35509	 0.003479	 0.02996	 0.0174	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35509	 87288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35509	 87288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35510	 35574	 0.014419	 0.037068	 0.00918	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35511	 35512	 0.001803	 0.007086	 0.00185	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35512	 35513	 0.0025	 0.009094	 0.00278	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35512	 36490	 0.007589	 0.019703	 0.00478	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87106	 35512	 0.002681	 0.021123	 0.00618	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35512	 87289	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35512	 87289	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35514	 35517	 0.053089	 0.07736	 0.00175	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87289	 35514	 0.024298	 0.061794	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87106	 35515	 0.004721	 0.018901	 0.00476	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35515	 87294	 0.002304	 0.012701	 0.00297	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35516	 35522	 0.006926	 0.0348	 0.00906	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35516	 35526	 0.005292	 0.024679	 0.00611	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35516	 87290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35516	 87290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35517	 35738	 0.11849	 0.30466	 0.00472	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87284	 35517	 0.05657	 0.07435	 0.00102	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87290	 35517	 0.024317	 0.02911	 0.00048	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35518	 35522	 0.002598	 0.011698	 0.00311	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87287	 35519	 0.059993	 0.11879	 0.00174	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35520	 35522	 0.00298	 0.012126	 0.00295	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35520	 35525	 0.003028	 0.010388	 0.00249	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35520	 87291	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35520	 87291	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87291	 35521	 0.045904	 0.035981	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35522	 35524	 0.010986	 0.043987	 0.01108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35523	 87292	 0.10425	 0.081719	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35524	 35545	 0.013743	 0.05402	 0.01413	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35524	 87292	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35524	 87292	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35525	 35739	 0.012904	 0.045615	 0.01028	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35526	 35527	 0.008523	 0.027801	 0.00738	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35527	 35737	 0.005399	 0.018012	 0.00457	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35528	 36492	 0.006928	 0.038653	 0.00987	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35529	 87293	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87295	 35530	 0.10803	 0.085493	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35531	 36410	 0.077137	 0.15273	 0.00224	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35531	 87296	 0.12317	 0.20193	 0.00357	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35532	 87297	 0.11488	 0.074376	 0.00142	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35533	 36517	 0.006593	 0.051952	 0.0152	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35533	 87296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35533	 87296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35533	 87300	 0.008114	 0.06325	 0.01892	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35534	 35535	 0.007348	 0.019077	 0.00463	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35534	 35537	 0.005938	 0.015942	 0.00361	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35534	 87297	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35534	 87297	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35535	 36025	 0.01344	 0.034552	 0.00856	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87110	 35535	 0.02164	 0.060354	 0.01267	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35536	 87298	 0.021485	 0.017003	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35537	 87298	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35537	 87298	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35537	 87300	 0.00399	 0.011126	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35538	 39427	 0.001295	 0.044631	 4.3556	 4217.0	 4427.8	 4638.7	 0.0	 0.0	 0	 -30.0	 30.0;
	35538	 87299	 0.000111	 0.008848	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35538	 87299	 0.000111	 0.008848	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87300	 35538	 0.000108	 0.008649	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35538	 95333	 0.000541	 0.017187	 1.7877	 4217.0	 4427.8	 4638.7	 0.0	 0.0	 0	 -30.0	 30.0;
	87299	 35539	 0.000737	 0.00632	 0.01388	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35540	 35541	 0.008706	 0.03543	 0.00863	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35540	 35544	 0.015562	 0.04113	 0.00963	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35540	 35545	 0.014963	 0.048809	 0.01296	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35541	 35691	 0.008069	 0.032306	 0.00814	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87135	 35542	 0.014901	 0.036985	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35543	 35544	 0.007692	 0.030797	 0.00776	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35543	 35739	 0.008628	 0.034545	 0.0087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35546	 35547	 8e-05	 0.001001	 0.06858	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35546	 35553	 0.000126	 0.001499	 0.11247	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35546	 87301	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35546	 87301	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35547	 87302	 9.6e-05	 0.007684	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87301	 35548	 0.009836	 0.023704	 0.00669	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87303	 35549	 0.008267	 0.033099	 0.00834	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35549	 87624	 0.019898	 0.054179	 0.01194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35550	 35551	 0.001456	 0.009929	 0.01788	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87302	 35550	 0.001243	 0.008558	 0.01511	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35551	 36469	 0.001528	 0.010192	 0.01921	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87271	 35552	 0.14672	 0.24511	 0.00416	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35552	 87305	 0.06008	 0.14228	 0.0026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35553	 36563	 0.001168	 0.015125	 0.96874	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35553	 87305	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35553	 87305	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87301	 35554	 0.012299	 0.03302	 0.00748	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35555	 36486	 0.019262	 0.10205	 0.02588	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35555	 36488	 0.010085	 0.055596	 0.013	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35555	 38077	 0.01925	 0.073188	 0.02049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35555	 38078	 0.035651	 0.12917	 0.02774	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87123	 35555	 0.048371	 0.2224	 0.05715	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35556	 35557	 0.009142	 0.049141	 0.01209	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35556	 36148	 0.012109	 0.063084	 0.01655	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35557	 35558	 0.011165	 0.051227	 0.01312	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35557	 37770	 0.024927	 0.066934	 0.01517	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35557	 87306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35557	 87306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35558	 36588	 0.020283	 0.069593	 0.01668	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35558	 38356	 0.018577	 0.062603	 0.01556	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35559	 35561	 0.004147	 0.033317	 0.00937	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35559	 35563	 0.007182	 0.046265	 0.01213	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35559	 87308	 0.024233	 0.09706	 0.02447	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35560	 35562	 0.07036	 0.16336	 0.00243	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35560	 87307	 0.045364	 0.13918	 0.00377	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35560	 87495	 0.07987	 0.18269	 0.00446	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35561	 36147	 0.00637	 0.041032	 0.01076	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35561	 87307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35561	 87307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35562	 35564	 0.10851	 0.25197	 0.00375	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35563	 36296	 0.015717	 0.090333	 0.0256	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35563	 87308	 0.010815	 0.053335	 0.01442	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35564	 87654	 0.11489	 0.26678	 0.00397	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87119	 35565	 0.001829	 0.021387	 0.07488	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87280	 35565	 0.009343	 0.070193	 0.27289	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35565	 87308	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87309	 35565	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87309	 35566	 0.13188	 0.085385	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87120	 35567	 0.008804	 0.048854	 0.01485	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87123	 35567	 0.006907	 0.039268	 0.01137	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35568	 35569	 0.013851	 0.036609	 0.00857	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35568	 36490	 0.018263	 0.048271	 0.0113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35569	 35570	 0.016816	 0.046896	 0.00984	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35569	 87310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35569	 87310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87098	 35570	 0.024121	 0.058138	 0.01642	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35571	 36496	 0.023318	 0.060547	 0.0147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35571	 36513	 0.017964	 0.045161	 0.0117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35572	 35573	 0.18975	 0.15621	 0.00317	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87288	 35573	 0.078669	 0.20391	 0.00386	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35574	 36406	 0.017435	 0.046811	 0.01061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35575	 87592	 0.30154	 0.21805	 0.00331	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35576	 35631	 0.015813	 0.041056	 0.00997	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35576	 36404	 0.013705	 0.035581	 0.00864	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35577	 87322	 0.53553	 0.37977	 0.006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35577	 87328	 0.1779	 0.23386	 0.00321	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35578	 87312	 0.089737	 0.088156	 0.00149	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35579	 35580	 0.011037	 0.027746	 0.00719	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35579	 35587	 0.018624	 0.048356	 0.01174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35580	 35622	 0.020505	 0.054198	 0.01269	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35581	 87321	 0.11779	 0.09322	 0.00117	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35582	 35622	 0.019801	 0.055222	 0.01159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35582	 35762	 0.017372	 0.045916	 0.01075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35583	 35584	 0.005707	 0.014671	 0.00363	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35583	 35762	 0.00908	 0.025321	 0.00531	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35584	 35589	 0.005085	 0.014179	 0.00298	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35584	 87311	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35584	 87311	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87311	 35585	 0.044712	 0.045161	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35585	 87312	 0.038104	 0.060822	 0.0014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35586	 87312	 0.058885	 0.046601	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35587	 87312	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35587	 87312	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35587	 87327	 0.00545	 0.021419	 0.0056	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35588	 35659	 0.045697	 0.046156	 0.00061	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35588	 87313	 0.013057	 0.033206	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35589	 87313	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35589	 87313	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35589	 87327	 0.006919	 0.032272	 0.00799	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35590	 35592	 0.001707	 0.005568	 0.00148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35590	 35981	 0.002424	 0.009866	 0.0024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35590	 87314	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35590	 87314	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87314	 35591	 0.023797	 0.015406	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35592	 35593	 0.002058	 0.008239	 0.00208	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35592	 35595	 0.002543	 0.008723	 0.00209	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35592	 35981	 0.003794	 0.01491	 0.0039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35593	 35594	 0.001509	 0.00604	 0.00152	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35594	 35595	 0.002384	 0.009545	 0.0024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87105	 35594	 0.004821	 0.029159	 0.00744	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35595	 35598	 0.001406	 0.007474	 0.00173	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35596	 35597	 0.001609	 0.008522	 0.00216	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35596	 35752	 0.012067	 0.055363	 0.01419	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35596	 87315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35596	 87315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35596	 87359	 0.012948	 0.065903	 0.0239	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35597	 35598	 0.001248	 0.00609	 0.00168	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87132	 35599	 0.012114	 0.031143	 0.00771	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35600	 36005	 0.057641	 0.11796	 0.0029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87315	 35600	 0.049028	 0.10507	 0.00184	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35601	 35602	 0.003843	 0.030877	 0.00868	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35601	 35753	 0.002655	 0.021326	 0.00599	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87105	 35602	 0.003136	 0.02218	 0.00609	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35603	 38312	 0.001895	 0.022396	 0.04529	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87104	 35603	 0.001212	 0.014286	 0.02636	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35604	 35607	 0.009247	 0.037024	 0.00933	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87283	 35604	 0.012038	 0.048201	 0.01214	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35605	 35608	 0.000453	 0.006207	 0.46987	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35605	 35713	 0.000356	 0.004443	 0.30455	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35605	 87316	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35605	 87316	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35606	 35607	 0.0086	 0.03551	 0.0084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35606	 35709	 0.016445	 0.067911	 0.01607	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35608	 35613	 0.000218	 0.002721	 0.18646	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35608	 87317	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35608	 87317	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35609	 35611	 0.011835	 0.054302	 0.01391	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35609	 36507	 0.010839	 0.054836	 0.01527	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35609	 36514	 0.004061	 0.023082	 0.00668	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35610	 36506	 0.018364	 0.050003	 0.01102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35611	 35694	 0.014247	 0.035814	 0.00928	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35612	 35631	 0.020511	 0.054213	 0.01269	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87089	 35612	 0.008205	 0.02288	 0.0048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35612	 87318	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35612	 87318	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35614	 35615	 0.004504	 0.012262	 0.0027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35614	 35617	 0.006678	 0.018183	 0.00401	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35614	 87319	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35614	 87319	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35615	 35625	 0.023338	 0.072591	 0.01515	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87089	 35615	 0.01165	 0.039254	 0.00976	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35615	 87320	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35615	 87320	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35616	 35617	 0.004668	 0.012337	 0.00289	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87089	 35616	 0.004601	 0.015784	 0.00378	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87320	 35618	 0.10843	 0.08581	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35619	 87321	 0.074799	 0.11459	 0.00161	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35620	 35621	 0.046251	 0.035477	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35621	 87321	 0.0404	 0.041253	 0.00064	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87089	 35622	 0.017397	 0.06614	 0.01852	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35622	 87321	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35622	 87321	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87321	 35623	 0.14974	 0.11487	 0.00154	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87319	 35624	 0.25451	 0.20146	 0.00254	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35625	 35761	 0.025171	 0.063285	 0.0164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35626	 35627	 0.19314	 0.14212	 0.00208	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35626	 36358	 0.26376	 0.17081	 0.00325	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35626	 36400	 0.20354	 0.15423	 0.00212	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35626	 87322	 0.070961	 0.14523	 0.00357	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35628	 87322	 0.054004	 0.13883	 0.00215	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35629	 36404	 0.019236	 0.049945	 0.01212	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87089	 35629	 0.043235	 0.10425	 0.02945	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35629	 87322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35629	 87322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87318	 35630	 0.21072	 0.16679	 0.0021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35632	 87502	 0.072238	 0.079455	 0.00106	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35633	 35640	 0.005006	 0.025151	 0.00655	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35633	 36387	 0.007051	 0.031747	 0.00845	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35634	 87323	 0.045197	 0.072144	 0.00166	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35635	 35636	 0.0076	 0.032167	 0.00724	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35635	 35639	 0.011504	 0.03208	 0.00673	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35635	 36386	 0.007467	 0.029052	 0.00776	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35636	 36598	 0.007658	 0.038479	 0.01001	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35637	 35638	 0.10101	 0.079937	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35638	 87324	 0.013733	 0.053427	 0.00089	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35639	 35641	 0.004796	 0.012451	 0.00302	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35640	 35641	 0.001958	 0.014088	 0.00373	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35640	 87323	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35640	 87323	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35641	 35642	 0.003869	 0.014008	 0.00301	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35641	 87324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35641	 87324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35642	 35646	 0.005464	 0.029985	 0.00793	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35642	 87325	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35642	 87325	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87325	 35643	 0.094508	 0.066947	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87325	 35644	 0.22621	 0.16027	 0.00253	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35645	 87326	 0.091809	 0.072658	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35646	 35647	 0.005847	 0.028885	 0.00844	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87086	 35646	 0.010343	 0.11445	 0.03436	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35646	 87326	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35646	 87326	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35647	 35649	 0.005008	 0.023934	 0.00838	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35648	 35649	 0.012746	 0.03817	 0.0086	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35648	 36598	 0.010099	 0.025386	 0.00658	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35649	 36586	 0.003328	 0.025936	 0.00775	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35650	 35799	 0.000742	 0.0088	 0.67014	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35650	 87327	 0.000173	 0.013839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35651	 35654	 0.007504	 0.020431	 0.0045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87327	 35651	 0.019732	 0.053728	 0.01184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35651	 87329	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35651	 87329	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35652	 35653	 0.1656	 0.12982	 0.00167	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35653	 35655	 0.053684	 0.059046	 0.00079	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87327	 35654	 0.014336	 0.03849	 0.00872	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35654	 87330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35654	 87330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35654	 87367	 0.037968	 0.095485	 0.02475	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35655	 35656	 0.010027	 0.019852	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35656	 35658	 0.046629	 0.036901	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87330	 35656	 0.019334	 0.039565	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35657	 35658	 0.019703	 0.030182	 0.00042	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87328	 35657	 0.050096	 0.099189	 0.00146	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35660	 35662	 0.009325	 0.033766	 0.00724	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87327	 35660	 0.007661	 0.030674	 0.00773	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35660	 87331	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35660	 87331	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87331	 35661	 0.10538	 0.076183	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35662	 35663	 0.011426	 0.030198	 0.00707	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35662	 87332	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35662	 87332	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35663	 87374	 0.010824	 0.029059	 0.00659	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35664	 35668	 0.004659	 0.023569	 0.00656	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35664	 87333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35664	 87333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35665	 35671	 0.002521	 0.009807	 0.00262	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35665	 35674	 0.007776	 0.031132	 0.00784	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35666	 36390	 0.14187	 0.18649	 0.00256	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87333	 35666	 0.086105	 0.12001	 0.00205	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35667	 87335	 0.019143	 0.026117	 0.00047	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35668	 35669	 0.001703	 0.005843	 0.0014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35668	 35670	 0.001172	 0.004263	 0.00131	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35669	 35678	 0.010777	 0.036972	 0.00886	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35670	 35673	 0.001591	 0.006368	 0.00215	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35671	 35673	 0.001345	 0.006365	 0.00153	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35671	 87334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35671	 87334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35672	 35677	 0.007748	 0.039194	 0.00068	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87334	 35672	 0.003615	 0.016761	 0.00035	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35673	 87335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35673	 87335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35674	 36592	 0.018379	 0.0759	 0.01796	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35675	 35676	 0.006512	 0.033919	 0.0089	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35675	 36595	 0.013919	 0.063199	 0.02194	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35676	 35678	 0.006454	 0.030489	 0.00976	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35676	 87336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35676	 87336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87336	 35677	 0.019131	 0.10078	 0.00181	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35679	 35680	 0.01512	 0.039255	 0.00953	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35679	 35692	 0.016423	 0.044717	 0.00985	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35679	 35804	 0.009475	 0.039122	 0.00926	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35679	 87337	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35679	 87337	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35680	 35690	 0.011548	 0.032203	 0.00676	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35681	 87338	 0.062274	 0.081044	 0.00113	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35681	 87339	 0.08025	 0.1589	 0.00233	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35681	 87380	 0.18873	 0.2481	 0.0034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35682	 35687	 0.008971	 0.035919	 0.00905	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35682	 35689	 0.004197	 0.016804	 0.00423	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35682	 87338	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35682	 87338	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35683	 35684	 0.006245	 0.024546	 0.00642	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35683	 35814	 0.009369	 0.035613	 0.00997	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35683	 87339	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35683	 87339	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35684	 35685	 0.006882	 0.027051	 0.00708	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35684	 87340	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35684	 87340	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35685	 35742	 0.008093	 0.032402	 0.00816	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35686	 35687	 0.013353	 0.03937	 0.00916	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35686	 35742	 0.013607	 0.046682	 0.01118	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35687	 87341	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35687	 87341	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86375	 35688	 0.43177	 0.47533	 0.00635	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87341	 35688	 0.067897	 0.088363	 0.00124	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35689	 35690	 0.00465	 0.018618	 0.00469	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35690	 35691	 0.0051	 0.019384	 0.00543	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35690	 35692	 0.012832	 0.032987	 0.00817	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87113	 35690	 0.026544	 0.10965	 0.02596	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87137	 35693	 0.054935	 0.098742	 0.00177	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35695	 35697	 0.020105	 0.070395	 0.00195	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35695	 36516	 0.11024	 0.18573	 0.00265	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87125	 35695	 0.016468	 0.060889	 0.00113	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87125	 35695	 0.016468	 0.060889	 0.00113	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35696	 35700	 0.00689	 0.044381	 0.01163	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35697	 87342	 0.018747	 0.12869	 0.00235	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35698	 87342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35698	 87342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35699	 35700	 0.004004	 0.018029	 0.0048	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35699	 36340	 0.004604	 0.017909	 0.00478	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35700	 35701	 0.001947	 0.019681	 0.00579	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87121	 35701	 0.001078	 0.010532	 0.00296	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35702	 87343	 0.044333	 0.067914	 0.00095	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35703	 35705	 0.0034	 0.013612	 0.00343	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87121	 35703	 0.003469	 0.013888	 0.0035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35704	 35705	 0.003028	 0.00877	 0.00212	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87255	 35704	 0.004104	 0.013828	 0.00344	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35704	 87343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35704	 87343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35705	 87344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35705	 87344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87344	 35706	 0.023223	 0.045979	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35707	 36300	 0.001075	 0.010997	 0.00654	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87255	 35707	 0.000634	 0.007172	 0.00403	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87120	 35709	 0.034356	 0.19099	 0.05821	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35709	 87345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35709	 87345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87345	 35711	 0.020385	 0.071375	 0.00198	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35712	 35715	 0.14668	 0.14353	 0.00203	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35713	 87346	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87119	 35714	 0.005776	 0.049527	 0.09434	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87346	 35714	 0.001502	 0.012542	 0.02178	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35714	 87348	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35714	 87348	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35715	 35716	 0.022498	 0.055068	 0.00094	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87348	 35716	 0.02718	 0.083471	 0.00157	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35717	 87350	 0.042469	 0.031246	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35718	 35719	 0.042209	 0.029899	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35718	 35727	 0.017177	 0.033664	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35720	 35722	 0.015209	 0.01119	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35721	 87349	 0.034399	 0.024367	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35722	 35723	 0.02088	 0.015362	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35722	 35731	 0.074516	 0.058972	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35722	 87349	 0.010494	 0.023804	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35723	 35725	 0.017337	 0.013589	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35724	 87349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35724	 87349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35724	 87354	 0.005226	 0.02212	 0.00498	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35726	 87351	 0.033449	 0.033785	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87349	 35727	 0.012537	 0.029101	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35728	 35730	 0.003144	 0.010786	 0.00258	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35728	 35742	 0.00494	 0.037848	 0.01014	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35728	 35746	 0.001685	 0.004525	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35728	 87350	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35728	 87350	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35728	 87354	 0.007946	 0.030913	 0.00826	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35729	 35730	 0.001518	 0.006423	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35729	 87351	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35729	 87351	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35730	 35737	 0.005399	 0.015057	 0.00316	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35730	 87352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35730	 87352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35732	 35744	 0.005669	 0.032227	 0.00933	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35732	 87353	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35732	 87353	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35732	 87354	 0.00208	 0.018149	 0.00498	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35733	 35745	 0.11976	 0.12096	 0.0016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87353	 35733	 0.052329	 0.052342	 0.00071	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35734	 87355	 0.029516	 0.057846	 0.00087	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35735	 35756	 0.021278	 0.14755	 0.26297	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87293	 35735	 0.002827	 0.032031	 0.05763	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35735	 87354	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87355	 35735	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87354	 35736	 0.00555	 0.018513	 0.0047	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35738	 35740	 0.031703	 0.089965	 0.00141	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87352	 35738	 0.050909	 0.091859	 0.00133	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35740	 35741	 0.033675	 0.074533	 0.00122	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35741	 87356	 0.033368	 0.071508	 0.00125	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35742	 87356	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35742	 87356	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35743	 36175	 0.066167	 0.086965	 0.00119	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35743	 87357	 0.03347	 0.079257	 0.00145	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35744	 36174	 0.006051	 0.021172	 0.00702	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35744	 87357	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35744	 87357	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87275	 35745	 0.078637	 0.13248	 0.00189	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35747	 35748	 0.018694	 0.046997	 0.01218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35747	 35751	 0.018082	 0.048548	 0.011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35747	 36578	 0.014366	 0.03857	 0.00874	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35747	 36579	 0.019104	 0.050495	 0.01182	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35748	 35749	 0.016527	 0.042908	 0.01041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35749	 35750	 0.011632	 0.030743	 0.0072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35749	 36530	 0.057186	 0.1439	 0.03732	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35749	 87358	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35749	 87358	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35749	 87435	 0.01278	 0.050234	 0.01314	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35750	 35751	 0.01964	 0.050994	 0.01238	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35751	 36524	 0.017325	 0.068107	 0.01782	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35751	 36580	 0.020165	 0.057843	 0.01424	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35752	 87359	 0.005128	 0.024887	 0.00569	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35753	 35755	 0.003557	 0.015053	 0.00339	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35753	 87359	 0.006249	 0.032395	 0.00791	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35754	 35755	 0.005445	 0.023045	 0.00519	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35754	 35758	 0.011944	 0.04861	 0.01185	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35756	 35760	 0.000685	 0.009219	 0.01921	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35756	 36010	 0.004418	 0.030139	 0.05429	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35756	 38312	 0.007718	 0.051515	 0.09721	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35756	 87359	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35756	 87359	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35757	 35758	 0.00679	 0.021223	 0.00615	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35757	 88247	 0.012339	 0.042331	 0.01014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35758	 35759	 0.005074	 0.020306	 0.00686	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35759	 36152	 0.010324	 0.048867	 0.01175	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35760	 36150	 0.002277	 0.015969	 0.02719	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35760	 36151	 0.002648	 0.018245	 0.03221	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35760	 87360	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35760	 87360	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35761	 35763	 0.017221	 0.045517	 0.01065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35763	 35764	 0.016852	 0.03912	 0.01192	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35763	 87361	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35763	 87361	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35764	 35765	 0.012752	 0.032056	 0.00831	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35765	 35766	 0.008866	 0.022792	 0.00564	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35765	 87362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35765	 87362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35766	 35803	 0.009329	 0.024655	 0.00577	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35767	 87363	 0.090956	 0.1801	 0.00264	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35767	 87626	 0.25364	 0.27906	 0.00372	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87096	 35768	 0.025944	 0.084648	 0.02248	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35768	 87363	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35768	 87363	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35768	 87632	 0.018957	 0.065042	 0.01558	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35769	 36486	 0.009961	 0.051893	 0.01361	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87096	 35769	 0.008445	 0.04317	 0.01177	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35770	 35774	 0.004761	 0.033391	 0.05687	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35770	 36540	 0.00167	 0.011388	 0.0205	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35770	 87364	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35770	 87364	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35771	 35773	 0.013411	 0.035445	 0.0083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87364	 35771	 0.016294	 0.042305	 0.01027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87364	 35772	 0.018172	 0.048029	 0.01124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35772	 87365	 0.018666	 0.049335	 0.01155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35773	 87365	 0.013403	 0.037378	 0.00785	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87095	 35774	 0.000896	 0.012192	 0.02481	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35774	 87365	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87366	 35774	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87366	 35775	 0.070533	 0.10278	 0.00232	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35776	 35777	 0.001165	 0.007768	 0.01464	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87088	 35776	 0.015418	 0.10438	 0.19315	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35777	 35781	 0.002802	 0.018688	 0.03523	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35777	 87367	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87368	 35777	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87368	 35778	 0.16158	 0.12788	 0.00161	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35779	 35780	 0.14381	 0.11382	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87368	 35780	 0.096718	 0.24867	 0.00385	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35780	 87369	 0.21014	 0.13607	 0.00259	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35780	 87375	 0.12169	 0.12173	 0.00164	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35781	 87376	 0.002521	 0.016368	 0.0326	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87332	 35782	 0.044608	 0.088323	 0.0013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87362	 35782	 0.17851	 0.13135	 0.00192	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35783	 35784	 0.014803	 0.030294	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35784	 87369	 0.005645	 0.032088	 0.00058	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35784	 87375	 0.03089	 0.076671	 0.00127	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35785	 35787	 0.002021	 0.00508	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35785	 87374	 0.00294	 0.010084	 0.00242	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35786	 87369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35786	 87369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35786	 87374	 0.003679	 0.011501	 0.00333	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35787	 87370	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35787	 87370	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35788	 35790	 0.021918	 0.016126	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87370	 35788	 0.010534	 0.019008	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35789	 35795	 0.003912	 0.013689	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87370	 35789	 0.006544	 0.021831	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35791	 35794	 0.003138	 0.010573	 0.00263	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35791	 35803	 0.010235	 0.027051	 0.00633	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35792	 35793	 0.000884	 0.006394	 0.00344	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35792	 35794	 0.002838	 0.010031	 0.00226	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35792	 35801	 0.001749	 0.018847	 0.01007	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35793	 35796	 0.000674	 0.007914	 0.0021	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35793	 87371	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35793	 87371	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35794	 87372	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35794	 87372	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87371	 35795	 0.004002	 0.017834	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35796	 87373	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35796	 87373	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35796	 87374	 0.001279	 0.013559	 0.00402	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35797	 35798	 0.000889	 0.006655	 0.02575	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85622	 35797	 0.016137	 0.10929	 0.20233	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35797	 87374	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87375	 35797	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35798	 87376	 0.00087	 0.007972	 0.03147	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35799	 87376	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35799	 87376	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87084	 35800	 0.23598	 0.17063	 0.00259	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87083	 35801	 0.002143	 0.024253	 0.01362	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35801	 87377	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35801	 87377	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87377	 35802	 0.12131	 0.13214	 0.0018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87113	 35804	 0.003902	 0.01562	 0.00394	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35805	 39201	 0.000123	 0.001588	 0.10134	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35805	 87378	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35805	 87378	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35806	 35809	 0.016267	 0.047121	 0.01137	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87113	 35806	 0.01217	 0.04302	 0.00969	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35807	 87379	 0.20032	 0.2108	 0.00309	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35807	 87483	 0.19047	 0.15681	 0.00318	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35808	 36133	 0.091434	 0.14008	 0.00197	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35808	 87501	 0.090028	 0.15834	 0.00298	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35809	 35811	 0.006805	 0.027246	 0.00686	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35809	 87379	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35809	 87379	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35810	 35811	 0.003405	 0.014176	 0.00442	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35810	 35814	 0.007932	 0.033572	 0.00755	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35810	 36159	 0.005476	 0.039397	 0.01044	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87113	 35810	 0.026438	 0.10396	 0.02721	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35810	 87380	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35810	 87380	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35811	 87381	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35811	 87381	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87381	 35812	 0.020479	 0.041908	 0.00103	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87337	 35813	 0.22733	 0.16106	 0.00255	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35815	 35828	 0.001988	 0.004996	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35815	 35861	 0.002213	 0.006524	 0.00152	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35815	 35923	 0.001782	 0.00621	 0.00144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35815	 87382	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35815	 87382	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35816	 87386	 0.016463	 0.011901	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35817	 35818	 0.001489	 0.00596	 0.0015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35817	 35895	 0.001912	 0.005052	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35817	 87419	 0.007116	 0.018806	 0.0044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35818	 35833	 0.000745	 0.004993	 0.00153	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35819	 35820	 0.002223	 0.00749	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35820	 35822	 0.001693	 0.008819	 0.00231	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35821	 35822	 0.001038	 0.00579	 0.00148	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35821	 35932	 0.000818	 0.006159	 0.00171	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35822	 35836	 0.001723	 0.004429	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35822	 87383	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35822	 87383	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35822	 87429	 0.002596	 0.022263	 0.00634	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35823	 35824	 0.008118	 0.016074	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87383	 35823	 0.009382	 0.021282	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35823	 87389	 0.009573	 0.018954	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35823	 87407	 0.033689	 0.086603	 0.00134	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35824	 35825	 0.02474	 0.019579	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35826	 35831	 0.002252	 0.006131	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35826	 87384	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35826	 87384	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35827	 35828	 0.001114	 0.004033	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35827	 35830	 0.00209	 0.006161	 0.00143	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35827	 87385	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35827	 87385	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35828	 35861	 0.00138	 0.004734	 0.00113	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87384	 35829	 0.007761	 0.014668	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87385	 35829	 0.01093	 0.019722	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35830	 35831	 0.001538	 0.005277	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35830	 35863	 0.001959	 0.005086	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35831	 35833	 0.001606	 0.008506	 0.00216	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35831	 87386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35831	 87386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87386	 35832	 0.015024	 0.014516	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35833	 35834	 0.001497	 0.006866	 0.00176	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35833	 35850	 0.00235	 0.00851	 0.00183	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35833	 35851	 0.002059	 0.005743	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35833	 35862	 0.005254	 0.013887	 0.00325	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35833	 35890	 0.003493	 0.009232	 0.00216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35833	 87387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35833	 87387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35833	 87429	 0.003146	 0.024667	 0.01127	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35834	 35835	 0.000891	 0.004555	 0.00124	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35835	 35837	 0.000629	 0.002854	 0.00099	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35835	 87388	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35835	 87388	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35836	 35837	 0.000603	 0.002981	 0.00087	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35836	 35838	 0.000556	 0.004261	 0.00114	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35837	 87389	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35837	 87389	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35838	 35844	 0.000868	 0.004785	 0.00112	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35838	 35847	 0.001075	 0.003168	 0.00074	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35839	 35840	 0.014499	 0.010481	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35839	 87390	 0.021237	 0.015043	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35841	 35842	 0.001913	 0.005949	 0.00124	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35841	 35843	 0.002291	 0.00589	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35842	 35935	 0.002377	 0.011085	 0.00275	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35843	 35845	 0.00102	 0.002695	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35844	 35882	 0.001325	 0.007305	 0.00171	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35844	 87390	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35844	 87390	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35845	 35865	 0.001746	 0.004052	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35846	 35847	 0.000729	 0.003863	 0.00098	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35846	 35865	 0.000881	 0.004736	 0.00117	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35847	 87391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35847	 87391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35848	 35952	 0.013135	 0.033765	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87389	 35848	 0.00801	 0.018968	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35848	 87396	 0.018256	 0.017119	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35849	 35850	 0.001069	 0.005893	 0.00138	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35849	 35857	 0.000474	 0.002468	 0.00065	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35849	 87392	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35849	 87392	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35850	 35855	 0.001198	 0.003167	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35851	 35854	 0.001049	 0.003798	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35851	 87393	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35851	 87393	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87393	 35852	 0.020465	 0.016196	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87393	 35853	 0.013988	 0.011069	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35854	 35885	 0.002285	 0.006039	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35854	 87394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35854	 87394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35855	 35856	 0.0013	 0.004461	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35855	 87395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35855	 87395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35856	 35866	 0.000795	 0.00277	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35857	 35858	 0.000481	 0.002549	 0.00065	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35858	 35860	 0.000848	 0.004417	 0.00116	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35859	 35860	 0.000841	 0.004452	 0.00113	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35859	 35866	 0.000919	 0.005063	 0.00118	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35860	 87396	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35860	 87396	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35860	 87429	 0.001258	 0.012073	 0.00351	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35861	 35936	 0.001388	 0.00604	 0.00172	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35862	 35925	 0.001406	 0.009058	 0.00237	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35863	 35894	 0.003345	 0.009327	 0.00196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35863	 87397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35863	 87397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35864	 87430	 0.018333	 0.018516	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35865	 87398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35865	 87398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35865	 87429	 0.000839	 0.006542	 0.00196	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35866	 35888	 0.00102	 0.003327	 0.00088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35866	 87399	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35866	 87399	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35867	 35868	 0.035042	 0.022686	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87382	 35867	 0.031118	 0.051897	 0.00075	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35868	 87418	 0.015155	 0.030005	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35869	 35870	 0.001128	 0.003267	 0.00079	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35869	 35898	 0.002696	 0.007126	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35870	 35920	 0.001277	 0.004626	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35871	 35872	 0.028613	 0.018524	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35872	 87418	 0.011589	 0.022945	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35873	 35931	 0.00279	 0.0094	 0.00234	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35873	 35960	 0.002314	 0.006823	 0.00159	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35874	 35960	 0.00262	 0.00608	 0.00185	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35874	 35962	 0.002244	 0.012064	 0.00297	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35874	 87400	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35874	 87400	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35875	 35958	 0.002755	 0.015663	 0.00028	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35875	 87401	 0.011233	 0.02019	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35875	 87402	 0.009851	 0.013963	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35876	 35877	 0.001306	 0.004479	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35876	 35878	 0.00254	 0.005897	 0.0018	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35876	 87401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35876	 87401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35877	 35879	 0.001179	 0.003846	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35878	 35879	 0.002871	 0.009847	 0.00236	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35878	 87402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35878	 87402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35878	 87429	 0.002982	 0.01524	 0.00415	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35879	 35968	 0.001017	 0.00632	 0.00178	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35879	 87403	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35879	 87403	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87403	 35880	 0.02491	 0.019713	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35881	 35955	 0.018929	 0.01452	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35882	 35883	 0.00143	 0.004817	 0.0012	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35882	 87429	 0.003359	 0.010955	 0.00291	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35883	 35954	 0.001435	 0.004158	 0.001	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35883	 35956	 0.001551	 0.0036	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87395	 35884	 0.01028	 0.017075	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87399	 35884	 0.002895	 0.005383	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35885	 35887	 0.001582	 0.004665	 0.00109	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35885	 87404	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35885	 87404	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87404	 35886	 0.022789	 0.014753	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35887	 35888	 0.001281	 0.00322	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35887	 35889	 0.001638	 0.00903	 0.00211	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35887	 35942	 0.001918	 0.006946	 0.00149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35887	 87405	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35887	 87405	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35889	 35951	 0.001746	 0.00883	 0.00246	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35889	 87406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35889	 87406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35889	 87429	 0.001037	 0.011487	 0.00374	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35890	 35891	 0.001373	 0.00363	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35891	 35893	 0.002255	 0.005669	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87397	 35892	 0.008405	 0.014018	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35893	 35940	 0.001908	 0.005044	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35894	 35938	 0.003595	 0.009501	 0.00222	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35895	 87407	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35895	 87407	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35896	 35897	 0.002954	 0.008236	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35896	 36484	 0.008216	 0.023048	 0.00593	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35896	 87408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35896	 87408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35896	 87410	 0.008489	 0.023674	 0.00497	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35897	 87409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35897	 87409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35898	 35900	 0.002241	 0.0061	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35898	 35919	 0.002549	 0.006737	 0.00158	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35899	 35922	 0.001755	 0.01446	 0.02981	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35899	 36363	 0.015975	 0.10693	 0.20262	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87092	 35899	 0.003621	 0.027127	 0.10504	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35899	 87410	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87411	 35899	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87410	 35900	 0.003135	 0.011351	 0.00244	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35900	 87419	 0.009277	 0.031258	 0.00777	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87410	 35901	 0.003718	 0.012404	 0.00315	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35901	 87412	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35901	 87412	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35902	 35903	 0.022237	 0.047654	 0.00083	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35902	 35905	 0.02605	 0.05475	 0.001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87412	 35903	 0.021743	 0.043049	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35904	 87413	 0.041282	 0.03267	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35905	 35910	 0.097025	 0.071386	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35905	 87414	 0.052654	 0.092601	 0.00174	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35906	 35909	 0.002906	 0.007543	 0.00183	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35906	 35919	 0.002457	 0.006596	 0.00149	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35906	 87413	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35906	 87413	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87413	 35907	 0.03206	 0.025372	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35908	 35921	 0.006303	 0.012479	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87413	 35908	 0.03828	 0.030294	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35908	 87414	 0.022924	 0.016866	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35909	 87414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35909	 87414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35909	 87419	 0.002635	 0.016689	 0.00453	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35910	 35911	 0.024287	 0.049702	 0.00122	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35911	 87417	 0.018775	 0.082723	 0.00144	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35912	 35916	 0.004085	 0.021635	 0.00548	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35913	 87415	 0.12741	 0.097737	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35913	 87652	 0.045541	 0.097594	 0.00171	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35914	 35916	 0.003107	 0.019677	 0.00534	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35914	 35927	 0.003029	 0.022697	 0.00554	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35914	 87415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35914	 87415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35915	 35916	 0.009079	 0.023994	 0.00562	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35915	 35924	 0.006735	 0.017484	 0.00424	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35915	 87416	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35915	 87416	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35916	 87417	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35916	 87417	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87416	 35917	 0.007544	 0.04638	 0.00084	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87417	 35917	 0.067016	 0.081699	 0.00131	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35917	 87420	 0.010871	 0.061083	 0.00113	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87414	 35918	 0.077997	 0.061727	 0.00078	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35920	 87418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35920	 87418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35920	 87419	 0.002628	 0.013673	 0.00403	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87418	 35921	 0.006513	 0.017218	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87085	 35922	 0.001953	 0.019462	 0.06496	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35922	 87419	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87420	 35922	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87419	 35923	 0.002222	 0.009673	 0.00276	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35923	 87421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35923	 87421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35924	 35925	 0.001978	 0.012528	 0.0034	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35924	 35926	 0.00226	 0.016505	 0.00424	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35924	 35933	 0.00524	 0.013848	 0.00324	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35926	 35927	 0.001695	 0.014433	 0.0036	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35926	 35934	 0.005335	 0.014099	 0.0033	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87086	 35927	 0.001137	 0.012734	 0.00405	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35928	 35963	 0.001211	 0.015875	 0.03488	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87085	 35928	 0.000698	 0.006756	 0.02389	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87114	 35928	 0.00127	 0.008906	 0.01516	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35929	 35931	 0.003748	 0.020637	 0.00745	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35929	 35961	 0.005169	 0.020695	 0.00521	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87086	 35929	 0.001437	 0.016875	 0.01013	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35930	 87422	 0.049624	 0.039272	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35931	 35959	 0.001979	 0.009078	 0.00233	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35931	 87422	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35931	 87422	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35932	 35933	 0.00085	 0.006277	 0.00181	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35933	 35934	 0.001418	 0.013616	 0.00396	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35934	 35935	 0.002156	 0.012028	 0.00307	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87086	 35934	 0.002381	 0.02359	 0.00722	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35936	 35937	 0.003539	 0.009501	 0.00215	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35936	 87423	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35936	 87423	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35937	 35939	 0.005063	 0.013382	 0.00313	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35938	 36446	 0.005427	 0.015135	 0.00318	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35939	 36446	 0.005069	 0.017389	 0.00417	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35939	 87424	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35939	 87424	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35940	 35941	 0.0018	 0.004832	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35940	 87425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35940	 87425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35941	 36447	 0.005328	 0.013696	 0.00339	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35942	 35947	 0.00255	 0.00662	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35942	 87426	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35942	 87426	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35943	 35951	 0.002096	 0.005844	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35943	 87427	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35943	 87427	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35944	 36448	 0.027247	 0.021563	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87427	 35944	 0.014574	 0.028854	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35945	 35948	 0.001502	 0.00397	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35945	 35951	 0.004085	 0.011121	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35945	 87428	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35945	 87428	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35946	 35947	 0.002432	 0.006782	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35946	 36447	 0.00228	 0.006122	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35948	 35949	 0.001262	 0.003388	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35949	 36451	 0.001809	 0.004697	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87405	 35950	 0.011814	 0.00854	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87396	 35952	 0.006176	 0.014123	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87398	 35952	 0.006721	 0.016683	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35952	 87430	 0.014443	 0.036732	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35953	 87429	 0.00018	 0.014416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35953	 87429	 0.00018	 0.014416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87429	 35954	 0.001632	 0.005598	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35955	 35957	 0.019502	 0.014348	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87430	 35955	 0.015583	 0.03963	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35956	 35959	 0.002095	 0.005438	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35957	 87431	 0.023464	 0.035944	 0.0005	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87400	 35958	 0.009182	 0.021743	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87430	 35958	 0.041499	 0.07459	 0.00134	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35958	 87431	 0.004553	 0.024259	 0.00043	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87429	 35959	 0.006235	 0.016479	 0.00386	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35960	 87431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35960	 87431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35961	 35962	 0.004735	 0.016243	 0.00389	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35962	 87432	 0.012327	 0.030988	 0.00803	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35963	 36477	 0.005106	 0.033399	 0.06557	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35963	 36538	 0.002423	 0.016443	 0.02994	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35963	 87432	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35963	 87432	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35964	 35965	 0.003526	 0.009318	 0.00218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35964	 35966	 0.006923	 0.017974	 0.00436	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35964	 87635	 0.021058	 0.072252	 0.01731	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35965	 35968	 0.003512	 0.010171	 0.00245	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35966	 36461	 0.005829	 0.014652	 0.0038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35967	 35968	 0.003289	 0.01108	 0.00275	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35967	 87610	 0.009466	 0.025018	 0.00586	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35969	 35977	 0.001658	 0.011119	 0.00268	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87429	 35969	 0.001554	 0.012092	 0.00314	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35970	 35971	 0.019738	 0.013981	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35970	 35972	 0.024175	 0.037034	 0.00052	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87406	 35970	 0.004145	 0.020962	 0.00041	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	35972	 35974	 0.004623	 0.016515	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35972	 35976	 0.004756	 0.016246	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35973	 35974	 0.013577	 0.026881	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87428	 35974	 0.018377	 0.016927	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35975	 35977	 0.002782	 0.00928	 0.00235	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35975	 36459	 0.003689	 0.009576	 0.00232	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35975	 87433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35975	 87433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35976	 87434	 0.003862	 0.021953	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	35977	 87434	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35977	 87434	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35978	 87436	 0.2062	 0.22684	 0.00303	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35979	 36156	 0.000381	 0.004927	 0.31454	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35979	 36563	 0.000966	 0.012503	 0.79986	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35979	 87435	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87197	 35980	 0.033501	 0.16349	 0.00282	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87358	 35980	 0.047108	 0.18854	 0.00398	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35981	 87437	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35981	 87437	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35982	 35983	 0.019215	 0.014558	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87437	 35982	 0.026437	 0.017115	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	35984	 35989	 0.001605	 0.005407	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35984	 35992	 0.007878	 0.026543	 0.0066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87437	 35985	 0.018547	 0.014678	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87138	 35986	 0.014089	 0.026982	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87138	 35987	 0.015454	 0.026033	 0.00037	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	35988	 35989	 0.002238	 0.00791	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35988	 35990	 0.004894	 0.01772	 0.0038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35990	 35992	 0.010213	 0.026515	 0.00644	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35990	 87438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	35990	 87438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87438	 35991	 0.025952	 0.028544	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35992	 35993	 0.014319	 0.060612	 0.01364	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35992	 35994	 0.010739	 0.038888	 0.00834	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87105	 35992	 0.003674	 0.022586	 0.00651	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35993	 38310	 0.01389	 0.058796	 0.01323	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35994	 39799	 0.013271	 0.04691	 0.01057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35995	 35996	 0.005057	 0.024541	 0.00561	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	35996	 35997	 0.007565	 0.030287	 0.00763	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35997	 35998	 0.005371	 0.017517	 0.00465	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	35997	 39124	 0.005281	 0.039782	 0.01104	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	35998	 35999	 0.004878	 0.018543	 0.00519	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	35999	 36000	 0.003127	 0.024635	 0.00721	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87132	 35999	 0.004229	 0.023203	 0.00613	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36000	 36001	 0.007604	 0.026085	 0.00625	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36000	 39127	 0.006361	 0.03818	 0.01156	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36001	 36043	 0.010325	 0.035421	 0.00849	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36001	 87456	 0.014784	 0.05072	 0.01215	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36002	 87455	 0.002058	 0.014178	 0.02503	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36003	 36007	 0.009419	 0.027282	 0.00658	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87082	 36003	 0.007184	 0.020808	 0.00502	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87133	 36004	 0.020786	 0.12633	 0.00233	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36005	 87442	 0.067897	 0.19476	 0.003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36006	 36010	 0.001251	 0.008234	 0.01593	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36006	 87439	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36006	 87439	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87439	 36007	 0.006777	 0.026637	 0.00697	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36007	 87440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36007	 87440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87440	 36008	 0.087353	 0.088231	 0.00117	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36009	 36379	 0.010901	 0.029265	 0.00663	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36009	 36596	 0.017045	 0.047535	 0.00998	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36010	 87441	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36010	 87441	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87360	 36011	 0.015317	 0.064835	 0.01459	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87441	 36011	 0.009351	 0.031505	 0.00783	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36011	 87442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36011	 87442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36012	 36022	 0.001307	 0.004485	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36012	 36024	 0.005245	 0.014626	 0.00307	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36012	 87443	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36012	 87443	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87443	 36013	 0.020237	 0.016015	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36013	 87447	 0.030249	 0.023711	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87443	 36014	 0.052269	 0.041365	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36014	 87444	 0.023653	 0.036907	 0.00062	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36014	 87446	 0.004018	 0.015396	 0.00044	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36015	 36018	 0.001993	 0.010187	 0.00278	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36015	 36024	 0.012337	 0.029731	 0.00839	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36015	 36037	 0.007068	 0.028298	 0.00713	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36015	 87444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36015	 87444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36016	 87445	 0.039402	 0.031182	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36017	 36018	 0.003282	 0.008436	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36017	 36019	 0.00091	 0.004738	 0.00124	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36017	 36521	 0.013051	 0.071953	 0.01682	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36017	 87445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36017	 87445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36018	 36060	 0.005466	 0.033588	 0.01228	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36019	 36020	 0.00109	 0.003739	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36019	 87446	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36019	 87446	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36020	 36022	 0.002058	 0.006865	 0.00174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87296	 36021	 0.099645	 0.23135	 0.00441	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36021	 87447	 0.009591	 0.022268	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36022	 87447	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36022	 87447	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87445	 36023	 0.047534	 0.094114	 0.00138	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36024	 36025	 0.004951	 0.016983	 0.00407	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36024	 36026	 0.001528	 0.007549	 0.0022	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36026	 36028	 0.001677	 0.007694	 0.00197	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36026	 87448	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36026	 87448	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87448	 36027	 0.00839	 0.019275	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36027	 87449	 0.014905	 0.028878	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36028	 36029	 0.001937	 0.006646	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36028	 87449	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36028	 87449	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36029	 87450	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36029	 87450	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87111	 36030	 0.054747	 0.14074	 0.00218	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87097	 36031	 0.005419	 0.073059	 0.15266	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87102	 36031	 0.000477	 0.005398	 0.01081	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36031	 87451	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36031	 87451	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36031	 87452	 0.000851	 0.01099	 0.0249	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36032	 36418	 7.7e-05	 0.001239	 0.08697	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36032	 87452	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36032	 87452	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36033	 87453	 0.050682	 0.035901	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36034	 36035	 0.001897	 0.008962	 0.00287	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87124	 36034	 0.007204	 0.018702	 0.00454	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36034	 87601	 0.002867	 0.015802	 0.00369	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36035	 36036	 0.00101	 0.006211	 0.00179	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36035	 87453	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36035	 87453	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87451	 36036	 0.003742	 0.023009	 0.00664	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36037	 36038	 0.010087	 0.029739	 0.00692	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36037	 36059	 0.011354	 0.034001	 0.00766	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87451	 36038	 0.015125	 0.039976	 0.00936	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36039	 87454	 0.018877	 0.084116	 0.00143	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36039	 87462	 0.016141	 0.053265	 0.00086	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36039	 87581	 0.11474	 0.30342	 0.00551	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36040	 36049	 0.003315	 0.030865	 0.00956	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36040	 39138	 0.004506	 0.036826	 0.00999	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36040	 87454	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36040	 87454	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36041	 87460	 0.040576	 0.036359	 0.00074	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36042	 38794	 0.005247	 0.033231	 0.00902	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36042	 87461	 0.004454	 0.032041	 0.00849	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36043	 38793	 0.0037	 0.036261	 0.01136	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36043	 87456	 0.004016	 0.033775	 0.01001	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36044	 38975	 0.001859	 0.023338	 1.6141	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36044	 87455	 0.000104	 0.008342	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87456	 36044	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36045	 36046	 0.000653	 0.005297	 0.00973	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36045	 87457	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36045	 87457	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36046	 36048	 0.000619	 0.004015	 0.008	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36046	 87458	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36046	 87458	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36047	 36048	 0.000424	 0.002894	 0.00521	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36047	 36051	 0.000696	 0.004407	 0.00923	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36047	 87459	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87460	 36047	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36048	 87461	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36048	 87461	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36049	 36050	 0.001236	 0.011224	 0.00366	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36049	 87462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36049	 87462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36049	 87463	 0.001529	 0.016566	 0.01016	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36050	 36128	 0.001769	 0.016988	 0.00494	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87455	 36051	 0.001402	 0.014175	 0.03216	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36051	 87463	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87464	 36051	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36051	 87465	 0.000529	 0.006274	 0.02136	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87464	 36052	 0.045961	 0.036373	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36053	 36372	 0.000165	 0.002134	 0.13617	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36053	 87465	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36053	 87465	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36054	 36138	 0.00158	 0.018058	 0.00551	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36054	 36366	 0.002533	 0.032963	 0.00953	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36055	 36058	 0.006605	 0.047517	 0.01259	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36055	 87466	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36055	 87466	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36055	 87575	 0.009328	 0.037349	 0.00941	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87139	 36056	 0.12475	 0.098729	 0.00124	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36057	 36058	 0.005286	 0.044454	 0.01317	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36059	 36070	 0.015298	 0.046458	 0.01017	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36060	 36064	 0.004867	 0.024	 0.00649	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36061	 36068	 0.004564	 0.024534	 0.00604	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36061	 36069	 0.00542	 0.027707	 0.00755	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36061	 87467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36061	 87467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36062	 36068	 0.001911	 0.010119	 0.00256	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36062	 36070	 0.005736	 0.031621	 0.00739	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87467	 36063	 0.086857	 0.068739	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36064	 36066	 0.00195	 0.006504	 0.00165	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36064	 87468	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36064	 87468	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36065	 36067	 0.031603	 0.02046	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36066	 36068	 0.000754	 0.003017	 0.00076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36066	 87469	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36066	 87469	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87468	 36067	 0.011552	 0.021158	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87469	 36067	 0.020293	 0.026409	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36069	 36343	 0.007912	 0.041214	 0.01081	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36070	 36423	 0.012601	 0.069471	 0.01624	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36071	 36072	 0.001959	 0.005674	 0.00137	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36071	 36083	 0.000498	 0.003997	 0.00112	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36071	 36129	 0.002986	 0.026057	 0.00716	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36071	 36130	 0.001656	 0.012593	 0.00396	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36071	 39133	 0.019527	 0.10176	 0.02671	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36071	 87470	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36071	 87470	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36071	 87492	 0.003712	 0.036539	 0.0151	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36072	 36073	 0.0012	 0.00418	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36073	 36074	 0.001249	 0.004284	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36074	 36081	 0.001338	 0.004845	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36075	 87487	 0.03831	 0.075081	 0.00113	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36076	 36077	 0.011819	 0.009354	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36076	 87472	 0.020426	 0.036713	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36078	 36079	 0.016611	 0.012008	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36079	 87472	 0.015614	 0.01577	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36080	 36082	 0.000726	 0.003709	 0.00101	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36080	 36088	 0.000598	 0.003058	 0.00083	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36081	 36082	 0.000904	 0.003618	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36082	 87471	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36082	 87471	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36083	 36084	 0.000426	 0.004073	 0.00134	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36084	 36085	 0.001371	 0.004778	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36084	 36092	 0.000805	 0.00603	 0.00147	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36085	 36115	 0.001148	 0.004857	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36086	 87475	 0.025918	 0.020316	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36087	 36088	 0.000736	 0.003831	 0.001	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36087	 36090	 0.001932	 0.010603	 0.0028	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36087	 87472	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36087	 87472	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36089	 36135	 0.003261	 0.019818	 0.00037	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36089	 87473	 0.004886	 0.026238	 0.00062	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36090	 36126	 0.002336	 0.011336	 0.00259	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36090	 87473	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36090	 87473	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36090	 87492	 0.002048	 0.022941	 0.00729	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36091	 36099	 0.00492	 0.011161	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87472	 36091	 0.009616	 0.019038	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36092	 36094	 0.000956	 0.005484	 0.00182	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36092	 87474	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36092	 87474	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36093	 36097	 0.017588	 0.044728	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87470	 36093	 0.019224	 0.044624	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36094	 36104	 0.001032	 0.007298	 0.002	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36095	 36096	 0.037722	 0.029568	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36096	 87478	 0.019031	 0.014918	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36097	 87476	 0.007604	 0.018614	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36098	 36102	 0.001683	 0.006093	 0.00131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36098	 87475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36098	 87475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36099	 36100	 0.00356	 0.015684	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87473	 36099	 0.005369	 0.037405	 0.00088	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36100	 87476	 0.005236	 0.020368	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36101	 87477	 0.035523	 0.026135	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36102	 36103	 0.000457	 0.00495	 0.00155	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36102	 36115	 0.001371	 0.009199	 0.00222	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36102	 87476	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36102	 87476	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36103	 36104	 0.000776	 0.005811	 0.00142	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36103	 36108	 0.001756	 0.007031	 0.00177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36103	 87477	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36103	 87477	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36103	 87492	 0.00121	 0.012189	 0.00748	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36104	 87478	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36104	 87478	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36105	 36106	 0.000912	 0.00365	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36105	 36108	 0.001151	 0.004752	 0.00112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36106	 36110	 0.001613	 0.006132	 0.00172	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36106	 87479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36106	 87479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36107	 36111	 0.024804	 0.02481	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87479	 36107	 0.027432	 0.01983	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36107	 87480	 0.07285	 0.055881	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36108	 87480	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36108	 87480	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36109	 87481	 0.007395	 0.019009	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36110	 36112	 0.002063	 0.008108	 0.00212	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36111	 36113	 0.018273	 0.027992	 0.00039	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36112	 36142	 0.005418	 0.021295	 0.00557	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36112	 87481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36112	 87481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36112	 87492	 0.003694	 0.024782	 0.00598	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87481	 36113	 0.008565	 0.021781	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87470	 36114	 0.017371	 0.035549	 0.00087	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87471	 36114	 0.007788	 0.01542	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87475	 36114	 0.008813	 0.038831	 0.00067	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36115	 87482	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36115	 87482	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36116	 36130	 0.005046	 0.037279	 0.01076	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36116	 38773	 0.007822	 0.055329	 0.01519	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36116	 87483	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36116	 87483	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36117	 36131	 0.035682	 0.090746	 0.00143	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36118	 36129	 0.003652	 0.020984	 0.00594	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36118	 39136	 0.007242	 0.028994	 0.0073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36118	 87484	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36118	 87484	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87484	 36119	 0.11376	 0.083699	 0.00122	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36120	 36121	 0.001427	 0.014535	 0.00375	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36120	 39137	 0.005239	 0.02888	 0.00675	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36120	 39138	 0.007181	 0.028752	 0.00724	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36121	 36122	 0.003225	 0.020426	 0.00554	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36121	 36123	 0.005737	 0.019329	 0.0048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36122	 36128	 0.00206	 0.01414	 0.00412	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36122	 87485	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36122	 87485	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36123	 36125	 0.00474	 0.016258	 0.0039	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36124	 87489	 0.029879	 0.032863	 0.00044	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36125	 36126	 0.002672	 0.010873	 0.00265	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36125	 87486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36125	 87486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36126	 87487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36126	 87487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87486	 36127	 0.007763	 0.034738	 0.00072	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36127	 87488	 0.00542	 0.024019	 0.00072	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36128	 36134	 0.003756	 0.015509	 0.00367	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36128	 87488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36128	 87488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87470	 36131	 0.009495	 0.043102	 0.00093	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36132	 36133	 0.039702	 0.063373	 0.00146	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87477	 36132	 0.028573	 0.11116	 0.00186	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36134	 36137	 0.001644	 0.006583	 0.00166	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36134	 87489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36134	 87489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36135	 87490	 0.005574	 0.040268	 0.00076	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36136	 87491	 0.021712	 0.02217	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36137	 36138	 0.001121	 0.00793	 0.00218	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36137	 87490	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36137	 87490	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36138	 36139	 0.001773	 0.009061	 0.00247	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36139	 87491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36139	 87491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36140	 36372	 0.000436	 0.005594	 0.41974	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36140	 87492	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36140	 87492	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87492	 36141	 0.005075	 0.024628	 0.00563	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36142	 36143	 0.005927	 0.02412	 0.00588	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36142	 87493	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36142	 87493	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36143	 36160	 0.005733	 0.022305	 0.00596	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36144	 36145	 0.008018	 0.049271	 0.01802	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87096	 36144	 0.005075	 0.034045	 0.00822	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36145	 36147	 0.009858	 0.062448	 0.01695	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36145	 87494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36145	 87494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87494	 36146	 0.28423	 0.20553	 0.00312	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36148	 87495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36148	 87495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87096	 36149	 0.005307	 0.056888	 0.01819	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36150	 36151	 0.002082	 0.013515	 0.02692	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87085	 36150	 0.010945	 0.083125	 0.15338	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36150	 87496	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36150	 87496	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36151	 36153	 0.001433	 0.009874	 0.01743	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36152	 37988	 0.008798	 0.03201	 0.0098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36152	 87497	 0.007264	 0.041738	 0.01182	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36153	 36154	 0.001669	 0.010572	 0.02214	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36154	 87497	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36154	 87497	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36154	 87498	 0.001134	 0.013864	 0.02847	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36155	 36157	 0.011505	 0.031325	 0.0069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36155	 36602	 0.017208	 0.045481	 0.01065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36156	 87498	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87499	 36156	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87496	 36157	 0.018398	 0.064391	 0.02135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87499	 36157	 0.005805	 0.034	 0.00926	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36157	 87500	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36157	 87500	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36158	 36159	 0.009264	 0.0377	 0.00919	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36158	 36171	 0.010359	 0.042158	 0.01027	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36159	 36160	 0.003982	 0.027335	 0.00797	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36159	 87501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36159	 87501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36161	 36163	 0.038283	 0.078675	 0.0015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87136	 36161	 0.068105	 0.061028	 0.00125	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87481	 36161	 0.089322	 0.22965	 0.00355	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36162	 36164	 0.006842	 0.020593	 0.00644	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36162	 87502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36162	 87502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87502	 36163	 0.017192	 0.044556	 0.00084	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36164	 87503	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36164	 87503	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87503	 36165	 0.026306	 0.086813	 0.00141	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36165	 87507	 0.049199	 0.086525	 0.00163	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36165	 87508	 0.11972	 0.12225	 0.0019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36166	 36167	 0.004521	 0.012606	 0.00265	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36166	 36170	 0.007722	 0.02796	 0.006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36167	 87504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36167	 87504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87504	 36168	 0.039372	 0.070767	 0.00127	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36168	 87505	 0.020063	 0.051024	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36169	 36170	 0.006117	 0.020407	 0.00518	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36169	 87505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36169	 87505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36170	 36171	 0.003478	 0.013923	 0.00351	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36170	 36172	 0.002891	 0.015933	 0.00372	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36170	 36174	 0.002951	 0.011598	 0.00303	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87354	 36170	 0.022122	 0.091369	 0.02163	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36170	 87506	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36170	 87506	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36172	 36173	 0.004284	 0.022316	 0.00585	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36172	 87507	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36172	 87507	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36173	 87508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36173	 87508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87506	 36175	 0.090932	 0.087862	 0.00128	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36176	 36177	 0.000863	 0.00328	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36176	 36191	 0.003052	 0.00851	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36176	 87509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36176	 87509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36177	 36178	 0.000261	 0.002136	 0.00058	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36177	 36184	 0.001038	 0.003946	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36177	 87510	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36177	 87510	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36178	 87513	 0.000933	 0.007095	 0.00223	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36179	 36180	 0.007633	 0.010404	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87510	 36179	 0.005534	 0.010598	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36180	 36183	 0.024872	 0.016102	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36181	 36183	 0.003885	 0.009988	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36181	 87511	 0.004738	 0.012181	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36182	 36241	 0.000481	 0.002504	 0.00066	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36182	 36289	 0.000642	 0.003451	 0.00085	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36182	 87511	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36182	 87511	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36183	 87519	 0.015013	 0.019732	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36184	 36205	 0.00116	 0.00398	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36184	 87512	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36184	 87512	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36185	 36186	 0.009808	 0.007762	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87512	 36185	 0.005192	 0.009131	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36185	 87514	 0.030805	 0.019943	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36187	 36188	 0.014393	 0.01139	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87509	 36187	 0.006762	 0.013389	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36188	 87514	 0.018344	 0.014379	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87509	 36189	 0.010586	 0.016217	 0.00023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36189	 87514	 0.026901	 0.021289	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36190	 36286	 0.001007	 0.010695	 0.01955	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36190	 87513	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36190	 87513	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36190	 87532	 0.000797	 0.008132	 0.02582	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36191	 87514	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36191	 87514	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36191	 87557	 0.004154	 0.009642	 0.00294	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87514	 36192	 0.018985	 0.012753	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36193	 36194	 0.012701	 0.008223	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36193	 36202	 0.011391	 0.009015	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87514	 36194	 0.008832	 0.012537	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36195	 87515	 0.038169	 0.030206	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36196	 87515	 0.025999	 0.020379	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36197	 36198	 0.002418	 0.006278	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36197	 87515	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36197	 87515	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36197	 87552	 0.003793	 0.013219	 0.00307	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36198	 36199	 0.00275	 0.007966	 0.00192	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36198	 87516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36198	 87516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36199	 36200	 0.001295	 0.003525	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36200	 36204	 0.003364	 0.009159	 0.00202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36200	 87517	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36200	 87517	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36201	 36202	 0.010694	 0.008463	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87517	 36201	 0.008405	 0.006918	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36203	 87518	 0.008624	 0.011766	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36204	 36205	 0.00128	 0.003887	 0.00085	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36204	 87518	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36204	 87518	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36206	 36207	 0.001068	 0.003339	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36206	 36241	 0.000815	 0.004165	 0.00114	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36206	 87519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36206	 87519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36206	 87557	 0.009117	 0.023669	 0.00574	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36207	 36208	 0.001383	 0.003654	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36207	 36217	 0.002148	 0.005766	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36208	 36209	 0.001782	 0.004478	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36209	 36214	 0.001255	 0.005025	 0.00127	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36209	 87557	 0.004274	 0.015109	 0.0034	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87516	 36210	 0.012466	 0.024681	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36210	 87520	 0.027737	 0.021741	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36211	 36215	 0.001071	 0.00482	 0.00128	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36211	 36232	 0.004513	 0.011602	 0.00287	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36211	 36238	 0.001492	 0.006315	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36211	 87520	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36211	 87520	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36211	 87552	 0.006576	 0.02381	 0.00511	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87520	 36212	 0.023408	 0.016921	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36213	 36235	 0.020848	 0.020853	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36213	 87521	 0.017008	 0.020361	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36214	 36215	 0.00059	 0.00275	 0.00068	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36214	 36216	 0.001246	 0.003344	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36214	 36224	 0.00413	 0.010617	 0.00263	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36215	 87521	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36215	 87521	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36216	 36217	 0.001957	 0.005457	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36217	 87522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36217	 87522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36218	 36221	 0.001667	 0.005809	 0.00135	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36218	 36223	 0.002482	 0.008515	 0.00204	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36218	 36245	 0.001436	 0.007717	 0.0019	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36218	 87523	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36218	 87523	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36219	 36228	 0.058852	 0.046575	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36220	 36223	 0.001973	 0.005536	 0.00142	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36220	 36230	 0.000906	 0.002541	 0.00065	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36220	 87524	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36220	 87524	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36221	 36224	 0.001502	 0.00501	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36221	 87525	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36221	 87525	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36222	 36257	 0.002967	 0.011661	 0.00305	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36222	 36264	 0.003133	 0.012544	 0.00316	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36224	 36225	 0.00163	 0.004804	 0.00112	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36224	 87526	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36224	 87526	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36225	 36232	 0.002123	 0.006924	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36226	 36228	 0.037347	 0.029556	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36227	 36229	 0.0018	 0.004757	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36227	 36230	 0.001015	 0.002993	 0.0007	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36227	 87527	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36227	 87527	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87527	 36228	 0.014245	 0.015667	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36228	 87528	 0.025092	 0.019669	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36228	 87529	 0.022653	 0.017163	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36229	 87528	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36229	 87528	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36229	 87548	 0.002896	 0.008387	 0.00202	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36231	 36232	 0.001168	 0.004087	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36231	 87548	 0.001228	 0.004917	 0.00124	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36232	 87529	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36232	 87529	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36233	 36236	 0.002645	 0.006866	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36233	 87530	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36233	 87530	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36233	 87548	 0.002063	 0.005453	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36234	 36235	 0.014721	 0.016191	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87530	 36234	 0.012281	 0.013626	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87529	 36235	 0.027108	 0.021453	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36236	 36237	 0.001951	 0.005066	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36236	 87531	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36236	 87531	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36237	 36238	 0.00111	 0.004446	 0.00112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36237	 36276	 0.001267	 0.006477	 0.00177	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36239	 36253	 0.000141	 0.001961	 0.12512	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36239	 36281	 0.000303	 0.00542	 0.38483	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36239	 87532	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36240	 87535	 0.015897	 0.012581	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36241	 87535	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36241	 87535	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36242	 36243	 0.003901	 0.01011	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36242	 87559	 0.00414	 0.01479	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87511	 36243	 0.00459	 0.011393	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36244	 87559	 0.015234	 0.011686	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36245	 36246	 0.000683	 0.004584	 0.00111	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36245	 87536	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36245	 87536	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36246	 36249	 0.001001	 0.006343	 0.00172	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36246	 87537	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36246	 87537	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87537	 36247	 0.008205	 0.011184	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36247	 87538	 0.005656	 0.010166	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36248	 36249	 0.000915	 0.004626	 0.00129	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36248	 36288	 0.001258	 0.006213	 0.00181	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36248	 87538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36248	 87538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36249	 87539	 0.00065	 0.005629	 0.00202	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87532	 36250	 0.000744	 0.006804	 0.0131	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36250	 87539	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87540	 36250	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36251	 36252	 0.009301	 0.028533	 0.00077	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87540	 36251	 0.007165	 0.0239	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87534	 36252	 0.008551	 0.037873	 0.00086	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36254	 36590	 0.00022	 0.002847	 0.18173	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36254	 87541	 0.000278	 0.020855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36254	 87541	 0.000278	 0.020855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36255	 37849	 0.010264	 0.061151	 0.01609	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36255	 87542	 0.002887	 0.019347	 0.00593	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87541	 36256	 0.002637	 0.018491	 0.03148	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36256	 87542	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87543	 36256	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36257	 36260	 0.002585	 0.013214	 0.0036	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36258	 87544	 0.026677	 0.047949	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36259	 36260	 0.006762	 0.023197	 0.00556	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36259	 36261	 0.009197	 0.038926	 0.00876	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87539	 36260	 0.003072	 0.017995	 0.0049	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36260	 87544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36260	 87544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36261	 37848	 0.009552	 0.038244	 0.00964	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36262	 36264	 0.006163	 0.024677	 0.00622	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36262	 36269	 0.007697	 0.031781	 0.00752	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36263	 87545	 0.025683	 0.05085	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36264	 87545	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36264	 87545	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36264	 87546	 0.005854	 0.015196	 0.00369	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36265	 87547	 0.019036	 0.037689	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36266	 36267	 0.000391	 0.002575	 0.00498	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36266	 36271	 0.002057	 0.014423	 0.02456	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36266	 87546	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87547	 36266	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36267	 87548	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36267	 87548	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36268	 36275	 0.033131	 0.050754	 0.00071	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87547	 36268	 0.022032	 0.032104	 0.00073	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36269	 37991	 0.008414	 0.033689	 0.00849	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36270	 36277	 0.0027	 0.010988	 0.00268	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36270	 87549	 0.004782	 0.019147	 0.00482	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87180	 36271	 0.000823	 0.014313	 0.04806	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36271	 87549	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36271	 87549	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36271	 87554	 0.001025	 0.014923	 0.03686	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36272	 36273	 0.005061	 0.024564	 0.00562	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36272	 88161	 0.009389	 0.043077	 0.01104	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36273	 36274	 0.001276	 0.012254	 0.00356	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36273	 36285	 0.004695	 0.01987	 0.00447	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36273	 87550	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36273	 87550	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36274	 87555	 0.002137	 0.021775	 0.00561	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87531	 36275	 0.045401	 0.029392	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36275	 87553	 0.043166	 0.085466	 0.00125	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36276	 36280	 0.002294	 0.012159	 0.00406	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36276	 87551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36276	 87551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36277	 36280	 0.002123	 0.008259	 0.00221	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87551	 36278	 0.010726	 0.02102	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36279	 36286	 0.000474	 0.005366	 0.02325	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36279	 87552	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36279	 87552	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36279	 87554	 0.000225	 0.003364	 0.01227	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36280	 87553	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36280	 87553	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36280	 87555	 0.001381	 0.010877	 0.00318	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36281	 87554	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87555	 36281	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87555	 36282	 0.003808	 0.013064	 0.00313	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87550	 36283	 0.09903	 0.078374	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36284	 36290	 0.1832	 0.145	 0.00183	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36284	 87556	 0.050184	 0.080105	 0.00185	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36285	 38016	 0.013852	 0.053896	 0.0144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36285	 87556	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36285	 87556	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36286	 87557	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87558	 36286	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36287	 36288	 0.001033	 0.002812	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36287	 87559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36287	 87559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36288	 36289	 0.000809	 0.004347	 0.00107	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36288	 87560	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36288	 87560	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36291	 36292	 0.018625	 0.067773	 0.02075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36291	 36293	 0.007579	 0.052031	 0.01518	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36291	 36595	 0.007423	 0.047017	 0.01276	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87123	 36292	 0.033971	 0.13612	 0.03433	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36293	 36295	 0.003723	 0.029912	 0.00841	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87126	 36294	 0.027584	 0.06532	 0.00119	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87316	 36295	 0.005445	 0.039172	 0.01038	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36295	 87561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36295	 87561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87316	 36296	 0.009281	 0.04136	 0.01124	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87347	 36297	 0.2965	 0.23248	 0.00298	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36298	 36301	 0.00188	 0.007526	 0.0019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36298	 36306	 0.00123	 0.008249	 0.00199	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36298	 87562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36298	 87562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87562	 36299	 0.012023	 0.009109	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36300	 36335	 0.003799	 0.023604	 0.00666	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36300	 87563	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36300	 87563	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36300	 87575	 0.008012	 0.056678	 0.01555	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36301	 36314	 0.001107	 0.00435	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36302	 87564	 0.021183	 0.015005	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36303	 36312	 0.001305	 0.004255	 0.00113	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36303	 87564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36303	 87564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36304	 36308	 0.01526	 0.009879	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36305	 87565	 0.016236	 0.024872	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36306	 87565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36306	 87565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36306	 87571	 0.000881	 0.006512	 0.00188	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36307	 36308	 0.003448	 0.011502	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87565	 36307	 0.002998	 0.011248	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36308	 36309	 0.005132	 0.013191	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36309	 36310	 0.003755	 0.014446	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36309	 87568	 0.007915	 0.016962	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36310	 36311	 0.005547	 0.010315	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36311	 36330	 0.01134	 0.026327	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87564	 36311	 0.001376	 0.012808	 0.00025	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36311	 87566	 0.01308	 0.02895	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36312	 36313	 0.001355	 0.004522	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36313	 87566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36313	 87566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36314	 36315	 0.000894	 0.003398	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36314	 87567	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36314	 87567	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36315	 36323	 0.001296	 0.005187	 0.00131	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36316	 36317	 0.001157	 0.004548	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36316	 36325	 0.001522	 0.005128	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36317	 36318	 0.000766	 0.003992	 0.00105	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36318	 36320	 0.000556	 0.003457	 0.00098	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36318	 36328	 0.001225	 0.006051	 0.00177	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36318	 87568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36318	 87568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87568	 36319	 0.029142	 0.022843	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36320	 36321	 0.000494	 0.00323	 0.00082	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36320	 87569	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36320	 87569	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36321	 87571	 0.000883	 0.006064	 0.00177	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36322	 36332	 0.042856	 0.047136	 0.00063	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36322	 36333	 0.026254	 0.020777	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36322	 36334	 0.013179	 0.026092	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87563	 36322	 0.009658	 0.054897	 0.00099	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87567	 36322	 0.014024	 0.025049	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36323	 36335	 0.001008	 0.004625	 0.00118	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36324	 36331	 0.006846	 0.021002	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87566	 36324	 0.003884	 0.023605	 0.00044	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36325	 87570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36325	 87570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36326	 36329	 0.000854	 0.004709	 0.0011	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36326	 36347	 0.001476	 0.006772	 0.00173	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36327	 36359	 0.001121	 0.014702	 0.0323	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36327	 36361	 0.000274	 0.004141	 0.01487	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36327	 87571	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36327	 87571	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36328	 36329	 0.001272	 0.006432	 0.00179	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87570	 36330	 0.013939	 0.025151	 0.00036	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36331	 36342	 0.01381	 0.024917	 0.00036	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36331	 36350	 0.007542	 0.015435	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36331	 87574	 0.042347	 0.045223	 0.00096	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36332	 36333	 0.024582	 0.04141	 0.00059	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87342	 36332	 0.05689	 0.18776	 0.00304	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87562	 36333	 0.027801	 0.057133	 0.00109	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36335	 36336	 0.001768	 0.007299	 0.00173	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36335	 87572	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36335	 87572	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36336	 36340	 0.002791	 0.011524	 0.00273	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36337	 36339	 0.007223	 0.0281	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36337	 36341	 0.008883	 0.017588	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87572	 36337	 0.005993	 0.032071	 0.00097	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36338	 36343	 0.004641	 0.024176	 0.00634	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36338	 36347	 0.003764	 0.019606	 0.00514	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36338	 87573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36338	 87573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87573	 36339	 0.007156	 0.023613	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36341	 36342	 0.009133	 0.012729	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36344	 36346	 0.048836	 0.038648	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36345	 36346	 0.117	 0.075753	 0.00144	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87573	 36345	 0.023437	 0.059604	 0.00094	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36347	 87574	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36347	 87574	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36347	 87575	 0.010205	 0.040862	 0.01029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87574	 36348	 0.14455	 0.15901	 0.00212	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36349	 36350	 0.008088	 0.016013	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36349	 36353	 0.01416	 0.018428	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36351	 36356	 0.009639	 0.024512	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87573	 36351	 0.021537	 0.036281	 0.00052	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36352	 36356	 0.043159	 0.034156	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36353	 36355	 0.005144	 0.017161	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87574	 36353	 0.009778	 0.03262	 0.00052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87574	 36354	 0.032567	 0.025773	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36355	 36356	 0.008567	 0.020287	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36357	 36358	 0.21617	 0.14524	 0.00256	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87088	 36359	 0.004835	 0.060006	 0.2173	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36359	 87575	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36359	 87575	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87569	 36360	 0.033505	 0.043603	 0.00061	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36360	 87577	 0.01401	 0.02867	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36361	 87576	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36361	 87576	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87571	 36362	 0.001836	 0.009733	 0.00325	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87575	 36362	 0.006446	 0.033577	 0.00881	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36362	 87577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36362	 87577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87465	 36363	 0.001415	 0.011744	 0.02384	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36363	 87578	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87579	 36363	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87579	 36364	 0.033362	 0.026402	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87578	 36365	 0.002358	 0.006233	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36365	 87580	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36365	 87580	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87100	 36366	 0.00045	 0.00798	 0.00401	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87100	 36367	 0.000545	 0.004949	 0.00161	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36367	 87581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36367	 87581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36368	 36371	 0.008538	 0.015637	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36368	 36375	 0.017757	 0.041226	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87581	 36368	 0.003515	 0.014065	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36369	 36371	 0.024755	 0.016628	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36370	 36377	 0.029935	 0.022024	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87580	 36370	 0.009685	 0.024895	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36372	 87582	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36372	 87582	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36373	 36374	 0.041995	 0.033235	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36374	 87585	 0.059006	 0.042656	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36375	 36376	 0.069107	 0.05417	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36378	 36379	 0.016611	 0.041759	 0.01082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36378	 36380	 0.006603	 0.023012	 0.00534	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87578	 36378	 0.002312	 0.013429	 0.00316	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36378	 87585	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36378	 87585	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36380	 36382	 0.006361	 0.017738	 0.00372	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36380	 87586	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36380	 87586	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36381	 87587	 0.036382	 0.028792	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36382	 36383	 0.003258	 0.007562	 0.0023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36382	 87587	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36382	 87587	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36383	 36386	 0.005215	 0.015376	 0.00358	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87586	 36384	 0.061634	 0.067133	 0.00091	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87586	 36385	 0.11305	 0.1486	 0.00204	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36386	 87588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36386	 87588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36387	 36388	 0.006227	 0.028566	 0.00732	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36388	 36389	 0.005103	 0.023412	 0.006	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87492	 36389	 0.007637	 0.032325	 0.00727	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87272	 36390	 0.26803	 0.28638	 0.00606	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36391	 36392	 0.016239	 0.067057	 0.01587	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87365	 36391	 0.010674	 0.067622	 0.01836	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36392	 87589	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36392	 87589	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36393	 36394	 0.012237	 0.032342	 0.00757	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36393	 36397	 0.034421	 0.089393	 0.02171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36393	 36524	 0.012324	 0.041116	 0.01043	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36394	 36395	 0.010288	 0.041866	 0.0102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36394	 36524	 0.027842	 0.072297	 0.01755	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36395	 36396	 0.018679	 0.049371	 0.01156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36395	 38126	 0.017007	 0.042755	 0.01108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36396	 38192	 0.033907	 0.091059	 0.02065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36397	 36487	 0.035013	 0.092567	 0.02168	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36398	 87590	 0.19249	 0.13917	 0.00211	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36399	 36401	 0.007717	 0.031861	 0.00754	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36401	 36402	 0.005558	 0.021125	 0.00591	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36401	 87590	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36401	 87590	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36402	 36404	 0.007515	 0.030086	 0.00758	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87089	 36402	 0.047394	 0.15829	 0.0402	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36403	 36404	 0.014312	 0.037826	 0.00885	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36403	 36405	 0.012354	 0.032652	 0.00764	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36403	 87591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36403	 87591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87327	 36405	 0.032149	 0.084992	 0.0199	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36406	 36408	 0.012092	 0.042145	 0.00977	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36406	 87592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36406	 87592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36407	 87593	 0.25846	 0.20459	 0.00258	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36408	 87593	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36408	 87593	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36409	 36410	 0.088627	 0.089518	 0.00119	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87122	 36410	 0.051008	 0.29002	 0.00525	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36411	 36512	 0.022176	 0.057578	 0.01398	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36412	 36413	 0.000728	 0.002635	 0.00057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36412	 87599	 0.001178	 0.004105	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36413	 87594	 0.001309	 0.004367	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87452	 36414	 0.000681	 0.004313	 0.00903	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36414	 87594	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87595	 36414	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36415	 36416	 0.000142	 0.00193	 0.00393	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87452	 36415	 0.000208	 0.002827	 0.00575	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36416	 87596	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36416	 87596	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36416	 87597	 0.000746	 0.005228	 0.0089	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36416	 87598	 0.00042	 0.00318	 0.00585	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36417	 36418	 3.9e-05	 0.000469	 0.03519	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36417	 36419	 4.4e-05	 0.000545	 0.03736	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36417	 87597	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36417	 87597	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36418	 87598	 9.9e-05	 0.007891	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87599	 36418	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36419	 87600	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36419	 87600	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95333	 36419	 0.001454	 0.025043	 1.9734	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 0	 -30.0	 30.0;
	87597	 36420	 0.000752	 0.00457	 0.01041	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36420	 87601	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36420	 87601	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87600	 36421	 0.001774	 0.011517	 0.02294	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36422	 36423	 0.018507	 0.051921	 0.01337	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87601	 36422	 0.012402	 0.033298	 0.00755	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87265	 36423	 0.016827	 0.067383	 0.01698	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87410	 36425	 0.005054	 0.020235	 0.0051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36425	 87602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36425	 87602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87409	 36426	 0.05917	 0.046826	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87411	 36426	 0.034796	 0.068893	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36427	 36428	 0.070433	 0.077469	 0.00103	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36427	 36430	 0.12716	 0.10064	 0.00127	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36428	 36430	 0.15687	 0.12034	 0.00162	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87602	 36428	 0.020207	 0.089034	 0.00155	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36429	 87603	 0.031377	 0.079797	 0.00126	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87129	 36430	 0.032007	 0.12452	 0.00208	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36431	 36433	 0.015762	 0.055721	 0.01256	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36431	 36495	 0.004358	 0.023077	 0.00585	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36431	 87603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36431	 87603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36432	 36438	 0.006384	 0.033255	 0.00872	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36432	 36495	 0.005929	 0.030884	 0.0081	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36433	 36434	 0.011537	 0.029951	 0.00727	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36434	 87604	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36434	 87604	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87273	 36435	 0.051971	 0.17339	 0.00275	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87604	 36435	 0.040524	 0.093102	 0.00141	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87410	 36436	 0.006359	 0.051093	 0.01436	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36436	 87605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36436	 87605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87602	 36437	 0.039861	 0.13298	 0.00211	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87605	 36437	 0.047422	 0.10163	 0.00178	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36438	 36484	 0.008712	 0.028416	 0.00754	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87093	 36438	 0.004706	 0.040082	 0.01	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87094	 36439	 0.10736	 0.084159	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36440	 36444	 0.004714	 0.013654	 0.00329	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36440	 36446	 0.00386	 0.0102	 0.00239	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36441	 36442	 0.026643	 0.021084	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36441	 36457	 0.022603	 0.027554	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87427	 36442	 0.05473	 0.10836	 0.00159	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36443	 36480	 0.001332	 0.008881	 0.01674	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36443	 87606	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36443	 87606	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87606	 36444	 0.006343	 0.022421	 0.00505	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36445	 36446	 0.005338	 0.0166	 0.00346	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87606	 36445	 0.0073	 0.025041	 0.006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36447	 36452	 0.01206	 0.032379	 0.00734	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36447	 36458	 0.003175	 0.00816	 0.00202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36447	 87607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36447	 87607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36448	 87613	 0.043524	 0.035824	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36449	 36485	 0.049567	 0.039227	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36449	 87608	 0.052604	 0.04163	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36450	 36455	 0.002401	 0.006444	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36450	 36462	 0.007098	 0.019057	 0.00432	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36450	 36478	 0.003636	 0.010888	 0.00245	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36450	 87620	 0.001447	 0.005888	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36451	 36452	 0.004338	 0.011465	 0.00268	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36451	 87608	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36451	 87608	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36452	 87609	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36452	 87609	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36452	 87610	 0.002108	 0.007634	 0.00164	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36453	 36464	 0.000487	 0.00321	 0.00621	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36453	 87610	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36453	 87610	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36454	 36456	 0.002322	 0.006323	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36454	 87614	 0.001669	 0.004411	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36455	 36465	 0.002498	 0.006601	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36455	 87611	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36455	 87611	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36456	 87612	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36456	 87612	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36456	 87614	 0.002294	 0.005766	 0.00149	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36456	 87620	 0.003369	 0.008904	 0.00208	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87607	 36457	 0.007727	 0.025778	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36458	 36466	 0.001264	 0.00325	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36458	 87613	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36458	 87613	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87610	 36459	 0.002096	 0.005269	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87433	 36460	 0.009945	 0.025565	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87608	 36460	 0.014412	 0.028245	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36461	 36462	 0.008088	 0.020791	 0.00515	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36463	 87621	 0.075723	 0.05474	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36464	 36477	 0.000764	 0.005156	 0.00949	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36464	 36480	 0.002538	 0.0178	 0.03031	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36464	 87614	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36464	 87614	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87614	 36465	 0.001549	 0.00402	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36466	 36467	 0.003094	 0.008177	 0.00191	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87606	 36467	 0.007089	 0.019299	 0.00425	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87609	 36468	 0.042287	 0.034805	 0.00071	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36469	 36470	 0.000736	 0.004966	 0.00914	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36469	 87615	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36469	 87615	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36470	 36471	 0.00046	 0.00314	 0.00565	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36470	 87616	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36470	 87616	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36471	 36475	 0.000806	 0.005103	 0.01069	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36471	 87617	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36471	 87617	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87617	 36472	 0.007034	 0.019616	 0.00412	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36473	 36476	 0.008245	 0.02179	 0.0051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36473	 36478	 0.009503	 0.03312	 0.00768	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87615	 36473	 0.007316	 0.02649	 0.00568	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36473	 87618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36473	 87618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87618	 36474	 0.082004	 0.090197	 0.0012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36474	 87625	 0.053956	 0.096981	 0.00174	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36475	 36477	 0.000723	 0.004692	 0.00935	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36475	 87619	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36475	 87619	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87619	 36476	 0.003928	 0.010546	 0.00239	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36477	 87620	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87621	 36477	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36478	 87622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36478	 87622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87622	 36479	 0.019695	 0.050628	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36480	 36481	 0.001225	 0.008267	 0.01522	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36480	 87623	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36480	 87623	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87092	 36481	 0.002258	 0.015556	 0.02746	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36481	 87624	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87625	 36481	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87624	 36482	 0.007074	 0.021999	 0.00459	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87093	 36483	 0.002549	 0.012569	 0.0034	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87623	 36483	 0.00889	 0.030984	 0.00718	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36487	 38041	 0.017498	 0.070069	 0.01766	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87096	 36487	 0.032828	 0.13153	 0.03317	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36487	 87626	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36487	 87626	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36488	 87627	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36488	 87627	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87627	 36489	 0.20258	 0.1361	 0.0024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36491	 36496	 0.014131	 0.041665	 0.00969	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87106	 36491	 0.006103	 0.016617	 0.00366	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36492	 36493	 0.004353	 0.017107	 0.00448	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87106	 36492	 0.007361	 0.03433	 0.0085	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36493	 36494	 0.006542	 0.025714	 0.00673	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36494	 36495	 0.008042	 0.021591	 0.00489	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36494	 36500	 0.004842	 0.017534	 0.00376	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36496	 36500	 0.006772	 0.023937	 0.00539	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36497	 87628	 0.057634	 0.042403	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36498	 87628	 0.033736	 0.02482	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36499	 87628	 0.051602	 0.039096	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36500	 36501	 0.00157	 0.007755	 0.00226	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36500	 36503	 0.008374	 0.042361	 0.01179	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36500	 87628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36500	 87628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36501	 36502	 0.006763	 0.035232	 0.00924	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36502	 36508	 0.00686	 0.036874	 0.00907	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87093	 36503	 0.004648	 0.054963	 0.01565	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36504	 36505	 0.004658	 0.018651	 0.0047	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87093	 36504	 0.00376	 0.020726	 0.00484	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36505	 36508	 0.005535	 0.018989	 0.00455	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87093	 36506	 0.005748	 0.028878	 0.00752	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36507	 36509	 0.001888	 0.010406	 0.00243	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36509	 36510	 0.001225	 0.006383	 0.00167	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36509	 87629	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36509	 87629	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87629	 36511	 0.038104	 0.029868	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87098	 36512	 0.015785	 0.04402	 0.00924	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87098	 36513	 0.005921	 0.015648	 0.00366	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87098	 36514	 0.004597	 0.023253	 0.00647	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36514	 87630	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36514	 87630	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36515	 36516	 0.14939	 0.14436	 0.0021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36515	 36518	 0.16727	 0.13113	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87099	 36515	 0.024146	 0.047322	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87630	 36516	 0.045695	 0.10821	 0.00198	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36517	 36520	 0.012983	 0.034313	 0.00803	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87098	 36517	 0.008058	 0.060391	 0.01473	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36519	 36520	 0.014566	 0.037817	 0.00918	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36519	 36521	 0.006653	 0.03343	 0.0087	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36522	 36534	 0.053944	 0.034924	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36523	 36527	 0.018698	 0.04942	 0.01157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36524	 36525	 0.012669	 0.034493	 0.0076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36524	 36530	 0.024148	 0.06383	 0.01494	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36525	 36526	 0.006685	 0.0182	 0.00401	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36526	 36527	 0.004191	 0.011687	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36526	 36528	 0.00398	 0.010684	 0.00242	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36526	 36549	 0.009157	 0.023773	 0.00577	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36528	 36532	 0.003689	 0.009273	 0.0024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36529	 87631	 0.043744	 0.11245	 0.00174	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36530	 87631	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36530	 87631	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36530	 87649	 0.002656	 0.020926	 0.00612	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36531	 36540	 0.002923	 0.020495	 0.0349	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36531	 38131	 0.010999	 0.073482	 0.13884	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36531	 87632	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36531	 87632	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36531	 87648	 0.001638	 0.010374	 0.02173	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36532	 36533	 0.001507	 0.003913	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36532	 87633	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36532	 87633	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36533	 36549	 0.001487	 0.004265	 0.00105	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36533	 87634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36533	 87634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36534	 36535	 0.018173	 0.030613	 0.00044	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36535	 36536	 0.037737	 0.026731	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36535	 87650	 0.017038	 0.029963	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87634	 36536	 0.016315	 0.032302	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36537	 36567	 0.003022	 0.007987	 0.00187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36537	 36568	 0.00391	 0.010334	 0.00242	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87127	 36537	 0.001287	 0.008149	 0.00221	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36538	 36542	 0.002425	 0.015364	 0.03218	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36538	 87635	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36538	 87635	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36539	 87639	 0.049862	 0.12818	 0.00198	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36540	 36542	 0.003998	 0.025957	 0.05172	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36540	 87636	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36540	 87636	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36541	 36557	 0.012313	 0.031653	 0.00784	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87636	 36541	 0.015235	 0.039165	 0.0097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36541	 87637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36541	 87637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36541	 87638	 0.01346	 0.034601	 0.00857	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36542	 87638	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87639	 36542	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36543	 36545	 0.057833	 0.045333	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87637	 36543	 0.11319	 0.088729	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36543	 87645	 0.054723	 0.043307	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36544	 36545	 0.036704	 0.023762	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36544	 87651	 0.028251	 0.022357	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36546	 36547	 0.001659	 0.00417	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36546	 36549	 0.003932	 0.010393	 0.00243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36546	 36566	 0.0021	 0.00555	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36547	 36554	 0.00121	 0.003294	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36547	 87640	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36547	 87640	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87640	 36548	 0.017616	 0.011405	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36549	 87641	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36549	 87641	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36549	 87649	 0.002197	 0.018841	 0.00536	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87641	 36550	 0.02058	 0.014877	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36551	 36552	 0.000854	 0.006306	 0.00182	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36551	 87649	 0.001586	 0.01274	 0.00358	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36552	 36554	 0.000965	 0.003309	 0.00079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36552	 87642	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36552	 87642	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36553	 36554	 0.001381	 0.003584	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36553	 36555	 0.00101	 0.002669	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36553	 36562	 0.001404	 0.003712	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36555	 36556	 0.002455	 0.006489	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36555	 87643	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36555	 87643	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36556	 36557	 0.002093	 0.00562	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36556	 36568	 0.00205	 0.005417	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36557	 36559	 0.003435	 0.009351	 0.00206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36557	 36567	 0.003787	 0.010007	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36557	 87644	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36557	 87644	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36558	 36559	 0.002402	 0.006237	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36558	 36561	 0.002056	 0.005338	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36559	 87645	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36559	 87645	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36560	 36561	 0.001896	 0.006388	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36560	 87646	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36560	 87646	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36560	 87649	 0.003285	 0.019241	 0.00524	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36561	 36562	 0.002094	 0.0057	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36561	 36565	 0.003484	 0.008955	 0.00222	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36561	 87647	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36561	 87647	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36563	 87648	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87649	 36563	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87646	 36564	 0.026555	 0.050189	 0.00081	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87636	 36565	 0.009349	 0.024708	 0.00578	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36566	 36567	 0.00235	 0.006398	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36566	 87650	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36566	 87650	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36567	 87651	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36567	 87651	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36569	 36570	 0.005897	 0.02055	 0.00477	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36569	 36571	 0.005898	 0.024964	 0.00562	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36569	 36579	 0.011607	 0.029839	 0.00739	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87115	 36569	 0.006458	 0.053595	 0.0141	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36570	 36576	 0.008462	 0.022364	 0.00523	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36571	 36575	 0.010464	 0.027654	 0.00647	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36571	 36596	 0.031211	 0.10882	 0.02525	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36572	 36573	 0.004192	 0.014379	 0.00344	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36572	 36582	 0.006149	 0.02868	 0.0071	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36573	 36574	 0.004605	 0.015796	 0.00378	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36574	 36575	 0.004506	 0.015928	 0.00359	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36576	 36577	 0.014609	 0.038613	 0.00904	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36577	 36578	 0.011059	 0.028712	 0.00697	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36577	 36602	 0.014406	 0.038074	 0.00891	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36580	 36581	 0.007922	 0.026693	 0.00663	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36581	 36582	 0.005657	 0.019059	 0.00474	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87115	 36582	 0.003445	 0.021822	 0.00592	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87087	 36583	 0.11176	 0.072358	 0.00138	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36584	 36585	 0.002006	 0.015808	 0.00462	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87086	 36584	 0.001977	 0.029538	 0.00874	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36584	 87652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36584	 87652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36585	 36586	 0.00218	 0.018569	 0.00463	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36587	 87653	 0.21688	 0.17003	 0.00218	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87117	 36588	 0.022967	 0.087332	 0.02446	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36588	 87653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36588	 87653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87117	 36589	 0.0071	 0.045734	 0.01199	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87123	 36589	 0.006527	 0.03823	 0.01041	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36589	 87654	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36589	 87654	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36590	 87655	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87656	 36590	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87543	 36591	 0.31018	 0.22829	 0.00334	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87134	 36593	 0.038027	 0.12991	 0.00282	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36593	 87658	 0.041539	 0.15982	 0.00273	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87308	 36594	 0.037991	 0.16096	 0.03627	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36594	 87657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36594	 87657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36595	 87658	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36595	 87658	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36596	 36599	 0.016157	 0.047639	 0.01108	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87441	 36596	 0.018316	 0.052539	 0.01293	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36597	 87659	 0.050618	 0.077542	 0.00109	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36598	 87659	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36598	 87659	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36599	 36602	 0.012248	 0.043294	 0.00976	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87442	 36600	 0.083344	 0.1615	 0.00348	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36600	 87660	 0.042003	 0.094236	 0.0015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36601	 36602	 0.014894	 0.041537	 0.00872	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87496	 36601	 0.014937	 0.038781	 0.00941	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36601	 87660	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36601	 87660	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36603	 36605	 0.03127	 0.095931	 0.0026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36603	 88054	 0.042194	 0.127	 0.00248	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36604	 36607	 0.11356	 0.089877	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36604	 37003	 0.18131	 0.1435	 0.00181	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36605	 36607	 0.035463	 0.084586	 0.00189	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36605	 88037	 0.063094	 0.10523	 0.00153	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36606	 36608	 0.00533	 0.023749	 0.00645	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36606	 87661	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36606	 87661	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87661	 36607	 0.011628	 0.079815	 0.00146	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36607	 88038	 0.26428	 0.20721	 0.00266	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36608	 37491	 0.006869	 0.035115	 0.00957	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36609	 37610	 0.10967	 0.10731	 0.00152	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87661	 36609	 0.052207	 0.093839	 0.00169	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36610	 36612	 0.006838	 0.027376	 0.0069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36610	 36633	 0.012112	 0.040407	 0.01025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36611	 37636	 0.19748	 0.12787	 0.00243	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36612	 36613	 0.004146	 0.021597	 0.00566	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36612	 36615	 0.006053	 0.026348	 0.00751	 211.0	 211.0	 211.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36612	 88047	 0.008767	 0.066046	 0.01833	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36613	 36632	 0.009157	 0.047704	 0.01251	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36614	 39167	 0.16582	 0.11988	 0.00182	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36615	 39698	 0.003834	 0.019397	 0.0054	 211.0	 211.0	 211.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36616	 36617	 0.003755	 0.014757	 0.00386	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36616	 87662	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36616	 87662	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36616	 87789	 0.011868	 0.034042	 0.00838	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36617	 36619	 0.004683	 0.024392	 0.0064	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36618	 37484	 0.007776	 0.031135	 0.00784	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36619	 36620	 0.005176	 0.026961	 0.00707	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36619	 87663	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36619	 87663	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36620	 37688	 0.007007	 0.037113	 0.00941	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36621	 36622	 0.1687	 0.10923	 0.00208	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36621	 87963	 0.04918	 0.12508	 0.00198	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36623	 36770	 0.000142	 0.001826	 0.13696	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36623	 37422	 0.00025	 0.003349	 0.22941	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36624	 87667	 0.056126	 0.094551	 0.00135	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36625	 87666	 0.038581	 0.099179	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36626	 87666	 0.043783	 0.069887	 0.00161	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36627	 87664	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87665	 36627	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36627	 88384	 0.008087	 0.07857	 0.27939	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87664	 36628	 0.001321	 0.006996	 0.00177	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36628	 87666	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36628	 87666	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36629	 37489	 0.007739	 0.038235	 0.01117	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87664	 36629	 0.00508	 0.02646	 0.00694	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36629	 87667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36629	 87667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87664	 36630	 0.00369	 0.012656	 0.00303	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36631	 36632	 0.007578	 0.038739	 0.01056	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36631	 37490	 0.005042	 0.026701	 0.00677	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36633	 37684	 0.005241	 0.034272	 0.00872	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87664	 36633	 0.004202	 0.031047	 0.00896	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36634	 36635	 0.037764	 0.11598	 0.00218	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36634	 88009	 0.031418	 0.12223	 0.00204	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36635	 87997	 0.020202	 0.13868	 0.00253	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36635	 88034	 0.035703	 0.27834	 0.0052	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36636	 37483	 0.028027	 0.13454	 0.00402	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36636	 88035	 0.038854	 0.17315	 0.00294	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36637	 87668	 0.23141	 0.18142	 0.00233	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36638	 37349	 0.063704	 0.11668	 0.00201	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36638	 87669	 0.084703	 0.19462	 0.00296	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36639	 36640	 0.002611	 0.020004	 0.00536	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36639	 36641	 0.002548	 0.018825	 0.00543	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36639	 87668	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36639	 87668	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36640	 37043	 0.004049	 0.032328	 0.00797	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36641	 36643	 0.002169	 0.016496	 0.00518	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36642	 36643	 0.001065	 0.010567	 0.00287	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36642	 36645	 0.008195	 0.022989	 0.00592	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36642	 39084	 0.013322	 0.14295	 0.04577	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36642	 87669	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36642	 87669	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36643	 38513	 0.005102	 0.020053	 0.00525	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87669	 36644	 0.050318	 0.055344	 0.00074	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36645	 37350	 0.009893	 0.033334	 0.00828	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36646	 37316	 0.002291	 0.005948	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36646	 87670	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36646	 87670	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36646	 87671	 0.001598	 0.004107	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36646	 87677	 0.003635	 0.009605	 0.00225	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36647	 36653	 0.000717	 0.004544	 0.00952	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36647	 87671	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36647	 87671	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36647	 87672	 0.000281	 0.003247	 0.00622	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36648	 36974	 0.000285	 0.004705	 0.41265	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36648	 87672	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36648	 87672	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95338	 36648	 0.000467	 0.01483	 1.5395	 4217.0	 4427.8	 4638.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36649	 36656	 0.001015	 0.004131	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36649	 87675	 0.002452	 0.011042	 0.00294	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36650	 36651	 0.00032	 0.002531	 0.00878	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36650	 87675	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36650	 87675	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87672	 36651	 0.000199	 0.002569	 0.00582	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36651	 87676	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36651	 87676	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36652	 36666	 0.035834	 0.060366	 0.00086	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87676	 36652	 0.019247	 0.023463	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36653	 87677	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87678	 36653	 0.000321	 0.02569	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36654	 36655	 0.001251	 0.00429	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36654	 87679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36654	 87679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36655	 36656	 0.001038	 0.00376	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36657	 87680	 0.008212	 0.039418	 0.00118	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87141	 36658	 0.007415	 0.046077	 0.01301	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36658	 87680	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36658	 87680	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36659	 36661	 0.002755	 0.017747	 0.00465	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87141	 36659	 0.003341	 0.023634	 0.00649	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36660	 36661	 0.001081	 0.007255	 0.00175	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36660	 36667	 0.00219	 0.011772	 0.0029	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87142	 36662	 0.099708	 0.10967	 0.00146	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36663	 36975	 0.003652	 0.021393	 0.00583	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87141	 36663	 0.017474	 0.048731	 0.01023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36663	 87681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36663	 87681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36664	 36666	 0.01276	 0.029619	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87674	 36664	 0.041671	 0.049884	 0.00083	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36665	 37310	 0.006607	 0.020061	 0.00439	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87673	 36665	 0.00488	 0.017077	 0.00566	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87681	 36666	 0.017275	 0.067204	 0.00112	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87677	 36667	 0.002484	 0.008103	 0.00215	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36668	 36669	 0.002952	 0.010688	 0.00229	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36668	 36672	 0.008712	 0.0219	 0.00567	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36668	 87682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36668	 87682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36669	 36670	 0.003109	 0.016193	 0.00425	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36669	 36671	 0.008956	 0.023671	 0.00554	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36670	 87732	 0.004331	 0.029053	 0.00701	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36671	 37051	 0.012022	 0.031212	 0.00758	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36671	 87683	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36671	 87683	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36672	 37053	 0.010315	 0.028084	 0.00619	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36673	 37526	 0.010122	 0.040527	 0.01021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36673	 87996	 0.00835	 0.032818	 0.00859	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36674	 37004	 0.004138	 0.013943	 0.00347	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36674	 87684	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36674	 87684	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36674	 87687	 0.010931	 0.039769	 0.01218	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87684	 36675	 0.008987	 0.017794	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36676	 36677	 0.013238	 0.014137	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36677	 36678	 0.007639	 0.025484	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36677	 36679	 0.015689	 0.023795	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36677	 36686	 0.006713	 0.03577	 0.00063	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36678	 36680	 0.01263	 0.019707	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36678	 87685	 0.012061	 0.036303	 0.00071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87684	 36681	 0.015527	 0.039914	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36682	 87685	 0.027651	 0.070321	 0.00111	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36683	 87685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36683	 87685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36683	 87687	 0.008682	 0.034124	 0.00893	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36684	 36781	 0.001159	 0.013268	 0.02596	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36684	 87686	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36684	 87686	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36685	 87687	 0.00018	 0.014416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87688	 36686	 0.013461	 0.092402	 0.00168	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87164	 36687	 0.003994	 0.030089	 0.00835	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36687	 87689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36687	 87689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36688	 36978	 0.052305	 0.12142	 0.00231	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87689	 36688	 0.013075	 0.050097	 0.00142	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36689	 36690	 0.007658	 0.029791	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87689	 36689	 0.014514	 0.038468	 0.00098	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36689	 87690	 0.009598	 0.05114	 0.0009	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36690	 87945	 0.091193	 0.085521	 0.00132	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36691	 36693	 0.002511	 0.024529	 0.00688	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87164	 36691	 0.011592	 0.049064	 0.01104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36691	 87690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36691	 87690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36692	 36693	 0.007186	 0.024652	 0.00591	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36692	 37486	 0.005405	 0.028155	 0.00738	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36692	 87975	 0.006255	 0.063743	 0.01643	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36693	 37393	 0.006027	 0.031394	 0.00823	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36694	 36695	 0.002076	 0.014081	 0.02564	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87155	 36694	 0.002305	 0.01518	 0.02937	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87148	 36695	 0.010415	 0.071853	 0.12712	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36695	 87691	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87692	 36695	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36696	 37049	 0.020805	 0.058023	 0.01218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36696	 37472	 0.009057	 0.046265	 0.01164	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36696	 37599	 0.010434	 0.035794	 0.00858	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36697	 36699	 0.035263	 0.090649	 0.0014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36697	 37450	 0.062143	 0.14213	 0.00347	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36698	 36699	 0.011883	 0.092618	 0.00173	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36698	 37375	 0.027241	 0.09532	 0.00197	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36698	 37551	 0.041181	 0.15844	 0.00271	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36699	 36703	 0.044679	 0.1719	 0.00293	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36700	 36703	 0.10569	 0.13892	 0.0019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36700	 37452	 0.1542	 0.16798	 0.00229	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36701	 36702	 0.13613	 0.10671	 0.00137	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36702	 37563	 0.08786	 0.13326	 0.00191	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36703	 37556	 0.033203	 0.11077	 0.00176	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36703	 87786	 0.064607	 0.39283	 0.00725	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36704	 36705	 7.3e-05	 0.001978	 0.16601	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36704	 37478	 8.3e-05	 0.002139	 0.19481	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36704	 87693	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36704	 87693	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36705	 37013	 0.000272	 0.004192	 0.32255	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36705	 37527	 0.000263	 0.004123	 0.40074	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36705	 37678	 0.001136	 0.013584	 1.0225	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36705	 87694	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87695	 36705	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87694	 36706	 0.001247	 0.011469	 0.02182	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36706	 87696	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36706	 87696	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36707	 87697	 0.021048	 0.14991	 0.00337	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36707	 88011	 0.020722	 0.15744	 0.00359	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36708	 37477	 0.001746	 0.028482	 0.017	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87695	 36708	 0.001622	 0.025707	 0.01626	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36709	 36999	 0.006079	 0.048842	 0.01373	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36709	 37036	 0.003465	 0.050027	 0.01589	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87695	 36709	 0.004132	 0.040374	 0.01133	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36709	 87697	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36709	 87697	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36710	 36713	 0.023278	 0.054043	 0.0008	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36710	 36714	 0.008792	 0.033823	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36710	 87698	 0.006014	 0.018469	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36711	 36716	 0.004347	 0.017689	 0.00431	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36711	 87698	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36711	 87698	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36712	 37235	 0.080861	 0.086155	 0.00123	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87698	 36712	 0.023281	 0.060338	 0.00114	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36713	 36715	 0.009937	 0.022539	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36713	 36725	 0.026532	 0.061598	 0.00092	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36714	 88050	 0.018868	 0.08873	 0.00165	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36715	 87699	 0.011717	 0.030121	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36716	 36718	 0.002144	 0.010593	 0.00309	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36716	 87699	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36716	 87699	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36717	 36718	 0.001598	 0.004109	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36717	 37242	 0.002445	 0.006286	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36718	 36722	 0.00209	 0.014021	 0.00338	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36718	 87700	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36718	 87700	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87700	 36719	 0.037304	 0.029522	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36720	 36722	 0.002279	 0.008956	 0.00234	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36720	 36724	 0.00321	 0.013252	 0.00314	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36720	 87701	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36720	 87701	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87701	 36721	 0.009166	 0.022435	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87154	 36722	 0.003806	 0.036548	 0.01063	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36723	 36727	 0.15144	 0.11143	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36723	 87892	 0.069832	 0.064324	 0.00103	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36724	 36726	 0.003193	 0.022153	 0.00632	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36725	 87889	 0.04496	 0.24764	 0.00559	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36725	 88005	 0.036505	 0.11211	 0.0021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36726	 37027	 0.004323	 0.044049	 0.01135	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36728	 36729	 0.021823	 0.10133	 0.00277	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36728	 88014	 0.024512	 0.16827	 0.00307	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36729	 87747	 0.028434	 0.13882	 0.00291	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87143	 36730	 0.001974	 0.019996	 0.04025	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36730	 87702	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36730	 87702	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36731	 37399	 0.020706	 0.055596	 0.0126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87702	 36731	 0.015266	 0.040347	 0.00944	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36732	 88004	 0.17465	 0.13823	 0.00174	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36733	 36734	 0.010799	 0.030114	 0.00632	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36733	 37085	 0.005527	 0.047409	 0.01349	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36733	 87952	 0.007916	 0.054925	 0.01568	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87176	 36734	 0.011682	 0.082646	 0.02269	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36734	 87703	 0.01168	 0.03087	 0.00723	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36735	 36797	 0.001579	 0.012064	 0.04484	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36735	 37405	 0.000883	 0.009408	 0.04605	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36735	 87703	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36735	 87703	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36736	 37656	 0.013259	 0.045486	 0.0109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36736	 39657	 0.022262	 0.062089	 0.01303	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36736	 87705	 0.007463	 0.026379	 0.00594	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36737	 36739	 0.00109	 0.007353	 0.01354	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36737	 36992	 0.001893	 0.012774	 0.02352	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36738	 36742	 0.002651	 0.011221	 0.00252	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36738	 87704	 0.003267	 0.008633	 0.00202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36738	 87705	 0.002837	 0.011358	 0.00286	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36739	 36740	 0.000606	 0.004172	 0.00736	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36739	 87704	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36739	 87704	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36740	 37417	 0.006277	 0.041349	 0.08007	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36740	 37463	 0.00344	 0.023214	 0.04275	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36740	 37465	 0.002935	 0.019052	 0.03795	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36740	 38959	 0.005443	 0.036742	 0.06769	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87232	 36740	 0.01033	 0.070557	 0.12732	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36740	 87705	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87706	 36740	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36741	 36742	 0.004525	 0.011747	 0.00285	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36741	 87707	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36741	 87707	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36742	 36743	 0.004039	 0.018529	 0.00475	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36743	 38954	 0.007593	 0.031613	 0.00986	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36744	 38953	 0.18132	 0.17744	 0.00251	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87707	 36744	 0.15917	 0.12597	 0.00159	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36745	 87713	 0.002301	 0.009404	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36745	 87928	 0.001729	 0.00675	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36746	 87713	 0.005629	 0.006191	 8e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36747	 36748	 0.000523	 0.001793	 0.00043	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36747	 36767	 0.000581	 0.001937	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36748	 37337	 0.000645	 0.002214	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36748	 87708	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36748	 87708	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36749	 36750	 0.008811	 0.006973	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36749	 36751	 0.00758	 0.013539	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36749	 36758	 0.004546	 0.010554	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36752	 36760	 0.011933	 0.020102	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36753	 87712	 0.03657	 0.064313	 0.00121	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36754	 36755	 0.003155	 0.011423	 0.00245	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36754	 36766	 0.002953	 0.011824	 0.00298	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36754	 37333	 0.004589	 0.013529	 0.00315	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36755	 36756	 0.003601	 0.018091	 0.00471	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36755	 87709	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36755	 87709	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36756	 37311	 0.008224	 0.021735	 0.00509	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87691	 36756	 0.006717	 0.0611	 0.01543	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87709	 36757	 0.13872	 0.10979	 0.00138	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36758	 36759	 0.012262	 0.009612	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36758	 87713	 0.002423	 0.012258	 0.00021	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36760	 87710	 0.009475	 0.01939	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36761	 36764	 0.010429	 0.020439	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36762	 87710	 0.007381	 0.01298	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36763	 36769	 0.001323	 0.007494	 0.00186	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36763	 87710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36763	 87710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36764	 87714	 0.009464	 0.026855	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36765	 36766	 0.002853	 0.007335	 0.00182	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36765	 87711	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36765	 87711	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36766	 87712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36766	 87712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36767	 87713	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36767	 87713	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36768	 87714	 0.012485	 0.032093	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87673	 36769	 0.003052	 0.027016	 0.01484	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36769	 87714	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36769	 87714	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36770	 36772	 6.5e-05	 0.001596	 0.11761	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36770	 37413	 0.00028	 0.004395	 0.3259	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36771	 87715	 0.18458	 0.14609	 0.00184	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36772	 36985	 0.000305	 0.003807	 0.26092	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36772	 37075	 0.000158	 0.002171	 0.1642	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36772	 46947	 0.000799	 0.009544	 0.71711	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36772	 87715	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36772	 87715	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36773	 36774	 9.5e-05	 0.00118	 0.08087	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36773	 87716	 0.00209	 0.091976	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36773	 87716	 0.00209	 0.091976	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36774	 36775	 9.7e-05	 0.001204	 0.0825	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36774	 87717	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36774	 87717	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36775	 37659	 0.000155	 0.001851	 0.13887	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36776	 37604	 0.008197	 0.045186	 0.01056	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36776	 87718	 0.004267	 0.0222	 0.00654	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36777	 36778	 0.000931	 0.009309	 0.01925	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36777	 36780	 0.001119	 0.014448	 0.03274	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36777	 37470	 0.002974	 0.039971	 0.14128	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36777	 87718	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36777	 87718	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36778	 36782	 0.001579	 0.015021	 0.02669	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36779	 37389	 0.053386	 0.20771	 0.00347	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36779	 87719	 0.025929	 0.13816	 0.00242	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36780	 36781	 0.00068	 0.009533	 0.01828	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36780	 87719	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36780	 87719	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36781	 37291	 0.006997	 0.047756	 0.08607	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36782	 37291	 0.005557	 0.037079	 0.06993	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36782	 87720	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36782	 87720	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36783	 37393	 0.006698	 0.03489	 0.00915	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36783	 37459	 0.007046	 0.031988	 0.0111	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36784	 36785	 0.054611	 0.12679	 0.00189	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36784	 88037	 0.055046	 0.24533	 0.00417	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36785	 87721	 0.026485	 0.12779	 0.00226	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36785	 87976	 0.065143	 0.34327	 0.00616	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36786	 37394	 0.009857	 0.035693	 0.00766	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36786	 37587	 0.020067	 0.068849	 0.0165	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36786	 87721	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36786	 87721	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36787	 88039	 0.095473	 0.18905	 0.00278	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36788	 36789	 0.001219	 0.005431	 0.00148	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36788	 36791	 0.00053	 0.004699	 0.00125	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36788	 87722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36788	 87722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36789	 36798	 0.015411	 0.050271	 0.01335	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36790	 36804	 0.00026	 0.003108	 0.23317	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36790	 87723	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36791	 36795	 0.004964	 0.013118	 0.00307	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87723	 36791	 0.000454	 0.005809	 0.00173	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36792	 36793	 0.011986	 0.021626	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87724	 36792	 0.014939	 0.035376	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87722	 36794	 0.012162	 0.031263	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36795	 36796	 0.004469	 0.015331	 0.00367	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36796	 87725	 0.010601	 0.042447	 0.0107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36797	 37087	 0.00133	 0.016262	 0.0334	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36797	 87725	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36797	 87725	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36798	 88000	 0.016712	 0.059077	 0.01331	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87724	 36799	 0.14599	 0.11555	 0.00145	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36800	 37650	 0.020422	 0.051342	 0.0133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36800	 87726	 0.005168	 0.032734	 0.00888	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36801	 36803	 0.017674	 0.045433	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36801	 87727	 0.007565	 0.026488	 0.00073	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36801	 88590	 0.1603	 0.42523	 0.0108	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36802	 87727	 0.067858	 0.14543	 0.00255	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36803	 36805	 0.014627	 0.019224	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36803	 87727	 0.005392	 0.020746	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36804	 37678	 0.000937	 0.013943	 0.89946	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36804	 39258	 3.4e-05	 0.000551	 0.03866	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36804	 87726	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36805	 36806	 0.039031	 0.030889	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36807	 36808	 0.002671	 0.008713	 0.00231	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36807	 36811	 0.00347	 0.009317	 0.00211	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36808	 36809	 0.001301	 0.003914	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36808	 87728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36808	 87728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36809	 87729	 0.003248	 0.009863	 0.00216	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36810	 36812	 0.000557	 0.003797	 0.00684	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87169	 36810	 0.001531	 0.009935	 0.01979	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36810	 87729	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36810	 87729	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36810	 87731	 0.001265	 0.008629	 0.01554	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87156	 36811	 0.073321	 0.19764	 0.05556	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36811	 87730	 0.003565	 0.009707	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36811	 87732	 0.003615	 0.012401	 0.00297	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36812	 36816	 0.001153	 0.008081	 0.01376	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36812	 87730	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36812	 87730	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36813	 37498	 0.003478	 0.020372	 0.00555	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87730	 36813	 0.002635	 0.017678	 0.00427	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36814	 36930	 0.000333	 0.004308	 0.27501	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36814	 87731	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36814	 87731	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87177	 36815	 0.016844	 0.058936	 0.00122	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87728	 36815	 0.018416	 0.052818	 0.00081	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36816	 87732	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36816	 87732	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36816	 87776	 0.000738	 0.009123	 0.0183	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36817	 37552	 0.035718	 0.12498	 0.00259	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36817	 87733	 0.038078	 0.14814	 0.00247	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36818	 87733	 0.044301	 0.11388	 0.00176	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36818	 87829	 0.046617	 0.15552	 0.00247	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36819	 36821	 0.004724	 0.024606	 0.00645	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36819	 87733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36819	 87733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87733	 36820	 0.11418	 0.12166	 0.00173	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36821	 37362	 0.007696	 0.039343	 0.01072	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36822	 37343	 0.18319	 0.14499	 0.00183	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87172	 36823	 0.032968	 0.084749	 0.00131	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36824	 36825	 0.011666	 0.032532	 0.00683	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36824	 87734	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36824	 87734	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36825	 39301	 0.011848	 0.033983	 0.00836	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36825	 87735	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36825	 87735	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36826	 37663	 0.016042	 0.055038	 0.01319	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36826	 87736	 0.006651	 0.02663	 0.00671	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36827	 36829	 0.000828	 0.011004	 0.02351	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36827	 37661	 0.006128	 0.041816	 0.07535	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36827	 37699	 0.003297	 0.028409	 0.05346	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36827	 87736	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87737	 36827	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87737	 36828	 0.16403	 0.1162	 0.00184	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36829	 37397	 0.001392	 0.018731	 0.03904	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36830	 36831	 0.023803	 0.13531	 0.00245	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87172	 36830	 0.099563	 0.25598	 0.00396	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36830	 87995	 0.030109	 0.199	 0.00392	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87734	 36831	 0.073299	 0.14366	 0.00215	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36832	 87738	 0.019643	 0.021395	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36832	 87741	 0.025146	 0.0199	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36833	 36836	 0.002486	 0.006569	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36833	 36844	 0.002911	 0.023387	 0.00657	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36833	 87738	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36833	 87738	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36834	 87740	 0.004686	 0.01147	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36835	 36840	 0.002038	 0.006797	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36835	 87739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36835	 87739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36836	 36838	 0.001108	 0.002877	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36836	 36851	 0.004731	 0.01623	 0.00389	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36836	 87740	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36836	 87740	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36837	 36842	 0.002671	 0.006713	 0.00174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36837	 87741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36837	 87741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36838	 87742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36838	 87742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87739	 36839	 0.019832	 0.026065	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87742	 36839	 0.007067	 0.011738	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36840	 36852	 0.001849	 0.007827	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36841	 36842	 0.000846	 0.002991	 0.00067	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36841	 36852	 0.002246	 0.007704	 0.00185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36842	 87743	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36842	 87743	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87742	 36843	 0.023179	 0.01557	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87743	 36843	 0.005173	 0.010138	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87157	 36844	 0.005656	 0.050083	 0.02751	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36845	 36849	 0.002422	 0.011545	 0.00334	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36846	 36847	 0.000516	 0.00627	 0.0203	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36846	 37428	 0.001956	 0.025649	 0.05636	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36846	 87744	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36846	 87744	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36847	 37014	 0.000628	 0.007235	 0.02612	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36848	 36850	 0.006295	 0.026644	 0.006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36848	 37015	 0.003538	 0.034563	 0.0097	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87744	 36848	 0.004024	 0.025487	 0.00692	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36849	 36850	 0.006642	 0.027424	 0.00649	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36850	 87745	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36850	 87745	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36850	 88010	 0.008677	 0.0436	 0.01135	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87151	 36851	 0.011825	 0.074917	 0.02034	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36851	 87746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36851	 87746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36852	 36853	 0.002929	 0.021637	 0.00625	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36853	 36854	 0.017201	 0.04466	 0.01084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36853	 87966	 0.002828	 0.02715	 0.0079	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36854	 37068	 0.013029	 0.046057	 0.01038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36855	 36856	 0.005113	 0.037375	 0.01103	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36855	 37685	 0.008192	 0.050841	 0.01232	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36855	 87747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36855	 87747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36856	 37056	 0.004804	 0.039265	 0.01065	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36857	 36997	 0.030527	 0.07676	 0.01989	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36857	 37685	 0.014087	 0.036573	 0.00888	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36857	 87748	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36857	 87748	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87748	 36858	 0.14614	 0.09462	 0.0018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36859	 36860	 0.013528	 0.035121	 0.00852	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36859	 37606	 0.023743	 0.061649	 0.01497	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36860	 37502	 0.019084	 0.047977	 0.01243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87720	 36860	 0.01988	 0.052546	 0.0123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36861	 37374	 0.065303	 0.18731	 0.00288	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36861	 87749	 0.046986	 0.15675	 0.00248	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36862	 37444	 0.011967	 0.042302	 0.00953	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36862	 37584	 0.006518	 0.025617	 0.0067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36862	 87749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36862	 87749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36863	 36864	 0.15837	 0.1145	 0.00174	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36863	 37373	 0.087611	 0.29233	 0.00464	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36863	 37445	 0.029539	 0.12629	 0.00285	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36865	 87753	 0.004064	 0.010087	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36866	 87750	 0.004788	 0.012308	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36866	 87754	 0.003291	 0.012802	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36867	 36868	 0.000995	 0.00271	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36867	 36878	 0.001082	 0.003017	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36867	 87750	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36867	 87750	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36868	 36869	 0.000862	 0.002681	 0.00056	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36869	 36870	 0.000807	 0.002813	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36869	 87751	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36869	 87751	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36870	 36881	 0.00114	 0.003432	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36870	 87752	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36870	 87752	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36871	 36872	 0.004209	 0.008334	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87752	 36871	 0.016149	 0.011674	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36872	 36873	 0.00202	 0.007858	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36873	 87753	 0.006271	 0.009511	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36873	 87757	 0.002491	 0.009124	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36874	 36875	 0.000995	 0.003321	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36874	 87753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36874	 87753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36874	 87758	 0.001087	 0.005659	 0.00148	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36874	 87771	 0.005429	 0.01514	 0.00318	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36875	 36876	 0.001272	 0.005251	 0.00124	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36875	 36883	 0.000417	 0.003124	 0.00076	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36875	 36885	 0.00196	 0.006831	 0.00158	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36875	 87754	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36875	 87754	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36876	 36885	 0.001461	 0.003921	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36877	 36878	 0.001856	 0.004817	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36877	 36887	 0.001352	 0.003574	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36878	 36918	 0.001841	 0.004866	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36878	 87771	 0.003979	 0.015481	 0.00413	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36879	 87755	 0.008186	 0.012773	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36880	 36901	 0.001339	 0.004066	 0.00089	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36880	 87755	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36880	 87755	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36880	 87771	 0.00162	 0.009176	 0.00227	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36881	 87756	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36881	 87756	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36881	 87771	 0.001123	 0.006036	 0.00148	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87756	 36882	 0.013423	 0.014763	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36883	 87757	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36883	 87757	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36883	 87758	 0.000335	 0.002525	 0.0007	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36884	 36893	 0.002933	 0.01141	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87754	 36884	 0.012347	 0.016069	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36886	 36913	 0.001058	 0.006014	 0.00174	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36886	 36944	 0.001203	 0.008074	 0.00195	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36888	 36890	 0.006911	 0.013235	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36888	 36894	 0.009292	 0.021572	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36888	 87765	 0.004998	 0.016672	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36889	 36890	 0.007259	 0.010578	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36889	 36903	 0.025287	 0.016371	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36891	 87761	 0.006138	 0.018475	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36891	 87772	 0.080819	 0.06396	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36892	 36895	 0.000273	 0.001913	 0.00326	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36892	 36915	 0.000866	 0.006684	 0.0136	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36892	 36921	 0.000979	 0.006744	 0.0119	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36892	 36941	 0.000367	 0.003056	 0.00953	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36892	 87758	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87759	 36892	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36893	 36896	 0.02476	 0.025283	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36893	 87762	 0.001961	 0.011921	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36894	 36909	 0.00867	 0.011829	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36894	 87761	 0.005761	 0.01922	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36895	 87760	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87761	 36895	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87761	 36896	 0.005453	 0.014018	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36897	 36944	 0.001283	 0.004011	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36897	 87762	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36897	 87762	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36898	 87763	 0.017384	 0.016302	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36899	 36900	 0.001219	 0.003318	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36899	 36918	 0.001325	 0.003502	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36899	 87763	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36899	 87763	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36900	 36901	 0.001365	 0.003806	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36901	 87764	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36901	 87764	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36902	 36929	 0.021267	 0.016831	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87764	 36902	 0.008603	 0.016861	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36902	 87770	 0.003891	 0.020732	 0.00036	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36903	 36907	 0.029904	 0.023665	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36903	 87773	 0.007277	 0.018706	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36904	 36931	 0.000953	 0.00318	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36904	 87765	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36904	 87765	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36905	 36906	 0.008846	 0.017513	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87765	 36905	 0.002473	 0.013026	 0.00023	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36906	 36907	 0.028665	 0.018557	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36906	 87774	 0.021065	 0.037863	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36908	 36937	 0.00813	 0.015934	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36909	 87766	 0.004259	 0.008433	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36910	 36931	 0.001645	 0.004415	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36910	 87766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36910	 87766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36911	 87781	 0.014365	 0.02002	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36911	 87788	 0.47892	 0.3757	 0.00482	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36912	 87767	 0.014546	 0.037391	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36913	 87768	 0.003068	 0.007966	 0.00193	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36914	 87767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36914	 87767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36914	 87768	 0.001187	 0.004754	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36915	 37617	 0.001662	 0.011087	 0.0209	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36915	 87768	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36915	 87768	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36916	 37618	 0.095733	 0.075764	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36916	 87769	 0.03563	 0.081857	 0.00124	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36917	 36918	 0.002182	 0.00561	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87768	 36917	 0.002223	 0.005771	 0.0014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36917	 87769	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36917	 87769	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36919	 36924	 0.001167	 0.00494	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36919	 36927	 0.001029	 0.004189	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36920	 87770	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36920	 87770	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36920	 87771	 0.00095	 0.003259	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36921	 36966	 0.005172	 0.034503	 0.06506	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36921	 87771	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87772	 36921	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36921	 87776	 0.000672	 0.00503	 0.01946	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87772	 36922	 0.018145	 0.01436	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36923	 36924	 0.001117	 0.004473	 0.00113	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87771	 36923	 0.000914	 0.003229	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36923	 87773	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36923	 87773	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36924	 36925	 0.00239	 0.007432	 0.00155	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36924	 87774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36924	 87774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36925	 36935	 0.005631	 0.019626	 0.00455	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36926	 87775	 0.011616	 0.009105	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36927	 87775	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36927	 87775	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36927	 87777	 0.002629	 0.010524	 0.00265	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87775	 36928	 0.021688	 0.017	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36930	 37282	 0.000212	 0.003797	 0.26952	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36930	 87776	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36930	 87776	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36931	 36940	 0.001028	 0.005354	 0.0014	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36932	 36933	 0.029658	 0.019201	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36932	 87779	 0.005408	 0.011066	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36933	 36934	 0.017858	 0.01353	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36935	 37284	 0.004392	 0.019775	 0.00526	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36935	 37432	 0.010719	 0.02833	 0.00663	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36936	 87781	 0.025531	 0.020012	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36937	 36938	 0.003897	 0.010019	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87766	 36937	 0.004829	 0.011095	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36937	 87781	 0.004274	 0.029337	 0.00053	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36938	 36939	 0.006401	 0.009806	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36940	 37284	 0.003017	 0.01542	 0.0042	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36940	 87779	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36940	 87779	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36941	 87780	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87781	 36941	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36941	 87908	 0.000612	 0.006667	 0.0269	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36942	 36944	 0.00227	 0.010219	 0.00272	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36942	 36945	 0.000889	 0.00463	 0.00121	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87780	 36942	 0.002956	 0.007951	 0.00223	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36943	 36944	 0.001926	 0.01035	 0.00255	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36943	 37290	 0.003901	 0.019269	 0.00563	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36943	 37713	 0.006393	 0.01607	 0.00416	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36945	 37290	 0.003203	 0.016682	 0.00438	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87781	 36946	 0.011188	 0.019531	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36947	 36950	 0.003507	 0.031897	 0.00805	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36947	 37469	 0.004661	 0.039974	 0.01138	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36947	 87782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36947	 87782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36948	 36949	 0.012266	 0.092759	 0.00309	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87782	 36948	 0.020457	 0.079585	 0.00133	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87782	 36948	 0.020457	 0.079585	 0.00133	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36948	 88009	 0.061379	 0.24568	 0.00519	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36949	 37473	 0.022251	 0.11571	 0.00251	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36949	 88009	 0.071807	 0.15093	 0.00275	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36950	 37604	 0.004347	 0.033885	 0.01013	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36951	 36959	 0.011739	 0.036508	 0.00762	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36951	 37296	 0.007683	 0.020306	 0.00475	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36951	 87783	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36951	 87783	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87783	 36952	 0.088573	 0.079371	 0.00162	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36953	 37565	 0.009237	 0.024412	 0.00571	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36953	 87784	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36953	 87784	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36954	 36956	 0.030907	 0.078601	 0.00124	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36954	 88024	 0.10206	 0.13414	 0.00184	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36955	 36956	 0.025633	 0.09972	 0.00166	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36955	 37341	 0.015416	 0.07438	 0.00131	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36955	 37570	 0.029337	 0.068111	 0.00101	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36956	 88024	 0.12683	 0.21368	 0.00304	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36957	 37338	 0.058369	 0.10532	 0.00152	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36957	 37340	 0.044944	 0.13789	 0.00374	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36957	 87785	 0.017884	 0.082923	 0.00172	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36958	 36959	 0.006663	 0.019299	 0.00465	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36958	 87785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36958	 87785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36960	 87786	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36960	 87786	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36960	 87981	 0.02859	 0.068915	 0.01946	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36961	 36971	 0.012985	 0.026573	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36962	 36965	 0.004684	 0.01306	 0.00274	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36962	 36970	 0.005295	 0.017839	 0.00443	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36963	 36965	 0.003997	 0.011147	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36963	 87787	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36963	 87787	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36964	 87788	 0.031017	 0.022422	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36965	 87788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36965	 87788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36965	 87789	 0.001115	 0.007888	 0.00216	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36966	 37632	 0.003574	 0.03813	 0.06914	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87145	 36966	 0.006137	 0.064345	 0.12127	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36966	 87789	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36966	 87789	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36967	 37625	 0.008809	 0.030217	 0.00724	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87789	 36967	 0.002253	 0.011931	 0.00302	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36968	 37622	 0.010769	 0.028461	 0.00666	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87789	 36968	 0.009435	 0.03179	 0.0079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87662	 36969	 0.012513	 0.066671	 0.00117	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87787	 36969	 0.046392	 0.051026	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36970	 37628	 0.005092	 0.026967	 0.00684	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87788	 36971	 0.005688	 0.027754	 0.00048	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	36972	 36988	 0.000287	 0.003706	 0.23656	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36972	 37075	 0.00018	 0.002322	 0.14819	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36972	 39287	 0.000135	 0.002314	 0.18727	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36973	 39288	 0.003776	 0.026482	 0.0451	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36973	 87790	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87791	 36973	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36973	 87825	 0.004316	 0.028792	 0.05429	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36973	 91182	 0.003538	 0.022968	 0.04576	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36973	 92229	 0.004882	 0.033134	 0.06035	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36974	 87792	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87793	 36974	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87793	 36975	 0.003965	 0.033344	 0.00988	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87164	 36976	 0.005302	 0.021226	 0.00535	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36976	 87794	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36976	 87794	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36977	 37440	 0.033949	 0.11879	 0.00246	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87794	 36977	 0.020178	 0.089416	 0.00268	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	36978	 36979	 0.051589	 0.13121	 0.00207	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36978	 37392	 0.033279	 0.059442	 0.00088	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36979	 37449	 0.095617	 0.10415	 0.00142	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87681	 36980	 0.027509	 0.09177	 0.00145	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36980	 87795	 0.048532	 0.074347	 0.00104	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36981	 36982	 0.009905	 0.026592	 0.00603	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36981	 87795	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36981	 87795	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36982	 37050	 0.014193	 0.057764	 0.01408	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87793	 36982	 0.009745	 0.067623	 0.01931	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36982	 87796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36982	 87796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87796	 36983	 0.1497	 0.11848	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36984	 36990	 0.005954	 0.031016	 0.00813	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36984	 87798	 0.002836	 0.016613	 0.00453	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36985	 36988	 0.000169	 0.002018	 0.1514	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36985	 37511	 0.001237	 0.021253	 1.6688	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36985	 87797	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36986	 36992	 0.00069	 0.006798	 0.01449	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87797	 36986	 0.000665	 0.004319	 0.0086	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36986	 87800	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36986	 87800	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36986	 87801	 0.002238	 0.014174	 0.02968	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87800	 36987	 0.091813	 0.14327	 0.00239	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	36987	 88466	 0.15956	 0.28798	 0.00416	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36988	 38406	 0.000929	 0.011103	 0.83481	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36988	 87801	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36988	 87801	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87799	 36989	 0.12993	 0.10185	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87705	 36990	 0.04547	 0.12688	 0.02665	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	36990	 87964	 0.007106	 0.036298	 0.00913	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36991	 37418	 0.006612	 0.031515	 0.00913	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36991	 87802	 0.00864	 0.045931	 0.01066	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	36992	 87802	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36992	 87802	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36993	 36997	 0.003005	 0.028849	 0.00839	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36993	 37055	 0.004097	 0.038145	 0.01182	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36994	 36995	 0.00356	 0.022929	 0.00601	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	36994	 37036	 0.007881	 0.041741	 0.01058	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36995	 36996	 0.002093	 0.020092	 0.00584	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36996	 88013	 0.010876	 0.10631	 0.02985	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	36997	 36998	 0.004801	 0.039944	 0.0121	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	36998	 36999	 0.011503	 0.038377	 0.00973	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87702	 36998	 0.005019	 0.052812	 0.02968	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	36999	 37530	 0.006211	 0.043932	 0.01206	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37000	 37645	 0.011615	 0.042059	 0.00902	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37000	 87803	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37000	 87803	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37001	 37003	 0.019795	 0.10547	 0.00185	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37001	 88053	 0.11242	 0.11355	 0.0015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37002	 37003	 0.021716	 0.11707	 0.00236	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37002	 87991	 0.018269	 0.12541	 0.00229	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37004	 37006	 0.001151	 0.005882	 0.0016	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37004	 87804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37004	 87804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37005	 87805	 0.02006	 0.022257	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37006	 37008	 0.004781	 0.021526	 0.00573	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37006	 87805	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37006	 87805	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87804	 37007	 0.019803	 0.050361	 0.0008	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37008	 37010	 0.004868	 0.025356	 0.00665	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37008	 37012	 0.010758	 0.05931	 0.01386	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87687	 37008	 0.014277	 0.051947	 0.01591	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37009	 37011	 0.03772	 0.096965	 0.0015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37010	 37012	 0.006299	 0.033358	 0.00846	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37011	 87806	 0.038534	 0.11822	 0.0032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37012	 37386	 0.002609	 0.029826	 0.0091	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37012	 87806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37012	 87806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37013	 87807	 0.000229	 0.017175	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37013	 87807	 0.000229	 0.017175	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87161	 37014	 0.000674	 0.008011	 0.01453	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87807	 37014	 0.00077	 0.010228	 0.02185	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87696	 37015	 0.003652	 0.035066	 0.0102	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37016	 37254	 6.4e-05	 0.001004	 0.09755	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37016	 37474	 5.1e-05	 0.00088	 0.07119	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37017	 37030	 0.001141	 0.017201	 0.03959	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37017	 37475	 0.000228	 0.003466	 0.00786	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87153	 37017	 0.001348	 0.013682	 0.03422	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37017	 87808	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87809	 37017	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87809	 37018	 0.015138	 0.031816	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37018	 87987	 0.014688	 0.037757	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37019	 37020	 0.000445	 0.002983	 0.00072	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37019	 37024	 0.001477	 0.009656	 0.00246	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37020	 37023	 0.003263	 0.008622	 0.00202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87808	 37020	 0.003198	 0.016579	 0.00405	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37020	 87810	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37020	 87810	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87810	 37021	 0.01834	 0.019295	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37022	 37023	 0.002485	 0.006767	 0.00149	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37022	 37026	 0.003128	 0.008267	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37024	 37025	 0.002189	 0.015478	 0.00425	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37025	 37477	 0.0047	 0.03381	 0.00896	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37025	 87812	 0.009051	 0.03105	 0.00744	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37026	 87811	 0.00797	 0.020036	 0.00519	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37027	 87811	 0.001551	 0.014082	 0.00459	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37028	 37351	 0.007312	 0.029276	 0.00738	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37028	 37518	 0.0099	 0.063777	 0.01672	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37028	 37523	 0.007025	 0.036595	 0.0096	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37028	 87812	 0.002306	 0.02636	 0.00804	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37029	 37033	 0.013733	 0.021921	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37030	 37031	 0.000207	 0.002696	 0.01015	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37030	 87811	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37030	 87811	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37031	 87812	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87813	 37031	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37031	 88064	 0.006992	 0.071573	 0.22818	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87812	 37032	 0.001438	 0.005082	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37032	 87814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37032	 87814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87814	 37033	 0.005852	 0.016784	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87814	 37034	 0.01034	 0.026296	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37034	 87931	 0.062207	 0.14441	 0.00275	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37035	 37055	 0.007873	 0.042391	 0.01165	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87812	 37035	 0.00942	 0.043935	 0.01088	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87812	 37036	 0.002945	 0.033632	 0.016	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87809	 37037	 0.038186	 0.047401	 0.00103	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37038	 37384	 0.039554	 0.13196	 0.00209	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37038	 87815	 0.017425	 0.067789	 0.00113	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37039	 37040	 0.003886	 0.019198	 0.00561	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37039	 37385	 0.007802	 0.035795	 0.00917	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37039	 87815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37039	 87815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37040	 37048	 0.010866	 0.056606	 0.01485	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37041	 37047	 0.009894	 0.067914	 0.00124	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37041	 88023	 0.027778	 0.17079	 0.00308	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37042	 37045	 0.11427	 0.090436	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37043	 37046	 0.003327	 0.020443	 0.00747	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37044	 37046	 0.004221	 0.021576	 0.00588	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37044	 37377	 0.007164	 0.036623	 0.00998	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37044	 87816	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37044	 87816	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87816	 37045	 0.021696	 0.042956	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37046	 87817	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37046	 87817	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37046	 88460	 0.032707	 0.13514	 0.03201	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87817	 37047	 0.022106	 0.13591	 0.00245	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37047	 87818	 0.054995	 0.12768	 0.0019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37048	 38915	 0.011625	 0.060564	 0.01589	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37048	 87818	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37048	 87818	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37049	 37555	 0.00888	 0.034903	 0.00913	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37049	 87819	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37049	 87819	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37050	 37051	 0.008797	 0.035223	 0.00887	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37051	 37053	 0.010345	 0.028849	 0.00606	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87819	 37052	 0.15828	 0.12527	 0.00158	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37052	 87820	 0.11258	 0.088251	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87156	 37053	 0.040133	 0.13533	 0.03367	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37053	 87820	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37053	 87820	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37054	 37058	 0.03235	 0.14254	 0.00248	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87803	 37054	 0.037427	 0.11482	 0.00311	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37055	 37056	 0.006886	 0.027064	 0.00708	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37055	 37354	 0.007238	 0.044917	 0.01088	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37056	 37057	 0.006493	 0.029789	 0.00763	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87664	 37057	 0.022807	 0.05734	 0.01486	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37057	 87821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37057	 87821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87821	 37058	 0.026097	 0.11565	 0.00347	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37059	 87822	 0.013964	 0.023322	 0.0004	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37060	 37061	 0.000387	 0.001549	 0.00039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37060	 37064	 0.002193	 0.007643	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37061	 37062	 0.000406	 0.001544	 0.00043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37062	 37063	 0.000421	 0.001656	 0.00043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37062	 87822	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37062	 87822	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37063	 37065	 0.00057	 0.003824	 0.00092	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37064	 37068	 0.010625	 0.041336	 0.01104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87157	 37065	 0.005009	 0.04549	 0.01483	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37066	 37067	 0.047952	 0.094943	 0.00139	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37067	 87823	 0.024673	 0.094923	 0.00162	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87157	 37068	 0.001999	 0.022849	 0.00697	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37068	 87823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37068	 87823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37069	 37661	 0.001985	 0.012887	 0.02567	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37070	 37071	 0.009213	 0.024348	 0.0057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87717	 37070	 0.015549	 0.043362	 0.0091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37071	 37073	 0.009039	 0.027448	 0.00601	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87146	 37071	 0.012865	 0.064649	 0.01683	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37071	 87824	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37071	 87824	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37072	 37073	 0.004298	 0.022763	 0.00577	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37072	 37537	 0.003238	 0.016554	 0.00451	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37073	 37629	 0.005585	 0.024886	 0.00676	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87824	 37074	 0.086905	 0.14246	 0.00252	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37075	 87825	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37075	 87825	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37076	 37078	 0.009877	 0.033883	 0.00812	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37076	 37429	 0.016234	 0.042906	 0.01004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37076	 37430	 0.016927	 0.046088	 0.01015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37076	 37696	 0.014775	 0.041205	 0.00865	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37077	 37078	 0.010888	 0.028776	 0.00674	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37077	 88070	 0.009476	 0.031613	 0.00802	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37078	 37079	 0.001507	 0.009047	 0.00274	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37078	 37082	 0.010416	 0.027528	 0.00644	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87723	 37078	 0.04456	 0.15029	 0.0374	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37079	 37080	 0.002562	 0.017585	 0.00513	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37079	 37081	 0.002099	 0.005276	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37080	 37085	 0.003699	 0.028135	 0.00884	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37081	 37082	 0.005597	 0.018858	 0.00469	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37081	 37083	 0.001166	 0.007383	 0.002	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37082	 37509	 0.012093	 0.037609	 0.00785	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37083	 37084	 0.001889	 0.014231	 0.00395	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37084	 37086	 0.005929	 0.035856	 0.00915	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37084	 87828	 0.010593	 0.027995	 0.00655	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37085	 87826	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37085	 87826	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87703	 37086	 0.00556	 0.045442	 0.01233	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37086	 87827	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37086	 87827	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37087	 37510	 0.001286	 0.016067	 0.03156	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37087	 87828	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37087	 87828	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37088	 37374	 0.075411	 0.17509	 0.0026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37088	 87829	 0.037004	 0.14396	 0.0024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37089	 37448	 0.10386	 0.18133	 0.00281	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37090	 37359	 0.012029	 0.052363	 0.01492	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37090	 87829	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37090	 87829	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37091	 87830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37091	 87830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37092	 37093	 0.005047	 0.009993	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37092	 37106	 0.010078	 0.011085	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87830	 37092	 0.003666	 0.017887	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37092	 87835	 0.017531	 0.040701	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37094	 87831	 0.006168	 0.023996	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37095	 37097	 0.011834	 0.009365	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37096	 37097	 0.010587	 0.006854	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37097	 37099	 0.004361	 0.006804	 0.00011	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37097	 87831	 0.004333	 0.015162	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37098	 37100	 0.000699	 0.003703	 0.00094	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37098	 37104	 0.000565	 0.002518	 0.00068	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37100	 37101	 0.000652	 0.002609	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37100	 87831	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37100	 87831	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37102	 37103	 0.008114	 0.008925	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87831	 37102	 0.003784	 0.015141	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37102	 87905	 0.006293	 0.018048	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37104	 37105	 0.000455	 0.001823	 0.00046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37105	 87832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37105	 87832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37107	 37108	 0.00278	 0.009275	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87830	 37107	 0.002466	 0.010865	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87832	 37108	 0.002656	 0.010219	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37108	 87836	 0.004325	 0.014273	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37109	 37275	 4.6e-05	 0.000854	 0.06759	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37109	 37281	 8.9e-05	 0.001369	 0.1053	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37109	 87833	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87835	 37110	 0.002319	 0.014257	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37110	 87837	 0.006251	 0.013138	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37111	 37124	 0.000554	 0.002884	 0.00076	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87834	 37111	 0.000628	 0.004706	 0.00115	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37111	 87836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37111	 87836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87834	 37112	 0.001531	 0.005159	 0.00128	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37112	 87837	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37112	 87837	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37113	 37114	 0.005732	 0.01008	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87837	 37113	 0.005679	 0.01217	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37113	 87840	 0.006429	 0.028647	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37115	 37116	 0.001094	 0.00305	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37115	 37117	 0.000668	 0.001733	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37116	 37279	 0.001252	 0.003146	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37117	 37118	 0.000616	 0.001549	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37118	 37121	 0.001576	 0.004291	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37119	 37122	 0.000291	 0.002629	 0.00518	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37119	 37272	 0.000321	 0.002033	 0.00426	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37119	 87838	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37119	 87838	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87838	 37120	 0.000722	 0.002432	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37120	 87839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37120	 87839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37121	 37123	 0.000788	 0.002655	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37121	 87840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37121	 87840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37122	 37262	 0.000117	 0.001344	 0.00485	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37122	 87841	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37122	 87841	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37122	 87906	 0.000493	 0.004695	 0.00834	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37123	 37129	 0.00129	 0.003511	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37123	 37157	 0.000695	 0.004071	 0.00111	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37124	 87842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37124	 87842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87834	 37125	 0.000975	 0.003904	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37125	 87843	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37125	 87843	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87843	 37126	 0.00253	 0.006502	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37127	 37135	 0.000355	 0.001847	 0.00048	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87834	 37127	 0.000811	 0.004225	 0.00111	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87834	 37128	 0.002846	 0.007641	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37129	 87899	 0.005844	 0.015445	 0.00362	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87833	 37130	 0.000213	 0.003328	 0.00715	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37130	 87844	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87845	 37130	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87843	 37131	 0.005242	 0.013476	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37132	 37133	 0.006437	 0.006772	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87845	 37133	 0.006663	 0.015467	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37134	 37135	 0.000334	 0.001651	 0.00048	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37134	 37137	 0.000507	 0.003214	 0.00087	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87834	 37134	 0.001328	 0.006031	 0.00209	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37136	 37138	 0.008828	 0.006986	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37137	 37151	 0.000485	 0.002607	 0.00064	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37137	 87846	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37137	 87846	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87846	 37138	 0.006596	 0.012927	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37139	 37162	 0.002772	 0.007197	 0.00175	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87834	 37139	 0.001918	 0.011233	 0.00306	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37139	 87847	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37139	 87847	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37140	 37144	 0.000508	 0.002568	 0.00071	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37140	 37145	 0.000816	 0.003855	 0.00123	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87844	 37140	 0.000597	 0.00583	 0.00164	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37141	 37145	 0.001403	 0.007429	 0.00188	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37141	 37171	 0.001963	 0.010032	 0.00273	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37142	 37185	 0.014905	 0.037905	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37143	 37148	 0.00844	 0.006679	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37143	 87849	 0.015838	 0.011652	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37144	 37145	 0.000387	 0.002017	 0.00053	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37144	 87848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37144	 87848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37145	 87849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37145	 87849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87849	 37146	 0.015087	 0.014038	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37147	 37154	 0.000795	 0.004271	 0.00105	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37147	 37192	 0.001133	 0.005692	 0.00148	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37147	 87850	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37147	 87850	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87848	 37148	 0.010211	 0.013919	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37149	 37150	 0.000614	 0.002597	 0.00058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37149	 37154	 0.001761	 0.009708	 0.00227	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87844	 37149	 0.00088	 0.004586	 0.0012	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37150	 37152	 0.001124	 0.004574	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37151	 37152	 0.000574	 0.003164	 0.00074	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37152	 37153	 0.000408	 0.002125	 0.00056	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37152	 37156	 0.000717	 0.002919	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37153	 37155	 0.000573	 0.00316	 0.00074	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37154	 37155	 0.000621	 0.003236	 0.00085	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37154	 37164	 0.001842	 0.006317	 0.00151	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37155	 87851	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37155	 87851	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37156	 37163	 0.001114	 0.003481	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37156	 87852	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37156	 87852	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37157	 37158	 0.002005	 0.00559	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87841	 37157	 0.000626	 0.003963	 0.00108	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37158	 37258	 0.002002	 0.007869	 0.00206	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87154	 37158	 0.00321	 0.040385	 0.01251	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37158	 87853	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37158	 87853	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37158	 87907	 0.001137	 0.005118	 0.00136	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37159	 37160	 0.000596	 0.003105	 0.00081	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37159	 37245	 0.001679	 0.008891	 0.00225	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37160	 37258	 0.000739	 0.003851	 0.00101	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37160	 87854	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37160	 87854	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87847	 37161	 0.00469	 0.024991	 0.00044	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87852	 37161	 0.011706	 0.023176	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37162	 37217	 0.001405	 0.00482	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37163	 87877	 0.000989	 0.00309	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37164	 37192	 0.001063	 0.00586	 0.00137	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37164	 37200	 0.000755	 0.002642	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87850	 37165	 0.009581	 0.014677	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37166	 37193	 0.001166	 0.003999	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37166	 87855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37166	 87855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37167	 87868	 0.010979	 0.028224	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37168	 87856	 0.006383	 0.014479	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37168	 87861	 0.002047	 0.011634	 0.00021	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37169	 37170	 0.003654	 0.008197	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37169	 87860	 0.005859	 0.015061	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37170	 87860	 0.008967	 0.02305	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37170	 87862	 0.005882	 0.022628	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37171	 37172	 0.001072	 0.005677	 0.00144	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37171	 87856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37171	 87856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37172	 37177	 0.001342	 0.006156	 0.00158	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37172	 87857	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37172	 87857	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37173	 37190	 0.000339	 0.002315	 0.00417	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37173	 87858	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87859	 37173	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37174	 37175	 0.000821	 0.004523	 0.00106	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87858	 37174	 0.000765	 0.003912	 0.00107	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37174	 87860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37174	 87860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37175	 37194	 0.000943	 0.004453	 0.00143	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37175	 87861	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37175	 87861	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37176	 37183	 0.002016	 0.010678	 0.00271	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37176	 37635	 0.003811	 0.017483	 0.00448	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37177	 87862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37177	 87862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37178	 87863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37178	 87863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37178	 87864	 0.00305	 0.007839	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37179	 37184	 0.011875	 0.039187	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37179	 37546	 0.020874	 0.047956	 0.00073	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37180	 37184	 0.025654	 0.027396	 0.00058	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37180	 37186	 0.02513	 0.031576	 0.00048	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37181	 37191	 0.000224	 0.002538	 0.00947	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87145	 37181	 0.002968	 0.028507	 0.06401	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37181	 87864	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87865	 37181	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87865	 37182	 0.017604	 0.040871	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37182	 87866	 0.00915	 0.021022	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37183	 87866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37183	 87866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37183	 87867	 0.001563	 0.007723	 0.00226	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37184	 37185	 0.003009	 0.013407	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87849	 37185	 0.014719	 0.079345	 0.0016	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87857	 37185	 0.004587	 0.015303	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37186	 37187	 0.004434	 0.014632	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87862	 37186	 0.002552	 0.01569	 0.00028	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87863	 37186	 0.004817	 0.019277	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87863	 37187	 0.00496	 0.00982	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37188	 37206	 0.002219	 0.009031	 0.0022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37188	 87867	 0.001964	 0.008109	 0.00192	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87859	 37189	 0.008589	 0.036888	 0.00067	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87862	 37189	 0.009771	 0.028734	 0.00059	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87865	 37189	 0.004373	 0.023399	 0.00071	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37190	 37191	 0.000137	 0.001665	 0.00621	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37190	 37214	 0.00071	 0.007737	 0.03122	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37191	 87867	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37191	 87867	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37192	 37193	 0.000497	 0.002589	 0.00068	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37193	 37194	 0.0005	 0.002554	 0.0007	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37193	 37199	 0.001719	 0.005898	 0.00141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37193	 87868	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37193	 87868	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37195	 37196	 0.000731	 0.003451	 0.0011	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87858	 37195	 0.001307	 0.006922	 0.00175	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37195	 87869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37195	 87869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37196	 37210	 0.000891	 0.00464	 0.00122	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37197	 37198	 0.013026	 0.017121	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87859	 37197	 0.006671	 0.025951	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37197	 87873	 0.041672	 0.04209	 0.00056	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37199	 37201	 0.000719	 0.003554	 0.00104	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37199	 87870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37199	 87870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37200	 37201	 0.000759	 0.004018	 0.00102	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37200	 87877	 0.000338	 0.003861	 0.00118	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37202	 37203	 0.000451	 0.005562	 0.0018	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37202	 37216	 0.000744	 0.003876	 0.00102	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37202	 87871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37202	 87871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37202	 87907	 0.001421	 0.010878	 0.00802	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37203	 37204	 0.00075	 0.003973	 0.00101	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37203	 37213	 0.001229	 0.006073	 0.00177	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37203	 87872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37203	 87872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37204	 37210	 0.00073	 0.003732	 0.00102	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87872	 37205	 0.007443	 0.013632	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37206	 37207	 0.001792	 0.008135	 0.00282	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87834	 37206	 0.00996	 0.050916	 0.01388	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37206	 87873	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37206	 87873	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37207	 37209	 0.001278	 0.004858	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37207	 37212	 0.000752	 0.003917	 0.00103	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37208	 37209	 0.000897	 0.00475	 0.0012	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37208	 37224	 0.00063	 0.003335	 0.00085	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37209	 87874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37209	 87874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37210	 87875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37210	 87875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87875	 37211	 0.008276	 0.014447	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37211	 87876	 0.021451	 0.017656	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37212	 37213	 0.000664	 0.003571	 0.00088	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37212	 87876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37212	 87876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37214	 37215	 9.3e-05	 0.001237	 0.00444	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37214	 87877	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37214	 87877	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37215	 37244	 0.000239	 0.003179	 0.00679	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37215	 87878	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37215	 87878	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37215	 87906	 0.00029	 0.004399	 0.00997	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87878	 37216	 0.001046	 0.005448	 0.00143	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37217	 37218	 0.001072	 0.004362	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37218	 87886	 0.000713	 0.004247	 0.00112	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37219	 37220	 0.000782	 0.004141	 0.00105	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37219	 87886	 0.000808	 0.004128	 0.00113	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37220	 87879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37220	 87879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37221	 37223	 0.001012	 0.005269	 0.00138	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37221	 37248	 0.001085	 0.007095	 0.0018	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37221	 87880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37221	 87880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37222	 37231	 0.010328	 0.02024	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87874	 37222	 0.007046	 0.018112	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37222	 87881	 0.010285	 0.03674	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37222	 87883	 0.0128	 0.032904	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37223	 37224	 0.000798	 0.004079	 0.00111	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37223	 87881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37223	 87881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37224	 87882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37224	 87882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37225	 37226	 0.0008	 0.004045	 0.00113	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37225	 37248	 0.001496	 0.007791	 0.00204	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37226	 37228	 0.001144	 0.005248	 0.00134	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87880	 37227	 0.010545	 0.035176	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87882	 37227	 0.00481	 0.014755	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37227	 87883	 0.00547	 0.010171	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37228	 87883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37228	 87883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37229	 37230	 0.004691	 0.015481	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87874	 37229	 0.003433	 0.019513	 0.00035	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37230	 37232	 0.008334	 0.0165	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87873	 37232	 0.042428	 0.046666	 0.00062	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87873	 37233	 0.022083	 0.073668	 0.00117	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37233	 88046	 0.045876	 0.1054	 0.0016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37233	 88049	 0.087722	 0.1737	 0.00255	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37234	 37238	 0.030463	 0.044389	 0.001	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87873	 37235	 0.074209	 0.097535	 0.00134	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37236	 87888	 0.012953	 0.016857	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37237	 37240	 0.015935	 0.012491	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37237	 87888	 0.017334	 0.03432	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37238	 37239	 0.027465	 0.034954	 0.00051	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87883	 37238	 0.005254	 0.017526	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37240	 87884	 0.018828	 0.017343	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37241	 37242	 0.002248	 0.005941	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37241	 87884	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37241	 87884	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37242	 87885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37242	 87885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87885	 37243	 0.019029	 0.012319	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37244	 87886	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37244	 87886	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37244	 87906	 0.000116	 0.001816	 0.0039	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37245	 37247	 0.0012	 0.006449	 0.00159	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37246	 87887	 0.032393	 0.025635	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37247	 37248	 0.001245	 0.006482	 0.0017	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37248	 37249	 0.001148	 0.003868	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37248	 87887	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37248	 87887	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37248	 87907	 0.00116	 0.012834	 0.00385	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37249	 87888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37249	 87888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87853	 37250	 0.010165	 0.057784	 0.00105	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87885	 37250	 0.011227	 0.034442	 0.00093	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87854	 37251	 0.010873	 0.027949	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37252	 87891	 0.021233	 0.042039	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37253	 37257	 2.7e-05	 0.000541	 0.03623	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37253	 37266	 2e-05	 0.000395	 0.02648	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37254	 87889	 0.00209	 0.091976	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37254	 87889	 0.00209	 0.091976	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37255	 37256	 2.2e-05	 0.000289	 0.01844	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37255	 37266	 2.2e-05	 0.000275	 0.01887	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37256	 87890	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37257	 87892	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37257	 87892	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37258	 37260	 0.000536	 0.004506	 0.00133	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37259	 37260	 0.000532	 0.005376	 0.00158	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87890	 37259	 0.000818	 0.009345	 0.00285	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37260	 87893	 0.001586	 0.006454	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37261	 37269	 0.015534	 0.015689	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37262	 37270	 0.00013	 0.001578	 0.00511	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37262	 87893	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37262	 87893	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37263	 37267	 9e-05	 0.000877	 0.00305	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87153	 37263	 0.000701	 0.009537	 0.01941	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37263	 87894	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37263	 87894	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37264	 37266	 1e-05	 0.000287	 0.02147	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37264	 37277	 1.4e-05	 0.000362	 0.02688	 2893.0	 3037.6	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37264	 87895	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37264	 87895	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87894	 37265	 0.000586	 0.003233	 0.00076	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37265	 87896	 0.000863	 0.004734	 0.00125	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37266	 87896	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37266	 87896	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37267	 37270	 0.000161	 0.001535	 0.00561	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37267	 87897	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37267	 87897	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37268	 37271	 0.000926	 0.004816	 0.00142	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87897	 37268	 0.00121	 0.003197	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37268	 87904	 0.001133	 0.004932	 0.00141	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37269	 87901	 0.006321	 0.014673	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37270	 87898	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37270	 87898	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37271	 37274	 0.001023	 0.004096	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87833	 37272	 0.000369	 0.004761	 0.01079	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37272	 87899	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87900	 37272	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37272	 87902	 0.000106	 0.001199	 0.00447	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87900	 37273	 0.007968	 0.013422	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37274	 37276	 0.001824	 0.006605	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37274	 87901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37274	 87901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37275	 87902	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87903	 37275	 0.000243	 0.018209	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87162	 37276	 0.001451	 0.005811	 0.00146	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87898	 37276	 0.004125	 0.010902	 0.00255	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37277	 87904	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37277	 87904	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87899	 37278	 0.001525	 0.005138	 0.00128	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37278	 87905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37278	 87905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87899	 37279	 0.001621	 0.006491	 0.00164	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87851	 37280	 0.01557	 0.011029	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37281	 87906	 9.6e-05	 0.007684	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87907	 37281	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37282	 87908	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87909	 37282	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37283	 37284	 0.002136	 0.010917	 0.00298	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37283	 37287	 0.001449	 0.00918	 0.00249	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87909	 37284	 0.003883	 0.020227	 0.00531	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37285	 87911	 0.061277	 0.066744	 0.00091	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87163	 37286	 0.000695	 0.007205	 0.01552	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87163	 37286	 0.000695	 0.007205	 0.01552	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87908	 37286	 0.000396	 0.005364	 0.02393	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37286	 87910	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37286	 87910	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37287	 37288	 0.000452	 0.005065	 0.00161	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87909	 37287	 0.003571	 0.014035	 0.00367	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37287	 87911	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37287	 87911	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37288	 37289	 0.000384	 0.002781	 0.0015	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87910	 37289	 0.00135	 0.009502	 0.0054	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87909	 37290	 0.001384	 0.013287	 0.00387	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37291	 37294	 0.001327	 0.008615	 0.01716	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37291	 37372	 0.002009	 0.018161	 0.03581	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37291	 87912	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37291	 87912	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87912	 37292	 0.17544	 0.13753	 0.00177	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37293	 87914	 0.055294	 0.077063	 0.00132	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37294	 38930	 0.013274	 0.14743	 0.283	 491.0	 515.5	 540.1	 0.0	 0.0	 0	 -30.0	 30.0;
	37294	 38930	 0.013274	 0.14743	 0.283	 491.0	 515.5	 540.1	 0.0	 0.0	 0	 -30.0	 30.0;
	37294	 87913	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87914	 37294	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37294	 95343	 0.004817	 0.047385	 0.1628	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37295	 87915	 0.056745	 0.07044	 0.00154	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37296	 87915	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37296	 87915	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37296	 87981	 0.011344	 0.041078	 0.00881	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37297	 87916	 0.003635	 0.006263	 0.0001	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37298	 37305	 0.0003	 0.001653	 0.0006	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37298	 37336	 0.000418	 0.002175	 0.00057	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37298	 87916	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37298	 87916	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37299	 37300	 0.001293	 0.005285	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37299	 87924	 0.00106	 0.006028	 0.00011	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87710	 37300	 0.003058	 0.012236	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87710	 37301	 0.006918	 0.019632	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37302	 37303	 0.007659	 0.009507	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87714	 37302	 0.014409	 0.012911	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37303	 87917	 0.002239	 0.009976	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37304	 37324	 0.000783	 0.003313	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37304	 87917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37304	 87917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37305	 37322	 0.000419	 0.002655	 0.00072	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37306	 37307	 0.001078	 0.005913	 0.00156	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37306	 87918	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37306	 87918	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37307	 37308	 0.003858	 0.010377	 0.00291	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37307	 37326	 0.004985	 0.018948	 0.0053	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37307	 37334	 0.002116	 0.013007	 0.00375	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87673	 37307	 0.00065	 0.008177	 0.00253	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37308	 37311	 0.009903	 0.026172	 0.00613	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37309	 87926	 0.017722	 0.029854	 0.00043	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37310	 37553	 0.018049	 0.047706	 0.01117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37312	 87923	 0.018016	 0.018396	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37313	 37314	 0.001789	 0.016453	 0.00033	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37313	 87927	 0.002598	 0.017361	 0.00038	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87678	 37314	 0.008795	 0.032518	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87678	 37314	 0.008795	 0.032518	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87677	 37315	 0.00141	 0.004912	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37315	 87919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37315	 87919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87677	 37316	 0.002853	 0.007658	 0.00174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87919	 37317	 0.002823	 0.017157	 0.00032	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37317	 87920	 0.005683	 0.016298	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37318	 37319	 0.000725	 0.005458	 0.00151	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37318	 37330	 0.000769	 0.004613	 0.0014	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87677	 37318	 0.00203	 0.01056	 0.00311	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37318	 87920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37318	 87920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37319	 37320	 0.000506	 0.003695	 0.00109	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37319	 87921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37319	 87921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37320	 37325	 0.000596	 0.004696	 0.00137	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37320	 87922	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37320	 87922	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37321	 37322	 0.00058	 0.004344	 0.00106	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37321	 37335	 0.000599	 0.004586	 0.00123	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37322	 87923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37322	 87923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37323	 37324	 0.000539	 0.002708	 0.0007	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37323	 87924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37323	 87924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37324	 37325	 0.000606	 0.00436	 0.00116	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37327	 37329	 0.003004	 0.016881	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87921	 37327	 0.00259	 0.014522	 0.0004	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87918	 37328	 0.012819	 0.017474	 0.00039	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87918	 37329	 0.007624	 0.03397	 0.00058	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87671	 37330	 0.000896	 0.007157	 0.00176	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37330	 87925	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37330	 87925	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87925	 37331	 0.007256	 0.012118	 0.00021	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37332	 87926	 0.023941	 0.025567	 0.00054	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37333	 37334	 0.003397	 0.011652	 0.00279	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37334	 87926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37334	 87926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87677	 37335	 0.001696	 0.016802	 0.00515	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37335	 87927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37335	 87927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37336	 37337	 0.000486	 0.002188	 0.00058	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37336	 87928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37336	 87928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37338	 37339	 0.070387	 0.13937	 0.00205	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37339	 37340	 0.041341	 0.11858	 0.00182	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37340	 37342	 0.036605	 0.092722	 0.00184	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37340	 87942	 0.044639	 0.19559	 0.00421	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37341	 37381	 0.019108	 0.097228	 0.0022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37342	 37560	 0.0263	 0.10232	 0.00171	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37343	 37348	 0.12992	 0.13123	 0.00174	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37344	 37345	 0.11757	 0.12932	 0.00173	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37345	 87929	 0.032825	 0.08348	 0.00132	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37346	 37347	 0.008292	 0.028447	 0.00682	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37346	 37701	 0.003792	 0.01373	 0.00295	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37346	 87929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37346	 87929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37346	 87935	 0.004353	 0.017428	 0.00439	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37347	 37350	 0.007779	 0.030577	 0.008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37348	 37349	 0.012821	 0.026237	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37349	 87930	 0.035097	 0.10067	 0.00155	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37350	 37707	 0.006617	 0.036475	 0.00853	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37350	 87930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37350	 87930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37351	 37352	 0.005942	 0.026755	 0.00712	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37352	 37354	 0.005492	 0.030275	 0.00708	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37352	 87931	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37352	 87931	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87803	 37353	 0.2441	 0.19322	 0.00243	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37355	 87932	 0.12096	 0.087444	 0.00133	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37356	 37603	 0.059667	 0.1413	 0.00258	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37356	 87933	 0.030363	 0.1353	 0.0023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37357	 88031	 0.23652	 0.18543	 0.00238	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37358	 87933	 0.014151	 0.027734	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37359	 37360	 0.001015	 0.007176	 0.00197	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37359	 87932	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37359	 87932	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37360	 37361	 0.00095	 0.010501	 0.00315	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37360	 87933	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37360	 87933	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37361	 87935	 0.002251	 0.024893	 0.00747	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37362	 37364	 0.004229	 0.026784	 0.00727	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37363	 87936	 0.073169	 0.12326	 0.00176	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37364	 87934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37364	 87934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37364	 87935	 0.001283	 0.01232	 0.00358	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37365	 87935	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87936	 37365	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37365	 88725	 0.009986	 0.097209	 0.34668	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37366	 37367	 0.021189	 0.089679	 0.00169	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87936	 37367	 0.017705	 0.065464	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87158	 37368	 0.000551	 0.008413	 0.00271	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87720	 37368	 0.004339	 0.038415	 0.0211	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37368	 87937	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37368	 87937	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87937	 37369	 0.17242	 0.12465	 0.00189	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37370	 37371	 0.22952	 0.18167	 0.00229	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37371	 87939	 0.062259	 0.099381	 0.00229	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37372	 87938	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87939	 37372	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37373	 37374	 0.027933	 0.12308	 0.00214	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37373	 37375	 0.026538	 0.11693	 0.00203	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37373	 37551	 0.064496	 0.16717	 0.00316	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37373	 88074	 0.02564	 0.15765	 0.00284	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87733	 37376	 0.061279	 0.23937	 0.00531	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37376	 87940	 0.029153	 0.1292	 0.00388	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37377	 37378	 0.008448	 0.04541	 0.01117	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37378	 37561	 0.005471	 0.03016	 0.00705	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37378	 87940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37378	 87940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37379	 37380	 0.003671	 0.01973	 0.00485	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37379	 37571	 0.00465	 0.02563	 0.00599	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37379	 87941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37379	 87941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37380	 37383	 0.004741	 0.023984	 0.00668	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37381	 87942	 0.011307	 0.07672	 0.00143	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37382	 37384	 0.026098	 0.0592	 0.00118	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37382	 87942	 0.028653	 0.073657	 0.00114	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37383	 38937	 0.027293	 0.1731	 0.04707	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37383	 87942	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37383	 87942	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87942	 37384	 0.054599	 0.14036	 0.00217	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37384	 88729	 0.24003	 0.61772	 0.00957	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37385	 87943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37385	 87943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37386	 37387	 0.003053	 0.038404	 0.0119	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37387	 37471	 0.006015	 0.078007	 0.03088	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37387	 87944	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37387	 87944	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37388	 87983	 0.12436	 0.14578	 0.00254	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87944	 37389	 0.033704	 0.11801	 0.00327	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37390	 37391	 0.006572	 0.022142	 0.0055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37390	 37394	 0.010108	 0.034675	 0.00831	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87164	 37391	 0.010642	 0.061155	 0.01733	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37391	 87945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37391	 87945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87945	 37392	 0.020702	 0.080536	 0.00134	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37394	 37585	 0.016508	 0.046038	 0.00966	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37394	 87946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37394	 87946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37395	 88033	 0.085063	 0.1433	 0.00204	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37396	 87948	 0.12943	 0.21589	 0.00314	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87175	 37397	 0.001833	 0.012371	 0.02278	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37397	 87947	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87948	 37397	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37398	 37400	 0.0037	 0.027726	 0.00676	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37398	 87949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37398	 87949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37398	 88065	 0.011468	 0.047354	 0.0112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37399	 37401	 0.014355	 0.04837	 0.01202	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37400	 37514	 0.008407	 0.067551	 0.01899	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37400	 87950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37400	 87950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37400	 87951	 0.004049	 0.031496	 0.00818	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87723	 37401	 0.019318	 0.10235	 0.02596	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37401	 87951	 0.009407	 0.031697	 0.00788	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37402	 37403	 0.001443	 0.009791	 0.01782	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37402	 87951	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37402	 87951	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37402	 88001	 0.005762	 0.04968	 0.09356	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37403	 39342	 0.00164	 0.013694	 0.02378	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37403	 88064	 0.003234	 0.037765	 0.07829	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87175	 37404	 0.001237	 0.01156	 0.02131	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37404	 87952	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37404	 87952	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37405	 37406	 0.000862	 0.011463	 0.02449	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37405	 87953	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37405	 87953	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37406	 37465	 0.002398	 0.016815	 0.02863	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87173	 37406	 0.001343	 0.009718	 0.04034	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37406	 88557	 0.009643	 0.065856	 0.1188	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37407	 37416	 0.000441	 0.003006	 0.00541	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87173	 37407	 0.003754	 0.025866	 0.04567	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37407	 87954	 0.0002	 0.001833	 0.00723	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37407	 87977	 0.002307	 0.015734	 0.02833	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37408	 37411	 2.8e-05	 0.000368	 0.02347	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37408	 87954	 9.6e-05	 0.007684	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87955	 37408	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37409	 37410	 0.008787	 0.022588	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87948	 37410	 0.12024	 0.27922	 0.00415	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37410	 87956	 0.003403	 0.02092	 0.00038	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37411	 37413	 2.1e-05	 0.000262	 0.01795	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37412	 37415	 0.001534	 0.006242	 0.00152	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87955	 37412	 0.00066	 0.004425	 0.00107	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37412	 87961	 0.003742	 0.020627	 0.00482	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37413	 37421	 6.6e-05	 0.000819	 0.05613	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37413	 87956	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37413	 87956	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37414	 37419	 0.014587	 0.037498	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87956	 37414	 0.004895	 0.021568	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37414	 87962	 0.006701	 0.027972	 0.00081	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37416	 37417	 0.000822	 0.005336	 0.01063	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37416	 37420	 0.001276	 0.008948	 0.01523	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37416	 87957	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37416	 87957	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37417	 87958	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37417	 87958	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87958	 37418	 0.00752	 0.019874	 0.00465	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37419	 87960	 0.01015	 0.023318	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37420	 37423	 0.001119	 0.007845	 0.01335	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87954	 37420	 0.001324	 0.00912	 0.0161	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37420	 87959	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87960	 37420	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37421	 87961	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37422	 46948	 0.000861	 0.021303	 2.1793	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37422	 46948	 0.000861	 0.021303	 2.1793	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37422	 87963	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37422	 87963	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37423	 87964	 0.003027	 0.10896	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37423	 87964	 0.003027	 0.10896	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37424	 37426	 0.006876	 0.033908	 0.00917	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37424	 37598	 0.007772	 0.030549	 0.00799	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37425	 88608	 0.25427	 0.16466	 0.00313	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37426	 37427	 0.003805	 0.026913	 0.00739	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37427	 39402	 0.005272	 0.033391	 0.00906	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37427	 87965	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37427	 87965	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87150	 37428	 0.001075	 0.009218	 0.02024	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87168	 37428	 0.003494	 0.032156	 0.06121	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37428	 87966	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37428	 87966	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87157	 37429	 0.010707	 0.04287	 0.0108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87966	 37429	 0.009711	 0.043728	 0.01164	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87151	 37430	 0.014149	 0.037395	 0.00875	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37431	 37434	 0.005906	 0.023646	 0.00596	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37432	 37433	 0.003957	 0.017335	 0.00596	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37433	 37434	 0.002576	 0.008977	 0.00208	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37433	 87967	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37433	 87967	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37434	 37442	 0.005356	 0.014582	 0.00321	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37434	 87968	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37434	 87968	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37435	 37436	 0.007162	 0.014035	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87968	 37435	 0.005324	 0.020713	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37435	 87969	 0.023903	 0.018916	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37436	 37443	 0.032847	 0.025995	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37437	 37442	 0.004311	 0.011081	 0.00274	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37437	 87969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37437	 87969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37438	 37440	 0.021311	 0.071093	 0.00113	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87969	 37438	 0.021304	 0.039613	 0.00093	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37439	 37443	 0.023124	 0.032228	 0.00055	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37441	 87971	 0.00392	 0.016186	 0.00383	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37442	 87970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37442	 87970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37442	 87971	 0.005175	 0.030057	 0.00708	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87970	 37443	 0.010796	 0.027753	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37444	 87971	 0.007174	 0.046211	 0.01211	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37445	 87972	 0.012373	 0.083951	 0.00157	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87163	 37446	 0.002771	 0.037302	 0.07778	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87731	 37446	 0.005284	 0.036409	 0.06431	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37446	 87971	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87972	 37446	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37446	 88273	 0.015478	 0.12148	 0.44125	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37447	 37448	 0.035131	 0.035483	 0.00047	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37448	 37600	 0.045999	 0.11825	 0.00183	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87972	 37448	 0.006605	 0.045338	 0.00083	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87972	 37449	 0.060023	 0.056288	 0.00087	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37450	 87973	 0.051252	 0.147	 0.00226	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37451	 37502	 0.015964	 0.042861	 0.00971	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37451	 37505	 0.014012	 0.04807	 0.01152	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87913	 37451	 0.019272	 0.050937	 0.01192	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37451	 87973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37451	 87973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37452	 37453	 0.18568	 0.14556	 0.00187	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87973	 37452	 0.082207	 0.13731	 0.00233	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37454	 87974	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37454	 87974	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37454	 87975	 0.00823	 0.021367	 0.00519	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37455	 37457	 0.13862	 0.089749	 0.00171	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87974	 37455	 0.10545	 0.082659	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37456	 37524	 0.033394	 0.10604	 0.00186	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87974	 37456	 0.079735	 0.15788	 0.00232	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37457	 88051	 0.16617	 0.13027	 0.00167	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37458	 38721	 0.00168	 0.030363	 2.1913	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37458	 87975	 0.000117	 0.009351	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37458	 95344	 0.000842	 0.01563	 1.0361	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 0	 -30.0	 30.0;
	87975	 37459	 0.005069	 0.023013	 0.00799	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37460	 38406	 0.001155	 0.014446	 0.99336	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37460	 87977	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37460	 87977	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87978	 37460	 0.00016	 0.012814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37461	 37463	 0.00148	 0.009989	 0.01839	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87977	 37461	 0.001133	 0.007355	 0.01465	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87978	 37462	 0.008622	 0.028121	 0.00747	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37462	 87980	 0.012754	 0.035777	 0.00921	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37463	 87979	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37463	 87979	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87979	 37464	 0.021821	 0.056093	 0.00087	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37465	 87980	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37465	 87980	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37466	 37468	 0.18035	 0.11678	 0.00222	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37466	 87982	 0.057303	 0.11231	 0.00168	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37467	 87981	 0.000124	 0.009885	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37469	 87983	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37469	 87983	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37469	 87984	 0.001542	 0.016339	 0.00485	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87155	 37470	 0.000937	 0.010332	 0.01963	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87155	 37470	 0.000937	 0.010332	 0.01963	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37470	 87984	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37470	 87984	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87156	 37471	 0.001138	 0.010071	 0.00553	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87156	 37472	 0.002716	 0.01954	 0.00518	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37472	 87985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37472	 87985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87985	 37473	 0.021063	 0.12801	 0.00236	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37474	 37481	 2e-05	 0.000313	 0.03038	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37474	 87986	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37474	 87986	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37475	 87987	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37475	 87987	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37475	 87989	 0.000268	 0.002006	 0.00776	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37476	 37478	 5.6e-05	 0.001431	 0.09793	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37476	 37481	 4.9e-05	 0.00093	 0.08202	 2840.0	 2982.0	 3124.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37476	 87988	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37476	 87988	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87988	 37477	 0.000743	 0.010297	 0.0071	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37478	 37479	 4e-05	 0.001056	 0.0784	 2893.0	 3037.6	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87693	 37480	 0.04189	 0.16298	 0.00272	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87693	 37480	 0.04189	 0.16298	 0.00272	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87745	 37480	 0.16664	 0.64908	 0.01085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87745	 37480	 0.16664	 0.64908	 0.01085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87831	 37480	 0.12887	 0.50171	 0.00838	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87831	 37480	 0.12887	 0.50171	 0.00838	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37481	 87989	 0.000281	 0.02246	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37481	 87989	 0.000281	 0.02246	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37482	 37483	 0.06588	 0.11842	 0.00213	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37483	 87998	 0.015501	 0.11777	 0.00268	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37484	 37485	 0.005402	 0.028139	 0.00738	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37485	 37486	 0.003763	 0.018554	 0.00502	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37485	 37487	 0.009434	 0.027325	 0.00659	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37485	 87990	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37485	 87990	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87164	 37487	 0.005232	 0.024002	 0.00615	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37489	 87991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37489	 87991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37490	 37491	 0.005724	 0.028278	 0.00826	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37490	 87992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37490	 87992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37491	 87993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37491	 87993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87992	 37492	 0.026958	 0.15325	 0.00277	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37492	 87994	 0.015883	 0.10903	 0.00199	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37493	 87994	 0.12287	 0.13515	 0.0018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37494	 37495	 0.006651	 0.035359	 0.0082	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37494	 38522	 0.008852	 0.037467	 0.00843	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37494	 39169	 0.026069	 0.10613	 0.02588	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37494	 87994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37494	 87994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37495	 87995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37495	 87995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87169	 37496	 0.003922	 0.026754	 0.04819	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37496	 87996	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37496	 87996	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37497	 37499	 0.00583	 0.023725	 0.00578	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87996	 37497	 0.008504	 0.028653	 0.00712	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37497	 87997	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37497	 87997	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37498	 37499	 0.003049	 0.012905	 0.0029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37499	 37501	 0.00352	 0.014088	 0.00476	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87170	 37499	 0.006188	 0.0494	 0.01218	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37500	 37501	 0.006591	 0.022612	 0.00542	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37500	 37584	 0.011668	 0.040667	 0.00943	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37500	 87998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37500	 87998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37503	 88036	 0.21906	 0.17339	 0.00218	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37504	 37506	 0.18442	 0.14596	 0.00184	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37505	 87999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37505	 87999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37506	 37708	 0.018349	 0.12595	 0.0023	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87999	 37506	 0.0182	 0.10346	 0.00187	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37507	 37511	 0.000137	 0.001637	 0.12281	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87144	 37508	 0.016795	 0.043178	 0.01069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87171	 37508	 0.004138	 0.009971	 0.00282	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87171	 37509	 0.011764	 0.031091	 0.00728	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87143	 37510	 0.003752	 0.025852	 0.04565	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37510	 88000	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37510	 88000	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37510	 88001	 0.00165	 0.010712	 0.02134	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37511	 88001	 0.000118	 0.009419	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88002	 37511	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37512	 37515	 0.006308	 0.021252	 0.00528	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88002	 37512	 0.005548	 0.014404	 0.0035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37513	 38602	 0.000968	 0.017358	 1.2385	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37513	 88003	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37513	 88003	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88003	 37514	 0.00323	 0.027516	 0.00687	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37514	 88004	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37514	 88004	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37515	 37649	 0.011303	 0.039953	 0.009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37516	 37643	 0.045053	 0.12922	 0.00199	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37516	 88007	 0.031317	 0.13799	 0.0024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37517	 37518	 0.004802	 0.023679	 0.0064	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37517	 37642	 0.005244	 0.02635	 0.00686	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37517	 88005	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37517	 88005	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37518	 88006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37518	 88006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37519	 37520	 0.003306	 0.013994	 0.00315	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87154	 37519	 0.023887	 0.12451	 0.03269	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37519	 88007	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37519	 88007	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37520	 37521	 0.00364	 0.014812	 0.00361	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37521	 37522	 0.00387	 0.018282	 0.00585	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37521	 37523	 0.004934	 0.025704	 0.00674	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37521	 88008	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37521	 88008	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37522	 37689	 0.009351	 0.035546	 0.00995	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87931	 37524	 0.035658	 0.14148	 0.00404	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37525	 37526	 0.009639	 0.029013	 0.00908	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37525	 37599	 0.011143	 0.038226	 0.00916	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37526	 88009	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37526	 88009	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37527	 37529	 0.000136	 0.002131	 0.2071	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37527	 88010	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87152	 37528	 0.019612	 0.13663	 0.00321	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87745	 37528	 0.037366	 0.14537	 0.00243	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88011	 37528	 0.048643	 0.18716	 0.0032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37529	 37532	 0.000174	 0.002876	 0.25223	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37529	 88012	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37529	 88012	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88012	 37530	 0.004171	 0.031421	 0.00872	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87143	 37531	 0.001326	 0.016211	 0.03329	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37531	 88013	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88014	 37531	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37531	 88015	 0.001408	 0.010727	 0.01951	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37532	 88015	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37532	 88015	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37534	 37535	 0.00481	 0.019575	 0.00477	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87146	 37534	 0.007664	 0.032436	 0.0073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87159	 37535	 0.001666	 0.007642	 0.00196	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37536	 37537	 0.001538	 0.009557	 0.0027	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87159	 37536	 0.000648	 0.006774	 0.00186	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87146	 37537	 0.016093	 0.047449	 0.01104	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37537	 88016	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37537	 88016	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87160	 37538	 0.019682	 0.051009	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88016	 37539	 0.084909	 0.085763	 0.00114	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37540	 37543	 0.004051	 0.014667	 0.00315	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87864	 37540	 0.003048	 0.010773	 0.00243	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37541	 88017	 0.02162	 0.03886	 0.0007	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37542	 37545	 0.004827	 0.016558	 0.00397	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87864	 37542	 0.002523	 0.008502	 0.00211	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87159	 37543	 0.005585	 0.014356	 0.00355	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37543	 88017	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37543	 88017	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37544	 37546	 0.048307	 0.048792	 0.00065	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37544	 88018	 0.068947	 0.044637	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87159	 37545	 0.007732	 0.020074	 0.00487	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37545	 88018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37545	 88018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88018	 37547	 0.03988	 0.07168	 0.00129	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87716	 37548	 0.018484	 0.12688	 0.00231	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87795	 37548	 0.077868	 0.21572	 0.00356	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37548	 88019	 0.13276	 0.1341	 0.00178	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37549	 37550	 0.008462	 0.035815	 0.00806	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87149	 37549	 0.016405	 0.073118	 0.01987	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37549	 88019	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37549	 88019	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37550	 37623	 0.008988	 0.035325	 0.00924	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37551	 37552	 0.039447	 0.10141	 0.00157	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37553	 37555	 0.016079	 0.04317	 0.00978	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87673	 37553	 0.022913	 0.082988	 0.01781	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87691	 37553	 0.007478	 0.041496	 0.01261	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87692	 37554	 0.26429	 0.26702	 0.00354	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87691	 37555	 0.009311	 0.037279	 0.00939	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37556	 88020	 0.020758	 0.074154	 0.00147	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37557	 37559	 0.00389	 0.015575	 0.00392	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37557	 88020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37557	 88020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37558	 37563	 0.054929	 0.15755	 0.00242	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37558	 88021	 0.038572	 0.089552	 0.00133	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37559	 37561	 0.004862	 0.024851	 0.00677	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37559	 88021	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37559	 88021	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37560	 88022	 0.017946	 0.073343	 0.00148	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37561	 37562	 0.010654	 0.028157	 0.00659	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37561	 88022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37561	 88022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37562	 88023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37562	 88023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87733	 37563	 0.080082	 0.35297	 0.00613	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37564	 37576	 0.009186	 0.031513	 0.00755	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87981	 37564	 0.017154	 0.060642	 0.01367	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37565	 37567	 0.011962	 0.031055	 0.00754	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87981	 37565	 0.022548	 0.073561	 0.01953	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37565	 88024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37565	 88024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37566	 37568	 0.021351	 0.045755	 0.0008	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88024	 37566	 0.070788	 0.093038	 0.00128	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37566	 88025	 0.065495	 0.048187	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37567	 88025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37567	 88025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37568	 37569	 0.020067	 0.08942	 0.00152	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88025	 37568	 0.037538	 0.073569	 0.0011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37569	 88026	 0.020463	 0.078403	 0.00222	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37570	 88026	 0.029082	 0.072184	 0.0012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37571	 88026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37571	 88026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37572	 37573	 0.02551	 0.065575	 0.00101	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37572	 37582	 0.051472	 0.10534	 0.00259	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88026	 37572	 0.018591	 0.077605	 0.00224	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37573	 37574	 0.041755	 0.10734	 0.00166	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37574	 37581	 0.098126	 0.13377	 0.00297	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37574	 37582	 0.061884	 0.12253	 0.0018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88025	 37574	 0.03285	 0.076266	 0.00113	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37575	 37580	 0.19644	 0.25824	 0.00354	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88025	 37575	 0.043073	 0.11073	 0.00171	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37576	 88027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37576	 88027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88027	 37577	 0.025008	 0.047892	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37578	 37579	 0.031552	 0.06247	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88027	 37578	 0.022313	 0.10766	 0.0019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37579	 37580	 0.082126	 0.10794	 0.00148	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37583	 37709	 0.008688	 0.042925	 0.01254	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87170	 37583	 0.011744	 0.072991	 0.02061	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87170	 37584	 0.003298	 0.036524	 0.01188	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37585	 37589	 0.012885	 0.035933	 0.00754	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37586	 88028	 0.045233	 0.081302	 0.00146	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37587	 37590	 0.006256	 0.032588	 0.00855	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37587	 37612	 0.009383	 0.039713	 0.00894	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37588	 88028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37588	 88028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37588	 88029	 0.006189	 0.02157	 0.005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37589	 88029	 0.009006	 0.023382	 0.00568	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87166	 37590	 0.004261	 0.01706	 0.0043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87167	 37591	 0.0153	 0.092984	 0.00172	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37591	 88030	 0.012419	 0.048314	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37592	 88029	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88030	 37592	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88030	 37593	 0.011568	 0.023673	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37593	 88031	 0.15251	 0.20047	 0.00275	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37594	 37596	 0.008794	 0.026468	 0.00828	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87166	 37594	 0.004198	 0.014629	 0.00339	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37595	 37596	 0.010406	 0.034714	 0.0088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37595	 37602	 0.014733	 0.038939	 0.00912	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37595	 88031	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37595	 88031	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37596	 88032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37596	 88032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37597	 37691	 0.04261	 0.15756	 0.00292	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87167	 37597	 0.013385	 0.053565	 0.00113	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87166	 37598	 0.006457	 0.023382	 0.00502	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37600	 37603	 0.053892	 0.13706	 0.00217	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37601	 37602	 0.013516	 0.035723	 0.00836	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37601	 88033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37601	 88033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37604	 37605	 0.006285	 0.02595	 0.00614	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87158	 37604	 0.017456	 0.17983	 0.05112	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37604	 88034	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37604	 88034	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37605	 88035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37605	 88035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37606	 88036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37606	 88036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88036	 37607	 0.065639	 0.12997	 0.00191	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37608	 37609	 0.007041	 0.024154	 0.00579	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37608	 88037	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37608	 88037	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37609	 88038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37609	 88038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87172	 37610	 0.11188	 0.080879	 0.00123	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87172	 37611	 0.039798	 0.081446	 0.002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37612	 88039	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37612	 88039	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37613	 37620	 0.003575	 0.01076	 0.00337	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37613	 88040	 0.000951	 0.005109	 0.00126	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37614	 37624	 0.00427	 0.015461	 0.00332	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37614	 88040	 0.002223	 0.00749	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37615	 37625	 0.006166	 0.02057	 0.00522	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37615	 88040	 0.001616	 0.004765	 0.00111	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37616	 88041	 0.013748	 0.021451	 0.00036	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87148	 37617	 0.010374	 0.07157	 0.12662	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37617	 88040	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88041	 37617	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37618	 37619	 0.072549	 0.057415	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88041	 37618	 0.033168	 0.055093	 0.00117	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37620	 37621	 0.011682	 0.031807	 0.00701	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37620	 88042	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37620	 88042	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37621	 37623	 0.006265	 0.02149	 0.00515	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37622	 37623	 0.009574	 0.026066	 0.00574	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37624	 37717	 0.004804	 0.015669	 0.00416	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88042	 37626	 0.029166	 0.048445	 0.00103	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37627	 37631	 0.074424	 0.14587	 0.00219	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87663	 37627	 0.093842	 0.11944	 0.00175	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37628	 37629	 0.006632	 0.032767	 0.00957	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37629	 37630	 0.006253	 0.021452	 0.00514	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37630	 88043	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37630	 88043	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37630	 88044	 0.001453	 0.007229	 0.00233	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88043	 37631	 0.01019	 0.020176	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37631	 88045	 0.018289	 0.047014	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37632	 88044	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88045	 37632	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88045	 37633	 0.072965	 0.074506	 0.00116	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37634	 37640	 0.003739	 0.019475	 0.00511	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88044	 37634	 0.003786	 0.018701	 0.00546	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37635	 88046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37635	 88046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37636	 39700	 0.028063	 0.10918	 0.00182	 80.0	 84.0	 88.0	 0.0	 0.0	 0	 -30.0	 30.0;
	37636	 88048	 0.012607	 0.07094	 0.00153	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37637	 88047	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88048	 37637	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37637	 88064	 0.001258	 0.016725	 0.03573	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37637	 88384	 0.009889	 0.062722	 0.13162	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87949	 37638	 0.052891	 0.1445	 0.00245	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88048	 37638	 0.05621	 0.1113	 0.00163	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37639	 88737	 0.023988	 0.12782	 0.00224	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37640	 37641	 0.003157	 0.016446	 0.00431	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37641	 37642	 0.004076	 0.020138	 0.00588	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37641	 88049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37641	 88049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37642	 88050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37642	 88050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88049	 37643	 0.15474	 0.13868	 0.00284	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87976	 37644	 0.06981	 0.12981	 0.00304	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37644	 88052	 0.065761	 0.10497	 0.00242	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37645	 88051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37645	 88051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37646	 37647	 0.007049	 0.017719	 0.00459	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37646	 88052	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37646	 88052	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37647	 37648	 0.007326	 0.025132	 0.00602	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87664	 37647	 0.029278	 0.14479	 0.04235	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37647	 88053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37647	 88053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37648	 88054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37648	 88054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37649	 37650	 0.011895	 0.041458	 0.00961	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37650	 37652	 0.01133	 0.038176	 0.00949	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37651	 88562	 0.032028	 0.10941	 0.00238	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37652	 39271	 0.008722	 0.030399	 0.00705	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37653	 37654	 0.013133	 0.034709	 0.00812	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87703	 37653	 0.014601	 0.038591	 0.00903	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37654	 37655	 0.013033	 0.034445	 0.00806	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87211	 37654	 0.037233	 0.12781	 0.03065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37655	 37656	 0.011595	 0.03907	 0.00971	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37655	 88055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37655	 88055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37657	 39654	 0.23086	 0.18273	 0.0023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88055	 37657	 0.21889	 0.15508	 0.00245	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87147	 37658	 0.096822	 0.11591	 0.00193	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37660	 88057	 0.071669	 0.12882	 0.00231	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37661	 37698	 0.003095	 0.020642	 0.03891	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37661	 88056	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88057	 37661	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37662	 88058	 0.074791	 0.14809	 0.00217	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88056	 37663	 0.016244	 0.045302	 0.00951	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37663	 88058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37663	 88058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37663	 88069	 0.01277	 0.035611	 0.00747	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37664	 37665	 0.000335	 0.003068	 0.00123	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37664	 37666	 0.000265	 0.002548	 0.00074	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37664	 37668	 0.000408	 0.002125	 0.00056	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37665	 37680	 0.00082	 0.008359	 0.00215	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37666	 37676	 0.000656	 0.005441	 0.00143	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37666	 88059	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37666	 88059	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37667	 37668	 0.000618	 0.003157	 0.00086	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37667	 37675	 0.000353	 0.00293	 0.00115	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37667	 88060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37667	 88060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37669	 37675	 0.001595	 0.005203	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37669	 88061	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37669	 88061	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37670	 37671	 0.000777	 0.003974	 0.00108	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37670	 37675	 0.001876	 0.008447	 0.00225	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37671	 37674	 0.001001	 0.005863	 0.0016	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37672	 37683	 0.030197	 0.077625	 0.0012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37672	 88062	 0.012415	 0.045903	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37673	 37674	 0.00118	 0.007332	 0.00207	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37673	 37687	 0.004792	 0.015985	 0.00405	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37673	 88062	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37673	 88062	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37673	 88065	 0.001564	 0.015015	 0.00437	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37675	 37677	 0.000561	 0.006204	 0.00186	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37676	 37677	 0.000541	 0.00442	 0.0012	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37677	 88063	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37677	 88063	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37677	 88065	 0.000841	 0.007244	 0.00421	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37678	 88064	 9.9e-05	 0.007891	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88065	 37678	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37679	 37686	 0.032186	 0.078784	 0.00135	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88063	 37679	 0.046144	 0.058727	 0.00086	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37680	 37684	 0.006037	 0.041441	 0.01209	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37680	 37685	 0.001658	 0.019471	 0.00516	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88065	 37680	 0.002787	 0.030819	 0.00924	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37681	 37682	 0.050274	 0.038564	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88061	 37681	 0.007555	 0.024932	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88014	 37686	 0.14511	 0.36775	 0.00729	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88047	 37687	 0.010541	 0.027858	 0.00652	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37688	 37689	 0.008605	 0.044828	 0.01176	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87975	 37689	 0.004258	 0.048674	 0.01485	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37689	 88066	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37689	 88066	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87990	 37690	 0.04006	 0.15585	 0.0026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88066	 37690	 0.025799	 0.11433	 0.00343	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37691	 88067	 0.010089	 0.056689	 0.00105	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37691	 88068	 0.048889	 0.12434	 0.00197	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37692	 37693	 0.006322	 0.016709	 0.00391	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37692	 88067	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37692	 88067	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37693	 37695	 0.008612	 0.030013	 0.00696	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37693	 88068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37693	 88068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87735	 37694	 0.019459	 0.10451	 0.00248	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88068	 37694	 0.02529	 0.10121	 0.00214	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37695	 39403	 0.020002	 0.067404	 0.01676	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37696	 37697	 0.012458	 0.035734	 0.00879	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87157	 37696	 0.008896	 0.026228	 0.0061	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37697	 88070	 0.010683	 0.036648	 0.00878	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37698	 37699	 0.001392	 0.009284	 0.0175	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37698	 88069	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37698	 88069	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87168	 37699	 0.004684	 0.032274	 0.057	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37699	 88070	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37699	 88070	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37700	 88071	 0.017266	 0.026449	 0.00037	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37701	 37702	 0.002216	 0.01149	 0.00281	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37701	 88071	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37701	 88071	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37702	 37704	 0.004968	 0.031466	 0.00854	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37703	 88072	 0.096028	 0.17154	 0.00253	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37704	 37705	 0.005807	 0.040289	 0.0115	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37705	 38381	 0.01849	 0.1743	 0.05292	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37705	 88072	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37705	 88072	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37706	 37707	 0.004952	 0.025794	 0.00677	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37706	 38462	 0.00322	 0.020396	 0.00554	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37706	 88073	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37706	 88073	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37708	 88074	 0.017766	 0.13847	 0.00259	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37709	 88074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37709	 88074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37710	 37711	 0.002847	 0.011397	 0.00287	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37710	 37712	 0.002527	 0.008931	 0.00201	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37711	 37714	 0.002983	 0.010852	 0.00332	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37711	 37716	 0.003132	 0.012186	 0.00325	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87164	 37711	 0.006965	 0.069795	 0.02324	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37712	 37715	 0.005623	 0.022512	 0.00567	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37713	 37714	 0.001457	 0.004554	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87910	 37715	 0.006548	 0.035199	 0.00866	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37716	 37717	 0.004858	 0.019092	 0.00499	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87789	 37716	 0.008152	 0.021929	 0.00615	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37718	 38022	 0.12772	 0.36645	 0.00564	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37718	 88075	 0.042194	 0.13398	 0.00235	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87204	 37719	 0.083513	 0.066092	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37720	 88075	 0.037306	 0.024152	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37721	 37723	 0.001499	 0.003891	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87204	 37722	 0.029314	 0.026268	 0.00054	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37723	 88075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37723	 88075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88075	 37724	 0.036905	 0.029206	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87178	 37725	 0.037836	 0.20372	 0.05024	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37725	 88076	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37725	 88076	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88075	 37726	 0.007754	 0.020551	 0.00052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88076	 37726	 0.05344	 0.17637	 0.00286	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37727	 88078	 0.04661	 0.095387	 0.00235	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37728	 37731	 0.007832	 0.02309	 0.00537	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37728	 39165	 0.010971	 0.032345	 0.00752	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37728	 88077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37728	 88077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88077	 37729	 0.070775	 0.045821	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37730	 38305	 0.012692	 0.050818	 0.0128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37730	 39164	 0.011765	 0.040362	 0.00967	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37731	 37732	 0.011654	 0.030802	 0.00721	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37731	 37733	 0.007891	 0.03258	 0.00771	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87193	 37731	 0.046888	 0.16102	 0.03863	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37731	 88078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37731	 88078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37732	 38311	 0.017627	 0.045317	 0.01122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37733	 88231	 0.011008	 0.044076	 0.01111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37734	 37736	 0.31874	 0.25234	 0.00318	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37734	 88115	 0.10623	 0.27022	 0.00427	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37735	 37847	 0.29035	 0.29053	 0.00393	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37735	 38363	 0.10631	 0.19771	 0.00463	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37735	 88115	 0.13056	 0.30319	 0.00451	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37737	 37741	 0.011532	 0.048813	 0.01099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87192	 37737	 0.00859	 0.036359	 0.00818	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37738	 88081	 0.18423	 0.14582	 0.00184	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37739	 38155	 0.008433	 0.052404	 0.01479	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37739	 88079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37739	 88079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37740	 38366	 0.016522	 0.066159	 0.01667	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37740	 88080	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37740	 88080	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37741	 37742	 0.001864	 0.007252	 0.00194	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37742	 88081	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37742	 88081	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37743	 38305	 0.018376	 0.055317	 0.01731	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87193	 37743	 0.004592	 0.015318	 0.00388	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37744	 38317	 0.010205	 0.041529	 0.01012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87193	 37744	 0.011212	 0.039236	 0.013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37745	 37746	 0.009871	 0.054173	 0.01432	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37745	 37780	 0.009011	 0.052785	 0.01438	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37746	 88082	 0.014136	 0.056602	 0.01426	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37746	 88257	 0.012311	 0.09153	 0.03493	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87200	 37747	 0.14267	 0.092372	 0.00176	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37748	 37750	 0.002359	 0.022048	 0.04066	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37748	 38338	 0.002188	 0.019522	 0.03954	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37749	 37752	 0.002877	 0.008482	 0.00197	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37749	 38290	 0.011997	 0.031707	 0.00742	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87199	 37749	 0.008227	 0.021743	 0.00509	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37750	 47323	 0.015616	 0.10795	 0.19153	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87198	 37750	 0.0009	 0.005697	 0.01193	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37750	 88082	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37750	 88082	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37750	 88243	 0.001338	 0.014577	 0.05882	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37751	 37752	 0.00214	 0.006409	 0.00144	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88082	 37751	 0.002799	 0.009429	 0.00234	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37753	 37754	 0.007106	 0.018266	 0.00452	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37753	 37855	 0.026822	 0.1092	 0.02662	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37753	 38234	 0.01453	 0.057117	 0.01494	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37753	 88083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37753	 88083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37754	 37757	 0.015198	 0.040169	 0.0094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37755	 37757	 0.008188	 0.020583	 0.00533	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37755	 38361	 0.02334	 0.066956	 0.01648	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37756	 88084	 0.11879	 0.08588	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37757	 88084	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37757	 88084	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37758	 37856	 0.018772	 0.05622	 0.01267	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37758	 38114	 0.016947	 0.058143	 0.01393	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37758	 88085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37758	 88085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37759	 37977	 0.017498	 0.052676	 0.01648	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37759	 38179	 0.015667	 0.05375	 0.01288	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37760	 37763	 0.014532	 0.052875	 0.01619	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37760	 38103	 0.007855	 0.03145	 0.00792	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37761	 37762	 0.010084	 0.029209	 0.00705	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37761	 38233	 0.017	 0.050913	 0.01147	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37762	 38362	 0.031206	 0.12707	 0.03099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37762	 88086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37762	 88086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37763	 37775	 0.012989	 0.049379	 0.01383	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37763	 88087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37763	 88087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87186	 37764	 0.11373	 0.08724	 0.00117	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37765	 37766	 8e-05	 0.001234	 0.09492	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37767	 37973	 0.016635	 0.065392	 0.01711	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87178	 37767	 0.010373	 0.039429	 0.01104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37768	 37769	 0.082284	 0.084023	 0.00131	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87179	 37768	 0.03458	 0.088894	 0.00138	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37770	 37773	 0.007961	 0.028964	 0.00887	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37770	 38076	 0.016634	 0.060527	 0.01853	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37771	 38075	 0.014866	 0.051003	 0.01222	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37771	 88088	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37771	 88088	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37772	 37773	 0.00965	 0.040847	 0.00919	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37772	 38358	 0.015329	 0.060257	 0.01577	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37773	 88089	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37773	 88089	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37774	 88090	 0.070868	 0.13572	 0.00214	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37775	 88214	 0.01199	 0.04558	 0.01276	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37776	 37778	 0.000773	 0.006136	 0.01181	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37776	 88090	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37776	 88090	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37776	 88216	 0.002183	 0.017981	 0.03706	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88090	 37777	 0.007871	 0.018274	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37778	 38123	 0.001865	 0.012438	 0.02344	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37778	 38132	 0.002106	 0.013667	 0.02723	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37779	 38240	 0.01108	 0.056647	 0.01544	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37780	 37783	 0.003531	 0.028364	 0.00797	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87200	 37781	 0.086617	 0.35415	 0.00717	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87201	 37781	 0.029422	 0.067289	 0.00164	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37781	 88222	 0.39704	 0.50581	 0.00742	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87209	 37782	 0.019229	 0.034696	 0.0005	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87201	 37784	 0.020813	 0.016471	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87201	 37785	 0.007967	 0.01432	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37786	 37787	 0.038983	 0.080114	 0.00153	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37786	 88092	 0.063672	 0.1184	 0.00277	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37786	 88155	 0.02478	 0.13647	 0.00308	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37787	 37790	 0.14636	 0.19239	 0.00264	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37787	 37972	 0.2221	 0.20462	 0.00328	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37787	 38268	 0.13416	 0.22377	 0.00325	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37788	 37789	 0.013828	 0.048881	 0.01102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87178	 37788	 0.023387	 0.11539	 0.03123	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37788	 88091	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37788	 88091	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37789	 88092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37789	 88092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88092	 37790	 0.073128	 0.11673	 0.00269	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37790	 88182	 0.12162	 0.21947	 0.00317	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88091	 37791	 0.28639	 0.18547	 0.00353	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37792	 37793	 0.005774	 0.02649	 0.00679	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37793	 37795	 0.009384	 0.03398	 0.00729	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37793	 88093	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37793	 88093	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88093	 37794	 0.11893	 0.10657	 0.00218	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37794	 88241	 0.083613	 0.17113	 0.00421	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37795	 38039	 0.01466	 0.050293	 0.01205	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37796	 37797	 0.005146	 0.020602	 0.00519	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37796	 37828	 0.008163	 0.033705	 0.00797	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37797	 39641	 0.003701	 0.012951	 0.00429	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37798	 88097	 0.042906	 0.033955	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37799	 88095	 0.074919	 0.05929	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37800	 37803	 0.001042	 0.007028	 0.01294	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37800	 37815	 0.000916	 0.005946	 0.01184	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37800	 37826	 0.000433	 0.00422	 0.01469	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37800	 88094	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88095	 37800	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37801	 37813	 0.001435	 0.004156	 0.001	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88094	 37801	 0.004147	 0.012225	 0.00284	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37802	 37805	 0.000839	 0.003359	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37802	 37807	 0.002682	 0.010736	 0.0027	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88094	 37802	 0.004441	 0.011737	 0.00275	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37803	 88096	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88097	 37803	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37803	 91059	 0.006356	 0.069103	 0.13587	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37803	 91059	 0.006356	 0.069103	 0.13587	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88097	 37804	 0.026244	 0.01699	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37804	 88098	 0.017406	 0.012806	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88096	 37805	 0.001287	 0.004486	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37805	 88098	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37805	 88098	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37806	 37807	 0.001126	 0.004425	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37806	 39634	 0.000713	 0.002855	 0.00072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37807	 88099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37807	 88099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87191	 37808	 0.013314	 0.010537	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88099	 37809	 0.020744	 0.016417	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37810	 88100	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37810	 88100	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37810	 88101	 0.002179	 0.008725	 0.0022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37810	 88713	 0.003607	 0.013712	 0.00384	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88099	 37811	 0.013291	 0.023741	 0.00035	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37812	 37813	 0.002152	 0.006232	 0.0015	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37812	 39634	 0.004099	 0.01143	 0.0024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37814	 37815	 0.000499	 0.003956	 0.00761	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37814	 39605	 0.00374	 0.024949	 0.04703	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37814	 88101	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37814	 88101	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37815	 88102	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37815	 88102	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37816	 37819	 0.003808	 0.009885	 0.0024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88101	 37816	 0.004516	 0.015065	 0.00382	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37816	 88103	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37816	 88103	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88103	 37817	 0.047336	 0.049802	 0.00073	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37818	 37821	 0.004099	 0.016413	 0.00413	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37818	 37824	 0.005094	 0.019819	 0.00529	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37819	 39623	 0.003448	 0.008952	 0.00217	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37819	 88104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37819	 88104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37820	 37822	 0.001489	 0.00596	 0.0015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37820	 39603	 0.010291	 0.028698	 0.00602	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37820	 88105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37820	 88105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37820	 88713	 0.007157	 0.024943	 0.00578	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37821	 37822	 0.001006	 0.004258	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88105	 37823	 0.053535	 0.049815	 0.00094	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37823	 88206	 0.040507	 0.22764	 0.00422	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37824	 37825	 0.008038	 0.032183	 0.00811	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37825	 38302	 0.013388	 0.053605	 0.01351	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88102	 37825	 0.009616	 0.024721	 0.00612	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37826	 37827	 0.0005	 0.005923	 0.02016	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37826	 88106	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37826	 88106	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37827	 38304	 0.001003	 0.011356	 0.04237	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37827	 88107	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37827	 88107	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37828	 38302	 0.009284	 0.037172	 0.00937	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37829	 37830	 0.00068	 0.003214	 0.00103	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37829	 37831	 0.001179	 0.005309	 0.00141	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37829	 88108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37829	 88108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37830	 37835	 0.001062	 0.005373	 0.0015	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37831	 37842	 0.001779	 0.006993	 0.00183	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37831	 88109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37831	 88109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37832	 37833	 0.005258	 0.023431	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88108	 37832	 0.00873	 0.017865	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37832	 88113	 0.008935	 0.038374	 0.0007	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37833	 88110	 0.003158	 0.019417	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37834	 37835	 0.00257	 0.008815	 0.00211	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37834	 38056	 0.002713	 0.012316	 0.00427	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37834	 88110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37834	 88110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37835	 37836	 0.00137	 0.00362	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37835	 38057	 0.001945	 0.00984	 0.00274	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37836	 37837	 0.001926	 0.005172	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37837	 88111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37837	 88111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37838	 37842	 0.005335	 0.018301	 0.00438	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87208	 37839	 0.036159	 0.085627	 0.00157	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37840	 38040	 0.004437	 0.022679	 0.00618	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37840	 38057	 0.004565	 0.01794	 0.00469	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37840	 88112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37840	 88112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87208	 37841	 0.059964	 0.047455	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37843	 37844	 0.013882	 0.058759	 0.01322	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37843	 88113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37843	 88113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37844	 38058	 0.006861	 0.043458	 0.0118	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87181	 37844	 0.080072	 0.24373	 0.05354	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37844	 88114	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37844	 88114	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88108	 37845	 0.031656	 0.022884	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37846	 38118	 0.017457	 0.058826	 0.01462	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87178	 37846	 0.015904	 0.13223	 0.05181	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37846	 88115	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37846	 88115	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37847	 38023	 0.15528	 0.27743	 0.0041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37848	 37990	 0.013266	 0.056153	 0.01264	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37849	 37990	 0.022344	 0.089489	 0.02255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37849	 88116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37849	 88116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88116	 37850	 0.11912	 0.094277	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37851	 37990	 0.018762	 0.064371	 0.01543	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37851	 38287	 0.020795	 0.07008	 0.01742	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37851	 88117	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37851	 88117	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88117	 37852	 0.20295	 0.14934	 0.00218	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37853	 38218	 0.032047	 0.089394	 0.01877	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37853	 38359	 0.019101	 0.062311	 0.01655	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87542	 37853	 0.043553	 0.11314	 0.02748	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88116	 37854	 0.1035	 0.16523	 0.00381	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37855	 37859	 0.011951	 0.037357	 0.01082	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37855	 38370	 0.026395	 0.066363	 0.0172	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87192	 37855	 0.031123	 0.14291	 0.03666	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37856	 37858	 0.013469	 0.035598	 0.00833	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37856	 38297	 0.028276	 0.078868	 0.01656	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37857	 88118	 0.011757	 0.023278	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37858	 37859	 0.003555	 0.010481	 0.00244	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37858	 38179	 0.029702	 0.085218	 0.02098	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37858	 88118	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37858	 88118	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37860	 37862	 0.077705	 0.061495	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37861	 37862	 0.023305	 0.039259	 0.00056	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37862	 88127	 0.048927	 0.12969	 0.00329	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37863	 37866	 0.011895	 0.035623	 0.00802	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37864	 88119	 0.029189	 0.14766	 0.00257	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37864	 88127	 0.016934	 0.10411	 0.00188	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37865	 88132	 0.13621	 0.24582	 0.00355	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37866	 38217	 0.014088	 0.048332	 0.01158	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37866	 88119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37866	 88119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37866	 88130	 0.011624	 0.11167	 0.03251	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37867	 37997	 0.000767	 0.00934	 0.00309	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37867	 88120	 0.00031	 0.003543	 0.00108	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37868	 37870	 0.000581	 0.003677	 0.0077	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37868	 88120	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37868	 88120	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37869	 37910	 0.028347	 0.022219	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37869	 88122	 0.015812	 0.014168	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37870	 37871	 0.000339	 0.003737	 0.0071	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37870	 37871	 0.000339	 0.003737	 0.0071	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87180	 37870	 0.001505	 0.022622	 0.10231	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37870	 88121	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88122	 37870	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87206	 37871	 0.000287	 0.004769	 0.01761	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37871	 88123	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88124	 37871	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37872	 37875	 0.002105	 0.008907	 0.002	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88123	 37872	 0.001068	 0.0049	 0.00126	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88124	 37873	 0.025271	 0.019999	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37874	 37880	 0.015868	 0.012558	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37874	 37881	 0.017297	 0.01747	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37875	 37876	 0.001303	 0.005217	 0.00131	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37876	 88130	 0.001743	 0.006341	 0.00194	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37877	 37879	 0.002007	 0.007629	 0.00214	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37877	 88125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37877	 88125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37877	 88130	 0.001681	 0.006997	 0.00218	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88125	 37878	 0.027292	 0.027299	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37879	 37892	 0.001693	 0.009444	 0.00241	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88121	 37879	 0.006542	 0.038975	 0.01025	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37879	 88126	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37879	 88126	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37881	 37882	 0.007109	 0.020391	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88126	 37881	 0.004651	 0.031927	 0.00058	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37882	 37885	 0.009261	 0.01722	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37882	 37886	 0.01221	 0.049902	 0.00101	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37882	 37909	 0.019913	 0.014105	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37883	 37884	 0.007958	 0.022582	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37883	 37890	 0.027942	 0.042804	 0.0006	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88126	 37883	 0.010513	 0.03507	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37884	 37885	 0.005214	 0.013403	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37886	 37887	 0.009991	 0.01196	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37886	 37907	 0.21244	 0.16098	 0.00222	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37887	 37888	 0.091786	 0.092709	 0.00123	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37888	 37889	 0.026645	 0.019261	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37889	 88127	 0.075489	 0.069535	 0.00111	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88126	 37890	 0.026917	 0.068455	 0.00108	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37890	 88127	 0.035873	 0.10289	 0.00158	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37891	 88127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37891	 88127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37891	 88130	 0.010564	 0.053444	 0.01488	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37892	 37893	 0.000793	 0.004646	 0.00127	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37892	 88128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37892	 88128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37893	 37895	 0.001361	 0.007969	 0.00217	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87206	 37894	 0.000568	 0.007928	 0.01534	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37894	 88129	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37894	 88129	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87207	 37895	 0.00135	 0.00749	 0.00228	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37896	 48635	 0.000665	 0.011369	 0.88705	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37896	 88130	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37896	 88130	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37897	 37995	 0.002023	 0.008101	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88121	 37897	 0.002876	 0.011705	 0.00285	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37898	 37899	 0.048843	 0.038286	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88122	 37898	 0.015344	 0.039023	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37900	 37901	 0.004322	 0.016428	 0.0046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88121	 37900	 0.004758	 0.026226	 0.00613	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37900	 88131	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37900	 88131	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88129	 37901	 0.004345	 0.016905	 0.00452	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88131	 37902	 0.10203	 0.14486	 0.00238	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37903	 38209	 0.033528	 0.091313	 0.02013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37903	 38288	 0.013139	 0.05261	 0.01326	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88129	 37903	 0.008279	 0.040822	 0.01104	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37903	 88132	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37903	 88132	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37904	 37906	 0.1612	 0.1327	 0.00269	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37905	 37906	 0.077534	 0.06136	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88128	 37906	 0.02438	 0.062672	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88122	 37908	 0.028993	 0.022726	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88126	 37911	 0.020753	 0.015269	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37912	 37946	 0.001701	 0.004275	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37912	 37947	 0.002191	 0.007637	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37912	 88133	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37912	 88133	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88133	 37913	 0.025757	 0.020384	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37914	 37915	 0.000574	 0.002183	 0.00061	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37914	 37916	 0.000874	 0.003498	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37915	 37947	 0.001182	 0.005003	 0.00113	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37916	 37925	 0.00124	 0.004965	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37917	 37918	 0.034028	 0.02693	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37917	 37948	 0.027081	 0.029496	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37918	 37921	 0.013142	 0.010401	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37918	 88135	 0.013198	 0.025865	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37919	 37953	 0.007344	 0.019409	 0.00454	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37919	 88134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37919	 88134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37920	 37932	 0.000988	 0.004879	 0.00142	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37920	 88135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37920	 88135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88135	 37922	 0.028908	 0.022878	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37923	 37924	 0.009957	 0.016023	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37923	 37930	 0.008912	 0.01608	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37924	 88136	 0.008426	 0.016683	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37925	 37927	 0.001586	 0.005173	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37925	 38254	 0.003042	 0.015845	 0.00416	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37925	 88136	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37925	 88136	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88136	 37926	 0.006907	 0.030775	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37926	 88234	 0.007096	 0.029	 0.00059	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37927	 37928	 0.000862	 0.003123	 0.00067	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37928	 88137	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37928	 88137	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37929	 37930	 0.011245	 0.008899	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37929	 88140	 0.016709	 0.016758	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88137	 37930	 0.015531	 0.028024	 0.00041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37930	 88140	 0.00707	 0.013998	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37931	 37932	 0.000659	 0.003489	 0.00088	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37931	 37935	 0.001056	 0.004228	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37931	 88138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37931	 88138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37932	 88139	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37932	 88139	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88139	 37933	 0.01941	 0.014889	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37934	 37938	 0.005097	 0.01043	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88138	 37934	 0.004387	 0.014636	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37935	 88140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37935	 88140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37936	 38259	 0.009223	 0.040635	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88137	 37936	 0.004055	 0.020512	 0.00036	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37936	 88141	 0.013622	 0.031295	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37937	 88141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37937	 88141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37937	 88153	 0.008993	 0.024486	 0.00539	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37938	 37940	 0.00661	 0.014829	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37939	 37942	 0.023586	 0.023823	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88141	 37939	 0.050697	 0.0373	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88141	 37940	 0.027095	 0.021442	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37940	 88142	 0.014581	 0.018099	 0.00039	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37941	 37944	 0.00194	 0.005281	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37941	 88142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37941	 88142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37942	 37943	 0.025047	 0.019822	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37942	 88151	 0.011068	 0.019971	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37943	 88143	 0.019829	 0.014589	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37944	 88143	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37944	 88143	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37944	 88153	 0.004815	 0.013109	 0.00289	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37945	 38140	 0.020466	 0.022292	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88133	 37945	 0.013616	 0.02907	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37946	 38135	 0.005718	 0.014843	 0.0036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37946	 88144	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37946	 88144	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37947	 88145	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37947	 88145	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88145	 37948	 0.01247	 0.022273	 0.00033	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37949	 88146	 0.004949	 0.019815	 0.00499	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88134	 37950	 0.036196	 0.028645	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37951	 37954	 0.001176	 0.008651	 0.01692	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37951	 37970	 0.00267	 0.018015	 0.03317	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37951	 88146	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37951	 88146	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37952	 37958	 0.001146	 0.004149	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88146	 37952	 0.001947	 0.007399	 0.00207	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37953	 37955	 0.013709	 0.058028	 0.01306	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37953	 37959	 0.001827	 0.007315	 0.00184	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37954	 38332	 0.003302	 0.046326	 0.08891	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37954	 88147	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37954	 88147	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37955	 38333	 0.010464	 0.040712	 0.01087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37956	 37971	 0.010183	 0.036875	 0.00791	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37956	 88153	 0.015335	 0.052612	 0.01261	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37957	 37958	 0.001694	 0.005812	 0.00139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37957	 37964	 0.002309	 0.00836	 0.00179	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37958	 37959	 0.001465	 0.006048	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37959	 88148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37959	 88148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37960	 37962	 0.030083	 0.059561	 0.00087	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88148	 37960	 0.008279	 0.025424	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37961	 88152	 0.099675	 0.078884	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37962	 37963	 0.033798	 0.026747	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37962	 88151	 0.050721	 0.04014	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37964	 37965	 0.002036	 0.006985	 0.00167	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37964	 88149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37964	 88149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37965	 37966	 0.001697	 0.005534	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37966	 37967	 0.002346	 0.00609	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37966	 88150	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37966	 88150	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37967	 37969	 0.004686	 0.010878	 0.00331	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37967	 88151	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37967	 88151	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88151	 37968	 0.02374	 0.018787	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37969	 88152	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37969	 88152	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37969	 88153	 0.003781	 0.009111	 0.00257	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37970	 38256	 0.001498	 0.01032	 0.01822	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	37970	 88153	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88154	 37970	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37971	 37973	 0.011742	 0.048483	 0.01147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37971	 88155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37971	 88155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88154	 37972	 0.040607	 0.09287	 0.00227	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37973	 38335	 0.014036	 0.050828	 0.01091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88137	 37974	 0.013015	 0.009983	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88140	 37975	 0.00523	 0.013553	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88141	 37975	 0.009766	 0.019336	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88079	 37976	 0.039825	 0.15966	 0.00412	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	37976	 88156	 0.054975	 0.16548	 0.00324	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37977	 37978	 0.016514	 0.050151	 0.01098	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37977	 88156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37977	 88156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37978	 37981	 0.018415	 0.051663	 0.0133	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37979	 88267	 0.27482	 0.17798	 0.00339	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88156	 37980	 0.13045	 0.23451	 0.00421	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37980	 88203	 0.087022	 0.24699	 0.00388	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37980	 88267	 0.1277	 0.21215	 0.0045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37981	 37982	 0.016596	 0.048072	 0.0116	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37981	 88157	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37981	 88157	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37982	 38276	 0.031214	 0.087069	 0.01828	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37982	 88158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37982	 88158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88157	 37983	 0.053644	 0.042453	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	37984	 88159	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37984	 88159	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37984	 88263	 0.031568	 0.12647	 0.03189	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37985	 88160	 0.099855	 0.16823	 0.0024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	37986	 88185	 0.24683	 0.20323	 0.00412	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37987	 37988	 0.012468	 0.034769	 0.0073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37987	 37989	 0.012363	 0.033193	 0.00752	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37987	 88160	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37987	 88160	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37988	 38105	 0.034333	 0.09077	 0.02125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	37989	 38093	 0.013826	 0.035896	 0.00871	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87181	 37990	 0.00341	 0.027399	 0.0077	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87181	 37991	 0.007918	 0.033512	 0.00754	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37992	 37993	 0.006738	 0.035099	 0.00921	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87181	 37992	 0.009763	 0.05171	 0.01311	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37993	 37994	 0.004241	 0.022545	 0.00523	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37994	 37995	 0.004592	 0.018386	 0.00463	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	37996	 37997	 0.002194	 0.009132	 0.00285	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37996	 37999	 0.002336	 0.011542	 0.00337	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37997	 37998	 0.001489	 0.008431	 0.00209	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	37998	 37999	 0.001865	 0.010924	 0.00298	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	37999	 38000	 0.002326	 0.018689	 0.00525	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37999	 38001	 0.004037	 0.01385	 0.00332	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87181	 38000	 0.003751	 0.036017	 0.01048	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38001	 38003	 0.003964	 0.018185	 0.00466	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38002	 88165	 0.05903	 0.043431	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38003	 38017	 0.003215	 0.016749	 0.00439	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87180	 38004	 0.000971	 0.007322	 0.01362	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38004	 88161	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88162	 38004	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38005	 38006	 0.033274	 0.026333	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38006	 38009	 0.019135	 0.017944	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88162	 38006	 0.046322	 0.063198	 0.00113	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38007	 38011	 0.002541	 0.010173	 0.00256	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38007	 38016	 0.004121	 0.013749	 0.00349	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88161	 38007	 0.006551	 0.017586	 0.00399	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38007	 88163	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38007	 88163	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88163	 38008	 0.02454	 0.018055	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38009	 38010	 0.011412	 0.017807	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38010	 38013	 0.010566	 0.017621	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38010	 88164	 0.004594	 0.024199	 0.00043	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38011	 38012	 0.001345	 0.004688	 0.00109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38011	 38015	 0.002479	 0.008352	 0.00208	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38011	 88164	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38011	 88164	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38012	 38015	 0.001138	 0.003711	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38013	 38014	 0.032399	 0.02564	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88161	 38017	 0.004808	 0.024324	 0.00677	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38017	 88165	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38017	 88165	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38018	 38019	 0.020468	 0.053145	 0.0129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38018	 88166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38018	 88166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38019	 88167	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38019	 88167	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38020	 38031	 0.20589	 0.2243	 0.00305	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88167	 38020	 0.060237	 0.10827	 0.00194	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38021	 38027	 0.014856	 0.043802	 0.01019	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38022	 38023	 0.022268	 0.043642	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87179	 38022	 0.042288	 0.28699	 0.00536	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38024	 38281	 0.015382	 0.046065	 0.01038	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38025	 38053	 0.11581	 0.20898	 0.00302	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38025	 88168	 0.095295	 0.1713	 0.00308	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38026	 38156	 0.010057	 0.045284	 0.01205	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38026	 88168	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38026	 88168	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38027	 38032	 0.009042	 0.023897	 0.00559	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38027	 38358	 0.023862	 0.057513	 0.01624	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38028	 38033	 0.01167	 0.035438	 0.00776	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38028	 38285	 0.019907	 0.047977	 0.01355	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38029	 38030	 0.13765	 0.10128	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38030	 88170	 0.03509	 0.063314	 0.00092	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38031	 88169	 0.023991	 0.031531	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38032	 38033	 0.0039	 0.010124	 0.00246	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38033	 38034	 0.002918	 0.010617	 0.00325	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38033	 88169	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38033	 88169	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38034	 38035	 0.004471	 0.015062	 0.00374	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38034	 38038	 0.004683	 0.019821	 0.00446	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38034	 88170	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38034	 88170	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38035	 38036	 0.009307	 0.023926	 0.00592	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38036	 38358	 0.019602	 0.05181	 0.01213	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87205	 38037	 0.10967	 0.21496	 0.00322	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38039	 38040	 0.003146	 0.016081	 0.00438	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38042	 38180	 0.009627	 0.049217	 0.01342	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38042	 88171	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38042	 88171	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38043	 38048	 0.006787	 0.04074	 0.01234	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38043	 38231	 0.022189	 0.058651	 0.01373	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38043	 38317	 0.014894	 0.059639	 0.01503	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38044	 88173	 0.059142	 0.046805	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38045	 38046	 0.001555	 0.006227	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38045	 38052	 0.004469	 0.016988	 0.00476	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38045	 88172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38045	 88172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38046	 38048	 0.003242	 0.012741	 0.00333	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38046	 88173	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38046	 88173	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88173	 38047	 0.025138	 0.016886	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38048	 38049	 0.005739	 0.022558	 0.0059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87189	 38048	 0.022721	 0.089331	 0.02338	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38049	 38167	 0.011279	 0.060739	 0.01669	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38049	 38205	 0.012686	 0.044392	 0.01471	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88083	 38050	 0.24388	 0.244	 0.0033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88172	 38050	 0.18788	 0.17308	 0.00277	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38051	 38052	 0.007703	 0.022094	 0.00544	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38051	 38371	 0.0079	 0.027532	 0.00638	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38052	 38206	 0.022914	 0.057608	 0.01493	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38053	 88174	 0.067806	 0.13426	 0.00197	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38054	 38055	 0.005131	 0.016039	 0.00465	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38055	 38057	 0.005925	 0.013754	 0.00419	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38055	 88174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38055	 88174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38058	 38059	 0.01451	 0.038349	 0.00898	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38058	 88175	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38058	 88175	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38059	 88176	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38059	 88176	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88175	 38060	 0.015443	 0.10321	 0.00228	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38060	 88225	 0.03903	 0.21934	 0.00406	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38061	 38062	 0.003942	 0.015335	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38061	 88177	 0.004246	 0.015167	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38062	 38069	 0.005712	 0.020405	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38063	 38069	 0.007467	 0.019193	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38063	 88180	 0.012485	 0.02472	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38064	 38065	 0.001811	 0.008306	 0.00213	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38064	 38078	 0.00145	 0.005699	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38064	 88177	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38064	 88177	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38065	 38079	 0.000879	 0.002647	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88177	 38066	 0.030957	 0.021929	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38067	 38068	 0.010549	 0.032395	 0.00061	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38067	 88180	 0.012889	 0.050141	 0.00084	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38068	 38073	 0.037591	 0.10782	 0.00166	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38069	 38070	 0.005216	 0.020909	 0.00054	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38070	 88178	 0.01707	 0.11718	 0.00214	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38070	 88180	 0.019303	 0.064395	 0.00102	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38071	 88178	 0.024315	 0.10835	 0.00184	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38071	 88179	 0.024957	 0.1198	 0.00358	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38072	 88178	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38072	 88178	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88178	 38073	 0.037553	 0.10388	 0.00241	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38074	 38079	 0.017528	 0.048882	 0.01026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38074	 38187	 0.015284	 0.041616	 0.00917	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38076	 38077	 0.009951	 0.040495	 0.00987	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38077	 88179	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38077	 88179	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38078	 88180	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38078	 88180	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38079	 88181	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38079	 88181	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38081	 88182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38081	 88182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38082	 38322	 0.089186	 0.22685	 0.00359	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88182	 38082	 0.08777	 0.22566	 0.00349	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38083	 38086	 0.039331	 0.15302	 0.00255	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38083	 38186	 0.27136	 0.21481	 0.0027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88080	 38083	 0.039132	 0.15056	 0.00257	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38084	 38086	 0.1312	 0.17246	 0.00236	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38085	 38087	 0.053315	 0.17099	 0.00423	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38085	 38243	 0.072722	 0.25452	 0.00527	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38085	 38271	 0.181	 0.12823	 0.00203	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38086	 38087	 0.020255	 0.11514	 0.00208	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38086	 38270	 0.13975	 0.34221	 0.00585	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87195	 38087	 0.024029	 0.19992	 0.00378	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88079	 38087	 0.080643	 0.20511	 0.00324	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38088	 38090	 0.008559	 0.026617	 0.00555	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38088	 38239	 0.009915	 0.029231	 0.0068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38088	 88183	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38088	 88183	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38089	 38091	 0.010407	 0.02985	 0.00734	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38089	 38239	 0.007442	 0.020876	 0.00537	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38090	 38095	 0.006557	 0.019635	 0.00442	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38090	 88184	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38090	 88184	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38091	 38096	 0.009619	 0.026982	 0.00695	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38092	 88185	 0.13302	 0.08936	 0.00158	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38093	 88187	 0.008053	 0.021284	 0.00498	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38094	 38102	 0.023554	 0.054113	 0.00082	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88086	 38094	 0.18117	 0.33705	 0.00789	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38095	 38098	 0.007243	 0.019142	 0.00448	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38095	 38229	 0.005997	 0.024008	 0.00605	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38095	 38320	 0.008086	 0.042121	 0.01105	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38096	 88185	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38096	 88185	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38096	 88187	 0.004393	 0.015527	 0.0035	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38097	 88186	 0.032572	 0.025531	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38098	 88186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38098	 88186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38099	 38316	 0.004885	 0.036401	 0.06937	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38099	 88187	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88188	 38099	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88186	 38100	 0.012237	 0.024228	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88188	 38100	 0.01451	 0.033686	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38101	 38102	 0.038108	 0.028037	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88186	 38102	 0.015823	 0.036734	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88188	 38102	 0.006994	 0.029195	 0.00084	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38103	 38104	 0.004836	 0.018815	 0.00503	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38103	 38233	 0.013466	 0.036665	 0.00808	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88187	 38104	 0.003673	 0.014438	 0.00378	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38105	 38169	 0.009629	 0.040754	 0.00917	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88187	 38105	 0.011571	 0.030041	 0.00729	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88186	 38106	 0.043725	 0.030972	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38107	 88189	 0.23816	 0.18672	 0.0024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38108	 38111	 0.007852	 0.02561	 0.0068	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38108	 38299	 0.018981	 0.065123	 0.0156	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38108	 88189	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38108	 88189	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38109	 38110	 0.00941	 0.034236	 0.01048	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38109	 38294	 0.009383	 0.03757	 0.00947	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38110	 38113	 0.005177	 0.020727	 0.00522	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38111	 38113	 0.002379	 0.008614	 0.00185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38112	 88190	 0.022219	 0.020674	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38112	 88191	 0.008876	 0.016503	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38113	 38114	 0.001965	 0.00662	 0.00165	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38113	 38373	 0.069109	 0.18292	 0.04289	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38113	 88190	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38113	 88190	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38114	 88191	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38114	 88191	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38115	 38119	 0.054997	 0.10073	 0.00174	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88182	 38115	 0.032444	 0.17288	 0.00303	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38116	 38119	 0.085334	 0.12435	 0.00281	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88115	 38116	 0.13019	 0.24937	 0.00392	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38117	 38120	 0.08961	 0.16007	 0.00236	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38118	 38222	 0.012413	 0.040488	 0.01075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38119	 38120	 0.01413	 0.0328	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88092	 38119	 0.091745	 0.30284	 0.00491	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38121	 38122	 0.00102	 0.009434	 0.01775	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87196	 38121	 0.000322	 0.003647	 0.0073	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38121	 88192	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38121	 88192	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38122	 38123	 0.000307	 0.002735	 0.0048	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38123	 88193	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38123	 88193	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38124	 88198	 0.034487	 0.067589	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87197	 38125	 0.05702	 0.14502	 0.00229	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38125	 88195	 0.033068	 0.076773	 0.00114	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38126	 38134	 0.013358	 0.040003	 0.00901	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38126	 88194	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38126	 88194	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88194	 38127	 0.075137	 0.059463	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38128	 38129	 0.002407	 0.006461	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38128	 88197	 0.002175	 0.005636	 0.0017	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38129	 38134	 0.020849	 0.048402	 0.01475	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38129	 88195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38129	 88195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38130	 88196	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38130	 88196	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38130	 88197	 0.004123	 0.011068	 0.00251	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38131	 38132	 0.000656	 0.004578	 0.00786	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38131	 38133	 0.002243	 0.015138	 0.02788	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87196	 38131	 0.002204	 0.017017	 0.03463	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38131	 88197	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88198	 38131	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38132	 88199	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38132	 88199	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38133	 38195	 0.002598	 0.016864	 0.03359	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38133	 88200	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38133	 88200	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88200	 38134	 0.013053	 0.034499	 0.00808	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38135	 38142	 0.002692	 0.007329	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38136	 38138	 0.023076	 0.018262	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88145	 38137	 0.033793	 0.03028	 0.00062	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88144	 38138	 0.01155	 0.022867	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38139	 38140	 0.024775	 0.017549	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38141	 38144	 0.005001	 0.019011	 0.00532	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38141	 38152	 0.007989	 0.033812	 0.00761	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38142	 38143	 0.001937	 0.00561	 0.00135	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38143	 38144	 0.001646	 0.004955	 0.00155	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38144	 88201	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38144	 88201	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38145	 38146	 0.050669	 0.040099	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87194	 38146	 0.026461	 0.052391	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88201	 38147	 0.062716	 0.040603	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38148	 38378	 0.008704	 0.050985	 0.01389	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88147	 38148	 0.005801	 0.034818	 0.01054	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38149	 38151	 0.007548	 0.03022	 0.00761	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38150	 38151	 0.00278	 0.011764	 0.00265	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38150	 38152	 0.001345	 0.005232	 0.0014	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38151	 38154	 0.003004	 0.026614	 0.00709	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38152	 88202	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38152	 88202	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88202	 38153	 0.035716	 0.0253	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38154	 38155	 0.004852	 0.040807	 0.01209	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38155	 88203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38155	 88203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38156	 38159	 0.009042	 0.030465	 0.00757	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38156	 88204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38156	 88204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38157	 38158	 0.066252	 0.10576	 0.00244	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38157	 38322	 0.11229	 0.18756	 0.00319	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38158	 88205	 0.008161	 0.031398	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38159	 88205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38159	 88205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38160	 38161	 0.056656	 0.14565	 0.00225	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88176	 38160	 0.085483	 0.16926	 0.00248	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88205	 38160	 0.051713	 0.13671	 0.00248	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38161	 38324	 0.075419	 0.19389	 0.003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38162	 88207	 0.086055	 0.18089	 0.0033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38163	 38301	 0.15735	 0.36546	 0.00544	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38163	 88206	 0.047767	 0.15168	 0.00266	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38163	 88402	 0.060114	 0.15892	 0.00289	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38164	 38166	 0.00902	 0.032815	 0.01005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38164	 88206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38164	 88206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38165	 88207	 0.051783	 0.04098	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38166	 38167	 0.005753	 0.031711	 0.00741	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87193	 38166	 0.010792	 0.056222	 0.01475	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38166	 88207	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38166	 88207	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38168	 38170	 0.18523	 0.11994	 0.00228	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38169	 38171	 0.007119	 0.030131	 0.00678	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38170	 88208	 0.012341	 0.031723	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38171	 38176	 0.012217	 0.049718	 0.01211	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38171	 88208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38171	 88208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38172	 38173	 0.032989	 0.10121	 0.00274	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88192	 38172	 0.02546	 0.12228	 0.00237	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38173	 88209	 0.094296	 0.18672	 0.00274	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38174	 88209	 0.017061	 0.052338	 0.00142	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38175	 88209	 0.065196	 0.051104	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87185	 38176	 0.049577	 0.2021	 0.04936	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88193	 38176	 0.00933	 0.054193	 0.01276	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38176	 88209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38176	 88209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38177	 38179	 0.00486	 0.034377	 0.00943	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38177	 38361	 0.008229	 0.05514	 0.01689	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38178	 38179	 0.007699	 0.042402	 0.01531	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87192	 38178	 0.007056	 0.043848	 0.01238	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38179	 38373	 0.072896	 0.2218	 0.0487	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38179	 88210	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38179	 88210	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38180	 38182	 0.006455	 0.031327	 0.00716	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38181	 88211	 0.16552	 0.131	 0.00165	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38182	 88211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38182	 88211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38183	 38184	 0.15386	 0.15392	 0.00208	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38183	 38185	 0.037392	 0.13084	 0.00271	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88211	 38183	 0.004857	 0.02761	 0.0005	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38185	 38188	 0.031743	 0.15491	 0.00267	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88211	 38186	 0.090712	 0.13759	 0.00197	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38187	 38189	 0.020755	 0.054859	 0.01284	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38188	 88212	 0.02071	 0.12733	 0.0023	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38189	 38275	 0.023458	 0.069173	 0.0161	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38189	 88212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38189	 88212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38190	 38191	 0.031997	 0.065757	 0.00125	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88166	 38190	 0.087692	 0.19676	 0.00314	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88212	 38191	 0.048995	 0.10993	 0.00175	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38192	 38193	 0.022474	 0.062681	 0.01316	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38192	 88213	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38192	 88213	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38193	 38365	 0.023573	 0.062309	 0.01459	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88213	 38194	 0.14468	 0.11451	 0.00144	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38195	 38197	 0.001259	 0.008174	 0.01628	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38195	 88216	 0.000877	 0.005554	 0.01163	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38196	 38197	 0.001648	 0.011184	 0.02036	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87184	 38196	 0.001889	 0.017319	 0.06837	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38196	 88214	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38196	 88214	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38196	 88216	 0.002107	 0.014369	 0.02587	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38197	 88215	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38197	 88215	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38198	 38201	 7.5e-05	 0.000975	 0.0622	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38198	 88216	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88217	 38198	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88215	 38199	 0.000469	 0.005058	 0.0027	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38199	 88218	 0.000561	 0.0059	 0.00331	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38200	 88219	 0.0527	 0.034118	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38201	 88218	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38202	 38365	 0.009666	 0.050353	 0.01321	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88218	 38202	 0.004395	 0.023624	 0.00581	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38203	 38240	 0.014889	 0.060596	 0.01477	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38203	 38303	 0.011164	 0.047253	 0.01063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38203	 88220	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38203	 88220	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38204	 88221	 0.11679	 0.091547	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87189	 38205	 0.00968	 0.036796	 0.0103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38205	 88221	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38205	 88221	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38206	 38207	 0.020831	 0.056721	 0.0125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87189	 38206	 0.014027	 0.037072	 0.00868	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38207	 88222	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38207	 88222	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38208	 38289	 0.00092	 0.010989	 0.82621	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38208	 88223	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88224	 38208	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38209	 88225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38209	 88225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38210	 38212	 0.07455	 0.24874	 0.00394	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38210	 38215	 0.092491	 0.18931	 0.00466	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38210	 38324	 0.11473	 0.40168	 0.00833	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88225	 38210	 0.031878	 0.19601	 0.00353	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88225	 38211	 0.12499	 0.098919	 0.00125	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38212	 88226	 0.087978	 0.20428	 0.00304	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38213	 38215	 0.061684	 0.093556	 0.00134	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38214	 88226	 0.05686	 0.11258	 0.00165	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88119	 38215	 0.12426	 0.26635	 0.00466	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38216	 88226	 0.069277	 0.054825	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38217	 88226	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38217	 88226	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38219	 38220	 0.017595	 0.05929	 0.01474	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87181	 38220	 0.06472	 0.18184	 0.04689	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38221	 88228	 0.091346	 0.12453	 0.00276	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38222	 38225	 0.005258	 0.014662	 0.00308	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38223	 88227	 0.052953	 0.057677	 0.00079	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38224	 88227	 0.044715	 0.03505	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38225	 88227	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38225	 88227	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88227	 38226	 0.030732	 0.071349	 0.00106	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38226	 88228	 0.043987	 0.11142	 0.00221	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87178	 38227	 0.04414	 0.25406	 0.08489	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38227	 88228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38227	 88228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88228	 38228	 0.14717	 0.11537	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38229	 38232	 0.007276	 0.029132	 0.00734	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38230	 88230	 0.03518	 0.081664	 0.00155	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38231	 38232	 0.016362	 0.043245	 0.01012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38231	 88229	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38231	 88229	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38232	 38233	 0.009521	 0.031055	 0.00824	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38232	 38234	 0.010249	 0.041038	 0.01034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88187	 38232	 0.027865	 0.073659	 0.01725	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38232	 88230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38232	 88230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38235	 38237	 0.001681	 0.01121	 0.02113	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38235	 38312	 0.003038	 0.020722	 0.03732	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38236	 38239	 0.009182	 0.036762	 0.00926	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38236	 88231	 0.004613	 0.01813	 0.00474	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38237	 88231	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38237	 88231	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88183	 38238	 0.24159	 0.2658	 0.00355	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38240	 88232	 0.008089	 0.031791	 0.00832	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38241	 38242	 0.000835	 0.008907	 0.01614	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87188	 38241	 0.004738	 0.030017	 0.06289	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88223	 38241	 0.004486	 0.030278	 0.05577	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38241	 88232	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38241	 88232	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38242	 38298	 0.001641	 0.016822	 0.03306	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38243	 38249	 0.059155	 0.13734	 0.00204	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38243	 88233	 0.051079	 0.13239	 0.0025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38244	 38275	 0.038284	 0.10681	 0.02243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38244	 88233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38244	 88233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38244	 88236	 0.017526	 0.070181	 0.01769	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38245	 38250	 0.028474	 0.051377	 0.00074	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38246	 38247	 0.011903	 0.033777	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38246	 38258	 0.047926	 0.068036	 0.00112	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38246	 38269	 0.003663	 0.016983	 0.00035	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38247	 38252	 0.01192	 0.023361	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38248	 38249	 0.03484	 0.074662	 0.00131	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38248	 38250	 0.01191	 0.034159	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38248	 38251	 0.03247	 0.025696	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38250	 88234	 0.013991	 0.05599	 0.00118	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38252	 38262	 0.027112	 0.032456	 0.00054	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38253	 38261	 0.01219	 0.020535	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38254	 88234	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38254	 88234	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88153	 38255	 0.00363	 0.012831	 0.00289	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38255	 88235	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38255	 88235	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38256	 88236	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88237	 38256	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88237	 38257	 0.068486	 0.054199	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38258	 38260	 0.045892	 0.035972	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38258	 38261	 0.009898	 0.02121	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88237	 38258	 0.022313	 0.051794	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38259	 38261	 0.00569	 0.019923	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38262	 38263	 0.077684	 0.057156	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38263	 38264	 0.074786	 0.055023	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88237	 38263	 0.033933	 0.1132	 0.00179	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38265	 38267	 0.092246	 0.16897	 0.00292	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38266	 38268	 0.018461	 0.056635	 0.00153	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88235	 38266	 0.013199	 0.064409	 0.00111	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88237	 38266	 0.039252	 0.062655	 0.00144	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38267	 38280	 0.21103	 0.21319	 0.00282	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88237	 38267	 0.030971	 0.13801	 0.00234	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38268	 38280	 0.088208	 0.14081	 0.00324	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88234	 38269	 0.005977	 0.031081	 0.00067	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38270	 38274	 0.034723	 0.13359	 0.00228	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38272	 38273	 0.045271	 0.061711	 0.00137	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38272	 38274	 0.066177	 0.10326	 0.00173	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88233	 38272	 0.16061	 0.26334	 0.00465	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38272	 88238	 0.12764	 0.13904	 0.00189	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38274	 88238	 0.037035	 0.073327	 0.00108	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38275	 38283	 0.018449	 0.051757	 0.01332	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38275	 88238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38275	 88238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38276	 38277	 0.004544	 0.01849	 0.0045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38276	 88252	 0.04461	 0.12153	 0.02679	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38277	 38354	 0.019057	 0.076315	 0.01923	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38277	 88239	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38277	 88239	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38278	 38279	 0.18239	 0.1181	 0.00225	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38278	 88241	 0.16321	 0.12794	 0.00164	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38279	 38280	 0.23035	 0.18233	 0.0023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38280	 88240	 0.11475	 0.21021	 0.00363	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38281	 38282	 0.017359	 0.048412	 0.01016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38281	 88240	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38281	 88240	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38282	 38284	 0.015642	 0.041997	 0.00952	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38282	 88241	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38282	 88241	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38286	 38287	 0.012197	 0.037932	 0.00792	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38286	 38288	 0.008317	 0.0333	 0.00839	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38286	 88242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38286	 88242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38289	 88243	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38289	 88243	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38290	 38291	 0.014106	 0.041591	 0.00968	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38291	 88244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38291	 88244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38292	 38293	 0.005658	 0.02493	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88244	 38292	 0.016628	 0.074094	 0.00126	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38293	 88245	 0.018778	 0.082736	 0.00144	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38294	 38295	 0.008804	 0.034603	 0.00905	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38295	 38337	 0.003015	 0.032639	 0.01374	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38295	 38373	 0.067889	 0.1851	 0.04085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38295	 88245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38295	 88245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38296	 38297	 0.00136	 0.004666	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88224	 38296	 0.02665	 0.088935	 0.02256	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38297	 38299	 0.017573	 0.063639	 0.01366	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38297	 38372	 0.023865	 0.063081	 0.01477	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88243	 38298	 0.002304	 0.023338	 0.04699	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88206	 38300	 0.098977	 0.18407	 0.00431	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38300	 88246	 0.073756	 0.20433	 0.00337	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38301	 88246	 0.035208	 0.081728	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38302	 38303	 0.006309	 0.025259	 0.00636	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38302	 38313	 0.013936	 0.050467	 0.01083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88107	 38302	 0.008637	 0.03053	 0.00688	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87188	 38304	 0.003294	 0.028978	 0.06047	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88223	 38304	 0.003424	 0.032589	 0.05793	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38304	 88246	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38304	 88246	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38305	 38306	 0.0118	 0.042729	 0.00917	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38306	 38307	 0.007539	 0.018169	 0.00513	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87202	 38306	 0.024746	 0.07099	 0.01747	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38307	 38308	 0.009015	 0.023406	 0.00568	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87202	 38308	 0.01037	 0.035573	 0.00852	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38309	 38310	 0.010829	 0.028621	 0.0067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38310	 38311	 0.004804	 0.019234	 0.00485	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38311	 88247	 0.013257	 0.053951	 0.01315	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38312	 88247	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38312	 88247	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38313	 88248	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38313	 88248	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38314	 38315	 0.075556	 0.059795	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88248	 38314	 0.064494	 0.1277	 0.00187	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38316	 88249	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38316	 88249	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38317	 38318	 0.009166	 0.031442	 0.00753	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38317	 88250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38317	 88250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38318	 88251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38318	 88251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87203	 38319	 0.009474	 0.058248	 0.00105	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88251	 38319	 0.009929	 0.046037	 0.00096	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87202	 38320	 0.006181	 0.0322	 0.00845	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88229	 38321	 0.061893	 0.13009	 0.00237	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88250	 38321	 0.049817	 0.11797	 0.00216	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88228	 38322	 0.17905	 0.25424	 0.00418	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38323	 38324	 0.1558	 0.11463	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88228	 38324	 0.1002	 0.33436	 0.0053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38325	 88252	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38325	 88252	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38326	 38327	 0.037912	 0.029717	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38327	 88253	 0.006174	 0.012225	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38328	 38333	 0.01036	 0.034909	 0.00868	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38328	 88253	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38328	 88253	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38328	 88255	 0.003542	 0.016249	 0.00416	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88253	 38329	 0.044201	 0.03498	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38329	 88254	 0.024425	 0.035753	 0.00055	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38330	 38334	 0.007024	 0.024096	 0.00577	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38330	 88254	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38330	 88254	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38330	 88255	 0.003796	 0.013419	 0.00302	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88253	 38331	 0.02834	 0.022428	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87182	 38332	 0.000191	 0.002379	 0.00845	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38332	 88255	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38332	 88255	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38333	 38334	 0.005793	 0.016616	 0.00409	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88255	 38335	 0.007975	 0.027357	 0.00655	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87178	 38336	 0.00557	 0.047774	 0.0136	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87183	 38336	 0.00384	 0.030852	 0.00867	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38337	 38353	 0.00265	 0.026546	 0.00884	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38337	 38355	 0.009065	 0.030543	 0.00759	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38337	 88256	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38337	 88256	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38338	 38339	 0.000491	 0.005758	 0.01285	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38338	 88257	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38338	 88257	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38339	 38340	 0.000197	 0.00203	 0.00394	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38339	 88258	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38339	 88258	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38340	 38347	 0.000134	 0.001377	 0.00267	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38341	 38343	 0.000333	 0.004194	 0.01002	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38341	 38346	 7.9e-05	 0.000899	 0.00212	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38342	 38350	 0.001886	 0.00717	 0.00201	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38342	 88260	 0.002148	 0.009092	 0.00205	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38343	 88259	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38343	 88259	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88259	 38344	 0.022016	 0.040324	 0.0007	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38345	 88261	 0.017797	 0.012606	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38346	 38347	 9.2e-05	 0.000978	 0.00177	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38346	 88260	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88261	 38346	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88261	 38348	 0.029919	 0.023677	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38349	 88262	 0.012275	 0.022483	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38350	 38353	 0.002464	 0.0256	 0.00792	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88258	 38350	 0.003458	 0.013143	 0.00368	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38350	 88262	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38350	 88262	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38351	 88263	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38351	 88263	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38352	 88264	 0.050763	 0.040173	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38353	 88264	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38353	 88264	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38354	 38355	 0.002251	 0.007037	 0.00204	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88263	 38354	 0.006267	 0.034776	 0.01057	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38356	 38357	 0.010199	 0.030069	 0.007	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38357	 38358	 0.010063	 0.041549	 0.00983	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38357	 38359	 0.0134	 0.04371	 0.01161	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87656	 38357	 0.073148	 0.1967	 0.04467	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38360	 88265	 0.18355	 0.20192	 0.0027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38361	 38362	 0.005094	 0.03081	 0.00786	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87185	 38362	 0.00418	 0.042256	 0.01243	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38362	 88265	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38362	 88265	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38363	 38364	 0.19513	 0.25652	 0.00352	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88076	 38364	 0.14793	 0.26595	 0.00478	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38365	 38368	 0.004117	 0.029618	 0.00785	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38366	 38367	 0.008944	 0.034798	 0.00929	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38367	 38368	 0.001503	 0.01126	 0.00275	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38368	 88266	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38368	 88266	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88171	 38369	 0.3431	 0.34336	 0.00464	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88266	 38369	 0.21091	 0.1552	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38370	 38371	 0.013834	 0.047459	 0.01137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38370	 38372	 0.018757	 0.047156	 0.01222	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38373	 38375	 0.011313	 0.043005	 0.01204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88252	 38373	 0.070948	 0.18267	 0.04532	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38373	 88267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38373	 88267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38374	 88268	 0.03432	 0.027161	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38375	 88268	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38375	 88268	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38376	 38377	 0.018753	 0.049566	 0.0116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38377	 38378	 0.006708	 0.03996	 0.01051	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38379	 38384	 0.001319	 0.00528	 0.00133	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38379	 88274	 0.002362	 0.009456	 0.00238	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87217	 38380	 0.002554	 0.010038	 0.00263	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38380	 88274	 0.003908	 0.018965	 0.00434	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38381	 88269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38381	 88269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38381	 88274	 0.001789	 0.018399	 0.00522	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88269	 38382	 0.019808	 0.020006	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88269	 38383	 0.016046	 0.03177	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38384	 38385	 0.000752	 0.005924	 0.00173	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38384	 38390	 0.001814	 0.017725	 0.00497	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38385	 39328	 0.001373	 0.009567	 0.0036	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38386	 38390	 0.002414	 0.023173	 0.00674	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38386	 38464	 0.004159	 0.032419	 0.00969	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38386	 88270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38386	 88270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38387	 38392	 0.003964	 0.021851	 0.00511	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38387	 38471	 0.005124	 0.026689	 0.007	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38388	 38389	 0.046728	 0.091579	 0.00137	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38389	 88272	 0.019281	 0.054713	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38390	 38392	 0.006102	 0.031193	 0.0085	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38390	 39280	 0.006837	 0.035616	 0.00934	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38390	 88271	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38390	 88271	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38391	 38394	 0.039718	 0.040556	 0.00063	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88271	 38391	 0.12739	 0.082475	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38393	 38471	 0.008354	 0.051913	 0.01465	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87217	 38393	 0.00349	 0.021447	 0.00784	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38393	 88272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38393	 88272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87218	 38394	 0.015021	 0.05011	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38395	 39083	 0.000842	 0.008433	 0.00281	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38395	 39085	 0.001867	 0.014708	 0.0043	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87217	 38395	 0.000445	 0.005865	 0.00359	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38396	 39021	 0.000179	 0.003317	 0.2624	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38396	 39338	 7.1e-05	 0.00111	 0.10782	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38396	 88273	 0.000118	 0.009419	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38396	 88273	 0.000118	 0.009419	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38397	 38404	 0.002123	 0.023479	 0.00704	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38397	 39371	 0.002315	 0.024191	 0.00665	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38398	 88277	 0.068444	 0.13552	 0.00199	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38399	 38400	 0.002857	 0.023711	 0.00624	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38399	 39131	 0.006302	 0.049659	 0.01453	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38400	 38401	 0.001958	 0.019786	 0.00582	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38400	 38541	 0.021219	 0.07685	 0.01649	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38400	 88276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38400	 88276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38401	 39370	 0.008346	 0.052866	 0.01435	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38401	 88277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38401	 88277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88276	 38402	 0.026778	 0.080598	 0.00158	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38403	 38404	 0.006235	 0.024961	 0.00629	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38403	 38405	 0.002585	 0.019473	 0.0054	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38403	 88278	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38403	 88278	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38404	 38535	 0.00933	 0.039492	 0.00889	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38405	 39276	 0.0028	 0.023847	 0.00595	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38406	 38970	 0.000226	 0.002922	 0.18652	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38406	 88279	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38406	 88279	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38407	 38409	 0.005235	 0.013834	 0.00324	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88279	 38407	 0.013196	 0.033172	 0.00859	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38408	 38724	 0.008036	 0.036185	 0.00963	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87233	 38408	 0.008559	 0.043006	 0.01119	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38409	 38410	 0.005382	 0.015007	 0.00315	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38410	 38475	 0.008387	 0.031882	 0.00893	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87233	 38410	 0.005171	 0.032754	 0.00889	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38411	 39325	 0.10971	 0.071032	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38412	 38413	 0.049781	 0.091181	 0.00157	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38412	 88579	 0.04623	 0.16177	 0.00335	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38413	 39762	 0.17315	 0.1624	 0.00251	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38414	 38415	 0.002318	 0.006463	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38414	 88280	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38414	 88280	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38414	 88284	 0.004027	 0.014583	 0.00313	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38415	 38440	 0.001574	 0.005565	 0.00125	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38416	 88281	 0.02261	 0.044766	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38417	 38440	 0.001702	 0.006164	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38417	 39064	 0.002833	 0.015252	 0.00419	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38417	 88281	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38417	 88281	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38418	 38421	 0.001893	 0.013123	 0.00769	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38418	 38429	 0.002594	 0.020707	 0.0051	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38418	 39057	 0.006948	 0.018654	 0.00423	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38419	 88282	 0.007569	 0.012082	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38420	 38421	 0.001423	 0.006783	 0.00196	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38420	 88282	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38420	 88282	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38420	 88284	 0.001858	 0.01024	 0.00239	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38421	 38424	 0.003088	 0.008408	 0.00185	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38421	 88283	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38421	 88283	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38421	 88284	 0.00245	 0.015518	 0.00421	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88280	 38422	 0.003197	 0.015602	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88283	 38422	 0.003479	 0.016984	 0.00036	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88283	 38423	 0.025395	 0.045359	 0.00067	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38424	 38425	 0.003426	 0.008808	 0.00218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38425	 38432	 0.007481	 0.019421	 0.00471	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38426	 38427	 0.017501	 0.025502	 0.00058	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38427	 88285	 0.014942	 0.042855	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38428	 39032	 0.003411	 0.023018	 0.04239	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38428	 39425	 0.00288	 0.039228	 0.07988	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87240	 38428	 0.003928	 0.027064	 0.04779	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38428	 88284	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88285	 38428	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38428	 88584	 0.003461	 0.044726	 0.10145	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38429	 38430	 0.004471	 0.016188	 0.00347	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38429	 39055	 0.004872	 0.012524	 0.0031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38429	 39414	 0.004741	 0.018982	 0.00478	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38430	 38431	 0.006949	 0.023412	 0.00582	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38431	 39422	 0.007309	 0.025073	 0.00601	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38432	 38441	 0.010267	 0.027952	 0.00616	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87241	 38433	 0.010327	 0.027292	 0.00639	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87242	 38434	 0.15285	 0.12097	 0.00152	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38435	 38436	 0.007171	 0.016646	 0.00507	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38436	 38437	 0.002726	 0.014437	 0.00366	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88284	 38436	 0.004151	 0.022068	 0.00512	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38437	 39144	 0.004364	 0.022734	 0.00596	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38438	 38439	 0.002594	 0.013511	 0.00354	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88284	 38438	 0.003404	 0.015617	 0.004	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38439	 39064	 0.005304	 0.018194	 0.00436	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38439	 39073	 0.002469	 0.012858	 0.00337	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88284	 38440	 0.007423	 0.019617	 0.00459	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87241	 38441	 0.017213	 0.046215	 0.01048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38442	 38443	 0.001478	 0.006255	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38442	 38456	 0.002753	 0.011021	 0.00278	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38443	 38448	 0.003343	 0.013005	 0.00347	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38444	 38448	 0.003149	 0.012814	 0.00312	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38444	 88286	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38444	 88286	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38445	 38446	 0.018408	 0.011917	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38445	 38447	 0.015756	 0.021478	 0.00048	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38445	 38449	 0.015427	 0.023633	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38445	 38452	 0.04033	 0.082534	 0.00203	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88286	 38445	 0.010314	 0.023945	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38445	 88287	 0.005678	 0.028724	 0.0005	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38446	 38447	 0.007774	 0.015392	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38447	 38856	 0.052872	 0.1082	 0.00266	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38448	 38451	 0.002918	 0.007713	 0.00181	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38448	 38458	 0.004806	 0.025036	 0.00657	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87215	 38448	 0.004059	 0.03324	 0.02137	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38448	 88287	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38448	 88287	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38449	 38450	 0.039045	 0.025278	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88287	 38449	 0.008045	 0.020681	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38451	 88288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38451	 88288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38452	 39305	 0.072193	 0.1856	 0.00287	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88286	 38452	 0.024099	 0.063875	 0.00162	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38453	 38454	 0.002027	 0.009203	 0.00319	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38453	 39156	 0.006699	 0.050463	 0.014	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38453	 39158	 0.006169	 0.032135	 0.00843	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87215	 38453	 0.005122	 0.064449	 0.01997	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38454	 38456	 0.00222	 0.021688	 0.00609	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38455	 38456	 0.000589	 0.006514	 0.00195	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87215	 38455	 0.002735	 0.024802	 0.01297	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88287	 38457	 0.033749	 0.030241	 0.00062	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38458	 38886	 0.004148	 0.021605	 0.00567	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38459	 38460	 0.070301	 0.092399	 0.00127	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38459	 39305	 0.033407	 0.10249	 0.00278	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88288	 38459	 0.012864	 0.080777	 0.00177	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38461	 38462	 0.004062	 0.02873	 0.00788	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38461	 38467	 0.003099	 0.024109	 0.00626	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38462	 88289	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38462	 88289	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38463	 88607	 0.1853	 0.14215	 0.00191	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38464	 38465	 0.005358	 0.022124	 0.00523	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38464	 39402	 0.018239	 0.077212	 0.01738	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38464	 88290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38464	 88290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38465	 38466	 0.004854	 0.016651	 0.00399	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38466	 38467	 0.001455	 0.011685	 0.00328	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38466	 38471	 0.003563	 0.022138	 0.00625	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38468	 38469	 0.11476	 0.090822	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38469	 88291	 0.056574	 0.10169	 0.00183	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38470	 88291	 0.076664	 0.049634	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38471	 88291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38471	 88291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38472	 38473	 0.00744	 0.034131	 0.00874	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38472	 38731	 0.014101	 0.049149	 0.0114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38473	 39369	 0.011228	 0.039689	 0.00894	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38473	 88292	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38473	 88292	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38473	 88307	 0.009992	 0.06535	 0.02421	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38474	 39766	 0.05655	 0.10204	 0.00148	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88292	 38474	 0.044459	 0.088027	 0.00129	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38474	 88306	 0.030392	 0.15201	 0.00271	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38475	 38476	 0.008815	 0.034649	 0.00906	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38476	 38478	 0.011614	 0.029195	 0.00756	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38476	 88293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38476	 88293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38476	 88294	 0.021285	 0.074195	 0.01721	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38477	 38478	 0.006565	 0.025803	 0.00675	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38477	 38479	 0.0113	 0.028405	 0.00736	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38477	 39808	 0.00982	 0.033686	 0.00807	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38478	 38961	 0.009918	 0.027658	 0.00581	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38479	 88294	 0.015021	 0.04189	 0.00879	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38480	 88295	 0.15132	 0.11862	 0.00152	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88293	 38481	 0.24661	 0.1597	 0.00304	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38482	 38958	 0.008095	 0.055812	 0.09865	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38482	 39182	 0.004956	 0.033814	 0.06091	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87229	 38482	 0.00961	 0.065283	 0.11908	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38482	 88294	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88295	 38482	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38483	 38485	 0.001984	 0.005151	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38483	 88296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38483	 88296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38484	 88297	 0.008591	 0.028658	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38484	 88757	 0.024625	 0.082148	 0.0013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38485	 88297	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38485	 88297	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88296	 38486	 0.032174	 0.02279	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38487	 38496	 0.039699	 0.07091	 0.00105	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38487	 38498	 0.18557	 0.14688	 0.00185	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88296	 38487	 0.058514	 0.059102	 0.00078	 33.0	 33.0	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38488	 38489	 0.023345	 0.047774	 0.00118	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88297	 38488	 0.018378	 0.042223	 0.00064	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38489	 38491	 0.012431	 0.031488	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38490	 39777	 0.020329	 0.031142	 0.00044	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38491	 88756	 0.011727	 0.032439	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38492	 38493	 0.017674	 0.058326	 0.00094	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38492	 88756	 0.00964	 0.037501	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38493	 88298	 0.01465	 0.042017	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38494	 39692	 0.006144	 0.014806	 0.00418	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38494	 88298	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38494	 88298	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38495	 38990	 0.042256	 0.10863	 0.00168	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38495	 88732	 0.045614	 0.12091	 0.00307	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38496	 38497	 0.11024	 0.087249	 0.0011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38500	 38506	 0.002998	 0.015324	 0.00418	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38500	 38507	 0.004018	 0.020327	 0.00566	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38501	 88299	 0.11543	 0.084926	 0.00124	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38502	 38506	 0.002352	 0.01225	 0.00321	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38502	 88299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38502	 88299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38502	 88331	 0.007428	 0.038693	 0.01015	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38503	 38504	 0.00316	 0.016734	 0.00424	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38503	 39352	 0.003765	 0.01994	 0.00505	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38503	 88300	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38503	 88300	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38504	 38505	 0.003722	 0.019025	 0.00519	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38507	 38734	 0.00509	 0.026513	 0.00695	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38508	 88775	 0.055961	 0.10968	 0.00164	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38509	 38510	 0.007212	 0.028875	 0.00727	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38509	 38949	 0.012638	 0.043356	 0.01039	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38509	 38952	 0.020539	 0.054287	 0.01271	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38510	 38511	 0.007064	 0.029898	 0.00673	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38510	 39160	 0.00933	 0.037357	 0.00941	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38510	 39196	 0.007386	 0.028734	 0.00767	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38511	 38916	 0.011075	 0.043532	 0.01139	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38512	 38519	 0.094327	 0.074651	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38513	 38514	 0.005777	 0.022706	 0.00594	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38514	 38518	 0.004126	 0.021852	 0.00554	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38515	 38516	 0.0307	 0.088053	 0.00135	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87669	 38515	 0.052105	 0.10952	 0.002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38516	 88301	 0.036252	 0.12685	 0.00263	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38517	 38518	 0.004436	 0.023884	 0.00656	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38517	 39759	 0.00818	 0.052696	 0.01382	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38517	 88301	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38517	 88301	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38518	 38520	 0.006904	 0.033691	 0.00931	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38518	 88302	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38518	 88302	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88302	 38519	 0.026439	 0.099185	 0.00178	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38519	 88303	 0.12944	 0.095239	 0.00139	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38520	 38796	 0.00561	 0.02868	 0.00782	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38520	 38799	 0.007154	 0.03619	 0.01008	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38520	 88303	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38520	 88303	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38522	 39166	 0.007855	 0.041755	 0.00969	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38523	 88304	 0.14563	 0.10529	 0.0016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38524	 38529	 0.005777	 0.019819	 0.00475	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38524	 38980	 0.012724	 0.033628	 0.00787	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38524	 88304	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38524	 88304	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38525	 38528	 0.008053	 0.041951	 0.011	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38525	 38811	 0.006161	 0.033965	 0.00794	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38526	 88305	 0.23507	 0.18606	 0.00234	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38527	 38528	 0.003804	 0.020969	 0.0049	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38527	 38529	 0.003668	 0.014416	 0.00377	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38527	 39419	 0.006137	 0.038135	 0.01076	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38528	 88305	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38528	 88305	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38530	 38531	 0.021526	 0.083743	 0.0014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88305	 38530	 0.030282	 0.080051	 0.00145	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88305	 38531	 0.060634	 0.14359	 0.00263	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38531	 88611	 0.040657	 0.15818	 0.00264	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38531	 88616	 0.05179	 0.25277	 0.00436	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38532	 88306	 0.050097	 0.10696	 0.00241	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38532	 88308	 0.040371	 0.093728	 0.00139	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38532	 88610	 0.47587	 0.62631	 0.00859	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38533	 38534	 0.004022	 0.022068	 0.00583	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38533	 88306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38533	 88306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38533	 88307	 0.003312	 0.030123	 0.0076	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38534	 39371	 0.008408	 0.042246	 0.01099	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38535	 38540	 0.003466	 0.019231	 0.00585	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38536	 88308	 0.016924	 0.043505	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38537	 88307	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88308	 38537	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38537	 88311	 0.000664	 0.007644	 0.0276	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38538	 38817	 0.009767	 0.032909	 0.00818	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38538	 88312	 0.010659	 0.024744	 0.00754	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38539	 88309	 0.017922	 0.041609	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38539	 88310	 0.011641	 0.023923	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38540	 88309	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38540	 88309	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38540	 88312	 0.003953	 0.02177	 0.00786	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38541	 38542	 0.004521	 0.011622	 0.00288	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38541	 88310	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38541	 88310	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38541	 88312	 0.009247	 0.032229	 0.00747	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38541	 88312	 0.009247	 0.032229	 0.00747	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38542	 39276	 0.011696	 0.038149	 0.01013	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38543	 88311	 0.000104	 0.008342	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88312	 38543	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38544	 38548	 0.00722	 0.025162	 0.00583	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38544	 38782	 0.005919	 0.021433	 0.0046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38545	 88313	 0.068749	 0.12405	 0.00179	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38546	 38547	 0.007684	 0.030765	 0.00775	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38546	 38781	 0.006785	 0.026666	 0.00698	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38547	 38942	 0.013163	 0.055719	 0.01254	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38548	 38944	 0.006766	 0.047856	 0.01313	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38548	 39192	 0.008595	 0.026865	 0.00778	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38548	 88313	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38548	 88313	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38549	 38550	 0.10836	 0.085758	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38550	 38555	 0.025053	 0.075406	 0.00147	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38550	 38562	 0.02309	 0.080845	 0.00224	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38551	 38554	 0.007656	 0.035122	 0.009	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38551	 38764	 0.013113	 0.039472	 0.01235	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38552	 88314	 0.064704	 0.12811	 0.00188	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38553	 39811	 0.03316	 0.14178	 0.0032	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38553	 88314	 0.042921	 0.12311	 0.00189	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38554	 38556	 0.004925	 0.016062	 0.00426	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38554	 39403	 0.03632	 0.18275	 0.04766	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87212	 38554	 0.009383	 0.080854	 0.04699	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38554	 88314	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38554	 88314	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38555	 38559	 0.069797	 0.051352	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38555	 88315	 0.014488	 0.041553	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38556	 88315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38556	 88315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88314	 38557	 0.043701	 0.057436	 0.00079	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38558	 38560	 0.061975	 0.041631	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88315	 38558	 0.029899	 0.053405	 0.00079	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88315	 38561	 0.076816	 0.15056	 0.00226	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38562	 39322	 0.032977	 0.16093	 0.00278	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38563	 38564	 0.023729	 0.060347	 0.00095	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38563	 39348	 0.027905	 0.071734	 0.00111	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38564	 38565	 0.026867	 0.059465	 0.00098	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38565	 38601	 0.021902	 0.050848	 0.00076	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38566	 88326	 0.03144	 0.041322	 0.00057	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38567	 38569	 0.024202	 0.051865	 0.00091	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38567	 88326	 0.019606	 0.076272	 0.00127	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38568	 38569	 0.026194	 0.047978	 0.00083	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38569	 38570	 0.005053	 0.013097	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38570	 88316	 0.001445	 0.008881	 0.0002	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38571	 88316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38571	 88316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38571	 88317	 0.001346	 0.004872	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38572	 88317	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88318	 38572	 0.000318	 0.023855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38572	 88384	 0.000925	 0.010728	 0.03813	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38573	 88320	 0.006386	 0.013068	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38574	 38577	 0.000993	 0.00629	 0.00171	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38574	 39730	 0.003822	 0.010102	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38574	 88319	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38574	 88319	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38575	 38621	 0.002377	 0.012368	 0.00364	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38575	 38622	 0.001967	 0.006749	 0.00162	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38576	 88342	 0.015961	 0.028799	 0.00042	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38577	 38578	 0.000729	 0.005156	 0.00141	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38578	 38579	 0.000963	 0.004559	 0.0011	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38578	 88320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38578	 88320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38578	 88325	 0.004268	 0.021591	 0.00601	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38579	 38580	 0.001756	 0.007972	 0.00277	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38579	 38581	 0.00076	 0.003886	 0.00106	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38579	 38588	 0.001206	 0.008907	 0.00257	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88317	 38580	 0.00176	 0.008844	 0.0023	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38581	 38583	 0.001376	 0.007583	 0.00177	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38582	 88321	 0.018744	 0.019139	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38583	 88321	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38583	 88321	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38583	 88325	 0.002002	 0.010232	 0.00279	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38584	 38585	 0.009501	 0.018811	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38584	 88326	 0.006136	 0.022689	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38585	 38586	 0.018498	 0.019709	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38585	 88323	 0.007059	 0.023548	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38587	 88322	 0.014723	 0.018737	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38588	 38590	 0.000361	 0.003399	 0.00103	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38588	 88322	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38588	 88322	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38589	 38593	 0.001314	 0.00526	 0.00133	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38589	 88323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38589	 88323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38589	 88327	 0.000893	 0.006634	 0.00253	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38590	 38593	 0.000611	 0.003354	 0.00089	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38590	 88385	 0.003229	 0.012929	 0.00326	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38591	 88324	 0.004593	 0.022411	 0.00039	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38591	 88342	 0.006298	 0.016693	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38592	 38597	 0.00171	 0.006958	 0.0017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38592	 88324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38592	 88324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38593	 38596	 0.000865	 0.002966	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38594	 38595	 0.013178	 0.010329	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38594	 38598	 0.01009	 0.007909	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38595	 88382	 0.007514	 0.010949	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38596	 38597	 0.001157	 0.003057	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38596	 38717	 0.001448	 0.003754	 0.00114	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38597	 88385	 0.001007	 0.005238	 0.00154	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88323	 38598	 0.028235	 0.020773	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38598	 88382	 0.026137	 0.020684	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38599	 38600	 0.000171	 0.001603	 0.00295	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38599	 88325	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88326	 38599	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38600	 38719	 0.000445	 0.003065	 0.00541	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38600	 88327	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38600	 88327	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38600	 88328	 0.000313	 0.004749	 0.01077	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88326	 38601	 0.005432	 0.029065	 0.00088	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38601	 88329	 0.003663	 0.021946	 0.00053	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38602	 38603	 3.4e-05	 0.000403	 0.0302	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38602	 38721	 0.000107	 0.001979	 0.13069	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38602	 88328	 9.1e-05	 0.007299	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38603	 88330	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38603	 88330	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88332	 38604	 0.071936	 0.046572	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88329	 38605	 0.073257	 0.057975	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38605	 88333	 0.019273	 0.015252	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38605	 88369	 0.12168	 0.096302	 0.00121	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38606	 38676	 0.000751	 0.004123	 0.00109	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88331	 38606	 0.001186	 0.007511	 0.00204	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38606	 88333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38606	 88333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38607	 38609	 0.00017	 0.001618	 0.00591	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38607	 38611	 0.000357	 0.002319	 0.00462	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88330	 38607	 0.000173	 0.002527	 0.00968	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38607	 88334	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38607	 88334	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38608	 38660	 0.00035	 0.004004	 0.00122	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88331	 38608	 0.002227	 0.014105	 0.00383	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88334	 38608	 0.00087	 0.004929	 0.00122	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38608	 88335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38608	 88335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38609	 38610	 0.000297	 0.001927	 0.00384	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38609	 38659	 8.8e-05	 0.000855	 0.00298	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38610	 38611	 5.7e-05	 0.000854	 0.002	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38610	 88336	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88337	 38610	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38611	 38613	 8.7e-05	 0.001216	 0.00233	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88328	 38611	 0.000224	 0.002291	 0.00727	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38611	 88338	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38611	 88338	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88327	 38612	 0.001518	 0.004568	 0.00143	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38612	 88339	 0.000869	 0.004528	 0.00119	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38613	 38614	 8.3e-05	 0.000769	 0.00145	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38613	 88339	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38613	 88339	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38614	 88340	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38614	 88340	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38615	 38720	 0.000864	 0.005566	 0.00146	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88336	 38615	 0.000454	 0.003211	 0.00088	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88337	 38616	 0.010677	 0.006913	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88338	 38617	 0.005602	 0.02496	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38617	 88361	 0.017562	 0.017566	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38618	 38653	 0.010519	 0.008324	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38618	 88356	 0.034308	 0.022211	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38618	 88382	 0.024395	 0.026831	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38619	 38626	 0.001142	 0.008602	 0.00239	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38619	 38627	 0.002467	 0.006521	 0.00153	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38619	 88341	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38619	 88341	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38619	 88385	 0.0009	 0.008823	 0.00276	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88324	 38620	 0.006799	 0.022436	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88341	 38620	 0.030323	 0.022973	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38620	 88345	 0.059658	 0.046763	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38621	 88342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38621	 88342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38621	 88385	 0.002713	 0.017477	 0.00458	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38622	 39861	 0.002136	 0.007328	 0.00176	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38623	 88344	 0.022206	 0.029185	 0.0004	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38624	 38625	 0.001686	 0.005784	 0.00139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38624	 38626	 0.002193	 0.009546	 0.00272	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38624	 88343	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38624	 88343	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38625	 39863	 0.002378	 0.006284	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38626	 88344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38626	 88344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38627	 88345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38627	 88345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38628	 38639	 0.013062	 0.020006	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38629	 39862	 0.029439	 0.054738	 0.00128	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38630	 38637	 0.002619	 0.010812	 0.00256	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38630	 39871	 0.009645	 0.034093	 0.00768	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38630	 88346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38630	 88346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38630	 88386	 0.00101	 0.010019	 0.00272	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38631	 38722	 4.6e-05	 0.000595	 0.03799	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38631	 88347	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88349	 38632	 0.015216	 0.023308	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88348	 38633	 0.000441	 0.004305	 0.00121	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38633	 88350	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38633	 88350	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88346	 38634	 0.020625	 0.034397	 0.0005	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38635	 88351	 0.007152	 0.01416	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38636	 39354	 0.00611	 0.043514	 0.00098	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38636	 88351	 0.002542	 0.018406	 0.00046	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38637	 88351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38637	 88351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38638	 38639	 0.028848	 0.020435	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88341	 38639	 0.018775	 0.072232	 0.00123	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88343	 38639	 0.023391	 0.018335	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88345	 38640	 0.003018	 0.018341	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88345	 38641	 0.02524	 0.033173	 0.00045	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88350	 38642	 0.01261	 0.022177	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38643	 38644	 0.003203	 0.012014	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88350	 38643	 0.002916	 0.014229	 0.00025	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38644	 38710	 0.01765	 0.022969	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88350	 38644	 0.005429	 0.025156	 0.00048	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38644	 88352	 0.005581	 0.018618	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38645	 38646	 0.001679	 0.00815	 0.00186	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38645	 38712	 0.005987	 0.015543	 0.00377	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38645	 88352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38645	 88352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38646	 88353	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38646	 88353	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38647	 88787	 0.02028	 0.047076	 0.0009	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38648	 88364	 0.026499	 0.026764	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38649	 38650	 0.001228	 0.003557	 0.00086	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38649	 38667	 0.001609	 0.004176	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38650	 88354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38650	 88354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38650	 88385	 0.00103	 0.005211	 0.00145	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88345	 38651	 0.019603	 0.046419	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88354	 38651	 0.004554	 0.011147	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38652	 38669	 0.000543	 0.003702	 0.00667	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38652	 38669	 0.000543	 0.003702	 0.00667	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38652	 38718	 0.000646	 0.004226	 0.00829	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38652	 88355	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88356	 38652	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 0	 -30.0	 30.0;
	38652	 88384	 0.000364	 0.002455	 0.00452	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38652	 88384	 0.000364	 0.002455	 0.00452	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38652	 88384	 0.000364	 0.002455	 0.00452	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38653	 88357	 0.017201	 0.012655	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 0	 -30.0	 30.0;
	38654	 38655	 0.000997	 0.003475	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88355	 38654	 0.002456	 0.006686	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38654	 88357	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38654	 88357	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38655	 38656	 0.000333	 0.001951	 0.00053	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38656	 88358	 0.000222	 0.001626	 0.00048	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38657	 38658	 8.8e-05	 0.000842	 0.00189	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38657	 38669	 0.0009	 0.006103	 0.01111	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38657	 88358	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38657	 88358	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38658	 38659	 6.7e-05	 0.000644	 0.00228	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38658	 88359	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88360	 38658	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38659	 88361	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38659	 88361	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38660	 38661	 0.001154	 0.004619	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38660	 38675	 0.000571	 0.003135	 0.00083	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88358	 38661	 0.001017	 0.003681	 0.00079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38661	 88362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38661	 88362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88362	 38662	 0.008939	 0.013949	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38663	 38664	 0.000587	 0.002351	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88358	 38663	 0.000786	 0.004334	 0.00101	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38664	 38665	 0.001707	 0.005033	 0.00117	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38664	 88363	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38664	 88363	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88355	 38665	 0.002314	 0.006114	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88356	 38666	 0.004706	 0.016074	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88355	 38667	 0.002149	 0.007374	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 0	 -30.0	 30.0;
	38667	 88364	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38667	 88364	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38668	 88366	 0.008187	 0.013068	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38669	 39842	 0.003325	 0.02268	 0.04085	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38669	 39843	 0.002928	 0.019278	 0.03731	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88347	 38669	 0.000488	 0.005323	 0.01032	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38669	 88365	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88366	 38669	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 0	 -30.0	 30.0;
	38670	 38672	 0.0023	 0.006262	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38670	 38723	 0.001617	 0.004198	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38671	 38672	 0.00154	 0.00407	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38671	 38673	 0.002001	 0.006866	 0.00164	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38672	 88367	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38672	 88367	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38673	 38675	 0.00072	 0.00364	 0.00101	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38673	 88368	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38673	 88368	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88368	 38674	 0.01393	 0.012483	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38676	 38677	 0.001638	 0.004596	 0.00118	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88334	 38676	 0.001619	 0.005553	 0.00133	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38677	 38678	 0.002511	 0.007003	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38678	 38679	 0.002534	 0.006514	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38678	 38680	 0.001442	 0.003743	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38679	 38683	 0.000938	 0.00594	 0.00161	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38679	 38684	 0.001674	 0.009227	 0.00216	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38680	 38690	 0.002015	 0.005325	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38681	 88369	 0.015307	 0.05955	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38682	 38685	 0.003378	 0.017891	 0.00453	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38682	 38686	 0.001475	 0.010522	 0.00326	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38682	 88774	 0.002706	 0.030931	 0.00943	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38683	 38685	 0.001906	 0.009931	 0.0026	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38683	 38688	 0.001155	 0.009003	 0.00269	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88331	 38683	 0.011513	 0.02989	 0.00726	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38683	 88369	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38683	 88369	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38684	 38692	 0.004453	 0.01552	 0.0036	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38684	 39832	 0.004365	 0.011332	 0.00275	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38685	 88370	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38685	 88370	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38686	 38688	 0.00022	 0.002147	 0.0006	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38686	 88371	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38686	 88371	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38687	 39833	 0.092697	 0.073361	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88371	 38687	 0.012184	 0.021899	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88369	 38689	 0.026993	 0.019513	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38690	 88372	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38690	 88372	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88372	 38691	 0.047919	 0.033943	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38692	 38693	 0.002598	 0.008667	 0.0022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38693	 38723	 0.005049	 0.013745	 0.00303	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38694	 38695	 0.033757	 0.026715	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38694	 38697	 0.016037	 0.03143	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38695	 88373	 0.026863	 0.019419	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38696	 38706	 0.002314	 0.006116	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38696	 39820	 0.001937	 0.006318	 0.00168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38696	 88373	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38696	 88373	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38697	 38698	 0.002563	 0.009971	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38697	 38703	 0.012019	 0.027904	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88366	 38697	 0.002623	 0.018004	 0.00033	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38698	 88374	 0.010271	 0.018813	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38699	 38700	 0.001125	 0.003062	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38699	 38702	 0.001224	 0.00295	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38700	 38705	 0.001408	 0.003656	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38700	 88374	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38700	 88374	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38701	 38704	 0.001621	 0.004201	 0.00127	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38701	 88375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38701	 88375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88348	 38702	 0.001988	 0.009122	 0.00234	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38702	 88376	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38702	 88376	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88375	 38703	 0.004189	 0.010768	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38703	 88377	 0.003012	 0.00766	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88365	 38704	 0.001457	 0.00707	 0.00162	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38704	 88377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38704	 88377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38705	 38706	 0.001265	 0.003179	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38706	 38714	 0.001614	 0.004191	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38706	 88378	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38706	 88378	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38707	 38708	 0.002249	 0.012785	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88350	 38707	 0.0091	 0.021126	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88375	 38707	 0.001851	 0.011381	 0.00021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38708	 38710	 0.003593	 0.013825	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38709	 38711	 0.014935	 0.022651	 0.00032	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88376	 38709	 0.007854	 0.020762	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38710	 38716	 0.006147	 0.014269	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38712	 39817	 0.005246	 0.018543	 0.00418	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38712	 88379	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38712	 88379	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38713	 88380	 0.032972	 0.024258	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38714	 39821	 0.00389	 0.010443	 0.00237	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38714	 88380	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38714	 88380	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38715	 38716	 0.030324	 0.028216	 0.00053	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88379	 38715	 0.035474	 0.028073	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38717	 88381	 0.001154	 0.004179	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38718	 38719	 0.000237	 0.001789	 0.00383	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38718	 88381	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88382	 38718	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38719	 88383	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38719	 88383	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88359	 38720	 0.002477	 0.006648	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38720	 88385	 0.004825	 0.014224	 0.00331	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38721	 38722	 6.5e-05	 0.000811	 0.0556	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38721	 88384	 0.000118	 0.009419	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 2.0	 1	 -30.0	 30.0;
	38721	 88384	 0.000118	 0.009419	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 2.0	 1	 -30.0	 30.0;
	38721	 88384	 0.000118	 0.009419	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 2.0	 1	 -30.0	 30.0;
	88385	 38721	 0.000154	 0.012356	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88385	 38721	 0.000154	 0.012356	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95344	 38721	 0.000868	 0.01487	 1.1623	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 0	 -30.0	 30.0;
	38722	 88386	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38723	 39827	 0.009008	 0.023386	 0.00568	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88365	 38723	 0.001361	 0.00342	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38724	 38725	 0.008409	 0.029423	 0.00975	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38724	 38947	 0.014004	 0.04129	 0.00961	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38725	 38726	 0.005772	 0.022688	 0.00594	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38725	 39299	 0.015978	 0.062807	 0.01643	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38726	 38727	 0.006736	 0.027412	 0.00668	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38726	 38952	 0.015278	 0.038407	 0.00995	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38727	 38923	 0.015674	 0.062763	 0.01581	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38728	 88388	 0.052429	 0.094601	 0.00137	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38729	 88751	 0.10987	 0.098459	 0.00201	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38730	 39765	 0.011727	 0.045626	 0.01219	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38730	 88388	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38730	 88388	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38732	 38738	 0.011907	 0.040847	 0.00979	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38732	 39261	 0.010943	 0.038139	 0.00884	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38733	 88389	 0.061172	 0.11205	 0.00193	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38734	 38737	 0.005341	 0.029798	 0.00761	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38734	 88389	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38734	 88389	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38735	 88390	 0.084474	 0.092914	 0.00124	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38736	 38740	 0.000557	 0.007	 0.02449	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38736	 39836	 0.000591	 0.007184	 0.02326	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38737	 38738	 0.002806	 0.01386	 0.00405	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38737	 88390	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38737	 88390	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38737	 88391	 0.006491	 0.026799	 0.00634	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38738	 38741	 0.003481	 0.020894	 0.00633	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38739	 88392	 0.031137	 0.080041	 0.00124	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38739	 88393	 0.014945	 0.057497	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87232	 38740	 0.003575	 0.047548	 0.10169	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38740	 88391	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88392	 38740	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38740	 88472	 0.002749	 0.034591	 0.12115	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38741	 38971	 0.005173	 0.034703	 0.00838	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38741	 88393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38741	 88393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38742	 38775	 0.023078	 0.061002	 0.01428	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38742	 88394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38742	 88394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38742	 88396	 0.00991	 0.033998	 0.00815	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38743	 38749	 0.00464	 0.018881	 0.0046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38743	 88395	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38743	 88395	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38743	 88399	 0.002346	 0.011449	 0.00316	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38744	 88396	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88397	 38744	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38744	 88398	 0.000417	 0.005646	 0.01163	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38744	 88571	 0.00664	 0.045076	 0.08214	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38745	 39289	 0.000662	 0.007904	 0.59358	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38745	 88398	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88399	 38745	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88397	 38746	 0.12611	 0.092786	 0.00136	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38747	 39109	 0.005397	 0.033182	 0.00957	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88399	 38747	 0.003851	 0.022126	 0.00627	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88395	 38748	 0.12946	 0.1322	 0.00206	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38749	 39285	 0.014361	 0.056449	 0.01477	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38749	 88400	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38749	 88400	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38750	 39751	 0.043369	 0.10069	 0.0015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38750	 88678	 0.067613	 0.15698	 0.00233	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38751	 38752	 0.024163	 0.062114	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38751	 88678	 0.03173	 0.050648	 0.00117	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38752	 38754	 0.020143	 0.067195	 0.00107	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38753	 38754	 0.046381	 0.079914	 0.00127	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38753	 38758	 0.051789	 0.086024	 0.00182	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38754	 38755	 0.010455	 0.058747	 0.00109	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38755	 88401	 0.03211	 0.15415	 0.00461	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38756	 38760	 0.066608	 0.15304	 0.00232	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38756	 88401	 0.060063	 0.15441	 0.00239	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38757	 38919	 0.029274	 0.073607	 0.01908	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87193	 38757	 0.009796	 0.065646	 0.02012	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38757	 88401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38757	 88401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38758	 88402	 0.037454	 0.086955	 0.00129	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38759	 39605	 0.001353	 0.00981	 0.01975	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38759	 88402	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38759	 88402	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38760	 38946	 0.066092	 0.15185	 0.00231	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38761	 88403	 0.16746	 0.10843	 0.00206	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38762	 88403	 0.059509	 0.11663	 0.00175	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38763	 38764	 0.014448	 0.051073	 0.01151	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38763	 39277	 0.011707	 0.038184	 0.01014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38763	 39301	 0.02168	 0.070726	 0.01878	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38763	 88403	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38763	 88403	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38765	 88404	 0.093163	 0.14272	 0.002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38765	 88405	 0.079551	 0.20452	 0.00317	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38766	 38767	 0.007688	 0.025905	 0.00644	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88312	 38767	 0.009999	 0.026426	 0.00619	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38767	 88404	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38767	 88404	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87243	 38768	 0.082999	 0.058794	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38769	 38770	 0.00374	 0.014217	 0.00398	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88312	 38769	 0.015076	 0.050799	 0.01263	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38770	 38771	 0.002502	 0.017697	 0.00486	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38771	 38772	 0.004756	 0.028766	 0.00734	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38771	 38773	 0.016297	 0.043074	 0.01008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87378	 38772	 0.00782	 0.057114	 0.01468	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38772	 88405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38772	 88405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38774	 88406	 0.15629	 0.1237	 0.00156	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38775	 38780	 0.012376	 0.02873	 0.00875	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38775	 88406	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38775	 88406	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38776	 38780	 0.009243	 0.024429	 0.00572	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38776	 38786	 0.011089	 0.029308	 0.00686	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38777	 39809	 0.018774	 0.048266	 0.01195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88294	 38777	 0.013244	 0.030744	 0.00937	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38778	 38783	 0.011232	 0.030582	 0.00674	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88294	 38778	 0.007577	 0.027439	 0.00589	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38778	 88407	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38778	 88407	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88407	 38779	 0.087893	 0.069559	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38780	 38781	 0.006417	 0.023344	 0.00715	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38780	 88408	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38780	 88408	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38782	 38783	 0.006891	 0.018211	 0.00426	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38784	 38787	 0.007456	 0.020018	 0.00454	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38784	 39190	 0.012313	 0.029672	 0.00838	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88394	 38785	 0.17031	 0.12904	 0.00178	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38786	 39809	 0.009002	 0.02337	 0.00567	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88294	 38787	 0.00385	 0.009995	 0.00243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38788	 38789	 0.00303	 0.030026	 0.0092	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38788	 39223	 0.005042	 0.047462	 0.01438	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38789	 38792	 0.00285	 0.02487	 0.00683	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38789	 39120	 0.006228	 0.033478	 0.00824	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38789	 88409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38789	 88409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38790	 38791	 0.00375	 0.02917	 0.00758	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38790	 39225	 0.004673	 0.05038	 0.02693	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87463	 38790	 0.01264	 0.1255	 0.03416	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38791	 38794	 0.004528	 0.028678	 0.00778	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38791	 88410	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38791	 88410	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38792	 38793	 0.002825	 0.027993	 0.00857	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87454	 38795	 0.14746	 0.1622	 0.00216	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88410	 38795	 0.098258	 0.12915	 0.00177	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38796	 38798	 0.004371	 0.022342	 0.00609	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38797	 88509	 0.10851	 0.14262	 0.00195	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38799	 38800	 0.003525	 0.018017	 0.00491	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38800	 38824	 0.007352	 0.018482	 0.00479	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38800	 38915	 0.014202	 0.078304	 0.01831	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38800	 88411	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38800	 88411	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38801	 39795	 0.002926	 0.039852	 0.08116	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38801	 88412	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88413	 38801	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38802	 38803	 0.001624	 0.008457	 0.00222	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38802	 38809	 0.004805	 0.026485	 0.00619	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88412	 38803	 0.002619	 0.015718	 0.00476	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38803	 88414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38803	 88414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88414	 38804	 0.006169	 0.027487	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38804	 88415	 0.006461	 0.03871	 0.00093	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38805	 38806	 0.004413	 0.022986	 0.00603	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38805	 88415	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38805	 88415	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38806	 38811	 0.005405	 0.028155	 0.00738	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88304	 38807	 0.070095	 0.31243	 0.00531	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88413	 38807	 0.017395	 0.087994	 0.00153	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38807	 88416	 0.074769	 0.24947	 0.00396	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38807	 88417	 0.007808	 0.048001	 0.00087	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38808	 88418	 0.090375	 0.096293	 0.00137	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38809	 38815	 0.007937	 0.02874	 0.00617	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38809	 39794	 0.004334	 0.022577	 0.00592	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38809	 88416	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38809	 88416	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88414	 38810	 0.038732	 0.087859	 0.00175	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38812	 88417	 0.046383	 0.11924	 0.00185	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38812	 88423	 0.054378	 0.12877	 0.00235	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38812	 88424	 0.15907	 0.1259	 0.00159	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38813	 88417	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38813	 88417	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38813	 88422	 0.009198	 0.05716	 0.01613	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38814	 38815	 0.006262	 0.032618	 0.00856	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87222	 38814	 0.002421	 0.027118	 0.00862	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38814	 88418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38814	 88418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38815	 39789	 0.005453	 0.027585	 0.00768	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38816	 38818	 0.005898	 0.036651	 0.01034	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38816	 39772	 0.006676	 0.035885	 0.00883	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38817	 38819	 0.006817	 0.022234	 0.0059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38818	 39198	 0.007113	 0.045822	 0.01201	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38818	 39408	 0.013274	 0.03337	 0.00865	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38819	 39200	 0.012946	 0.045764	 0.01031	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38820	 38821	 0.00286	 0.007426	 0.0018	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38820	 38824	 0.004045	 0.012282	 0.00269	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38820	 88419	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38820	 88419	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38821	 88422	 0.005253	 0.014649	 0.00307	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38822	 38823	 0.001142	 0.00574	 0.00149	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38822	 38827	 0.001808	 0.009244	 0.00252	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38822	 88420	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38822	 88420	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38822	 88422	 0.005112	 0.017535	 0.0042	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38823	 38824	 0.002417	 0.008542	 0.00192	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38823	 88421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38823	 88421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38825	 38928	 0.13909	 0.15151	 0.00206	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88419	 38825	 0.016048	 0.046026	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38826	 38930	 0.001989	 0.025023	 0.05983	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38826	 88422	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88423	 38826	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38826	 88614	 0.005189	 0.058344	 0.10692	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38827	 38980	 0.003814	 0.023698	 0.00669	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88420	 38828	 0.034242	 0.046677	 0.00104	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38829	 38940	 0.0052	 0.02461	 0.00592	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88422	 38829	 0.004843	 0.026031	 0.0064	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38829	 88424	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38829	 88424	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38830	 38981	 0.002618	 0.01443	 0.00337	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38830	 88425	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38830	 88425	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88423	 38831	 0.045632	 0.1449	 0.00254	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88425	 38831	 0.010105	 0.039465	 0.00088	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38832	 38909	 0.001306	 0.00457	 0.00151	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38832	 38911	 0.000795	 0.005199	 0.00132	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38832	 88426	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38832	 88426	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38833	 88428	 0.020226	 0.013094	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38834	 88427	 0.001403	 0.005937	 0.00134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38834	 88455	 0.002106	 0.007663	 0.00235	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38835	 38878	 0.000205	 0.002186	 0.00396	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38835	 38880	 0.000878	 0.005783	 0.01119	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38835	 88427	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88428	 38835	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38836	 38839	 0.013155	 0.01041	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88426	 38836	 0.00795	 0.01108	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38837	 38838	 0.00165	 0.004602	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38837	 88429	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38837	 88429	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38837	 88455	 0.002955	 0.010445	 0.00235	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38838	 38847	 0.001628	 0.004228	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38839	 88434	 0.011333	 0.010155	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38840	 88430	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38840	 88430	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38840	 88447	 0.0007	 0.004348	 0.00123	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38841	 38842	 0.000199	 0.001683	 0.00328	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38841	 38907	 0.000175	 0.001535	 0.0028	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38842	 38844	 0.000102	 0.001383	 0.00281	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38842	 88431	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38842	 88431	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88430	 38843	 0.002374	 0.016106	 0.0003	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38844	 38846	 0.000268	 0.001786	 0.00337	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38844	 88432	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38844	 88432	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38845	 38905	 0.00174	 0.005861	 0.00146	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88432	 38845	 0.000902	 0.004137	 0.00106	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38846	 88433	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38846	 88433	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88432	 38847	 0.00196	 0.006603	 0.00164	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38847	 88434	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38847	 88434	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38848	 38849	 0.000704	 0.002373	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38848	 38906	 0.000642	 0.003729	 0.00088	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38848	 88435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38848	 88435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38849	 38853	 0.001355	 0.004649	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88435	 38850	 0.008368	 0.025698	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38850	 88453	 0.008185	 0.015219	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38851	 38911	 0.00071	 0.0027	 0.00076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38851	 88447	 0.000773	 0.005365	 0.00153	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38852	 38853	 0.001285	 0.005894	 0.00151	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38852	 38909	 0.000971	 0.004877	 0.00127	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38853	 38912	 0.000617	 0.004647	 0.00129	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38854	 38900	 0.002501	 0.006287	 0.00163	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38854	 38901	 0.001584	 0.005435	 0.0013	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38854	 38903	 0.001827	 0.010614	 0.0025	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38854	 88436	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38854	 88436	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38855	 38896	 0.008007	 0.023192	 0.00559	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87215	 38855	 0.004668	 0.012336	 0.00289	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87216	 38856	 0.028077	 0.066486	 0.00122	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38857	 39228	 0.004005	 0.033237	 0.00874	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87215	 38857	 0.002629	 0.026084	 0.00709	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38858	 38859	 0.002617	 0.019334	 0.00558	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87215	 38858	 0.003254	 0.023215	 0.0072	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38858	 88437	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38858	 88437	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38859	 39327	 0.004161	 0.031345	 0.0087	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38859	 88438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38859	 88438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38860	 88440	 0.050025	 0.032387	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38861	 38875	 0.001991	 0.015989	 0.03006	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87214	 38861	 0.000286	 0.002327	 0.00762	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38861	 88439	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88440	 38861	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87216	 38862	 0.056193	 0.044471	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38863	 38864	 0.00158	 0.00621	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38863	 38866	 0.003106	 0.012435	 0.00313	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87215	 38864	 0.006204	 0.024385	 0.00638	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38865	 38866	 0.001919	 0.007682	 0.00194	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38865	 38868	 0.001498	 0.008221	 0.00217	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38865	 88441	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38865	 88441	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88439	 38866	 0.003498	 0.014235	 0.00347	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38866	 88442	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38866	 88442	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88442	 38867	 0.024161	 0.040702	 0.00058	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38868	 38869	 0.002167	 0.008674	 0.00219	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38868	 38872	 0.002197	 0.008636	 0.00226	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88439	 38868	 0.010055	 0.031271	 0.00653	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87245	 38870	 0.019598	 0.033014	 0.00047	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38870	 88443	 0.03189	 0.048853	 0.00069	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38870	 88444	 0.007051	 0.016697	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88441	 38871	 0.066324	 0.052489	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38872	 88443	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38872	 88443	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38872	 88445	 0.001424	 0.009556	 0.00231	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38873	 88444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38873	 88444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38873	 88445	 0.002488	 0.006679	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38873	 88455	 0.00285	 0.010833	 0.00303	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38874	 38876	 0.025527	 0.02001	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88426	 38874	 0.075476	 0.059732	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38875	 38880	 0.000306	 0.002277	 0.00434	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38875	 88445	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38875	 88445	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38875	 88454	 0.000951	 0.006415	 0.01181	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38876	 88446	 0.004414	 0.010247	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88427	 38877	 0.002925	 0.010033	 0.0024	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38877	 88446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38877	 88446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38877	 88450	 0.002469	 0.006525	 0.00153	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87219	 38878	 0.000223	 0.003316	 0.01229	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38878	 88447	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38878	 88447	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87219	 38879	 0.000544	 0.006174	 0.01355	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38879	 88448	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88449	 38879	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38880	 88450	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38880	 88450	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88437	 38881	 0.10344	 0.08186	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88443	 38882	 0.022863	 0.058144	 0.00092	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88444	 38882	 0.04012	 0.10313	 0.0016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38882	 88610	 0.07766	 0.19966	 0.00309	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88449	 38883	 0.017549	 0.028011	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38884	 38902	 0.004437	 0.011154	 0.00289	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87215	 38884	 0.012893	 0.033474	 0.00812	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38885	 38886	 0.002188	 0.011587	 0.00294	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38885	 38887	 0.003524	 0.012819	 0.00392	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38885	 38888	 0.001745	 0.008004	 0.00205	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38887	 88452	 0.002915	 0.014403	 0.00421	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38888	 38890	 0.001516	 0.00815	 0.002	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38889	 38890	 0.000915	 0.004679	 0.00128	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38889	 38900	 0.003262	 0.010883	 0.00276	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38889	 38901	 0.001874	 0.006784	 0.00146	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38889	 88451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38889	 88451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38891	 38892	 0.026133	 0.028743	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88451	 38892	 0.013915	 0.032949	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88451	 38893	 0.025133	 0.030638	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38894	 38895	 0.001114	 0.00839	 0.00233	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38894	 88452	 0.001221	 0.007386	 0.00188	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38895	 88455	 0.001625	 0.009826	 0.00251	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38896	 38913	 0.002964	 0.009986	 0.00248	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88436	 38897	 0.037085	 0.029349	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38898	 38899	 0.000417	 0.003189	 0.01185	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38898	 88452	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38898	 88452	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38899	 88454	 0.000314	 0.002614	 0.00815	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38900	 38912	 0.000765	 0.005735	 0.0014	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88452	 38900	 0.001695	 0.006785	 0.00171	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38902	 38913	 0.003694	 0.011545	 0.00334	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38903	 38904	 0.000947	 0.005884	 0.00166	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38903	 88453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38903	 88453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38904	 38905	 0.00121	 0.00415	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88433	 38904	 0.001479	 0.007562	 0.00206	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88433	 38906	 0.000738	 0.00446	 0.00114	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38907	 38908	 0.000526	 0.00451	 0.00858	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38908	 39199	 0.001642	 0.0112	 0.02017	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87219	 38908	 0.000349	 0.002801	 0.00526	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38909	 88455	 0.000729	 0.004893	 0.00118	 241.0	 241.0	 241.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38910	 88454	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38910	 88454	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88455	 38910	 0.000173	 0.013839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88447	 38911	 0.00152	 0.008339	 0.0022	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88452	 38913	 0.001017	 0.00972	 0.0032	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38914	 38915	 0.010431	 0.035786	 0.00857	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38914	 38929	 0.007182	 0.023958	 0.00608	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38914	 88456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38914	 88456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38916	 38918	 0.008691	 0.030291	 0.00702	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38916	 38920	 0.019579	 0.067176	 0.0161	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38916	 88457	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38916	 88457	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87235	 38917	 0.087222	 0.24755	 0.00389	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38917	 88458	 0.030094	 0.10039	 0.00159	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38918	 38919	 0.007189	 0.028783	 0.00725	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38918	 88458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38918	 88458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38919	 38921	 0.011513	 0.038794	 0.00964	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87193	 38920	 0.017978	 0.096839	 0.02662	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87193	 38921	 0.015112	 0.070491	 0.01746	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38922	 38924	 0.010383	 0.034639	 0.00879	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38922	 39796	 0.022935	 0.067629	 0.01574	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38923	 38924	 0.007854	 0.020757	 0.00486	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38923	 39159	 0.009939	 0.034639	 0.00803	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38924	 38925	 0.003102	 0.018018	 0.00424	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38926	 39797	 0.034055	 0.11875	 0.02756	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38926	 39799	 0.026847	 0.07311	 0.01611	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38927	 39165	 0.00946	 0.030856	 0.00819	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38927	 88459	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38927	 88459	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38929	 88460	 0.005792	 0.023191	 0.00584	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38930	 88460	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38930	 88460	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95343	 38930	 0.006315	 0.058017	 0.22974	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87223	 38931	 0.042733	 0.035173	 0.00071	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38932	 38934	 0.004331	 0.028321	 0.0072	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87222	 38932	 0.003817	 0.037876	 0.0103	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38932	 88461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38932	 88461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38933	 88462	 0.024012	 0.047543	 0.0007	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38934	 38935	 0.002461	 0.013505	 0.00357	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38934	 88462	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38934	 88462	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38935	 38937	 0.002356	 0.012989	 0.00304	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38936	 88463	 0.019938	 0.039476	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38937	 88463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38937	 88463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38937	 88726	 0.003906	 0.021433	 0.00567	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88418	 38938	 0.03433	 0.15299	 0.0026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88461	 38938	 0.046626	 0.11986	 0.00186	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88462	 38938	 0.018067	 0.072425	 0.00187	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38939	 38940	 0.006063	 0.024276	 0.00612	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87222	 38939	 0.001233	 0.008723	 0.00239	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38941	 38944	 0.003377	 0.015207	 0.00405	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38941	 39194	 0.00948	 0.040123	 0.00903	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87230	 38942	 0.000369	 0.001477	 0.00037	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38943	 38944	 0.003543	 0.015789	 0.00429	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87230	 38943	 0.005309	 0.024358	 0.00624	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87230	 38944	 0.007804	 0.038483	 0.01041	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87234	 38944	 0.001688	 0.018219	 0.00624	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87234	 38945	 0.007252	 0.018828	 0.00457	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38945	 88464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38945	 88464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88464	 38946	 0.043677	 0.10343	 0.00189	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38947	 38950	 0.010478	 0.034956	 0.00887	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38948	 88465	 0.13664	 0.10711	 0.00138	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38949	 38951	 0.005871	 0.020142	 0.00483	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38949	 39185	 0.018565	 0.046672	 0.01209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38950	 38951	 0.006855	 0.020211	 0.0047	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88294	 38950	 0.031934	 0.08293	 0.02014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38950	 88465	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38950	 88465	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38953	 88469	 0.051459	 0.13088	 0.00207	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38954	 38955	 0.008169	 0.034009	 0.0106	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38955	 38956	 0.006762	 0.027517	 0.0067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38955	 88466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38955	 88466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38956	 88467	 0.004501	 0.017691	 0.00463	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38957	 38961	 0.013992	 0.03698	 0.00866	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38957	 88467	 0.002603	 0.00688	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38958	 38959	 0.000749	 0.006339	 0.01235	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	38958	 88467	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38958	 88467	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38959	 38960	 0.001355	 0.009034	 0.01703	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38959	 88468	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88469	 38959	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87232	 38960	 0.003965	 0.025745	 0.0513	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	38960	 88470	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38960	 88470	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38962	 38965	 0.007694	 0.039332	 0.01072	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38962	 39209	 0.00721	 0.035623	 0.01041	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38963	 38965	 0.010599	 0.038382	 0.00824	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88391	 38963	 0.007759	 0.027043	 0.00627	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38964	 38965	 0.010636	 0.036487	 0.00874	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38964	 38966	 0.009668	 0.051972	 0.01279	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38964	 39220	 0.007711	 0.04084	 0.01035	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38965	 38967	 0.006656	 0.032882	 0.0096	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38965	 88473	 0.023248	 0.1056	 0.03669	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38966	 39129	 0.017356	 0.045872	 0.01074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38966	 39299	 0.010427	 0.054321	 0.01425	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38967	 38974	 0.008268	 0.039058	 0.0125	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38968	 38969	 0.006282	 0.025153	 0.00634	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38968	 38971	 0.010809	 0.043279	 0.0109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87211	 38969	 0.00731	 0.030939	 0.00696	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38970	 39655	 0.000174	 0.002077	 0.15583	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38971	 38973	 0.003493	 0.035311	 0.01038	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38972	 88471	 0.04181	 0.089265	 0.00202	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38973	 88471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38973	 88471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38973	 88473	 0.003234	 0.034904	 0.01196	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38974	 88473	 0.008537	 0.047064	 0.011	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38975	 88472	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88473	 38975	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38976	 88474	 0.22775	 0.14748	 0.00281	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38977	 38978	 0.005292	 0.024022	 0.00834	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38977	 39318	 0.006202	 0.032846	 0.00833	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38977	 88474	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38977	 88474	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38978	 39317	 0.010769	 0.036942	 0.00885	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	38978	 88475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38978	 88475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38979	 39310	 0.3381	 0.25626	 0.00353	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88475	 38979	 0.030963	 0.093197	 0.00182	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38980	 38986	 0.004174	 0.025938	 0.00732	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38981	 38982	 0.0046	 0.022726	 0.00664	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38982	 38985	 0.002666	 0.014696	 0.00343	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38983	 38984	 0.003804	 0.019815	 0.0052	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38983	 38985	 0.003828	 0.019567	 0.00533	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38984	 39099	 0.00448	 0.023729	 0.00601	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38985	 38987	 0.00415	 0.021197	 0.00533	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	38988	 39418	 0.043179	 0.111	 0.00172	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38989	 39688	 0.16321	 0.12917	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38990	 38991	 0.091203	 0.092121	 0.00122	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	38992	 38993	 0.031077	 0.07359	 0.00135	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38994	 39102	 0.006644	 0.016491	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38994	 88510	 0.002522	 0.014335	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	38995	 39007	 0.000714	 0.005052	 0.00139	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38995	 39103	 0.000735	 0.007179	 0.00201	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38995	 88476	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38995	 88476	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38996	 88510	 0.015611	 0.012354	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38997	 39008	 0.009217	 0.021396	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	38997	 88486	 0.019639	 0.060249	 0.00163	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38997	 88510	 0.007069	 0.011283	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38998	 39011	 0.000803	 0.004183	 0.0011	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38998	 39104	 0.000508	 0.002648	 0.00069	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	38999	 39011	 0.000639	 0.006136	 0.00178	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	38999	 39012	 0.000484	 0.00348	 0.00092	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38999	 88477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	38999	 88477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39000	 39012	 0.000698	 0.00434	 0.00122	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39000	 39013	 0.001067	 0.005652	 0.00143	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39000	 88478	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39000	 88478	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39001	 39014	 0.001647	 0.009444	 0.00314	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39001	 39100	 0.000593	 0.004333	 0.00128	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39002	 39003	 0.004642	 0.010615	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88478	 39002	 0.005892	 0.019654	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39003	 39004	 0.002503	 0.011155	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39003	 39015	 0.009802	 0.023993	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39004	 39005	 0.026319	 0.019364	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39004	 39101	 0.003212	 0.018074	 0.00039	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88476	 39006	 0.013737	 0.024691	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39007	 39017	 0.001473	 0.004435	 0.00139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39007	 39053	 0.002861	 0.014472	 0.00403	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39009	 39010	 0.006246	 0.016056	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39009	 88481	 0.011037	 0.031654	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39009	 88510	 0.006974	 0.023264	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39010	 88481	 0.011949	 0.027737	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39011	 39023	 0.000833	 0.004589	 0.00107	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39011	 39024	 0.002331	 0.008123	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39011	 88482	 0.000951	 0.009614	 0.00283	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39013	 88479	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39013	 88479	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39014	 39048	 0.00172	 0.011803	 0.00344	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39014	 88480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39014	 88480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39015	 39016	 0.027113	 0.019205	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88480	 39015	 0.010478	 0.020534	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39017	 39056	 0.002388	 0.006917	 0.00167	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39018	 39057	 0.002702	 0.009268	 0.00222	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39018	 39103	 0.002778	 0.011304	 0.00275	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39018	 39105	 0.001086	 0.005402	 0.00174	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39019	 39020	 0.0005	 0.003168	 0.00086	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39019	 39105	 0.000747	 0.004732	 0.00128	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39020	 39030	 0.001729	 0.009528	 0.00223	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39020	 88481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39020	 88481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39020	 88482	 0.000418	 0.004081	 0.00115	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39021	 39427	 0.000492	 0.009128	 0.6035	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39021	 88482	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39021	 88482	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39022	 39023	 0.001032	 0.005466	 0.00139	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88482	 39022	 0.001063	 0.005931	 0.00151	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39024	 88484	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39024	 88484	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39025	 39045	 0.005894	 0.02293	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88484	 39025	 0.003255	 0.018501	 0.00033	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39026	 39045	 0.020984	 0.023079	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39027	 39046	 0.013597	 0.021704	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39027	 39088	 0.006748	 0.041463	 0.00095	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88477	 39027	 0.009429	 0.04526	 0.00135	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88479	 39027	 0.004859	 0.017965	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39028	 39058	 0.024961	 0.026595	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39028	 88486	 0.00803	 0.01864	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39029	 39030	 0.0013	 0.006647	 0.00181	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39029	 39066	 0.002264	 0.009214	 0.00224	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39029	 88485	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39029	 88485	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39030	 88486	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39030	 88486	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88486	 39031	 0.004913	 0.019189	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39031	 88492	 0.002881	 0.016375	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39032	 39039	 0.000314	 0.002547	 0.00468	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39032	 39080	 0.000317	 0.004614	 0.01139	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39032	 88487	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88488	 39032	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39033	 39034	 0.000973	 0.006164	 0.00167	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39033	 39082	 0.001705	 0.006828	 0.00172	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39033	 88489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39033	 88489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39033	 88491	 0.00096	 0.005085	 0.00129	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88482	 39034	 0.000933	 0.005361	 0.00152	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39035	 39036	 0.000465	 0.002792	 0.00085	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88487	 39035	 0.00086	 0.005447	 0.00148	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39036	 39059	 0.00096	 0.004907	 0.00134	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39037	 39067	 0.00465	 0.01229	 0.00288	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88487	 39037	 0.003474	 0.00902	 0.00219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39037	 88490	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39037	 88490	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39038	 39075	 0.007434	 0.02132	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88490	 39038	 0.004847	 0.01487	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39039	 88491	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39039	 88491	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39040	 39041	 0.000364	 0.004092	 0.00118	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88491	 39040	 0.000346	 0.003834	 0.00125	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39040	 88492	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39040	 88492	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88482	 39041	 0.000622	 0.006711	 0.0023	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39041	 88493	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39041	 88493	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88483	 39042	 0.016039	 0.031755	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39043	 39086	 0.001679	 0.010153	 0.00259	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39043	 39090	 0.002581	 0.01729	 0.0053	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88482	 39043	 0.001056	 0.010461	 0.0032	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39043	 88494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39043	 88494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39044	 39091	 0.015558	 0.023833	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39045	 39092	 0.011417	 0.026505	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39047	 39098	 0.004521	 0.018821	 0.00587	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39047	 88495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39047	 88495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39048	 39051	 0.005511	 0.018905	 0.00453	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39048	 88496	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39048	 88496	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39049	 39050	 0.002823	 0.015562	 0.00364	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39049	 39051	 0.002951	 0.018688	 0.00507	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39049	 39099	 0.003736	 0.016647	 0.00452	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39050	 39410	 0.003248	 0.017456	 0.00429	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39051	 39054	 0.006595	 0.017431	 0.00408	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88482	 39051	 0.003425	 0.038365	 0.0122	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39052	 88497	 0.067961	 0.068644	 0.00091	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39053	 39054	 0.002982	 0.016029	 0.00394	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39054	 39412	 0.001652	 0.009494	 0.00269	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39054	 88497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39054	 88497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39055	 39056	 0.003485	 0.008959	 0.00222	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39059	 39060	 0.002277	 0.006853	 0.00214	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39059	 88498	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39059	 88498	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39060	 39068	 0.001966	 0.00712	 0.00153	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39060	 88499	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39060	 88499	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88498	 39061	 0.0155	 0.035985	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88499	 39061	 0.029066	 0.021011	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39061	 88500	 0.009423	 0.021551	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39062	 39063	 0.000591	 0.003079	 0.00081	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39062	 39069	 0.001689	 0.009309	 0.00218	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39063	 39064	 0.000994	 0.005079	 0.00138	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39064	 39065	 0.001389	 0.005562	 0.0014	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39065	 39066	 0.001564	 0.00662	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39067	 39069	 0.001191	 0.005985	 0.00156	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39067	 39076	 0.001135	 0.00515	 0.00179	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39068	 39069	 0.000855	 0.004712	 0.0011	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39068	 88500	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39068	 88500	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39069	 39074	 0.001384	 0.007332	 0.00186	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39070	 39071	 0.001329	 0.006921	 0.00182	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39070	 39076	 0.001456	 0.007195	 0.0021	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39070	 88501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39070	 88501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39071	 39142	 0.002363	 0.012309	 0.00323	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39071	 88502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39071	 88502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39072	 39074	 0.001572	 0.007766	 0.00227	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39072	 39143	 0.002381	 0.012609	 0.0032	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39072	 88503	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39072	 88503	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39073	 39143	 0.002644	 0.012512	 0.00301	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39074	 88504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39074	 88504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39075	 88507	 0.014621	 0.037584	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39076	 88505	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39076	 88505	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39077	 39078	 0.005096	 0.022454	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88505	 39077	 0.007661	 0.029804	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88275	 39078	 0.011387	 0.054942	 0.00097	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88274	 39079	 0.003093	 0.017052	 0.00399	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39079	 88506	 0.0019	 0.008975	 0.00287	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88273	 39080	 0.000843	 0.00852	 0.01933	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39080	 88506	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88507	 39080	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39080	 88585	 0.001197	 0.016297	 0.03317	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88488	 39081	 0.030922	 0.023719	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39082	 39083	 0.000519	 0.005501	 0.00163	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88482	 39082	 0.003228	 0.017796	 0.00416	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39084	 39086	 0.001385	 0.011129	 0.00313	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39084	 39760	 0.00801	 0.050736	 0.01377	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87217	 39084	 0.002517	 0.027283	 0.00853	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39085	 39086	 0.000602	 0.004575	 0.00144	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39087	 39088	 0.018472	 0.028822	 0.00048	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39088	 39095	 0.014948	 0.038016	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39089	 39090	 0.001483	 0.007969	 0.00196	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39089	 39093	 0.002024	 0.010717	 0.00272	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39090	 88508	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39090	 88508	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88494	 39091	 0.017679	 0.044959	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88508	 39092	 0.012864	 0.040846	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39093	 39094	 0.002893	 0.015319	 0.00388	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39094	 39760	 0.003821	 0.019328	 0.00538	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39095	 39096	 0.021787	 0.051592	 0.00094	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39096	 39097	 0.017099	 0.035937	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88495	 39097	 0.017956	 0.041687	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39098	 39099	 0.003539	 0.013909	 0.00364	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39099	 88509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39099	 88509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39100	 39103	 0.000723	 0.005246	 0.00181	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39101	 39102	 0.007916	 0.014228	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39101	 88510	 0.006859	 0.02721	 0.00078	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39103	 39104	 0.000561	 0.002868	 0.00078	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88482	 39103	 0.001169	 0.009917	 0.00594	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39103	 88510	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39103	 88510	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39106	 39285	 0.015617	 0.043553	 0.00914	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87790	 39106	 0.021092	 0.05575	 0.01305	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39107	 39284	 0.38186	 0.37388	 0.00529	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88400	 39107	 0.2277	 0.23003	 0.00305	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39108	 39111	 0.009471	 0.037227	 0.00974	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39108	 39746	 0.011029	 0.04335	 0.01134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39109	 39110	 0.002551	 0.016157	 0.00439	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39110	 39114	 0.00414	 0.026222	 0.00712	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39111	 39112	 0.002665	 0.010672	 0.00269	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39112	 39113	 0.002433	 0.009899	 0.00241	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39113	 39114	 0.001565	 0.00637	 0.00155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87230	 39113	 0.008194	 0.04117	 0.01072	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39114	 39115	 0.003202	 0.01355	 0.00305	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87230	 39115	 0.005041	 0.02613	 0.00638	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39115	 88511	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39115	 88511	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88511	 39116	 0.12919	 0.10224	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39117	 88512	 0.094488	 0.10393	 0.00139	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39118	 39122	 0.010314	 0.037348	 0.00801	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39118	 39123	 0.014033	 0.038207	 0.00842	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39118	 39797	 0.014486	 0.048811	 0.01213	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39119	 39122	 0.001145	 0.012046	 0.00677	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39119	 39222	 0.00421	 0.037273	 0.02047	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39119	 88512	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39119	 88512	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39120	 39121	 0.002327	 0.011897	 0.00324	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39120	 39122	 0.007055	 0.024202	 0.0058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39120	 88513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39120	 88513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39121	 39126	 0.003411	 0.016112	 0.00516	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39122	 39123	 0.002766	 0.021559	 0.00645	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39122	 39129	 0.037759	 0.10142	 0.023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87132	 39122	 0.012291	 0.12852	 0.03535	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39122	 88514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39122	 88514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39123	 39124	 0.005036	 0.037932	 0.01053	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39123	 88515	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39123	 88515	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39124	 39798	 0.01489	 0.039976	 0.00906	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39125	 39126	 0.007012	 0.035844	 0.00977	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87132	 39125	 0.014235	 0.067259	 0.02153	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39126	 39127	 0.003598	 0.024109	 0.00739	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39126	 88516	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39126	 88516	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39128	 88517	 0.072434	 0.14197	 0.00213	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39129	 88517	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39129	 88517	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39130	 39134	 0.002764	 0.028167	 0.00726	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39130	 39276	 0.003353	 0.031212	 0.00967	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39131	 39133	 0.004425	 0.034862	 0.0102	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39132	 39138	 0.003349	 0.031176	 0.00966	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39132	 39208	 0.005245	 0.044117	 0.01307	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39133	 39138	 0.007216	 0.038219	 0.00969	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39133	 88518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39133	 88518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39134	 39136	 0.002457	 0.024003	 0.00674	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39134	 88519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39134	 88519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39135	 88520	 0.085991	 0.13174	 0.00185	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39136	 39137	 0.003958	 0.0187	 0.00598	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39136	 88520	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39136	 88520	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39139	 88521	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39139	 88521	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39139	 88580	 0.003951	 0.020579	 0.0054	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39140	 39141	 0.003374	 0.013508	 0.0034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39140	 88523	 0.001872	 0.015746	 0.00466	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39140	 88586	 0.013486	 0.046268	 0.01108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39141	 88522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39141	 88522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39144	 39145	 0.003618	 0.019944	 0.00466	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39145	 39146	 0.0019	 0.012237	 0.00321	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39145	 88523	 0.007507	 0.025042	 0.00635	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39146	 39230	 0.004582	 0.029515	 0.00774	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39147	 39148	 0.00082	 0.006581	 0.02215	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87240	 39147	 0.003009	 0.041417	 0.08259	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39147	 88523	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39147	 88523	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39147	 88585	 0.00294	 0.020617	 0.03511	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39148	 88524	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39148	 88524	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39149	 39150	 0.002672	 0.023317	 0.0064	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87212	 39149	 0.003648	 0.03503	 0.01019	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39150	 39152	 0.001582	 0.018702	 0.00532	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39150	 39231	 0.002802	 0.030992	 0.00929	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39150	 88525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39150	 88525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39151	 88526	 0.012665	 0.042249	 0.00067	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39151	 88527	 0.046605	 0.071394	 0.001	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39152	 39158	 0.003458	 0.040241	 0.01183	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39152	 88526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39152	 88526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39153	 39154	 0.003664	 0.014668	 0.0037	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39153	 39155	 0.004681	 0.019047	 0.00464	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39154	 39156	 0.003612	 0.017846	 0.00521	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39154	 88527	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39154	 88527	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39155	 39232	 0.003834	 0.020303	 0.00515	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39155	 88528	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39155	 88528	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39156	 39157	 0.006738	 0.017493	 0.00425	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39157	 39303	 0.008243	 0.021786	 0.0051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39159	 39160	 0.014442	 0.038774	 0.00879	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39159	 39162	 0.008638	 0.032835	 0.00919	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39159	 88529	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39159	 88529	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39160	 39161	 0.007379	 0.031231	 0.00703	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39161	 39163	 0.006061	 0.023037	 0.00645	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39162	 39163	 0.014787	 0.050729	 0.01216	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39162	 88530	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39162	 88530	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39163	 39164	 0.007862	 0.026228	 0.00665	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87193	 39163	 0.046237	 0.15878	 0.03809	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39165	 88531	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39165	 88531	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39166	 39649	 0.009853	 0.054317	 0.0127	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39167	 88532	 0.058473	 0.11578	 0.0017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39168	 39752	 0.009613	 0.022315	 0.0068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39168	 88532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39168	 88532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39169	 39718	 0.013736	 0.067872	 0.01983	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39170	 39173	 0.008712	 0.022396	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39170	 39184	 0.060602	 0.066656	 0.00089	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39171	 39172	 0.002312	 0.006003	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39171	 39187	 0.002998	 0.007225	 0.00204	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39171	 39189	 0.007209	 0.019053	 0.00446	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39171	 88533	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39171	 88533	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39171	 88537	 0.004666	 0.016494	 0.00372	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39172	 88534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39172	 88534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39172	 88537	 0.002816	 0.012919	 0.00331	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39173	 39174	 0.009731	 0.017822	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39173	 39175	 0.005744	 0.013197	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88534	 39173	 0.005255	 0.027328	 0.00059	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39175	 39176	 0.006518	 0.01513	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39176	 88535	 0.002212	 0.009802	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39177	 39178	 0.002642	 0.006981	 0.00163	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39177	 88535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39177	 88535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39177	 88537	 0.002599	 0.014259	 0.00377	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39178	 39179	 0.001126	 0.002713	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39179	 39183	 0.003965	 0.010193	 0.00252	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88535	 39180	 0.018633	 0.019898	 0.00042	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39180	 88536	 0.028895	 0.05721	 0.00084	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39181	 39196	 0.005249	 0.020632	 0.0054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39181	 88536	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39181	 88536	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39181	 88537	 0.008554	 0.02522	 0.00587	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39182	 88537	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39182	 88537	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39183	 39185	 0.009996	 0.025951	 0.0063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88537	 39183	 0.009717	 0.035187	 0.00755	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39186	 39187	 0.002315	 0.006117	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39186	 39190	 0.00424	 0.011205	 0.00262	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88533	 39188	 0.039955	 0.030271	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39188	 88539	 0.061617	 0.048763	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39189	 39190	 0.003075	 0.008371	 0.00184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39189	 39193	 0.003295	 0.008554	 0.00208	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39189	 88538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39189	 88538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88538	 39191	 0.089422	 0.063344	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39192	 39193	 0.004201	 0.010799	 0.00267	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39193	 88539	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39193	 88539	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88537	 39194	 0.008526	 0.029247	 0.00701	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88457	 39195	 0.27062	 0.19568	 0.00297	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39197	 39198	 0.009669	 0.033169	 0.00795	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88448	 39197	 0.005723	 0.019634	 0.0047	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39198	 88541	 0.007665	 0.061591	 0.01732	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87251	 39200	 0.007119	 0.045095	 0.01224	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39201	 88540	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39201	 88540	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88405	 39202	 0.073899	 0.11796	 0.00272	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88542	 39202	 0.035261	 0.12338	 0.00256	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39203	 39204	 0.003509	 0.033691	 0.0098	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39203	 39377	 0.006768	 0.037309	 0.00872	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39203	 39851	 0.009456	 0.038481	 0.00938	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39204	 39205	 0.003127	 0.031606	 0.00929	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39205	 39207	 0.002668	 0.012238	 0.00314	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39205	 39222	 0.014407	 0.079433	 0.01857	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87113	 39205	 0.0889	 0.30076	 0.07514	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39205	 88543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39205	 88543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39206	 88544	 0.012999	 0.025738	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39207	 39208	 0.003361	 0.026196	 0.00783	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39207	 88544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39207	 88544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39209	 39220	 0.005927	 0.037541	 0.01019	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39209	 39852	 0.00443	 0.036204	 0.00982	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39210	 88545	 0.035224	 0.090548	 0.0014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39211	 39212	 0.000527	 0.004388	 0.01369	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39211	 39853	 0.000696	 0.005409	 0.01939	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39212	 39215	 0.000819	 0.006662	 0.02183	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88311	 39212	 0.011553	 0.081163	 0.13856	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39213	 88547	 0.12159	 0.09623	 0.00121	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39214	 39216	 0.003362	 0.009911	 0.00231	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39214	 88545	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39214	 88545	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88540	 39215	 0.018751	 0.1257	 0.23866	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39215	 88546	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88547	 39215	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39216	 39217	 0.001358	 0.006941	 0.00189	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39216	 39219	 0.001697	 0.010183	 0.00308	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88546	 39216	 0.00193	 0.012429	 0.00326	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39216	 88548	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39216	 88548	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39217	 39224	 0.002728	 0.013945	 0.0038	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39218	 39219	 0.001668	 0.010564	 0.00287	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39218	 39223	 0.001387	 0.00981	 0.00269	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39220	 39221	 0.005968	 0.025259	 0.00568	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39221	 39222	 0.00494	 0.020102	 0.0049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39222	 39223	 0.004806	 0.025834	 0.00636	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39223	 39224	 0.002636	 0.013022	 0.0038	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88546	 39225	 0.002242	 0.018356	 0.0118	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39226	 39331	 0.001052	 0.013587	 0.03079	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87238	 39226	 0.000375	 0.005573	 0.02066	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87246	 39226	 0.00055	 0.007714	 0.01479	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39227	 39228	 0.004593	 0.042767	 0.01325	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87212	 39227	 0.002295	 0.02242	 0.00629	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39228	 88549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39228	 88549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39229	 39233	 0.004202	 0.036401	 0.01307	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39229	 39234	 0.006207	 0.032874	 0.00833	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87241	 39229	 0.00372	 0.036347	 0.0102	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39230	 39231	 0.00425	 0.017292	 0.00421	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39230	 39233	 0.009723	 0.033354	 0.00799	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87239	 39230	 0.015212	 0.088376	 0.02082	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88524	 39231	 0.001929	 0.014003	 0.00484	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39232	 39233	 0.003731	 0.01843	 0.00538	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39234	 39235	 0.006281	 0.032718	 0.00858	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39236	 39237	 0.022597	 0.014629	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39236	 39239	 0.035532	 0.028119	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39236	 88552	 0.00295	 0.011349	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39238	 39240	 0.003817	 0.013094	 0.00314	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39238	 39260	 0.001395	 0.006398	 0.00164	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39240	 39242	 0.001276	 0.004448	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39241	 39242	 0.000756	 0.003431	 0.00119	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39241	 88550	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39241	 88550	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39241	 88551	 0.002155	 0.011224	 0.00294	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39242	 39263	 0.004257	 0.02288	 0.00563	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39243	 88552	 0.029778	 0.023566	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39244	 39268	 0.000254	 0.003138	 0.00629	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87210	 39244	 0.002198	 0.021897	 0.07309	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39244	 88551	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88552	 39244	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39245	 39247	 0.002564	 0.006776	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88551	 39245	 0.002155	 0.00554	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39246	 39248	 0.001234	 0.004158	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88551	 39246	 0.004775	 0.01262	 0.00295	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39247	 39256	 0.002946	 0.00791	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39248	 88555	 0.001301	 0.004463	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39249	 39259	 0.000123	 0.00158	 0.11846	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39249	 88553	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88554	 39250	 0.043172	 0.033116	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39251	 39252	 0.000213	 0.001421	 0.00268	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39251	 39268	 0.000841	 0.008005	 0.01422	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39251	 39269	 0.000526	 0.007379	 0.01415	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88553	 39251	 0.000119	 0.001661	 0.00542	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39251	 88555	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39251	 88555	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39252	 88557	 0.00054	 0.003557	 0.00688	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39253	 39271	 0.003891	 0.01311	 0.00326	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87726	 39253	 0.003167	 0.012447	 0.00326	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39253	 88563	 0.009731	 0.025718	 0.00602	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39253	 88565	 0.006805	 0.018976	 0.00398	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39254	 39256	 0.003877	 0.010245	 0.0024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39254	 88558	 0.002734	 0.008501	 0.00177	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39255	 88556	 0.031608	 0.025014	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39256	 39257	 0.001023	 0.003414	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39256	 88556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39256	 88556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88555	 39257	 0.001707	 0.006035	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39258	 39259	 0.00013	 0.00241	 0.15909	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39258	 88557	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88558	 39258	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39259	 88559	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88559	 39260	 0.004701	 0.033821	 0.00896	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87211	 39261	 0.004276	 0.048134	 0.01392	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39262	 39263	 0.00461	 0.015378	 0.0039	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39263	 39264	 0.002078	 0.009834	 0.00236	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39264	 88561	 0.006156	 0.021118	 0.00506	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88550	 39265	 0.022881	 0.017935	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39266	 88564	 0.020568	 0.048706	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39267	 39272	 0.000561	 0.008856	 0.01857	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39267	 39342	 0.001071	 0.013266	 0.04789	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39267	 88561	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88562	 39267	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39268	 39269	 0.000386	 0.003264	 0.00636	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39268	 88563	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88564	 39268	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39269	 39272	 0.00027	 0.002024	 0.00783	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39269	 88565	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39269	 88565	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39270	 39271	 0.001614	 0.004149	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88565	 39270	 0.002698	 0.007005	 0.0017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39272	 88566	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39272	 88566	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88561	 39273	 0.00288	 0.018831	 0.00479	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88566	 39273	 0.001748	 0.011725	 0.00283	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88560	 39274	 0.16039	 0.12694	 0.0016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39275	 39276	 0.007726	 0.025773	 0.00654	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39277	 39278	 0.007933	 0.033576	 0.00756	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39277	 88567	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39277	 88567	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39278	 39281	 0.008888	 0.040776	 0.01045	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39279	 39404	 0.01647	 0.085819	 0.02252	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87227	 39279	 0.005706	 0.057685	 0.01696	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39279	 88568	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39279	 88568	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87227	 39280	 0.005939	 0.043878	 0.01267	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39281	 39335	 0.005926	 0.03087	 0.0081	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39282	 39288	 0.000935	 0.011173	 0.02207	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87801	 39282	 0.001603	 0.017432	 0.03789	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39283	 88570	 0.07014	 0.055509	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87791	 39284	 0.048676	 0.12513	 0.00194	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39285	 39286	 0.012626	 0.034378	 0.00757	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39286	 39291	 0.011341	 0.029153	 0.00722	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39287	 39289	 6.2e-05	 0.000737	 0.0553	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39287	 49555	 0.000943	 0.011267	 0.84719	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39287	 88569	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39287	 88569	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87825	 39288	 0.002794	 0.026595	 0.04726	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39288	 88570	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39288	 88570	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39288	 88571	 0.000314	 0.003523	 0.00645	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39288	 88571	 0.000314	 0.003523	 0.00645	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39289	 88571	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88572	 39289	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39290	 39291	 0.008043	 0.032202	 0.00811	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88572	 39290	 0.004742	 0.017251	 0.00528	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88396	 39291	 0.027332	 0.070857	 0.02144	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39292	 39295	 0.13921	 0.11017	 0.00139	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39293	 39294	 0.031082	 0.079047	 0.00125	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39294	 39295	 0.042904	 0.084948	 0.00125	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39294	 39296	 0.13664	 0.10814	 0.00136	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39295	 88574	 0.095839	 0.22253	 0.00331	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39297	 88574	 0.051515	 0.102	 0.0015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39298	 39307	 0.21145	 0.16736	 0.00211	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88473	 39299	 0.013999	 0.071572	 0.01951	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39300	 88763	 0.11752	 0.2251	 0.00354	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39303	 39304	 0.008788	 0.026318	 0.00593	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39304	 88573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39304	 88573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86575	 39305	 0.14949	 0.42443	 0.00667	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87247	 39305	 0.35022	 0.69443	 0.01021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88573	 39305	 0.024109	 0.10684	 0.00321	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87242	 39306	 0.26344	 0.59842	 0.01196	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39307	 39321	 0.01727	 0.066169	 0.00187	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88314	 39307	 0.11177	 0.23957	 0.0042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39308	 39311	 0.002758	 0.009291	 0.00231	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39308	 88574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39308	 88574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39309	 88577	 0.10458	 0.08198	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39310	 39316	 0.003926	 0.021163	 0.00043	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39310	 88577	 0.009449	 0.050344	 0.00088	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39311	 39312	 0.001715	 0.005592	 0.00148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39312	 39314	 0.00177	 0.010982	 0.00266	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39312	 88575	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39312	 88575	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88575	 39313	 0.008565	 0.016958	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39314	 39315	 0.001254	 0.006741	 0.00166	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39314	 39320	 0.003878	 0.013515	 0.00313	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39314	 88576	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39314	 88576	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39315	 39317	 0.002255	 0.01065	 0.00341	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88576	 39316	 0.01553	 0.028875	 0.00068	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39316	 88578	 0.038532	 0.089458	 0.00133	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39317	 39319	 0.00508	 0.026464	 0.00694	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39317	 88577	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39317	 88577	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39320	 39326	 0.019575	 0.18457	 0.05605	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39320	 39812	 0.008576	 0.022665	 0.00531	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39320	 88578	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39320	 88578	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88578	 39321	 0.017251	 0.085597	 0.00204	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87247	 39322	 0.022752	 0.1253	 0.00283	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87213	 39323	 0.03851	 0.091194	 0.00167	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39324	 39326	 0.001821	 0.018722	 0.00708	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87212	 39324	 0.003342	 0.037011	 0.01204	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39325	 88579	 0.01928	 0.049562	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39326	 39327	 0.001208	 0.008544	 0.00234	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87215	 39326	 0.004927	 0.053111	 0.0284	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39326	 88579	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39326	 88579	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39328	 88586	 0.001699	 0.013244	 0.00396	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87226	 39329	 0.001593	 0.01034	 0.0206	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39329	 88580	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39329	 88580	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39329	 88584	 0.002109	 0.014385	 0.0259	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87228	 39330	 0.014496	 0.048359	 0.00077	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87226	 39331	 0.001165	 0.015478	 0.03307	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39331	 88581	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88582	 39331	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88582	 39332	 0.21033	 0.15207	 0.00231	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39332	 88583	 0.031258	 0.057252	 0.00099	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87246	 39333	 0.001283	 0.018041	 0.07485	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39333	 88583	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39333	 88583	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39333	 88584	 0.000485	 0.00761	 0.02526	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39334	 88584	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39334	 88584	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39335	 39336	 0.004128	 0.01416	 0.00339	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87227	 39335	 0.001058	 0.010881	 0.00309	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39336	 39337	 0.007436	 0.026282	 0.00592	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39337	 88586	 0.008138	 0.021849	 0.00495	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39338	 88585	 0.000101	 0.00811	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88586	 39338	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39339	 88737	 0.043319	 0.10604	 0.00181	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39340	 39341	 0.035731	 0.070746	 0.00104	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39340	 39709	 0.018073	 0.059641	 0.00097	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39340	 39711	 0.022413	 0.035776	 0.00082	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88318	 39340	 0.030037	 0.18468	 0.00333	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39342	 39345	 0.001164	 0.012564	 0.02494	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39342	 88587	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39342	 88587	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39343	 88588	 0.036519	 0.027668	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39344	 39352	 0.006219	 0.031245	 0.00813	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88587	 39344	 0.008519	 0.030847	 0.00662	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39344	 88588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39344	 88588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39344	 88589	 0.001359	 0.006169	 0.00214	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88330	 39345	 0.003772	 0.031078	 0.06408	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39345	 88589	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88590	 39345	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39346	 39348	 0.029692	 0.076327	 0.00118	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88590	 39346	 0.007115	 0.022591	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88590	 39347	 0.01464	 0.037633	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39349	 39350	 0.060707	 0.044664	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88590	 39350	 0.022361	 0.073792	 0.0012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39351	 39724	 0.027756	 0.054397	 0.00082	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39353	 39354	 0.007311	 0.02439	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39353	 88605	 0.014746	 0.038982	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39354	 39355	 0.008888	 0.020635	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39355	 88591	 0.00881	 0.014062	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39356	 88591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39356	 88591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39356	 88592	 0.002324	 0.008214	 0.00185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88591	 39357	 0.006373	 0.016381	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88347	 39358	 0.000732	 0.010943	 0.0256	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39358	 88592	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88593	 39358	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88593	 39359	 0.024804	 0.11053	 0.00188	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39359	 88606	 0.027084	 0.031748	 0.00055	 36.0	 36.0	 36.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39360	 39361	 0.024429	 0.017973	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39361	 39362	 0.021215	 0.015336	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39361	 39364	 0.009491	 0.022035	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39363	 39373	 0.007592	 0.020382	 0.00462	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88592	 39363	 0.002379	 0.008016	 0.00199	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39363	 88594	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39363	 88594	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88594	 39364	 0.007176	 0.016992	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88594	 39365	 0.022319	 0.04419	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39366	 39367	 0.019259	 0.049914	 0.00094	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39366	 88605	 0.004137	 0.023278	 0.0005	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39367	 39873	 0.054395	 0.1077	 0.00158	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39368	 88605	 0.074405	 0.22399	 0.00438	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39369	 39387	 0.0054	 0.019554	 0.0042	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39370	 39376	 0.005004	 0.024283	 0.00555	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39370	 88595	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39370	 88595	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39371	 39386	 0.001839	 0.015598	 0.00934	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39371	 88596	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39371	 88596	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39372	 39373	 0.005116	 0.013152	 0.00326	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88592	 39372	 0.004808	 0.012087	 0.00313	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39373	 39375	 0.00598	 0.023941	 0.00603	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39373	 88597	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39373	 88597	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88597	 39374	 0.037661	 0.045084	 0.00075	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39375	 39376	 0.004526	 0.019155	 0.00431	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39375	 88598	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39375	 88598	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39376	 39377	 0.004316	 0.022064	 0.00601	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39376	 39380	 0.004429	 0.022642	 0.00617	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39378	 39388	 0.044845	 0.045295	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39378	 88606	 0.011315	 0.043532	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39379	 39380	 0.001826	 0.00615	 0.00153	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39379	 39401	 0.00716	 0.021111	 0.00491	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39379	 88599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39379	 88599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39380	 39381	 0.001155	 0.004889	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39381	 39396	 0.002096	 0.00719	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39382	 88603	 0.015459	 0.031636	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39383	 39388	 0.050362	 0.050867	 0.00067	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39383	 88606	 0.015973	 0.045328	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39384	 39390	 0.018588	 0.036803	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39385	 88604	 0.03853	 0.064907	 0.00092	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39386	 39396	 0.001362	 0.015571	 0.00436	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39386	 88600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39386	 88600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39387	 39399	 0.003667	 0.012778	 0.00296	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39387	 88601	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39387	 88601	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39388	 88602	 0.009008	 0.020912	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39389	 39395	 0.001932	 0.005389	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39389	 88602	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39389	 88602	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39390	 39391	 0.005723	 0.014713	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39391	 39392	 0.028502	 0.022341	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39391	 39393	 0.009747	 0.022393	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39391	 88603	 0.00707	 0.043442	 0.00099	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39392	 39393	 0.00773	 0.018304	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39393	 39397	 0.005958	 0.019661	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88292	 39393	 0.10428	 0.26812	 0.00415	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88602	 39393	 0.023895	 0.050221	 0.00091	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39394	 39395	 0.001686	 0.005782	 0.00139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39394	 39396	 0.001361	 0.007969	 0.00217	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39396	 39399	 0.004803	 0.012693	 0.00297	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88592	 39396	 0.019261	 0.062833	 0.01668	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39396	 88603	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39396	 88603	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39397	 39398	 0.013692	 0.020974	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88603	 39397	 0.003417	 0.023456	 0.00043	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39399	 88604	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39399	 88604	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39400	 39401	 0.007919	 0.026419	 0.0067	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88592	 39400	 0.001556	 0.013476	 0.00484	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39400	 88605	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39400	 88605	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39401	 88606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39401	 88606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39402	 88607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39402	 88607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39403	 39404	 0.011518	 0.039514	 0.00947	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39403	 88608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39403	 88608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39404	 88609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39404	 88609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88290	 39405	 0.18426	 0.14584	 0.00184	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88567	 39406	 0.071652	 0.18421	 0.00285	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88609	 39406	 0.047017	 0.096221	 0.00237	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39407	 39408	 0.010987	 0.029037	 0.0068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87215	 39407	 0.031802	 0.079967	 0.02072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39407	 88610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39407	 88610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88610	 39409	 0.12499	 0.080922	 0.00154	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39410	 39411	 0.003748	 0.015476	 0.00366	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39412	 39413	 0.00219	 0.008766	 0.00221	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39413	 39414	 0.004605	 0.019489	 0.00439	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39413	 39415	 0.00285	 0.014317	 0.00373	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39413	 39421	 0.010439	 0.043105	 0.0102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39415	 39416	 0.005249	 0.018007	 0.00431	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39416	 39420	 0.002381	 0.007765	 0.00206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39417	 39421	 0.002366	 0.015875	 0.00383	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39418	 88612	 0.024544	 0.090753	 0.00168	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39419	 88611	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39419	 88611	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39419	 88615	 0.006352	 0.05071	 0.0125	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39420	 39421	 0.003183	 0.008264	 0.00201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39421	 39424	 0.004093	 0.014266	 0.00331	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39421	 88612	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39421	 88612	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39421	 88615	 0.02085	 0.056774	 0.01251	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39422	 39423	 0.005353	 0.018036	 0.00448	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39423	 88613	 0.006386	 0.017809	 0.00374	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39423	 88615	 0.012362	 0.036449	 0.00848	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39424	 39426	 0.004134	 0.01504	 0.0046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39425	 88613	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39425	 88613	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39425	 88614	 0.000827	 0.006814	 0.01404	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88613	 39426	 0.003388	 0.015544	 0.00398	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39427	 39658	 0.00104	 0.01653	 1.5364	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39427	 39658	 0.00104	 0.01653	 1.5364	 2700.0	 2700.0	 2700.0	 0.0	 0.0	 0	 -30.0	 30.0;
	39427	 88614	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39427	 88614	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95333	 39427	 0.000819	 0.02876	 2.504	 4217.0	 4427.8	 4638.7	 0.0	 0.0	 0	 -30.0	 30.0;
	39428	 39429	 0.000398	 0.002469	 0.0006	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39428	 39430	 0.000629	 0.004116	 0.00105	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39428	 88617	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39428	 88617	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39429	 39529	 0.000687	 0.00427	 0.00121	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39430	 39513	 0.000964	 0.006685	 0.00191	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39430	 88618	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39430	 88618	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39431	 39528	 0.004395	 0.014502	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88618	 39431	 0.006567	 0.013002	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39432	 39433	 0.000756	 0.003822	 0.00106	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39432	 39515	 0.001265	 0.006238	 0.00169	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39433	 39442	 0.000593	 0.003088	 0.00081	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39433	 88619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39433	 88619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39434	 39435	 0.003793	 0.014228	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39434	 88653	 0.011352	 0.016833	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88619	 39435	 0.027404	 0.021687	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39435	 88621	 0.002911	 0.012972	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39436	 88653	 0.017397	 0.014319	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39437	 39451	 0.000993	 0.005173	 0.00136	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39437	 39498	 0.001555	 0.004361	 0.00112	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39437	 39499	 0.001512	 0.005187	 0.00124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39437	 88620	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39437	 88620	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88620	 39438	 0.007332	 0.01343	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39438	 88623	 0.004623	 0.015423	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39439	 39440	 0.000552	 0.002877	 0.00075	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39439	 39450	 0.000931	 0.003245	 0.00075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39439	 39527	 0.000815	 0.005163	 0.0014	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39440	 39449	 0.000436	 0.00276	 0.00075	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39440	 88621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39440	 88621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39441	 39448	 0.00481	 0.013797	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88621	 39441	 0.009387	 0.015813	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39442	 39447	 0.000663	 0.003356	 0.00093	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39443	 39444	 0.005022	 0.009943	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39443	 39528	 0.005889	 0.009021	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39444	 39445	 0.004196	 0.008587	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39445	 88654	 0.002237	 0.006861	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39446	 39447	 0.000465	 0.002463	 0.00062	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39446	 39460	 0.000513	 0.002672	 0.0007	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39447	 88622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39447	 88622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39448	 39456	 0.003099	 0.009507	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39449	 39453	 0.000536	 0.002989	 0.00076	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39450	 39452	 0.000512	 0.002722	 0.00063	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39450	 88623	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39450	 88623	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39451	 39485	 0.000859	 0.004245	 0.00124	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39452	 39483	 0.001034	 0.004024	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39452	 39485	 0.002271	 0.006182	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39453	 39474	 0.00166	 0.008186	 0.00221	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39453	 39478	 0.00116	 0.003978	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39454	 88625	 0.010108	 0.020012	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39455	 88624	 0.019682	 0.015576	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39456	 88625	 0.001199	 0.006416	 0.00019	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39457	 39458	 0.000802	 0.003209	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39457	 39474	 0.000537	 0.002997	 0.00077	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39457	 88624	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39457	 88624	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39458	 88625	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39458	 88625	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39458	 88655	 0.001979	 0.007166	 0.00154	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39459	 39460	 0.000325	 0.001692	 0.00044	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39459	 39465	 0.000368	 0.001919	 0.0005	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39460	 88626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39460	 88626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39461	 88656	 0.006962	 0.011611	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39462	 39463	 0.00223	 0.013358	 0.00032	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39462	 88656	 0.002577	 0.010065	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39463	 88660	 0.00174	 0.013565	 0.00025	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39464	 39465	 0.000497	 0.002589	 0.00068	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39464	 88658	 0.000429	 0.002194	 0.0006	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39466	 39532	 0.000129	 0.000932	 0.00188	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39466	 39533	 0.00019	 0.001327	 0.00228	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39467	 39468	 0.000126	 0.000982	 0.00352	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39467	 88708	 0.000162	 0.002526	 0.00543	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39468	 39469	 0.000201	 0.001358	 0.0025	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39468	 39470	 0.000252	 0.001779	 0.00377	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39469	 39470	 0.00024	 0.001657	 0.00292	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39469	 39642	 0.000258	 0.002974	 0.00633	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39469	 88627	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39469	 88627	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39470	 39532	 0.000162	 0.001728	 0.00313	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39470	 88628	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88629	 39470	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88628	 39471	 0.000945	 0.003292	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39471	 88659	 0.001048	 0.003154	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88629	 39472	 0.012097	 0.009482	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39473	 88636	 0.027359	 0.021652	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39473	 88657	 0.018303	 0.014485	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39474	 39531	 0.000566	 0.002892	 0.00079	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39474	 88630	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39474	 88630	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39474	 88635	 0.00183	 0.006658	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39475	 39476	 0.012769	 0.008267	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88630	 39475	 0.018402	 0.014563	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39476	 88631	 0.013408	 0.010611	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39477	 39478	 0.001001	 0.004546	 0.00158	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39477	 88631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39477	 88631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39477	 88635	 0.000456	 0.003726	 0.00101	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39478	 88632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39478	 88632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39479	 39480	 0.000792	 0.002715	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39479	 39483	 0.000823	 0.003896	 0.00094	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39479	 88633	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39479	 88633	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39480	 39481	 0.000634	 0.002412	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39481	 39493	 0.00071	 0.003446	 0.00079	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39482	 39484	 0.004719	 0.009657	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39482	 88637	 0.004754	 0.011257	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39484	 88634	 0.008507	 0.016291	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39485	 39486	 0.000556	 0.002551	 0.00065	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39485	 39496	 0.001699	 0.006152	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39485	 88634	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39485	 88634	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39485	 88713	 0.003553	 0.029487	 0.00776	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39486	 39492	 0.000634	 0.003205	 0.00089	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88627	 39487	 0.018091	 0.011712	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39488	 39642	 0.00027	 0.003486	 0.0079	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39488	 88635	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88636	 39488	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39489	 39493	 0.000839	 0.006697	 0.00165	 266.0	 266.0	 266.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39489	 88711	 0.000936	 0.007052	 0.00196	 266.0	 266.0	 266.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39490	 88712	 0.029425	 0.023065	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39491	 39492	 0.001131	 0.004528	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39491	 39494	 0.001026	 0.00403	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88635	 39491	 0.002705	 0.010281	 0.00288	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39491	 88637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39491	 88637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39492	 88638	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39492	 88638	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39493	 39494	 0.001029	 0.00391	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39494	 39495	 0.001669	 0.004921	 0.00114	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39495	 39517	 0.001254	 0.006298	 0.00164	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39495	 39534	 0.001782	 0.00497	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39496	 39497	 0.001988	 0.005576	 0.00144	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39497	 88639	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39497	 88639	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39498	 39508	 0.001409	 0.004596	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39498	 88640	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39498	 88640	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39499	 88641	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39499	 88641	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39500	 39550	 0.013189	 0.023705	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88641	 39500	 0.004064	 0.018108	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88641	 39501	 0.020417	 0.016157	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39502	 39506	 0.000965	 0.006217	 0.00163	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39502	 39587	 0.001435	 0.005022	 0.00166	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39502	 88642	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39502	 88642	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39503	 39504	 0.000885	 0.002469	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39503	 39534	 0.001423	 0.003659	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39504	 39505	 0.001387	 0.003488	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39505	 39506	 0.000763	 0.006233	 0.00169	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39505	 39521	 0.000845	 0.006133	 0.00212	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39506	 88643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39506	 88643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39507	 88651	 0.025426	 0.01993	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39508	 39551	 0.001681	 0.005768	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39509	 39535	 0.065633	 0.085416	 0.00119	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39509	 88645	 0.013857	 0.025003	 0.00036	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39509	 88656	 0.0191	 0.079727	 0.0023	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39510	 88646	 0.011943	 0.022572	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39511	 39512	 0.001905	 0.006535	 0.00157	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39511	 39516	 0.001661	 0.004896	 0.00114	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39511	 88644	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39511	 88644	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39512	 39513	 0.001226	 0.005187	 0.00117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39512	 88645	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39512	 88645	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39513	 88646	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39513	 88646	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39514	 39515	 0.001677	 0.006714	 0.00169	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39514	 39516	 0.002025	 0.006823	 0.0017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39514	 88647	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39514	 88647	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39515	 88648	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39515	 88648	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39516	 39538	 0.002501	 0.013464	 0.0037	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39517	 39526	 0.001279	 0.006665	 0.00175	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39517	 88649	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39517	 88649	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39518	 39520	 0.001191	 0.004086	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39518	 88650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39518	 88650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88649	 39519	 0.015138	 0.015182	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39520	 39523	 0.001264	 0.004575	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39521	 88651	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39521	 88651	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39521	 88713	 0.00137	 0.014097	 0.004	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39522	 39610	 0.005253	 0.008047	 0.00011	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39523	 39524	 0.001684	 0.005238	 0.00109	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39523	 88652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39523	 88652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39523	 88713	 0.001339	 0.010086	 0.0028	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39524	 39611	 0.001463	 0.003865	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39525	 39526	 0.000854	 0.003323	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39525	 39645	 0.001357	 0.005745	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39526	 88713	 0.00231	 0.012034	 0.00316	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39527	 39543	 0.002973	 0.010361	 0.0024	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39527	 39549	 0.004766	 0.01661	 0.00385	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39527	 88653	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39527	 88653	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39527	 88718	 0.004346	 0.04173	 0.01214	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88622	 39528	 0.007382	 0.017139	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39529	 88654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39529	 88654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39529	 88655	 0.000539	 0.003757	 0.00141	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39530	 39533	 0.000284	 0.002654	 0.00489	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39530	 88655	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88656	 39530	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39531	 88657	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39531	 88657	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39531	 88658	 0.000755	 0.003999	 0.00101	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39532	 39605	 0.00437	 0.030111	 0.05317	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39532	 88658	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39532	 88658	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39533	 88659	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88660	 39533	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39533	 88717	 0.000341	 0.005323	 0.01144	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39534	 88661	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39534	 88661	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39536	 88662	 0.096181	 0.076118	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39537	 39540	 0.002101	 0.009363	 0.00254	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39537	 39742	 0.003805	 0.017133	 0.00456	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39538	 39540	 0.005383	 0.018138	 0.00451	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39538	 88662	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39538	 88662	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39538	 88718	 0.007398	 0.06346	 0.01806	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39539	 39540	 0.004056	 0.012147	 0.00274	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39539	 39547	 0.00392	 0.011353	 0.00274	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39540	 88663	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39540	 88663	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88663	 39541	 0.042413	 0.030043	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39542	 88664	 0.024105	 0.019077	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39543	 39546	 0.002507	 0.007189	 0.00177	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39543	 88664	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39543	 88664	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39544	 88665	 0.025207	 0.019335	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39545	 39546	 0.001708	 0.004294	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39545	 39547	 0.003762	 0.010241	 0.00226	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39545	 88665	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39545	 88665	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39547	 39548	 0.003077	 0.007734	 0.002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39547	 39560	 0.002958	 0.007818	 0.00183	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39548	 39549	 0.00204	 0.005391	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39549	 39561	 0.002831	 0.007481	 0.00175	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39549	 88666	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39549	 88666	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88666	 39550	 0.021125	 0.018055	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39551	 39552	 0.0022	 0.006134	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39551	 88667	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39551	 88667	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39552	 39553	 0.002241	 0.005203	 0.00158	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39553	 39562	 0.002212	 0.005845	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39553	 88668	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39553	 88668	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39554	 39567	 0.003476	 0.010809	 0.00226	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39554	 39573	 0.001661	 0.005417	 0.00144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39554	 88669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39554	 88669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39555	 39556	 0.00146	 0.004188	 0.00103	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39555	 39557	 0.001492	 0.00375	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39555	 88670	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39555	 88670	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39556	 39562	 0.001073	 0.003336	 0.0007	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39557	 39558	 0.002979	 0.008784	 0.00204	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39557	 88671	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39557	 88671	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39558	 39568	 0.00989	 0.033928	 0.00813	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39558	 88672	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39558	 88672	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88671	 39559	 0.008438	 0.019588	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39559	 88673	 0.010782	 0.015027	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39559	 88674	 0.019848	 0.024637	 0.00054	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39560	 88673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39560	 88673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39561	 39562	 0.002191	 0.005688	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39562	 88674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39562	 88674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39563	 88675	 0.1177	 0.08509	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39564	 39568	 0.004375	 0.017518	 0.00441	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39564	 39749	 0.007429	 0.029197	 0.00764	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39564	 88675	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39564	 88675	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39565	 39567	 0.004974	 0.017334	 0.00402	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39565	 39568	 0.003948	 0.012341	 0.00357	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39566	 39585	 0.003077	 0.008131	 0.0019	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39566	 88676	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39566	 88676	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39567	 88677	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39567	 88677	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39568	 39569	 0.007232	 0.028957	 0.0073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39568	 39741	 0.01652	 0.047854	 0.01154	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87193	 39568	 0.015709	 0.11378	 0.06131	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39568	 88678	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39568	 88678	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39569	 39585	 0.004918	 0.016408	 0.00416	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39569	 88679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39569	 88679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39570	 88696	 0.026445	 0.05236	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39571	 39572	 0.002572	 0.00745	 0.0018	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39571	 39587	 0.002055	 0.007441	 0.0016	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39571	 88680	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39571	 88680	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39572	 39573	 0.001868	 0.006093	 0.00162	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39572	 88681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39572	 88681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39573	 88682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39573	 88682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39574	 39576	 0.001671	 0.00605	 0.0013	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39574	 88683	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39574	 88683	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39575	 88684	 0.011123	 0.022022	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39575	 88688	 0.026152	 0.020499	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39576	 39577	 0.002094	 0.005437	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39576	 39648	 0.002114	 0.006896	 0.00183	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39576	 88684	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39576	 88684	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39577	 39578	 0.001835	 0.00426	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39577	 39581	 0.001857	 0.005589	 0.00175	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39578	 39579	 0.001464	 0.003986	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39579	 39580	 0.00163	 0.003927	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39579	 39585	 0.001918	 0.00768	 0.00193	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39580	 39581	 0.002261	 0.007541	 0.00191	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39581	 39584	 0.00071	 0.005189	 0.00153	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39581	 88685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39581	 88685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88685	 39582	 0.017134	 0.026247	 0.00037	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39583	 39584	 0.000764	 0.006136	 0.00172	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39583	 88686	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39583	 88686	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39583	 88695	 0.001988	 0.015497	 0.00463	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39584	 39596	 0.002631	 0.007064	 0.0016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39585	 88687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39585	 88687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88682	 39586	 0.010893	 0.021566	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88687	 39586	 0.004979	 0.01413	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39587	 88688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39587	 88688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39588	 39648	 0.001964	 0.007862	 0.00198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39588	 88689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39588	 88689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39588	 88713	 0.005455	 0.027884	 0.0076	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39589	 39590	 0.032104	 0.025165	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39589	 39599	 0.01137	 0.008219	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88689	 39589	 0.025613	 0.02027	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88651	 39590	 0.018519	 0.047605	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39590	 88693	 0.027501	 0.030248	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39591	 39610	 0.017008	 0.015949	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39592	 39601	 0.001302	 0.004386	 0.00109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39592	 39613	 0.001707	 0.00575	 0.00143	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39593	 39612	 0.017465	 0.013822	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39593	 88690	 0.041086	 0.041096	 0.00056	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39594	 88690	 0.009337	 0.018487	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39595	 39598	 0.003334	 0.011437	 0.00274	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39595	 39602	 0.004124	 0.010366	 0.00269	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39595	 88690	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39595	 88690	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39595	 88713	 0.008693	 0.030727	 0.00692	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39596	 39600	 0.001643	 0.004224	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39596	 88691	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39596	 88691	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88686	 39597	 0.04502	 0.035628	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88690	 39597	 0.020881	 0.038246	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39598	 88695	 0.002412	 0.009652	 0.00326	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39599	 88692	 0.00905	 0.01412	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39600	 39601	 0.002235	 0.006085	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39600	 88692	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39600	 88692	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39601	 88693	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39601	 88693	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39602	 39619	 0.003027	 0.008	 0.00187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39603	 39604	 0.004482	 0.011635	 0.00282	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39604	 39606	 0.002845	 0.007151	 0.00185	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39604	 88694	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39604	 88694	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39605	 88695	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88696	 39605	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39605	 91055	 0.009533	 0.065099	 0.11743	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39606	 88697	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39606	 88697	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88697	 39607	 0.014807	 0.015119	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88402	 39608	 0.014596	 0.056782	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88697	 39608	 0.008138	 0.027147	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88402	 39609	 0.022052	 0.07002	 0.00123	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88697	 39609	 0.012923	 0.02759	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88652	 39610	 0.009677	 0.027753	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39611	 39613	 0.000996	 0.002633	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39611	 88698	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39611	 88698	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39612	 88699	 0.020651	 0.016343	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39613	 39614	 0.000791	 0.002863	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39614	 39616	 0.001102	 0.003594	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39614	 88699	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39614	 88699	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88652	 39615	 0.013051	 0.025839	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39616	 39617	 0.000679	 0.004371	 0.00115	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39616	 88700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39616	 88700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39617	 88701	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39617	 88701	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39617	 88713	 0.000879	 0.008443	 0.00246	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39618	 39620	 0.0191	 0.014052	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39618	 88702	 0.013214	 0.017367	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39619	 39622	 0.001931	 0.005104	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39619	 88702	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39619	 88702	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88700	 39620	 0.009276	 0.01818	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88701	 39621	 0.019209	 0.021127	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39622	 39623	 0.001436	 0.003333	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39624	 39625	 0.020963	 0.01659	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88701	 39625	 0.011587	 0.026901	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88100	 39626	 0.03499	 0.041886	 0.0007	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39626	 88706	 0.029798	 0.045647	 0.00064	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39627	 39631	 0.000833	 0.005716	 0.00167	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39627	 39645	 0.001477	 0.005912	 0.002	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39627	 88703	 0.000897	 0.004353	 0.001	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39627	 88711	 0.001857	 0.007666	 0.00181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39628	 88703	 0.000383	 0.00322	 0.00095	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39628	 88711	 0.000425	 0.003202	 0.00089	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39629	 39630	 0.000207	 0.001619	 0.0032	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39629	 88703	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39629	 88703	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39630	 39644	 0.000452	 0.002976	 0.00576	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39630	 88704	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88705	 39630	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39631	 39633	 0.000632	 0.00424	 0.00102	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39631	 88706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39631	 88706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88705	 39632	 0.016932	 0.015172	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39632	 88707	 0.010578	 0.015413	 0.00035	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39633	 39634	 0.000643	 0.004461	 0.00127	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87190	 39634	 0.0012	 0.006067	 0.00169	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39634	 88707	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39634	 88707	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39635	 39637	 4.2e-05	 0.000497	 0.03726	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39635	 47174	 0.000168	 0.002592	 0.19944	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39636	 39637	 2.6e-05	 0.000362	 0.02312	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39636	 39643	 0.000207	 0.002468	 0.18513	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39636	 46846	 0.000828	 0.010716	 0.68508	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39636	 88708	 0.00014	 0.01123	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88709	 39636	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 0	 -30.0	 30.0;
	39637	 88710	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39637	 88710	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39638	 39639	 0.019394	 0.019399	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88705	 39638	 0.012431	 0.029436	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39640	 39641	 0.001544	 0.006007	 0.0016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88710	 39640	 0.001287	 0.005449	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39641	 88715	 0.003764	 0.009463	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39642	 88711	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88712	 39642	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39643	 88713	 0.000114	 0.009105	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39644	 88715	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39644	 88715	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39645	 88716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39645	 88716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39646	 88717	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87221	 39647	 0.006109	 0.016146	 0.00378	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39650	 39651	 0.007448	 0.019683	 0.00461	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39650	 88720	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39650	 88720	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39651	 39855	 0.009007	 0.036061	 0.00909	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39651	 88721	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39651	 88721	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87244	 39652	 0.061915	 0.12725	 0.00243	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88720	 39652	 0.042293	 0.086552	 0.00213	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39653	 39874	 0.01703	 0.051004	 0.01149	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39653	 88722	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39653	 88722	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39654	 88724	 0.046164	 0.14178	 0.00266	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39655	 88723	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39656	 39657	 0.017179	 0.046123	 0.01045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88723	 39656	 0.014125	 0.037331	 0.00874	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39658	 88725	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39658	 88725	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88727	 39659	 0.0214	 0.016774	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39660	 39671	 0.033012	 0.026125	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39660	 39672	 0.036331	 0.028752	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88726	 39661	 0.001481	 0.006795	 0.00174	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39661	 88728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39661	 88728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39662	 39664	 0.013877	 0.028399	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88728	 39662	 0.004367	 0.014918	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87225	 39663	 0.015062	 0.029518	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39664	 88729	 0.021811	 0.031782	 0.00072	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39665	 39695	 0.003999	 0.015719	 0.00411	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87224	 39666	 0.001691	 0.005802	 0.00139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39667	 39668	 0.045863	 0.060278	 0.00083	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87249	 39667	 0.008866	 0.022791	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88727	 39669	 0.037937	 0.079736	 0.00145	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88727	 39670	 0.020167	 0.039929	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39673	 39674	 0.037981	 0.026904	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88728	 39673	 0.009608	 0.024698	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88728	 39674	 0.012266	 0.026188	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39674	 88729	 0.017171	 0.040661	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39675	 39677	 0.023504	 0.036005	 0.00051	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39675	 88729	 0.016116	 0.041427	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88726	 39676	 0.003737	 0.019104	 0.00521	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39676	 88729	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39676	 88729	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39678	 39693	 0.019482	 0.086815	 0.00147	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88729	 39678	 0.009109	 0.056003	 0.00101	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39679	 88733	 0.030957	 0.055856	 0.00081	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39680	 39681	 0.001532	 0.008708	 0.00252	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39680	 39694	 0.001654	 0.011351	 0.00331	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39681	 39683	 0.002547	 0.010198	 0.00257	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39682	 88730	 0.00338	 0.013814	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39682	 88732	 0.06826	 0.1671	 0.00286	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39683	 39684	 0.002106	 0.005565	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39683	 88730	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39683	 88730	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39684	 88731	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39684	 88731	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39685	 39686	 0.011377	 0.029247	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39685	 39687	 0.023954	 0.055612	 0.00083	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88731	 39685	 0.005974	 0.017133	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39687	 88732	 0.051051	 0.11851	 0.00226	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39689	 88732	 0.034772	 0.068847	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87250	 39691	 0.054874	 0.088307	 0.00138	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88726	 39692	 0.007081	 0.075988	 0.01979	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39692	 88732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39692	 88732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39693	 88733	 0.015646	 0.052194	 0.00083	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88726	 39694	 0.009039	 0.054257	 0.01643	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39694	 88733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39694	 88733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87224	 39696	 0.006762	 0.022783	 0.00566	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39696	 88734	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39696	 88734	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39697	 39698	 0.005571	 0.020173	 0.00433	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39697	 39715	 0.006051	 0.020387	 0.00507	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39697	 88735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39697	 88735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39698	 39716	 0.013611	 0.046695	 0.01119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39698	 88736	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39698	 88736	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39699	 39700	 0.095483	 0.069026	 0.00105	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88736	 39699	 0.12246	 0.12505	 0.00195	 49.0	 49.0	 49.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39700	 88737	 0.01109	 0.05351	 0.00094	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88317	 39701	 0.010836	 0.087082	 0.02449	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39701	 88737	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39701	 88737	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39702	 39706	 0.031614	 0.048429	 0.00068	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39702	 39708	 0.030659	 0.051647	 0.00074	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39703	 39704	 0.043597	 0.032076	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39704	 39705	 0.013917	 0.048697	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39704	 39714	 0.016926	 0.082595	 0.00143	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39705	 39706	 0.027942	 0.080143	 0.00123	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88737	 39706	 0.018006	 0.051643	 0.00079	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39707	 39709	 0.090876	 0.071234	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39708	 39709	 0.028119	 0.055109	 0.00083	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39710	 39711	 0.015964	 0.045788	 0.0007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39710	 39726	 0.015146	 0.058269	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39712	 39727	 0.064654	 0.071113	 0.00095	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39712	 88741	 0.035819	 0.0702	 0.00105	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39713	 39714	 0.015414	 0.047285	 0.00128	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39713	 39728	 0.028012	 0.072598	 0.00137	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39714	 88739	 0.007826	 0.045644	 0.00092	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39715	 39718	 0.008508	 0.028382	 0.0072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39716	 39753	 0.011101	 0.038082	 0.00912	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39716	 88738	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39716	 88738	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39716	 88740	 0.006771	 0.03527	 0.00925	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87237	 39717	 0.12138	 0.085984	 0.00136	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39718	 39721	 0.000987	 0.006983	 0.00192	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39719	 39721	 0.001641	 0.00809	 0.00219	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39719	 88739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39719	 88739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39720	 88740	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39720	 88740	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39721	 39722	 0.001709	 0.006717	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88317	 39721	 0.015261	 0.0646	 0.01454	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88740	 39721	 0.001153	 0.009566	 0.00252	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39721	 88741	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39721	 88741	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39722	 39859	 0.00714	 0.029055	 0.00708	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39723	 88744	 0.011969	 0.02715	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39724	 39725	 0.016633	 0.0472	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39725	 88744	 0.011301	 0.066903	 0.0013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39726	 88742	 0.015169	 0.07402	 0.00128	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39727	 88742	 0.034988	 0.042653	 0.00068	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39728	 88746	 0.015066	 0.041731	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39729	 39732	 0.003156	 0.010633	 0.00264	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39729	 88742	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39729	 88742	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39730	 39734	 0.002142	 0.005507	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39730	 88743	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39730	 88743	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39731	 88744	 0.002228	 0.017361	 0.00032	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39731	 88745	 0.002119	 0.017146	 0.00044	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88317	 39732	 0.001469	 0.011577	 0.00339	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39732	 88744	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39732	 88744	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39733	 39734	 0.00194	 0.005409	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39733	 39738	 0.001631	 0.007344	 0.00195	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39733	 88745	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39733	 88745	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88743	 39735	 0.017486	 0.031429	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39736	 88746	 0.033293	 0.05855	 0.0011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39737	 39738	 0.001655	 0.004254	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39737	 88746	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39737	 88746	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39739	 88747	 0.099897	 0.13923	 0.00238	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39740	 39743	 0.004161	 0.016355	 0.00428	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39740	 39744	 0.006025	 0.024123	 0.00608	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39741	 39742	 0.002846	 0.01507	 0.00382	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39741	 39743	 0.004779	 0.019132	 0.00482	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39741	 39745	 0.004979	 0.024164	 0.00552	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39742	 88747	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39742	 88747	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39744	 39746	 0.005427	 0.020629	 0.00577	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39745	 39748	 0.003868	 0.026834	 0.00766	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39745	 39749	 0.004547	 0.016542	 0.00506	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39746	 39748	 0.003033	 0.009894	 0.00263	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87229	 39747	 0.001288	 0.020095	 0.04318	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39747	 88748	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88749	 39747	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39747	 91055	 0.002841	 0.029129	 0.05725	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88748	 39748	 0.000911	 0.006254	 0.00182	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39750	 39751	 0.038287	 0.096983	 0.00192	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88749	 39750	 0.034327	 0.088244	 0.00137	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39752	 39753	 0.006965	 0.025221	 0.00541	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39754	 39755	 0.055066	 0.14156	 0.00219	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39754	 39793	 0.038117	 0.12224	 0.00302	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39755	 39757	 0.00517	 0.013289	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39755	 88762	 0.050002	 0.17864	 0.00355	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39756	 39777	 0.062058	 0.099061	 0.00228	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88302	 39758	 0.084521	 0.26843	 0.00471	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88496	 39758	 0.04539	 0.24188	 0.00424	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39758	 88750	 0.015	 0.057707	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39759	 39760	 0.002913	 0.017898	 0.00654	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39759	 88750	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39759	 88750	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88750	 39761	 0.18326	 0.14505	 0.00183	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39762	 39763	 0.1009	 0.11098	 0.00148	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39763	 88753	 0.15421	 0.24743	 0.00457	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39765	 39768	 0.003805	 0.023645	 0.00667	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39765	 88751	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39765	 88751	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88292	 39766	 0.22772	 0.1747	 0.00235	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39766	 88752	 0.13085	 0.094597	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39766	 88753	 0.21297	 0.16856	 0.00212	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39767	 39768	 0.004341	 0.01489	 0.00357	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39767	 39770	 0.001738	 0.010094	 0.00238	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39767	 88752	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39767	 88752	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39768	 39769	 0.002429	 0.011475	 0.00367	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88307	 39768	 0.011966	 0.086102	 0.02283	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39768	 88753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39768	 88753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39769	 39772	 0.005073	 0.026428	 0.00693	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39770	 39771	 0.003505	 0.022578	 0.00592	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88307	 39771	 0.006597	 0.049694	 0.01379	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39773	 88754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39773	 88754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39773	 88761	 0.00127	 0.005168	 0.00126	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39774	 39784	 0.001837	 0.010128	 0.00237	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39774	 88761	 0.001696	 0.006788	 0.00171	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39775	 39790	 0.00235	 0.012011	 0.00327	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39775	 88755	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39775	 88755	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39775	 88761	 0.001398	 0.006905	 0.00202	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88755	 39776	 0.019989	 0.039576	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39777	 88762	 0.006773	 0.041642	 0.00075	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39778	 88762	 0.021921	 0.017348	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88754	 39779	 0.005246	 0.013486	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39779	 88756	 0.016601	 0.020237	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39780	 88756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39780	 88756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39780	 88761	 0.003286	 0.011897	 0.00255	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39781	 39782	 0.009081	 0.013233	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88754	 39781	 0.008324	 0.021574	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39783	 88757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39783	 88757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39783	 88761	 0.004105	 0.017865	 0.00509	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39785	 88758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39785	 88758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39786	 39787	 0.016283	 0.054319	 0.00086	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88758	 39786	 0.006658	 0.035759	 0.00085	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39786	 88762	 0.027386	 0.084104	 0.00158	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88734	 39787	 0.007522	 0.042756	 0.00077	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39788	 39789	 0.003535	 0.018413	 0.00483	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39788	 39790	 0.002457	 0.013542	 0.00317	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39789	 88759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39789	 88759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39791	 39794	 0.00548	 0.025556	 0.00633	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39791	 88760	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39791	 88760	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39792	 39793	 0.10523	 0.13695	 0.00192	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88760	 39792	 0.034649	 0.080442	 0.0012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88416	 39793	 0.018741	 0.1139	 0.0021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39795	 88761	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88762	 39795	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39796	 39797	 0.014416	 0.038705	 0.00877	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39796	 88763	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39796	 88763	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39798	 39799	 0.012132	 0.040475	 0.01027	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39800	 39810	 0.16231	 0.12846	 0.00162	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39801	 39804	 0.00238	 0.00802	 0.00199	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39801	 39806	 0.0113	 0.030766	 0.00678	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39801	 39807	 0.014055	 0.037147	 0.0087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39801	 88764	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39801	 88764	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88764	 39802	 0.036964	 0.029253	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39803	 39804	 0.002653	 0.008654	 0.0023	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88572	 39803	 0.010505	 0.036039	 0.00863	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39804	 88765	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39804	 88765	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88765	 39805	 0.011791	 0.009243	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39806	 39809	 0.013241	 0.03404	 0.00843	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39807	 88766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39807	 88766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39808	 39809	 0.013865	 0.035997	 0.00874	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88766	 39810	 0.16122	 0.1276	 0.00161	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39811	 88768	 0.016272	 0.072108	 0.00217	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39812	 39814	 0.006357	 0.021807	 0.00522	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39813	 88769	 0.061751	 0.11142	 0.00161	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39814	 39815	 0.001918	 0.011918	 0.00336	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39814	 88767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39814	 88767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39815	 39816	 0.004296	 0.030904	 0.00819	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39815	 88768	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39815	 88768	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39816	 88769	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39816	 88769	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39817	 39819	 0.007366	 0.022908	 0.00478	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39817	 39824	 0.002108	 0.008013	 0.00224	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88379	 39818	 0.066391	 0.052541	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39819	 39851	 0.011955	 0.036304	 0.00795	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39820	 39829	 0.003059	 0.010814	 0.00244	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39821	 39824	 0.003738	 0.009395	 0.00243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39822	 39823	 0.032483	 0.025462	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39822	 88772	 0.010828	 0.019042	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39824	 39825	 0.002561	 0.010664	 0.00333	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39825	 39830	 0.001536	 0.007998	 0.0021	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39825	 88770	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39825	 88770	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39826	 88771	 0.036892	 0.028918	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39827	 39829	 0.003862	 0.010367	 0.00235	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39827	 88771	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39827	 88771	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39828	 88772	 0.029768	 0.023558	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39829	 39830	 0.001451	 0.01026	 0.00282	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39829	 88772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39829	 88772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39830	 39841	 0.002332	 0.009491	 0.00231	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39830	 88773	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39830	 88773	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39830	 88781	 0.000505	 0.007354	 0.00235	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88370	 39831	 0.050112	 0.039658	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39832	 39834	 0.00461	 0.012182	 0.00285	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39834	 39840	 0.003091	 0.008024	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39835	 39837	 0.001165	 0.012885	 0.00386	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39835	 88776	 0.002821	 0.032836	 0.00965	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88328	 39836	 0.002279	 0.029894	 0.0657	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39836	 88774	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88775	 39836	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88774	 39837	 0.000958	 0.011379	 0.00396	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39838	 39840	 0.001008	 0.006095	 0.00156	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39838	 88776	 0.001574	 0.013411	 0.00335	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39839	 39842	 0.000326	 0.003811	 0.00789	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39839	 39843	 0.000496	 0.006398	 0.0145	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39839	 39853	 0.000884	 0.012156	 0.02422	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39839	 88776	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88777	 39839	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39840	 39841	 0.001391	 0.006263	 0.00167	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39842	 88778	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88779	 39842	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39843	 39844	 0.000161	 0.001418	 0.00296	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39843	 88780	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39843	 88780	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39844	 88781	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39844	 88781	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88779	 39845	 0.013003	 0.025483	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88778	 39846	 0.002611	 0.010626	 0.00259	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39846	 88782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39846	 88782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39847	 39848	 0.039478	 0.040311	 0.00063	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39847	 39850	 0.025976	 0.05143	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88782	 39847	 0.005734	 0.025398	 0.00058	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88770	 39849	 0.019263	 0.03814	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39850	 88783	 0.063363	 0.09887	 0.00165	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39851	 88783	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39851	 88783	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88776	 39852	 0.004006	 0.030172	 0.00837	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39854	 39855	 0.007041	 0.031376	 0.00853	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87236	 39854	 0.00359	 0.018702	 0.0049	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39855	 39869	 0.008321	 0.019315	 0.00588	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39856	 39857	 0.007583	 0.020357	 0.00461	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39856	 39865	 0.00533	 0.014087	 0.0033	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39857	 39858	 0.004848	 0.016336	 0.00406	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39857	 39864	 0.004095	 0.010822	 0.00253	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87236	 39858	 0.003046	 0.014782	 0.00338	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39859	 39860	 0.002338	 0.008887	 0.00249	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39860	 39861	 0.002245	 0.008988	 0.00226	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39861	 39863	 0.002347	 0.006919	 0.00161	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88387	 39862	 0.047663	 0.1573	 0.00255	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39862	 88784	 0.021047	 0.032242	 0.00045	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39862	 88787	 0.012411	 0.043426	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39863	 39864	 0.004533	 0.011652	 0.00289	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39864	 88784	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39864	 88784	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39865	 39867	 0.002669	 0.009665	 0.00207	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39865	 39868	 0.00166	 0.005869	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87236	 39865	 0.006342	 0.029958	 0.00959	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39866	 39868	 0.001784	 0.004716	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39866	 88785	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39866	 88785	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39867	 39869	 0.003755	 0.00944	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39869	 39870	 0.003081	 0.016983	 0.00397	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87236	 39869	 0.006665	 0.042218	 0.01146	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39869	 88786	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39869	 88786	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39870	 39874	 0.011807	 0.039389	 0.00999	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39871	 88787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39871	 88787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88787	 39872	 0.028369	 0.065853	 0.00125	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39875	 42164	 0.002701	 0.030638	 0.27951	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39875	 42790	 0.001883	 0.02134	 0.19448	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39875	 43768	 0.000462	 0.005229	 0.04761	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39875	 88788	 0.000119	 0.009548	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39875	 88788	 0.000119	 0.009548	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39876	 39890	 2e-06	 2.8e-05	 0.00047	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39876	 44106	 0.000659	 0.008338	 0.07438	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39876	 44107	 0.000382	 0.004037	 0.06038	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39876	 44107	 0.000382	 0.004037	 0.06038	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39877	 43313	 0.006729	 0.033181	 0.00897	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39877	 43336	 0.06666	 0.18174	 0.04011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39877	 43374	 0.026417	 0.10046	 0.02814	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39877	 43478	 0.015119	 0.12364	 0.03358	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39877	 43668	 0.002789	 0.030081	 0.00861	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39877	 43701	 0.009823	 0.032771	 0.00831	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39877	 43702	 0.013334	 0.051878	 0.01386	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39877	 88790	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39877	 88790	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39878	 40053	 0.001329	 0.015055	 0.13713	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39878	 43408	 0.001419	 0.025863	 0.25675	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39878	 44795	 0.002009	 0.035323	 0.37916	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39878	 88791	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39878	 88791	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39879	 43440	 7.8e-05	 0.000905	 0.00793	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39879	 88792	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39879	 88792	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39880	 39952	 0.002167	 0.01345	 0.00326	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39880	 88801	 0.001612	 0.017665	 0.0049	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39881	 43539	 0.000444	 0.004872	 0.04733	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39881	 88793	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39881	 88793	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39882	 39925	 2.8e-05	 0.000335	 0.00062	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39882	 43758	 0.006019	 0.072806	 0.15367	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39882	 88795	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39882	 88795	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39883	 43294	 0.012403	 0.050477	 0.0123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39883	 43397	 0.005813	 0.046707	 0.01313	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39883	 43400	 0.012391	 0.071983	 0.01695	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39883	 43460	 0.022215	 0.12773	 0.03622	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39883	 43554	 0.006684	 0.067577	 0.01988	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39883	 44027	 0.018912	 0.10421	 0.03766	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39883	 88796	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39883	 88796	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39884	 43408	 0.000143	 0.001949	 0.03955	 1646.0	 1728.3	 1810.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39884	 43539	 0.001501	 0.017455	 0.15098	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39884	 88797	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39884	 88797	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39885	 43296	 0.050467	 0.17335	 0.0416	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39885	 43400	 0.011637	 0.0524	 0.01395	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39885	 43401	 0.014106	 0.048394	 0.01159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39885	 43761	 0.042319	 0.10644	 0.02759	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39885	 43904	 0.012579	 0.033246	 0.00778	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39885	 43905	 0.024846	 0.065675	 0.01538	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39885	 88799	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39885	 88799	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39886	 43391	 0.009298	 0.036545	 0.00956	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39886	 44072	 0.036181	 0.16619	 0.04264	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39886	 88800	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39886	 88800	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39887	 40045	 0.004108	 0.04523	 0.44151	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39887	 43408	 0.001779	 0.019426	 0.19088	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39887	 88801	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39887	 88801	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39888	 43744	 0.01322	 0.078771	 0.02073	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39888	 44013	 0.018979	 0.049277	 0.01196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39888	 44015	 0.004833	 0.016577	 0.00397	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39888	 88803	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39888	 88803	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39889	 43556	 0.021644	 0.050249	 0.01531	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39889	 43568	 0.009353	 0.042911	 0.01099	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39889	 44015	 0.008819	 0.031174	 0.00702	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39889	 44016	 0.013724	 0.048513	 0.01093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39889	 88804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39889	 88804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39890	 43755	 0.000895	 0.012904	 0.11843	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39890	 51716	 0.003502	 0.03977	 0.36336	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39891	 42755	 0.00119	 0.004148	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39891	 42756	 0.002511	 0.007272	 0.00175	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39891	 43982	 0.000956	 0.003756	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39892	 43836	 0.003991	 0.013447	 0.00334	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39892	 43851	 0.000389	 0.001528	 0.0004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39892	 43852	 0.002323	 0.005971	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39893	 43660	 0.000611	 0.003069	 0.0008	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39893	 43661	 0.000971	 0.005059	 0.00133	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39893	 88805	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39893	 88805	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39894	 43376	 0.021854	 0.085923	 0.02249	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39894	 43381	 0.007658	 0.023936	 0.00693	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39894	 43418	 0.014875	 0.039936	 0.00905	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39895	 43780	 0.000454	 0.00469	 0.07371	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39895	 44824	 0.000421	 0.006498	 0.14759	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39895	 88806	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39895	 88806	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39896	 43491	 0.003035	 0.01193	 0.00312	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39896	 43492	 0.006528	 0.044813	 0.01307	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39896	 88807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39896	 88807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39897	 43392	 0.004649	 0.029448	 0.00799	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39897	 43454	 0.013491	 0.054018	 0.01361	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39897	 43936	 0.012669	 0.051559	 0.01256	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39897	 88808	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39897	 88808	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39898	 43580	 0.064075	 0.28559	 0.00485	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39898	 43582	 0.031778	 0.062918	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39898	 44468	 0.050545	 0.2629	 0.0057	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39898	 90076	 0.13975	 0.40101	 0.00617	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39898	 90173	 0.11103	 0.18706	 0.00266	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39899	 43560	 0.003911	 0.031418	 0.00883	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39899	 43561	 0.000778	 0.002056	 0.00048	 137.0	 137.0	 137.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39899	 88809	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39899	 88809	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39900	 43293	 0.01076	 0.043787	 0.01067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39900	 43719	 0.018483	 0.092898	 0.02419	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39900	 44029	 0.003011	 0.012433	 0.00294	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39901	 43683	 0.001361	 0.003596	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39901	 43689	 0.000431	 0.001567	 0.00048	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88788	 39901	 0.087666	 0.2259	 0.0561	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39901	 88810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39901	 88810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39902	 43431	 0.00199	 0.018101	 0.00457	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39902	 43432	 0.008958	 0.022518	 0.00583	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39902	 43775	 0.020551	 0.057316	 0.01203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39903	 43377	 0.01143	 0.028732	 0.00744	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39903	 43418	 0.014818	 0.040346	 0.00889	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39903	 43432	 0.021804	 0.078971	 0.01695	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39904	 44109	 0.001682	 0.007717	 0.00198	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39905	 39932	 0.001021	 0.00455	 0.00124	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39905	 44108	 0.010483	 0.038139	 0.01168	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39905	 44919	 0.031163	 0.1269	 0.03095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39905	 88811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39905	 88811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39906	 41968	 0.00988	 0.039557	 0.00997	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39906	 43480	 0.005628	 0.023822	 0.00536	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39906	 43485	 0.002495	 0.012745	 0.00321	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39906	 43490	 0.005029	 0.030186	 0.00914	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88788	 39906	 0.063908	 0.17421	 0.03844	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39906	 88812	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39906	 88812	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39907	 43481	 0.001195	 0.003159	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39907	 43490	 0.007229	 0.024357	 0.00605	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39907	 88813	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39907	 88813	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39908	 43893	 0.006196	 0.016086	 0.0039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39908	 43896	 0.005143	 0.012929	 0.00335	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39908	 43897	 0.000791	 0.003627	 0.00093	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39908	 90214	 0.00345	 0.011834	 0.00284	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39909	 43441	 0.000989	 0.004537	 0.00116	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39909	 43444	 0.003278	 0.013536	 0.0032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39909	 88814	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39909	 88814	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39909	 90081	 0.000428	 0.001715	 0.00043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39910	 43423	 0.010231	 0.038891	 0.01089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39910	 43537	 0.008132	 0.022676	 0.00476	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39911	 43614	 0.000688	 0.002361	 0.00057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39911	 43629	 0.002616	 0.006725	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39911	 90134	 0.005481	 0.014484	 0.00339	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39912	 43331	 0.002082	 0.00955	 0.00245	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39912	 43332	 0.004651	 0.016207	 0.00376	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39912	 43346	 0.003989	 0.014099	 0.00318	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39912	 43353	 0.003108	 0.012444	 0.00313	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39912	 43354	 0.005871	 0.020142	 0.00483	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39913	 43646	 0.025631	 0.066555	 0.01616	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39913	 44076	 0.005403	 0.019563	 0.0042	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39914	 39927	 6e-06	 1.9e-05	 0.0	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39914	 43354	 0.032173	 0.12238	 0.03429	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39914	 43740	 0.002902	 0.008556	 0.00199	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39915	 43401	 0.01112	 0.045252	 0.01103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39915	 43459	 0.022708	 0.18873	 0.04976	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39915	 88815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39915	 88815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39916	 43302	 0.012195	 0.030657	 0.00794	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39916	 43304	 0.000211	 0.000589	 0.00012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39916	 88816	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39916	 88816	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39917	 43387	 0.011011	 0.044086	 0.01111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39917	 43388	 0.012487	 0.028987	 0.00883	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39917	 43650	 0.027235	 0.16946	 0.04792	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39917	 43787	 0.043611	 0.14975	 0.03592	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39917	 88817	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39917	 88817	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39918	 43875	 0.019086	 0.050445	 0.01181	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39918	 44049	 0.001571	 0.00408	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39918	 88818	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39918	 88818	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39919	 41962	 0.003936	 0.028077	 0.0087	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39919	 43659	 0.0014	 0.00578	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39919	 43661	 0.000567	 0.003004	 0.00076	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39920	 43869	 0.003737	 0.056957	 1.0511	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39920	 43921	 0.000162	 0.002146	 0.03401	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39920	 43927	 0.000178	 0.002014	 0.01834	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39920	 51731	 0.001475	 0.023447	 0.23966	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39920	 88819	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39920	 88819	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39921	 43356	 0.019515	 0.049061	 0.01271	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39921	 44004	 0.000418	 0.001006	 0.00028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39921	 44013	 0.01611	 0.044927	 0.00943	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39921	 88821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39921	 88821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39922	 43407	 0.008609	 0.023113	 0.00524	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39922	 44110	 0.010892	 0.029243	 0.00663	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39922	 88822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39922	 88822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88807	 39923	 0.023819	 0.053439	 0.00085	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39923	 90100	 0.003359	 0.022792	 0.00043	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39924	 43414	 0.015366	 0.093387	 0.00172	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39924	 90139	 0.22323	 0.47876	 0.00839	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39925	 43835	 0.000466	 0.003105	 0.00585	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39925	 88823	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39925	 88823	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39926	 43496	 0.003755	 0.041313	 0.40295	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39926	 44795	 0.001424	 0.016141	 0.14703	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39926	 88824	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39926	 88824	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39927	 43744	 0.002995	 0.009313	 0.00194	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39927	 44021	 0.009704	 0.056846	 0.01549	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39928	 43997	 0.003529	 0.014362	 0.0035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39928	 44004	 0.00265	 0.007434	 0.00191	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39928	 44006	 0.000574	 0.002988	 0.00078	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39928	 88826	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39928	 88826	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39929	 43533	 0.005782	 0.015524	 0.00352	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39929	 43537	 0.000353	 0.002497	 0.00069	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39929	 88827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39929	 88827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39929	 90113	 0.025161	 0.13818	 0.03657	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39930	 43340	 0.005905	 0.013566	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39930	 43341	 0.003953	 0.009177	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39931	 43555	 0.010204	 0.031897	 0.00924	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39931	 43565	 0.014676	 0.085987	 0.02343	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39931	 44113	 0.019654	 0.051947	 0.01216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39931	 88828	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39931	 88828	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39932	 44109	 0.002815	 0.013661	 0.00312	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39933	 42027	 0.008986	 0.053535	 0.01409	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39933	 43501	 0.001779	 0.004473	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39933	 43515	 0.009709	 0.023398	 0.00661	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39933	 90102	 0.000379	 0.001489	 0.00039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39934	 43729	 0.005134	 0.018983	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39934	 43730	 0.010109	 0.021246	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39934	 90168	 0.062593	 0.14381	 0.00218	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39935	 44108	 0.00634	 0.021151	 0.00536	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39935	 44110	 0.007665	 0.020257	 0.00474	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39935	 44919	 0.020845	 0.081954	 0.02145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39935	 45328	 0.032747	 0.18201	 0.05546	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39936	 43722	 0.011565	 0.040306	 0.00935	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39936	 43728	 0.012271	 0.044437	 0.00953	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39936	 88829	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39936	 88829	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39937	 43774	 0.000242	 0.001868	 0.0038	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39937	 43940	 0.00812	 0.0542	 0.10229	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39937	 88830	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39937	 88830	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39938	 43765	 0.009215	 0.024354	 0.0057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39938	 43945	 0.006049	 0.030897	 0.00777	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88788	 39938	 0.027226	 0.070697	 0.01716	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39939	 43575	 0.19864	 0.14073	 0.00222	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39939	 43577	 0.00693	 0.006498	 0.0001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39940	 43342	 0.005556	 0.01413	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39940	 43347	 0.036799	 0.056373	 0.00079	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39941	 43430	 0.000409	 0.003284	 0.00092	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39941	 43431	 0.000804	 0.006338	 0.00185	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39942	 43930	 0.013644	 0.022984	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39942	 43931	 0.022789	 0.029003	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39942	 43932	 0.077955	 0.28831	 0.00534	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39943	 43694	 0.002326	 0.006039	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39943	 43696	 0.002531	 0.006688	 0.00157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39943	 43697	 0.002617	 0.006915	 0.00162	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39943	 43699	 0.000639	 0.005477	 0.00156	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39944	 43690	 0.001631	 0.006344	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39944	 90157	 0.002255	 0.012687	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39945	 43379	 0.00586	 0.033606	 0.01117	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39945	 43381	 0.012199	 0.03167	 0.00769	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39945	 43421	 0.018927	 0.052784	 0.01108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39945	 43587	 0.012877	 0.048951	 0.01371	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39945	 43935	 0.010993	 0.039994	 0.01225	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39946	 43562	 0.11883	 0.16871	 0.00278	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39946	 44077	 0.006227	 0.012743	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39946	 90120	 0.11353	 0.13309	 0.00231	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39947	 43557	 0.018842	 0.017	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39947	 43583	 0.46066	 0.41607	 0.00696	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39948	 43617	 0.031713	 0.06279	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39948	 43618	 0.022925	 0.02252	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39948	 43619	 0.010837	 0.007676	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39948	 90136	 0.007017	 0.004543	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	39949	 43790	 0.028689	 0.066594	 0.00127	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39950	 43541	 0.010045	 0.026078	 0.00633	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39950	 43782	 0.000616	 0.002145	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39950	 88831	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39950	 88831	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39951	 43725	 0.034886	 0.15546	 0.00264	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39951	 44032	 0.084429	 0.1728	 0.00425	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39951	 90179	 0.044221	 0.10267	 0.00153	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39952	 44075	 0.005174	 0.038977	 0.01082	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39952	 44076	 0.006181	 0.021542	 0.005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39953	 39975	 0.000984	 0.011323	 0.11098	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39953	 41336	 0.002069	 0.020496	 0.35144	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39953	 41336	 0.002069	 0.020496	 0.35144	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39953	 41344	 0.002138	 0.022097	 0.34786	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39953	 41344	 0.002138	 0.022097	 0.34786	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39953	 41952	 0.000216	 0.002366	 0.02298	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39953	 41953	 0.000189	 0.003012	 0.04892	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39953	 43153	 0.000305	 0.003019	 0.05167	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39953	 43153	 0.000305	 0.003019	 0.05167	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39953	 88832	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39953	 88832	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39954	 42664	 0.000176	 0.002939	 0.02775	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39954	 43236	 0.000797	 0.007887	 0.13503	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39954	 43236	 0.000797	 0.007887	 0.13503	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39954	 43266	 0.000566	 0.005599	 0.09585	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39954	 43266	 0.000566	 0.005599	 0.09585	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39954	 43280	 0.000421	 0.006828	 0.14057	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39954	 88834	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39954	 88834	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88835	 39954	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88835	 39954	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39955	 39981	 0.001336	 0.013223	 0.22649	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39955	 39981	 0.001336	 0.013223	 0.22649	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39955	 40019	 9e-05	 0.000999	 0.00942	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39955	 41948	 0.00057	 0.008958	 0.09338	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39955	 42331	 0.000711	 0.007342	 0.11538	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39955	 42331	 0.000711	 0.007342	 0.11538	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39955	 88836	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39955	 88836	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39956	 39970	 0.002973	 0.030068	 0.49669	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39956	 39970	 0.002973	 0.030068	 0.49669	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39956	 39982	 0.003931	 0.044662	 0.40844	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39956	 42483	 0.00124	 0.022954	 0.22081	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39956	 42505	 0.000764	 0.014136	 0.13588	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39956	 88837	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39956	 88837	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88838	 39956	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88838	 39956	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39957	 41235	 0.002123	 0.021574	 0.3514	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39957	 41235	 0.002123	 0.021574	 0.3514	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39957	 43054	 0.001095	 0.01131	 0.17779	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39957	 43054	 0.001095	 0.01131	 0.17779	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39957	 43150	 0.000234	 0.002413	 0.03791	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39957	 43150	 0.000234	 0.002413	 0.03791	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39957	 43153	 0.00027	 0.002856	 0.0427	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39957	 43153	 0.00027	 0.002856	 0.0427	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39957	 88839	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39957	 88839	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88840	 39957	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88840	 39957	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39958	 39974	 6.7e-05	 0.00094	 0.01519	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39958	 43446	 0.000232	 0.00245	 0.03664	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39958	 43446	 0.000232	 0.00245	 0.03664	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39958	 88841	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39958	 88841	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39959	 39988	 0.00014	 0.001921	 0.03293	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39959	 42790	 0.004835	 0.055023	 0.50439	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39959	 42947	 3e-05	 0.000707	 0.01361	 1940.0	 2037.0	 2134.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39959	 88842	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39959	 88842	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39960	 39978	 0.000182	 0.002487	 0.02534	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39960	 43134	 2.3e-05	 0.000242	 0.00362	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39960	 43134	 2.3e-05	 0.000242	 0.00362	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39960	 43188	 0.000213	 0.003864	 0.03862	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39960	 88845	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39960	 88845	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88846	 39960	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88846	 39960	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39961	 40274	 0.000168	 0.001748	 0.02718	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39961	 40274	 0.000168	 0.001748	 0.02718	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39961	 42910	 0.000389	 0.00484	 0.04862	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39961	 88847	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39961	 88847	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39962	 39966	 0.002579	 0.042182	 0.40942	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39962	 42809	 0.001575	 0.015483	 0.26905	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39962	 42835	 0.001166	 0.012454	 0.18297	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39962	 42835	 0.001166	 0.012454	 0.18297	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39962	 88848	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39962	 88848	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88849	 39962	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88849	 39962	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39963	 40013	 0.001486	 0.017365	 0.16527	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39963	 88850	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39963	 88850	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88851	 39963	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88851	 39963	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39964	 40172	 0.01587	 0.10622	 0.20125	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39964	 41943	 0.010943	 0.10448	 0.18652	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39964	 42962	 0.002498	 0.029762	 0.06444	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39964	 88852	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39964	 88852	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88853	 39964	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88853	 39964	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39965	 42164	 0.002325	 0.026369	 0.24043	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39965	 42947	 0.001092	 0.01242	 0.11219	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39965	 88854	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39965	 88854	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39966	 42505	 0.00238	 0.032333	 0.49457	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39966	 88855	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39966	 88855	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 0	 -30.0	 30.0;
	39967	 41584	 9.4e-05	 0.001538	 0.0151	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39967	 41614	 0.000144	 0.001595	 0.01519	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39967	 88858	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39967	 88858	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39968	 43074	 0.000389	 0.004517	 0.03904	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39968	 43134	 2.3e-05	 0.000409	 0.00437	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39968	 43136	 7.2e-05	 0.00099	 0.01675	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39968	 88860	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39968	 88860	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39969	 42250	 0.000179	 0.00243	 0.03702	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39969	 45884	 0.000435	 0.007894	 0.07892	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39969	 88861	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39969	 88861	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88862	 39969	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88862	 39969	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39970	 42366	 0.00029	 0.00367	 0.06408	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39970	 42370	 0.000575	 0.006308	 0.06128	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39970	 42505	 0.002224	 0.037274	 0.72999	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39970	 43150	 0.001644	 0.016702	 0.27183	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39970	 43150	 0.001644	 0.016702	 0.27183	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39970	 88863	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39970	 88863	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39971	 41266	 7.6e-05	 0.000888	 0.00768	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39971	 41619	 0.00012	 0.001625	 0.02862	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39971	 88864	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39971	 88864	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39972	 42745	 0.004582	 0.031262	 0.05631	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39972	 88867	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39972	 88867	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88868	 39972	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88868	 39972	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39973	 41651	 0.00067	 0.007591	 0.06912	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39973	 88869	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39973	 88869	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39974	 42790	 0.001174	 0.013079	 0.12338	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39974	 43026	 0.000217	 0.005268	 0.09086	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39974	 88870	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39974	 88870	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39975	 42370	 0.000965	 0.010538	 0.10348	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39975	 88871	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39975	 88871	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88872	 39975	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88872	 39975	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39976	 42172	 0.000165	 0.001685	 0.00535	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39976	 45886	 0.000312	 0.00454	 0.01121	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39976	 88873	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39976	 88873	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88874	 39976	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88874	 39976	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39977	 40267	 0.001626	 0.023004	 0.21963	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39977	 42483	 0.000463	 0.006	 0.13423	 1646.0	 1728.3	 1810.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39977	 42956	 0.001318	 0.024399	 0.23475	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39977	 88875	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39977	 88875	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39978	 41333	 0.001359	 0.014381	 0.21521	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39978	 41333	 0.001359	 0.014381	 0.21521	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39978	 43136	 0.00019	 0.001962	 0.03084	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39978	 43136	 0.00019	 0.001962	 0.03084	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39978	 43150	 0.000181	 0.001918	 0.02869	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39978	 43150	 0.000181	 0.001918	 0.02869	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39978	 88877	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39978	 88877	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39979	 41400	 0.000346	 0.00342	 0.05853	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39979	 41400	 0.000346	 0.00342	 0.05853	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39979	 41859	 0.000758	 0.008748	 0.0767	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39979	 43054	 0.000136	 0.001536	 0.01399	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39979	 43081	 5.8e-05	 0.000679	 0.01186	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39979	 88878	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39979	 88878	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39980	 40015	 1.8e-05	 0.00032	 0.00611	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39980	 40027	 0.001438	 0.014857	 0.23364	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39980	 40027	 0.001438	 0.014857	 0.23364	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39980	 88880	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39980	 88880	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39981	 40999	 0.00199	 0.020674	 0.32194	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39981	 40999	 0.00199	 0.020674	 0.32194	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39981	 42104	 0.000945	 0.012372	 0.11201	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39981	 43142	 6.7e-05	 0.00089	 0.01425	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39982	 42018	 0.002346	 0.041711	 0.43895	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39982	 88881	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39982	 88881	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39983	 39984	 7e-06	 7.2e-05	 2e-05	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39983	 43228	 0.000551	 0.004811	 0.00191	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39983	 43239	 0.000344	 0.001456	 0.00033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39984	 43210	 0.002041	 0.023746	 0.00698	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39984	 43240	 0.000913	 0.004587	 0.00119	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39985	 41582	 9.3e-05	 0.000857	 0.0021	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	39985	 88882	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39985	 88882	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88883	 39985	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88883	 39985	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39986	 40215	 0.016316	 0.059089	 0.01268	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39986	 40216	 0.017173	 0.068769	 0.01733	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39986	 42924	 0.015402	 0.03872	 0.01003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39986	 88884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39986	 88884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39987	 42382	 0.005746	 0.062291	 0.01947	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39987	 42868	 0.001382	 0.005432	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39987	 88885	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39987	 88885	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39988	 42710	 0.000133	 0.001312	 0.02245	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39988	 42710	 0.000133	 0.001312	 0.02245	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39988	 88886	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39988	 88886	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88887	 39988	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88887	 39988	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39989	 41912	 0.001361	 0.00562	 0.00133	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39989	 41987	 0.010467	 0.10879	 0.03367	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39989	 42375	 0.017724	 0.060809	 0.01457	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39989	 42482	 0.01328	 0.052199	 0.01366	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39989	 88888	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39989	 88888	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39989	 89057	 0.040831	 0.10501	 0.02602	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39990	 41906	 0.016266	 0.045362	 0.00952	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39990	 41907	 0.006398	 0.046767	 0.0138	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39990	 42595	 0.005152	 0.039913	 0.01398	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39990	 42600	 0.005005	 0.040904	 0.0111	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39990	 88889	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39990	 88889	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39991	 41105	 3.3e-05	 0.000455	 0.0078	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39991	 88890	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39991	 88890	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39992	 40287	 0.001124	 0.015752	 0.0302	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39992	 40288	 0.000721	 0.005052	 0.0086	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39992	 88891	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39992	 88891	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39993	 40267	 0.0008	 0.008255	 0.12974	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	39993	 88892	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39993	 88892	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88893	 39993	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88893	 39993	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39994	 42550	 9.1e-05	 0.001025	 0.00933	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39994	 42809	 0.001202	 0.01362	 0.12405	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39994	 88894	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39994	 88894	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88895	 39994	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88895	 39994	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39995	 42345	 0.005149	 0.020951	 0.0051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39995	 42368	 0.014179	 0.035645	 0.00924	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88872	 39995	 0.004325	 0.019843	 0.00508	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39995	 88896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39995	 88896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39996	 42358	 1.8e-05	 0.000406	 0.00767	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	39996	 42664	 0.000646	 0.008979	 0.08878	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39996	 43030	 0.000612	 0.011409	 0.10805	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39996	 88897	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39996	 88897	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39997	 42928	 0.002475	 0.00654	 0.00153	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	39997	 45811	 0.008062	 0.047224	 0.01287	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	39997	 88899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39997	 88899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39998	 42376	 0.015536	 0.053302	 0.01277	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	39998	 42964	 0.001678	 0.009241	 0.00334	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	39998	 88900	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39998	 88900	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39999	 42888	 0.000116	 0.001273	 0.01237	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39999	 42910	 0.00034	 0.003788	 0.03572	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	39999	 88901	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39999	 88901	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40000	 41501	 0.001585	 0.017177	 0.00537	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40000	 43174	 0.002353	 0.009246	 0.00242	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40000	 43176	 0.002549	 0.009917	 0.00265	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40000	 43179	 0.000361	 0.002898	 0.00081	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40000	 43180	 0.006353	 0.025434	 0.00641	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40000	 88903	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40000	 88903	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40001	 43106	 0.000265	 0.003585	 0.06316	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40001	 43154	 0.000173	 0.00419	 0.07226	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40001	 43156	 0.000201	 0.002841	 0.04589	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40001	 88904	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40001	 88904	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40002	 40209	 0.013773	 0.082072	 0.0216	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40002	 42365	 0.003783	 0.017903	 0.0043	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40003	 42535	 0.001006	 0.00345	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40003	 42541	 0.002632	 0.010241	 0.00274	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40004	 40210	 0.002876	 0.020519	 0.00636	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40004	 42329	 0.005096	 0.057373	 0.01659	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40004	 42735	 0.005183	 0.025155	 0.00575	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40005	 42982	 0.005604	 0.02571	 0.00659	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40005	 42987	 0.00433	 0.025364	 0.00691	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40005	 42993	 0.009396	 0.025582	 0.00564	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40005	 88905	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40005	 88905	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40006	 42771	 0.000996	 0.003607	 0.00077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40006	 89835	 0.00092	 0.003101	 0.00077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40007	 40016	 0.001626	 0.006182	 0.00173	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40008	 41895	 0.009395	 0.037614	 0.00948	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40008	 41901	 0.000149	 0.001097	 0.00032	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40008	 41902	 0.00449	 0.030122	 0.00727	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40009	 41732	 0.000249	 0.002462	 0.04213	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40009	 41865	 5.9e-05	 0.000944	 0.01549	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40009	 42104	 0.000305	 0.00564	 0.05419	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40009	 88906	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40009	 88906	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40010	 42340	 0.004508	 0.011915	 0.00279	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40010	 42342	 0.000263	 0.001087	 0.00026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40011	 42487	 0.000451	 0.001806	 0.00045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40011	 42494	 0.000787	 0.003982	 0.00111	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40011	 88908	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40011	 88908	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40012	 42849	 0.000402	 0.004171	 0.00801	 511.0	 511.0	 511.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40012	 42849	 0.00042	 0.0043	 0.0088	 511.0	 511.0	 511.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40012	 88909	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 -1.0	 1	 -30.0	 30.0;
	40012	 88909	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 -1.0	 1	 -30.0	 30.0;
	40012	 88909	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 -1.0	 1	 -30.0	 30.0;
	40013	 41668	 0.001598	 0.015714	 0.27308	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40013	 41668	 0.001598	 0.015714	 0.27308	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40013	 88910	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40013	 88910	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40014	 41479	 0.004459	 0.038246	 0.01089	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40014	 41509	 0.004358	 0.017129	 0.00448	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40014	 42126	 0.020918	 0.088559	 0.01994	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40014	 43168	 0.00179	 0.007285	 0.00177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40014	 43171	 0.00076	 0.00841	 0.00252	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40014	 88911	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40014	 88911	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40014	 89980	 0.005989	 0.019981	 0.00507	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40015	 48875	 0.001101	 0.019393	 0.3225	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40015	 88912	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40015	 88912	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40016	 40215	 0.002177	 0.008858	 0.00216	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40016	 42924	 0.013901	 0.056573	 0.01379	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40017	 40782	 0.002506	 0.009749	 0.0026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40017	 40791	 0.000545	 0.00378	 0.00108	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40017	 40808	 0.000193	 0.001759	 0.00044	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40017	 40813	 0.00148	 0.004937	 0.00125	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40017	 41452	 0.00741	 0.024968	 0.00621	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40017	 41546	 0.001716	 0.012861	 0.00314	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40017	 88915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40017	 88915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40018	 41654	 0.009292	 0.045098	 0.01031	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40018	 41655	 0.019484	 0.074081	 0.02074	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40018	 42357	 0.008151	 0.03171	 0.00847	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40018	 42365	 0.002219	 0.015697	 0.00431	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40019	 88916	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40019	 88916	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40020	 42674	 0.001119	 0.005827	 0.00153	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40020	 42715	 0.001304	 0.003446	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40020	 88917	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40020	 88917	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40021	 42974	 0.00138	 0.007571	 0.002	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40021	 42982	 0.000945	 0.003295	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40021	 42991	 0.001399	 0.007437	 0.00173	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40021	 42997	 0.004291	 0.018675	 0.00532	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40021	 88918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40021	 88918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40022	 42716	 0.000569	 0.005604	 0.01194	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40022	 42717	 9.8e-05	 0.001538	 0.0051	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88855	 40022	 0.013043	 0.1025	 0.17702	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40022	 88919	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40022	 88919	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40023	 41091	 0.000942	 0.010768	 0.00328	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40023	 41098	 0.001347	 0.009384	 0.00353	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40023	 42043	 0.001193	 0.00389	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40023	 42044	 0.001969	 0.006155	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40023	 42441	 0.010099	 0.029774	 0.00693	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40023	 88920	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40023	 88920	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40024	 88921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40024	 88921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40024	 89976	 0.000221	 0.000757	 0.00018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40025	 41945	 0.000132	 0.001099	 0.00343	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40025	 41947	 0.000436	 0.00708	 0.01398	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40025	 88922	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40025	 88922	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40025	 89941	 0.001261	 0.017347	 0.03457	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40026	 40210	 0.004043	 0.013869	 0.00332	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40026	 40213	 0.005204	 0.018136	 0.00421	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40026	 88923	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40026	 88923	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40027	 43201	 0.000235	 0.004211	 0.08198	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40027	 88924	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40027	 88924	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88925	 40027	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88925	 40027	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40028	 88926	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40028	 88926	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88927	 40028	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88927	 40028	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40028	 89730	 0.00031	 0.002067	 0.00389	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40029	 40237	 0.014882	 0.051869	 0.01203	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40029	 40260	 0.000778	 0.005085	 0.00129	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40029	 40262	 0.002476	 0.006429	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40029	 41912	 0.013533	 0.058913	 0.01679	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40030	 42338	 0.017645	 0.029428	 0.00043	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40030	 42341	 0.006599	 0.010533	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40030	 89675	 0.024906	 0.044939	 0.00065	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40031	 89572	 0.005717	 0.020424	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40031	 89579	 0.007489	 0.017206	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40032	 41009	 0.004407	 0.01023	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40033	 42864	 0.001135	 0.002999	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40033	 88928	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40033	 88928	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40034	 40234	 0.000701	 0.002395	 5e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40034	 40235	 0.011559	 0.009148	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40034	 40247	 0.013718	 0.022005	 0.00041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40034	 40249	 0.005861	 0.025824	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40035	 41973	 0.001865	 0.009937	 0.00017	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40035	 89535	 0.03126	 0.08966	 0.00138	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40036	 42544	 0.001973	 0.007498	 0.0021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40036	 42556	 0.003192	 0.015769	 0.00461	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40036	 42585	 0.002571	 0.008818	 0.00211	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40036	 88929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40036	 88929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40037	 40669	 0.000298	 0.00117	 0.00031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40037	 41541	 0.000854	 0.003358	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40037	 88930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40037	 88930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40038	 40217	 0.007509	 0.043987	 0.01198	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40038	 41941	 0.011036	 0.037186	 0.00924	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40038	 42728	 0.032815	 0.086754	 0.02031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40038	 42730	 0.007161	 0.028672	 0.00722	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40039	 41698	 0.000738	 0.004049	 0.00107	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40039	 41723	 0.000562	 0.002841	 0.00079	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40039	 88931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40039	 88931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40040	 41940	 0.00681	 0.027265	 0.00687	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40040	 42643	 0.017693	 0.073065	 0.01729	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40040	 42726	 0.035949	 0.092449	 0.0229	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40040	 88932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40040	 88932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40041	 44191	 0.001773	 0.017901	 0.29499	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40041	 44191	 0.001773	 0.017901	 0.29499	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40041	 44233	 0.001031	 0.01168	 0.10637	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40041	 44904	 0.002608	 0.031035	 0.28555	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40041	 88933	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40041	 88933	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40042	 45364	 0.013774	 0.080698	 0.02199	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40042	 45380	 0.001914	 0.011488	 0.00348	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40042	 45381	 0.001063	 0.011906	 0.00378	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40042	 45383	 0.004633	 0.015893	 0.00381	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40042	 46538	 0.023139	 0.092675	 0.02336	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40042	 46541	 0.012023	 0.060417	 0.01573	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40042	 88936	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40042	 88936	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40043	 40112	 0.00251	 0.02758	 0.26838	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40043	 44440	 0.000473	 0.00468	 0.0801	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40043	 45413	 0.000997	 0.010554	 0.15788	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40043	 88937	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40043	 88937	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40044	 45173	 0.015615	 0.056547	 0.01213	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40044	 45174	 0.00373	 0.021206	 0.00614	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40044	 45181	 0.009163	 0.037836	 0.00895	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40044	 45182	 0.004998	 0.013208	 0.00309	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40044	 45184	 0.00256	 0.006647	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40045	 40052	 0.00202	 0.028575	 0.46304	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40045	 40063	 0.00166	 0.022611	 0.45994	 1646.0	 1728.3	 1810.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40045	 44249	 0.000573	 0.006284	 0.06104	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40045	 44825	 0.00297	 0.042109	 0.40325	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40045	 45266	 0.002447	 0.02617	 0.38522	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40045	 45266	 0.002447	 0.02617	 0.38522	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40045	 88939	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40045	 88939	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40046	 40064	 0.002475	 0.016068	 0.03201	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40046	 44239	 0.011437	 0.1148	 0.38732	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40046	 88942	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40046	 88942	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88943	 40046	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 0	 -30.0	 30.0;
	88943	 40046	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 0	 -30.0	 30.0;
	40047	 40053	 0.003133	 0.036226	 0.31847	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40047	 44429	 0.000755	 0.010338	 0.10537	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40047	 44486	 0.000125	 0.001393	 0.01314	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40047	 88944	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40047	 88944	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40048	 44931	 0.001396	 0.01546	 0.00503	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40048	 44933	 0.017952	 0.047449	 0.01111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40048	 44934	 0.007997	 0.031431	 0.00822	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40048	 88945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40048	 88945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40049	 44731	 0.000408	 0.004477	 0.04349	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40049	 45046	 0.000279	 0.003215	 0.02818	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40049	 45413	 0.000595	 0.005999	 0.09875	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40049	 88946	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40049	 88946	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40050	 44400	 0.001495	 0.003882	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40050	 44601	 0.003421	 0.012092	 0.00272	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40050	 44604	 0.00075	 0.003175	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40050	 44607	 0.001786	 0.008041	 0.00214	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40050	 88948	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40050	 88948	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40051	 44435	 0.000225	 0.002611	 0.02257	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40051	 88949	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40051	 88949	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40052	 44825	 0.000408	 0.004978	 0.04339	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40052	 88952	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40052	 88952	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40053	 88953	 0.000641	 0.033327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40053	 88953	 0.000641	 0.033327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88954	 40053	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88954	 40053	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40054	 44850	 0.021556	 0.18839	 0.05186	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40054	 44862	 0.008843	 0.023742	 0.00538	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40054	 88955	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40054	 88955	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40055	 44888	 0.008298	 0.05567	 0.01344	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40055	 88956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40055	 88956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40055	 88963	 0.006843	 0.042524	 0.012	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40056	 40080	 0.002827	 0.008465	 0.00191	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40056	 44868	 0.006837	 0.069673	 0.01796	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40056	 45003	 0.011452	 0.029439	 0.00729	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40056	 88957	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40056	 88957	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40057	 44257	 0.021291	 0.13641	 0.04596	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40057	 88963	 0.000767	 0.002151	 0.00055	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88953	 40058	 1e-05	 0.000121	 0.00026	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40058	 88958	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40058	 88958	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88959	 40058	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88959	 40058	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40058	 90502	 0.002045	 0.026418	 0.05988	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40059	 44918	 0.01292	 0.035177	 0.00775	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40059	 44970	 0.014474	 0.057958	 0.0146	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88954	 40059	 0.006968	 0.023904	 0.00573	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40059	 88960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40059	 88960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40060	 44940	 0.000524	 0.001827	 0.00042	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40060	 44942	 0.001735	 0.004838	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40060	 44945	 0.001001	 0.003338	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40060	 44963	 0.006105	 0.022108	 0.00474	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40060	 88961	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40060	 88961	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40061	 44332	 0.008423	 0.038643	 0.0099	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40061	 44822	 0.008036	 0.020862	 0.00506	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88952	 40061	 0.007281	 0.024976	 0.00598	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40062	 43751	 0.029082	 0.078095	 0.0177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40062	 44465	 0.007788	 0.080136	 0.02274	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40062	 44919	 0.008882	 0.034911	 0.00913	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40062	 88962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40062	 88962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40063	 44825	 0.000867	 0.010005	 0.08773	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40063	 88963	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40063	 88963	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40064	 88964	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40064	 88964	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40065	 44327	 0.049517	 0.12739	 0.03157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40065	 44851	 0.031825	 0.10923	 0.02618	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40065	 45254	 0.081373	 0.2155	 0.05057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40065	 45463	 0.044673	 0.17583	 0.04609	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40065	 88977	 0.015782	 0.092473	 0.0252	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40066	 44818	 0.000283	 0.004442	 0.04629	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40066	 44993	 0.007756	 0.088964	 0.82496	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40066	 88965	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40066	 88965	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88966	 40066	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 0	 -30.0	 30.0;
	88966	 40066	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 0	 -30.0	 30.0;
	40067	 44264	 0.009468	 0.036836	 0.00984	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40067	 45222	 0.004802	 0.013074	 0.00288	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40067	 88967	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40067	 88967	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40068	 88968	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40068	 88968	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40068	 90293	 0.001189	 0.004202	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40069	 44930	 0.00187	 0.006413	 0.00154	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88940	 40069	 0.000116	 0.000939	 0.0003	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40069	 88969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40069	 88969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40069	 90297	 0.000916	 0.004274	 0.00106	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40070	 44872	 0.000941	 0.004981	 0.00126	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40070	 44873	 0.001741	 0.005214	 0.00117	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40070	 44874	 0.017096	 0.049039	 0.01207	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40070	 45445	 0.012649	 0.056959	 0.01516	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40071	 45020	 0.025132	 0.067483	 0.0153	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40071	 45338	 0.005911	 0.015622	 0.00366	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40071	 88970	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40071	 88970	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40072	 44269	 0.005639	 0.025872	 0.00663	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40072	 44705	 0.008708	 0.027218	 0.00788	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40072	 44706	 0.008079	 0.023171	 0.0057	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40072	 88971	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40072	 88971	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40073	 44853	 0.002477	 0.028203	 0.25513	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40073	 45248	 0.00022	 0.002446	 0.02307	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40073	 88972	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40073	 88972	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40074	 44620	 0.00278	 0.011128	 0.0028	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40074	 45261	 0.001868	 0.010939	 0.00298	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40074	 88974	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40074	 88974	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40074	 90591	 0.000497	 0.003148	 0.00085	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40075	 44982	 0.002486	 0.010117	 0.00246	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40075	 44983	 0.001228	 0.004279	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40075	 88975	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40075	 88975	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40076	 44862	 0.026989	 0.070081	 0.01701	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40076	 45004	 0.020467	 0.054099	 0.01266	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40076	 45007	 0.011831	 0.040588	 0.00972	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40077	 44215	 0.006319	 0.030668	 0.00701	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40077	 45017	 0.028801	 0.11538	 0.02909	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40077	 88976	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40077	 88976	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40078	 44853	 0.001577	 0.017868	 0.16278	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40078	 88977	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40078	 88977	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40079	 44330	 0.004863	 0.016223	 0.00411	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40079	 44331	 0.013732	 0.036292	 0.0085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40081	 44282	 0.002625	 0.009147	 0.00212	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40081	 44283	 0.002571	 0.006676	 0.00162	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40081	 45269	 0.002635	 0.009039	 0.00217	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40081	 45271	 0.003717	 0.009979	 0.00226	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40082	 44145	 0.004038	 0.025579	 0.00694	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40082	 45288	 0.001421	 0.007368	 0.0018	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40082	 45289	 0.001127	 0.008636	 0.00231	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40082	 88979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40082	 88979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40083	 44876	 0.002458	 0.010554	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40084	 45067	 0.001587	 0.007748	 0.00016	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40084	 90536	 0.005034	 0.011688	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40085	 45233	 0.003108	 0.008067	 0.00196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40085	 45235	 0.000281	 0.001145	 0.00028	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40085	 88980	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40085	 88980	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40086	 45259	 0.000451	 0.001861	 0.00044	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40087	 44956	 8.5e-05	 0.00094	 0.00895	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40087	 88981	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40087	 88981	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40088	 44445	 0.0042	 0.014639	 0.00339	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40088	 44446	 0.014552	 0.037408	 0.00926	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40088	 44447	 0.005733	 0.019665	 0.00471	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40088	 88982	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40088	 88982	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40089	 44910	 0.008549	 0.016371	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40089	 90491	 0.041012	 0.13682	 0.00217	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40090	 44844	 0.015256	 0.039217	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40091	 44857	 0.002134	 0.018619	 0.00511	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40091	 45279	 0.003591	 0.03806	 0.0113	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40092	 44261	 0.002653	 0.007397	 0.00155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40092	 44262	 0.003322	 0.009263	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40092	 88983	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40092	 88983	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40093	 44910	 0.005166	 0.015847	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40093	 44911	 0.020033	 0.026329	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40093	 44912	 0.018023	 0.012106	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40093	 44913	 0.007523	 0.013438	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40094	 44254	 0.002824	 0.007874	 0.00165	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40094	 44256	 0.001188	 0.002757	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40094	 88984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40094	 88984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40095	 90461	 0.00505	 0.022925	 0.0005	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40095	 90462	 0.046679	 0.20802	 0.00353	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40096	 45242	 0.000694	 0.001835	 0.00043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40096	 88985	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40096	 88985	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88941	 40097	 0.001301	 0.002988	 5e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40098	 44804	 0.016408	 0.065662	 0.00139	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40098	 44806	 0.009996	 0.013137	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40099	 45001	 0.009913	 0.055697	 0.00103	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40099	 45002	 0.026505	 0.060617	 0.00148	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40100	 45241	 0.030096	 0.055124	 0.00095	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40100	 45253	 0.083558	 0.21482	 0.00333	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40101	 90492	 0.008634	 0.024762	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40102	 45269	 0.000124	 0.000345	 7e-05	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40102	 45270	 0.001474	 0.003422	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40102	 88986	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40102	 88986	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40103	 90375	 0.014632	 0.03397	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40103	 90376	 0.093154	 0.084048	 0.00141	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40104	 44862	 0.005558	 0.014288	 0.00354	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40104	 45003	 0.010873	 0.032561	 0.00734	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40105	 44693	 0.012474	 0.065708	 0.00118	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40105	 45442	 0.013943	 0.032033	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40105	 90644	 0.022365	 0.086043	 0.00147	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40106	 45326	 0.058315	 0.044182	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40106	 90609	 0.022488	 0.024734	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40106	 90610	 0.01374	 0.016106	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40107	 45416	 0.088109	 0.24075	 0.00409	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40107	 90324	 0.083396	 0.066	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40108	 45334	 0.014261	 0.048052	 0.01194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40108	 51993	 0.039192	 0.19359	 0.05247	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40108	 88987	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40108	 88987	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40109	 46267	 0.000195	 0.00318	 0.04962	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40109	 46464	 0.00067	 0.007729	 0.06777	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40109	 88988	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40109	 88988	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88989	 40109	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88989	 40109	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40110	 40126	 0.001853	 0.020952	 0.19162	 736.0	 736.0	 736.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40110	 45479	 0.001782	 0.02018	 0.184	 736.0	 736.0	 736.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40110	 45489	 0.001695	 0.019207	 0.175	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40110	 88990	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40110	 88990	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40110	 88990	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40111	 45884	 4.1e-05	 0.000671	 0.01382	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40111	 46464	 0.000654	 0.007176	 0.06971	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40111	 88991	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40111	 88991	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40112	 44956	 0.002058	 0.022603	 0.21982	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40112	 45536	 0.000307	 0.004428	 0.04062	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40112	 46307	 0.002149	 0.039079	 0.39211	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40112	 88994	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40112	 88994	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40113	 44795	 0.000513	 0.008539	 0.0902	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40113	 45900	 0.000637	 0.008247	 0.18453	 1646.0	 1728.3	 1810.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40113	 88996	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40113	 88996	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40114	 46300	 0.00066	 0.009376	 0.08869	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40114	 46445	 0.000597	 0.006553	 0.06365	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40114	 46704	 0.000994	 0.011612	 0.11047	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40114	 88997	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40114	 88997	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40115	 43276	 0.000472	 0.005349	 0.0487	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40115	 45653	 0.001596	 0.02302	 0.21144	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40115	 88998	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40115	 88998	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88999	 40115	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88999	 40115	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40116	 45526	 0.006601	 0.026431	 0.00666	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40116	 45544	 0.007271	 0.03475	 0.01217	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40116	 46348	 0.012767	 0.051121	 0.01288	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40116	 46364	 0.001231	 0.013047	 0.00387	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40116	 46377	 0.000638	 0.006094	 0.00201	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40116	 46422	 0.091549	 0.24259	 0.05696	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40116	 46428	 0.11405	 0.30267	 0.07119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40117	 45503	 0.001477	 0.006251	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40117	 45506	 0.003986	 0.011753	 0.00273	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40117	 45525	 0.001583	 0.007952	 0.00207	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40117	 89000	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40117	 89000	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40118	 45678	 0.001228	 0.012534	 0.0398	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88841	 40118	 0.01192	 0.11808	 0.40984	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40118	 89001	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40118	 89001	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40119	 46371	 0.024933	 0.064741	 0.01572	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40119	 46810	 0.002672	 0.009167	 0.0022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40119	 46810	 0.002672	 0.009167	 0.0022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40119	 46817	 0.00248	 0.008355	 0.00208	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40119	 46817	 0.00248	 0.008355	 0.00208	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40119	 46821	 0.001485	 0.006042	 0.00147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40119	 89002	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40119	 89002	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40119	 91041	 0.002041	 0.008022	 0.0021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40119	 91041	 0.002041	 0.008022	 0.0021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40119	 91043	 0.003183	 0.012951	 0.00316	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40119	 91043	 0.003183	 0.012951	 0.00316	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40120	 44489	 0.002267	 0.024897	 0.24219	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40120	 45536	 0.000345	 0.004281	 0.03966	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40120	 89003	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40120	 89003	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40121	 45850	 0.001586	 0.017102	 0.0049	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40121	 46630	 0.001915	 0.007277	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40121	 46631	 0.002634	 0.006622	 0.00172	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40121	 89005	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40121	 89005	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40122	 45774	 0.001836	 0.020155	 0.19596	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40122	 46592	 0.000483	 0.00527	 0.05174	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40122	 89006	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40122	 89006	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40123	 46012	 0.000533	 0.00875	 0.13408	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40123	 46382	 2.9e-05	 0.000319	 0.0031	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40123	 46383	 0.000196	 0.002217	 0.02018	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40123	 46386	 0.000153	 0.002363	 0.04121	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40123	 89008	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40123	 89008	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40124	 45786	 0.010977	 0.029011	 0.00679	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40124	 46588	 0.021975	 0.076602	 0.01777	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40124	 46798	 0.008023	 0.05865	 0.01731	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40124	 89010	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40124	 89010	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40125	 46142	 0.001025	 0.002858	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40125	 46296	 0.001097	 0.003284	 0.00074	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40125	 46297	 0.000592	 0.002328	 0.00061	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40125	 46298	 0.001109	 0.002574	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40125	 46305	 0.001239	 0.003326	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40125	 89011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40125	 89011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40126	 45489	 0.000158	 0.001745	 0.01661	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40126	 45524	 0.0001	 0.001138	 0.01036	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40126	 89012	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40126	 89012	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40127	 40151	 0.00125	 0.006385	 0.00161	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40127	 45797	 0.007258	 0.037809	 0.00992	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40127	 89014	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40127	 89014	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40128	 45833	 0.000491	 0.003923	 0.00097	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40128	 45851	 0.002091	 0.015043	 0.00399	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40128	 45852	 0.003656	 0.017741	 0.00406	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40128	 46760	 0.003862	 0.038319	 0.01042	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40128	 89015	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40128	 89015	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40129	 45700	 0.015314	 0.063237	 0.01496	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40129	 45770	 0.003087	 0.017737	 0.00502	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40129	 45784	 0.011419	 0.041546	 0.01272	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40129	 45785	 0.006448	 0.025342	 0.00663	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40129	 90741	 0.000648	 0.005454	 0.00162	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40130	 45888	 0.003897	 0.024213	 0.00683	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40130	 46468	 0.001651	 0.008795	 0.00247	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40130	 46473	 0.005013	 0.026709	 0.0075	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40130	 89016	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40130	 89016	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40130	 90943	 0.001826	 0.02251	 0.00727	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40131	 46676	 0.005528	 0.01505	 0.00332	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40131	 46680	 0.000546	 0.005242	 0.00152	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40131	 46681	 0.002115	 0.00895	 0.00201	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40131	 46742	 0.008979	 0.022571	 0.00585	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40131	 89017	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40131	 89017	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40132	 45998	 0.007785	 0.029593	 0.00828	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40132	 46002	 0.004861	 0.014631	 0.00458	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40132	 89018	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40132	 89018	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45884	 40133	 0.003332	 0.040185	 0.67921	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40133	 46591	 0.000297	 0.003295	 0.03137	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40133	 46592	 0.00024	 0.002714	 0.02471	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40133	 46597	 0.000672	 0.007485	 0.07059	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40133	 89019	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40133	 89019	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40134	 45785	 0.00614	 0.01594	 0.00387	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40134	 45788	 0.007893	 0.031601	 0.00796	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40135	 46356	 0.001214	 0.008422	 0.0024	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40135	 46358	 0.000977	 0.00335	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40135	 46362	 0.001383	 0.005854	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40135	 89021	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40135	 89021	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40136	 45952	 0.001061	 0.002754	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40136	 45952	 0.001061	 0.002754	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40136	 89022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40136	 89022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40136	 90790	 0.001989	 0.005415	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40136	 90790	 0.001989	 0.005415	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 0	 -30.0	 30.0;
	40137	 46835	 0.001772	 0.005511	 0.00115	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40137	 46836	 0.0032	 0.010674	 0.00271	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40138	 45544	 0.015574	 0.040435	 0.00981	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40138	 46362	 0.000463	 0.001801	 0.00048	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40138	 46363	 0.000486	 0.002301	 0.00055	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40138	 89023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40138	 89023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40139	 45510	 0.00288	 0.051541	 0.53825	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40139	 45732	 0.007755	 0.11416	 1.0805	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40139	 45974	 0.000129	 0.001536	 0.0141	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40139	 46307	 0.004662	 0.05404	 0.47677	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40139	 89024	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40139	 89024	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40140	 40171	 0.000146	 0.000387	 9e-05	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40141	 45711	 0.00372	 0.010374	 0.00218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40141	 46665	 0.006353	 0.02689	 0.00605	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40142	 45555	 0.003064	 0.010511	 0.00252	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40142	 45558	 0.006164	 0.016003	 0.00388	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40142	 89025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40142	 89025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40143	 45479	 9e-06	 0.000151	 0.00153	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40143	 45489	 9.8e-05	 0.00104	 0.00965	 736.0	 736.0	 736.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40144	 45897	 0.060066	 0.15611	 0.03794	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40144	 45991	 0.067708	 0.1792	 0.04202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40144	 46002	 0.004795	 0.017363	 0.00373	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40144	 89026	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40144	 89026	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40145	 45683	 0.011155	 0.029481	 0.0069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40145	 46519	 0.003163	 0.008358	 0.00196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40146	 45559	 0.002299	 0.006077	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40146	 45560	 0.003627	 0.011013	 0.00241	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40146	 45563	 0.014309	 0.049872	 0.01156	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40146	 89027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40146	 89027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40147	 46512	 0.000321	 0.002164	 0.00398	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88998	 40147	 9.6e-05	 0.000621	 0.00124	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40147	 89028	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40147	 89028	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89029	 40147	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89029	 40147	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40147	 90917	 0.017961	 0.12242	 0.22439	 366.0	 384.3	 402.6	 0.0	 0.0	 0	 -30.0	 30.0;
	40148	 45556	 0.00909	 0.02965	 0.00787	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40148	 45558	 0.004439	 0.011525	 0.0028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40148	 45741	 0.017917	 0.046518	 0.01129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40148	 45764	 0.009889	 0.026549	 0.00602	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40149	 40152	 0.007022	 0.018557	 0.00434	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40149	 45563	 0.010261	 0.02664	 0.00647	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40149	 89030	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40149	 89030	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40150	 46163	 0.001842	 0.004868	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40150	 46305	 0.001371	 0.003624	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40150	 89031	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40150	 89031	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40151	 43521	 0.008097	 0.03691	 0.01171	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40152	 46526	 0.016072	 0.056017	 0.01299	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40153	 90914	 0.002394	 0.007986	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40154	 46835	 0.004563	 0.013663	 0.00308	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40154	 89032	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40154	 89032	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40155	 45581	 0.033525	 0.11184	 0.00177	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40155	 46548	 0.12732	 0.10076	 0.00127	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40155	 46549	 0.14165	 0.14466	 0.00225	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40155	 46550	 0.02468	 0.063443	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40156	 44791	 0.024167	 0.037017	 0.00064	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40156	 45901	 0.011917	 0.030633	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40156	 45903	 0.016638	 0.025961	 0.00043	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88825	 40156	 0.30132	 0.59725	 0.00878	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40157	 45820	 0.092533	 0.18137	 0.00272	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40157	 45821	 0.022874	 0.072632	 0.00127	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40158	 45698	 0.004244	 0.017964	 0.00404	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40158	 45699	 0.010885	 0.037341	 0.00895	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40158	 45785	 0.010019	 0.025185	 0.00652	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40159	 45607	 0.000787	 0.002864	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40159	 45696	 0.008083	 0.020318	 0.00526	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40159	 89033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40159	 89033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40160	 45458	 0.004063	 0.023096	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40160	 45459	 0.02504	 0.018101	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40160	 45477	 0.12945	 0.30061	 0.00447	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40160	 90650	 0.019115	 0.1297	 0.00242	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40161	 46503	 0.000717	 0.001895	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40161	 46506	 0.001298	 0.003431	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40161	 89034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40161	 89034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40162	 45947	 0.024893	 0.038133	 0.00054	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40162	 90792	 0.007353	 0.02109	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40162	 90796	 0.21132	 0.16726	 0.00211	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40163	 45639	 0.014045	 0.010641	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40163	 45641	 0.004194	 0.01078	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40163	 45646	 0.021528	 0.015562	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40164	 44310	 0.10521	 0.10627	 0.00141	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40164	 46412	 0.015348	 0.039452	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40165	 46524	 0.15273	 0.1082	 0.00171	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40165	 46559	 0.47609	 0.37706	 0.00475	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40165	 90961	 0.013239	 0.04369	 0.00071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40166	 46841	 0.040199	 0.079593	 0.00117	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40166	 46842	 0.014411	 0.01894	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40167	 45557	 0.009982	 0.01658	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40167	 90675	 0.012965	 0.023304	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40168	 46834	 0.018392	 0.038656	 0.0007	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40168	 46837	 0.010946	 0.048229	 0.00084	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40168	 91044	 0.12082	 0.23925	 0.00351	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40169	 45451	 0.050062	 0.1287	 0.00199	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40169	 45853	 0.096776	 0.14826	 0.00208	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40169	 45855	 0.15983	 0.1176	 0.00172	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40170	 90804	 0.045854	 0.090788	 0.00133	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40170	 90805	 0.055396	 0.066315	 0.0011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40171	 45626	 0.001158	 0.003005	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40171	 45627	 0.000677	 0.001817	 0.00041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40171	 45630	 0.001235	 0.003206	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40171	 89035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40171	 89035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40172	 46961	 0.011843	 0.10749	 0.21309	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40172	 46968	 0.007871	 0.068965	 0.12599	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40172	 89036	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89037	 40172	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40173	 40175	 0.019482	 0.017457	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40174	 40177	 0.017297	 0.012726	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40175	 40176	 0.008907	 0.013644	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40175	 40188	 0.065902	 0.051657	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89037	 40175	 0.009216	 0.041239	 0.00085	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40176	 40178	 0.007309	 0.011666	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40177	 40178	 0.009161	 0.019631	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40177	 40181	 0.009872	 0.011572	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89037	 40177	 0.011407	 0.032717	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40179	 40180	 0.013672	 0.01082	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89037	 40179	 0.023345	 0.049842	 0.00113	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40180	 40181	 0.015471	 0.014508	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40181	 40182	 0.019897	 0.015746	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89037	 40183	 0.020894	 0.041368	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40184	 41962	 0.006205	 0.048273	 0.01254	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89036	 40184	 0.00595	 0.045595	 0.01221	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40185	 40186	 0.010768	 0.065135	 0.01663	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40185	 41963	 0.011222	 0.056777	 0.01581	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40186	 40187	 0.012087	 0.048397	 0.01219	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40186	 42726	 0.028458	 0.079375	 0.01667	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40186	 89038	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40186	 89038	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89036	 40187	 0.004126	 0.023962	 0.00564	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40189	 42727	 0.013211	 0.052897	 0.01333	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89036	 40189	 0.007157	 0.027207	 0.00762	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40190	 89820	 0.17931	 0.16519	 0.00265	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40191	 40192	 0.2196	 0.17382	 0.00219	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40192	 40193	 0.12384	 0.098007	 0.00123	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88914	 40192	 0.14048	 0.36126	 0.00559	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40194	 40195	 0.005872	 0.023081	 0.00604	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40194	 40196	 0.008063	 0.039758	 0.01075	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88856	 40194	 0.003546	 0.025921	 0.00765	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40195	 40197	 0.003523	 0.022311	 0.00606	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88856	 40195	 0.008698	 0.047731	 0.01262	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40196	 42592	 0.007575	 0.037422	 0.01093	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40197	 40292	 0.004843	 0.034258	 0.0094	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40198	 40200	 0.011909	 0.026358	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40198	 40202	 0.015855	 0.03385	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40198	 89039	 0.027649	 0.030115	 0.00041	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40198	 90010	 0.021933	 0.1328	 0.00416	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40199	 43262	 0.004783	 0.039092	 0.01061	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40199	 89039	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40199	 89039	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40199	 89040	 0.001727	 0.012942	 0.00316	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89039	 40200	 0.006316	 0.013484	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40200	 89041	 0.022597	 0.052462	 0.00078	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40201	 42444	 0.000795	 0.008073	 0.13127	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40201	 42444	 0.000795	 0.008073	 0.13127	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40201	 43236	 0.000653	 0.006742	 0.10595	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40201	 43236	 0.000653	 0.006742	 0.10595	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40201	 89040	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40203	 40204	 0.004167	 0.022398	 0.00551	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40203	 42397	 0.005769	 0.031657	 0.00837	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40204	 43270	 0.003897	 0.019254	 0.00562	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40205	 40206	 0.040442	 0.116	 0.00178	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40205	 89881	 0.077794	 0.19044	 0.00326	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89037	 40206	 0.23033	 0.51021	 0.00837	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89038	 40206	 0.13273	 0.27905	 0.00509	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40206	 89818	 0.091796	 0.26334	 0.00405	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40206	 89880	 0.062213	 0.21255	 0.00462	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40207	 40210	 0.006646	 0.041245	 0.00999	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40207	 42364	 0.012229	 0.038227	 0.01107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40208	 40216	 0.019736	 0.052991	 0.01201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40208	 43028	 0.014181	 0.04865	 0.01166	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40208	 89042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40208	 89042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40209	 40213	 0.003605	 0.013053	 0.0028	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40209	 89043	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40209	 89043	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40210	 89044	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40210	 89044	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89044	 40211	 0.037181	 0.098291	 0.00178	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40211	 89045	 0.022418	 0.057629	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40212	 42339	 0.002139	 0.015387	 0.00408	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40212	 42736	 0.005976	 0.036719	 0.01343	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40212	 89045	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40212	 89045	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40213	 40215	 0.003921	 0.037642	 0.01095	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40213	 89046	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40213	 89046	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88923	 40214	 0.091846	 0.067576	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89046	 40214	 0.018549	 0.047173	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40215	 42609	 0.016922	 0.057023	 0.01417	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40217	 41941	 0.005057	 0.04197	 0.01104	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40217	 42023	 0.016491	 0.071793	 0.02046	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40217	 49453	 0.025936	 0.10199	 0.0267	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40217	 49586	 0.012268	 0.046637	 0.01306	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40218	 42024	 0.1442	 0.09336	 0.00178	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40218	 89556	 0.38032	 0.29826	 0.00383	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40219	 40222	 0.009684	 0.039987	 0.00946	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40219	 42929	 0.009918	 0.039711	 0.01001	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40220	 42030	 0.069928	 0.20059	 0.00309	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40220	 89047	 0.012664	 0.060522	 0.00132	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40220	 89048	 0.041264	 0.11836	 0.00182	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40221	 43025	 0.012981	 0.066319	 0.01669	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40221	 89047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40221	 89047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40222	 89048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40222	 89048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40222	 89049	 0.005778	 0.030099	 0.00789	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89048	 40223	 0.10566	 0.13117	 0.00286	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40223	 89914	 0.26434	 0.20725	 0.00266	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40224	 43022	 0.001617	 0.010498	 0.02091	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40224	 89049	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40224	 89049	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40225	 40226	 0.013341	 0.035816	 0.00812	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40225	 42623	 0.020201	 0.053395	 0.0125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40226	 40227	 0.013555	 0.035191	 0.00854	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40227	 40229	 0.005714	 0.013769	 0.00389	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40227	 42643	 0.012112	 0.051266	 0.01154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40227	 89050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40227	 89050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40228	 42644	 0.1473	 0.3421	 0.00509	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89050	 40228	 0.062358	 0.062984	 0.00083	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40228	 89051	 0.019191	 0.022973	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40229	 42915	 0.008497	 0.02206	 0.00535	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40229	 89051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40229	 89051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40230	 40232	 0.004385	 0.010383	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40230	 40236	 0.004603	 0.013202	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40230	 89058	 0.018354	 0.014525	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40231	 40232	 0.002212	 0.004336	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40231	 40233	 0.002282	 0.005297	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40231	 40234	 0.002505	 0.005815	 9e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40233	 40258	 0.006651	 0.008741	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40236	 40271	 0.007214	 0.014282	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40236	 89052	 0.008412	 0.023871	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40236	 89053	 0.003699	 0.016203	 0.00035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40236	 89058	 0.023833	 0.026213	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40237	 40253	 0.005302	 0.021228	 0.00535	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40237	 89052	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40237	 89052	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40237	 89057	 0.001679	 0.008705	 0.00213	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40237	 89062	 0.00105	 0.009609	 0.00385	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40238	 40239	 0.002521	 0.009584	 0.00268	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40238	 89053	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40238	 89053	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40238	 89057	 0.002083	 0.010465	 0.00272	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40238	 89062	 0.000948	 0.009097	 0.00265	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40239	 40243	 0.002012	 0.011785	 0.00321	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40239	 40266	 0.001979	 0.019003	 0.00553	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40239	 89054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40239	 89054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40240	 40241	 0.005419	 0.013929	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89053	 40240	 0.005827	 0.011925	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40241	 40247	 0.009273	 0.018359	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89053	 40242	 0.010029	 0.033456	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40242	 89055	 0.006035	 0.017309	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40243	 40244	 0.000948	 0.006003	 0.00163	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40243	 89055	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40243	 89055	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40243	 89057	 0.004474	 0.017582	 0.0046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40244	 40270	 0.003673	 0.022567	 0.00825	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40244	 89056	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40244	 89056	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40245	 40246	 0.01187	 0.023264	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89054	 40245	 0.020324	 0.041592	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89055	 40246	 0.006418	 0.016498	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89056	 40246	 0.009886	 0.026133	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40248	 40249	 0.01236	 0.024224	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89056	 40248	 0.02626	 0.024625	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40249	 40259	 0.023669	 0.01711	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40250	 40267	 0.000169	 0.003121	 0.02998	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40250	 41668	 0.000567	 0.013925	 0.2415	 1940.0	 2037.0	 2134.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40250	 89057	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40251	 40272	 0.029871	 0.023639	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89058	 40251	 0.008451	 0.021725	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40251	 89059	 0.044914	 0.029078	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40251	 89063	 0.15324	 0.15479	 0.00205	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40252	 89059	 0.01302	 0.025517	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40253	 42993	 0.017536	 0.071373	 0.01739	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89057	 40253	 0.003941	 0.01352	 0.00324	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40253	 89059	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40253	 89059	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89059	 40254	 0.029623	 0.032582	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40255	 40258	 0.037803	 0.024474	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89059	 40256	 0.027368	 0.053637	 0.0008	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40257	 40258	 0.013843	 0.010955	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40258	 40272	 0.012567	 0.012693	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89058	 40258	 0.005448	 0.019075	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40260	 41910	 0.005309	 0.037555	 0.01031	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40261	 89060	 0.011546	 0.026805	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89057	 40262	 0.019289	 0.050082	 0.01216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40262	 89060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40262	 89060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40263	 41909	 0.020101	 0.050534	 0.01309	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40263	 42985	 0.022198	 0.076165	 0.01825	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40263	 89062	 0.005292	 0.054421	 0.02059	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40264	 40265	 0.010845	 0.037205	 0.00891	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40264	 41912	 0.016663	 0.038682	 0.01179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40264	 89061	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40264	 89061	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40265	 40266	 0.001113	 0.01163	 0.0032	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40265	 89816	 0.002081	 0.029435	 0.00975	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40267	 89062	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40267	 89062	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89057	 40268	 0.011978	 0.04109	 0.00984	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40268	 89063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40268	 89063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40269	 89064	 0.066032	 0.20281	 0.00381	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40270	 89064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40270	 89064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40270	 89432	 0.013991	 0.07148	 0.01798	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89058	 40271	 0.040541	 0.026246	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40273	 40274	 0.000587	 0.006265	 0.09201	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40273	 40274	 0.000587	 0.006265	 0.09201	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40273	 42498	 0.000859	 0.008667	 0.14269	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40273	 42498	 0.000859	 0.008667	 0.14269	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40273	 42910	 0.000465	 0.00815	 0.0872	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40273	 89065	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40273	 89065	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40275	 40277	 0.001616	 0.006838	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40275	 42637	 0.016168	 0.081255	 0.02115	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88847	 40275	 0.007105	 0.041617	 0.01134	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89065	 40275	 0.00707	 0.041412	 0.01128	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40275	 89066	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40275	 89066	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40276	 40282	 0.061362	 0.1141	 0.00267	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89066	 40276	 0.007989	 0.018122	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40277	 40278	 0.007965	 0.027872	 0.00924	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40278	 40279	 0.011664	 0.046703	 0.01177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40279	 40281	 0.004309	 0.016936	 0.00443	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88856	 40279	 0.021676	 0.12101	 0.03094	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40280	 40281	 0.000947	 0.003599	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40280	 42923	 0.009026	 0.035116	 0.00938	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40282	 42635	 0.075194	 0.21569	 0.00332	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40283	 40284	 0.005232	 0.015747	 0.00493	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40283	 40286	 0.009363	 0.031547	 0.00784	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40283	 89067	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40283	 89067	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40284	 41889	 0.017249	 0.044343	 0.01098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40285	 40286	 0.007256	 0.021392	 0.00498	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88851	 40285	 0.017804	 0.12602	 0.03461	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40285	 89068	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40285	 89068	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40286	 89069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40286	 89069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88850	 40287	 0.001392	 0.012324	 0.05222	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40287	 89070	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40287	 89070	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88855	 40288	 0.00619	 0.078969	 0.14974	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40288	 89071	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40288	 89071	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40289	 40290	 0.000839	 0.008546	 0.0022	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88891	 40289	 0.001775	 0.015486	 0.00425	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40290	 43012	 0.006907	 0.040459	 0.01102	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40290	 89072	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40290	 89072	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40291	 89074	 0.022831	 0.12979	 0.00235	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40291	 89075	 0.029183	 0.11354	 0.0019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40291	 89855	 0.042397	 0.1216	 0.00187	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40292	 40293	 0.004429	 0.022639	 0.00617	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40292	 89073	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40292	 89073	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40293	 40296	 0.013871	 0.04674	 0.01162	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40293	 89074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40293	 89074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40293	 89851	 0.014546	 0.082391	 0.02043	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40294	 40295	 0.038278	 0.1277	 0.00202	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40294	 42596	 0.033052	 0.14648	 0.0044	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40294	 42597	 0.04175	 0.096929	 0.00144	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89074	 40295	 0.023566	 0.11505	 0.00241	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40296	 42604	 0.01213	 0.040872	 0.01016	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40296	 43009	 0.015393	 0.054415	 0.01226	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40297	 89075	 0.15787	 0.10606	 0.00187	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40298	 42843	 0.011777	 0.031618	 0.00717	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40298	 43008	 0.012433	 0.041892	 0.01041	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40298	 89075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40298	 89075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40299	 40303	 0.008051	 0.026258	 0.00697	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40299	 89076	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40299	 89076	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40300	 40302	 0.007685	 0.025895	 0.00644	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40300	 42656	 0.01368	 0.046097	 0.01146	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88910	 40300	 0.00742	 0.062411	 0.01849	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40300	 89077	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40300	 89077	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89077	 40301	 0.019116	 0.037849	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40302	 40303	 0.009519	 0.025557	 0.00579	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88910	 40303	 0.008527	 0.080288	 0.02433	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40303	 89078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40303	 89078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40304	 40305	 0.064209	 0.050815	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89069	 40304	 0.30292	 0.24945	 0.00505	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89078	 40304	 0.051696	 0.10236	 0.0015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40305	 40306	 0.023618	 0.033528	 0.00055	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89076	 40305	 0.064834	 0.12707	 0.0019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40306	 40307	 0.01254	 0.012805	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89078	 40306	 0.010281	 0.034297	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40308	 40309	 0.030207	 0.03051	 0.0004	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89078	 40308	 0.09304	 0.13209	 0.00217	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40309	 40310	 0.010675	 0.019552	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89077	 40309	 0.017088	 0.066478	 0.00111	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40311	 40314	 0.002672	 0.006868	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40311	 89239	 0.002774	 0.010405	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40312	 40313	 0.008197	 0.005307	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40312	 40320	 0.003086	 0.007934	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40312	 40322	 0.002609	 0.005363	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40312	 89239	 0.00134	 0.007616	 0.00014	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40314	 40321	 0.010246	 0.008433	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40315	 40317	 0.001817	 0.00356	 5e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40315	 41518	 0.004878	 0.012538	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40316	 40319	 0.006756	 0.005119	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40317	 40318	 0.002547	 0.004991	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40317	 40319	 0.001855	 0.003449	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40318	 40340	 0.004077	 0.007356	 0.00011	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40319	 40321	 0.002061	 0.005298	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40320	 40321	 0.001945	 0.004606	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40322	 40326	 0.003669	 0.00771	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40323	 40325	 0.003167	 0.007243	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40323	 89240	 0.004325	 0.010242	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40324	 40325	 0.0022	 0.008254	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40324	 40328	 0.00394	 0.007216	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40324	 89233	 0.002036	 0.010588	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40325	 40326	 0.002985	 0.006109	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40326	 40327	 0.004883	 0.008414	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40327	 40335	 0.004108	 0.009216	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40327	 41518	 0.012774	 0.010013	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40328	 40329	 0.009832	 0.006365	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40329	 40333	 0.011787	 0.009239	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40330	 40332	 0.004181	 0.008193	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40330	 40476	 0.004377	 0.007868	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40331	 40333	 0.002746	 0.009062	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40331	 89233	 0.003525	 0.012343	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40332	 40333	 0.004861	 0.008682	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40332	 89081	 0.00657	 0.008635	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40333	 40334	 0.00282	 0.007	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40334	 40335	 0.00333	 0.006098	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40335	 40341	 0.007405	 0.00561	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40335	 40364	 0.008961	 0.013727	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40336	 40337	 0.002779	 0.002606	 4e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40336	 40344	 0.001521	 0.003012	 4e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40337	 40338	 0.003126	 0.002474	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40338	 40339	 0.002826	 0.002237	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40338	 40340	 0.006454	 0.007098	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40340	 40343	 0.004838	 0.008729	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40342	 40343	 0.008591	 0.006799	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40343	 40344	 0.004773	 0.007311	 0.0001	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40343	 40353	 0.002381	 0.014951	 0.00033	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40344	 40346	 0.002625	 0.003578	 8e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40345	 40346	 0.004513	 0.003571	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40346	 40350	 0.002571	 0.006089	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40347	 40349	 0.006256	 0.004903	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40348	 40350	 0.002274	 0.0018	 2e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40349	 40350	 0.001019	 0.003125	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40349	 40355	 0.001147	 0.005837	 0.00013	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40351	 40352	 0.004321	 0.006619	 9e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40351	 40355	 0.014253	 0.010933	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40352	 40364	 0.005216	 0.010326	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40353	 40354	 0.00871	 0.005851	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40353	 40369	 0.002544	 0.006541	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40353	 89082	 0.004934	 0.015153	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40354	 40360	 0.011698	 0.009258	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40355	 40356	 0.003026	 0.005991	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40355	 89082	 0.004429	 0.019515	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40356	 40358	 0.001859	 0.0062	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40357	 89079	 0.009179	 0.008225	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40358	 40359	 0.000737	 0.003075	 9e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40359	 89079	 0.000846	 0.005311	 0.00012	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40360	 41519	 0.003264	 0.006462	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40361	 40362	 0.005902	 0.003964	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40362	 89082	 0.008984	 0.00711	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40363	 41533	 0.000453	 0.001525	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40363	 89079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40363	 89079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40364	 89081	 0.002728	 0.009746	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40365	 40366	 0.000617	 0.002182	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40365	 40507	 0.001221	 0.004114	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40365	 89080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40365	 89080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40366	 89081	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40366	 89081	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40367	 40477	 0.010315	 0.008086	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40368	 40369	 0.002407	 0.005586	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89080	 40368	 0.002006	 0.00662	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89081	 40368	 0.007098	 0.011957	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40369	 40370	 0.008584	 0.007337	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40370	 40375	 0.006096	 0.008883	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40371	 40376	 0.005654	 0.010163	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89080	 40371	 0.009333	 0.007071	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40371	 89092	 0.003046	 0.007071	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40372	 40376	 0.008913	 0.00577	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40373	 40375	 0.008799	 0.006233	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40373	 41520	 0.009298	 0.007358	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40374	 40375	 0.008827	 0.005714	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40374	 89082	 0.005836	 0.004574	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40375	 40376	 0.004646	 0.007117	 0.0001	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40375	 40377	 0.002476	 0.007453	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40377	 89412	 0.001574	 0.008385	 0.00015	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40378	 40389	 0.004118	 0.00453	 6e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40378	 40390	 0.011594	 0.007506	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40378	 89412	 0.00545	 0.01401	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40379	 40384	 0.0059	 0.004624	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40380	 40381	 0.00583	 0.003775	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40380	 40382	 0.005878	 0.006465	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40380	 40384	 0.008331	 0.005393	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40382	 40383	 0.005897	 0.003818	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40382	 40557	 0.004101	 0.009521	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40382	 89412	 0.003731	 0.006285	 9e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40383	 40384	 0.002199	 0.004354	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40383	 40386	 0.006413	 0.0063	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40384	 40385	 0.008768	 0.006939	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40384	 40406	 0.0016	 0.004113	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40385	 40407	 0.004496	 0.004217	 7e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40386	 89086	 0.003732	 0.009593	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40387	 89082	 0.005927	 0.00469	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40388	 40426	 0.002435	 0.008816	 0.00189	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40388	 89082	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40388	 89082	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40389	 40390	 0.005764	 0.004562	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89082	 40389	 0.006893	 0.009059	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40390	 40391	 0.007973	 0.006309	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40390	 41531	 0.006569	 0.006588	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40391	 40396	 0.003548	 0.004664	 6e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89079	 40391	 0.005213	 0.007901	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40392	 89083	 0.003171	 0.003936	 9e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40392	 89377	 0.006721	 0.006788	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40393	 40411	 0.001251	 0.004292	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40393	 41533	 0.000852	 0.002253	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40393	 89083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40393	 89083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40394	 40398	 0.002746	 0.004383	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40394	 89377	 0.002257	 0.00397	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40395	 40396	 0.005818	 0.004205	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40395	 41532	 0.002062	 0.004084	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40395	 89377	 0.00733	 0.005801	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40396	 40397	 0.006107	 0.004833	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40397	 40404	 0.002216	 0.003537	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40397	 41531	 0.008711	 0.006894	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40397	 89377	 0.01575	 0.011587	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40398	 40399	 0.001881	 0.004605	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40399	 40400	 0.002219	 0.004394	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40399	 40401	 0.003164	 0.00348	 5e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40399	 40412	 0.001894	 0.005021	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40400	 89085	 0.002393	 0.005555	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40401	 40402	 0.005643	 0.004465	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40402	 40403	 0.005861	 0.004638	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40402	 41532	 0.002464	 0.004829	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40402	 89084	 0.002556	 0.00733	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40403	 40404	 0.005972	 0.004726	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40404	 40405	 0.005825	 0.00461	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40404	 40408	 0.003965	 0.007851	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40405	 40406	 0.005794	 0.004585	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40406	 41531	 0.002465	 0.004093	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40407	 40408	 0.001826	 0.003395	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40407	 89086	 0.0015	 0.00731	 0.00014	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40408	 40409	 0.005826	 0.004567	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40409	 40410	 0.004123	 0.004393	 6e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40410	 89084	 0.002188	 0.004332	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40411	 40413	 0.001166	 0.002997	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40411	 89084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40411	 89084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40411	 89378	 0.000536	 0.004673	 0.00128	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40412	 40414	 0.007481	 0.005408	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40412	 40422	 0.005933	 0.011747	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89084	 40412	 0.006533	 0.004723	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40412	 89085	 0.010777	 0.008529	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40413	 40416	 0.000468	 0.001457	 0.0003	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40413	 89085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40413	 89085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40414	 40415	 0.003828	 0.002478	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40414	 40419	 0.006472	 0.005122	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40415	 40421	 0.012016	 0.00884	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89085	 40415	 0.006982	 0.005526	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40416	 40418	 0.000462	 0.001611	 0.00037	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89084	 40417	 0.006392	 0.004293	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40418	 40431	 0.00062	 0.002161	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40419	 40420	 0.006115	 0.004839	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40419	 40421	 0.005487	 0.003966	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40420	 40430	 0.008247	 0.006465	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40421	 40422	 0.001657	 0.00426	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40421	 40430	 0.013149	 0.010307	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40422	 40423	 0.001601	 0.003716	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40422	 40428	 0.002911	 0.007695	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40423	 40424	 0.001411	 0.003656	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40424	 40425	 0.00576	 0.004238	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40424	 89379	 0.001819	 0.007434	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40426	 89086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40426	 89086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40426	 89378	 0.000255	 0.002867	 0.00075	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40427	 40428	 0.001602	 0.003719	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40427	 89379	 0.002712	 0.00555	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40429	 40430	 0.005716	 0.003701	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40430	 41538	 0.004691	 0.013312	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40431	 40432	 0.000661	 0.002269	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40432	 40436	 0.000553	 0.002284	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40433	 40434	 0.001816	 0.004171	 6e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40433	 40435	 0.002028	 0.004659	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40434	 40440	 0.002747	 0.005107	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40435	 41538	 0.003031	 0.006964	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40436	 40443	 0.000591	 0.002406	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40437	 40438	 0.005882	 0.004166	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40438	 40439	 0.00201	 0.004667	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40438	 40441	 0.002852	 0.006112	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40439	 40440	 0.00275	 0.003749	 8e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40440	 89402	 0.003165	 0.008136	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40441	 40442	 0.001124	 0.00261	 4e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40441	 40452	 0.001996	 0.008893	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40441	 41579	 0.007858	 0.005087	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40442	 40444	 0.006504	 0.004785	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40442	 89087	 0.001065	 0.002644	 4e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40443	 40449	 0.000237	 0.001749	 0.0005	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40443	 89087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40443	 89087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40445	 40446	 0.002054	 0.004068	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89087	 40445	 0.002034	 0.004275	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40446	 40447	 0.002806	 0.006645	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40446	 89132	 0.001538	 0.010165	 0.0002	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40448	 89132	 0.002412	 0.006199	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40449	 89088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40449	 89088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40449	 89390	 0.000418	 0.003181	 0.001	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40450	 40451	 0.001785	 0.002735	 4e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89088	 40450	 0.001017	 0.00236	 4e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40451	 40452	 0.003062	 0.00547	 8e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40452	 40453	 0.008839	 0.00639	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40452	 40660	 0.004424	 0.009481	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40452	 89391	 0.001967	 0.013347	 0.00025	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40454	 40455	 0.012024	 0.012027	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40454	 41153	 0.016686	 0.018352	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40454	 41155	 0.006414	 0.009825	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40455	 40456	 0.011081	 0.008769	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40455	 41156	 0.006024	 0.013664	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40455	 89235	 0.020714	 0.022783	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40457	 40458	 0.002284	 0.009154	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40457	 40465	 0.005276	 0.013562	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40458	 40459	 0.012743	 0.01287	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40458	 89235	 0.003892	 0.017146	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40459	 40460	 0.007339	 0.012363	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40460	 41218	 0.003437	 0.009753	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40461	 41004	 0.012598	 0.008924	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40461	 41005	 0.013799	 0.018136	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40461	 41218	 0.008644	 0.013487	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40462	 40463	 0.011446	 0.009058	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40463	 40466	 0.008079	 0.013609	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40463	 89242	 0.003542	 0.008388	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40464	 40465	 0.004802	 0.009508	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40464	 40471	 0.010778	 0.014165	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40464	 89235	 0.005683	 0.023723	 0.00068	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40465	 40467	 0.006746	 0.008867	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40465	 40468	 0.005516	 0.01081	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40466	 40492	 0.013512	 0.011548	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40467	 40469	 0.015925	 0.012483	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40468	 40473	 0.011734	 0.009286	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40469	 40489	 0.011342	 0.012354	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40470	 89235	 0.023473	 0.018576	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40472	 40475	 0.01009	 0.013131	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40472	 89232	 0.008425	 0.032776	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40473	 40481	 0.018359	 0.014529	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40474	 40476	 0.011547	 0.008179	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40474	 89233	 0.006204	 0.014402	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40475	 40481	 0.005795	 0.011473	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40475	 89376	 0.013989	 0.016398	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40476	 89376	 0.005234	 0.010362	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40477	 89092	 0.006575	 0.007021	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40478	 40485	 0.002223	 0.004357	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40478	 89092	 0.009267	 0.009896	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40479	 40484	 0.0078	 0.005239	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40479	 89089	 0.005453	 0.004275	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40480	 40505	 0.001729	 0.00482	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40480	 41192	 0.003623	 0.009864	 0.00217	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40480	 41530	 0.000874	 0.002311	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40480	 89089	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40480	 89089	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40481	 40488	 0.013953	 0.018338	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40481	 89090	 0.009281	 0.010208	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40482	 40502	 0.000695	 0.002456	 0.00055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40482	 41530	 0.001911	 0.00496	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40482	 89090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40482	 89090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89090	 40483	 0.007232	 0.005321	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89090	 40484	 0.013046	 0.008446	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40484	 89091	 0.009118	 0.006708	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40485	 89091	 0.002383	 0.003823	 7e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40485	 89095	 0.005249	 0.008766	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40486	 40505	 0.000484	 0.001279	 0.0003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40486	 89091	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40486	 89091	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40487	 40507	 0.000423	 0.001451	 0.00035	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40487	 89092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40487	 89092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40488	 40489	 0.004921	 0.00888	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40488	 40501	 0.013206	 0.009354	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40488	 89371	 0.039199	 0.039592	 0.00052	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40489	 40490	 0.006119	 0.009847	 0.00015	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40489	 40495	 0.004376	 0.01255	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40490	 40492	 0.002888	 0.006604	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40491	 89093	 0.011774	 0.008512	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40492	 89093	 0.002178	 0.00668	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40493	 41221	 0.001099	 0.003704	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40493	 89093	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40493	 89093	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40494	 40495	 0.009073	 0.009075	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40494	 40500	 0.004431	 0.008772	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40494	 40517	 0.011733	 0.009285	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40495	 40530	 0.006485	 0.016671	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40496	 40498	 0.003245	 0.009308	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40496	 89098	 0.00752	 0.012668	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40497	 40498	 0.006665	 0.006731	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40497	 40529	 0.012188	 0.009234	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40498	 89103	 0.004799	 0.016394	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40499	 40530	 0.011807	 0.009255	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40500	 40532	 0.003246	 0.008254	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40501	 89094	 0.01081	 0.008473	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40502	 40513	 0.000757	 0.002468	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40502	 89094	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40502	 89094	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40503	 40504	 0.009702	 0.007678	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89094	 40503	 0.00935	 0.007399	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40504	 40511	 0.004418	 0.008747	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40504	 89095	 0.008624	 0.009188	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40505	 40507	 0.000684	 0.002345	 0.00056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40505	 41523	 0.001017	 0.004937	 0.00113	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40505	 89095	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40505	 89095	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40506	 89097	 0.008686	 0.006663	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40507	 40509	 0.000773	 0.00258	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40507	 89096	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40507	 89096	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89092	 40508	 0.013818	 0.009989	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89096	 40508	 0.005847	 0.004627	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40509	 40510	 0.000684	 0.002281	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40510	 41523	 0.000351	 0.002356	 0.00057	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40510	 89097	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40510	 89097	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40511	 40512	 0.009706	 0.007608	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40511	 89371	 0.002772	 0.008343	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40513	 40515	 0.000632	 0.002608	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40513	 89098	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40513	 89098	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40514	 40544	 0.012177	 0.009637	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40515	 40550	 0.000351	 0.001925	 0.00051	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40515	 89099	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40515	 89099	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40516	 40518	 0.003473	 0.007978	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40516	 89242	 0.004238	 0.008211	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89093	 40517	 0.009247	 0.00934	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40518	 40523	 0.005528	 0.015855	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40518	 40525	 0.009112	 0.009204	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40519	 40523	 0.004917	 0.008872	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40519	 89241	 0.017465	 0.011307	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40520	 40522	 0.004414	 0.011347	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40520	 40993	 0.007891	 0.016911	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40520	 41219	 0.006324	 0.011367	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40521	 40522	 0.010267	 0.006647	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40522	 41224	 0.003137	 0.01035	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40523	 89244	 0.006193	 0.018998	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40524	 40527	 0.005926	 0.011733	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40524	 41222	 0.003205	 0.006345	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40525	 40526	 0.01832	 0.01186	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40525	 89375	 0.009833	 0.019469	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40526	 40531	 0.011844	 0.007668	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40527	 89375	 0.014388	 0.011386	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40528	 40544	 0.008161	 0.006458	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40529	 40537	 0.009084	 0.009175	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40530	 40535	 0.003757	 0.00633	 9e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40530	 89100	 0.003441	 0.01108	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40531	 89374	 0.005351	 0.010594	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40532	 89100	 0.002067	 0.008043	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40533	 89374	 0.009099	 0.007201	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40534	 40543	 0.000814	 0.002151	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40534	 40623	 0.001827	 0.005094	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40534	 41527	 0.001427	 0.003669	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40534	 89100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40534	 89100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40535	 40536	 0.00221	 0.00433	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40536	 40541	 0.003651	 0.00723	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89100	 40536	 0.004456	 0.008823	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40537	 40538	 0.008727	 0.006841	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40537	 40540	 0.003637	 0.009251	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40539	 40540	 0.003246	 0.006363	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40540	 40622	 0.001774	 0.007816	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40540	 89116	 0.004438	 0.011409	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40541	 89116	 0.003242	 0.008334	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40542	 89101	 0.004391	 0.007009	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40543	 40624	 0.000693	 0.00245	 0.00055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40543	 89101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40543	 89101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40544	 89103	 0.00326	 0.008291	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40545	 41230	 0.001444	 0.010125	 0.01724	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40545	 89102	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89103	 40545	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40545	 89399	 0.000507	 0.003418	 0.00629	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40546	 40547	 0.00719	 0.00529	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89103	 40546	 0.007292	 0.005365	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40547	 89372	 0.009675	 0.007421	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40548	 40566	 0.000254	 0.001794	 0.00049	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40548	 41524	 0.000181	 0.001284	 0.00035	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40549	 40601	 0.004242	 0.011012	 0.00267	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40549	 41523	 0.00085	 0.003511	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40549	 41624	 0.000686	 0.002484	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40549	 89104	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40549	 89104	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40550	 40551	 0.000375	 0.001719	 0.00044	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89102	 40550	 0.000446	 0.002401	 0.00066	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40551	 40552	 0.000307	 0.001113	 0.00024	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40551	 41523	 0.000462	 0.001617	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40552	 40564	 0.000399	 0.001369	 0.00033	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40553	 40554	 0.000295	 0.000995	 0.00025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40553	 41523	 0.000725	 0.001823	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40554	 40562	 0.000412	 0.00124	 0.00039	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40555	 40556	 0.001033	 0.004017	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40555	 40560	 0.004457	 0.008163	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40555	 89106	 0.00465	 0.01809	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40556	 40557	 0.001417	 0.004727	 7e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89104	 40556	 0.011866	 0.008405	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40557	 41521	 0.011234	 0.011347	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40558	 40559	 0.00587	 0.004447	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40558	 40572	 0.01263	 0.008176	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40559	 40560	 0.003473	 0.00442	 6e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40560	 89105	 0.002372	 0.004853	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40561	 40567	 0.008362	 0.006045	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40562	 40566	 0.000699	 0.002797	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40562	 89105	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40562	 89105	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40563	 40564	 0.00032	 0.001133	 0.00026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40563	 40565	 0.000592	 0.002031	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40563	 40566	 0.000383	 0.000984	 0.00024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40564	 40566	 0.00069	 0.002145	 0.00045	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40564	 41523	 0.001017	 0.004306	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40564	 89106	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40564	 89106	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40565	 40566	 0.000252	 0.000989	 0.00026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40565	 40579	 0.000263	 0.001054	 0.00027	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40565	 40583	 0.000624	 0.00214	 0.00051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40566	 89107	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40566	 89107	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40567	 40568	 0.001458	 0.00418	 6e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89107	 40567	 0.008406	 0.005647	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40567	 89109	 0.004553	 0.009721	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40568	 40569	 0.001887	 0.004798	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89107	 40568	 0.006969	 0.01057	 0.00015	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40569	 40570	 0.001617	 0.004014	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40570	 41536	 0.004701	 0.009309	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40571	 40572	 0.005675	 0.004175	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40571	 41536	 0.006092	 0.00622	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40573	 41521	 0.003716	 0.008628	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40573	 41534	 0.006286	 0.004625	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40573	 41536	 0.002168	 0.00665	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40574	 40594	 0.003723	 0.004456	 7e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40574	 41522	 0.004913	 0.006394	 9e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40574	 41536	 0.003159	 0.006639	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40575	 40576	 0.002204	 0.003876	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40575	 40596	 0.004881	 0.006415	 9e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40576	 40577	 0.002579	 0.005106	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40577	 40578	 0.002213	 0.004382	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40577	 40581	 0.005833	 0.004217	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40578	 89108	 0.001646	 0.00423	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40579	 40583	 0.000432	 0.001203	 0.00025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40579	 40586	 0.000657	 0.00278	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40579	 89108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40579	 89108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40580	 40581	 0.006891	 0.005453	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40581	 40588	 0.008352	 0.006609	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40582	 89109	 0.007878	 0.006175	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40583	 40586	 0.000388	 0.001511	 0.0004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40583	 89109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40583	 89109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40584	 89110	 0.001566	 0.006091	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40584	 89372	 0.001526	 0.004376	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40585	 41524	 0.000428	 0.002507	 0.00068	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40585	 89110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40585	 89110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40585	 89400	 0.00034	 0.003013	 0.0008	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40586	 40590	 0.000618	 0.002119	 0.00051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40586	 89111	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40586	 89111	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40586	 89400	 0.001008	 0.004035	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89111	 40587	 0.007955	 0.006296	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40588	 40598	 0.002933	 0.006002	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89111	 40588	 0.002357	 0.00842	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40589	 89112	 0.007521	 0.005952	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40590	 40591	 0.000644	 0.002333	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40590	 89112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40590	 89112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40591	 40644	 0.000692	 0.002331	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40592	 40593	 0.005881	 0.004655	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40592	 40605	 0.010949	 0.007088	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40593	 40604	 0.004758	 0.006254	 9e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40593	 41522	 0.002038	 0.003179	 5e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40594	 89113	 0.003566	 0.006434	 9e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40595	 40596	 0.005881	 0.004654	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40596	 40597	 0.005872	 0.004449	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40596	 40598	 0.00555	 0.009976	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40596	 40599	 0.002498	 0.004896	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40599	 40600	 0.002376	 0.004704	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40599	 89115	 0.009263	 0.007624	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40600	 89113	 0.002442	 0.004362	 6e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40601	 40610	 0.000809	 0.002137	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40601	 89113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40601	 89113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40602	 40603	 0.002894	 0.004387	 9e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89113	 40602	 0.001973	 0.00329	 5e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40603	 40604	 0.002435	 0.004376	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40603	 89404	 0.004993	 0.014321	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40605	 40606	 0.008685	 0.008687	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40606	 40607	 0.005875	 0.004605	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40606	 40619	 0.004403	 0.007913	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40607	 40608	 0.005873	 0.004505	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40608	 40609	 0.004523	 0.004242	 7e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40609	 89114	 0.002207	 0.003968	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40610	 40611	 0.000399	 0.001054	 0.00025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40610	 89114	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40610	 89114	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40611	 40612	 0.000322	 0.001106	 0.00026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40612	 41568	 0.000905	 0.003104	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40612	 89115	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40612	 89115	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40613	 89385	 0.00984	 0.007788	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40614	 40615	 0.005152	 0.005667	 8e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40614	 40616	 0.010133	 0.009914	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40614	 89385	 0.003552	 0.010186	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40615	 41575	 0.004991	 0.008914	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89114	 40615	 0.006826	 0.008687	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40616	 40617	 0.005886	 0.004658	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40617	 40618	 0.005875	 0.004605	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40617	 40661	 0.004449	 0.008028	 0.00012	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40619	 40620	 0.002208	 0.003668	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40619	 40661	 0.007909	 0.010395	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40620	 40621	 0.001853	 0.00618	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40621	 89380	 0.001812	 0.007937	 0.00017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40622	 89116	 0.003666	 0.008512	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40622	 89119	 0.001147	 0.006519	 0.00012	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40623	 40627	 0.000596	 0.001987	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40623	 89116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40623	 89116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40624	 40625	 0.001777	 0.004126	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40624	 40626	 0.000892	 0.002358	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40625	 41225	 0.000712	 0.002896	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40625	 41528	 0.000934	 0.003256	 0.00075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40625	 89117	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40625	 89117	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40626	 40627	 0.000811	 0.002106	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40626	 40632	 0.000617	 0.002079	 0.00052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40627	 40628	 0.000773	 0.002042	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40627	 89118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40627	 89118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40628	 40629	 0.000759	 0.002683	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40628	 89119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40628	 89119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40629	 40636	 0.000621	 0.001869	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40629	 89120	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40629	 89120	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89120	 40630	 0.008563	 0.006066	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40631	 40634	 0.003302	 0.007666	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89118	 40631	 0.004875	 0.008796	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40632	 40633	 0.000525	 0.002044	 0.00055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40632	 89121	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40632	 89121	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40633	 40639	 0.000517	 0.002134	 0.0005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40634	 40635	 0.010287	 0.008141	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40634	 40638	 0.002921	 0.008376	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40635	 89122	 0.006225	 0.006847	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40636	 40637	 0.000543	 0.002133	 0.00056	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40636	 89122	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40636	 89122	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40637	 41526	 0.000988	 0.004403	 0.0012	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40638	 40641	 0.001762	 0.007202	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40639	 41246	 0.000516	 0.002099	 0.00051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40639	 89123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40639	 89123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40640	 40641	 0.004927	 0.007179	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40640	 89256	 0.005034	 0.00922	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40641	 40642	 0.002889	 0.006191	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40641	 89373	 0.00148	 0.007697	 0.00017	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40642	 40643	 0.003754	 0.006468	 0.0001	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40643	 40647	 0.004483	 0.009422	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40643	 41255	 0.007291	 0.015624	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40644	 40651	 0.000515	 0.00206	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40644	 89124	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40644	 89124	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40645	 40646	 0.001839	 0.00394	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89124	 40645	 0.002638	 0.004444	 6e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40645	 89401	 0.00467	 0.013393	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40646	 40647	 0.001839	 0.004269	 6e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40648	 40649	 0.005894	 0.004664	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40648	 89126	 0.00457	 0.007633	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40649	 40650	 0.005861	 0.003795	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40650	 89125	 0.005895	 0.004262	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40651	 40653	 0.000621	 0.00244	 0.00064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40651	 89125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40651	 89125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40652	 89408	 0.005002	 0.00368	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40653	 40670	 0.000632	 0.002211	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40653	 89126	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40653	 89126	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89125	 40654	 0.006529	 0.004719	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40655	 40656	 0.004533	 0.004534	 6e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40655	 41573	 0.002374	 0.005429	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40655	 89386	 0.001507	 0.004324	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40656	 40657	 0.001233	 0.004114	 7e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40656	 40665	 0.025653	 0.016608	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40656	 41570	 0.007907	 0.005119	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89125	 40657	 0.001466	 0.007813	 0.00014	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40658	 41573	 0.002514	 0.006464	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40658	 89408	 0.003604	 0.008364	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40659	 41574	 0.000402	 0.001578	 0.00041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40659	 41580	 0.000287	 0.001092	 0.00031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40660	 40664	 0.002422	 0.006947	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40661	 89388	 0.002426	 0.01603	 0.00032	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40662	 40663	 0.00454	 0.003593	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40662	 89387	 0.007261	 0.005143	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40664	 89398	 0.001961	 0.011916	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40665	 40666	 0.004869	 0.003853	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40665	 41576	 0.013687	 0.008861	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40665	 41620	 0.00493	 0.008861	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40665	 89387	 0.009665	 0.007648	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40667	 40668	 0.001823	 0.00339	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40667	 41542	 0.005209	 0.008701	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40667	 89388	 0.002347	 0.009028	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40668	 41542	 0.007	 0.005061	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88930	 40668	 0.002754	 0.005788	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40669	 40690	 0.000573	 0.00233	 0.00057	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40670	 40675	 0.000366	 0.001818	 0.00059	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40670	 89127	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40670	 89127	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40671	 89396	 0.006203	 0.004909	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40672	 41596	 0.008004	 0.005888	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40672	 41618	 0.011394	 0.009017	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40673	 40678	 0.014408	 0.011294	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40673	 41581	 0.007763	 0.008539	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40673	 41602	 0.003285	 0.004318	 6e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40674	 40677	 0.013207	 0.010451	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40675	 41617	 0.001239	 0.00425	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40675	 41621	 0.000413	 0.001652	 0.00042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40675	 89370	 0.001115	 0.006857	 0.00198	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40676	 40677	 0.003283	 0.004002	 6e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40676	 89394	 0.02052	 0.015097	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40677	 40684	 0.001958	 0.005416	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40677	 41602	 0.002551	 0.005923	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40678	 40679	 0.005861	 0.004638	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40679	 40680	 0.001831	 0.003849	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40679	 89394	 0.002471	 0.006549	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40680	 40681	 0.002972	 0.004507	 6e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40681	 89128	 0.008131	 0.006373	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40682	 41622	 0.000928	 0.003095	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40682	 89128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40682	 89128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40683	 89394	 0.005878	 0.004324	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40684	 40685	 0.005939	 0.004207	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40684	 89130	 0.001659	 0.007391	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40686	 40687	 0.000458	 0.001937	 0.00044	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40686	 40688	 0.000638	 0.001737	 0.00038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40686	 89262	 0.000701	 0.002892	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40687	 41621	 0.000369	 0.001502	 0.00037	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40687	 89129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40687	 89129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40688	 89130	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40688	 89130	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40688	 89370	 0.000702	 0.00281	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40689	 89131	 0.005749	 0.004156	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40689	 89395	 0.013918	 0.011015	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88858	 40690	 0.000269	 0.001733	 0.00045	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40690	 89131	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40690	 89131	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40691	 40692	 0.002575	 0.002804	 4e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89131	 40691	 0.003993	 0.00313	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40692	 40693	 0.001503	 0.003972	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88859	 40692	 0.001824	 0.004171	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40693	 40694	 0.00201	 0.004666	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40693	 89410	 0.004702	 0.010917	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40694	 40695	 0.001375	 0.002891	 5e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40695	 40696	 0.003291	 0.005544	 8e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40696	 41600	 0.007374	 0.008111	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40697	 89132	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40697	 89132	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40697	 89390	 0.000487	 0.002673	 0.00071	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40698	 40699	 0.003017	 0.007145	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89132	 40698	 0.002175	 0.008158	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40698	 89391	 0.002131	 0.00871	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40699	 40700	 0.013522	 0.013283	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40699	 41583	 0.002776	 0.00662	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40700	 40701	 0.004691	 0.011482	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40700	 41598	 0.018264	 0.013438	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40700	 89406	 0.014314	 0.043912	 0.00119	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40701	 89395	 0.004356	 0.012494	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40702	 41592	 0.004377	 0.002834	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40703	 40707	 0.001212	 0.002481	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40703	 41592	 0.002137	 0.00565	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40704	 41591	 0.008446	 0.005468	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40705	 40711	 0.005777	 0.004528	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40705	 41591	 0.009208	 0.007287	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40706	 41585	 0.004312	 0.007161	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40706	 41598	 0.015288	 0.010829	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40707	 41585	 0.007626	 0.005978	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40707	 41598	 0.005294	 0.010483	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40708	 41608	 0.017407	 0.012807	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40709	 40712	 0.00536	 0.00347	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40709	 41560	 0.015077	 0.011932	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40709	 41566	 0.011343	 0.008977	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40709	 41586	 0.006985	 0.009181	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40709	 41587	 0.00431	 0.004695	 6e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40710	 40711	 0.001654	 0.003242	 5e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40710	 41587	 0.002417	 0.004037	 7e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40711	 40715	 0.008192	 0.00901	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40713	 40725	 0.013348	 0.009821	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40713	 41560	 0.009698	 0.010666	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40713	 41561	 0.010189	 0.006844	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40714	 41560	 0.007871	 0.006229	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40715	 89384	 0.003729	 0.006001	 9e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40716	 40719	 0.002229	 0.004413	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40716	 41558	 0.001337	 0.0034	 5e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40716	 41559	 0.006204	 0.00491	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40717	 40722	 0.007363	 0.005827	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40718	 40719	 0.00318	 0.003497	 5e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40718	 40721	 0.00229	 0.004533	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40719	 40722	 0.00406	 0.010436	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40719	 40736	 0.008375	 0.021298	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40719	 89384	 0.004211	 0.010826	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40720	 40721	 0.003007	 0.005893	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40720	 41557	 0.003114	 0.005596	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40722	 41562	 0.008851	 0.00573	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40722	 41623	 0.002809	 0.005379	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40723	 40724	 0.007433	 0.005373	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40724	 40725	 0.005706	 0.004472	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40726	 40727	 0.004509	 0.004554	 6e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40726	 40736	 0.01309	 0.01036	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40726	 41623	 0.002269	 0.004492	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40727	 40728	 0.005841	 0.004137	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40728	 40729	 0.008543	 0.006761	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40729	 89133	 0.025652	 0.020301	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40730	 40731	 0.005366	 0.005419	 7e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40730	 41563	 0.014955	 0.010594	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40731	 40732	 0.002428	 0.00398	 7e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40732	 41548	 0.005652	 0.004473	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40732	 41549	 0.004049	 0.01041	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40733	 40749	 0.008776	 0.006945	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40733	 41613	 0.00712	 0.007755	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40734	 40739	 0.007262	 0.005747	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40735	 40738	 0.005863	 0.00464	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40736	 40737	 0.005789	 0.004581	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40736	 40738	 0.011508	 0.009107	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40736	 41564	 0.006449	 0.004662	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40738	 40739	 0.005512	 0.00432	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40738	 40743	 0.012097	 0.009482	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40739	 40740	 0.008765	 0.006936	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40740	 89133	 0.006359	 0.007612	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40741	 40744	 0.000827	 0.002185	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40741	 89133	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40741	 89133	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40742	 40743	 0.005202	 0.004117	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89133	 40742	 0.00624	 0.006242	 8e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40744	 41626	 0.000807	 0.00225	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40745	 40746	 0.006255	 0.00495	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40745	 89382	 0.006458	 0.006897	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40746	 41563	 0.012116	 0.008759	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40747	 40748	 0.005867	 0.004316	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40748	 40749	 0.005848	 0.004302	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40748	 40750	 0.010711	 0.007743	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40750	 40751	 0.008969	 0.007098	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40750	 41613	 0.015097	 0.011948	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40750	 89382	 0.007767	 0.012953	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40752	 40936	 0.005528	 0.004333	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40753	 40755	 0.000468	 0.001562	 0.0004	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40753	 40759	 0.00049	 0.001731	 0.00039	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40753	 89134	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40753	 89134	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40754	 40760	 0.007016	 0.005552	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89134	 40754	 0.010314	 0.007456	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40754	 89137	 0.010347	 0.010565	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40755	 41547	 0.001475	 0.003897	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40755	 41626	 0.000718	 0.002003	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40755	 89135	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40755	 89135	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40756	 41546	 0.002654	 0.006822	 0.00169	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40756	 41547	 0.00099	 0.002488	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40756	 89136	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40756	 89136	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40757	 41545	 0.007832	 0.009968	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89136	 40757	 0.012198	 0.009561	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40758	 40762	 0.005888	 0.003812	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89135	 40758	 0.008803	 0.006364	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40758	 89381	 0.032376	 0.02382	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40759	 40761	 0.000403	 0.001066	 0.00025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40759	 40763	 0.001008	 0.002707	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40761	 40763	 0.000545	 0.001565	 0.00038	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40761	 89137	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40761	 89137	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40763	 40782	 0.000517	 0.002328	 0.00062	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40763	 89138	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40763	 89138	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40764	 40780	 0.010945	 0.008292	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89138	 40764	 0.013564	 0.010734	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40765	 40766	 0.01246	 0.009167	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89137	 40765	 0.01095	 0.008056	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40766	 89140	 0.011353	 0.018122	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40767	 40975	 0.005269	 0.013543	 0.00335	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40767	 41546	 0.000654	 0.00218	 0.00055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40767	 89139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40767	 89139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40768	 40770	 0.00389	 0.007703	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89139	 40768	 0.012445	 0.009156	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40768	 89381	 0.003425	 0.008675	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40769	 40771	 0.0135	 0.010355	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40769	 40942	 0.004024	 0.007967	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89139	 40769	 0.001384	 0.006921	 0.00012	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40770	 40771	 0.008906	 0.009796	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40770	 40773	 0.010034	 0.007941	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40771	 41612	 0.012834	 0.009442	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40772	 41544	 0.014995	 0.011867	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40774	 40786	 0.009993	 0.006712	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40775	 40786	 0.007488	 0.011471	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40775	 40793	 0.008396	 0.006644	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40776	 40788	 0.0064	 0.010215	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40776	 89140	 0.003069	 0.007889	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40776	 89381	 0.011687	 0.010472	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40777	 41543	 0.020728	 0.016403	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40778	 40784	 0.009775	 0.007066	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40779	 40782	 0.001181	 0.004053	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40779	 40783	 0.000352	 0.001385	 0.00036	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40780	 40781	 0.006132	 0.006744	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40781	 89140	 0.004285	 0.006839	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40782	 89140	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40782	 89140	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40783	 40791	 0.000572	 0.00229	 0.00058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40784	 41543	 0.006264	 0.00491	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40785	 41543	 0.007368	 0.005775	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40786	 40789	 0.006073	 0.007269	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40786	 40805	 0.006028	 0.012337	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40787	 40790	 0.010986	 0.008083	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40788	 40789	 0.004087	 0.006196	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40790	 89141	 0.008985	 0.015136	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40790	 89144	 0.020558	 0.015769	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40791	 89141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40791	 89141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40792	 40793	 0.010421	 0.008247	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40792	 41544	 0.01296	 0.010159	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40793	 40794	 0.00969	 0.007595	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40794	 40797	 0.008468	 0.008318	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40795	 40979	 0.013256	 0.008582	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40796	 40979	 0.013089	 0.009272	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40797	 40799	 0.005359	 0.009027	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40797	 40805	 0.007894	 0.018328	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40798	 40799	 0.009031	 0.008148	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40798	 40804	 0.007931	 0.008724	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40799	 40800	 0.016373	 0.012834	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40799	 40806	 0.013102	 0.013959	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40800	 40801	 0.008963	 0.008256	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40801	 89142	 0.010371	 0.013631	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40801	 89172	 0.023349	 0.018478	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40802	 40818	 0.000903	 0.002519	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40802	 89142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40802	 89142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40803	 40804	 0.013258	 0.010492	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89142	 40803	 0.011629	 0.00881	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40804	 40817	 0.004438	 0.008787	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40805	 89144	 0.002786	 0.014176	 0.00032	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40806	 40807	 0.019627	 0.01444	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40806	 89144	 0.008168	 0.025936	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40808	 40810	 0.001606	 0.005411	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40808	 40827	 0.004977	 0.013153	 0.00308	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40808	 89143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40808	 89143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89143	 40809	 0.00341	 0.008075	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40809	 89144	 0.007536	 0.013597	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40810	 89144	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40810	 89144	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40810	 89389	 0.003333	 0.009654	 0.00233	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88915	 40811	 0.006051	 0.01198	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40812	 40814	 0.020486	 0.016058	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88915	 40812	 0.00255	 0.006485	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89143	 40812	 0.009394	 0.009488	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40813	 40815	 0.000728	 0.002961	 0.00072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40813	 89145	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40813	 89145	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89145	 40814	 0.010957	 0.008589	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40815	 40816	 0.000557	 0.002359	 0.00053	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88882	 40816	 0.000942	 0.00377	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40817	 89147	 0.0039	 0.013009	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40818	 40821	 0.000808	 0.002099	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40819	 40820	 0.000728	 0.00211	 0.00051	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40819	 40991	 0.000812	 0.002042	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40820	 41350	 0.001401	 0.004807	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40821	 40823	 0.001262	 0.00352	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40822	 89146	 0.01311	 0.010375	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40822	 89147	 0.006411	 0.007958	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40822	 89303	 0.019017	 0.019207	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40823	 41354	 0.001356	 0.003585	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40823	 89146	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40823	 89146	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40824	 40826	 0.001058	 0.003119	 0.00073	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40824	 89147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40824	 89147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40825	 40826	 0.001956	 0.005078	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40825	 41452	 0.001356	 0.003486	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40825	 41455	 0.002465	 0.006515	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40826	 89389	 0.00222	 0.008075	 0.00247	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40827	 41445	 0.003846	 0.013595	 0.00306	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88882	 40827	 0.001278	 0.005276	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40827	 89148	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40827	 89148	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88883	 40828	 0.012258	 0.035159	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40828	 89340	 0.013697	 0.031467	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40829	 40830	 0.000337	 0.001664	 0.00049	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40829	 40839	 0.00056	 0.0022	 0.00058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40830	 40833	 0.000768	 0.004647	 0.00119	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40831	 40832	 0.002201	 0.006312	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40831	 41555	 0.001835	 0.008085	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40832	 40840	 0.004424	 0.008759	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40833	 89149	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40833	 89149	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40833	 89150	 0.000505	 0.003468	 0.00101	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40834	 40837	 2.1e-05	 0.000248	 0.00433	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40834	 41343	 3.7e-05	 0.000372	 0.00612	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40835	 40836	 0.011747	 0.008899	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40835	 41334	 0.019549	 0.01547	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40836	 89160	 0.004442	 0.008796	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40837	 40886	 2.5e-05	 0.000271	 0.00397	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40837	 89150	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40837	 89150	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40838	 40841	 0.001244	 0.00323	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40838	 89151	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40838	 89151	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88865	 40839	 0.001079	 0.004565	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40839	 89152	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40839	 89152	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40840	 40842	 0.00918	 0.006754	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89152	 40840	 0.016541	 0.01309	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40841	 40874	 0.000497	 0.001952	 0.00051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40841	 40879	 0.00209	 0.005524	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40842	 40875	 0.006312	 0.004644	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40843	 40844	 0.001849	 0.007194	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40843	 40859	 0.026893	 0.021283	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40843	 41594	 0.012511	 0.009901	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40843	 89411	 0.008037	 0.013539	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40844	 40845	 0.003248	 0.007539	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40844	 40847	 0.010968	 0.008413	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88866	 40845	 0.004373	 0.011334	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40846	 40848	 0.004483	 0.008877	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89151	 40846	 0.001622	 0.007107	 0.00015	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40847	 40848	 0.006195	 0.006325	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40848	 40849	 0.002717	 0.006985	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40848	 89407	 0.001999	 0.007778	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40849	 40850	 0.001716	 0.00441	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40850	 40859	 0.008358	 0.010878	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40851	 89407	 0.014701	 0.011523	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40852	 40853	 0.008411	 0.005445	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40852	 41594	 0.009093	 0.006108	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40853	 89153	 0.005414	 0.006721	 0.00015	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40854	 41595	 0.000846	 0.002235	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40854	 89153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40854	 89153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40854	 89405	 0.001181	 0.003979	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40855	 41589	 0.007621	 0.008301	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40855	 41592	 0.000998	 0.003492	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40855	 41593	 0.002152	 0.005474	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40855	 89392	 0.004275	 0.011302	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40856	 40857	 0.000461	 0.001218	 0.00029	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40856	 40858	 0.000666	 0.001729	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40856	 41588	 0.001051	 0.002532	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88858	 40856	 0.00087	 0.002495	 0.00061	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40856	 89154	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40856	 89154	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40856	 89409	 0.000872	 0.002263	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40857	 41595	 0.000957	 0.00267	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40858	 41588	 0.000386	 0.001078	 0.00023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40859	 89407	 0.00359	 0.017812	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40860	 40865	 0.008829	 0.006772	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40861	 89384	 0.0092	 0.00618	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40862	 40863	 0.009219	 0.007227	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40862	 40873	 0.011412	 0.008396	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40862	 89406	 0.004613	 0.01055	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40862	 89413	 0.005168	 0.008631	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40863	 40864	 0.005855	 0.004633	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40864	 40865	 0.005858	 0.004636	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40864	 40871	 0.012135	 0.009603	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40865	 40866	 0.002197	 0.004349	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40866	 40867	 0.00195	 0.005594	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40867	 89157	 0.002872	 0.011218	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40868	 40878	 0.006523	 0.005162	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40869	 40870	 0.002198	 0.004352	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40869	 40878	 0.004497	 0.007178	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40869	 40911	 0.011799	 0.009337	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40870	 40871	 0.005134	 0.006748	 9e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40871	 40872	 0.00878	 0.006882	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40871	 40908	 0.012131	 0.00877	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40872	 40873	 0.00585	 0.004586	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40873	 89413	 0.010581	 0.008294	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40874	 40877	 0.000593	 0.002156	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40875	 89155	 0.004079	 0.006183	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40876	 40877	 0.000647	 0.002673	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40876	 40893	 0.000444	 0.001998	 0.00053	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40876	 89155	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40876	 89155	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40877	 40884	 0.000445	 0.001985	 0.00054	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40877	 41628	 0.001372	 0.006764	 0.00183	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40877	 89156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40877	 89156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40878	 40882	 0.002566	 0.00525	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40879	 40881	 0.000653	 0.001892	 0.00046	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40879	 40883	 0.001122	 0.004062	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40879	 41615	 0.000638	 0.001712	 0.00039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40879	 89157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40879	 89157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40879	 89405	 0.002913	 0.010151	 0.00235	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89156	 40880	 0.013293	 0.011911	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40881	 40883	 0.000619	 0.002122	 0.00051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40882	 41554	 0.012212	 0.007906	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89157	 40882	 0.001586	 0.006345	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40882	 89407	 0.019797	 0.015667	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40883	 40884	 0.000516	 0.002009	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40883	 40899	 0.000541	 0.001855	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40884	 89158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40884	 89158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40885	 89161	 0.017069	 0.013509	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40886	 41344	 6.5e-05	 0.000649	 0.01082	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40886	 89159	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40886	 89159	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40887	 40888	 8.5e-05	 0.000583	 0.00105	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40887	 41230	 0.00224	 0.015429	 0.02724	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40887	 41335	 0.000248	 0.001709	 0.00302	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40887	 89160	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40887	 89160	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40888	 89298	 0.000275	 0.001836	 0.00346	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89159	 40889	 0.000467	 0.0016	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40889	 89299	 0.001132	 0.003884	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40890	 40893	 0.000661	 0.004676	 0.00128	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40890	 89161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40890	 89161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40890	 89299	 0.000673	 0.005964	 0.00159	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40891	 40894	 0.001255	 0.007718	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89161	 40891	 0.004646	 0.009957	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40891	 89164	 0.005531	 0.01401	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89156	 40892	 0.004406	 0.007748	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40892	 89162	 0.004095	 0.010527	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40893	 89162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40893	 89162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40894	 40895	 0.004053	 0.01042	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89162	 40894	 0.009082	 0.009084	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40895	 89165	 0.003247	 0.006644	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40896	 40901	 0.000854	 0.003475	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40896	 40945	 0.00094	 0.003573	 0.001	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40896	 89163	 0.000814	 0.00326	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40897	 41344	 8.9e-05	 0.001474	 0.01381	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40897	 89163	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40898	 40899	 0.000404	 0.001068	 0.00025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40898	 40901	 0.000609	 0.002512	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40898	 40902	 0.000322	 0.001289	 0.00032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40899	 40901	 0.000931	 0.003138	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89158	 40900	 0.005272	 0.008881	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40900	 89166	 0.019642	 0.015544	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40901	 89165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40901	 89165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40902	 40907	 0.00152	 0.005214	 0.00125	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40902	 41553	 0.00055	 0.002202	 0.00055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40902	 89166	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40902	 89166	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40903	 40919	 0.003227	 0.00749	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40903	 40920	 0.005866	 0.003797	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89166	 40903	 0.004332	 0.010603	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89166	 40904	 0.004539	 0.003736	 8e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89165	 40905	 0.005182	 0.009635	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40905	 89167	 0.007659	 0.010066	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40906	 40921	 0.00583	 0.014472	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40906	 40944	 0.010613	 0.013948	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40906	 89167	 0.003734	 0.014527	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89163	 40907	 0.000844	 0.005655	 0.00173	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40907	 89167	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40907	 89167	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40908	 40909	 0.00262	 0.004414	 6e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40908	 40926	 0.00342	 0.003652	 8e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40909	 40910	 0.002195	 0.003503	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40910	 40911	 0.002194	 0.004345	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40911	 89168	 0.001724	 0.005069	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40912	 41553	 0.000573	 0.002252	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40912	 89168	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40912	 89168	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89168	 40913	 0.008196	 0.006287	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40914	 40915	 0.002195	 0.003503	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40914	 40917	 0.00691	 0.007379	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89168	 40914	 0.003561	 0.008431	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40915	 40916	 0.002197	 0.004349	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40916	 40927	 0.001608	 0.004133	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89168	 40916	 0.006587	 0.016349	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40917	 40918	 0.001613	 0.004146	 6e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40917	 41552	 0.002585	 0.006645	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40918	 40919	 0.001811	 0.004948	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40919	 40921	 0.00356	 0.00652	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40921	 40922	 0.01002	 0.007854	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40923	 40924	 0.005826	 0.004414	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40924	 40925	 0.011873	 0.008583	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40925	 40930	 0.028949	 0.022692	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40925	 40955	 0.003232	 0.007654	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40925	 40956	 0.008289	 0.016244	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89167	 40925	 0.005226	 0.0255	 0.00044	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40926	 41550	 0.008821	 0.005711	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40927	 40929	 0.003329	 0.007883	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40928	 40929	 0.00395	 0.009804	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40928	 41613	 0.006527	 0.011731	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40929	 40930	 0.011755	 0.009303	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40930	 40931	 0.003601	 0.009158	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40930	 40933	 0.008262	 0.008286	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40930	 41552	 0.002901	 0.005936	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40931	 40934	 0.003148	 0.008093	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40932	 40933	 0.011262	 0.008913	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40934	 40939	 0.004235	 0.008386	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40935	 40936	 0.009921	 0.007777	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40935	 40938	 0.011788	 0.009329	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40935	 41613	 0.004858	 0.009619	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40936	 40937	 0.009963	 0.00781	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40937	 40942	 0.011794	 0.008677	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40937	 41606	 0.014787	 0.011591	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40939	 40940	 0.00501	 0.008037	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40940	 40941	 0.014874	 0.010536	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40940	 40960	 0.016814	 0.015767	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89139	 40943	 0.01044	 0.008262	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40944	 40950	 0.009428	 0.009627	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89167	 40944	 0.004021	 0.010337	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40944	 89170	 0.014027	 0.018436	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40945	 40947	 0.001737	 0.00451	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40945	 40948	 0.000815	 0.003264	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40945	 41345	 0.001542	 0.006174	 0.00156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40945	 89169	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40945	 89169	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89169	 40946	 0.01524	 0.011017	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40947	 41359	 0.00079	 0.001986	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40948	 89170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40948	 89170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89170	 40949	 0.011811	 0.007646	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40951	 40963	 0.00316	 0.014139	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40951	 40967	 0.006827	 0.017549	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89170	 40951	 0.002861	 0.018621	 0.00038	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40952	 40959	 0.012191	 0.009556	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40953	 40954	 0.011793	 0.009333	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40954	 40955	 0.004446	 0.007385	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40956	 40963	 0.008728	 0.007184	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40957	 40958	 0.004974	 0.003596	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40958	 40959	 0.009802	 0.007757	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40958	 40962	 0.004658	 0.009222	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40959	 40960	 0.014336	 0.010548	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40960	 40961	 0.011459	 0.00843	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40960	 40966	 0.015732	 0.012331	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40960	 41612	 0.011647	 0.008569	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89164	 40960	 0.020305	 0.078993	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40961	 40976	 0.021383	 0.016922	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40962	 40963	 0.003469	 0.009949	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40963	 40964	 0.004894	 0.007131	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40964	 89171	 0.015625	 0.012248	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40965	 40976	 0.01248	 0.009877	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40966	 41544	 0.013625	 0.01068	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40967	 40977	 0.004599	 0.009107	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40968	 40969	 0.013459	 0.010324	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40968	 40973	 0.016065	 0.0104	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40968	 89172	 0.011209	 0.014587	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40968	 89304	 0.010595	 0.030387	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40970	 40971	 0.00919	 0.007564	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40970	 40972	 0.006123	 0.010768	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40970	 41358	 0.004869	 0.009324	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40971	 40988	 0.012538	 0.009922	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40972	 40973	 0.00722	 0.01106	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40973	 40987	 0.014219	 0.011253	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40974	 40976	 0.012363	 0.009784	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40975	 40978	 0.001091	 0.003042	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40975	 89171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40975	 89171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40976	 41544	 0.023039	 0.018233	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89171	 40976	 0.004248	 0.008325	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40976	 89304	 0.015749	 0.04469	 0.0007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89171	 40977	 0.003035	 0.00601	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40978	 40980	 0.000821	 0.002064	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40979	 89172	 0.006011	 0.011901	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40980	 40981	 0.000835	 0.002207	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40980	 89172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40980	 89172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40981	 40986	 0.00082	 0.00213	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40982	 89173	 0.015051	 0.01088	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40983	 40984	 0.001083	 0.00302	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40983	 41357	 0.001931	 0.005383	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40984	 40985	 0.000859	 0.002895	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40984	 89173	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40984	 89173	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40985	 41380	 0.001271	 0.003359	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40985	 89174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40985	 89174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40986	 40991	 0.000799	 0.002075	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40987	 40990	 0.013753	 0.013891	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40988	 40989	 0.015787	 0.012493	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89173	 40988	 0.008139	 0.020698	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40990	 89302	 0.00985	 0.019502	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40992	 41158	 0.014055	 0.010341	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40992	 41218	 0.004128	 0.012426	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40992	 89179	 0.004477	 0.019948	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40993	 89180	 0.006791	 0.016856	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40994	 41005	 0.012827	 0.010151	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40995	 89437	 0.013929	 0.020883	 0.00038	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40996	 41111	 0.002929	 0.007529	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40996	 41114	 0.001185	 0.005955	 0.00155	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40996	 41140	 0.003917	 0.010069	 0.00249	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40996	 89175	 0.000382	 0.003786	 0.00116	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40997	 40999	 0.000175	 0.00202	 0.01771	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40997	 41110	 0.000217	 0.002501	 0.02192	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40997	 89175	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40997	 89175	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89175	 40998	 0.00054	 0.00463	 0.00132	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40998	 89176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40998	 89176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40999	 41043	 0.000481	 0.005331	 0.05076	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40999	 41146	 8e-05	 0.000796	 0.01362	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40999	 41235	 0.000303	 0.003446	 0.03112	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40999	 41882	 0.000411	 0.004741	 0.04156	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40999	 89177	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89178	 40999	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41000	 41147	 0.001136	 0.005513	 0.00126	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41000	 41172	 0.001106	 0.002665	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41000	 41174	 0.001039	 0.005385	 0.00131	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41001	 41174	 0.000745	 0.002984	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41001	 41175	 0.000715	 0.005225	 0.00154	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89178	 41001	 0.000712	 0.007869	 0.00236	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41002	 41176	 0.001977	 0.005224	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41002	 41627	 0.002219	 0.007236	 0.00192	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41002	 89179	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41002	 89179	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41003	 41234	 0.00091	 0.003644	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41003	 89180	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41003	 89180	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41004	 89241	 0.0113	 0.014705	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41005	 41219	 0.009912	 0.015034	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89180	 41005	 0.00664	 0.025832	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41006	 41007	 0.019509	 0.015292	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41007	 41008	 0.011012	 0.02498	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41007	 41020	 0.014465	 0.034254	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41007	 41029	 0.027388	 0.030124	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41007	 42317	 0.008538	 0.033213	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41008	 41013	 0.011371	 0.020438	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41009	 41010	 0.006889	 0.012618	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41009	 41017	 0.020831	 0.041243	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41010	 41012	 0.025186	 0.019932	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41010	 41013	 0.006603	 0.013511	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41011	 41016	 0.021939	 0.014737	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41012	 41014	 0.00819	 0.013073	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41013	 41031	 0.011887	 0.021772	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41014	 41019	 0.003332	 0.008831	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41014	 41178	 0.031903	 0.025248	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41015	 41178	 0.026343	 0.020848	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41016	 41203	 0.007905	 0.018352	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41017	 41018	 0.008202	 0.008226	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41018	 41201	 0.014966	 0.015116	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41019	 41199	 0.0045	 0.02005	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41020	 89181	 0.010398	 0.037144	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41021	 89181	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41021	 89181	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41021	 89185	 0.001347	 0.011327	 0.00335	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41022	 41025	 0.004033	 0.014911	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41022	 89186	 0.007209	 0.042042	 0.00084	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41023	 41024	 0.012311	 0.018858	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89181	 41023	 0.007057	 0.016383	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41024	 41027	 0.007248	 0.02392	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41024	 89186	 0.004955	 0.034013	 0.00062	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41025	 41033	 0.008437	 0.013467	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41025	 41034	 0.019342	 0.025421	 0.00035	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41026	 41028	 0.0108	 0.021382	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41026	 41037	 0.006848	 0.019433	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89181	 41026	 0.011034	 0.045096	 0.00091	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41027	 41028	 0.004831	 0.013709	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41029	 41030	 0.039829	 0.028213	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41030	 41037	 0.013817	 0.014755	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41030	 89237	 0.037759	 0.074761	 0.0011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41031	 41036	 0.003971	 0.013566	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41032	 41033	 0.019282	 0.015259	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41032	 41035	 0.024665	 0.01783	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41032	 41037	 0.020789	 0.022865	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41032	 41148	 0.005494	 0.014124	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41034	 41163	 0.004816	 0.009897	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41035	 41036	 0.016469	 0.021433	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41035	 41149	 0.007782	 0.015251	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41036	 89238	 0.004954	 0.023677	 0.00052	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41038	 89186	 0.015479	 0.030336	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41038	 89662	 0.012973	 0.021549	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41039	 89182	 0.01447	 0.00972	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41040	 89182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41040	 89182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41040	 89183	 0.00159	 0.004277	 0.0012	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41041	 41060	 0.021991	 0.020622	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41041	 41062	 0.009407	 0.018625	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41041	 89184	 0.003089	 0.013765	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41042	 41043	 9.3e-05	 0.001036	 0.00977	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41042	 42250	 0.000526	 0.008755	 0.09248	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41042	 89183	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41043	 89185	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89186	 41044	 0.021706	 0.016445	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41045	 41046	 0.017677	 0.015108	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41045	 41048	 0.011995	 0.015764	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41045	 41050	 0.021053	 0.014142	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89186	 41045	 0.008091	 0.02699	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41045	 89187	 0.037513	 0.029687	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41046	 41047	 0.007726	 0.015298	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41046	 41050	 0.029734	 0.023531	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41047	 41053	 0.047801	 0.030946	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41047	 41054	 0.01759	 0.017961	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41047	 41057	 0.03793	 0.025478	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41047	 41062	 0.017666	 0.01583	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41048	 41049	 0.013527	 0.010376	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89186	 41048	 0.007061	 0.020253	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41050	 89187	 0.019641	 0.015396	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41051	 41167	 0.00295	 0.007796	 0.00182	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89185	 41051	 0.003967	 0.013608	 0.00326	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41051	 89187	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41051	 89187	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41052	 41053	 0.024123	 0.017438	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41052	 41054	 0.02755	 0.021595	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41053	 41068	 0.009295	 0.023893	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41053	 41136	 0.02381	 0.018843	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41053	 41138	 0.008229	 0.017634	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41053	 89219	 0.013708	 0.04031	 0.00083	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41054	 41065	 0.005906	 0.013986	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41055	 41059	 0.006846	 0.012304	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41055	 41063	 0.015102	 0.01243	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41055	 41073	 0.005618	 0.017253	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89184	 41055	 0.032804	 0.050252	 0.00071	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41056	 41057	 0.022028	 0.017432	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41057	 41063	 0.013941	 0.015334	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41057	 41064	 0.009163	 0.023555	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41058	 41060	 0.016539	 0.012964	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41058	 42296	 0.020138	 0.015937	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89186	 41061	 0.025639	 0.016599	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41064	 41074	 0.005298	 0.01362	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41065	 41066	 0.003773	 0.009698	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41066	 41067	 0.014221	 0.01667	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41066	 89191	 0.006408	 0.018379	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41067	 41069	 0.005171	 0.013293	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41069	 89217	 0.00942	 0.02338	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41070	 41076	 0.001731	 0.006932	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41070	 41079	 0.001476	 0.008644	 0.00235	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41070	 41092	 0.002049	 0.007972	 0.00213	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41070	 89188	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41070	 89188	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41071	 41072	 0.000637	 0.003316	 0.00087	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41071	 41079	 0.000841	 0.003923	 0.00097	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41072	 89189	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41072	 89189	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41073	 41077	 0.006553	 0.011825	 0.00017	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89189	 41073	 0.002709	 0.011309	 0.00033	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89189	 41074	 0.005713	 0.013064	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41075	 42285	 0.036508	 0.045318	 0.00099	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41075	 42288	 0.025484	 0.025491	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41075	 89190	 0.026705	 0.021134	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41076	 41079	 0.00107	 0.004353	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41076	 89190	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41076	 89190	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41077	 41078	 0.011346	 0.008979	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41079	 41080	 0.00114	 0.003911	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41080	 41088	 0.00153	 0.005247	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89189	 41081	 0.007336	 0.024472	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41081	 89191	 0.006592	 0.018907	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89183	 41082	 0.007819	 0.021287	 0.00469	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41082	 89191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41082	 89191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41082	 89203	 0.004337	 0.015706	 0.00337	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41083	 41084	 0.004623	 0.00946	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89191	 41083	 0.009175	 0.018165	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41084	 41090	 0.007106	 0.016497	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41084	 89217	 0.008877	 0.014825	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89188	 41085	 0.008234	 0.032033	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41085	 89192	 0.008406	 0.021785	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41086	 41087	 0.004571	 0.02572	 0.00056	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89188	 41086	 0.007483	 0.021462	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41086	 89193	 0.002496	 0.013356	 0.0004	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41087	 89204	 0.008262	 0.040334	 0.00085	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41088	 89192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41088	 89192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41088	 89203	 0.003809	 0.010227	 0.00232	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41089	 41090	 0.004635	 0.010977	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89192	 41089	 0.004407	 0.013992	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41089	 89204	 0.01711	 0.021239	 0.00046	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41091	 41092	 0.001348	 0.010445	 0.00366	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41091	 42442	 0.005002	 0.020026	 0.00505	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41092	 89193	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41092	 89193	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41093	 41095	 0.000743	 0.003467	 0.00086	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41093	 41097	 0.00154	 0.007873	 0.00215	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41093	 89194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41093	 89194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41094	 89200	 0.02336	 0.021907	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41095	 41096	 0.000458	 0.00293	 0.00099	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41095	 41122	 0.000498	 0.004	 0.00112	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41096	 41103	 0.000994	 0.006174	 0.00174	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41096	 41107	 0.000273	 0.002617	 0.00076	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41096	 41131	 0.000818	 0.004403	 0.00121	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41097	 41098	 0.0009	 0.007353	 0.002	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41097	 89195	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41097	 89195	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41097	 89199	 0.001572	 0.009756	 0.00236	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41099	 41100	 0.015795	 0.012381	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41099	 41101	 0.027844	 0.022035	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88920	 41099	 0.013971	 0.046608	 0.00074	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41100	 41101	 0.012231	 0.008999	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41100	 89196	 0.044299	 0.03398	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41101	 89196	 0.025527	 0.023513	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41102	 42055	 0.001843	 0.005138	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88890	 41102	 0.001438	 0.00469	 0.00125	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41102	 89196	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41102	 89196	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41103	 89197	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41103	 89197	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41103	 89199	 0.001762	 0.010833	 0.00312	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41104	 41106	 0.000705	 0.0036	 0.00091	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41104	 41107	 0.000712	 0.006106	 0.00174	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41104	 41713	 0.003158	 0.01285	 0.00313	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41104	 89198	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41104	 89198	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41104	 89199	 0.000663	 0.006576	 0.00179	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41105	 41732	 0.00049	 0.005696	 0.04924	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41105	 89199	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41105	 89199	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41106	 41107	 0.000638	 0.003147	 0.00085	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41107	 41108	 0.00055	 0.002716	 0.00079	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41107	 89200	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41107	 89200	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41108	 41129	 0.001336	 0.005347	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41108	 89201	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41108	 89201	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41109	 41718	 0.002961	 0.010115	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89201	 41109	 0.001726	 0.006614	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41110	 89202	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41111	 41112	 0.001207	 0.004371	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41112	 41685	 0.002171	 0.007448	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41113	 89205	 0.02125	 0.016817	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41113	 89215	 0.017041	 0.025846	 0.00037	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41114	 41115	 0.000591	 0.003076	 0.00081	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41115	 41116	 0.000627	 0.003372	 0.00083	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41116	 41135	 0.000585	 0.003212	 0.00085	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89195	 41117	 0.007773	 0.041901	 0.00084	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41117	 89207	 0.005498	 0.024223	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41118	 41119	 0.006318	 0.010551	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41118	 89210	 0.006485	 0.013272	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41119	 89209	 0.01412	 0.01274	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41120	 41121	 0.000582	 0.00425	 0.00109	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41120	 41126	 0.00051	 0.002801	 0.00074	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89203	 41120	 0.000522	 0.007381	 0.00244	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41120	 89205	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41120	 89205	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41121	 41127	 0.00089	 0.003561	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41121	 41133	 0.000713	 0.003018	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41121	 89206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41121	 89206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41122	 41123	 0.000201	 0.002219	 0.00067	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41122	 89207	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41122	 89207	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41123	 41127	 0.000505	 0.003032	 0.00092	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41123	 89208	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41123	 89208	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41124	 41125	 0.016637	 0.013166	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89205	 41124	 0.025309	 0.018296	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41124	 89209	 0.004556	 0.011712	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41126	 41127	 0.000544	 0.003344	 0.00096	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41126	 89209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41126	 89209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41127	 89210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41127	 89210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41128	 41135	 0.001443	 0.004863	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41128	 41685	 0.003138	 0.012563	 0.00317	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41128	 41695	 0.002181	 0.008572	 0.00224	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41128	 41697	 0.002079	 0.005582	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41128	 89211	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41128	 89211	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41129	 41695	 0.001138	 0.004699	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89194	 41130	 0.004895	 0.026957	 0.00061	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89207	 41130	 0.011007	 0.019861	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89211	 41130	 0.006337	 0.030416	 0.00091	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41130	 89212	 0.002688	 0.013599	 0.00024	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41130	 89213	 0.00473	 0.013565	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41131	 41132	 0.000531	 0.003262	 0.00094	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41131	 89212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41131	 89212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41132	 41134	 0.0005	 0.003993	 0.00098	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41132	 89213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41132	 89213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41133	 41134	 0.000585	 0.002991	 0.00082	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41133	 41135	 0.000648	 0.004023	 0.00097	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41134	 89214	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41134	 89214	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41135	 89215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41135	 89215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41136	 89219	 0.009976	 0.03328	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41137	 89216	 0.024044	 0.015566	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41137	 89219	 0.013089	 0.020051	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41138	 89216	 0.003985	 0.015503	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41139	 89216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41139	 89216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41139	 89218	 0.001039	 0.003764	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89203	 41140	 0.002496	 0.008325	 0.00211	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41140	 89217	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41140	 89217	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89217	 41141	 0.007665	 0.01348	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41142	 41143	 0.011293	 0.011406	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41142	 41144	 0.020871	 0.015356	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89176	 41142	 0.004593	 0.020466	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41143	 41144	 0.010164	 0.01557	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89216	 41143	 0.004265	 0.013541	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41144	 41145	 0.012678	 0.010033	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41146	 41609	 0.000862	 0.009454	 0.09185	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41146	 89218	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89178	 41147	 0.000749	 0.004823	 0.00126	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41147	 89220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41147	 89220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41148	 89222	 0.003993	 0.013972	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41149	 41151	 0.006024	 0.011927	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41149	 89238	 0.015184	 0.023261	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41150	 41151	 0.002947	 0.00603	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41150	 41153	 0.026525	 0.019175	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41150	 89222	 0.005431	 0.011595	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41152	 41153	 0.014158	 0.0143	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41152	 41154	 0.00812	 0.017973	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41152	 89222	 0.02577	 0.020394	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41153	 41194	 0.017668	 0.013982	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41154	 41155	 0.006411	 0.012694	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41154	 41160	 0.001291	 0.00886	 0.00016	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41154	 89221	 0.017117	 0.017478	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41156	 41157	 0.004211	 0.012917	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41157	 89227	 0.003913	 0.013699	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41159	 41160	 0.005121	 0.014689	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41159	 89226	 0.00386	 0.012878	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41160	 89227	 0.0063	 0.024509	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41161	 41164	 0.002528	 0.014367	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41161	 41173	 0.004202	 0.014019	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41161	 89225	 0.007023	 0.022522	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41162	 41166	 0.001178	 0.004476	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41162	 41175	 0.002002	 0.008146	 0.00198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41162	 89221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41162	 89221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41163	 41165	 0.003709	 0.011894	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41164	 41165	 0.003401	 0.01323	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89221	 41165	 0.009766	 0.017444	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41166	 41197	 0.003463	 0.009427	 0.00208	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41166	 89222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41166	 89222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41167	 41172	 0.000851	 0.002839	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89218	 41167	 0.001166	 0.009087	 0.00272	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41167	 89223	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41167	 89223	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89187	 41168	 0.025415	 0.020113	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89223	 41168	 0.02088	 0.01479	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89223	 41169	 0.012834	 0.025411	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89223	 41170	 0.004324	 0.008848	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41170	 89224	 0.00527	 0.009509	 0.00014	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41171	 41172	 0.000851	 0.002837	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41171	 89224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41171	 89224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89224	 41173	 0.00155	 0.010642	 0.00019	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41173	 89226	 0.007542	 0.013557	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41174	 41176	 0.001321	 0.00529	 0.00133	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41174	 89225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41174	 89225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41175	 89226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41175	 89226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41176	 89227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41176	 89227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41177	 41182	 0.00206	 0.009075	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41177	 41203	 0.002554	 0.008519	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41178	 41203	 0.00696	 0.01789	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41178	 89228	 0.004705	 0.026436	 0.00049	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41179	 41181	 0.005199	 0.010639	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41179	 41183	 0.005555	 0.012763	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41180	 41181	 0.019904	 0.012886	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41181	 41198	 0.008305	 0.013257	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41181	 89228	 0.006487	 0.012713	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41181	 89229	 0.024898	 0.024056	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41182	 41183	 0.001696	 0.007516	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41183	 89229	 0.001893	 0.012993	 0.00024	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41184	 89228	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41184	 89228	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41184	 89230	 0.003004	 0.008378	 0.00176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41184	 89236	 0.001906	 0.006641	 0.00154	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41185	 41189	 0.002444	 0.006458	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41185	 89229	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41185	 89229	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41185	 89230	 0.001237	 0.003865	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89229	 41186	 0.004379	 0.008483	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41186	 89231	 0.003446	 0.008858	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41187	 41193	 0.000213	 0.002414	 0.02198	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41187	 41537	 0.000452	 0.005118	 0.0466	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41187	 42250	 0.000779	 0.014134	 0.14134	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41187	 89230	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89228	 41188	 0.021021	 0.016477	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89229	 41188	 0.021023	 0.016638	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41188	 89232	 0.010298	 0.011326	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41189	 89232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41189	 89232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41189	 89234	 0.001106	 0.005647	 0.00142	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41190	 41191	 0.01671	 0.01266	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89232	 41190	 0.006929	 0.017812	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89230	 41192	 0.000389	 0.004442	 0.00124	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41192	 89233	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41192	 89233	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41193	 41195	 9.3e-05	 0.001021	 0.00992	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41193	 41235	 0.00025	 0.0035	 0.06713	 1646.0	 1728.3	 1810.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41193	 89234	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41194	 89237	 0.005057	 0.012999	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41195	 89236	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89228	 41196	 0.014454	 0.011439	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89236	 41197	 0.001181	 0.004729	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41197	 89238	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41197	 89238	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89237	 41198	 0.007247	 0.018431	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89238	 41198	 0.024433	 0.015818	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89238	 41199	 0.002415	 0.013728	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41200	 41201	 0.005742	 0.011751	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41200	 41206	 0.004993	 0.009886	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41200	 41207	 0.005019	 0.009021	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41200	 89240	 0.009765	 0.034167	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41202	 41203	 0.011061	 0.007161	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41203	 41204	 0.003059	 0.01045	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41204	 41205	 0.00264	 0.008108	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41205	 41208	 0.007614	 0.012413	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41205	 41209	 0.009736	 0.009834	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41207	 41208	 0.004309	 0.006878	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41207	 41212	 0.005349	 0.009797	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41208	 41210	 0.005108	 0.014649	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41209	 41210	 0.004414	 0.008739	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41210	 89240	 0.00211	 0.01297	 0.00023	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41211	 41214	 0.01188	 0.00798	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41212	 41213	 0.004127	 0.010609	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41213	 89239	 0.002581	 0.008275	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41214	 89239	 0.0085	 0.009349	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41215	 41216	 0.00053	 0.003873	 0.001	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41215	 89239	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41215	 89239	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89230	 41216	 0.000415	 0.004113	 0.00126	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41216	 89240	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41216	 89240	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89240	 41217	 0.010602	 0.007664	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41219	 89241	 0.007752	 0.012436	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41220	 41221	 0.000621	 0.003233	 0.00085	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41220	 41233	 0.002605	 0.012843	 0.00347	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41220	 89241	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41220	 89241	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41221	 89242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41221	 89242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41222	 41224	 0.003194	 0.00821	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41223	 41224	 0.00352	 0.008952	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41223	 89243	 0.003391	 0.011312	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41224	 89244	 0.002504	 0.012082	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41225	 41226	 0.000385	 0.002005	 0.00053	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41226	 41238	 0.000904	 0.003619	 0.00122	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41226	 89243	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41226	 89243	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41227	 41228	 0.000671	 0.002441	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41227	 89244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41227	 89244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41228	 89245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41228	 89245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41228	 89247	 0.000336	 0.003223	 0.00094	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41229	 41232	 0.000687	 0.003274	 0.00095	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41229	 41237	 0.001056	 0.004753	 0.00126	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41229	 89246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41229	 89246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41230	 89247	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41230	 89247	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41230	 89248	 0.000536	 0.004398	 0.00792	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41231	 41232	 0.000461	 0.002117	 0.00054	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41231	 41233	 0.000484	 0.002159	 0.00059	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41233	 41234	 0.000317	 0.00257	 0.00082	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41233	 89249	 0.000664	 0.006716	 0.00197	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41235	 89248	 8.1e-05	 0.006451	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41236	 41682	 0.001619	 0.005454	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89249	 41236	 0.001574	 0.004713	 0.00106	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41237	 41293	 0.000858	 0.003541	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89249	 41237	 0.002387	 0.008188	 0.00196	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41238	 41239	 0.000613	 0.003593	 0.00098	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41238	 89251	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41238	 89251	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41239	 41303	 0.000745	 0.006349	 0.00158	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41239	 89252	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41239	 89252	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41240	 41244	 0.006518	 0.012483	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89121	 41240	 0.007691	 0.008213	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41241	 41244	 0.006061	 0.010067	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41241	 41245	 0.012649	 0.017929	 0.00037	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89117	 41241	 0.005665	 0.010376	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41242	 41243	 0.012828	 0.009719	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41242	 41244	 0.001832	 0.009161	 0.00016	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41242	 89254	 0.002377	 0.006816	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41242	 89255	 0.004425	 0.013589	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89251	 41243	 0.021941	 0.017364	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41245	 89253	 0.003492	 0.007146	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41245	 89373	 0.023087	 0.035015	 0.0005	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41246	 41251	 0.000385	 0.00207	 0.00051	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41246	 89253	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41246	 89253	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41247	 41249	 0.000574	 0.001647	 0.00041	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41247	 41251	 0.001067	 0.002771	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41248	 41284	 0.0033	 0.005932	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41248	 89254	 0.003123	 0.004785	 7e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41249	 41250	 0.000603	 0.001966	 0.00052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41249	 89254	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41249	 89254	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41250	 41286	 0.001602	 0.006296	 0.00165	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41250	 89255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41250	 89255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41251	 41273	 0.002034	 0.007089	 0.00164	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41251	 89256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41251	 89256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41252	 41270	 0.012593	 0.009966	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89255	 41252	 0.00761	 0.015066	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89256	 41252	 0.006977	 0.00888	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41253	 41271	 0.00552	 0.009206	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89255	 41253	 0.011903	 0.007706	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41254	 41259	 0.000618	 0.002153	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41254	 41526	 0.000784	 0.002073	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41254	 89257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41254	 89257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41255	 41261	 0.007256	 0.01329	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89257	 41255	 0.004403	 0.008064	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41256	 41258	 0.000499	 0.001996	 0.0005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41256	 41526	 0.0008	 0.003144	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41256	 89258	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41256	 89258	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41257	 41270	 0.004703	 0.009217	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41257	 41274	 0.001173	 0.004653	 0.00013	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89258	 41257	 0.005894	 0.007606	 0.00015	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41257	 89259	 0.014713	 0.011643	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41258	 41269	 0.001763	 0.007056	 0.00178	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41258	 89259	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41258	 89259	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41259	 41262	 0.000489	 0.001901	 0.00051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41259	 89260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41259	 89260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41260	 41261	 0.008638	 0.006244	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89129	 41261	 0.007751	 0.012874	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41261	 89261	 0.010107	 0.018166	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41262	 41265	 0.000624	 0.002373	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41263	 41264	 0.006031	 0.006345	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41263	 89261	 0.002599	 0.006156	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41265	 41268	 0.00063	 0.004227	 0.00102	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41265	 89261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41265	 89261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41266	 41342	 5.3e-05	 0.000892	 0.01617	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41266	 41517	 7.1e-05	 0.00082	 0.00719	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41266	 41609	 0.000217	 0.002667	 0.0274	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41266	 89262	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89261	 41267	 0.004447	 0.009346	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41267	 89264	 0.003381	 0.008691	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41268	 89264	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41268	 89264	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41268	 89296	 0.000393	 0.003258	 0.00086	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41269	 41279	 0.000783	 0.003078	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41269	 89265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41269	 89265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41269	 89296	 0.000372	 0.003194	 0.00091	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89255	 41271	 0.024194	 0.018964	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41271	 89266	 0.004814	 0.012725	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41271	 89267	 0.016097	 0.012196	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41272	 41273	 0.000415	 0.001979	 0.00057	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41272	 41282	 0.000954	 0.006977	 0.00206	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41272	 89266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41272	 89266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41273	 89267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41273	 89267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41274	 41275	 0.003063	 0.008785	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89267	 41274	 0.003935	 0.007791	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41275	 41276	 0.005626	 0.011138	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41275	 41277	 0.01764	 0.01396	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89266	 41275	 0.01567	 0.01202	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89265	 41276	 0.004308	 0.012224	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89267	 41276	 0.009502	 0.016711	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41276	 89268	 0.005384	 0.015441	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41277	 41278	 0.003565	 0.009065	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89266	 41277	 0.016657	 0.013182	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89265	 41278	 0.026135	 0.020683	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41278	 89268	 0.002154	 0.007542	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41279	 89268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41279	 89268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41279	 89296	 0.000916	 0.003668	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41280	 89269	 0.007749	 0.019919	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41280	 89270	 0.008619	 0.01847	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41281	 89269	 0.017312	 0.013701	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41282	 41319	 0.000443	 0.004546	 0.00144	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41282	 89269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41282	 89269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41283	 41314	 0.011406	 0.007384	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41284	 41285	 0.003751	 0.008008	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89252	 41284	 0.014297	 0.011315	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41285	 89270	 0.003629	 0.015987	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41286	 89270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41286	 89270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41286	 89277	 0.001425	 0.008185	 0.00232	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89243	 41287	 0.007933	 0.022752	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41287	 89271	 0.004777	 0.012627	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41288	 41291	 0.000967	 0.003257	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89247	 41288	 0.001322	 0.003688	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41289	 41290	 0.000784	 0.002072	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41289	 41291	 0.001088	 0.002796	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41290	 41299	 0.000991	 0.0034	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41290	 89271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41290	 89271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41291	 41296	 0.001085	 0.003656	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41291	 89272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41291	 89272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89246	 41292	 0.020861	 0.016509	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89272	 41292	 0.002912	 0.006945	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41292	 89273	 0.010372	 0.029747	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41293	 41295	 0.001294	 0.005033	 0.00134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41294	 41297	 0.002494	 0.008319	 0.00211	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41294	 41309	 0.001911	 0.005329	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41294	 41782	 0.001114	 0.004848	 0.00138	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41294	 89273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41294	 89273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41295	 41309	 0.000798	 0.003245	 0.00079	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41296	 41297	 0.000658	 0.003411	 0.00083	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41297	 41298	 0.000782	 0.002727	 0.00063	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41297	 41308	 0.000788	 0.003613	 0.00093	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41298	 41299	 0.000544	 0.002751	 0.00077	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41298	 89277	 0.001302	 0.006354	 0.00175	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41299	 89274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41299	 89274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89271	 41300	 0.005317	 0.011395	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89274	 41300	 0.002037	 0.004658	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41301	 41302	 0.007782	 0.012421	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89271	 41301	 0.004848	 0.009013	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41302	 89275	 0.008317	 0.01274	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41303	 41305	 0.000412	 0.003364	 0.00091	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41303	 89275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41303	 89275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89275	 41304	 0.006733	 0.010207	 0.00021	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41304	 89276	 0.006178	 0.015881	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41305	 89276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41305	 89276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41305	 89277	 0.000366	 0.002991	 0.00081	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41306	 41333	 0.000227	 0.00286	 0.04358	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41306	 41342	 0.000304	 0.003513	 0.0308	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41306	 89277	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41307	 41308	 0.000875	 0.003559	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41307	 41309	 0.003557	 0.00955	 0.00216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41307	 41311	 0.001146	 0.003824	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41307	 41312	 0.001491	 0.00586	 0.00153	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41307	 41313	 0.001394	 0.003683	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89277	 41307	 0.001005	 0.003024	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41308	 89279	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41308	 89279	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41309	 41796	 0.001187	 0.00854	 0.00226	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89277	 41309	 0.004192	 0.01108	 0.00259	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41310	 41311	 0.001405	 0.003261	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41310	 41782	 0.003741	 0.009888	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89277	 41310	 0.002885	 0.010055	 0.00233	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41310	 89280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41310	 89280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41311	 41312	 0.001031	 0.003733	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41312	 41325	 0.00202	 0.00794	 0.00208	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41313	 41315	 0.00172	 0.003993	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41313	 41322	 0.002204	 0.007681	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89277	 41313	 0.00128	 0.004391	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89278	 41314	 0.036859	 0.027118	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41314	 89281	 0.005399	 0.01069	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41315	 41320	 0.001021	 0.003099	 0.00068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41315	 89281	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41315	 89281	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89281	 41316	 0.014999	 0.01187	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41316	 89284	 0.008053	 0.013376	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41317	 89286	 0.022873	 0.018102	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41318	 41334	 0.014316	 0.022851	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89269	 41318	 0.004583	 0.015122	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41318	 89282	 0.006383	 0.014818	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41319	 89282	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41319	 89282	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41319	 89290	 0.001226	 0.01051	 0.00299	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41320	 41321	 0.000525	 0.00222	 0.0005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41320	 89283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41320	 89283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41321	 41323	 0.001037	 0.003943	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41322	 41330	 0.00165	 0.005662	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41322	 89284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41322	 89284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41323	 41324	 0.00071	 0.003003	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41323	 89285	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41323	 89285	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41324	 41325	 0.000902	 0.003547	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41325	 41327	 0.000388	 0.00287	 0.00083	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41325	 41328	 0.00076	 0.004454	 0.00121	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41325	 89286	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41325	 89286	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41326	 41331	 0.012168	 0.02187	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41326	 89287	 0.005929	 0.017006	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41327	 41328	 0.000207	 0.001654	 0.00041	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41328	 41805	 0.000914	 0.004651	 0.00169	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41328	 41806	 0.000296	 0.002457	 0.00065	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41328	 89287	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41328	 89287	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41329	 41806	 0.001969	 0.007885	 0.00199	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41329	 41807	 0.000476	 0.004324	 0.00141	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41329	 89290	 0.001518	 0.011375	 0.00277	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41330	 89288	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41330	 89288	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41330	 89290	 0.001046	 0.006231	 0.00164	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41331	 89291	 0.034027	 0.026672	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41332	 41831	 0.00071	 0.00705	 0.00192	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41332	 89290	 0.001371	 0.011534	 0.00342	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41333	 41343	 0.000219	 0.002214	 0.03644	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41333	 41343	 0.000219	 0.002214	 0.03644	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41333	 41884	 0.000735	 0.00802	 0.07875	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41333	 89289	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41333	 89289	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41334	 89292	 0.004746	 0.0122	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89289	 41335	 0.000323	 0.002844	 0.00593	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41335	 89292	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41335	 89292	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41335	 89295	 0.000378	 0.004566	 0.00961	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41336	 41344	 6.7e-05	 0.001086	 0.01695	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41336	 41400	 0.000307	 0.005681	 0.05458	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41336	 89293	 0.000104	 0.008333	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41337	 41346	 0.000199	 0.00158	 0.00304	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89293	 41337	 5.5e-05	 0.000595	 0.0024	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41337	 89298	 0.000178	 0.002497	 0.00479	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89291	 41338	 0.035263	 0.027906	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89294	 41339	 0.014062	 0.015466	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41340	 41341	 0.028797	 0.018643	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41340	 41391	 0.003925	 0.015268	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89294	 41340	 0.006576	 0.025584	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41342	 41343	 4.1e-05	 0.000417	 0.00686	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41342	 41343	 4.1e-05	 0.000417	 0.00686	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41342	 41517	 0.000138	 0.001718	 0.01725	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41342	 89295	 6.8e-05	 0.005405	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89296	 41342	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41343	 89297	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41343	 89297	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41344	 41379	 0.000285	 0.004908	 0.04846	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41344	 41387	 0.000398	 0.004525	 0.04086	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41344	 41387	 0.000398	 0.004525	 0.04086	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41344	 41614	 0.000244	 0.00323	 0.06909	 1646.0	 1728.3	 1810.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41344	 89298	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41344	 89298	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89299	 41344	 0.000112	 0.008969	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 0	 -30.0	 30.0;
	41345	 41349	 0.001267	 0.003402	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89299	 41345	 0.000706	 0.005076	 0.00134	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41345	 89300	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41345	 89300	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41346	 41347	 8.7e-05	 0.000885	 0.00281	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41346	 41392	 0.000627	 0.00833	 0.01779	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41347	 41582	 0.002574	 0.018053	 0.03074	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89298	 41347	 0.000258	 0.002297	 0.00404	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41347	 89301	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41347	 89301	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89300	 41348	 0.006859	 0.017777	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89301	 41348	 0.004933	 0.01268	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41349	 41366	 0.002879	 0.007728	 0.00175	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41350	 41351	 0.001222	 0.00426	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41350	 89302	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41350	 89302	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41351	 41382	 0.002006	 0.006881	 0.00165	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41351	 41457	 0.001997	 0.005278	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41352	 41353	 0.009405	 0.007214	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89302	 41352	 0.007959	 0.013407	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89146	 41353	 0.0179	 0.013169	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41354	 41456	 0.001702	 0.004376	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41354	 89303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41354	 89303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41354	 89310	 0.005563	 0.019662	 0.00443	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41355	 89304	 0.006396	 0.012089	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41356	 89304	 0.003829	 0.012158	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41356	 89305	 0.002937	 0.013085	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41357	 89304	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41357	 89304	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89304	 41358	 0.003086	 0.008756	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41359	 41361	 0.001077	 0.002499	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41360	 41362	 0.004666	 0.00955	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41360	 89305	 0.004818	 0.010928	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41361	 41370	 0.001762	 0.00473	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41361	 89305	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41361	 89305	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41362	 41363	 0.004197	 0.008589	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89301	 41363	 0.004922	 0.014117	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41364	 89306	 0.007909	 0.011524	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41364	 89308	 0.006376	 0.0134	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41365	 41373	 0.010779	 0.008449	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41365	 41389	 0.017509	 0.017878	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41365	 89308	 0.02634	 0.020845	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41366	 41367	 0.001056	 0.002791	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41366	 41374	 0.002464	 0.006708	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41366	 89306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41366	 89306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41367	 41368	 0.001091	 0.00297	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41368	 41371	 0.001183	 0.003592	 0.00079	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41368	 41375	 0.000763	 0.00356	 0.00088	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41368	 89309	 0.000775	 0.006109	 0.00179	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41369	 41372	 0.014098	 0.018528	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89305	 41369	 0.005589	 0.008922	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41370	 41371	 0.001305	 0.003281	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41370	 89307	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41370	 89307	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89174	 41372	 0.00486	 0.013941	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89307	 41372	 0.003719	 0.009559	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41373	 41389	 0.016714	 0.015674	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41374	 41376	 0.001475	 0.005058	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41374	 89308	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41374	 89308	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41375	 41377	 0.001054	 0.003516	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41375	 41395	 0.001432	 0.007633	 0.00214	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41376	 41395	 0.000515	 0.002872	 0.00073	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41376	 89309	 0.001519	 0.009186	 0.00234	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41377	 41395	 0.00144	 0.00586	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41378	 41379	 6.7e-05	 0.001196	 0.0124	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41378	 41387	 6.3e-05	 0.000653	 0.01016	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41378	 41387	 6.3e-05	 0.000653	 0.01016	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41378	 41387	 6.3e-05	 0.000653	 0.01016	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41378	 89309	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41378	 89309	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41379	 89310	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89309	 41380	 0.001649	 0.005971	 0.00128	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89174	 41381	 0.022075	 0.01747	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41381	 89312	 0.02732	 0.019749	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41382	 41417	 0.002031	 0.007078	 0.00164	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89310	 41382	 0.001018	 0.005767	 0.00143	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41382	 89312	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41382	 89312	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89302	 41383	 0.002094	 0.00767	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89312	 41383	 0.00185	 0.010518	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41384	 41419	 0.009031	 0.025628	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41384	 89313	 0.008106	 0.019194	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89311	 41385	 0.011704	 0.015968	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41385	 89331	 0.020171	 0.015811	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41386	 41387	 4.7e-05	 0.000497	 0.00743	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41386	 41387	 4.7e-05	 0.000497	 0.00743	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41386	 41398	 4.3e-05	 0.000424	 0.00725	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41386	 41398	 4.3e-05	 0.000424	 0.00725	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41387	 89313	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41387	 89313	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41388	 41391	 0.00481	 0.016047	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41388	 89315	 0.002698	 0.015335	 0.00028	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41389	 41391	 0.005826	 0.016533	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89294	 41389	 0.017553	 0.045121	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89308	 41389	 0.013027	 0.02386	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41390	 41391	 0.016045	 0.012698	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41392	 89314	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41392	 89314	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41392	 89319	 0.000401	 0.00484	 0.01019	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41393	 41395	 0.000688	 0.004865	 0.00133	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89314	 41393	 0.000971	 0.010527	 0.00329	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41393	 89315	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41393	 89315	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41394	 41396	 0.007314	 0.0244	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89315	 41394	 0.003935	 0.011286	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89314	 41395	 0.002597	 0.015212	 0.00414	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41396	 89317	 0.005785	 0.019298	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41397	 41398	 3.7e-05	 0.000385	 0.00604	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41397	 41398	 3.7e-05	 0.000385	 0.00604	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41397	 41410	 0.000119	 0.002158	 0.02157	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41397	 89316	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41398	 41406	 0.000178	 0.003297	 0.03167	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41399	 41401	 0.00059	 0.005667	 0.00165	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41399	 89318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41399	 89318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41399	 89320	 0.000968	 0.009015	 0.00279	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41400	 41410	 0.000222	 0.0039	 0.04173	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41400	 89319	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89320	 41400	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88878	 41401	 0.001223	 0.013118	 0.00341	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89318	 41402	 0.012137	 0.024838	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41402	 89947	 0.011323	 0.023172	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89316	 41403	 0.000661	 0.006053	 0.00242	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41403	 89326	 0.000593	 0.006044	 0.00156	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41404	 41405	 0.000904	 0.003826	 0.00086	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41404	 41409	 0.000539	 0.00406	 0.00113	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89316	 41404	 0.003045	 0.011076	 0.00339	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41405	 41414	 0.000443	 0.005069	 0.00155	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41405	 41421	 0.000607	 0.006438	 0.00191	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41405	 89321	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41405	 89321	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41406	 41408	 0.000147	 0.001823	 0.01689	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41406	 41413	 6.7e-05	 0.001113	 0.01176	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41406	 89322	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41406	 89322	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41407	 89323	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41407	 89323	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41407	 89324	 0.000107	 0.00163	 0.0037	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41407	 89928	 0.000925	 0.012299	 0.02627	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41408	 41410	 4.5e-05	 0.000585	 0.0097	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41408	 89324	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89325	 41408	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41409	 89326	 0.000355	 0.0031	 0.00085	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41410	 89326	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41410	 89326	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41411	 89329	 0.011102	 0.02198	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41411	 89982	 0.030555	 0.033607	 0.00045	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41412	 43101	 0.001553	 0.013765	 0.00366	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41412	 89327	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41412	 89327	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41412	 89328	 0.000593	 0.006046	 0.00156	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41413	 89328	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41413	 89328	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89322	 41414	 0.000256	 0.002711	 0.0008	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41415	 41416	 0.00083	 0.004325	 0.00113	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41415	 43161	 0.003704	 0.009617	 0.00233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89322	 41415	 0.001042	 0.005897	 0.00146	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41415	 89329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41415	 89329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41416	 41422	 0.000785	 0.005735	 0.00169	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41416	 41433	 0.001956	 0.005169	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41416	 89330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41416	 89330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41417	 41426	 0.001452	 0.005705	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89310	 41417	 0.003	 0.008168	 0.0018	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41417	 89331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41417	 89331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41418	 41423	 0.000907	 0.004831	 0.00136	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89310	 41418	 0.00121	 0.006271	 0.00153	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41418	 89332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41418	 89332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89321	 41419	 0.015381	 0.040659	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41419	 89334	 0.01936	 0.025444	 0.00035	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41420	 41422	 0.000587	 0.003717	 0.00101	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41420	 41424	 0.001053	 0.006667	 0.00181	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41420	 89333	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41420	 89333	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41421	 41429	 0.001543	 0.009771	 0.00265	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41421	 89334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41421	 89334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41422	 89335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41422	 89335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41423	 41424	 0.000528	 0.003283	 0.00093	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41424	 41430	 0.00248	 0.006657	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41424	 89336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41424	 89336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89332	 41425	 0.007929	 0.014251	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41425	 89337	 0.012191	 0.011433	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41426	 41428	 0.000642	 0.004069	 0.0011	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41426	 89337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41426	 89337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89331	 41427	 0.031983	 0.020706	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89337	 41427	 0.007781	 0.01765	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41428	 41430	 0.001555	 0.007133	 0.00183	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41428	 41439	 0.001829	 0.004911	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41429	 41430	 0.000543	 0.002922	 0.0008	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41429	 89338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41429	 89338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41430	 41435	 0.002194	 0.006117	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41431	 41434	 0.013378	 0.024502	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89335	 41431	 0.011656	 0.023077	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89338	 41431	 0.015599	 0.030885	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89330	 41432	 0.026415	 0.019434	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41432	 89339	 0.025466	 0.018736	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41433	 43161	 0.002947	 0.007639	 0.00231	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41433	 89339	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41433	 89339	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89339	 41434	 0.003908	 0.022213	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41434	 89365	 0.037127	 0.029381	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41435	 41437	 0.001898	 0.004928	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41435	 41438	 0.00157	 0.005387	 0.00129	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41435	 41439	 0.001445	 0.005054	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41436	 41437	 0.000813	 0.004042	 0.0013	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41436	 41479	 0.001055	 0.004225	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41437	 41504	 0.001199	 0.008986	 0.00219	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41438	 41503	 0.001833	 0.00734	 0.00185	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41439	 41466	 0.000908	 0.007245	 0.00179	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41439	 43161	 0.005668	 0.028478	 0.00741	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89148	 41440	 0.015647	 0.035947	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41440	 89342	 0.0265	 0.020972	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41441	 89340	 0.005478	 0.012971	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41441	 89341	 0.011479	 0.020712	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41441	 89344	 0.010046	 0.019689	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41442	 41443	 0.000809	 0.002137	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41442	 41451	 0.002078	 0.004824	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41442	 89340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41442	 89340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41443	 41446	 0.002532	 0.006508	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41443	 89341	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41443	 89341	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89340	 41444	 0.022674	 0.016682	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41444	 89342	 0.005649	 0.008814	 0.00015	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41445	 41446	 0.00196	 0.005466	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41445	 89342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41445	 89342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41446	 41448	 0.001486	 0.003859	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89341	 41447	 0.02337	 0.016894	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41447	 89358	 0.020824	 0.04123	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41448	 41473	 0.001174	 0.003151	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41449	 41454	 0.001805	 0.004687	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41449	 41462	 0.00173	 0.00435	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41450	 41451	 0.000691	 0.00237	 0.00057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41450	 41469	 0.00108	 0.003639	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41451	 41453	 0.001274	 0.003275	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41451	 89343	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41451	 89343	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41452	 41453	 0.001235	 0.003264	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41452	 41454	 0.002031	 0.005272	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41452	 89344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41452	 89344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41454	 41462	 0.00224	 0.005758	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41454	 89345	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41454	 89345	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41455	 41456	 0.000875	 0.002311	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41455	 89346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41455	 89346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41456	 41460	 0.001113	 0.00363	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41456	 89347	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41456	 89347	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41457	 41458	 0.001418	 0.004943	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41457	 89348	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41457	 89348	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41458	 41464	 0.001333	 0.004012	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41458	 89349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41458	 89349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89349	 41459	 0.007064	 0.00777	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41459	 89352	 0.006952	 0.011594	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41460	 41461	 0.000707	 0.002209	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41461	 41464	 0.001644	 0.005641	 0.00135	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41461	 89350	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41461	 89350	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41462	 41465	 0.001131	 0.005585	 0.00163	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41462	 89351	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41462	 89351	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89350	 41463	 0.014595	 0.010738	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41463	 89353	 0.010629	 0.021044	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41464	 41466	 0.000448	 0.00353	 0.00103	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41464	 89352	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41464	 89352	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41465	 41466	 0.001356	 0.005277	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41465	 41478	 0.002996	 0.008404	 0.00216	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41465	 41487	 0.002336	 0.013279	 0.00384	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89310	 41465	 0.010401	 0.027489	 0.00643	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41465	 89353	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41465	 89353	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41466	 41467	 0.00045	 0.002681	 0.00071	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41467	 41479	 0.000671	 0.003413	 0.00124	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89351	 41468	 0.028295	 0.022392	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41468	 89354	 0.015147	 0.01666	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41469	 41470	 0.000948	 0.003351	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41469	 89354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41469	 89354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41470	 41471	 0.00065	 0.002189	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41471	 41478	 0.000755	 0.00429	 0.00124	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41471	 89355	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41471	 89355	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89354	 41472	 0.031099	 0.024611	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89355	 41472	 0.025048	 0.027549	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41472	 89358	 0.027146	 0.019972	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41473	 41474	 0.001302	 0.003495	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41473	 89356	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41473	 89356	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41474	 41476	 0.001684	 0.005775	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41474	 89357	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41474	 89357	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89356	 41475	 0.036251	 0.028415	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89357	 41475	 0.012406	 0.011116	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41476	 41477	 0.000453	 0.002602	 0.00074	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41476	 89358	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41476	 89358	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41477	 41488	 0.001715	 0.009409	 0.00249	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41477	 89359	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41477	 89359	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41478	 41480	 0.002146	 0.006707	 0.00194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41478	 41487	 0.000953	 0.00779	 0.00211	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41479	 41480	 0.001223	 0.004196	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41479	 89360	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41479	 89360	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41481	 41482	 0.016639	 0.028029	 0.0004	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41481	 89364	 0.047647	 0.037348	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41482	 43175	 0.017395	 0.045985	 0.00083	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41483	 41484	 0.008166	 0.021642	 0.00055	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89359	 41483	 0.011055	 0.021665	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41484	 89364	 0.008873	 0.054551	 0.00098	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41485	 41486	 0.009712	 0.012056	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41485	 41489	 0.008912	 0.017645	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89360	 41486	 0.040943	 0.029002	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41487	 41490	 0.001449	 0.005246	 0.00113	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41487	 41491	 0.001489	 0.007755	 0.00203	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41487	 41492	 0.002321	 0.009123	 0.00239	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41488	 41501	 0.00134	 0.012185	 0.00308	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41489	 41508	 0.01245	 0.032005	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41489	 89361	 0.023238	 0.018215	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41490	 41491	 0.001445	 0.005234	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41490	 89361	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41490	 89361	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41491	 41492	 0.001153	 0.002778	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41491	 41493	 0.001412	 0.005653	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41491	 41494	 0.001032	 0.003106	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41492	 41494	 0.002069	 0.005467	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41492	 41501	 0.001764	 0.007062	 0.00178	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41493	 41499	 0.000924	 0.003699	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41493	 89362	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41493	 89362	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41494	 41496	 0.000753	 0.003419	 0.00119	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41495	 41502	 0.008113	 0.024889	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41495	 89363	 0.002735	 0.014573	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41496	 41514	 0.001165	 0.006392	 0.00169	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41496	 89363	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41496	 89363	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41497	 41498	 0.005149	 0.017178	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89363	 41497	 0.003752	 0.008579	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41498	 89988	 0.007056	 0.034434	 0.00059	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41499	 41500	 0.000779	 0.002961	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41500	 43172	 0.000569	 0.002237	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41501	 43178	 0.001559	 0.007755	 0.0025	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41501	 89364	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41501	 89364	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89360	 41502	 0.023351	 0.033148	 0.00055	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41503	 43161	 0.002277	 0.012892	 0.0032	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41503	 89365	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41503	 89365	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41504	 41507	 0.000738	 0.005928	 0.00167	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41505	 89367	 0.026089	 0.019766	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41505	 89979	 0.021161	 0.035647	 0.00051	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41506	 41507	 0.002215	 0.008705	 0.00228	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41506	 89978	 0.004302	 0.016906	 0.00442	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41507	 41509	 0.001167	 0.00467	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41508	 89369	 0.005207	 0.027746	 0.00049	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41509	 41510	 0.002065	 0.005458	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41509	 89366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41509	 89366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41510	 41511	 0.002439	 0.008367	 0.002	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41510	 41513	 0.001086	 0.003376	 0.0007	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41511	 43155	 0.003219	 0.011656	 0.0025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41511	 89367	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41511	 89367	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89363	 41512	 0.009882	 0.019566	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41512	 89369	 0.00478	 0.012286	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41513	 41516	 0.001692	 0.004472	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41513	 89368	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41513	 89368	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41514	 41515	 0.000498	 0.003338	 0.00081	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41514	 89369	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41514	 89369	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41515	 41516	 0.000854	 0.003322	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41515	 43169	 0.002259	 0.007749	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41516	 43169	 0.001423	 0.004881	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41517	 89370	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41517	 89370	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89233	 41518	 0.009751	 0.029914	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89079	 41519	 0.00152	 0.004664	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89082	 41520	 0.013182	 0.010333	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89086	 41521	 0.006912	 0.010588	 0.00015	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89262	 41523	 0.006655	 0.031496	 0.00757	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41523	 89371	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41523	 89371	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89102	 41524	 0.001419	 0.003956	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41524	 89372	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41524	 89372	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89119	 41525	 0.006386	 0.006956	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89262	 41526	 0.002094	 0.009427	 0.00251	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41526	 89373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41526	 89373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41527	 41528	 0.000743	 0.002224	 0.0005	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41527	 89374	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41527	 89374	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41528	 89375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41528	 89375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89094	 41529	 0.012895	 0.009487	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89098	 41529	 0.003618	 0.007164	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41530	 89376	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41530	 89376	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41533	 89377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41533	 89377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41535	 89379	 0.002696	 0.006856	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41536	 41567	 0.005125	 0.022836	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41537	 41611	 8.4e-05	 0.000935	 0.00874	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41537	 89378	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41538	 89402	 0.001911	 0.01074	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41539	 41577	 0.013835	 0.008957	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41540	 41541	 0.000439	 0.001727	 0.00045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41540	 89380	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41540	 89380	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41540	 89403	 0.001872	 0.004861	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88930	 41542	 0.002207	 0.004951	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89141	 41543	 0.00419	 0.010772	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89140	 41545	 0.004785	 0.013723	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41545	 89381	 0.018543	 0.014535	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41546	 89381	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41546	 89381	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41547	 89382	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41547	 89382	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41549	 89413	 0.006715	 0.017261	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41550	 41551	 0.011409	 0.007386	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41550	 89413	 0.018553	 0.014683	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41553	 89383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41553	 89383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89168	 41554	 0.013196	 0.010443	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89383	 41554	 0.004432	 0.007966	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89149	 41555	 0.004049	 0.010409	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41555	 89415	 0.00577	 0.012365	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41556	 41625	 0.001758	 0.00472	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41556	 89384	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41556	 89384	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41556	 89405	 0.00072	 0.004015	 0.00103	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41557	 89413	 0.002739	 0.006358	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89384	 41558	 0.002259	 0.005807	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41559	 41561	 0.008613	 0.006816	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89384	 41560	 0.003079	 0.01016	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89133	 41563	 0.022057	 0.015945	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41565	 41566	 0.01278	 0.008274	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89384	 41565	 0.019262	 0.02391	 0.00052	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41567	 89401	 0.002887	 0.019819	 0.00036	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41568	 41572	 0.000556	 0.001874	 0.00047	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41568	 89385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41568	 89385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89124	 41569	 0.01145	 0.009061	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41571	 41572	 0.00052	 0.002022	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41571	 41574	 0.000367	 0.001236	 0.00031	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41571	 89386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41571	 89386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41574	 89387	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41574	 89387	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41575	 89388	 0.003194	 0.016823	 0.0003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41577	 89388	 0.005232	 0.010254	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41578	 41616	 0.000527	 0.001843	 0.00061	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41578	 89388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41578	 89388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41580	 41603	 0.000576	 0.002264	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89127	 41581	 0.014772	 0.011579	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41581	 89408	 0.005372	 0.00706	 0.0001	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41582	 89389	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41582	 89389	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41583	 89398	 0.002594	 0.010091	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41584	 41607	 6.3e-05	 0.000729	 0.00639	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41584	 89390	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41585	 41608	 0.004504	 0.007189	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41586	 41608	 0.007217	 0.005711	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41588	 41590	 0.000727	 0.001921	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41588	 89392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41588	 89392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41589	 41591	 0.006627	 0.006693	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41590	 41599	 0.002879	 0.007839	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41590	 89393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41590	 89393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41590	 89405	 0.000347	 0.002973	 0.00085	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89393	 41591	 0.003882	 0.009193	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88859	 41593	 0.001962	 0.007634	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89154	 41593	 0.003164	 0.006264	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41596	 41601	 0.01968	 0.014227	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41596	 41620	 0.002659	 0.009308	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89128	 41596	 0.000858	 0.005273	 0.0001	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41597	 41605	 0.000886	 0.003749	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89370	 41597	 0.000548	 0.004402	 0.00124	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41597	 89394	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41597	 89394	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88858	 41599	 0.001151	 0.004167	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89390	 41599	 0.002552	 0.008754	 0.0021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41599	 89395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41599	 89395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89128	 41600	 0.006781	 0.011424	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41601	 89411	 0.003335	 0.012829	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41602	 41604	 0.00367	 0.006015	 0.00011	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41603	 41605	 0.000632	 0.002674	 0.0006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41603	 89396	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41603	 89396	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41604	 89397	 0.002721	 0.004168	 6e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41605	 89397	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41605	 89397	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41607	 41611	 0.000131	 0.00171	 0.01548	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41607	 41619	 8.8e-05	 0.000931	 0.01392	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41607	 89398	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41607	 89398	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89393	 41608	 0.005434	 0.020383	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41609	 89399	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89390	 41610	 0.001916	 0.007532	 0.00197	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41610	 89402	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41610	 89402	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41610	 89403	 0.000848	 0.002309	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41611	 89403	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41613	 89413	 0.012366	 0.028704	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41614	 89405	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89297	 41615	 0.002914	 0.016257	 0.00415	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41615	 89407	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41615	 89407	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41616	 89409	 0.000744	 0.004989	 0.0012	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41617	 89408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41617	 89408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89396	 41618	 0.00878	 0.006949	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41619	 89409	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88865	 41622	 0.000538	 0.005803	 0.00166	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41622	 89411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41622	 89411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41624	 89412	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41624	 89412	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89405	 41625	 0.001425	 0.004754	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41625	 89413	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41625	 89413	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41626	 89414	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41626	 89414	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89249	 41627	 0.00105	 0.009776	 0.00303	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89299	 41628	 0.001347	 0.008361	 0.00203	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41628	 89415	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41628	 89415	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89068	 41629	 0.11439	 0.26562	 0.00395	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41629	 89416	 0.058711	 0.13489	 0.00205	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41630	 42356	 0.023402	 0.093727	 0.02362	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41630	 89416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41630	 89416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41631	 41632	 0.006297	 0.021007	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89416	 41631	 0.024248	 0.074386	 0.00201	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41632	 41634	 0.026283	 0.10225	 0.00171	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41632	 89417	 0.027384	 0.091351	 0.00145	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88851	 41633	 0.027868	 0.14827	 0.03444	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41633	 89417	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41633	 89417	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41634	 42352	 0.031127	 0.13715	 0.00238	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41635	 41636	 0.012638	 0.033402	 0.00782	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41635	 42005	 0.017972	 0.046204	 0.01144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41635	 89418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41635	 89418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88910	 41636	 0.020988	 0.05715	 0.01259	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41637	 41893	 0.009103	 0.035415	 0.00946	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88910	 41637	 0.004688	 0.018768	 0.00473	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41638	 42421	 0.006925	 0.026939	 0.0072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89040	 41638	 0.011265	 0.04768	 0.01073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41638	 89419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41638	 89419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41638	 89422	 0.007376	 0.023057	 0.00668	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41639	 42421	 0.007633	 0.040459	 0.0135	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41639	 89420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41639	 89420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41639	 89783	 0.008786	 0.047308	 0.013	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41640	 41647	 0.000116	 0.002241	 0.03739	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41640	 42661	 0.000185	 0.00336	 0.06284	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41641	 41643	 0.000165	 0.001919	 0.01659	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41641	 89421	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89422	 41641	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41642	 41644	 0.002466	 0.008308	 0.00206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41642	 41646	 0.002856	 0.011225	 0.00294	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41643	 41645	 7.8e-05	 0.001499	 0.02528	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41643	 42075	 0.000409	 0.007566	 0.0727	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41643	 89423	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41643	 89423	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89423	 41644	 0.001486	 0.005098	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41645	 41647	 0.000101	 0.001783	 0.0296	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41645	 89424	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89425	 41645	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41646	 41649	 0.001453	 0.005524	 0.00155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89423	 41646	 0.002837	 0.015741	 0.00478	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41646	 89784	 0.005188	 0.048837	 0.0148	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41647	 41651	 0.000334	 0.003852	 0.03377	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41647	 89426	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41647	 89426	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41648	 41658	 0.002945	 0.011787	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89426	 41648	 0.003469	 0.015748	 0.00034	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41649	 89427	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41649	 89427	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41649	 89428	 0.003287	 0.011957	 0.00366	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41650	 41658	 0.070204	 0.050751	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41650	 89429	 0.016991	 0.043209	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41651	 41656	 0.001003	 0.010951	 0.10754	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41651	 89428	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89421	 41652	 0.001671	 0.011272	 0.02076	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89424	 41652	 0.000463	 0.005691	 0.0106	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41652	 89577	 0.000919	 0.009735	 0.0223	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41653	 41654	 0.006392	 0.03744	 0.0102	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41653	 89430	 0.015338	 0.039432	 0.00976	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41653	 89578	 0.002752	 0.030436	 0.00913	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41654	 42326	 0.016745	 0.056426	 0.01403	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88869	 41654	 0.002287	 0.011679	 0.00294	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41655	 89430	 0.003184	 0.012746	 0.00321	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41656	 41657	 7.3e-05	 0.000831	 0.00751	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41656	 89430	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41656	 89430	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41657	 42153	 0.00018	 0.003149	 0.03369	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41657	 42324	 0.000116	 0.001425	 0.02282	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89427	 41658	 0.007241	 0.014337	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41659	 42480	 0.010432	 0.035149	 0.00874	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88838	 41659	 0.003131	 0.034301	 0.00951	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41659	 89816	 0.009598	 0.03345	 0.00776	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41660	 41663	 0.005595	 0.022767	 0.00555	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88838	 41660	 0.00086	 0.003345	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41661	 41663	 0.009411	 0.024873	 0.00582	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41661	 42376	 0.018192	 0.048844	 0.01107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41662	 89431	 0.011559	 0.016843	 0.00038	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41663	 42519	 0.010359	 0.042155	 0.01027	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41663	 89431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41663	 89431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41664	 41665	 0.18895	 0.14955	 0.00188	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41664	 41886	 0.12363	 0.21305	 0.00339	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41665	 89433	 0.031403	 0.11502	 0.00291	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41666	 89433	 0.045773	 0.090629	 0.00133	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89064	 41667	 0.085314	 0.22114	 0.00418	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41667	 89433	 0.064877	 0.10929	 0.00156	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41668	 89432	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89177	 41669	 0.000488	 0.003419	 0.00582	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89248	 41669	 0.000685	 0.004784	 0.00821	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41669	 89434	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41669	 89434	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41670	 41671	 0.001862	 0.006274	 0.00156	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41670	 41674	 0.001956	 0.007829	 0.00197	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89178	 41670	 0.00274	 0.010968	 0.00276	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89434	 41670	 0.002381	 0.008622	 0.00185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41671	 41673	 0.001377	 0.004593	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41671	 89435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41671	 89435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41672	 41684	 0.004072	 0.01987	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41672	 89436	 0.002568	 0.012911	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41673	 41881	 0.001169	 0.004681	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41673	 89436	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41673	 89436	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41674	 41685	 0.001475	 0.005906	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41674	 89437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41674	 89437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41675	 41677	 0.004912	 0.01678	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89435	 41675	 0.007313	 0.018798	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41676	 41677	 0.005938	 0.015264	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89436	 41676	 0.005178	 0.01235	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41676	 89507	 0.008485	 0.014294	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41676	 89509	 0.005236	 0.015019	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41677	 41687	 0.002208	 0.011763	 0.00021	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41677	 89509	 0.00756	 0.016732	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41678	 41681	 0.001123	 0.003913	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41678	 41682	 0.001581	 0.005155	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41678	 41769	 0.000432	 0.003929	 0.00099	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41679	 41683	 0.022188	 0.016039	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41680	 89438	 0.024502	 0.019391	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41681	 41682	 0.001918	 0.005068	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41681	 89438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41681	 89438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41683	 41684	 0.007127	 0.016546	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89250	 41683	 0.011689	 0.027138	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41685	 41694	 0.001403	 0.005617	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41685	 89508	 0.005727	 0.014396	 0.00373	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41686	 41688	 0.001808	 0.004694	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41686	 41689	 0.001415	 0.004422	 0.00128	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41686	 89439	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41686	 89439	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41687	 89440	 0.002008	 0.012347	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41688	 89440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41688	 89440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41689	 41690	 0.001251	 0.004865	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41689	 41774	 0.001071	 0.006274	 0.00171	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41690	 41740	 0.001558	 0.006125	 0.0016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41691	 41742	 0.010351	 0.027364	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89439	 41691	 0.003344	 0.015495	 0.0003	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41691	 89448	 0.002539	 0.014434	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41692	 41694	 0.000887	 0.003487	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41692	 41701	 0.001302	 0.005511	 0.00124	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89211	 41693	 0.009281	 0.026618	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41693	 89441	 0.006078	 0.011639	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41694	 89441	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41694	 89441	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41695	 89442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41695	 89442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41696	 41697	 0.001223	 0.004195	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41696	 41701	 0.00126	 0.003329	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41696	 89443	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41696	 89443	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41698	 41702	 0.001105	 0.004676	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41698	 89444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41698	 89444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41699	 41700	 0.013905	 0.010899	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89440	 41700	 0.003504	 0.014023	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89441	 41700	 0.011144	 0.031623	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41700	 89445	 0.002429	 0.01014	 0.00029	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41701	 41702	 0.001445	 0.005681	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41701	 41703	 0.000913	 0.002748	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41703	 41705	 0.000547	 0.00466	 0.00116	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41703	 89445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41703	 89445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88931	 41704	 0.005021	 0.021563	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41704	 89450	 0.029426	 0.029722	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41705	 41708	 0.001171	 0.002944	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41705	 41710	 0.001717	 0.006987	 0.0017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41705	 89446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41705	 89446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41706	 41707	 0.000772	 0.003601	 0.00089	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41706	 41710	 0.000973	 0.004018	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41706	 41712	 0.001024	 0.006	 0.00163	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41706	 89447	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41706	 89447	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41707	 41756	 0.002628	 0.012752	 0.00291	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41708	 41709	 0.001032	 0.003738	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41708	 89448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41708	 89448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41709	 41711	 0.001848	 0.004751	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41709	 41740	 0.001571	 0.004505	 0.00111	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41709	 41741	 0.000562	 0.006161	 0.00171	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41709	 89508	 0.002187	 0.01723	 0.00504	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41710	 89449	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41710	 89449	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41711	 89450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41711	 89450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41712	 41726	 0.000855	 0.004691	 0.00124	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41712	 41727	 0.000628	 0.004588	 0.00135	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41712	 89451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41712	 89451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41713	 41715	 0.002951	 0.016195	 0.00428	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41714	 41716	 0.02619	 0.016955	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41715	 89452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41715	 89452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41715	 89455	 0.000538	 0.005948	 0.00178	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89452	 41716	 0.007865	 0.020217	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41716	 89454	 0.013543	 0.037514	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41717	 41722	 0.004687	 0.016409	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89197	 41717	 0.003301	 0.012647	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89444	 41718	 0.008383	 0.024043	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41719	 41728	 0.040872	 0.032346	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89198	 41719	 0.039618	 0.025649	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41720	 41728	 0.020304	 0.014938	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41721	 41722	 0.002599	 0.012685	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88931	 41721	 0.012081	 0.012202	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89444	 41721	 0.00437	 0.0124	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41723	 41726	 0.000503	 0.003243	 0.00085	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41724	 89453	 0.021069	 0.015501	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89447	 41725	 0.002177	 0.01225	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89451	 41725	 0.003461	 0.011421	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41725	 89453	 0.005357	 0.015364	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41725	 89454	 0.006525	 0.029074	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41726	 89453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41726	 89453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41727	 41729	 0.002671	 0.010696	 0.00269	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41727	 89454	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41727	 89454	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41727	 89455	 0.002054	 0.012744	 0.00309	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89454	 41728	 0.020954	 0.036851	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41729	 41730	 0.00165	 0.005659	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41729	 41731	 0.000654	 0.004458	 0.00152	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41729	 41734	 0.000513	 0.004665	 0.00118	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41729	 41737	 0.001456	 0.012483	 0.00355	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41730	 41735	 0.000863	 0.007347	 0.00183	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41730	 41756	 0.000708	 0.006799	 0.00198	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41730	 89455	 0.002434	 0.013985	 0.00396	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41731	 41741	 0.000939	 0.007074	 0.00196	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41731	 41745	 0.001084	 0.005746	 0.00192	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41732	 42110	 0.000389	 0.007197	 0.06916	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41732	 89455	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41732	 89455	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41733	 89456	 0.021655	 0.014019	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89455	 41734	 0.000684	 0.005491	 0.00154	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41734	 89456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41734	 89456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41735	 41739	 0.000662	 0.005734	 0.00206	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88907	 41736	 0.005812	 0.01478	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89456	 41736	 0.024849	 0.071271	 0.0011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88906	 41737	 0.001183	 0.01101	 0.00341	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41738	 41754	 0.000597	 0.00436	 0.00112	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41738	 89499	 0.001087	 0.008264	 0.0026	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41739	 89501	 0.000508	 0.005274	 0.00163	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41740	 41746	 0.000381	 0.004087	 0.00106	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41741	 41745	 0.000401	 0.003972	 0.00122	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41742	 89457	 0.003282	 0.022529	 0.00041	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41742	 89459	 0.011599	 0.03006	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41743	 41749	 0.000369	 0.004128	 0.00131	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41743	 41774	 0.00113	 0.004664	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41743	 41775	 0.000262	 0.002514	 0.00073	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41744	 89458	 0.021227	 0.016799	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41745	 41756	 0.000777	 0.003626	 0.0009	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41746	 41747	 0.000316	 0.003391	 0.00088	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41746	 89457	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41746	 89457	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41747	 41752	 0.000931	 0.002596	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41747	 41753	 0.000922	 0.003624	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41747	 41756	 0.001915	 0.00745	 0.00199	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41747	 89458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41747	 89458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41748	 41750	 0.002389	 0.011071	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41748	 89459	 0.004027	 0.017946	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41749	 41765	 0.000903	 0.007748	 0.0022	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41749	 89459	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41749	 89459	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41750	 41751	 0.001949	 0.009089	 0.00021	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89458	 41751	 0.006041	 0.013815	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41751	 89462	 0.013112	 0.025961	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41752	 41760	 0.001478	 0.003907	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41752	 41761	 0.001872	 0.005025	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41753	 41756	 0.001113	 0.004709	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41754	 41755	 0.000663	 0.004969	 0.00121	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41754	 89460	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41754	 89460	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41755	 41760	 0.000386	 0.00418	 0.00176	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41756	 41758	 0.000914	 0.003661	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41756	 89499	 0.002914	 0.021838	 0.00533	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41757	 41758	 0.000802	 0.003893	 0.00089	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41757	 89499	 0.00324	 0.015977	 0.00432	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41759	 41766	 0.00322	 0.014188	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41759	 89461	 0.005318	 0.015253	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41760	 41761	 0.00071	 0.002791	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41760	 41765	 0.000902	 0.005286	 0.00144	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41761	 41765	 0.000409	 0.002744	 0.00066	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41761	 89461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41761	 89461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89461	 41762	 0.033647	 0.027694	 0.00056	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41762	 89462	 0.024188	 0.02443	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41762	 89486	 0.017541	 0.034729	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41763	 41764	 0.000508	 0.001997	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41763	 41765	 0.00116	 0.004408	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41764	 41787	 0.000789	 0.004483	 0.0013	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41764	 41788	 0.000954	 0.00252	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41765	 41835	 0.001858	 0.013566	 0.00349	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41765	 89462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41765	 89462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89461	 41766	 0.010039	 0.028794	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41766	 89487	 0.00322	 0.022104	 0.0004	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41767	 41768	 0.005418	 0.011388	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89273	 41767	 0.019777	 0.012803	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89273	 41768	 0.018298	 0.02803	 0.00039	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41768	 89463	 0.002858	 0.014459	 0.00025	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41769	 41770	 0.000373	 0.003196	 0.00091	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41769	 41782	 0.001834	 0.006393	 0.00148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41769	 89463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41769	 89463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41770	 41771	 0.000289	 0.002517	 0.00069	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41771	 41775	 0.001111	 0.00711	 0.00239	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41771	 41776	 0.000983	 0.003937	 0.00099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41771	 89464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41771	 89464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41772	 41774	 0.001091	 0.004441	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41772	 89465	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41772	 89465	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41772	 89510	 0.000831	 0.003381	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41773	 41777	 0.008862	 0.013576	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89465	 41773	 0.011844	 0.009373	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41775	 41776	 0.00123	 0.005967	 0.00136	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41775	 89466	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41775	 89466	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41776	 41778	 0.001218	 0.00359	 0.00084	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41776	 89467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41776	 89467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89464	 41777	 0.011524	 0.022817	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89466	 41777	 0.002454	 0.012412	 0.00022	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89467	 41777	 0.014036	 0.011108	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41778	 41779	 0.000357	 0.003044	 0.00076	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41778	 41790	 0.000359	 0.003443	 0.001	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41779	 41780	 0.000566	 0.003143	 0.00096	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41780	 41782	 0.000546	 0.003359	 0.00097	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41780	 89468	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41780	 89468	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41781	 41783	 0.007398	 0.014647	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41781	 89469	 0.016603	 0.012002	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41782	 89469	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41782	 89469	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89468	 41783	 0.00472	 0.009659	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41784	 89470	 0.025842	 0.023156	 0.00047	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41784	 89471	 0.004389	 0.012454	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41785	 89471	 0.003994	 0.021279	 0.00037	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41785	 89472	 0.004567	 0.022037	 0.00039	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41786	 41787	 0.000874	 0.00401	 0.00103	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41786	 41790	 0.000875	 0.006466	 0.00187	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41786	 41832	 0.00183	 0.013918	 0.00437	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41786	 89470	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41786	 89470	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41787	 41788	 0.000875	 0.003704	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41787	 89471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41787	 89471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41788	 41791	 0.001338	 0.005086	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41789	 41792	 0.000764	 0.00651	 0.00162	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41789	 41793	 0.00048	 0.004089	 0.00102	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41789	 89472	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41789	 89472	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41790	 41793	 0.001063	 0.003721	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41790	 89473	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41790	 89473	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41791	 41800	 0.001036	 0.005395	 0.00141	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41792	 41799	 0.000617	 0.005927	 0.00172	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41792	 89474	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41792	 89474	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41793	 41796	 0.000933	 0.007739	 0.00204	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41794	 41798	 0.015545	 0.026187	 0.00037	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89472	 41794	 0.016078	 0.029449	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41795	 41798	 0.01226	 0.031515	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41795	 89475	 0.007248	 0.016575	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41796	 89475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41796	 89475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41797	 41799	 0.001025	 0.004104	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41797	 41803	 0.000961	 0.003912	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89286	 41798	 0.01015	 0.036259	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89474	 41798	 0.007642	 0.038656	 0.00067	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41798	 89476	 0.006361	 0.018244	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41799	 41800	 0.000441	 0.004498	 0.00116	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41799	 41801	 0.000482	 0.003102	 0.00081	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41800	 41802	 0.000325	 0.003945	 0.00106	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41800	 41832	 0.001483	 0.005939	 0.0015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41801	 41817	 0.000447	 0.003159	 0.00087	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41802	 89480	 0.000323	 0.004573	 0.00151	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41803	 41804	 0.00047	 0.004273	 0.00108	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41803	 41815	 0.000385	 0.003894	 0.00114	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41804	 41805	 0.00038	 0.003262	 0.00093	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41805	 41806	 0.000508	 0.003153	 0.00076	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41805	 89476	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41805	 89476	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41807	 41808	 0.000315	 0.003206	 0.00083	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41808	 41809	 0.000932	 0.003626	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41808	 41813	 0.000664	 0.00389	 0.00106	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41809	 41815	 0.001352	 0.005315	 0.00139	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41810	 41811	 0.005104	 0.013121	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41810	 41822	 0.007818	 0.020098	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41811	 89478	 0.00428	 0.010208	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41812	 41813	 0.000349	 0.002807	 0.00079	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41812	 41828	 0.000286	 0.002795	 0.00078	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41813	 89477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41813	 89477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89477	 41814	 0.006406	 0.018179	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41814	 89478	 0.003893	 0.010008	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41815	 41819	 0.000771	 0.005808	 0.00161	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41815	 41823	 0.005393	 0.021198	 0.00555	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41815	 89478	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41815	 89478	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41816	 41817	 0.00043	 0.002465	 0.00082	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41816	 41819	 0.000275	 0.002283	 0.0006	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41817	 89479	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41817	 89479	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41818	 89480	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41818	 89480	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41818	 89495	 9.1e-05	 0.001446	 0.00297	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41819	 41821	 0.000455	 0.003656	 0.00103	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89480	 41819	 0.00024	 0.003555	 0.0011	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41820	 41821	 0.000423	 0.003186	 0.00088	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41820	 41827	 0.00085	 0.004883	 0.00138	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89480	 41820	 0.001272	 0.005092	 0.00128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41821	 89481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41821	 89481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89481	 41822	 0.006561	 0.014008	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41822	 89483	 0.004491	 0.01498	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41822	 89484	 0.003893	 0.017419	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41823	 41825	 0.001487	 0.008157	 0.00216	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88878	 41823	 0.001872	 0.02307	 0.00745	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41823	 89482	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41823	 89482	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41824	 41829	 0.001719	 0.004543	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41824	 41830	 0.002694	 0.007233	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41825	 41828	 0.00135	 0.006902	 0.00188	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41825	 89483	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41825	 89483	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41826	 89484	 0.007008	 0.019387	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41826	 89923	 0.007078	 0.022697	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41827	 41851	 0.000269	 0.002638	 0.00083	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41827	 89484	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41827	 89484	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41828	 41829	 0.001084	 0.002815	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89320	 41830	 0.004575	 0.01209	 0.00283	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89320	 41831	 0.001502	 0.017166	 0.00524	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41831	 89485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41831	 89485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41832	 41833	 0.001057	 0.004111	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41832	 89486	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41832	 89486	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41832	 89499	 0.003426	 0.02423	 0.00665	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41833	 41834	 0.00088	 0.003523	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41834	 41835	 0.001222	 0.004894	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41835	 41837	 0.000627	 0.00447	 0.00139	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41835	 41839	 0.000506	 0.004961	 0.00155	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41835	 89487	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41835	 89487	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41836	 41838	 0.01452	 0.014665	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41836	 89490	 0.011058	 0.021673	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41837	 41854	 0.000509	 0.00401	 0.00117	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89487	 41838	 0.011195	 0.029594	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41838	 89488	 0.011214	 0.020233	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41838	 89500	 0.005804	 0.027293	 0.00051	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41839	 89488	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41839	 89488	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41839	 89499	 0.000675	 0.007592	 0.00199	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41840	 41842	 0.001114	 0.003753	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41840	 43051	 0.000975	 0.005712	 0.00156	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41840	 89489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41840	 89489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41840	 89493	 0.002295	 0.007658	 0.00194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41841	 41842	 0.00113	 0.006733	 0.00177	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41841	 41855	 0.000957	 0.004463	 0.00111	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41841	 89490	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41841	 89490	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41842	 43052	 0.00401	 0.013756	 0.0033	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41842	 89491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41842	 89491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41842	 89493	 0.002685	 0.00697	 0.00169	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41843	 41846	 0.004004	 0.009939	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89490	 41843	 0.003867	 0.009224	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41844	 41845	 0.003796	 0.011658	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89491	 41844	 0.005894	 0.012061	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89489	 41845	 0.011186	 0.017854	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41845	 89506	 0.007651	 0.029763	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41846	 41847	 0.00175	 0.009218	 0.00017	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89491	 41846	 0.017951	 0.023593	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41847	 89502	 0.006422	 0.019721	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41848	 41849	 0.000102	 0.001141	 0.01076	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41848	 43042	 0.000125	 0.001416	 0.01289	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41848	 89492	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89493	 41848	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41849	 41850	 6.7e-05	 0.000759	 0.00691	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41849	 41853	 8.4e-05	 0.000971	 0.00851	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41849	 89494	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41849	 89494	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41850	 41859	 0.000423	 0.004797	 0.04367	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41850	 89495	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41850	 89495	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41851	 89496	 0.00024	 0.002444	 0.00063	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89495	 41852	 0.000329	 0.002133	 0.00425	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41852	 89496	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41852	 89496	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41852	 89497	 0.000138	 0.001277	 0.0024	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41853	 43042	 5e-05	 0.000559	 0.00527	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41853	 89497	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41853	 89497	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41854	 41855	 0.000978	 0.003804	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41854	 41857	 0.001236	 0.003862	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41856	 89498	 0.019909	 0.015756	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89494	 41857	 0.001923	 0.006703	 0.00155	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41857	 89498	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41857	 89498	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41858	 89500	 0.011315	 0.017161	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41859	 41865	 7.7e-05	 0.001007	 0.00912	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41859	 89499	 0.000109	 0.008705	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41860	 41861	 0.001521	 0.004405	 0.00106	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41860	 41867	 0.001291	 0.004036	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41860	 42099	 0.002463	 0.013664	 0.00415	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41860	 89501	 0.0015	 0.009306	 0.00225	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41861	 42082	 0.004077	 0.01048	 0.0026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41861	 42085	 0.00163	 0.004907	 0.00154	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88906	 41861	 0.002583	 0.007202	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41862	 41863	 0.0013	 0.003489	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41862	 41867	 0.001946	 0.006676	 0.0016	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41862	 89501	 0.001378	 0.004989	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88906	 41863	 0.000549	 0.004708	 0.00134	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41863	 89501	 0.001016	 0.004932	 0.00113	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41864	 41876	 0.001418	 0.004863	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41864	 89501	 0.001554	 0.004653	 0.00105	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41865	 89501	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41865	 89501	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41866	 41877	 0.000679	 0.004375	 0.00115	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89499	 41866	 0.002253	 0.007041	 0.00204	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41866	 89502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41866	 89502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41867	 41868	 0.001614	 0.004265	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41867	 41869	 0.002596	 0.00724	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41867	 41874	 0.001865	 0.005199	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41868	 41869	 0.00123	 0.003091	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41868	 41876	 0.001677	 0.005929	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41868	 89606	 0.005038	 0.026241	 0.00688	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41869	 41872	 0.001246	 0.003475	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41869	 41873	 0.001976	 0.005509	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41870	 41873	 0.000964	 0.003752	 0.001	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41870	 43066	 0.001117	 0.005126	 0.00131	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41871	 89503	 0.017597	 0.013793	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41871	 89593	 0.018609	 0.053373	 0.00082	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41871	 89932	 0.009448	 0.021432	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41872	 41878	 0.002676	 0.007072	 0.00166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41872	 89503	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41872	 89503	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41873	 41874	 0.002038	 0.005471	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41873	 89504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41873	 89504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89504	 41875	 0.015094	 0.011945	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41876	 41878	 0.001816	 0.004669	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41877	 41880	 0.000691	 0.006282	 0.00159	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41877	 89505	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41877	 89505	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41878	 41880	 0.002026	 0.00526	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89502	 41879	 0.016378	 0.021525	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89505	 41879	 0.008116	 0.016068	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41880	 89506	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41880	 89506	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41880	 89933	 0.001845	 0.020435	 0.00665	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41881	 89507	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41881	 89507	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41881	 89508	 0.001331	 0.004565	 0.00109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41881	 89510	 0.001328	 0.004694	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41882	 41884	 6.8e-05	 0.000748	 0.00726	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41882	 89508	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89438	 41883	 0.004723	 0.02305	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89507	 41883	 0.002481	 0.009844	 0.00028	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41884	 89510	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41885	 41887	 0.013435	 0.040236	 0.00906	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41885	 42996	 0.015804	 0.047574	 0.01489	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41885	 89512	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41885	 89512	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89076	 41886	 0.09661	 0.26733	 0.00621	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89512	 41886	 0.13525	 0.19202	 0.00316	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41887	 41888	 0.004234	 0.015332	 0.00329	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41888	 41889	 0.007095	 0.01875	 0.00439	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88851	 41888	 0.044569	 0.22444	 0.05859	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41890	 41892	 0.003115	 0.029324	 0.00888	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41890	 42750	 0.004488	 0.042252	 0.0128	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41891	 41892	 0.001265	 0.011779	 0.00365	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41891	 43001	 0.010634	 0.057266	 0.01574	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41891	 43018	 0.004614	 0.049515	 0.01289	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41891	 89519	 0.035716	 0.20962	 0.05727	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41893	 41897	 0.006232	 0.038727	 0.01093	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41893	 41898	 0.002831	 0.01524	 0.00419	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88910	 41893	 0.006134	 0.035929	 0.00979	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41894	 41900	 0.004766	 0.029614	 0.00836	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88881	 41894	 0.003556	 0.022093	 0.00624	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41895	 41896	 0.004281	 0.025693	 0.00778	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41895	 41907	 0.005393	 0.037419	 0.01068	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89071	 41895	 0.035946	 0.093356	 0.02267	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41896	 41900	 0.004434	 0.027555	 0.00778	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89071	 41897	 0.011612	 0.075949	 0.01932	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41898	 41900	 0.002274	 0.014556	 0.0049	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41898	 89513	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41898	 89513	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89513	 41899	 0.023881	 0.036578	 0.00064	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41899	 89883	 0.06524	 0.13352	 0.00329	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88851	 41900	 0.010099	 0.07609	 0.02112	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88881	 41901	 0.005392	 0.036126	 0.01107	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41902	 41904	 0.005975	 0.037848	 0.01027	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41903	 89514	 0.19623	 0.15531	 0.00196	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41903	 89776	 0.099862	 0.26405	 0.0048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41904	 41905	 0.002885	 0.010054	 0.00233	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88856	 41904	 0.004988	 0.061482	 0.01987	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41904	 89514	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41904	 89514	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41905	 41906	 0.008764	 0.023162	 0.00542	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41908	 89541	 0.077122	 0.22123	 0.0034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41908	 89543	 0.13407	 0.20541	 0.00288	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41908	 89685	 0.0335	 0.16349	 0.00282	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41909	 41910	 0.002395	 0.012035	 0.00313	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41909	 41988	 0.007128	 0.044238	 0.01072	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41909	 89515	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41909	 89515	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88888	 41911	 0.011027	 0.058752	 0.00103	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89515	 41911	 0.068107	 0.19536	 0.003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88863	 41912	 0.060286	 0.1683	 0.03537	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41913	 41914	 0.002589	 0.022207	 0.00632	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41913	 42010	 0.002681	 0.038248	 0.01278	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41913	 42720	 0.0081	 0.034282	 0.00771	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41914	 41915	 0.000796	 0.00859	 0.00294	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41914	 89516	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41914	 89516	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41915	 89517	 0.001448	 0.016846	 0.00495	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41916	 42719	 0.002042	 0.019434	 0.03453	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41916	 43197	 0.000573	 0.006245	 0.02519	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41916	 89517	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89518	 41916	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41917	 41924	 0.020778	 0.11675	 0.00216	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41917	 42011	 0.043719	 0.14935	 0.00325	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41917	 42011	 0.043719	 0.14935	 0.00325	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41917	 89520	 0.01869	 0.065397	 0.00135	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41917	 89520	 0.01869	 0.065397	 0.00135	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41917	 89553	 0.060862	 0.23681	 0.00395	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41917	 89553	 0.060862	 0.23681	 0.00395	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41918	 42018	 0.000495	 0.008464	 0.18138	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41918	 43201	 0.00088	 0.008707	 0.14908	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41918	 43201	 0.00088	 0.008707	 0.14908	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41918	 89519	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89520	 41919	 0.009038	 0.035158	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89520	 41919	 0.009038	 0.035158	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41919	 89521	 0.021269	 0.082744	 0.00138	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41919	 89521	 0.021269	 0.082744	 0.00138	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41920	 41924	 0.019592	 0.11907	 0.0022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41920	 89521	 0.01063	 0.065355	 0.00118	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89518	 41921	 0.024828	 0.12116	 0.00209	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41921	 89521	 0.004129	 0.018399	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41922	 43198	 0.003144	 0.019535	 0.00551	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41922	 89521	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41922	 89521	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89521	 41923	 0.024342	 0.029675	 0.00048	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41925	 41926	 0.008384	 0.024048	 0.00592	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41925	 42703	 0.009358	 0.026097	 0.00548	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41925	 89522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41925	 89522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41926	 41932	 0.008174	 0.025551	 0.0074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41926	 42169	 0.029332	 0.077539	 0.01815	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41927	 41935	 0.02246	 0.077066	 0.01847	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41927	 42170	 0.013702	 0.047007	 0.01126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41928	 89524	 0.080104	 0.15861	 0.00233	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41928	 89692	 0.2851	 0.20616	 0.00313	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41929	 89524	 0.15642	 0.1151	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89522	 41930	 0.15207	 0.15361	 0.00203	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41930	 89523	 0.019464	 0.050035	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41931	 41933	 0.025294	 0.0253	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41931	 89523	 0.010843	 0.021469	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88854	 41932	 0.002638	 0.02399	 0.00606	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41932	 89523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41932	 89523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41934	 41935	 0.004558	 0.03058	 0.00738	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88854	 41934	 0.00223	 0.013061	 0.00356	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88852	 41935	 0.003886	 0.035346	 0.00892	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41935	 89524	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41935	 89524	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88853	 41936	 0.056227	 0.18758	 0.00297	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89524	 41936	 0.038223	 0.14646	 0.00414	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41936	 89881	 0.057529	 0.19654	 0.00427	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41937	 42852	 0.010904	 0.043657	 0.011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41937	 43020	 0.010018	 0.042401	 0.00954	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41938	 41965	 0.01046	 0.047992	 0.0123	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41938	 43020	 0.019977	 0.069919	 0.02318	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41939	 42019	 0.003765	 0.049004	 0.01416	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41939	 42523	 0.004425	 0.036753	 0.01438	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41939	 89525	 0.010369	 0.037725	 0.01155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41940	 41942	 0.001613	 0.015182	 0.0046	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41940	 42651	 0.010833	 0.051278	 0.01233	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41941	 41942	 0.003515	 0.034343	 0.00964	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41941	 89525	 0.006537	 0.027214	 0.00849	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88901	 41942	 0.042061	 0.19328	 0.04963	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41942	 89525	 0.002999	 0.0262	 0.01038	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41943	 42022	 0.001548	 0.016875	 0.0681	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41943	 89525	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41943	 89525	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41944	 42155	 0.011766	 0.031588	 0.00716	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88840	 41944	 0.004227	 0.016922	 0.00426	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88922	 41944	 0.001054	 0.008867	 0.00263	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88839	 41945	 0.000339	 0.004505	 0.00962	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41946	 89528	 0.023571	 0.059946	 0.00095	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41946	 89529	 0.076763	 0.1176	 0.00165	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41946	 89610	 0.057669	 0.16366	 0.00257	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41946	 89671	 0.040799	 0.13611	 0.00216	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88871	 41947	 0.003895	 0.027203	 0.04671	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	41947	 89526	 0.000187	 0.002882	 0.00635	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	41948	 89526	 0.000125	 0.009999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41949	 41950	 0.012665	 0.034004	 0.00771	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89527	 41949	 0.006147	 0.014269	 0.00435	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41949	 89529	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41949	 89529	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88872	 41950	 0.00829	 0.02257	 0.00497	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41950	 89530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41950	 89530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88840	 41951	 0.002575	 0.01464	 0.00424	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41951	 89531	 0.002161	 0.021844	 0.00642	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41952	 89531	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41952	 89531	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41953	 42366	 0.000283	 0.004493	 0.07377	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41954	 41955	 0.015985	 0.10564	 0.00208	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41954	 41956	 0.011563	 0.078455	 0.00146	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41954	 43019	 0.039825	 0.19763	 0.00471	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89520	 41954	 0.071839	 0.33302	 0.00639	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41955	 42853	 0.023416	 0.16918	 0.00319	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41956	 89912	 0.041943	 0.25791	 0.00465	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41957	 41959	 0.014575	 0.040647	 0.00853	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41957	 42393	 0.020862	 0.069608	 0.01766	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41958	 89532	 0.032246	 0.098926	 0.00268	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41958	 89533	 0.031288	 0.12172	 0.00203	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41959	 43653	 0.018364	 0.048538	 0.01136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41959	 89532	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41959	 89532	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41960	 43654	 0.070182	 0.22603	 0.00385	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88805	 41960	 0.032593	 0.099989	 0.00271	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88805	 41961	 0.03445	 0.027264	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41963	 42391	 0.022034	 0.086631	 0.02267	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41963	 89533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41963	 89533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41964	 41965	 0.006426	 0.032286	 0.0084	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41964	 42618	 0.023925	 0.12228	 0.03079	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41966	 41967	 0.016832	 0.043701	 0.01061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41966	 43002	 0.010441	 0.036391	 0.00844	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41966	 89534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41966	 89534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41967	 43480	 0.011744	 0.04029	 0.00965	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41968	 42385	 0.016318	 0.055983	 0.01341	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41969	 41972	 0.009205	 0.024713	 0.0056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41969	 42752	 0.004158	 0.010988	 0.00257	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41970	 89535	 0.27124	 0.19613	 0.00297	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41970	 89834	 0.2524	 0.19788	 0.00254	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41971	 41972	 0.015698	 0.042741	 0.00942	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41971	 41981	 0.015362	 0.041826	 0.00922	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41972	 42751	 0.014972	 0.038872	 0.00944	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41972	 89535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41972	 89535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41973	 89536	 0.20488	 0.15718	 0.00211	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41973	 89537	 0.17858	 0.17914	 0.0029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41974	 41975	 0.019997	 0.050273	 0.01303	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41974	 42751	 0.019793	 0.067909	 0.01627	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41974	 43027	 0.01293	 0.038123	 0.00887	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41974	 89536	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41974	 89536	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41975	 41977	 0.014012	 0.036378	 0.00883	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41975	 89537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41975	 89537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41976	 41977	 0.00442	 0.011681	 0.00273	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41976	 42156	 0.021334	 0.071895	 0.01787	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41976	 89538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41976	 89538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41977	 42924	 0.010587	 0.030367	 0.00747	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41977	 89539	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41977	 89539	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89538	 41978	 0.014194	 0.028104	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89539	 41978	 0.055484	 0.04391	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41979	 41980	 0.14362	 0.096479	 0.0017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89539	 41979	 0.10167	 0.080463	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89537	 41980	 0.24638	 0.18671	 0.00257	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41980	 89611	 0.022043	 0.13397	 0.00247	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41980	 89807	 0.48044	 0.35378	 0.00517	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88788	 41981	 0.070115	 0.16301	 0.04975	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41981	 89614	 0.033357	 0.086627	 0.02103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41982	 41985	 0.012869	 0.040024	 0.00835	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41982	 42129	 0.018974	 0.05015	 0.01174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41982	 89540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41982	 89540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41983	 41984	 0.007912	 0.033488	 0.00754	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41983	 41987	 0.009365	 0.05324	 0.01541	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41983	 42144	 0.006568	 0.037338	 0.01081	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41983	 42145	 0.012025	 0.031781	 0.00744	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41984	 41987	 0.003185	 0.027128	 0.00677	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41984	 89541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41984	 89541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41985	 41986	 0.006511	 0.022691	 0.00526	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41986	 41990	 0.010415	 0.042385	 0.01033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41986	 89542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41986	 89542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41987	 41988	 0.009586	 0.039009	 0.0095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41987	 89543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41987	 89543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89515	 41989	 0.096928	 0.27806	 0.00428	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89542	 41989	 0.083274	 0.23888	 0.00367	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41989	 89906	 0.08079	 0.20941	 0.00396	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41990	 42986	 0.005666	 0.033755	 0.00888	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	41991	 41994	 0.007942	 0.031799	 0.00801	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41991	 42718	 0.008625	 0.0339	 0.00887	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	41992	 41994	 0.012541	 0.033734	 0.00946	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41992	 89544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41992	 89544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88867	 41993	 0.006276	 0.02153	 0.00516	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	41993	 89545	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41993	 89545	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41994	 41996	 0.005776	 0.017028	 0.00396	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88867	 41994	 0.007504	 0.05207	 0.01486	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41994	 89546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41994	 89546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	41995	 42003	 0.10416	 0.16763	 0.00263	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89545	 41995	 0.021238	 0.096414	 0.00209	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89546	 41995	 0.029356	 0.084198	 0.00129	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	41996	 41999	 0.005013	 0.014518	 0.0035	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	41997	 41998	 0.002324	 0.013498	 0.00318	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41997	 41999	 0.003578	 0.011937	 0.00303	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88867	 41997	 0.007892	 0.063414	 0.01783	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41998	 43193	 0.002652	 0.014552	 0.00385	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	41999	 42000	 0.004059	 0.010727	 0.00251	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42000	 42004	 0.003578	 0.009198	 0.00228	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42001	 42002	 0.002241	 0.006287	 0.00162	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42001	 43205	 0.013125	 0.039859	 0.00873	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42002	 42004	 0.002452	 0.006481	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42002	 89547	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42002	 89547	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89547	 42003	 0.075162	 0.082671	 0.0011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42005	 42006	 0.012483	 0.033514	 0.0076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42006	 42007	 0.002804	 0.012863	 0.0033	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42006	 89548	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42006	 89548	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88851	 42007	 0.002657	 0.023541	 0.00627	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42008	 42012	 0.000463	 0.005247	 0.04777	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42008	 42018	 0.0003	 0.005745	 0.09691	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42008	 42835	 0.001776	 0.029613	 0.31349	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42008	 89549	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42008	 89549	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42009	 42015	 0.003532	 0.021197	 0.00642	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42009	 43012	 0.009194	 0.058238	 0.01581	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42010	 89550	 0.001821	 0.026286	 0.00835	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42011	 89551	 0.023884	 0.14685	 0.00265	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42011	 89553	 0.030332	 0.11801	 0.00197	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42012	 89550	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42012	 89550	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42013	 42014	 0.014907	 0.034608	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42013	 89551	 0.015783	 0.03541	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42014	 89762	 0.10293	 0.27215	 0.00494	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42015	 42017	 0.002078	 0.013589	 0.00346	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42016	 89551	 0.020628	 0.016325	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42017	 42601	 0.013587	 0.070444	 0.0172	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42017	 89551	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42017	 89551	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42017	 89552	 0.000582	 0.008889	 0.00286	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81861	 42018	 0.00307	 0.032573	 0.48901	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81861	 42018	 0.00307	 0.032573	 0.48901	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81861	 42018	 0.00307	 0.032573	 0.48901	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42018	 89552	 0.000119	 0.009548	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42019	 42527	 0.009711	 0.040098	 0.00949	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42019	 89555	 0.002669	 0.028292	 0.0084	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42020	 42568	 0.058437	 0.13426	 0.00204	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42020	 89554	 0.18303	 0.12967	 0.00205	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42020	 89753	 0.047826	 0.11104	 0.00165	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42020	 89779	 0.1351	 0.5724	 0.01081	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42021	 42566	 0.003899	 0.02065	 0.00523	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42021	 89554	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42021	 89554	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42021	 89555	 0.005251	 0.025627	 0.00708	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42022	 46951	 0.001132	 0.013129	 0.04667	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42022	 89555	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89556	 42022	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42023	 49687	 0.016984	 0.082446	 0.01885	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89555	 42023	 0.008809	 0.030218	 0.00724	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89554	 42024	 0.24246	 0.19192	 0.00242	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42025	 42028	 0.006765	 0.039628	 0.0108	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42025	 42029	 0.008561	 0.050145	 0.01366	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42025	 42928	 0.010199	 0.059748	 0.01628	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42025	 89557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42025	 89557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42026	 43502	 0.042523	 0.10143	 0.00227	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42026	 43503	 0.060269	 0.11933	 0.00175	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42026	 45804	 0.12542	 0.099258	 0.00125	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42026	 89558	 0.034229	 0.10303	 0.00201	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42026	 90103	 0.023512	 0.10477	 0.00178	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42027	 42028	 0.008763	 0.030063	 0.0072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42027	 89558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42027	 89558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42028	 42029	 0.011177	 0.029539	 0.00691	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42029	 43597	 0.013529	 0.053179	 0.01391	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42029	 89559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42029	 89559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42029	 90083	 0.019699	 0.13225	 0.03196	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89559	 42030	 0.071255	 0.18318	 0.00284	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42030	 89885	 0.043548	 0.14528	 0.0023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42031	 89562	 0.25069	 0.19844	 0.0025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42032	 42033	 0.001414	 0.014662	 0.03158	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42032	 42033	 0.001414	 0.014662	 0.03158	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88924	 42032	 0.001047	 0.01136	 0.02229	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88924	 42032	 0.001047	 0.01136	 0.02229	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42032	 89560	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42032	 89560	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88912	 42033	 0.001476	 0.016581	 0.03034	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88912	 42033	 0.001476	 0.016581	 0.03034	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42033	 89561	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89562	 42033	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42034	 42731	 0.013143	 0.051662	 0.01352	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89561	 42034	 0.006318	 0.030112	 0.00872	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42035	 42041	 0.023287	 0.02352	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42035	 42443	 0.01227	 0.024294	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42036	 42037	 0.010043	 0.028804	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42036	 89565	 0.03415	 0.037561	 0.0005	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42037	 42038	 0.011501	 0.029248	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42037	 42431	 0.004479	 0.027538	 0.0005	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42038	 89563	 0.017116	 0.033888	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42039	 42040	 0.021114	 0.016709	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42040	 89563	 0.029121	 0.019562	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42040	 89564	 0.01686	 0.017029	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88920	 42041	 0.030573	 0.051503	 0.00073	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42041	 89563	 0.005421	 0.016317	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42042	 42043	 0.002057	 0.00517	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42042	 42045	 0.005157	 0.013388	 0.00325	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42042	 89563	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42042	 89563	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42043	 42044	 0.002243	 0.006107	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42043	 89564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42043	 89564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42044	 42049	 0.002935	 0.007756	 0.00182	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88890	 42045	 0.01139	 0.03058	 0.00693	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42045	 89565	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42045	 89565	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42046	 89566	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42046	 89566	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42046	 89568	 0.002268	 0.025922	 0.00791	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42047	 42422	 0.004897	 0.02492	 0.00903	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42047	 89567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42047	 89567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42047	 89568	 0.003822	 0.022938	 0.00695	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89421	 42048	 0.001696	 0.011442	 0.02107	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42048	 89568	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42048	 89568	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42049	 42113	 0.001751	 0.004627	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42050	 42113	 0.002027	 0.004885	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88890	 42050	 0.007907	 0.021228	 0.00481	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42050	 89569	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42050	 89569	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42051	 42052	 0.005885	 0.009914	 0.00014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42051	 89570	 0.019188	 0.012423	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42052	 42063	 0.006956	 0.018028	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42052	 89595	 0.01883	 0.014902	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42053	 42054	 0.001008	 0.002616	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42053	 42055	 0.001052	 0.002825	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42054	 42113	 0.000898	 0.002503	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42055	 42056	 0.000961	 0.002416	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42056	 42057	 0.001145	 0.002657	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42057	 42062	 0.003192	 0.008436	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42057	 42116	 0.001792	 0.004997	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42057	 89570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42057	 89570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42058	 42066	 0.009735	 0.022597	 0.00688	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42058	 42116	 0.002143	 0.005662	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42059	 42063	 0.006917	 0.017781	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89566	 42059	 0.00852	 0.057805	 0.00108	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42059	 89571	 0.006551	 0.026217	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42060	 42073	 0.029051	 0.083324	 0.00128	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42060	 89571	 0.027327	 0.027407	 0.00044	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42061	 42062	 0.002468	 0.006205	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42061	 42069	 0.003407	 0.011874	 0.00275	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42062	 89571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42062	 89571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89566	 42064	 0.014114	 0.050419	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89569	 42064	 0.014935	 0.038391	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42065	 42067	 0.017466	 0.031393	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42066	 42072	 0.000744	 0.005499	 0.00159	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89455	 42066	 0.005177	 0.013898	 0.00315	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42066	 89572	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42066	 89572	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89572	 42067	 0.008499	 0.023219	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42068	 89573	 0.040086	 0.029493	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42068	 89574	 0.026564	 0.052595	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42069	 42071	 0.004436	 0.016064	 0.00345	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42069	 89573	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42069	 89573	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42070	 42072	 0.00062	 0.003403	 0.0009	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42070	 42077	 0.000578	 0.00347	 0.00105	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42071	 42074	 0.002044	 0.01532	 0.00374	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42071	 89574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42071	 89574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42072	 89575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42072	 89575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42073	 89576	 0.018891	 0.048561	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42074	 89576	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42074	 89576	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42074	 89594	 0.002812	 0.01729	 0.00499	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42075	 42110	 0.000231	 0.00375	 0.03655	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42075	 89577	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89578	 42075	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42076	 42078	 0.002226	 0.007789	 0.00258	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89499	 42076	 0.013223	 0.034331	 0.00833	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42076	 89579	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42076	 89579	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42077	 42078	 0.002096	 0.005441	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42077	 42115	 0.001147	 0.008642	 0.0024	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42077	 89580	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42077	 89580	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42078	 42079	 0.00105	 0.00473	 0.00126	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42078	 89581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42078	 89581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42079	 42084	 0.000885	 0.006782	 0.00182	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42079	 89582	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42079	 89582	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42080	 42082	 0.002167	 0.007847	 0.00168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88906	 42080	 0.006111	 0.017042	 0.00358	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42080	 89583	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42080	 89583	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42081	 42082	 0.001464	 0.005956	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42081	 42084	 0.00175	 0.004624	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42081	 42088	 0.001056	 0.006488	 0.00237	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42083	 42084	 0.001579	 0.005743	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42083	 42091	 0.003583	 0.009302	 0.00226	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42083	 89594	 0.004164	 0.017193	 0.00407	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42085	 42089	 0.000675	 0.005426	 0.00153	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88906	 42085	 0.004644	 0.012056	 0.00293	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42086	 42100	 0.006678	 0.01066	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88907	 42086	 0.036937	 0.067654	 0.00117	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42086	 89587	 0.008778	 0.022563	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42086	 89593	 0.011187	 0.029572	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42087	 42088	 0.002248	 0.006827	 0.0015	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42087	 89584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42087	 89584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42087	 89596	 0.002394	 0.008342	 0.00193	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42088	 89590	 0.003191	 0.020213	 0.00549	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42089	 42098	 0.000307	 0.002998	 0.00084	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89581	 42090	 0.048662	 0.087467	 0.00157	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42090	 89586	 0.008178	 0.016735	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42091	 42095	 0.001646	 0.004232	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42092	 42093	 0.005845	 0.011572	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42092	 89588	 0.005888	 0.018064	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42093	 89585	 0.014193	 0.011682	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42094	 42095	 0.000887	 0.003486	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42094	 42096	 0.0008	 0.002789	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42094	 89585	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42094	 89585	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42095	 89586	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42095	 89586	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42096	 42102	 0.000773	 0.002603	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42097	 42098	 0.000608	 0.003848	 0.00104	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42097	 89596	 0.000433	 0.003374	 0.00101	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42098	 42099	 0.000924	 0.002874	 0.0006	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42099	 42101	 0.00065	 0.00219	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42099	 89587	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42099	 89587	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42099	 89596	 0.001003	 0.005874	 0.0016	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42101	 42107	 0.000572	 0.001963	 0.00047	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42102	 42103	 0.000684	 0.003751	 0.00099	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42102	 89596	 0.001027	 0.004037	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42103	 89588	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42103	 89588	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42103	 89590	 0.000515	 0.005457	 0.00162	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42104	 42146	 0.000292	 0.003201	 0.03109	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42104	 42152	 0.000157	 0.002704	 0.04709	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42104	 89589	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42105	 42106	 0.000566	 0.00189	 0.00048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42105	 89596	 0.000826	 0.002757	 0.0007	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42106	 42107	 0.000912	 0.003043	 0.00077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42107	 89592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42107	 89592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89592	 42108	 0.009781	 0.010758	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42109	 89593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42109	 89593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42109	 89606	 0.004758	 0.016583	 0.00385	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42110	 89594	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42110	 89594	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42111	 42112	 0.024789	 0.044555	 0.0008	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89591	 42111	 0.020028	 0.063594	 0.00111	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42113	 42116	 0.003525	 0.009315	 0.00218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42113	 89595	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42113	 89595	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89497	 42114	 0.001658	 0.020016	 0.04214	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89589	 42114	 0.000208	 0.002128	 0.00676	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42114	 89596	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89597	 42114	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89594	 42115	 0.0014	 0.015011	 0.0048	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42115	 89598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42115	 89598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42116	 89599	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42116	 89599	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42117	 42119	 0.008602	 0.026122	 0.00572	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42117	 42127	 0.008789	 0.028666	 0.00761	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42117	 43180	 0.00554	 0.033005	 0.00868	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42118	 42123	 0.004342	 0.017383	 0.00438	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42118	 43186	 0.007483	 0.02941	 0.00769	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42119	 42124	 0.002146	 0.018724	 0.00514	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42119	 43182	 0.008137	 0.027915	 0.00669	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88833	 42120	 0.083669	 0.16399	 0.00246	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42121	 42122	 0.004211	 0.012674	 0.00397	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42121	 42145	 0.007221	 0.024331	 0.00605	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42122	 42123	 0.002601	 0.007254	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42123	 42124	 0.001474	 0.011296	 0.00303	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42124	 42134	 0.007089	 0.018736	 0.00439	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42125	 89600	 0.055124	 0.043624	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42126	 42127	 0.008968	 0.0237	 0.00555	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42126	 42133	 0.003074	 0.008124	 0.0019	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42126	 42135	 0.002215	 0.008864	 0.00299	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42126	 42144	 0.004854	 0.022269	 0.0057	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42126	 89600	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42126	 89600	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42127	 42132	 0.006638	 0.02277	 0.00545	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89600	 42128	 0.080984	 0.18801	 0.00358	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42128	 89992	 0.22235	 0.17059	 0.00229	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42129	 42130	 0.010349	 0.026868	 0.00652	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42130	 42131	 0.005966	 0.014376	 0.00406	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42130	 89601	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42130	 89601	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42131	 42132	 0.00512	 0.013532	 0.00317	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42132	 42133	 0.002646	 0.006869	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42133	 42134	 0.001819	 0.006128	 0.00152	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42134	 42142	 0.001373	 0.004711	 0.00113	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42134	 89602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42134	 89602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42135	 42136	 0.00111	 0.003808	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42135	 42142	 0.000975	 0.00318	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42136	 42140	 0.000549	 0.004011	 0.00103	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42136	 42142	 0.00166	 0.004388	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42136	 89603	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42136	 89603	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89603	 42137	 0.017009	 0.01346	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89600	 42138	 0.023452	 0.046433	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89603	 42138	 0.007301	 0.01494	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89603	 42139	 0.022658	 0.037788	 0.00055	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42140	 42141	 0.000493	 0.003356	 0.00114	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42141	 42145	 0.003331	 0.02676	 0.00752	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42142	 42144	 0.001959	 0.010412	 0.00242	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42142	 89604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42142	 89604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89604	 42143	 0.009732	 0.016767	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42143	 89605	 0.014701	 0.037791	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88863	 42144	 0.008104	 0.11811	 0.03785	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42144	 89605	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42144	 89605	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42145	 42367	 0.009705	 0.081641	 0.02419	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42146	 43070	 0.000511	 0.005713	 0.05337	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42146	 43134	 0.000908	 0.010293	 0.09372	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42146	 89606	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89606	 42147	 0.002974	 0.016392	 0.00383	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42147	 89608	 0.002356	 0.018806	 0.00464	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42148	 42149	 0.013336	 0.008634	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89591	 42148	 0.006396	 0.021849	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42148	 89935	 0.02381	 0.065952	 0.00109	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42149	 42151	 0.020991	 0.015443	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42150	 42151	 0.026217	 0.020748	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89591	 42150	 0.013279	 0.03377	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89607	 42151	 0.041655	 0.054747	 0.00075	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42152	 42153	 0.000287	 0.002899	 0.04771	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42152	 42153	 0.000287	 0.002899	 0.04771	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42152	 89608	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42152	 89608	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42153	 42331	 0.000585	 0.00758	 0.16959	 1646.0	 1728.3	 1810.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42153	 89609	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42153	 89609	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42154	 89610	 0.087005	 0.10607	 0.0017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42154	 89669	 0.054793	 0.1307	 0.00293	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42155	 89610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42155	 89610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42156	 42157	 0.009329	 0.031431	 0.00781	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42156	 89611	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42156	 89611	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42157	 42161	 0.006635	 0.026565	 0.00669	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42158	 42162	 0.01652	 0.032707	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89611	 42158	 0.1038	 0.20553	 0.00302	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42158	 89612	 0.020799	 0.041181	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42159	 42161	 0.004231	 0.010877	 0.00269	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42159	 42628	 0.023633	 0.063456	 0.01438	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42159	 89614	 0.004961	 0.01729	 0.00401	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42160	 89612	 0.053966	 0.034938	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42160	 89615	 0.011441	 0.024426	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42161	 42163	 0.001192	 0.003246	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42161	 42166	 0.004361	 0.011873	 0.00262	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42161	 89612	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42161	 89612	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42161	 89614	 0.002307	 0.009238	 0.00233	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42162	 42165	 0.047838	 0.037498	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89612	 42162	 0.040187	 0.031804	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42162	 89613	 0.037328	 0.026442	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42163	 42166	 0.003339	 0.008584	 0.00213	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42163	 89613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42163	 89613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42164	 89614	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89613	 42165	 0.027313	 0.020951	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89615	 42165	 0.01346	 0.034231	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42165	 89616	 0.031278	 0.020249	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42165	 89617	 0.069001	 0.075894	 0.00101	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42166	 42168	 0.005044	 0.013096	 0.00318	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89614	 42166	 0.004216	 0.014901	 0.00336	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42166	 89616	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42166	 89616	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42167	 89617	 0.080409	 0.06303	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42168	 42169	 0.007491	 0.022086	 0.00514	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42168	 89617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42168	 89617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42169	 42170	 0.007887	 0.022843	 0.00551	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89522	 42171	 0.23119	 0.183	 0.0023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89617	 42171	 0.26855	 0.21258	 0.00268	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42172	 42178	 0.000446	 0.003952	 0.00812	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42172	 89618	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89619	 42172	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42173	 42174	 0.001325	 0.005606	 0.00126	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42173	 45879	 0.001119	 0.008703	 0.00226	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89618	 42173	 0.003378	 0.009069	 0.00206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42174	 42175	 0.001362	 0.005544	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42175	 42180	 0.002147	 0.007775	 0.00167	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42175	 89620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42175	 89620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42176	 42179	 0.001571	 0.005476	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89618	 42176	 0.001371	 0.005488	 0.00138	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42176	 89621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42176	 89621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42176	 89622	 0.001323	 0.007883	 0.00207	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89620	 42177	 0.013461	 0.017692	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89621	 42177	 0.006092	 0.009332	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42178	 42215	 0.000665	 0.004487	 0.00826	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42178	 42226	 0.000651	 0.004484	 0.00791	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42178	 89622	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42178	 89622	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42179	 42180	 0.001405	 0.004734	 0.00118	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42179	 89623	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42179	 89623	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42180	 89637	 0.000796	 0.006619	 0.002	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42181	 42395	 0.036346	 0.063919	 0.0012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42181	 45890	 0.017933	 0.041627	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42182	 42185	 0.001938	 0.007618	 0.00199	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42182	 45892	 0.002928	 0.011915	 0.0029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42182	 89624	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42182	 89624	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42183	 42395	 0.052163	 0.040888	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42183	 89625	 0.057685	 0.045217	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42184	 42185	 0.001486	 0.005648	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42184	 42197	 0.00272	 0.011511	 0.00259	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42184	 89625	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42184	 89625	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42186	 42187	 0.023076	 0.027624	 0.00046	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42186	 89667	 0.016509	 0.068912	 0.00199	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42187	 42192	 0.041659	 0.029509	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42187	 42196	 0.040179	 0.067105	 0.00114	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42187	 89628	 0.015889	 0.045571	 0.0007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42188	 42190	 0.012549	 0.029133	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42188	 42408	 0.038958	 0.03978	 0.00062	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88874	 42188	 0.13137	 0.23108	 0.00434	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42188	 89626	 0.018516	 0.047596	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42189	 42208	 0.003169	 0.017943	 0.00445	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42189	 42406	 0.002159	 0.008642	 0.00218	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42189	 89626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42189	 89626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42190	 42206	 0.024228	 0.024299	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42191	 42209	 0.017494	 0.04497	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89626	 42191	 0.010305	 0.033182	 0.00057	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42191	 89659	 0.031478	 0.056578	 0.00102	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42192	 89627	 0.023529	 0.018621	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42193	 42208	 0.007893	 0.019841	 0.00514	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42193	 42220	 0.005325	 0.013385	 0.00347	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42193	 89627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42193	 89627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89627	 42194	 0.031143	 0.020162	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42195	 42197	 0.002548	 0.008739	 0.00209	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42195	 42207	 0.002403	 0.008703	 0.00187	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42196	 42199	 0.029209	 0.023115	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42197	 89628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42197	 89628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42198	 42199	 0.005734	 0.010502	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89627	 42198	 0.008389	 0.019865	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42199	 42205	 0.030629	 0.022534	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42200	 42203	 0.001102	 0.003857	 0.00128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42200	 42267	 0.004404	 0.014839	 0.00369	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42201	 42203	 0.002574	 0.006682	 0.00162	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42201	 89629	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42201	 89629	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42201	 89632	 0.008376	 0.02822	 0.00701	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42202	 89630	 0.020515	 0.015093	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42203	 42211	 0.001416	 0.005761	 0.0014	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42203	 89630	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42203	 89630	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42204	 42205	 0.011828	 0.023417	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42204	 42209	 0.054007	 0.042741	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42204	 89631	 0.003914	 0.015057	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89630	 42205	 0.045685	 0.030688	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42206	 89631	 0.018361	 0.014392	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42207	 42208	 0.000799	 0.00201	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42207	 89631	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42207	 89631	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42208	 42210	 0.000731	 0.002779	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89629	 42209	 0.090866	 0.071911	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42210	 42211	 0.000974	 0.003901	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42212	 42218	 0.011464	 0.022699	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42212	 42244	 0.012646	 0.025038	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42212	 89633	 0.008707	 0.04795	 0.00108	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42212	 89635	 0.016505	 0.042428	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42213	 42214	 0.001771	 0.004112	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42213	 42220	 0.003006	 0.007943	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42214	 89632	 0.002226	 0.006208	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42215	 42284	 0.003685	 0.025005	 0.04554	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88861	 42215	 0.000942	 0.006205	 0.01201	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42215	 89632	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89633	 42215	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42216	 42217	 0.000633	 0.004476	 0.00123	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89632	 42216	 0.001047	 0.006506	 0.00184	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42217	 42219	 0.001319	 0.006505	 0.00176	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42217	 89634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42217	 89634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89634	 42218	 0.020993	 0.018811	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42218	 89644	 0.0057	 0.019958	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42219	 42222	 0.00122	 0.005494	 0.00146	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42219	 42256	 0.002104	 0.008903	 0.002	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42219	 42257	 0.00298	 0.014971	 0.0039	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42219	 89635	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42219	 89635	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42220	 42223	 0.001108	 0.005465	 0.00148	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42220	 42321	 0.001986	 0.015475	 0.00463	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89629	 42221	 0.016262	 0.032198	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42221	 89636	 0.024344	 0.01576	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42222	 42224	 0.00068	 0.003527	 0.00086	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42222	 89636	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42222	 89636	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42223	 42225	 0.000595	 0.002941	 0.00086	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42224	 42225	 0.000651	 0.00327	 0.00085	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88861	 42226	 0.000291	 0.001965	 0.00362	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42226	 89637	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42226	 89637	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42227	 42233	 0.000454	 0.003094	 0.00105	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88862	 42227	 0.000634	 0.004636	 0.00137	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42228	 42230	 0.001615	 0.004193	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88862	 42228	 0.003643	 0.010742	 0.0025	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42229	 42322	 0.008185	 0.008186	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42229	 89638	 0.018486	 0.014629	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89622	 42230	 0.001907	 0.007874	 0.00186	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89632	 42230	 0.00084	 0.004775	 0.00138	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42231	 42240	 0.001179	 0.004719	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89632	 42231	 0.001285	 0.004884	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42231	 89638	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42231	 89638	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42232	 89639	 0.004974	 0.0126	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42232	 89643	 0.007997	 0.01225	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42232	 89644	 0.003683	 0.014168	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42233	 42236	 0.000492	 0.003025	 0.00087	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42233	 89639	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42233	 89639	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88861	 42234	 0.000136	 0.001071	 0.00372	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42234	 89640	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89641	 42234	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42235	 42237	 0.000756	 0.002972	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42235	 42239	 0.001168	 0.004592	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42235	 42243	 0.000837	 0.002211	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42235	 42245	 0.0007	 0.004344	 0.00105	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89640	 42235	 0.00071	 0.006086	 0.00173	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42235	 89642	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42235	 89642	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42236	 42237	 0.000194	 0.00203	 0.00068	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89640	 42236	 0.000625	 0.003778	 0.00096	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42236	 89643	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42236	 89643	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42237	 42243	 0.00049	 0.002869	 0.00078	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89642	 42238	 0.009153	 0.015203	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42238	 89645	 0.025736	 0.016662	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42239	 42242	 0.001439	 0.004013	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42239	 42246	 0.0005	 0.00293	 0.0008	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42240	 42241	 0.000736	 0.002995	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42240	 89644	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42240	 89644	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42241	 42242	 0.000779	 0.003119	 0.00079	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42242	 89645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42242	 89645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42243	 42245	 0.000526	 0.003331	 0.0009	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42244	 42251	 0.004716	 0.015732	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89645	 42244	 0.002666	 0.010412	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42245	 42246	 0.000473	 0.002409	 0.00087	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42245	 89646	 0.000689	 0.004284	 0.00121	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42246	 42247	 0.00085	 0.004831	 0.0014	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42246	 89646	 0.000399	 0.002527	 0.00069	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42247	 42249	 0.000657	 0.003721	 0.00092	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42247	 89646	 0.000477	 0.002793	 0.00076	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42248	 42252	 0.007794	 0.020603	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42248	 89647	 0.003557	 0.02187	 0.00039	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42248	 89648	 0.013516	 0.03138	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42249	 42253	 0.001075	 0.005496	 0.0015	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42250	 89646	 0.000123	 0.009866	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89647	 42251	 0.014437	 0.021407	 0.00032	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42252	 42255	 0.005528	 0.03106	 0.00058	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89647	 42252	 0.005928	 0.040223	 0.00075	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42252	 89648	 0.010197	 0.018959	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42252	 89653	 0.033897	 0.030374	 0.00062	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42253	 42254	 0.001938	 0.008724	 0.00232	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42253	 89648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42253	 89648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42254	 42311	 0.001327	 0.006441	 0.00147	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42254	 89649	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42254	 89649	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42255	 42303	 0.010094	 0.039267	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89649	 42255	 0.030418	 0.025037	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42256	 42259	 0.00162	 0.006158	 0.00172	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42257	 42263	 0.002217	 0.007469	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42257	 42269	 0.002397	 0.007066	 0.00164	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42257	 89650	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42257	 89650	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42258	 42263	 0.001359	 0.003494	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42258	 89651	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42258	 89651	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42259	 42261	 0.002712	 0.009045	 0.00229	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42259	 89652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42259	 89652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42260	 42261	 0.003429	 0.011949	 0.00277	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89646	 42260	 0.002301	 0.013707	 0.00361	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42260	 89653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42260	 89653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42261	 42323	 0.002257	 0.009554	 0.00215	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42262	 42264	 0.002642	 0.013736	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42262	 42293	 0.008327	 0.023882	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42262	 89663	 0.032778	 0.02594	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42263	 89654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42263	 89654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89654	 42264	 0.003182	 0.016091	 0.00031	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42265	 42266	 0.001638	 0.006372	 0.0017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42265	 42269	 0.001759	 0.006371	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42265	 89655	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42265	 89655	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42266	 42290	 0.001587	 0.005444	 0.0013	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42266	 89656	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42266	 89656	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42267	 89657	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42267	 89657	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42267	 89660	 0.009679	 0.026991	 0.00567	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42268	 42270	 0.032652	 0.03266	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89657	 42268	 0.00889	 0.031104	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42268	 89658	 0.008657	 0.020499	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42269	 89658	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42269	 89658	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42270	 42281	 0.016033	 0.032809	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42270	 42283	 0.021041	 0.04306	 0.00106	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89656	 42270	 0.014746	 0.037905	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89657	 42270	 0.018339	 0.052042	 0.00082	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42271	 42281	 0.047028	 0.051223	 0.0007	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89656	 42271	 0.023181	 0.018345	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42272	 89659	 0.011879	 0.03407	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42272	 89700	 0.008936	 0.027413	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42273	 42275	 0.013089	 0.033647	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42273	 42415	 0.012057	 0.030993	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42274	 42402	 0.009363	 0.037486	 0.00944	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42274	 89659	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42274	 89659	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42274	 89660	 0.00384	 0.027625	 0.00732	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42275	 42277	 0.042896	 0.033947	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42275	 42283	 0.01634	 0.046864	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42275	 89661	 0.016295	 0.049988	 0.00135	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42275	 89708	 0.019811	 0.060774	 0.00165	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42276	 42278	 0.01331	 0.034213	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42276	 89708	 0.011687	 0.038988	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42278	 42280	 0.013938	 0.033004	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42279	 42280	 0.008287	 0.03224	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89188	 42279	 0.032135	 0.09217	 0.00142	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42279	 89710	 0.006814	 0.038734	 0.0007	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42280	 42287	 0.006418	 0.022928	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42280	 89661	 0.0286	 0.054054	 0.00087	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42281	 42282	 0.055057	 0.05507	 0.00074	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42282	 42286	 0.009005	 0.030039	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42282	 42295	 0.012014	 0.030884	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89189	 42282	 0.033441	 0.056335	 0.0008	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42283	 89661	 0.026406	 0.029044	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89202	 42284	 0.002376	 0.016365	 0.02889	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42284	 89660	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89661	 42284	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42285	 42286	 0.003771	 0.013202	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42285	 42287	 0.009698	 0.02752	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89661	 42285	 0.002753	 0.015648	 0.00028	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42286	 42288	 0.010123	 0.023501	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89190	 42287	 0.020371	 0.051601	 0.00102	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89661	 42288	 0.016008	 0.043732	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42289	 42323	 0.006008	 0.020244	 0.00503	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89183	 42289	 0.004188	 0.010766	 0.00267	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42289	 89662	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42289	 89662	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42290	 89663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42290	 89663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42291	 42292	 0.00702	 0.017781	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89656	 42291	 0.014094	 0.032715	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89663	 42291	 0.013677	 0.020951	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42292	 42298	 0.022555	 0.037995	 0.00054	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42293	 42301	 0.017356	 0.040287	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89663	 42293	 0.011339	 0.026326	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42294	 42301	 0.030442	 0.022397	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42295	 42296	 0.008376	 0.021531	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42296	 42298	 0.017528	 0.019091	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42297	 42298	 0.021921	 0.016608	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42298	 42300	 0.019698	 0.020114	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42299	 42300	 0.015581	 0.017137	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42300	 42301	 0.029878	 0.023645	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89182	 42300	 0.01101	 0.031578	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89662	 42301	 0.015941	 0.029198	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42302	 42307	 0.015271	 0.030235	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89662	 42302	 0.010793	 0.026419	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42303	 42306	 0.007509	 0.033462	 0.00057	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42303	 89668	 0.020909	 0.041398	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42304	 42305	 0.007512	 0.037999	 0.00066	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42304	 89664	 0.003459	 0.01669	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42305	 42308	 0.003039	 0.013468	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42305	 89666	 0.008957	 0.020795	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42306	 42307	 0.006796	 0.022426	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42307	 42309	 0.008483	 0.020088	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89181	 42307	 0.031797	 0.034634	 0.00047	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42308	 42310	 0.007502	 0.017413	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89181	 42308	 0.055194	 0.035733	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42309	 42310	 0.006314	 0.016231	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89181	 42309	 0.0245	 0.016457	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42310	 42319	 0.008924	 0.022939	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42310	 42320	 0.019279	 0.015257	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42311	 42313	 0.001675	 0.006914	 0.00164	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42311	 89664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42311	 89664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42312	 42313	 0.000866	 0.003522	 0.00086	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42312	 42314	 0.001506	 0.005023	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42312	 89665	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42312	 89665	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42314	 89666	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42314	 89666	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89665	 42315	 0.011889	 0.009319	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42316	 42318	 0.003936	 0.019207	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89666	 42316	 0.00395	 0.01998	 0.00035	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42317	 42318	 0.00315	 0.015371	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42318	 42319	 0.00884	 0.014742	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88873	 42321	 0.001176	 0.011071	 0.00335	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42321	 89667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42321	 89667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89639	 42322	 0.005801	 0.011369	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42323	 89668	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42323	 89668	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42324	 42331	 0.000463	 0.005685	 0.09108	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42324	 89669	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42324	 89669	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89669	 42325	 0.027302	 0.078306	 0.0012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42325	 89670	 0.052363	 0.15762	 0.00308	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42326	 42329	 0.01145	 0.043524	 0.01218	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42326	 89670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42326	 89670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42327	 42328	 0.004784	 0.012297	 0.00304	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42327	 42365	 0.01385	 0.037184	 0.00843	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42328	 42329	 0.008998	 0.027083	 0.00847	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42329	 42330	 0.008935	 0.033966	 0.00951	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42329	 42339	 0.003315	 0.026631	 0.00749	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42330	 42334	 0.008346	 0.022059	 0.00516	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88836	 42332	 0.009624	 0.032106	 0.00814	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42332	 89671	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42332	 89671	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89671	 42333	 0.035481	 0.07025	 0.00103	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42334	 42335	 0.001856	 0.005175	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42334	 89672	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42334	 89672	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42335	 42344	 0.001293	 0.004506	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42335	 89673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42335	 89673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89672	 42336	 0.0488	 0.035904	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89673	 42336	 0.0204	 0.020405	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42337	 42338	 0.009209	 0.016551	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42337	 42341	 0.006334	 0.014485	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89670	 42337	 0.098958	 0.26166	 0.00475	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42338	 89674	 0.009707	 0.024685	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42339	 42340	 0.006641	 0.017552	 0.00411	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42339	 89674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42339	 89674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42340	 42342	 0.0049	 0.013665	 0.00287	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42340	 89675	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42340	 89675	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89675	 42341	 0.024951	 0.0494	 0.00073	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42342	 42348	 0.008859	 0.035471	 0.00894	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42343	 42344	 0.00265	 0.009366	 0.00211	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42343	 42348	 0.003792	 0.015431	 0.00376	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88916	 42343	 0.017237	 0.044313	 0.01097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88836	 42345	 0.002774	 0.013128	 0.00316	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88916	 42345	 0.001733	 0.007052	 0.00172	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42345	 89676	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42345	 89676	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42346	 42350	 0.013354	 0.034328	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42346	 42351	 0.016752	 0.02378	 0.00039	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88896	 42346	 0.23472	 0.18008	 0.00242	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89676	 42346	 0.18612	 0.14731	 0.00185	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42347	 42349	 0.007669	 0.029153	 0.00816	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42347	 42368	 0.010939	 0.038667	 0.00871	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88836	 42347	 0.010392	 0.053088	 0.01336	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42347	 89677	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42347	 89677	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42349	 42607	 0.008446	 0.043995	 0.01154	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42349	 89678	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42349	 89678	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42350	 42351	 0.003356	 0.014786	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89677	 42350	 0.009119	 0.028004	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89678	 42350	 0.050498	 0.14484	 0.00223	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89676	 42351	 0.21434	 0.16965	 0.00214	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42352	 89679	 0.018459	 0.081333	 0.00141	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42353	 42354	 0.004921	 0.020319	 0.00481	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42353	 42998	 0.011034	 0.054415	 0.01472	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42354	 42356	 0.004718	 0.016509	 0.00547	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42355	 89679	 0.041221	 0.032622	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42356	 89679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42356	 89679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42357	 89787	 0.005621	 0.022092	 0.00578	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42358	 42666	 0.000319	 0.007548	 0.13668	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42359	 42360	 0.003922	 0.013455	 0.00322	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42359	 42362	 0.002045	 0.007774	 0.00218	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88897	 42359	 0.00456	 0.012243	 0.00277	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42360	 42665	 0.007769	 0.027078	 0.00628	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42361	 42362	 0.002246	 0.01721	 0.00461	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42361	 43033	 0.002955	 0.023737	 0.00667	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88898	 42363	 0.13181	 0.20194	 0.00284	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89044	 42363	 0.55072	 0.43628	 0.00549	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42363	 89921	 0.028982	 0.14143	 0.00244	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42364	 42365	 0.011586	 0.044041	 0.01233	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88897	 42364	 0.008478	 0.048013	 0.0119	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89428	 42365	 0.015898	 0.098697	 0.02392	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42366	 89680	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42366	 89680	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88863	 42367	 0.001601	 0.016467	 0.00467	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88875	 42367	 0.027447	 0.16095	 0.04392	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89531	 42367	 0.023703	 0.079885	 0.01986	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88872	 42368	 0.014928	 0.054061	 0.0116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42368	 89681	 0.014429	 0.052252	 0.01121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42369	 43285	 0.001956	 0.02743	 0.05261	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88871	 42369	 0.003711	 0.032643	 0.06813	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42369	 89681	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89682	 42369	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42369	 89683	 0.002211	 0.015627	 0.02617	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42370	 42371	 0.000116	 0.001869	 0.01903	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42370	 89683	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42370	 89683	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42371	 42372	 0.000126	 0.001335	 0.01996	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42371	 42372	 0.000126	 0.001335	 0.01996	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42372	 42373	 0.00016	 0.0016	 0.02667	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42372	 42373	 0.00016	 0.0016	 0.02667	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42373	 42483	 0.00059	 0.006092	 0.09573	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42373	 42483	 0.00059	 0.006092	 0.09573	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42373	 89684	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42373	 89684	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42374	 42375	 0.013965	 0.036195	 0.01095	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89684	 42374	 0.01525	 0.051386	 0.01277	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42374	 89685	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42374	 89685	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42376	 42379	 0.003209	 0.021859	 0.00744	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42376	 42486	 0.008431	 0.046786	 0.01422	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42377	 89686	 0.034958	 0.10736	 0.00201	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42377	 89769	 0.086264	 0.24483	 0.00385	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42378	 42379	 0.000785	 0.008834	 0.00232	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42378	 42381	 0.00078	 0.00633	 0.00202	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42378	 89686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42378	 89686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89686	 42380	 0.010544	 0.03381	 0.00084	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42380	 89687	 0.005959	 0.026551	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42381	 42382	 0.002495	 0.029506	 0.0084	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42381	 89687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42381	 89687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42383	 42514	 0.010381	 0.042246	 0.01029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42383	 42912	 0.012472	 0.058173	 0.01441	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42384	 42388	 0.015169	 0.050607	 0.01284	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42384	 43003	 0.017498	 0.045431	 0.01103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88854	 42384	 0.041203	 0.1252	 0.02744	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42384	 89688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42384	 89688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42385	 42389	 0.013653	 0.036085	 0.00845	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42386	 89689	 0.013637	 0.03133	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42386	 89691	 0.065545	 0.051378	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42386	 89693	 0.06319	 0.14671	 0.00218	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42387	 42388	 0.000591	 0.002248	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42387	 42390	 0.003169	 0.01233	 0.00329	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42387	 89689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42387	 89689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42388	 42389	 0.002368	 0.00698	 0.00162	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42389	 89690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42389	 89690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42390	 42391	 0.003124	 0.010717	 0.00257	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42390	 42392	 0.006488	 0.022935	 0.00517	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42391	 89691	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42391	 89691	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88852	 42392	 0.027345	 0.10953	 0.02761	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42392	 89692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42392	 89692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42393	 42913	 0.013745	 0.052253	 0.01463	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42393	 89693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42393	 89693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42394	 42402	 0.007369	 0.029986	 0.00731	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42394	 46646	 0.008771	 0.034474	 0.00902	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42395	 42407	 0.046181	 0.070745	 0.00099	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42395	 42408	 0.028158	 0.055751	 0.00082	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42395	 45894	 0.033038	 0.06761	 0.00166	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88874	 42395	 0.40158	 0.31798	 0.004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42396	 42399	 0.020501	 0.098407	 0.00294	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42396	 42420	 0.041777	 0.13937	 0.00221	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42396	 89694	 0.038389	 0.098685	 0.00153	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42396	 89695	 0.012409	 0.055296	 0.00094	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42397	 42398	 0.003006	 0.012232	 0.00298	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42397	 89694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42397	 89694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42398	 43219	 0.016209	 0.094976	 0.02589	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42398	 46644	 0.008124	 0.028717	 0.00647	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42398	 46646	 0.005064	 0.031428	 0.00761	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42398	 89695	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42398	 89695	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42399	 42401	 0.013466	 0.058997	 0.00127	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42400	 42417	 0.008597	 0.015356	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42401	 89696	 0.005602	 0.02951	 0.00053	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42402	 42405	 0.003515	 0.010363	 0.00241	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42402	 89696	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42402	 89696	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42403	 42407	 0.0113	 0.02995	 0.00076	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89696	 42403	 0.003517	 0.021624	 0.00039	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89696	 42404	 0.03107	 0.033842	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42404	 89697	 0.028577	 0.026322	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42404	 89698	 0.042408	 0.098459	 0.00146	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42405	 42406	 0.00256	 0.010062	 0.00263	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42405	 42409	 0.001331	 0.014587	 0.00404	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42405	 89697	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42405	 89697	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42409	 89701	 0.001775	 0.017394	 0.00545	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42410	 42411	 0.001258	 0.007806	 0.00189	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42410	 42423	 0.001558	 0.009868	 0.00268	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42411	 42412	 0.002505	 0.0106	 0.00239	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42411	 89698	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42411	 89698	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42412	 42414	 0.003155	 0.012274	 0.00328	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42412	 89699	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42412	 89699	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42413	 42415	 0.010842	 0.027573	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89699	 42413	 0.00685	 0.02665	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42413	 89700	 0.027966	 0.041927	 0.00076	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42413	 89708	 0.021813	 0.045845	 0.00084	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42414	 89700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42414	 89700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42416	 42444	 0.000326	 0.004052	 0.0407	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42416	 89701	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42417	 42419	 0.007468	 0.015283	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89702	 42417	 0.006969	 0.047835	 0.00087	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42418	 42419	 0.013515	 0.020703	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89041	 42420	 0.024004	 0.16478	 0.003	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42420	 89703	 0.033297	 0.095501	 0.00147	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42421	 89703	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42421	 89703	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42421	 89711	 0.002594	 0.025418	 0.00796	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42422	 42426	 0.002752	 0.00918	 0.00233	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42422	 89704	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42422	 89704	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42423	 42428	 0.000269	 0.002978	 0.00089	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42423	 89705	 0.000406	 0.004988	 0.00237	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42424	 42444	 0.000258	 0.003248	 0.0495	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42424	 89705	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42424	 89705	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42425	 42432	 0.027624	 0.020324	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89705	 42426	 0.001216	 0.0073	 0.00221	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42426	 89706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42426	 89706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89702	 42427	 0.035617	 0.10216	 0.00157	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89704	 42427	 0.013163	 0.022173	 0.00032	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89706	 42427	 0.009108	 0.019142	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42428	 42429	 0.000299	 0.00317	 0.00094	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42429	 42436	 0.003468	 0.013886	 0.0035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42429	 42441	 0.002582	 0.01222	 0.00294	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42429	 42441	 0.002582	 0.01222	 0.00294	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42429	 89707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42429	 89707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42430	 42432	 0.005054	 0.018685	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42430	 42432	 0.005054	 0.018685	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42430	 42440	 0.011455	 0.029445	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42430	 89709	 0.002047	 0.015212	 0.00036	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42431	 42432	 0.005324	 0.016333	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89565	 42431	 0.022845	 0.081613	 0.00162	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89704	 42431	 0.008397	 0.045099	 0.00107	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42432	 42433	 0.022273	 0.017627	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42432	 42434	 0.033704	 0.024797	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89706	 42432	 0.006883	 0.026776	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89706	 42432	 0.006883	 0.026776	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42435	 42438	 0.013341	 0.033112	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89707	 42435	 0.005655	 0.021755	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42436	 42437	 0.00213	 0.008668	 0.00211	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42437	 89708	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42437	 89708	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89698	 42438	 0.022686	 0.047681	 0.00087	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42438	 89709	 0.007735	 0.023728	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89708	 42439	 0.010747	 0.021279	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42439	 89710	 0.044965	 0.045416	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42440	 42443	 0.009936	 0.020333	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42441	 42445	 0.001859	 0.009023	 0.00206	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42441	 89709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42441	 89709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42442	 42445	 0.001872	 0.00773	 0.00183	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42442	 89710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42442	 89710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42444	 89711	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42444	 89711	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42446	 42447	 0.003979	 0.013272	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42446	 42448	 0.022607	 0.042726	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42446	 42449	 0.002426	 0.011823	 0.00022	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42447	 42448	 0.0489	 0.03833	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42447	 89713	 0.027007	 0.044029	 0.00067	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42448	 43291	 0.31332	 0.24804	 0.00312	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42449	 42450	 0.002977	 0.011582	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42449	 42452	 0.007315	 0.013065	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42450	 89712	 0.00419	 0.01867	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42451	 42466	 0.000947	 0.005545	 0.00151	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42451	 42476	 0.002247	 0.011706	 0.00307	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42451	 89712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42451	 89712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42452	 89716	 0.004078	 0.009326	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42453	 42454	 0.005806	 0.011378	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42453	 42462	 0.00652	 0.015136	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42454	 42461	 0.018058	 0.012791	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42454	 89713	 0.008778	 0.01991	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42455	 42460	 0.0017	 0.007196	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42455	 42474	 0.005083	 0.013433	 0.00314	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88875	 42455	 0.013521	 0.035103	 0.00852	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42455	 89713	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42455	 89713	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42456	 42481	 0.14683	 0.26399	 0.00474	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89713	 42456	 0.005532	 0.014221	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42457	 42461	 0.022241	 0.029231	 0.0004	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89061	 42457	 0.29153	 0.5778	 0.00849	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42457	 89715	 0.007386	 0.015115	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42458	 42484	 0.000424	 0.002826	 0.00533	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42458	 89714	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42458	 89714	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88876	 42459	 0.09739	 0.12675	 0.00177	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42459	 89715	 0.006564	 0.012571	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42460	 42471	 0.000645	 0.005365	 0.00162	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42460	 89715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42460	 89715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42461	 42462	 0.0055	 0.012577	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89715	 42461	 0.021731	 0.015988	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42462	 89716	 0.000999	 0.006856	 0.00012	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42463	 42470	 0.000881	 0.003728	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42463	 89716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42463	 89716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89716	 42464	 0.009382	 0.007424	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42465	 42466	 0.002767	 0.009644	 0.00224	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42465	 42486	 0.00408	 0.030142	 0.0087	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42465	 89717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42465	 89717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42466	 42468	 0.000898	 0.00313	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42466	 42469	 0.001461	 0.004922	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42466	 89718	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42466	 89718	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89717	 42467	 0.004993	 0.016655	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89718	 42467	 0.026006	 0.025547	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42467	 89723	 0.011382	 0.020847	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42468	 42469	 0.000659	 0.002296	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42468	 42485	 0.001589	 0.004126	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42469	 42470	 0.000565	 0.002198	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42469	 42485	 0.00142	 0.00396	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42470	 42471	 0.001194	 0.003984	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42470	 89721	 0.001812	 0.004705	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89714	 42471	 0.004077	 0.010945	 0.00248	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42471	 89721	 0.001155	 0.003766	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42472	 42473	 0.003183	 0.008413	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42472	 42485	 0.002379	 0.006386	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42473	 89719	 0.008567	 0.022241	 0.0054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88875	 42474	 0.008449	 0.02233	 0.00523	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88876	 42475	 0.049446	 0.19238	 0.00321	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42476	 42477	 0.003446	 0.019588	 0.00567	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42477	 42959	 0.008397	 0.037418	 0.01017	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42477	 42964	 0.01899	 0.066193	 0.01535	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42477	 43290	 0.010391	 0.027463	 0.00643	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42478	 42484	 0.001691	 0.011859	 0.02019	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42478	 43284	 0.008129	 0.052813	 0.10534	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88837	 42478	 0.001967	 0.01555	 0.05398	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42478	 89719	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42478	 89719	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42479	 42480	 0.011227	 0.0331	 0.0077	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88875	 42479	 0.012663	 0.035315	 0.00741	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42481	 89720	 0.14153	 0.11202	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88875	 42482	 0.008525	 0.034692	 0.00845	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42482	 89720	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42482	 89720	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42484	 89721	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89722	 42484	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42485	 89723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42485	 89723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42486	 89724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42486	 89724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42487	 42495	 0.000911	 0.003545	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42488	 42495	 0.000556	 0.002419	 0.00069	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42488	 42496	 0.002144	 0.005666	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42488	 42511	 0.003215	 0.011027	 0.00264	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42488	 89733	 0.001191	 0.004846	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42489	 42490	 0.004774	 0.007682	 0.00012	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42489	 89729	 0.005948	 0.010895	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42490	 89725	 0.013189	 0.014507	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42490	 89729	 0.005843	 0.013564	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42490	 89734	 0.006671	 0.013709	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42491	 42499	 0.000579	 0.003666	 0.00099	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42491	 42503	 0.000547	 0.002899	 0.00097	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42491	 89725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42491	 89725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42492	 89726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42492	 89726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42492	 89733	 0.001344	 0.003963	 0.00092	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88927	 42493	 0.005207	 0.017786	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88927	 42493	 0.005207	 0.017786	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42493	 89727	 0.003526	 0.011763	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42493	 89732	 0.00156	 0.012155	 0.00023	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42494	 89727	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42494	 89727	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42494	 89731	 0.001467	 0.006055	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42496	 42497	 0.000931	 0.002746	 0.00064	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42497	 42511	 0.001469	 0.004331	 0.00101	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42498	 42520	 7.5e-05	 0.001439	 0.02426	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42498	 89728	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42498	 89728	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89728	 42499	 0.000352	 0.005085	 0.00161	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42499	 89729	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42499	 89729	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42499	 89733	 0.000838	 0.00536	 0.0018	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42500	 42501	 0.000984	 0.003444	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89728	 42500	 0.001295	 0.005181	 0.00175	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42501	 42502	 0.00143	 0.005726	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42502	 42504	 0.001166	 0.004582	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42503	 42504	 0.000439	 0.002408	 0.00064	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42504	 42518	 0.001259	 0.006708	 0.00188	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42504	 89731	 0.001826	 0.009173	 0.00239	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42505	 42520	 7.5e-05	 0.001199	 0.01947	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42505	 89730	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42505	 89730	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88927	 42506	 0.029317	 0.075362	 0.00117	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89431	 42506	 0.15232	 0.2986	 0.00448	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88927	 42507	 0.030391	 0.087166	 0.00134	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42507	 89817	 0.056135	 0.12839	 0.00313	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89727	 42508	 0.037639	 0.027209	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89727	 42509	 0.049876	 0.050022	 0.00081	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42510	 42654	 0.027948	 0.13639	 0.00235	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89727	 42510	 0.019845	 0.13623	 0.00248	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42511	 42512	 0.00416	 0.02055	 0.006	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42512	 42513	 0.002543	 0.023127	 0.00584	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42512	 42918	 0.011208	 0.044054	 0.01153	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89065	 42513	 0.004341	 0.039426	 0.01285	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89731	 42514	 0.010798	 0.043235	 0.01089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42515	 42516	 0.002865	 0.009556	 0.00242	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42515	 42517	 0.005224	 0.016244	 0.00339	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42515	 42519	 0.005739	 0.028833	 0.0075	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42516	 42518	 0.001249	 0.005003	 0.00126	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89731	 42517	 0.002173	 0.007248	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42520	 89733	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42521	 42522	 0.001317	 0.00987	 0.00241	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42521	 42901	 0.003005	 0.01655	 0.00597	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42522	 42523	 0.008578	 0.051106	 0.01345	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42522	 42637	 0.013524	 0.042276	 0.01225	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42523	 42651	 0.015978	 0.060743	 0.01701	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42524	 42525	 0.002619	 0.017976	 0.00524	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42524	 42900	 0.013487	 0.085453	 0.0232	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42525	 42527	 0.006394	 0.068623	 0.01787	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42525	 89735	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42525	 89735	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89735	 42526	 0.12684	 0.13952	 0.00186	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42527	 42528	 0.005093	 0.023366	 0.00599	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42527	 89748	 0.009051	 0.056245	 0.01588	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42528	 42569	 0.007268	 0.033896	 0.0084	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42528	 89736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42528	 89736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42529	 42530	 0.015251	 0.077147	 0.00134	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89736	 42529	 0.020323	 0.09806	 0.00173	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42529	 89738	 0.064273	 0.11598	 0.00168	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42530	 89737	 0.023171	 0.099065	 0.00224	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42531	 42532	 0.002054	 0.015977	 0.00415	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42531	 42640	 0.004068	 0.03064	 0.0085	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42532	 42533	 0.002959	 0.01874	 0.00509	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42532	 89737	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42532	 89737	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42533	 42591	 0.004985	 0.031576	 0.00857	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42533	 42592	 0.00972	 0.035196	 0.00755	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42533	 89738	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42533	 89738	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42534	 42535	 0.00082	 0.002983	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42534	 42536	 0.001911	 0.007651	 0.00193	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42534	 42539	 0.000652	 0.00362	 0.0011	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42534	 89739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42534	 89739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42535	 42593	 0.000772	 0.003215	 0.001	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88909	 42536	 0.002142	 0.012549	 0.00342	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42537	 42538	 0.000743	 0.004268	 0.00121	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42537	 42593	 0.000978	 0.004485	 0.00115	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88909	 42538	 0.000327	 0.002625	 0.00074	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42539	 42542	 0.000615	 0.003571	 0.00084	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42539	 89740	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42539	 89740	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42540	 42543	 0.001349	 0.004907	 0.0015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42540	 42593	 0.001734	 0.007545	 0.00215	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42540	 89741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42540	 89741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42541	 42585	 0.004034	 0.016416	 0.004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42541	 42811	 0.00739	 0.01953	 0.00457	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42542	 42594	 0.001573	 0.007498	 0.00217	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42542	 89742	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42542	 89742	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42543	 42544	 0.000923	 0.003696	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42544	 89743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42544	 89743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42545	 42546	 0.000411	 0.003023	 0.00591	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42545	 89744	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89745	 42545	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88894	 42546	 0.000241	 0.003241	 0.00675	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89730	 42546	 0.011889	 0.13696	 0.2704	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42546	 89746	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42546	 89746	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42547	 42556	 0.004096	 0.019522	 0.00565	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88895	 42547	 0.000939	 0.007194	 0.00193	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89746	 42547	 0.000459	 0.003457	 0.00096	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88895	 42548	 0.001349	 0.006427	 0.00186	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89746	 42548	 0.001292	 0.004698	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42548	 89747	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42548	 89747	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42549	 42568	 0.033472	 0.0769	 0.00117	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89747	 42549	 0.006035	 0.019353	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42549	 89749	 0.005827	 0.014462	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42550	 89748	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89736	 42551	 0.073625	 0.21119	 0.00325	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89745	 42551	 0.042592	 0.084329	 0.00124	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89747	 42551	 0.01359	 0.03373	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42552	 42553	 0.001036	 0.004073	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42552	 42554	 0.001073	 0.008623	 0.00242	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42552	 42569	 0.003468	 0.015095	 0.0043	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42553	 42555	 0.002331	 0.009331	 0.00235	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89746	 42554	 0.000761	 0.006319	 0.00166	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42555	 42591	 0.006334	 0.036324	 0.01207	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89744	 42555	 0.000931	 0.009483	 0.00244	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42556	 89750	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42556	 89750	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88929	 42557	 0.028264	 0.045115	 0.00104	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89742	 42557	 0.007965	 0.030988	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89745	 42557	 0.020747	 0.092452	 0.00157	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42558	 42568	 0.02756	 0.057925	 0.00106	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89749	 42558	 0.014265	 0.032772	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42559	 42563	 0.001341	 0.003885	 0.00094	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42559	 89752	 0.001802	 0.006072	 0.00151	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42560	 42566	 0.003093	 0.016482	 0.00463	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42560	 89751	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42560	 89751	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42560	 89752	 0.000621	 0.003141	 0.00087	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42561	 46951	 0.000834	 0.007938	 0.0141	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88894	 42561	 0.000946	 0.006449	 0.01161	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42561	 89752	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42561	 89752	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89749	 42562	 0.009502	 0.018622	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89751	 42562	 0.027715	 0.046288	 0.00079	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42563	 42564	 0.001265	 0.003731	 0.00087	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89748	 42564	 0.001522	 0.004093	 0.00115	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89555	 42565	 0.010371	 0.045144	 0.01286	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89748	 42565	 0.005295	 0.025061	 0.00603	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42565	 89753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42565	 89753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89751	 42567	 0.067266	 0.04949	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89753	 42568	 0.023767	 0.044193	 0.00103	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42570	 42571	 0.025208	 0.057915	 0.00088	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89745	 42570	 0.035885	 0.073747	 0.00141	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42570	 89755	 0.036981	 0.085857	 0.00128	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42570	 89775	 0.069506	 0.39133	 0.00846	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42571	 89754	 0.012679	 0.029436	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42572	 42573	 0.001948	 0.005302	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42572	 89754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42572	 89754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42573	 42582	 0.009849	 0.027466	 0.00577	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42574	 42575	 0.00454	 0.011786	 0.00286	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89744	 42574	 0.005682	 0.019492	 0.00467	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42574	 89755	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42574	 89755	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42575	 42584	 0.004571	 0.012747	 0.00268	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42575	 89756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42575	 89756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89754	 42576	 0.045866	 0.046326	 0.00061	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42576	 89758	 0.034248	 0.071982	 0.00131	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42576	 89759	 0.018206	 0.042267	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42577	 42578	 0.00528	 0.016216	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42577	 89757	 0.007324	 0.020784	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42578	 42579	 0.009425	 0.021882	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42578	 42580	 0.009877	 0.02293	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42578	 42830	 0.05437	 0.057204	 0.00084	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42579	 89760	 0.010708	 0.028381	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42580	 89847	 0.027758	 0.059485	 0.00104	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42581	 42584	 0.004822	 0.012518	 0.00304	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42581	 89757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42581	 89757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42581	 89856	 0.011442	 0.031908	 0.0067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42582	 42842	 0.015872	 0.041949	 0.00982	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42582	 89758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42582	 89758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89758	 42583	 0.031683	 0.053373	 0.00076	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42584	 89759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42584	 89759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42585	 89760	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42585	 89760	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42586	 42592	 0.008656	 0.041257	 0.01195	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42586	 89761	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42586	 89761	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42586	 89851	 0.013805	 0.065808	 0.01907	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89761	 42587	 0.048031	 0.037649	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89761	 42588	 0.013456	 0.031864	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89758	 42589	 0.013641	 0.072681	 0.00127	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89761	 42589	 0.023585	 0.10554	 0.00217	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89073	 42590	 0.027059	 0.094743	 0.00262	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89761	 42590	 0.011949	 0.060445	 0.00105	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88909	 42593	 0.001804	 0.011423	 0.0031	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88909	 42594	 0.006431	 0.029993	 0.00743	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89744	 42594	 0.0031	 0.024902	 0.007	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42595	 42601	 0.009131	 0.045028	 0.01218	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88891	 42595	 0.008122	 0.05932	 0.01525	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42596	 42599	 0.032524	 0.12653	 0.00211	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88889	 42596	 0.00508	 0.017773	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88889	 42596	 0.00508	 0.017773	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42596	 89762	 0.028712	 0.11392	 0.00325	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42597	 42599	 0.029351	 0.1468	 0.00261	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42597	 89765	 0.005683	 0.052283	 0.00104	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42598	 42600	 0.001675	 0.016617	 0.00452	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42598	 89763	 0.002384	 0.022888	 0.00666	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42599	 89762	 0.009948	 0.028229	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42600	 89762	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42600	 89762	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89549	 42602	 0.001401	 0.009226	 0.01785	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42602	 89763	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42602	 89763	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42602	 89850	 0.007681	 0.063356	 0.13084	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42603	 42604	 0.002168	 0.008823	 0.00215	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42603	 42605	 0.002666	 0.006922	 0.00168	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89763	 42603	 0.006202	 0.016102	 0.00391	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42604	 43007	 0.011517	 0.037567	 0.00997	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42604	 89764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42604	 89764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42605	 42606	 0.001841	 0.004941	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42606	 89765	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42606	 89765	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42607	 42608	 0.010593	 0.036339	 0.00871	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42607	 42611	 0.008065	 0.029205	 0.00627	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42607	 89766	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42607	 89766	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42608	 42609	 0.004705	 0.032054	 0.01092	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42608	 42736	 0.004674	 0.022685	 0.00519	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42609	 42699	 0.010252	 0.04105	 0.01034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42609	 89767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42609	 89767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89766	 42610	 0.063812	 0.16405	 0.00254	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42610	 89768	 0.087449	 0.1714	 0.00257	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42610	 89806	 0.025874	 0.10266	 0.00293	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42611	 43283	 0.010285	 0.042469	 0.01005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42611	 89768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42611	 89768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42612	 42613	 0.009155	 0.0378	 0.00894	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42612	 42616	 0.010451	 0.039729	 0.01112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42612	 89899	 0.004137	 0.032242	 0.00964	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42613	 42614	 0.001785	 0.023232	 0.00671	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88854	 42613	 0.004715	 0.036747	 0.01099	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88852	 42614	 0.000414	 0.00504	 0.00167	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42615	 42624	 0.023582	 0.060631	 0.01502	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88852	 42615	 0.010901	 0.036368	 0.00922	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42616	 42617	 0.006591	 0.01742	 0.00408	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88852	 42616	 0.017293	 0.071412	 0.0169	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42616	 89769	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42616	 89769	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42617	 42622	 0.014741	 0.043463	 0.01011	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88913	 42618	 0.003391	 0.021041	 0.0051	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42619	 42621	 0.021366	 0.026522	 0.00058	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42620	 42621	 0.080596	 0.10489	 0.00147	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42620	 42732	 0.1733	 0.13716	 0.00173	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88880	 42621	 0.030917	 0.15088	 0.0026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42622	 42860	 0.019736	 0.061384	 0.01281	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42622	 89770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42622	 89770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42623	 42624	 0.004401	 0.01468	 0.00372	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42623	 89771	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42623	 89771	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42624	 42903	 0.021119	 0.054295	 0.01345	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42625	 42784	 0.21619	 0.16949	 0.00218	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88789	 42625	 0.2084	 0.41284	 0.00606	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42625	 89772	 0.19949	 0.14679	 0.00215	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88789	 42626	 0.042462	 0.18923	 0.00321	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42626	 89772	 0.1411	 0.12645	 0.00259	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42627	 42628	 0.014967	 0.037625	 0.00975	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42627	 89772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42627	 89772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42628	 42788	 0.033064	 0.079706	 0.02251	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42629	 42630	 0.023312	 0.031778	 0.00071	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42629	 42820	 0.11982	 0.11038	 0.00177	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42630	 42818	 0.041854	 0.097172	 0.00145	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42630	 89773	 0.025185	 0.097978	 0.00164	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42631	 42820	 0.076042	 0.099945	 0.00137	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42631	 89774	 0.047364	 0.15801	 0.0025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42632	 42633	 0.013417	 0.034491	 0.00854	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42632	 89773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42632	 89773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42633	 42634	 0.005429	 0.019189	 0.00432	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42634	 42740	 0.006376	 0.037987	 0.00999	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42634	 89774	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42634	 89774	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42635	 89776	 0.075467	 0.24909	 0.00404	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42636	 89776	 0.066005	 0.13069	 0.00192	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42637	 42640	 0.007943	 0.063415	 0.01563	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42638	 89775	 0.01464	 0.037634	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42639	 89775	 0.00855	 0.019847	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88856	 42640	 0.013275	 0.059778	 0.01591	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42640	 89775	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42640	 89775	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88856	 42641	 0.009997	 0.034295	 0.00822	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42641	 89776	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42641	 89776	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88857	 42642	 0.016073	 0.040876	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89776	 42642	 0.056981	 0.11282	 0.00166	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42643	 42648	 0.015616	 0.046042	 0.01071	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42644	 89777	 0.032431	 0.060303	 0.00141	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42645	 42649	 0.002102	 0.005862	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42645	 89777	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42645	 89777	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42646	 42647	 0.022754	 0.018007	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89777	 42646	 0.011496	 0.022761	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42647	 89778	 0.009948	 0.01795	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42648	 42649	 0.004088	 0.011839	 0.00286	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42648	 89778	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42648	 89778	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42649	 42650	 0.001204	 0.006635	 0.00155	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88901	 42649	 0.033457	 0.1316	 0.03446	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42650	 42651	 0.004465	 0.02134	 0.00747	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42651	 89779	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42651	 89779	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42652	 42902	 0.049423	 0.16488	 0.00261	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89779	 42652	 0.038406	 0.1312	 0.00285	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89077	 42653	 0.16636	 0.16805	 0.00223	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42653	 89780	 0.028331	 0.07283	 0.00113	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42654	 89780	 0.024898	 0.15308	 0.00276	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42655	 42921	 0.045394	 0.21905	 0.00387	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42655	 89780	 0.022743	 0.062914	 0.00146	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42656	 89780	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42656	 89780	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42657	 89782	 0.078511	 0.14112	 0.00253	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42657	 89789	 0.10582	 0.08375	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42658	 42935	 0.28066	 0.22217	 0.0028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42658	 89782	 0.062669	 0.16111	 0.00249	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42659	 43022	 0.003053	 0.0411	 0.08572	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88834	 42659	 0.000939	 0.011336	 0.02386	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42659	 89781	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89782	 42659	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42659	 89785	 0.001298	 0.009065	 0.01556	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42660	 46512	 0.007644	 0.051021	 0.09627	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88834	 42660	 0.001508	 0.01726	 0.03377	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89424	 42660	 0.002048	 0.027564	 0.05746	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42660	 89783	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42660	 89783	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42660	 89785	 0.001462	 0.020115	 0.04009	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42661	 42666	 0.000116	 0.002669	 0.05111	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42661	 89784	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42661	 89784	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42662	 89788	 0.025055	 0.058168	 0.00087	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42662	 90016	 0.45609	 0.35776	 0.00459	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42663	 89786	 0.028665	 0.056755	 0.00083	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42664	 89785	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89781	 42665	 0.012244	 0.032871	 0.00745	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42666	 89787	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88835	 42667	 0.002127	 0.00836	 0.00219	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42667	 89789	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42667	 89789	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42667	 90028	 0.007346	 0.04303	 0.01172	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42668	 42672	 0.002098	 0.007196	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42668	 42712	 0.002678	 0.007469	 0.00157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42668	 42942	 0.003004	 0.008066	 0.00183	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42668	 89790	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42668	 89790	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42668	 89792	 0.001912	 0.005635	 0.00131	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42668	 89810	 0.000851	 0.008433	 0.00258	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42669	 42670	 0.000615	 0.002109	 0.00051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42669	 42712	 0.001429	 0.00505	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42670	 89791	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42670	 89791	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42670	 89792	 0.001269	 0.003355	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42671	 42710	 9.9e-05	 0.001655	 0.0322	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42671	 42954	 0.000395	 0.004474	 0.04073	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42671	 89792	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42672	 42679	 0.001284	 0.004404	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42672	 89794	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42672	 89794	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42673	 42677	 0.000642	 0.005838	 0.00147	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42673	 42939	 0.00219	 0.007741	 0.00174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89792	 42673	 0.000452	 0.003752	 0.00147	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42674	 42677	 0.000895	 0.003585	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42674	 42681	 0.002595	 0.006859	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42674	 89795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42674	 89795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89795	 42675	 0.007373	 0.014597	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42675	 89796	 0.01502	 0.011521	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42676	 42677	 0.000777	 0.005821	 0.00142	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42676	 42951	 0.002919	 0.016955	 0.00399	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42677	 89796	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42677	 89796	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42678	 42679	 0.000623	 0.003182	 0.00087	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42678	 42681	 0.000415	 0.002552	 0.00093	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42678	 89797	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42678	 89797	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89792	 42679	 0.000838	 0.004906	 0.00134	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42680	 42687	 0.00131	 0.004765	 0.00146	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42680	 42715	 0.000941	 0.005005	 0.00116	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42680	 89798	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42680	 89798	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42681	 42683	 0.000821	 0.006154	 0.0015	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42681	 89799	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42681	 89799	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89799	 42682	 0.014843	 0.00961	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42683	 42690	 0.000459	 0.004409	 0.00128	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42683	 89800	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42683	 89800	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42684	 42685	 0.002404	 0.008418	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42684	 42686	 0.005659	 0.017379	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89800	 42684	 0.017577	 0.017753	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89796	 42685	 0.001701	 0.010458	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42686	 89893	 0.022862	 0.065572	 0.00101	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42687	 42688	 0.000857	 0.003489	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42688	 42689	 0.000737	 0.002949	 0.00074	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42689	 42691	 0.000961	 0.004068	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42689	 89801	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42689	 89801	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42690	 42691	 0.002345	 0.006383	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42690	 42694	 0.000951	 0.006729	 0.00185	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42690	 89802	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42690	 89802	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42691	 42694	 0.001125	 0.006588	 0.00179	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42691	 89803	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42691	 89803	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42692	 42705	 0.050457	 0.036475	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89803	 42693	 0.013152	 0.020147	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42694	 42696	 0.000737	 0.00781	 0.00232	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89802	 42695	 0.028154	 0.028161	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42696	 42697	 0.000699	 0.010271	 0.00314	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42696	 89804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42696	 89804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42696	 89810	 0.005377	 0.046118	 0.01312	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42697	 42698	 0.003927	 0.019402	 0.00567	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42697	 42699	 0.004531	 0.028699	 0.00779	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42697	 89805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42697	 89805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42698	 42699	 0.003807	 0.01006	 0.00235	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42698	 43283	 0.007059	 0.04013	 0.01162	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42699	 89806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42699	 89806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89767	 42700	 0.093136	 0.16742	 0.00301	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89805	 42700	 0.033767	 0.096849	 0.00149	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89806	 42700	 0.083881	 0.066384	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42701	 42702	 0.007496	 0.025258	 0.00628	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42701	 42925	 0.012563	 0.03373	 0.00764	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42701	 89807	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42701	 89807	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42702	 42711	 0.009418	 0.056111	 0.01476	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42703	 42711	 0.018357	 0.049983	 0.01101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42703	 89808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42703	 89808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42704	 42705	 0.089637	 0.070263	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89803	 42704	 0.11383	 0.090085	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89808	 42704	 0.061932	 0.15751	 0.00249	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89793	 42705	 0.011407	 0.05804	 0.00132	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89801	 42705	 0.041884	 0.029668	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89802	 42706	 0.038493	 0.030462	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89800	 42707	 0.025468	 0.019535	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42708	 42709	 0.074186	 0.052551	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89794	 42708	 0.004067	 0.018121	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89798	 42708	 0.004455	 0.009116	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42709	 42714	 0.15399	 0.12072	 0.00155	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42709	 89811	 0.031298	 0.051987	 0.0011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42710	 89809	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89810	 42710	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42711	 42712	 0.004217	 0.011321	 0.00257	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88887	 42711	 0.001484	 0.017546	 0.00499	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42711	 89811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42711	 89811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89810	 42712	 0.001537	 0.009158	 0.00241	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88843	 42713	 0.002671	 0.022912	 0.00652	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42713	 89812	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42713	 89812	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42713	 89899	 0.002096	 0.023591	 0.00682	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89808	 42714	 0.13146	 0.10305	 0.00132	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89811	 42714	 0.13909	 0.11008	 0.00139	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89792	 42715	 0.000555	 0.002887	 0.00085	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89549	 42716	 0.002846	 0.036765	 0.08336	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42716	 89813	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42716	 89813	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42717	 42719	 0.001239	 0.010493	 0.02045	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42717	 42738	 0.00437	 0.030521	 0.05241	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42717	 89814	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42717	 89814	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89814	 42718	 0.007685	 0.030768	 0.00775	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42719	 89815	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42719	 89815	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89815	 42720	 0.004583	 0.018347	 0.00462	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89517	 42721	 0.015782	 0.047264	 0.01065	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89815	 42721	 0.002862	 0.008439	 0.00196	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88837	 42722	 0.001483	 0.019953	 0.04158	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88892	 42722	 0.000491	 0.005088	 0.00977	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42722	 89816	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42722	 89816	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42723	 42725	 0.005216	 0.033038	 0.00897	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88893	 42723	 0.005727	 0.026275	 0.00673	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42724	 89817	 0.051523	 0.13245	 0.00205	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88926	 42725	 0.007391	 0.045445	 0.01311	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42725	 89817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42725	 89817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42726	 42729	 0.009729	 0.038955	 0.00981	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42726	 89818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42726	 89818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42727	 42728	 0.024067	 0.063616	 0.01489	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42727	 49622	 0.008857	 0.041308	 0.01023	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42727	 89819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42727	 89819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42729	 42730	 0.008404	 0.031946	 0.00894	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42731	 42859	 0.011043	 0.049725	 0.01323	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42733	 42734	 0.006939	 0.02937	 0.00661	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88913	 42733	 0.011465	 0.047341	 0.0112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42734	 42973	 0.014404	 0.048535	 0.01206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42734	 89820	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42734	 89820	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42735	 89821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42735	 89821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89810	 42736	 0.015012	 0.1593	 0.04737	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42736	 89822	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42736	 89822	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42737	 42743	 0.005169	 0.032076	 0.00777	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89814	 42737	 0.016168	 0.06291	 0.01681	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42737	 89823	 0.003913	 0.015379	 0.00402	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42738	 42739	 0.000715	 0.005816	 0.01906	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88848	 42738	 0.001971	 0.013581	 0.02397	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42738	 89823	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42738	 89823	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42739	 42745	 0.001673	 0.020215	 0.08849	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88848	 42739	 0.000466	 0.004355	 0.0165	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42739	 89824	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42739	 89824	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42740	 42741	 0.007163	 0.032252	 0.00858	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88849	 42740	 0.003084	 0.024775	 0.00696	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42741	 42744	 0.01034	 0.047439	 0.01215	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89824	 42742	 0.009351	 0.054779	 0.01492	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42742	 89825	 0.004899	 0.028147	 0.00797	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42743	 89825	 0.008575	 0.05322	 0.01289	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42744	 89825	 0.005755	 0.026839	 0.00665	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42745	 89825	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42745	 89825	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42745	 92245	 0.002073	 0.021496	 0.0463	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42745	 92245	 0.002073	 0.021496	 0.0463	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89548	 42746	 0.028105	 0.17018	 0.00533	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42746	 89826	 0.007238	 0.051544	 0.00116	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42747	 42750	 0.002177	 0.021601	 0.00587	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88851	 42747	 0.010815	 0.068512	 0.0186	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42747	 89826	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42747	 89826	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89826	 42748	 0.024733	 0.024297	 0.00041	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89826	 42749	 0.030212	 0.019559	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88870	 42751	 0.002962	 0.024211	 0.00657	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42752	 42753	 0.002233	 0.006226	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42753	 42755	 0.003336	 0.008957	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42754	 90236	 0.010826	 0.047698	 0.00083	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42754	 90247	 0.054207	 0.070545	 0.00099	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42756	 42763	 0.001963	 0.005788	 0.00135	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42756	 89827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42756	 89827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42757	 42758	 0.019973	 0.015806	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89827	 42757	 0.014114	 0.01117	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42758	 42759	 0.018209	 0.01441	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42758	 42762	 0.034286	 0.026875	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42759	 42761	 0.02855	 0.022594	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42760	 42761	 0.026096	 0.016895	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42760	 42783	 0.051305	 0.040602	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42761	 89829	 0.031671	 0.025064	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42762	 89828	 0.020694	 0.015225	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42763	 43978	 0.003454	 0.008325	 0.00235	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42763	 43979	 0.002259	 0.005969	 0.0014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42763	 89828	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42763	 89828	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42764	 42765	 0.016533	 0.012959	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42764	 42766	 0.028458	 0.02156	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89828	 42764	 0.026938	 0.020409	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42765	 42766	 0.012218	 0.009669	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42765	 89830	 0.019185	 0.013869	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42766	 89830	 0.018095	 0.012818	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42766	 89836	 0.024527	 0.034818	 0.00057	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42767	 42768	 0.002465	 0.006197	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42767	 89829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42767	 89829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42768	 42769	 0.001356	 0.004422	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42768	 42788	 0.003694	 0.009764	 0.00229	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42769	 42771	 0.001482	 0.005165	 0.0012	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42770	 42775	 0.021864	 0.017303	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42771	 42774	 0.001543	 0.004078	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42771	 89835	 0.002247	 0.005833	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42772	 89830	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42772	 89830	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42772	 89835	 0.002565	 0.00743	 0.00179	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42773	 43949	 0.001687	 0.004458	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42773	 43950	 0.002227	 0.005367	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42773	 89831	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42773	 89831	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42774	 89832	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42774	 89832	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42774	 89835	 0.001574	 0.00416	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42775	 42776	 0.009204	 0.018037	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89832	 42775	 0.005652	 0.011191	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42775	 89836	 0.029244	 0.029538	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42776	 42777	 0.028754	 0.018615	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89832	 42776	 0.014833	 0.02907	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42776	 89834	 0.026237	 0.027954	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42777	 89834	 0.035596	 0.028171	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42778	 42782	 0.008678	 0.019936	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42779	 42780	 0.004284	 0.007966	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89832	 42779	 0.003772	 0.014675	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42780	 42781	 0.006496	 0.012862	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42781	 42782	 0.006611	 0.01309	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89831	 42781	 0.004341	 0.010078	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42782	 42789	 0.020712	 0.016391	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42782	 89836	 0.011969	 0.036719	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42784	 89834	 0.050891	 0.10076	 0.00148	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42785	 42786	 0.011312	 0.039427	 0.00914	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42785	 42787	 0.006947	 0.018361	 0.0043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42785	 89833	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42785	 89833	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88788	 42786	 0.01735	 0.059525	 0.01426	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42787	 42788	 0.003096	 0.008311	 0.00188	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42788	 89834	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42788	 89834	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42788	 89835	 0.005174	 0.017434	 0.00433	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89833	 42789	 0.11989	 0.094881	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42790	 89835	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42791	 42850	 0.001074	 0.004434	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42791	 89837	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42791	 89837	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42792	 42808	 0.002427	 0.014921	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89837	 42792	 0.002229	 0.010336	 0.00021	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42793	 42794	 0.000626	 0.00443	 0.00122	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42793	 89858	 0.000532	 0.003827	 0.00101	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42794	 42795	 0.00074	 0.003525	 0.00102	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42794	 89838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42794	 89838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42794	 89845	 0.001768	 0.014113	 0.00348	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42795	 42796	 0.001353	 0.007015	 0.00171	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42796	 42797	 0.001568	 0.006276	 0.00212	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42796	 89839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42796	 89839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42797	 42811	 0.002222	 0.009043	 0.0022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42797	 89840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42797	 89840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89840	 42798	 0.003967	 0.017676	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42798	 89841	 0.005514	 0.024569	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42799	 42802	 0.001798	 0.005411	 0.00169	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42799	 89841	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42799	 89841	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42800	 42822	 0.026133	 0.020484	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42800	 89842	 0.007115	 0.014086	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42801	 42802	 0.002112	 0.007362	 0.00171	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42801	 42823	 0.003789	 0.010014	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42801	 89842	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42801	 89842	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42802	 89843	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42802	 89843	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42803	 42819	 0.023497	 0.050353	 0.00088	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89841	 42803	 0.010878	 0.018325	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89843	 42803	 0.008736	 0.021684	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42804	 42823	 0.001361	 0.004669	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42804	 89844	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42804	 89844	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42805	 42827	 0.025723	 0.023694	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42805	 89849	 0.015342	 0.035619	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89844	 42806	 0.010761	 0.013358	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88929	 42807	 0.033256	 0.1056	 0.00185	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89837	 42807	 0.010047	 0.019466	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42807	 89859	 0.01184	 0.046063	 0.00077	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89839	 42808	 0.012819	 0.026943	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42808	 89847	 0.003679	 0.025257	 0.00046	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42809	 42835	 0.000872	 0.011868	 0.1223	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42809	 49896	 0.000441	 0.004704	 0.06907	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42809	 49896	 0.000441	 0.004704	 0.06907	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42809	 89845	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89837	 42810	 0.007866	 0.02022	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89839	 42810	 0.007843	 0.018209	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42811	 89847	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42811	 89847	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42811	 89851	 0.012936	 0.050847	 0.0133	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42812	 42815	 0.007256	 0.014366	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42812	 42817	 0.00915	 0.021243	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89838	 42812	 0.009114	 0.023085	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89846	 42813	 0.04345	 0.034386	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89845	 42814	 0.002828	 0.011968	 0.00269	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42814	 89848	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42814	 89848	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89848	 42815	 0.01105	 0.021879	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42816	 42821	 0.011003	 0.036706	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89848	 42816	 0.006511	 0.027557	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89839	 42817	 0.008698	 0.016173	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89846	 42818	 0.015529	 0.075778	 0.00131	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89848	 42818	 0.040966	 0.08111	 0.00119	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89848	 42819	 0.028678	 0.073719	 0.00114	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42820	 89849	 0.12987	 0.1218	 0.00188	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42820	 89853	 0.029287	 0.075903	 0.00144	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89841	 42821	 0.007484	 0.024697	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42822	 42824	 0.017539	 0.034725	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42822	 42825	 0.017574	 0.031587	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89844	 42822	 0.012003	 0.019158	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42823	 42839	 0.002466	 0.016545	 0.00399	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42823	 89849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42823	 89849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42823	 89851	 0.009991	 0.036177	 0.00776	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89843	 42824	 0.008341	 0.019364	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42825	 42826	 0.013394	 0.024074	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42826	 42828	 0.031509	 0.031825	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42826	 89857	 0.012246	 0.035123	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42827	 42828	 0.011205	 0.021459	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42828	 89852	 0.013012	 0.050621	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42829	 42832	 0.022107	 0.047374	 0.00083	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89841	 42829	 0.034406	 0.04522	 0.00062	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42829	 89857	 0.03117	 0.076296	 0.0013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42830	 42848	 0.03556	 0.035916	 0.00048	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89840	 42831	 0.070945	 0.045931	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89847	 42831	 0.038033	 0.029812	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89847	 42832	 0.020154	 0.037474	 0.00088	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42833	 42834	 0.024469	 0.026913	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42834	 89857	 0.010041	 0.020548	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42835	 89850	 0.000104	 0.008333	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89851	 42835	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42836	 89852	 0.07216	 0.079369	 0.00106	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89851	 42837	 0.002969	 0.007707	 0.00187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42837	 89852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42837	 89852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42838	 89853	 0.078498	 0.057754	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42839	 89853	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42839	 89853	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42839	 89854	 0.002805	 0.025469	 0.0083	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88848	 42840	 0.000945	 0.011081	 0.0447	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89850	 42840	 0.002411	 0.019858	 0.04094	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42840	 89854	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42840	 89854	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42840	 92411	 0.002377	 0.031599	 0.06754	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42841	 43008	 0.012695	 0.051666	 0.01259	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88849	 42841	 0.009804	 0.034305	 0.01137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89851	 42842	 0.005566	 0.021878	 0.00572	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42842	 89855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42842	 89855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89851	 42843	 0.00769	 0.021444	 0.0045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42844	 89857	 0.03666	 0.029012	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42845	 89857	 0.024185	 0.026343	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42846	 42848	 0.036116	 0.026572	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89850	 42847	 0.00105	 0.007002	 0.0132	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42847	 89856	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89857	 42847	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89857	 42848	 0.026613	 0.052691	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42849	 50129	 0.00047	 0.006604	 0.02739	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42849	 89858	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89859	 42849	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89858	 42850	 0.001174	 0.0047	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42851	 42852	 0.001174	 0.004701	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42851	 42859	 0.009334	 0.042823	 0.01097	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42851	 89860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42851	 89860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42853	 42854	 0.067843	 0.1426	 0.0026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89860	 42853	 0.006043	 0.029006	 0.00087	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42854	 42858	 0.044058	 0.10076	 0.00246	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42854	 89997	 0.038243	 0.14141	 0.00262	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42855	 42856	 0.03268	 0.025862	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42856	 42857	 0.050789	 0.034117	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89860	 42856	 0.056644	 0.10375	 0.00179	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42857	 42858	 0.027466	 0.058858	 0.00103	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42860	 42864	 0.003011	 0.008395	 0.00176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88901	 42860	 0.0089	 0.030533	 0.00731	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42860	 89861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42860	 89861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42861	 42872	 0.028188	 0.022308	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42861	 89862	 0.028661	 0.021087	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42862	 42877	 0.001981	 0.005841	 0.00136	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42862	 42903	 0.009114	 0.02366	 0.00574	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42862	 89862	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42862	 89862	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42863	 42864	 0.00127	 0.003408	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42863	 42871	 0.001479	 0.005073	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42863	 89863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42863	 89863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42865	 42867	 0.01762	 0.012481	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42865	 42909	 0.046952	 0.09202	 0.00138	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42865	 89864	 0.013595	 0.034948	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42866	 42869	 0.00515	 0.013097	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88928	 42866	 0.002675	 0.006145	 9e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42868	 89864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42868	 89864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42868	 89868	 0.00072	 0.004322	 0.00131	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88885	 42869	 0.00466	 0.028321	 0.00052	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89864	 42869	 0.005253	 0.017524	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42869	 89865	 0.002206	 0.009775	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42870	 42871	 0.000633	 0.002171	 0.00052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42870	 89865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42870	 89865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42870	 89868	 0.000841	 0.004778	 0.00138	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42871	 89866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42871	 89866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42872	 42874	 0.02334	 0.018471	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42873	 42874	 0.017667	 0.013981	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42874	 42875	 0.016116	 0.01612	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42874	 89870	 0.018164	 0.021291	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42875	 89867	 0.009814	 0.015665	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42876	 42883	 0.006671	 0.009297	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42876	 89867	 0.016701	 0.013217	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42877	 42882	 0.001533	 0.005164	 0.00128	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42877	 89867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42877	 89867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42878	 42879	 0.013549	 0.010723	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42878	 42883	 0.021351	 0.016897	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89865	 42878	 0.003493	 0.013438	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89866	 42878	 0.019007	 0.015042	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42878	 89869	 0.011274	 0.013994	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42879	 42881	 0.012412	 0.008337	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42880	 42888	 6.6e-05	 0.000723	 0.00702	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42880	 89868	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42880	 89868	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42881	 89869	 0.018077	 0.012143	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42882	 42887	 0.000591	 0.002366	 0.0006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42882	 89869	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42882	 89869	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42882	 89871	 0.001682	 0.006392	 0.00179	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89869	 42883	 0.005078	 0.008434	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42884	 42891	 0.004067	 0.013566	 0.00344	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42884	 42904	 0.004494	 0.011296	 0.00293	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42884	 89870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42884	 89870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42885	 42892	 0.018054	 0.011688	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89869	 42885	 0.014302	 0.028316	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89869	 42886	 0.020109	 0.015762	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42887	 42890	 0.000768	 0.002987	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42888	 89871	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42888	 89871	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42889	 42890	 0.001701	 0.00616	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88901	 42889	 0.001164	 0.003921	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42890	 42891	 0.001844	 0.004788	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42891	 42895	 0.002975	 0.008296	 0.00174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88901	 42891	 0.002357	 0.009437	 0.00238	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42891	 89872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42891	 89872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42892	 42893	 0.021979	 0.015888	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42893	 42894	 0.014999	 0.022736	 0.00047	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89872	 42893	 0.008285	 0.023761	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89870	 42894	 0.036223	 0.026651	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42895	 42896	 0.004182	 0.010751	 0.00266	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42895	 89873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42895	 89873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42896	 42899	 0.004773	 0.012614	 0.00295	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42896	 89874	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42896	 89874	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89874	 42897	 0.026557	 0.021017	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42897	 89875	 0.079267	 0.062134	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42898	 42905	 0.086072	 0.093752	 0.00128	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42898	 89875	 0.051211	 0.10037	 0.0015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88847	 42899	 0.011566	 0.039679	 0.00951	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42899	 89875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42899	 89875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88847	 42900	 0.002101	 0.021601	 0.00817	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42900	 89876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42900	 89876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88847	 42901	 0.007912	 0.055971	 0.01536	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42901	 89877	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42901	 89877	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88902	 42902	 0.034894	 0.23679	 0.00442	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42903	 42904	 0.005714	 0.015102	 0.00353	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42905	 42906	 0.016418	 0.042549	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89877	 42905	 0.040592	 0.17887	 0.00311	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89870	 42906	 0.008329	 0.021586	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89770	 42907	 0.17577	 0.17755	 0.00235	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89861	 42907	 0.033897	 0.087138	 0.00135	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42908	 42909	 0.01632	 0.043254	 0.0011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88885	 42908	 0.004385	 0.018556	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42909	 89879	 0.032776	 0.12751	 0.00213	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42910	 89878	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42910	 89878	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88902	 42911	 0.13045	 0.098839	 0.00136	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89878	 42911	 0.084356	 0.08254	 0.00117	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88847	 42912	 0.012954	 0.07836	 0.02	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89065	 42912	 0.010289	 0.040029	 0.01069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42912	 89879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42912	 89879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42913	 42914	 0.008612	 0.034479	 0.00869	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42914	 42915	 0.008744	 0.023805	 0.00524	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88852	 42914	 0.027542	 0.11033	 0.02781	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89036	 42914	 0.045178	 0.18114	 0.04572	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42914	 89880	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42914	 89880	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42915	 89881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42915	 89881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88932	 42916	 0.090028	 0.17826	 0.00262	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88932	 42917	 0.006428	 0.016524	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89779	 42917	 0.11188	 0.22154	 0.00325	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42918	 42920	 0.015637	 0.053648	 0.01285	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42919	 89882	 0.050941	 0.10086	 0.00148	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88881	 42920	 0.01312	 0.052535	 0.01324	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42920	 89882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42920	 89882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89882	 42921	 0.029912	 0.11868	 0.00339	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42921	 89883	 0.06364	 0.14776	 0.0022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88881	 42922	 0.001895	 0.027359	 0.00869	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88910	 42922	 0.003003	 0.032184	 0.01029	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42922	 89883	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42922	 89883	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88881	 42923	 0.012477	 0.052811	 0.01189	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42924	 42925	 0.013005	 0.032693	 0.00847	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42926	 43278	 0.24386	 0.30287	 0.0066	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42926	 89887	 0.065348	 0.15476	 0.00283	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42927	 42933	 0.01122	 0.038492	 0.00922	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42927	 45811	 0.019951	 0.051801	 0.01257	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42928	 45807	 0.014794	 0.091836	 0.02226	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42928	 89884	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42928	 89884	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42929	 42930	 0.004478	 0.027825	 0.00785	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42929	 42933	 0.006954	 0.039953	 0.01132	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42929	 89885	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42929	 89885	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42929	 90081	 0.013478	 0.14298	 0.0425	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42930	 42934	 0.001437	 0.007921	 0.00185	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42930	 89886	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42930	 89886	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42931	 42932	 0.004307	 0.017245	 0.00434	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42931	 43279	 0.019947	 0.07052	 0.01589	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88835	 42931	 0.022646	 0.077703	 0.01862	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42931	 89887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42931	 89887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42932	 42933	 0.003589	 0.00977	 0.00215	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42932	 42934	 0.004799	 0.016724	 0.00388	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42932	 89888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42932	 89888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42933	 42934	 0.002746	 0.00706	 0.00175	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42935	 42936	 0.003018	 0.013375	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89885	 42935	 0.052147	 0.14799	 0.00233	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89886	 42935	 0.006034	 0.026437	 0.00057	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42936	 42937	 0.002741	 0.013865	 0.00024	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42937	 42938	 0.006428	 0.015221	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89888	 42937	 0.034153	 0.044887	 0.00062	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89887	 42938	 0.084142	 0.084988	 0.00113	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42939	 42940	 0.002229	 0.010817	 0.00247	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89792	 42939	 0.000818	 0.007482	 0.003	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42939	 89889	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42939	 89889	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42940	 42941	 0.001512	 0.006243	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42940	 42968	 0.003003	 0.01222	 0.00298	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42940	 89894	 0.004793	 0.019504	 0.00475	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42941	 42942	 0.002296	 0.009025	 0.00236	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89792	 42942	 0.003602	 0.00935	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42942	 89890	 0.000795	 0.008534	 0.00222	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42943	 42945	 0.00016	 0.002013	 0.00704	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42943	 42955	 0.000927	 0.01215	 0.02669	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89809	 42943	 0.000584	 0.003844	 0.00744	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42943	 89890	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42943	 89890	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42944	 42945	 0.000164	 0.001678	 0.0033	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42944	 42946	 4.9e-05	 0.000511	 0.00096	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88886	 42945	 0.000358	 0.003101	 0.00577	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88842	 42946	 0.000433	 0.004524	 0.00959	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42946	 89891	 0.000385	 0.002686	 0.00461	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42947	 42954	 0.000292	 0.003441	 0.06009	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42947	 89891	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42948	 42950	 0.034434	 0.022293	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89892	 42948	 0.006903	 0.017133	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89892	 42949	 0.021008	 0.041172	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42951	 89893	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42951	 89893	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42952	 42953	 0.00603	 0.021541	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89889	 42952	 0.008377	 0.032587	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42953	 89901	 0.006845	 0.022833	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42954	 42956	 0.000153	 0.001517	 0.02596	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42955	 43285	 0.002088	 0.020806	 0.06945	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88842	 42955	 0.001483	 0.020788	 0.03986	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42955	 89894	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89895	 42955	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42956	 89896	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89894	 42957	 0.000846	 0.008965	 0.00266	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89896	 42957	 0.000443	 0.004597	 0.00142	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	42958	 42959	 0.00391	 0.021456	 0.00567	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89896	 42958	 0.001616	 0.009628	 0.00253	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42959	 89898	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42959	 89898	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42960	 42961	 0.056773	 0.13181	 0.00196	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89892	 42960	 0.02543	 0.10616	 0.00306	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89897	 42960	 0.022627	 0.069413	 0.00188	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42961	 42963	 0.028073	 0.1237	 0.00215	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88844	 42961	 0.004739	 0.039422	 0.00075	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88842	 42962	 0.000694	 0.008966	 0.02032	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42962	 89899	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42962	 89899	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88900	 42963	 0.095374	 0.18885	 0.00277	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42963	 89900	 0.1046	 0.20502	 0.00307	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42964	 89900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42964	 89900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42965	 42966	 0.022491	 0.064506	 0.00099	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42965	 42967	 0.021093	 0.053644	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42965	 43289	 0.023698	 0.084659	 0.00168	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89898	 42966	 0.22252	 0.17613	 0.00222	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42966	 89901	 0.008384	 0.033263	 0.00095	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89893	 42967	 0.010103	 0.051104	 0.00089	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42967	 90033	 0.015282	 0.086872	 0.00157	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42968	 43286	 0.010186	 0.040784	 0.01028	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42968	 89901	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42968	 89901	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42969	 42970	 0.17539	 0.23055	 0.00316	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89560	 42969	 0.044385	 0.14807	 0.00235	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42969	 89902	 0.053805	 0.12492	 0.00186	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88868	 42970	 0.10426	 0.20646	 0.00303	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42971	 89902	 0.051476	 0.040738	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42972	 42973	 0.005233	 0.017631	 0.00438	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88867	 42972	 0.033292	 0.077306	 0.02356	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42972	 89902	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42972	 89902	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42974	 42975	 0.00065	 0.002228	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42974	 89903	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42974	 89903	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42975	 42997	 0.003347	 0.011483	 0.00275	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42975	 89904	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42975	 89904	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89903	 42976	 0.025102	 0.019865	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89904	 42976	 0.013637	 0.01069	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42977	 42997	 0.002345	 0.006725	 0.00165	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42978	 42983	 0.031631	 0.031948	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89904	 42978	 0.037855	 0.040332	 0.00058	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42979	 42981	 0.017303	 0.033137	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89903	 42979	 0.026417	 0.020906	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42980	 42981	 0.029883	 0.019346	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42980	 42984	 0.047432	 0.030707	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88918	 42981	 0.052107	 0.040844	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42981	 89905	 0.012806	 0.025355	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42982	 89905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42982	 89905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42983	 42984	 0.01259	 0.042	 0.00067	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42983	 42988	 0.078125	 0.061239	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88905	 42984	 0.013469	 0.056222	 0.00162	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	42985	 89906	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42985	 89906	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42986	 42987	 0.008794	 0.055705	 0.01512	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42986	 89907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42986	 89907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42987	 42993	 0.016229	 0.048602	 0.01095	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42987	 89908	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42987	 89908	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88918	 42989	 0.023452	 0.060782	 0.00115	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	42990	 42991	 0.00197	 0.012882	 0.00328	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	42990	 42995	 0.00289	 0.015561	 0.00428	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	42991	 42992	 0.004565	 0.015381	 0.00382	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42992	 42993	 0.007926	 0.023856	 0.00746	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	42993	 89909	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42993	 89909	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	42994	 42995	 0.012328	 0.036919	 0.00832	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89432	 42994	 0.050619	 0.13388	 0.03137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42995	 42996	 0.005685	 0.016466	 0.00397	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	42998	 43001	 0.004041	 0.022277	 0.00521	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	42999	 43000	 0.007362	 0.037241	 0.00065	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	42999	 89910	 0.008017	 0.041152	 0.00078	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89679	 43000	 0.062409	 0.27933	 0.00575	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43001	 89910	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43001	 89910	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43002	 43005	 0.006273	 0.017079	 0.00376	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43003	 43006	 0.020668	 0.054628	 0.01279	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43004	 43005	 0.008981	 0.023736	 0.00556	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89614	 43004	 0.011782	 0.029617	 0.00767	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43005	 43006	 0.00241	 0.006369	 0.00149	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43006	 89911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43006	 89911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43007	 43010	 0.009593	 0.049041	 0.01337	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89813	 43008	 0.018618	 0.06775	 0.02075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43009	 43010	 0.007077	 0.024277	 0.00582	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88919	 43010	 0.005548	 0.046039	 0.01211	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43011	 89912	 0.060881	 0.12054	 0.00177	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43013	 89912	 0.022868	 0.027375	 0.00046	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43014	 43015	 0.016644	 0.04399	 0.0103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43014	 89912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43014	 89912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89552	 43015	 0.028385	 0.085027	 0.01916	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43016	 43017	 0.000525	 0.003698	 0.0021	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43016	 43018	 0.002612	 0.026407	 0.00776	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43016	 89913	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43016	 89913	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43017	 43020	 0.002785	 0.017447	 0.01256	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89913	 43019	 0.017484	 0.086754	 0.00207	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88925	 43020	 0.029681	 0.18473	 0.05226	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43021	 43037	 0.01087	 0.029595	 0.00652	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43021	 89914	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43021	 89914	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43022	 89915	 0.000708	 0.008184	 0.01568	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43023	 43026	 0.000224	 0.003781	 0.06856	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43023	 43030	 0.000513	 0.006154	 0.10333	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43023	 89915	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43023	 89915	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88814	 43024	 0.01341	 0.073847	 0.00167	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89914	 43024	 0.046571	 0.24222	 0.00525	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43024	 89916	 0.024933	 0.055183	 0.0009	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43025	 43439	 0.001788	 0.008201	 0.0021	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43025	 43444	 0.001422	 0.00817	 0.00231	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89049	 43025	 0.004276	 0.043219	 0.01271	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43025	 89916	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43025	 89916	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43026	 43440	 0.000407	 0.006696	 0.06519	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43026	 89917	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43026	 89917	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43027	 43028	 0.011686	 0.048254	 0.01142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89917	 43027	 0.006718	 0.026403	 0.00691	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43028	 43037	 0.007477	 0.034301	 0.00879	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43028	 43038	 0.005164	 0.025514	 0.00745	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89917	 43028	 0.01048	 0.061393	 0.01673	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89914	 43029	 0.046551	 0.083994	 0.00121	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43029	 89919	 0.025428	 0.025965	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43030	 89918	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43030	 89918	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43031	 43032	 0.000368	 0.00272	 0.00078	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89918	 43031	 0.000938	 0.00754	 0.00212	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43031	 89919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43031	 89919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43032	 43033	 0.000423	 0.003244	 0.00087	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43034	 43035	 0.017846	 0.027338	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89919	 43035	 0.034177	 0.022126	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43035	 89920	 0.011899	 0.02762	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43036	 89920	 0.009241	 0.018111	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43037	 43038	 0.003376	 0.013135	 0.00351	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88897	 43037	 0.010428	 0.066059	 0.01793	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89918	 43037	 0.001752	 0.008171	 0.00202	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43037	 89920	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43037	 89920	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43038	 89921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43038	 89921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43039	 89926	 0.029324	 0.032253	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43039	 89927	 0.005338	 0.015309	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43040	 89926	 0.026971	 0.019105	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43041	 43050	 0.031272	 0.023692	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43041	 89923	 0.039194	 0.031018	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43041	 89926	 0.014021	 0.025298	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43042	 43045	 7.6e-05	 0.001276	 0.01307	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43042	 89922	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43043	 43044	 0.00128	 0.003833	 0.00086	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43043	 89924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43043	 89924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43043	 89925	 0.000717	 0.002415	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43044	 43049	 0.001199	 0.003729	 0.00078	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43045	 43054	 0.000117	 0.001323	 0.01204	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43045	 89925	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43045	 89925	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43046	 43047	 0.001051	 0.002703	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88878	 43046	 0.004512	 0.013581	 0.00425	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89922	 43046	 0.003537	 0.010645	 0.00333	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43046	 89926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43046	 89926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89925	 43047	 0.001475	 0.004113	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89923	 43048	 0.007712	 0.015114	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89924	 43048	 0.003428	 0.008811	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89922	 43049	 0.001425	 0.003972	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89489	 43050	 0.032511	 0.025483	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43051	 43052	 0.00219	 0.005962	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43051	 43058	 0.001126	 0.004508	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43051	 43061	 0.003805	 0.013053	 0.00313	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43052	 43053	 0.0023	 0.008328	 0.00179	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43052	 89927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43052	 89927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43053	 43056	 0.000967	 0.006894	 0.00214	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43053	 43187	 0.005393	 0.018169	 0.00452	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89925	 43053	 0.003492	 0.014208	 0.00346	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43054	 89928	 0.000125	 0.009999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89929	 43054	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43055	 43056	 0.001162	 0.006375	 0.00169	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43055	 43083	 0.000922	 0.005142	 0.00131	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88878	 43055	 0.001106	 0.006477	 0.00176	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89929	 43055	 0.001993	 0.007832	 0.00205	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43056	 43082	 0.000477	 0.004985	 0.00137	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43056	 89930	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43056	 89930	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43057	 43058	 0.001028	 0.004117	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43057	 43060	 0.002672	 0.008309	 0.00173	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43057	 43061	 0.001597	 0.004015	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43059	 89931	 0.021743	 0.017207	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43060	 43062	 0.001777	 0.009751	 0.00258	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43060	 89931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43060	 89931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43061	 43066	 0.001836	 0.011391	 0.00276	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43061	 89932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43061	 89932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43062	 43071	 0.00188	 0.011684	 0.0033	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43063	 43065	 0.022589	 0.024605	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89931	 43063	 0.030694	 0.025263	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43064	 43068	 0.000193	 0.002112	 0.02052	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43064	 89933	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43065	 89935	 0.010285	 0.02333	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89606	 43066	 0.001477	 0.010795	 0.00318	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43066	 89935	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43066	 89935	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89607	 43067	 0.042778	 0.043207	 0.00057	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89934	 43067	 0.006093	 0.023702	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43068	 43078	 0.000187	 0.002417	 0.02254	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43068	 89936	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43068	 89936	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43069	 43082	 0.001004	 0.004021	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43069	 89937	 0.001512	 0.006241	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43070	 43074	 0.000117	 0.001324	 0.01205	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43070	 89937	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43070	 89937	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43071	 43089	 0.006287	 0.016616	 0.00389	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89937	 43071	 0.001609	 0.006442	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43072	 43138	 0.000634	 0.004778	 0.00133	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43072	 43140	 0.002694	 0.010787	 0.00272	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43072	 89938	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43072	 89938	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43072	 89939	 0.000622	 0.005332	 0.00152	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43073	 43075	 0.001015	 0.004295	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43073	 43076	 0.00079	 0.005482	 0.00156	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43073	 43139	 0.001913	 0.005209	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43074	 89939	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43075	 43077	 0.001158	 0.004194	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43075	 89973	 0.001005	 0.005327	 0.00178	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89939	 43076	 0.000698	 0.005228	 0.00128	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43077	 89942	 0.000874	 0.0035	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43078	 43145	 8.6e-05	 0.001199	 0.01185	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43078	 89941	 0.000125	 0.009999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89943	 43079	 0.011127	 0.021308	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89497	 43080	 0.001431	 0.019477	 0.03964	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89941	 43080	 0.000288	 0.002255	 0.00388	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43080	 89944	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43080	 89944	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43081	 43086	 7.2e-05	 0.000976	 0.01719	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43082	 43084	 0.000677	 0.003888	 0.0011	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43083	 43187	 0.0009	 0.005701	 0.00155	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43084	 43187	 0.002078	 0.008581	 0.00203	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89937	 43084	 0.000434	 0.004248	 0.00133	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43085	 43087	 0.000694	 0.003928	 0.00097	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43085	 43088	 0.00109	 0.006977	 0.00235	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43085	 43092	 0.001245	 0.01047	 0.0031	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43085	 43097	 0.001381	 0.005843	 0.00131	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43085	 89945	 0.000871	 0.004229	 0.00097	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43086	 43188	 4.6e-05	 0.000876	 0.01477	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43086	 89945	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43086	 89945	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43087	 43088	 0.000778	 0.003937	 0.0011	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43088	 43112	 0.000498	 0.007105	 0.00237	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43089	 43113	 0.004082	 0.011824	 0.00285	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43089	 89946	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43089	 89946	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43090	 89956	 0.024681	 0.019532	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43091	 43113	 0.000696	 0.002737	 0.00072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43091	 43114	 0.000915	 0.003724	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43091	 89994	 0.000493	 0.005284	 0.00169	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43092	 43093	 0.000745	 0.006792	 0.00247	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43093	 43094	 0.001347	 0.00556	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89323	 43093	 0.003292	 0.01318	 0.00332	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89323	 43094	 0.001388	 0.008613	 0.00209	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43094	 89947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43094	 89947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89947	 43095	 0.003611	 0.01582	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43095	 89950	 0.0041	 0.01538	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43096	 43097	 0.001561	 0.015254	 0.00428	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43096	 43100	 0.001188	 0.007525	 0.00204	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43096	 89948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43096	 89948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43097	 89949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43097	 89949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43097	 89994	 0.001619	 0.013009	 0.00366	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89948	 43098	 0.01316	 0.037746	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89949	 43098	 0.007036	 0.025136	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43098	 89950	 0.027066	 0.077631	 0.00119	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43098	 89954	 0.01873	 0.06558	 0.00182	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43098	 89984	 0.031702	 0.090926	 0.0014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43099	 43100	 0.000543	 0.004362	 0.00123	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89323	 43099	 0.000881	 0.003969	 0.00106	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89325	 43099	 0.000862	 0.008276	 0.00241	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43099	 89950	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43099	 89950	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43101	 43102	 0.000951	 0.008295	 0.00228	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43101	 43165	 0.001665	 0.01033	 0.0025	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43102	 43103	 0.000534	 0.005903	 0.00177	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43102	 43105	 0.000425	 0.003863	 0.00098	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43102	 43108	 0.000994	 0.007343	 0.00212	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43103	 89960	 0.000831	 0.009669	 0.00284	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43104	 89952	 0.029732	 0.019972	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43105	 89951	 0.000511	 0.004904	 0.00143	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43106	 43135	 0.000164	 0.001614	 0.02802	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43106	 43135	 0.000164	 0.001614	 0.02802	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43106	 89951	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43107	 43109	 0.001823	 0.007166	 0.00187	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43107	 43158	 0.002855	 0.011108	 0.00297	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43107	 43163	 0.001186	 0.010169	 0.00289	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89951	 43107	 0.000991	 0.010686	 0.00306	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43108	 43109	 0.001071	 0.00538	 0.0014	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43109	 43164	 0.000631	 0.006377	 0.00188	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43110	 43125	 0.01117	 0.025933	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43110	 89953	 0.012159	 0.026057	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43111	 43112	 0.000573	 0.002253	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43111	 43123	 0.00066	 0.002726	 0.00065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43111	 89953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43111	 89953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43112	 43121	 0.000407	 0.003491	 0.00099	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43112	 43122	 0.001107	 0.004027	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43112	 89954	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43112	 89954	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43113	 43133	 0.002937	 0.011758	 0.00296	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43113	 89955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43113	 89955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43114	 43115	 0.000223	 0.002292	 0.00065	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43114	 43132	 0.002374	 0.008273	 0.00192	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43114	 43190	 0.001279	 0.007347	 0.00208	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43115	 43117	 0.000815	 0.003097	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43115	 43119	 0.001107	 0.003013	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43115	 89956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43115	 89956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43116	 43117	 0.000509	 0.00204	 0.00051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43116	 43133	 0.000499	 0.003531	 0.00097	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43117	 89957	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43117	 89957	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89938	 43118	 0.005544	 0.021569	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89956	 43118	 0.005004	 0.014351	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89957	 43118	 0.011617	 0.008547	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43118	 89958	 0.009248	 0.022953	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43119	 43130	 0.001	 0.002411	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43119	 89958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43119	 89958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89954	 43120	 0.005498	 0.015768	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89955	 43120	 0.015784	 0.012372	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43120	 89959	 0.007966	 0.01047	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43120	 89971	 0.029341	 0.083262	 0.00131	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43121	 43129	 0.001274	 0.004613	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43121	 43131	 0.000364	 0.002029	 0.00052	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43121	 89959	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43121	 89959	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43122	 43126	 0.000796	 0.003096	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43122	 43129	 0.000319	 0.00314	 0.0013	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43123	 89960	 0.000963	 0.003141	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43124	 43128	 0.000441	 0.004577	 0.00986	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43124	 89960	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43124	 89960	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43124	 89966	 0.000357	 0.002756	 0.00561	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89952	 43125	 0.006806	 0.049745	 0.00092	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43125	 89967	 0.00285	 0.013682	 0.00041	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89960	 43126	 0.001374	 0.005221	 0.00146	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89959	 43127	 0.026871	 0.01977	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43127	 89962	 0.006437	 0.01179	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89319	 43128	 0.001506	 0.018941	 0.04528	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43128	 89961	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43128	 89961	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43128	 89964	 0.000122	 0.001344	 0.00531	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89961	 43129	 0.000697	 0.002535	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43129	 89962	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43129	 89962	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43129	 89965	 0.000668	 0.007164	 0.00186	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43130	 43131	 0.000418	 0.002126	 0.00077	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43130	 43132	 0.00072	 0.002831	 0.00074	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89961	 43130	 0.000994	 0.002707	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89961	 43132	 0.000807	 0.002692	 0.00068	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43132	 89965	 0.000443	 0.005381	 0.00145	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43133	 43140	 0.000656	 0.005729	 0.00227	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43133	 89963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43133	 89963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43133	 89965	 0.002318	 0.006125	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43134	 89964	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89965	 43134	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43135	 43136	 0.000109	 0.00115	 0.01719	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43135	 43136	 0.000109	 0.00115	 0.01719	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43135	 89966	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89963	 43137	 0.005484	 0.016506	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43137	 89968	 0.008782	 0.016085	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43137	 89970	 0.004937	 0.013051	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43138	 43139	 0.000518	 0.003972	 0.00106	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43138	 89968	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43138	 89968	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43139	 89969	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43139	 89969	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43139	 89973	 0.000383	 0.003998	 0.00135	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43140	 43141	 0.00341	 0.010054	 0.00234	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43140	 89970	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43140	 89970	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43140	 89973	 0.000375	 0.005114	 0.00183	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88846	 43141	 0.000886	 0.008467	 0.00279	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43141	 89971	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43141	 89971	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43141	 89972	 0.001001	 0.011066	 0.00332	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43142	 43143	 0.0001	 0.001063	 0.01589	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43142	 43143	 0.0001	 0.001063	 0.01589	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43142	 43149	 0.000169	 0.001909	 0.01738	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43142	 89972	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43142	 89972	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43143	 43145	 6.3e-05	 0.001042	 0.011	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43143	 43146	 5.2e-05	 0.000659	 0.01004	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43144	 43146	 5.5e-05	 0.000587	 0.00862	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43144	 89973	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43144	 89973	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43145	 89974	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43145	 89974	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43147	 89975	 0.024512	 0.024757	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43148	 43189	 0.076568	 0.10064	 0.00138	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43149	 43150	 0.000147	 0.001628	 0.0155	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43149	 89975	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43149	 89975	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43150	 89976	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43150	 89976	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43151	 43157	 0.002275	 0.024111	 0.00716	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43151	 43186	 0.007829	 0.045858	 0.01249	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88877	 43151	 0.000893	 0.009025	 0.00265	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43152	 43189	 0.030197	 0.069061	 0.00169	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43152	 89977	 0.022274	 0.052745	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43153	 89977	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43153	 89977	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43154	 43156	 0.000165	 0.002262	 0.03878	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43154	 89978	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43154	 89978	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43155	 43163	 0.004085	 0.017288	 0.00389	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43155	 89979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43155	 89979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43156	 89980	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43156	 89980	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43157	 43158	 0.003047	 0.012897	 0.0029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88904	 43157	 0.000406	 0.004574	 0.00132	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89979	 43159	 0.020184	 0.039963	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43159	 89981	 0.043053	 0.034071	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43159	 89982	 0.015727	 0.030822	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43160	 43161	 0.000508	 0.005306	 0.00146	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43160	 43167	 0.00054	 0.005786	 0.00185	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89978	 43160	 0.002385	 0.01094	 0.0028	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43160	 89981	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43160	 89981	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89978	 43161	 0.003204	 0.016096	 0.00419	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43161	 89982	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43161	 89982	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43162	 89983	 0.008636	 0.02283	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43162	 89984	 0.009355	 0.024049	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89978	 43163	 0.001149	 0.008611	 0.0021	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43163	 89983	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43163	 89983	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43164	 43165	 0.002543	 0.00672	 0.00157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43164	 43166	 0.000471	 0.004923	 0.00135	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43164	 89984	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43164	 89984	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89322	 43165	 0.002677	 0.014851	 0.00451	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89328	 43165	 0.000927	 0.00908	 0.00284	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89951	 43165	 0.001822	 0.019726	 0.0083	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43165	 89985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43165	 89985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43166	 43167	 0.000254	 0.002658	 0.00073	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89328	 43166	 0.003945	 0.01329	 0.0033	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43167	 89986	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43167	 89986	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43168	 89987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43168	 89987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43169	 43171	 0.000688	 0.00572	 0.00173	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43169	 89988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43169	 89988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89988	 43170	 0.010385	 0.016576	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43170	 89989	 0.0086	 0.022107	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43171	 89989	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43171	 89989	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43172	 43174	 0.001273	 0.005181	 0.00126	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43173	 89990	 0.022412	 0.017736	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43174	 89990	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43174	 89990	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43175	 89991	 0.020285	 0.050349	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43176	 43180	 0.006475	 0.019089	 0.00444	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88903	 43177	 0.017467	 0.029013	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89987	 43177	 0.10704	 0.084713	 0.00107	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43178	 43179	 0.001131	 0.007999	 0.00219	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43179	 89991	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43179	 89991	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43180	 89992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43180	 89992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89992	 43181	 0.11103	 0.11137	 0.0018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43181	 89993	 0.052728	 0.1044	 0.00153	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88904	 43182	 0.01031	 0.026766	 0.0065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43182	 89993	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43182	 89993	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88833	 43183	 0.012555	 0.035629	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89977	 43183	 0.023201	 0.05306	 0.0013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43184	 43185	 0.098723	 0.072636	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88833	 43184	 0.0157	 0.014461	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88832	 43186	 0.002438	 0.030042	 0.0097	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89965	 43187	 0.005679	 0.030575	 0.0084	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43188	 89994	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43188	 89994	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88921	 43189	 0.075412	 0.098144	 0.00137	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89994	 43190	 0.000662	 0.003802	 0.00108	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89518	 43191	 0.022091	 0.097333	 0.00169	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43191	 89995	 0.014789	 0.066175	 0.00136	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43192	 43193	 0.002191	 0.011414	 0.00299	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43192	 43195	 0.003475	 0.013519	 0.00361	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43192	 89995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43192	 89995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43192	 89999	 0.005202	 0.022016	 0.00495	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43194	 43196	 0.001887	 0.004986	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43194	 89999	 0.004387	 0.011593	 0.00271	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43195	 43196	 0.001712	 0.004526	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43195	 89996	 0.002297	 0.009028	 0.00236	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43197	 89996	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43197	 89996	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43197	 89998	 0.000572	 0.008814	 0.01942	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43198	 43200	 0.00281	 0.017794	 0.00483	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88925	 43199	 0.01034	 0.048226	 0.01195	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43199	 89997	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43199	 89997	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43200	 89999	 0.00251	 0.015896	 0.00431	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43201	 43204	 0.000326	 0.004118	 0.03672	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43201	 89998	 0.000104	 0.008333	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89999	 43201	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43202	 90001	 0.033311	 0.030996	 0.00059	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43203	 43204	 0.000228	 0.002585	 0.02354	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43203	 90000	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43204	 90002	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43204	 90002	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88925	 43205	 0.006464	 0.021084	 0.0056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43206	 43209	 0.02005	 0.013468	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43206	 90003	 0.01488	 0.026744	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43207	 90003	 0.00748	 0.01481	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43207	 90004	 0.005387	 0.012756	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43208	 43210	 0.000786	 0.004333	 0.00101	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43208	 43271	 0.001357	 0.00552	 0.00134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43208	 90003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43208	 90003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43209	 90019	 0.054992	 0.043105	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43209	 90021	 0.018972	 0.015014	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43210	 43211	 0.000938	 0.003971	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43210	 43270	 0.00336	 0.016569	 0.00448	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43210	 90004	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43210	 90004	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43211	 43254	 0.000938	 0.004302	 0.0011	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43211	 90005	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43211	 90005	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43212	 43225	 0.018161	 0.014372	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43213	 43214	 0.009223	 0.016893	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43213	 43225	 0.006695	 0.013701	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90005	 43214	 0.015453	 0.015608	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43215	 43216	 0.00113	 0.003769	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43215	 43264	 0.00116	 0.004201	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43215	 90006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43215	 90006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43216	 43219	 0.001217	 0.004099	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43217	 43218	 0.014724	 0.018278	 0.0004	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90004	 43217	 0.047337	 0.037462	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43218	 90007	 0.007985	 0.018538	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43219	 43229	 0.00241	 0.014114	 0.00384	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43219	 90007	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43219	 90007	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43220	 43222	 0.016629	 0.027773	 0.00047	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43220	 43272	 0.041769	 0.030731	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43221	 43222	 0.010137	 0.028765	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90007	 43221	 0.005776	 0.022472	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43223	 43224	 0.021159	 0.024802	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43223	 90017	 0.014429	 0.035813	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43225	 43233	 0.002279	 0.012807	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43226	 43227	 0.013322	 0.013456	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43226	 43249	 0.016087	 0.012731	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43227	 90009	 0.003592	 0.00834	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43227	 90014	 0.012635	 0.013897	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43228	 43229	 0.000364	 0.002729	 0.00067	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43228	 90008	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43228	 90008	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43229	 43248	 0.000862	 0.00312	 0.00067	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43229	 43250	 0.001975	 0.006141	 0.00128	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43229	 90009	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43229	 90009	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90008	 43230	 0.004688	 0.010518	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43230	 90010	 0.004105	 0.012607	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43231	 43232	 0.00374	 0.008856	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90009	 43231	 0.005609	 0.009864	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43232	 90010	 0.006917	 0.017782	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43233	 43234	 0.014304	 0.018615	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43233	 90010	 0.006184	 0.027555	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43234	 43235	 0.002883	 0.010301	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90006	 43234	 0.006843	 0.01942	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43234	 90017	 0.005718	 0.014697	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43235	 90010	 0.003774	 0.013213	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43236	 43238	 3e-05	 0.000528	 0.01089	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43236	 43276	 0.000743	 0.010176	 0.10372	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43236	 43280	 0.000514	 0.005936	 0.05204	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43236	 90010	 0.000326	 0.024426	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43236	 90010	 0.000326	 0.024426	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90010	 43237	 0.007459	 0.018969	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43237	 90012	 0.003686	 0.012296	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43238	 43282	 0.000133	 0.001321	 0.0226	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43238	 43282	 0.000133	 0.001321	 0.0226	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43238	 90011	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90011	 43239	 0.001388	 0.004155	 0.00094	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43240	 43244	 0.002598	 0.008667	 0.0022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43241	 43242	 0.010602	 0.017859	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43241	 90013	 0.041353	 0.03172	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43242	 43243	 0.010687	 0.017518	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43242	 90027	 0.020937	 0.060049	 0.00092	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43243	 90013	 0.025981	 0.018403	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43244	 90013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43244	 90013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43245	 43251	 0.004337	 0.014468	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43245	 90014	 0.005901	 0.007325	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43246	 43247	 0.011475	 0.008995	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90008	 43247	 0.003258	 0.00739	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43248	 43250	 0.00123	 0.003302	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43248	 90014	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43248	 90014	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43250	 43253	 0.00086	 0.003641	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43250	 43254	 0.001065	 0.005734	 0.00158	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43250	 90026	 0.004626	 0.02756	 0.00725	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43251	 43252	 0.002397	 0.012126	 0.00024	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43251	 43255	 0.018863	 0.037347	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90013	 43251	 0.001911	 0.009175	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43252	 43256	 0.029105	 0.023034	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43252	 90015	 0.007425	 0.017237	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43253	 43254	 0.001022	 0.003443	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43253	 90015	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43253	 90015	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90013	 43255	 0.061467	 0.048644	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43255	 90027	 0.025416	 0.058126	 0.00142	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43257	 43259	 0.010147	 0.010177	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90015	 43257	 0.008869	 0.014227	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43258	 43259	 0.0165	 0.013058	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90015	 43258	 0.017954	 0.030245	 0.00043	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43258	 90018	 0.044031	 0.066782	 0.00096	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43260	 90029	 0.032899	 0.089878	 0.00153	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43261	 43262	 0.000822	 0.006838	 0.00207	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90011	 43261	 0.003507	 0.010503	 0.00237	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43261	 90028	 0.001652	 0.010264	 0.0029	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43262	 43263	 0.002308	 0.008043	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89783	 43262	 0.013667	 0.040295	 0.00937	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43263	 43264	 0.000678	 0.002759	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43263	 90016	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43263	 90016	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43264	 90017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43264	 90017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90006	 43265	 0.036967	 0.028007	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43266	 43282	 8.2e-05	 0.000863	 0.01291	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43266	 43282	 8.2e-05	 0.000863	 0.01291	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43267	 43268	 0.005702	 0.019873	 0.00461	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43267	 43273	 0.008223	 0.019088	 0.00582	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43267	 90018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43267	 90018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43267	 90026	 0.004238	 0.031921	 0.00886	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43268	 43271	 0.003733	 0.01041	 0.00218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43268	 43275	 0.005027	 0.013285	 0.00311	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43268	 90019	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43268	 90019	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90019	 43269	 0.049279	 0.040561	 0.00082	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43270	 43271	 0.002525	 0.009923	 0.0026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43270	 90020	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43270	 90020	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43271	 90021	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43271	 90021	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90003	 43272	 0.005414	 0.02106	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90020	 43272	 0.020162	 0.039919	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43273	 43277	 0.004591	 0.012803	 0.00269	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43274	 90023	 0.048219	 0.049237	 0.00077	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43275	 90022	 0.004884	 0.01362	 0.00286	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43276	 90022	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90022	 43277	 0.003562	 0.008953	 0.00232	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43277	 90024	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43277	 90024	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90023	 43278	 0.069987	 0.04531	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90024	 43278	 0.047275	 0.037057	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43279	 45812	 0.0127	 0.044265	 0.01027	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90022	 43279	 0.016674	 0.056187	 0.01397	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43279	 90025	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43279	 90025	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43279	 90026	 0.013078	 0.044068	 0.01095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43280	 90026	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90027	 43281	 0.014289	 0.087849	 0.00158	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43282	 90028	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43283	 43286	 0.006725	 0.026925	 0.00678	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43283	 90030	 0.009417	 0.055165	 0.01503	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43284	 43285	 0.000752	 0.011254	 0.02633	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89526	 43284	 0.00531	 0.066447	 0.1308	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43284	 90030	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90031	 43284	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43285	 90032	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43285	 90032	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43286	 90033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43286	 90033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43287	 43288	 0.009774	 0.043551	 0.00074	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89893	 43287	 0.007945	 0.054537	 0.00099	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89805	 43288	 0.056201	 0.067279	 0.00112	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89806	 43288	 0.045526	 0.12035	 0.00219	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90032	 43289	 0.037657	 0.12563	 0.00199	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43289	 90034	 0.11183	 0.1009	 0.00169	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43290	 90034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43290	 90034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89682	 43291	 0.074951	 0.25008	 0.00396	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90031	 43291	 0.2196	 0.15558	 0.00246	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90034	 43291	 0.026217	 0.15934	 0.00294	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88796	 43292	 0.062464	 0.16058	 0.00249	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43292	 90117	 0.059212	 0.15696	 0.00398	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43293	 43294	 0.004656	 0.016292	 0.0054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43295	 43399	 0.31874	 0.32208	 0.00427	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43295	 90035	 0.22168	 0.17546	 0.00221	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43296	 90035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43296	 90035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43297	 43298	 0.15401	 0.20244	 0.00277	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88825	 43297	 0.040753	 0.07987	 0.0012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43298	 43299	 0.19957	 0.14685	 0.00215	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43299	 90036	 0.053115	 0.10517	 0.00154	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88825	 43300	 0.306	 0.23192	 0.00319	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43300	 90079	 0.34966	 0.27683	 0.00349	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43301	 43434	 0.019887	 0.052564	 0.0123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43301	 90036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43301	 90036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43302	 44036	 0.037564	 0.10089	 0.02288	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43302	 90037	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43302	 90037	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88829	 43303	 0.66485	 0.73285	 0.00979	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43303	 90038	 0.038289	 0.10866	 0.00171	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43303	 90265	 0.11618	 0.23006	 0.00338	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43304	 90038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43304	 90038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43305	 43306	 0.10219	 0.080875	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88816	 43305	 0.017417	 0.040014	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90037	 43305	 0.077899	 0.12435	 0.00286	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90038	 43305	 0.027642	 0.038524	 0.00066	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43307	 43308	 0.039819	 0.031212	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43308	 43396	 0.098832	 0.19152	 0.00412	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88815	 43308	 0.079833	 0.21107	 0.00383	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88815	 43309	 0.088123	 0.069741	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43310	 90040	 0.065017	 0.094744	 0.00214	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43310	 90060	 0.38379	 0.30099	 0.00386	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43311	 43312	 0.012325	 0.032575	 0.00763	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43311	 43352	 0.023285	 0.061549	 0.01441	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43311	 44021	 0.03115	 0.10691	 0.02563	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43311	 90039	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43311	 90039	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43312	 43313	 0.009238	 0.021444	 0.00653	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43312	 43701	 0.021481	 0.051772	 0.01462	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43312	 90040	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43312	 90040	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43314	 43315	 0.017594	 0.042402	 0.01197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43314	 43316	 0.028739	 0.074629	 0.01812	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43314	 43692	 0.01879	 0.050451	 0.01144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43314	 43698	 0.016168	 0.045089	 0.00946	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43315	 43316	 0.008576	 0.031054	 0.00666	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43315	 90041	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43315	 90041	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43316	 44022	 0.013347	 0.053442	 0.01347	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43317	 43318	 0.024398	 0.019308	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43317	 43322	 0.015042	 0.011904	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43317	 90042	 0.01141	 0.020507	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43318	 43326	 0.011843	 0.008561	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43319	 43320	 0.001267	 0.003403	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43319	 43330	 0.001276	 0.004299	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43319	 43338	 0.004003	 0.014149	 0.00319	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43320	 43332	 0.001737	 0.006954	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43320	 43334	 0.00504	 0.012668	 0.00328	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43320	 43336	 0.003728	 0.009853	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43320	 90042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43320	 90042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43321	 43335	 0.0187	 0.013246	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90042	 43321	 0.010223	 0.015661	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43323	 43338	 0.00243	 0.006775	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43323	 43339	 0.002914	 0.007823	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43324	 43328	 0.001518	 0.006424	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43324	 43339	 0.00364	 0.00962	 0.00225	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43324	 43351	 0.004112	 0.010868	 0.00254	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43324	 90043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43324	 90043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90043	 43325	 0.01312	 0.012677	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43325	 90050	 0.076863	 0.049762	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43326	 43327	 0.008289	 0.008313	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43327	 90044	 0.015587	 0.011468	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43327	 90045	 0.006348	 0.014518	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43328	 43353	 0.002229	 0.008471	 0.00237	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43328	 90044	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43328	 90044	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43329	 90045	 0.026315	 0.020825	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43329	 90051	 0.048271	 0.035515	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43330	 43331	 0.001622	 0.006492	 0.00164	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43330	 90045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43330	 90045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43332	 43346	 0.003943	 0.010421	 0.00244	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43333	 43344	 0.015623	 0.023932	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90042	 43333	 0.042125	 0.033337	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43333	 90046	 0.04472	 0.035054	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43334	 43336	 0.003098	 0.010103	 0.00268	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43334	 43348	 0.006085	 0.016969	 0.00356	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43334	 43565	 0.030462	 0.16736	 0.04432	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43334	 90046	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43334	 90046	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43335	 43337	 0.023344	 0.018474	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43335	 90047	 0.028051	 0.022199	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43336	 90047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43336	 90047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43338	 90048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43338	 90048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43339	 43351	 0.002138	 0.005739	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43339	 43354	 0.0123	 0.037023	 0.01158	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43339	 43372	 0.01636	 0.056128	 0.01345	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43340	 43343	 0.008071	 0.011761	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43341	 43342	 0.015729	 0.016548	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43341	 43344	 0.013205	 0.019329	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43342	 43343	 0.006563	 0.011308	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43344	 43345	 0.02285	 0.018083	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43345	 90049	 0.009335	 0.023996	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43346	 90049	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43346	 90049	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43347	 43386	 0.13753	 0.14982	 0.00204	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43348	 43368	 0.008656	 0.022473	 0.00545	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43349	 43365	 0.25932	 0.20527	 0.00258	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90048	 43349	 0.019453	 0.047615	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43350	 90050	 0.058766	 0.12594	 0.00221	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43350	 90059	 0.052208	 0.10337	 0.00152	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43351	 43352	 0.011264	 0.029771	 0.00697	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43351	 90050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43351	 90050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43353	 90051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43353	 90051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43354	 90052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43354	 90052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43355	 43559	 0.13278	 0.17136	 0.00344	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43355	 90053	 0.042863	 0.070262	 0.00124	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43356	 43361	 0.012596	 0.043213	 0.01035	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43356	 43544	 0.022441	 0.078228	 0.01815	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43356	 44004	 0.019109	 0.050507	 0.01182	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43356	 90053	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43356	 90053	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43357	 43358	 0.037356	 0.029281	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43357	 43359	 0.038315	 0.12338	 0.0021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90053	 43357	 0.005182	 0.020738	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43359	 43856	 0.081924	 0.27335	 0.00433	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43360	 90090	 0.19877	 0.15249	 0.00205	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43361	 43544	 0.01001	 0.038945	 0.0104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43361	 90054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43361	 90054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43362	 90055	 0.043653	 0.034218	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43363	 90055	 0.013266	 0.044255	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43363	 90056	 0.072369	 0.18406	 0.00291	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43364	 43368	 0.005764	 0.01726	 0.00389	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88793	 43364	 0.024579	 0.1441	 0.03931	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43364	 90055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43364	 90055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43365	 43366	 0.17136	 0.1731	 0.00229	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43366	 90057	 0.086908	 0.14641	 0.00209	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43367	 43369	 0.011707	 0.038185	 0.01014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43367	 43423	 0.01067	 0.041512	 0.01109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43367	 43424	 0.01822	 0.045805	 0.01187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43367	 90056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43367	 90056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43368	 90057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43368	 90057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43369	 43424	 0.01688	 0.047075	 0.00988	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43369	 43528	 0.017728	 0.049441	 0.01038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43369	 90058	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43369	 90058	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43370	 90060	 0.084029	 0.16469	 0.00247	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43370	 90110	 0.27652	 0.20956	 0.00289	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43371	 43372	 0.007473	 0.025634	 0.00614	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43371	 43374	 0.010401	 0.035046	 0.00871	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43371	 43530	 0.004346	 0.025243	 0.00594	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43372	 43373	 0.00965	 0.026911	 0.00565	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43372	 90059	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43372	 90059	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43373	 43374	 0.003791	 0.009841	 0.00239	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43373	 43375	 0.011954	 0.027749	 0.00845	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43374	 90060	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43374	 90060	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43375	 43701	 0.016984	 0.050079	 0.01165	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43376	 43378	 0.017241	 0.050835	 0.01183	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43376	 43797	 0.007309	 0.058729	 0.01651	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43376	 90061	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43376	 90061	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43377	 90062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43377	 90062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43378	 43379	 0.009016	 0.03038	 0.00755	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43379	 90063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43379	 90063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90063	 43380	 0.012338	 0.055208	 0.00114	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43380	 90064	 0.007571	 0.04254	 0.00079	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43381	 90064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43381	 90064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43382	 43384	 0.030457	 0.10657	 0.00221	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43382	 43386	 0.18574	 0.18581	 0.00251	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43383	 43384	 0.042448	 0.11251	 0.00285	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43383	 43538	 0.036236	 0.11117	 0.00301	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43384	 43535	 0.095654	 0.18941	 0.00278	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88794	 43384	 0.080673	 0.35961	 0.00611	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43385	 43564	 0.30651	 0.28537	 0.0054	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88794	 43386	 0.17368	 0.49849	 0.00767	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90055	 43386	 0.18289	 0.13457	 0.00197	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43387	 44072	 0.012091	 0.045963	 0.01287	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43387	 90065	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43387	 90065	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43388	 43938	 0.016737	 0.038854	 0.01184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43389	 43390	 0.06023	 0.18498	 0.00347	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88800	 43389	 0.14364	 0.41219	 0.00634	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90065	 43389	 0.10832	 0.19473	 0.0035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43389	 90267	 0.056481	 0.18843	 0.00299	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88800	 43390	 0.11713	 0.21056	 0.00378	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90063	 43390	 0.15547	 0.51345	 0.00833	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43390	 90066	 0.25743	 0.23234	 0.00389	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43391	 43393	 0.004514	 0.017158	 0.0048	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43391	 43394	 0.006088	 0.021219	 0.00492	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43391	 43544	 0.019378	 0.10277	 0.03432	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43391	 90066	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43391	 90066	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43392	 43393	 0.007383	 0.030485	 0.00721	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43392	 43394	 0.005674	 0.024859	 0.00855	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43392	 43454	 0.025907	 0.075055	 0.01811	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43393	 43394	 0.002645	 0.007375	 0.00155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43394	 90067	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43394	 90067	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43395	 43396	 0.27719	 0.21942	 0.00276	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43396	 43455	 0.10583	 0.24574	 0.00366	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90067	 43396	 0.048192	 0.18542	 0.00317	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43397	 43400	 0.006481	 0.019508	 0.0061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43397	 43401	 0.009736	 0.032478	 0.00824	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43398	 43400	 0.017686	 0.04592	 0.01115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43398	 43401	 0.014573	 0.04064	 0.00853	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43398	 43905	 0.016066	 0.055998	 0.01299	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43399	 90068	 0.1048	 0.20752	 0.00305	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43400	 43401	 0.00236	 0.011167	 0.00269	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43400	 90068	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43400	 90068	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43401	 51411	 0.064804	 0.1971	 0.04325	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43402	 43404	 0.052113	 0.12341	 0.00226	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43402	 43640	 0.11614	 0.16926	 0.00383	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43403	 43404	 0.072971	 0.11648	 0.00268	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43403	 43707	 0.046532	 0.15357	 0.00249	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43404	 90069	 0.24988	 0.18068	 0.00274	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43404	 90070	 0.052684	 0.1223	 0.00233	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43405	 43765	 0.019284	 0.049576	 0.01228	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43405	 43943	 0.013741	 0.038319	 0.00804	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43405	 90069	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43405	 90069	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43406	 43766	 0.016985	 0.046247	 0.01019	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43406	 90070	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43406	 90070	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43406	 90134	 0.027695	 0.069635	 0.01805	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43407	 90071	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43407	 90071	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43407	 90072	 0.004241	 0.014147	 0.00359	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43408	 44475	 0.002075	 0.023122	 0.21831	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43408	 90072	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43409	 43410	 0.005308	 0.013645	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43410	 43416	 0.021001	 0.048756	 0.00073	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90073	 43410	 0.008024	 0.049328	 0.00089	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43411	 43416	 0.020204	 0.067401	 0.00107	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43411	 43534	 0.033273	 0.12945	 0.00216	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43412	 43413	 0.14324	 0.11337	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88798	 43412	 0.047012	 0.061789	 0.00085	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43413	 90120	 0.066531	 0.13173	 0.00193	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88798	 43414	 0.010163	 0.062483	 0.00113	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88797	 43415	 0.015241	 0.039181	 0.0097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43415	 90113	 0.024835	 0.065646	 0.01537	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43416	 43417	 0.011543	 0.033106	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90071	 43417	 0.006731	 0.022212	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43418	 43420	 0.01766	 0.049252	 0.01034	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43418	 90074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43418	 90074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43419	 43778	 0.076663	 0.12915	 0.00184	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90074	 43419	 0.038834	 0.095058	 0.00163	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43420	 43421	 0.019345	 0.04491	 0.01368	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43420	 43994	 0.036576	 0.094995	 0.02307	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43420	 90190	 0.01733	 0.060404	 0.01401	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43422	 43425	 0.00605	 0.017836	 0.00415	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43422	 43536	 0.016838	 0.067427	 0.01699	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43422	 90075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43422	 90075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43424	 43425	 0.012676	 0.033503	 0.00784	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43425	 90076	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43425	 90076	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43426	 43427	 0.006195	 0.020872	 0.00519	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43426	 43712	 0.021733	 0.074568	 0.01787	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43426	 44027	 0.032035	 0.12835	 0.03237	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43426	 44029	 0.0228	 0.12519	 0.03312	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43426	 90077	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43426	 90077	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43427	 43712	 0.015573	 0.046877	 0.01467	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43428	 43474	 0.25941	 0.27716	 0.00586	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90077	 43428	 0.061942	 0.12264	 0.0018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43429	 43778	 0.32202	 0.52549	 0.00802	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43429	 43790	 0.058678	 0.15085	 0.00233	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90061	 43429	 0.31081	 0.31406	 0.00416	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43429	 90078	 0.071715	 0.19867	 0.00328	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43429	 90109	 0.12201	 0.40722	 0.00646	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43430	 43493	 0.005497	 0.043313	 0.01267	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43432	 90078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43432	 90078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88825	 43433	 0.59021	 0.46764	 0.00589	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43433	 90681	 0.17731	 0.12562	 0.00199	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43434	 43435	 0.012799	 0.043127	 0.01072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43434	 45591	 0.026219	 0.079636	 0.01745	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43434	 90079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43434	 90079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43435	 43438	 0.006719	 0.041697	 0.0101	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43435	 90080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43435	 90080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43436	 43437	 0.14746	 0.11559	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89014	 43436	 0.21467	 0.16266	 0.00224	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90080	 43436	 0.29626	 0.21804	 0.00319	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43437	 43476	 0.19351	 0.15931	 0.00323	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90080	 43437	 0.35876	 0.28404	 0.00358	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43438	 43477	 0.020045	 0.052983	 0.0124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43438	 43529	 0.01895	 0.084468	 0.02296	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43439	 43441	 0.000798	 0.003663	 0.00094	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43440	 43442	 0.000237	 0.002683	 0.02442	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43440	 90081	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43442	 43446	 0.00018	 0.003016	 0.02847	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43442	 90083	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43443	 43444	 0.001505	 0.006774	 0.0018	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90083	 43443	 0.002375	 0.012785	 0.00351	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43444	 90085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43444	 90085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89916	 43445	 0.026745	 0.048072	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90085	 43445	 0.012353	 0.02528	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43446	 43496	 0.003139	 0.035629	 0.3253	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43446	 90086	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43446	 90086	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43447	 43448	 0.020194	 0.050769	 0.01315	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43447	 43599	 0.023572	 0.080883	 0.01938	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90086	 43447	 0.004204	 0.029733	 0.00816	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43448	 43449	 0.011518	 0.03757	 0.00997	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43448	 43943	 0.017826	 0.048538	 0.0107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43449	 43598	 0.009152	 0.026984	 0.00628	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43449	 90087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43449	 90087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43450	 43596	 0.057929	 0.13249	 0.00323	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90084	 43450	 0.060471	 0.1501	 0.00249	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88800	 43451	 0.12689	 0.23245	 0.00401	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88808	 43451	 0.033599	 0.06154	 0.00106	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43452	 43589	 0.014484	 0.061309	 0.0138	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43452	 43754	 0.020548	 0.08229	 0.02074	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43452	 90088	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43452	 90088	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43453	 43454	 0.009631	 0.045585	 0.01096	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43453	 90177	 0.009609	 0.055217	 0.01564	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43454	 90089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43454	 90089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43455	 43986	 0.15351	 0.27599	 0.00496	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88799	 43455	 0.24182	 0.55607	 0.00845	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90089	 43455	 0.020045	 0.11395	 0.00206	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43455	 90123	 0.31976	 0.62744	 0.00942	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43456	 43457	 0.007657	 0.025545	 0.00648	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43456	 43892	 0.008505	 0.030796	 0.00661	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43457	 43460	 0.009517	 0.03873	 0.00944	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43458	 90090	 0.011274	 0.022321	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43458	 90091	 0.063629	 0.13374	 0.00244	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43459	 43460	 0.012822	 0.033887	 0.00793	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43459	 43897	 0.0308	 0.10571	 0.02534	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43459	 44073	 0.036168	 0.14228	 0.03727	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43459	 90090	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43459	 90090	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43460	 43896	 0.02808	 0.10172	 0.02183	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43460	 90091	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43460	 90091	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43461	 43462	 0.003384	 0.027013	 0.00666	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43461	 43554	 0.006347	 0.052672	 0.01386	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43462	 43465	 0.011667	 0.039312	 0.00977	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43462	 43470	 0.006325	 0.021311	 0.0053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43462	 90092	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43462	 90092	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43463	 90093	 0.038016	 0.029799	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43464	 43465	 0.002537	 0.00681	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43464	 43887	 0.00548	 0.01664	 0.00364	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43464	 43889	 0.002493	 0.006266	 0.00162	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43465	 43469	 0.002402	 0.005576	 0.0017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43465	 43865	 0.008031	 0.02156	 0.00489	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43465	 43889	 0.004772	 0.012388	 0.00301	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43465	 90093	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43465	 90093	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90093	 43466	 0.012701	 0.025146	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43466	 90094	 0.059018	 0.046262	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43467	 43468	 0.004858	 0.012211	 0.00316	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43467	 43887	 0.005307	 0.013777	 0.00334	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43467	 90094	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43467	 90094	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43468	 43718	 0.015946	 0.038431	 0.01085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43469	 43470	 0.00601	 0.020617	 0.00494	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43471	 43472	 0.069529	 0.19944	 0.00307	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43471	 43645	 0.23988	 0.51453	 0.00902	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43471	 49948	 0.067704	 0.25949	 0.00734	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43471	 90261	 0.16048	 0.36883	 0.0056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43472	 44041	 0.12903	 0.29652	 0.00451	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43472	 46999	 0.063516	 0.43166	 0.01069	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90037	 43472	 0.1196	 0.20151	 0.00287	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43472	 90179	 0.16974	 0.40217	 0.00736	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43473	 43475	 0.015602	 0.041353	 0.00105	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43473	 44061	 0.073888	 0.169	 0.00413	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43474	 43475	 0.037226	 0.14483	 0.00242	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43474	 44028	 0.090559	 0.37029	 0.0075	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43476	 43520	 0.028455	 0.12918	 0.0028	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43476	 90095	 0.055699	 0.14764	 0.00375	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43477	 43478	 0.008865	 0.023016	 0.00559	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43478	 90095	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43478	 90095	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43479	 43700	 0.051976	 0.19999	 0.00341	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90095	 43479	 0.14115	 0.14157	 0.00229	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43480	 43481	 0.002245	 0.005932	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43480	 43482	 0.001736	 0.00466	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43481	 90096	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43481	 90096	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43482	 43483	 0.001069	 0.003096	 0.00075	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43482	 90097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43482	 90097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43483	 43484	 0.001122	 0.003744	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43484	 43485	 0.002188	 0.007507	 0.0018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43485	 90098	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43485	 90098	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88813	 43486	 0.007099	 0.014527	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90096	 43486	 0.0303	 0.029765	 0.0005	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43486	 90125	 0.20157	 0.36019	 0.00532	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43487	 43488	 0.071112	 0.1574	 0.00258	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90096	 43487	 0.007312	 0.020226	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43488	 43710	 0.27017	 0.19883	 0.00291	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89534	 43488	 0.25428	 0.20128	 0.00253	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43489	 43490	 0.014109	 0.04754	 0.01182	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43489	 43579	 0.014148	 0.036732	 0.00892	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43490	 43655	 0.023137	 0.061157	 0.01432	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43490	 90099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43490	 90099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88806	 43491	 0.008124	 0.031931	 0.00835	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43491	 90100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43491	 90100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43492	 43494	 0.0029	 0.017274	 0.00454	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43492	 43495	 0.003911	 0.010499	 0.00238	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43493	 43495	 0.012575	 0.031612	 0.00819	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43493	 43525	 0.009016	 0.048463	 0.01192	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43494	 90101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43494	 90101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43494	 90464	 0.010973	 0.054112	 0.01463	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43496	 90102	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90103	 43497	 0.02468	 0.019531	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43498	 43499	 0.000703	 0.003467	 0.00094	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43498	 43513	 0.00197	 0.006638	 0.00165	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43498	 45803	 0.011145	 0.036352	 0.00965	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43499	 43507	 0.003678	 0.011013	 0.00248	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90102	 43499	 0.000624	 0.003955	 0.00107	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43499	 90104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43499	 90104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90104	 43500	 0.019258	 0.015095	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43500	 90105	 0.012666	 0.010024	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43501	 43505	 0.001432	 0.003785	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43501	 90105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43501	 90105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43502	 43503	 0.007622	 0.019594	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90103	 43502	 0.008648	 0.02223	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90105	 43502	 0.00347	 0.009174	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43502	 90106	 0.009105	 0.014606	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43503	 43512	 0.041134	 0.030264	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43504	 43514	 0.085175	 0.067407	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90103	 43504	 0.071289	 0.05245	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43504	 90106	 0.030028	 0.023763	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43505	 43508	 0.001229	 0.003298	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43505	 90106	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43505	 90106	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43506	 43507	 0.001256	 0.003702	 0.00086	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43506	 43508	 0.001596	 0.004217	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43507	 43521	 0.006594	 0.034181	 0.00835	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43509	 43510	 0.03373	 0.026693	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43509	 43511	 0.016213	 0.012831	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90106	 43509	 0.029395	 0.021249	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43510	 43511	 0.018098	 0.014322	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43510	 43514	 0.018244	 0.016348	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43510	 43516	 0.11119	 0.087997	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90103	 43510	 0.10743	 0.079043	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43511	 43514	 0.043873	 0.032279	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90106	 43511	 0.045355	 0.029363	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43513	 45793	 0.038086	 0.14832	 0.03967	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43513	 45803	 0.010525	 0.036105	 0.00865	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90102	 43513	 0.002008	 0.012718	 0.00345	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43513	 90107	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43513	 90107	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89014	 43514	 0.11316	 0.32465	 0.00499	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43515	 43595	 0.022297	 0.056056	 0.01453	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43516	 90108	 0.035919	 0.083379	 0.00159	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43517	 43518	 0.016763	 0.042142	 0.01092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43517	 43521	 0.013812	 0.035799	 0.01083	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43517	 90108	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43517	 90108	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43518	 43599	 0.036313	 0.098905	 0.0218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43519	 43520	 0.018523	 0.029566	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90108	 43519	 0.13607	 0.098374	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43520	 43641	 0.41379	 0.26809	 0.0051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90103	 43520	 0.5333	 0.3457	 0.00658	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43522	 43789	 0.02116	 0.069031	 0.01833	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43522	 44886	 0.020543	 0.055158	 0.0125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43523	 90109	 0.072525	 0.057396	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43524	 43525	 0.001799	 0.007204	 0.00181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43524	 44885	 0.016034	 0.078265	 0.02162	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43524	 90109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43524	 90109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43526	 43527	 0.12094	 0.20202	 0.00343	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43526	 43531	 0.036195	 0.085712	 0.00157	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43526	 43532	 0.05265	 0.13535	 0.00209	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43527	 90110	 0.06152	 0.20525	 0.00325	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43528	 43529	 0.006508	 0.017719	 0.0039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43529	 43530	 0.00244	 0.008222	 0.00204	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43530	 90110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43530	 90110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90079	 43531	 0.074198	 0.17572	 0.00321	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90058	 43532	 0.062484	 0.15296	 0.00262	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43533	 90111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43533	 90111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43534	 43535	 0.26615	 0.21068	 0.00265	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90111	 43534	 0.071185	 0.183	 0.00283	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88827	 43535	 0.092615	 0.15603	 0.00222	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43536	 43537	 0.00195	 0.007807	 0.00197	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43536	 90112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43536	 90112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43538	 90114	 0.014531	 0.050877	 0.00141	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43539	 90113	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43540	 44114	 0.041144	 0.18336	 0.00311	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90073	 43540	 0.6884	 0.54567	 0.00687	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90114	 43540	 0.072269	 0.14309	 0.0021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43541	 43782	 0.009758	 0.028769	 0.00669	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43541	 46982	 0.013107	 0.079288	 0.02024	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88819	 43541	 0.019896	 0.13669	 0.03992	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43541	 90115	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43541	 90115	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43542	 43543	 0.042813	 0.11006	 0.0017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43542	 43750	 0.13333	 0.30639	 0.00466	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88820	 43542	 0.2458	 0.48208	 0.00723	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43542	 90172	 0.10159	 0.22796	 0.00364	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43542	 91951	 0.1561	 0.51554	 0.00836	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43542	 93180	 0.04815	 0.235	 0.00406	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90115	 43543	 0.11495	 0.22762	 0.00334	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43544	 90116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43544	 90116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43545	 43546	 0.019979	 0.10107	 0.00176	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90116	 43545	 0.039007	 0.086335	 0.00142	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43546	 43547	 0.017196	 0.10572	 0.00191	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90066	 43547	 0.028711	 0.15365	 0.00466	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43548	 43551	 0.10703	 0.27225	 0.00431	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90049	 43548	 0.17502	 0.1865	 0.00266	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43549	 43550	 0.21567	 0.1707	 0.00215	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43550	 43551	 0.059621	 0.099435	 0.00145	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43551	 90122	 0.036956	 0.12932	 0.00268	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43551	 90169	 0.086478	 0.20079	 0.00299	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43552	 43553	 0.046506	 0.19009	 0.00385	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90091	 43552	 0.068948	 0.17725	 0.00274	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88815	 43553	 0.049527	 0.30108	 0.00556	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43554	 90117	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43554	 90117	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43555	 43556	 0.016408	 0.056294	 0.01349	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43555	 44065	 0.037929	 0.10028	 0.02348	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43555	 90118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43555	 90118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43556	 90119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43556	 90119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43557	 43558	 0.022362	 0.040193	 0.00072	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90118	 43557	 0.016671	 0.042855	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90119	 43559	 0.16966	 0.21596	 0.00316	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43560	 44075	 0.019887	 0.067016	 0.01666	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88797	 43560	 0.02037	 0.063356	 0.01322	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43560	 90120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43560	 90120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43561	 43647	 0.036057	 0.093644	 0.02274	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43561	 44111	 0.023198	 0.061318	 0.01436	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43562	 43563	 0.21018	 0.16636	 0.00209	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88802	 43562	 0.020004	 0.057374	 0.00088	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43563	 44115	 0.48822	 0.49364	 0.00654	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43563	 90139	 0.043843	 0.15342	 0.00318	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43564	 90121	 0.037105	 0.08486	 0.00207	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43564	 90122	 0.027515	 0.10704	 0.00179	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88793	 43565	 0.008606	 0.033827	 0.00885	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88793	 43565	 0.008606	 0.033827	 0.00885	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43565	 90121	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43565	 90121	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43566	 43567	 0.030658	 0.12531	 0.00253	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88794	 43566	 0.03874	 0.13556	 0.00281	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90121	 43566	 0.038411	 0.055971	 0.00126	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88803	 43567	 0.24917	 0.38189	 0.00536	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88804	 43567	 0.14404	 0.22068	 0.0031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90119	 43567	 0.098688	 0.19343	 0.0029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43568	 43569	 0.009654	 0.032526	 0.00808	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43569	 90122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43569	 90122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43570	 43571	 0.005745	 0.026355	 0.00675	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43570	 90177	 0.010016	 0.04861	 0.01111	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43571	 43572	 0.004795	 0.023398	 0.00646	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43572	 43573	 0.005811	 0.023991	 0.00568	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43572	 43754	 0.035256	 0.14569	 0.03451	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43572	 50209	 0.023379	 0.061797	 0.01447	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43572	 90123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43572	 90123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43572	 90227	 0.027606	 0.10856	 0.02842	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43573	 43899	 0.010308	 0.041948	 0.01022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43573	 50209	 0.012555	 0.045463	 0.00976	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43573	 90124	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43573	 90124	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43574	 43903	 0.2188	 0.26201	 0.00436	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88820	 43574	 0.27725	 0.46737	 0.00666	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90123	 43574	 0.05509	 0.1279	 0.0019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90124	 43574	 0.16137	 0.12771	 0.00161	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43574	 93214	 0.13791	 0.30532	 0.00501	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43575	 43609	 0.26278	 0.26842	 0.00418	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43575	 90162	 0.15457	 0.21093	 0.00377	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43576	 43577	 0.10434	 0.082575	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43577	 90125	 0.017384	 0.035574	 0.00088	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43578	 43579	 0.008167	 0.021584	 0.00505	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43578	 44030	 0.025818	 0.087016	 0.02163	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43578	 90125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43578	 90125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43580	 43581	 0.10278	 0.080569	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43580	 44078	 0.038788	 0.16417	 0.0031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43580	 44468	 0.076455	 0.19656	 0.00304	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43583	 43585	 0.040951	 0.11746	 0.00181	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43583	 44115	 0.14619	 0.2168	 0.00326	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43584	 90126	 0.11821	 0.1194	 0.00158	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43584	 90141	 0.15536	 0.30456	 0.00457	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43585	 90126	 0.00591	 0.01813	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43586	 44072	 0.014776	 0.049788	 0.01237	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43586	 44113	 0.040563	 0.10536	 0.02559	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43586	 90126	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43586	 90126	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43587	 43589	 0.011831	 0.047372	 0.01194	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43588	 43589	 0.00931	 0.023934	 0.00593	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43588	 43936	 0.016968	 0.044054	 0.01069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43590	 43591	 0.074507	 0.19155	 0.00296	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43590	 90135	 0.43359	 0.40698	 0.00629	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43591	 43928	 0.29824	 0.21567	 0.00327	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90041	 43591	 0.042107	 0.12918	 0.0035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43591	 90127	 0.28383	 0.22468	 0.00283	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43592	 43593	 0.019928	 0.052673	 0.01233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43592	 90127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43592	 90127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43593	 43635	 0.021336	 0.056395	 0.0132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43594	 43640	 0.33828	 0.26782	 0.00337	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43594	 90129	 0.2252	 0.16282	 0.00247	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43595	 43597	 0.011031	 0.026583	 0.00751	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89047	 43596	 0.17371	 0.19109	 0.00255	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43596	 90128	 0.10526	 0.17733	 0.00253	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43597	 43599	 0.017024	 0.057366	 0.01426	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43597	 90128	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43597	 90128	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43598	 43599	 0.002685	 0.006971	 0.00169	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43598	 90129	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43598	 90129	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43600	 43739	 0.020076	 0.054664	 0.01204	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43600	 90130	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43600	 90130	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43601	 44012	 0.30373	 0.24044	 0.00303	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43602	 43604	 0.011467	 0.026225	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43602	 43605	 0.007106	 0.020381	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43602	 43607	 0.052441	 0.12175	 0.00181	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43602	 90218	 0.074201	 0.32703	 0.00568	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43603	 43604	 0.004275	 0.017107	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90130	 43603	 0.030748	 0.11535	 0.00207	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43604	 43605	 0.006014	 0.017248	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43606	 43607	 0.037479	 0.14581	 0.00243	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43606	 43873	 0.066202	 0.13549	 0.00333	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43606	 90168	 0.079979	 0.22942	 0.00353	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43606	 90217	 0.01985	 0.082412	 0.00215	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88829	 43608	 0.10193	 0.21847	 0.00383	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90130	 43608	 0.094031	 0.17487	 0.00409	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43609	 90132	 0.069076	 0.085749	 0.00187	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43610	 43611	 0.004883	 0.01856	 0.0052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43610	 44042	 0.010732	 0.041754	 0.01115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43611	 43612	 0.003985	 0.009604	 0.00271	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43611	 43709	 0.057115	 0.13778	 0.03895	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43611	 90131	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43611	 90131	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43612	 43655	 0.044795	 0.10802	 0.03052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43612	 90132	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43612	 90132	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43613	 43622	 0.043942	 0.028448	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43613	 43707	 0.37423	 0.2963	 0.00373	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43613	 90136	 0.042772	 0.027691	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43614	 43616	 0.001706	 0.005854	 0.0014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43615	 43616	 0.002219	 0.005956	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43615	 90133	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43615	 90133	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43617	 90137	 0.10717	 0.10825	 0.00143	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43620	 90136	 0.012453	 0.009761	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43621	 43622	 0.022415	 0.017739	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43621	 43624	 0.0137	 0.010079	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43622	 43623	 0.021458	 0.016981	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43623	 90135	 0.024615	 0.015936	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43624	 43625	 0.020227	 0.014882	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43624	 90135	 0.010523	 0.011574	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43625	 90136	 0.014008	 0.011085	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43626	 43768	 0.00142	 0.015819	 0.14925	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43626	 90134	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43627	 43628	 0.010602	 0.021696	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43627	 43636	 0.053198	 0.084916	 0.00196	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90135	 43628	 0.005664	 0.014559	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43628	 90136	 0.042237	 0.030533	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43629	 90136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43629	 90136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90136	 43630	 0.017279	 0.012712	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43631	 43634	 0.074535	 0.11418	 0.0016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43632	 43706	 0.017948	 0.079977	 0.00136	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90133	 43633	 0.059929	 0.11866	 0.00174	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43633	 90137	 0.24669	 0.19341	 0.00248	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90133	 43634	 0.031133	 0.052446	 0.00075	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90135	 43634	 0.12838	 0.12877	 0.00208	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90134	 43635	 0.015963	 0.04219	 0.00988	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43635	 90137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43635	 90137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43636	 43767	 0.17418	 0.12816	 0.00187	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43637	 43640	 0.31119	 0.24635	 0.0031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43637	 43641	 0.076684	 0.060687	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43638	 43639	 0.054651	 0.1001	 0.00173	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43638	 43641	 0.059255	 0.15233	 0.00236	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43638	 90146	 0.065561	 0.2551	 0.00426	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43639	 43707	 0.081169	 0.20868	 0.00323	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90087	 43640	 0.35935	 0.23278	 0.00443	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43642	 43643	 0.16463	 0.19711	 0.00328	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43642	 43645	 0.091359	 0.20992	 0.00319	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43642	 44056	 0.25854	 0.16743	 0.00319	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90127	 43642	 0.30704	 0.27528	 0.00563	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90137	 43642	 0.3367	 0.44283	 0.00607	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43643	 43644	 0.082448	 0.13771	 0.00234	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43643	 43932	 0.34921	 0.27647	 0.00348	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43643	 44056	 0.53489	 0.35974	 0.00634	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90127	 43643	 0.092738	 0.21533	 0.0032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43643	 90167	 0.14256	 0.40475	 0.00636	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43644	 43645	 0.073567	 0.11743	 0.00271	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43645	 43721	 0.074862	 0.22971	 0.00622	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90132	 43645	 0.46589	 0.30191	 0.00575	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43646	 43648	 0.014854	 0.044712	 0.01399	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43646	 44461	 0.021892	 0.075117	 0.018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43646	 90138	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43646	 90138	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43647	 43650	 0.007773	 0.026667	 0.00639	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88801	 43647	 0.019169	 0.064596	 0.01606	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43647	 90139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43647	 90139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43648	 43650	 0.020977	 0.056324	 0.01277	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43648	 43651	 0.018128	 0.061089	 0.01519	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90139	 43649	 0.070298	 0.13463	 0.00212	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43649	 90140	 0.027891	 0.027973	 0.00045	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43649	 90141	 0.026011	 0.085839	 0.00139	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43650	 90140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43650	 90140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43651	 43797	 0.013298	 0.095701	 0.02537	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43651	 90141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43651	 90141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43652	 43653	 0.002778	 0.006983	 0.00181	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43652	 43655	 0.018117	 0.046577	 0.01154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43652	 90142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43652	 90142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43653	 90143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43653	 90143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43654	 43662	 0.024944	 0.071544	 0.0011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90099	 43654	 0.036619	 0.096804	 0.00176	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43656	 43658	 0.025436	 0.066048	 0.01603	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43656	 44030	 0.032753	 0.091364	 0.01918	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43656	 90144	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43656	 90144	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90144	 43657	 0.20674	 0.19391	 0.003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43657	 90145	 0.04265	 0.084444	 0.00124	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43658	 43659	 0.003312	 0.011159	 0.00277	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43658	 90145	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43658	 90145	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43659	 43661	 0.000725	 0.003838	 0.00097	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43659	 48933	 0.012935	 0.068771	 0.01596	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43660	 43661	 0.000721	 0.003737	 0.00091	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90142	 43662	 0.061373	 0.044367	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90143	 43662	 0.086516	 0.068469	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43663	 43671	 0.00285	 0.007652	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43663	 90146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43663	 90146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43664	 43675	 0.028548	 0.021004	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43664	 90147	 0.013291	 0.025453	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43665	 43669	 0.040423	 0.037908	 0.00059	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43666	 43676	 0.015703	 0.040696	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43666	 43681	 0.025563	 0.065712	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43666	 43705	 0.005922	 0.046159	 0.00086	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43667	 90147	 0.019469	 0.045199	 0.00067	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43667	 90161	 0.045734	 0.14046	 0.00264	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43668	 43673	 0.00148	 0.006021	 0.00147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43668	 43674	 0.000997	 0.004444	 0.00121	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43668	 90147	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43668	 90147	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43669	 43670	 0.013498	 0.022126	 0.00039	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43669	 90148	 0.016879	 0.031385	 0.00073	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43669	 90150	 0.00473	 0.023924	 0.00042	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90146	 43670	 0.017909	 0.019698	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43671	 43672	 0.001322	 0.005293	 0.00133	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43671	 90148	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43671	 90148	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43672	 43684	 0.002302	 0.007896	 0.00189	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43672	 90149	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43672	 90149	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43673	 43688	 0.001772	 0.007211	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43673	 90150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43673	 90150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43674	 43684	 0.001023	 0.004095	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43674	 90151	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43674	 90151	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90151	 43675	 0.033913	 0.026583	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43676	 43677	 0.043702	 0.030957	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43676	 43682	 0.016372	 0.037136	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43678	 43679	 0.024745	 0.01602	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43679	 90156	 0.014936	 0.02491	 0.00036	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43679	 90159	 0.043202	 0.027969	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43680	 43681	 0.0063	 0.016194	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43680	 43682	 0.00772	 0.017923	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43680	 90155	 0.002314	 0.010195	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88810	 43682	 0.003078	 0.010268	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43683	 43684	 0.002182	 0.005766	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43684	 43688	 0.001305	 0.003448	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43684	 90152	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43684	 90152	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90149	 43685	 0.023011	 0.019666	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43685	 90153	 0.022996	 0.018928	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43686	 43696	 0.002765	 0.00771	 0.00162	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43686	 90153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43686	 90153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43687	 43688	 0.001059	 0.003634	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43687	 43695	 0.001275	 0.004373	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43687	 90154	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43687	 90154	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43689	 43695	 0.001068	 0.003665	 0.00088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43690	 43693	 0.008096	 0.013638	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43690	 90155	 0.006204	 0.020696	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43691	 43692	 0.001145	 0.003117	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43691	 90155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43691	 90155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43692	 43697	 0.003097	 0.008433	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43692	 43698	 0.00392	 0.009099	 0.00277	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43692	 90156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43692	 90156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90156	 43693	 0.021341	 0.017566	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43693	 90158	 0.023201	 0.018186	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43694	 43695	 0.000918	 0.003094	 0.00077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43694	 90157	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43694	 90157	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43697	 90158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43697	 90158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43698	 90159	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43698	 90159	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43699	 90160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43699	 90160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43700	 43703	 0.104	 0.26741	 0.00414	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43700	 90161	 0.014958	 0.071803	 0.00215	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43702	 90161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43702	 90161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43703	 43704	 0.035447	 0.075679	 0.00171	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43703	 43707	 0.052481	 0.12003	 0.00293	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90146	 43704	 0.018049	 0.035372	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90148	 43704	 0.031969	 0.057102	 0.00084	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88790	 43705	 0.003866	 0.03556	 0.00071	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90160	 43706	 0.014248	 0.036926	 0.0007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90070	 43707	 0.33705	 0.33825	 0.00547	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90148	 43707	 0.030308	 0.15039	 0.00359	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43708	 43709	 0.011082	 0.03878	 0.01285	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88788	 43708	 0.006899	 0.02762	 0.00696	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43709	 44057	 0.025175	 0.067599	 0.01532	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43709	 90162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43709	 90162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43709	 90181	 0.013417	 0.051006	 0.01428	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90162	 43710	 0.34061	 0.22063	 0.0042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43711	 43760	 0.099899	 0.19781	 0.0029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43711	 90163	 0.030471	 0.072155	 0.00132	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43712	 43713	 0.006992	 0.023984	 0.00575	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43712	 43714	 0.009229	 0.031097	 0.00773	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43713	 43714	 0.003273	 0.011853	 0.00254	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43714	 90163	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43714	 90163	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43714	 90178	 0.022797	 0.11247	 0.03044	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43715	 90164	 0.057159	 0.12204	 0.00276	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43715	 90186	 0.18033	 0.33043	 0.00571	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43715	 90568	 0.53914	 0.42709	 0.00538	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43716	 43991	 0.026225	 0.081575	 0.01703	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43716	 45188	 0.020966	 0.054436	 0.01321	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43716	 90164	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43716	 90164	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43717	 43779	 0.039183	 0.13666	 0.03172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43717	 43993	 0.033442	 0.086849	 0.02109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43717	 45187	 0.03381	 0.094314	 0.0198	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43717	 50293	 0.017543	 0.080502	 0.02063	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43717	 90165	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43717	 90165	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43718	 43719	 0.007976	 0.027799	 0.00645	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43719	 90166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43719	 90166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90166	 43720	 0.1126	 0.075638	 0.00133	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43721	 43725	 0.079447	 0.1083	 0.0024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43721	 90167	 0.046914	 0.20907	 0.00355	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43722	 90167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43722	 90167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43723	 43727	 0.033019	 0.076658	 0.00114	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43723	 90179	 0.064406	 0.16557	 0.00256	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43724	 43725	 0.040559	 0.04461	 0.0006	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43724	 43726	 0.036112	 0.028579	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43725	 43727	 0.015736	 0.021451	 0.00048	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43728	 43877	 0.013309	 0.084322	 0.0229	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43728	 90168	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43728	 90168	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88829	 43729	 0.007126	 0.018318	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90167	 43729	 0.067054	 0.14094	 0.00257	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88829	 43730	 0.00519	 0.010171	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43731	 43732	 0.049745	 0.097495	 0.00146	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43731	 43734	 0.16211	 0.12831	 0.00162	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43732	 43733	 0.060159	 0.04761	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43732	 43735	 0.1761	 0.11831	 0.00209	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90168	 43732	 0.02058	 0.10348	 0.00281	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43736	 43740	 0.008328	 0.020934	 0.00542	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43736	 43742	 0.010115	 0.028208	 0.00592	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43736	 90169	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43736	 90169	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88803	 43737	 0.024638	 0.10979	 0.00186	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43737	 90170	 0.035635	 0.13864	 0.00231	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43738	 43743	 0.071475	 0.14152	 0.00208	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88803	 43738	 0.10449	 0.26865	 0.00416	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43739	 43745	 0.006027	 0.021088	 0.00699	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43739	 44021	 0.012166	 0.047822	 0.01251	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43740	 43744	 0.002197	 0.005704	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43741	 90170	 0.042776	 0.056221	 0.00077	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43741	 90171	 0.026014	 0.019139	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43742	 90170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43742	 90170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90170	 43743	 0.071985	 0.056968	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43743	 90171	 0.068778	 0.05443	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43744	 43745	 0.001595	 0.00558	 0.00185	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43744	 90171	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43744	 90171	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43746	 43747	 0.016439	 0.059532	 0.01278	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43746	 43763	 0.016215	 0.057321	 0.01292	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88819	 43747	 0.014421	 0.057745	 0.01455	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43747	 90172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43747	 90172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43747	 92504	 0.01204	 0.049716	 0.01176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43748	 43750	 0.023221	 0.054986	 0.00101	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43748	 90232	 0.028049	 0.09821	 0.00272	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43749	 43750	 0.029916	 0.019367	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43750	 51760	 0.18694	 0.18753	 0.00303	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90172	 43750	 0.046682	 0.084232	 0.00122	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88791	 43751	 0.014884	 0.041509	 0.00871	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43751	 90173	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43751	 90173	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43752	 43753	 0.031015	 0.11932	 0.00204	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43752	 44913	 0.34831	 0.38333	 0.00512	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90073	 43752	 0.090743	 0.34923	 0.00596	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43752	 90274	 0.065795	 0.21952	 0.00348	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90111	 43753	 0.31138	 0.22065	 0.00349	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90173	 43753	 0.2058	 0.16289	 0.00205	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43754	 90174	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43754	 90174	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43754	 90176	 0.01412	 0.055503	 0.01452	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43755	 43756	 0.000211	 0.003048	 0.02796	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43756	 90175	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90176	 43756	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43757	 43918	 0.011249	 0.079017	 0.13488	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90175	 43757	 0.003073	 0.020738	 0.03819	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43757	 90177	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43757	 90177	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43758	 90178	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90179	 43758	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90179	 43759	 0.14729	 0.16202	 0.00216	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90163	 43760	 0.14148	 0.28018	 0.00411	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90179	 43760	 0.081574	 0.20748	 0.00328	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43761	 43763	 0.010945	 0.025408	 0.00774	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43762	 43764	 0.025924	 0.076234	 0.00156	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43762	 90180	 0.005937	 0.026456	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43763	 90180	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43763	 90180	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43764	 43781	 0.034684	 0.13494	 0.00225	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90035	 43764	 0.13516	 0.31061	 0.00472	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90180	 43764	 0.03763	 0.096733	 0.0015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43765	 43945	 0.012294	 0.041425	 0.0103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88830	 43765	 0.012439	 0.049806	 0.01255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43766	 90183	 0.010436	 0.037791	 0.00811	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43767	 90182	 0.071604	 0.16066	 0.00256	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43768	 90181	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43769	 90184	 0.035393	 0.027743	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43770	 43772	 0.047852	 0.037508	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43771	 90184	 0.02615	 0.060702	 0.00116	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43772	 43773	 0.019796	 0.015517	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43772	 90184	 0.012264	 0.034802	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43774	 90183	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90184	 43774	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43775	 43776	 0.018908	 0.049976	 0.0117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43776	 43777	 0.010594	 0.027999	 0.00655	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43777	 43779	 0.017496	 0.070061	 0.01766	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43777	 90248	 0.00657	 0.028598	 0.00815	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43778	 90253	 0.68892	 0.49893	 0.00756	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43779	 44933	 0.00864	 0.033958	 0.00888	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43779	 90185	 0.010307	 0.043626	 0.00982	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43780	 43990	 0.00105	 0.012909	 0.20694	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43780	 90185	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88831	 43781	 0.032413	 0.16494	 0.00374	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43781	 90187	 0.037048	 0.12226	 0.00198	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43782	 43784	 0.017596	 0.06917	 0.0181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88831	 43783	 0.003215	 0.025059	 0.00047	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43783	 91213	 0.027425	 0.21378	 0.004	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43784	 44025	 0.012272	 0.048237	 0.01262	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43784	 90187	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43784	 90187	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43785	 43786	 0.16181	 0.11698	 0.00177	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90187	 43785	 0.023807	 0.041559	 0.00064	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43787	 43789	 0.011536	 0.030972	 0.00702	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43788	 43790	 0.016779	 0.08839	 0.00159	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43788	 90188	 0.016405	 0.071874	 0.00155	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43788	 90191	 0.34686	 0.272	 0.00349	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43789	 90188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43789	 90188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43791	 43792	 0.000175	 0.001947	 0.01836	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43791	 43795	 0.000636	 0.006941	 0.06815	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43791	 43995	 0.000619	 0.010053	 0.09799	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43791	 90189	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43791	 90189	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43792	 44083	 0.001187	 0.013028	 0.1266	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43793	 43796	 0.01805	 0.050339	 0.01057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43793	 43993	 0.028062	 0.075354	 0.01708	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90189	 43794	 0.060865	 0.12051	 0.00177	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43794	 90250	 0.09129	 0.13985	 0.00196	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43795	 44104	 0.000868	 0.010019	 0.08784	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43795	 90190	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43795	 90190	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43796	 90269	 0.012606	 0.042477	 0.01056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43797	 90191	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43797	 90191	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43798	 43799	 0.089561	 0.16405	 0.00283	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90191	 43798	 0.12707	 0.11706	 0.00188	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88800	 43799	 0.8346	 0.54202	 0.01031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88817	 43799	 0.0267	 0.070767	 0.00179	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43800	 43801	 0.000917	 0.003606	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43800	 43870	 0.002495	 0.006593	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43800	 43874	 0.003622	 0.014499	 0.00365	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43800	 90192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43800	 90192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43801	 43824	 0.001142	 0.004572	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43802	 43804	 0.008976	 0.017771	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90192	 43802	 0.007946	 0.015018	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90192	 43803	 0.003568	 0.014157	 0.0004	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43803	 90194	 0.004045	 0.018022	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43804	 90194	 0.002699	 0.014493	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43804	 90199	 0.00641	 0.012692	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43805	 43869	 0.000205	 0.002369	 0.02077	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43805	 90193	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43806	 43807	 0.004548	 0.009558	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43806	 90215	 0.011096	 0.034075	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43807	 43821	 0.002618	 0.009352	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90194	 43807	 0.011018	 0.021815	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43807	 90195	 0.026375	 0.020873	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43808	 43809	 0.001032	 0.003479	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43808	 43810	 0.001477	 0.006251	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90193	 43808	 0.003809	 0.009889	 0.0024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43808	 90195	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43808	 90195	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43809	 43819	 0.001121	 0.003777	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43810	 43897	 0.003052	 0.010469	 0.00251	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43810	 90196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43810	 90196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43810	 90214	 0.003962	 0.010471	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43811	 43812	 0.004312	 0.01659	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43811	 43814	 0.007742	 0.011607	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43811	 90198	 0.017911	 0.023309	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90196	 43812	 0.002676	 0.009369	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43813	 43814	 0.011615	 0.022997	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43813	 43868	 0.00883	 0.017483	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43813	 90225	 0.004227	 0.023787	 0.00051	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43814	 43815	 0.008638	 0.01295	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43815	 43867	 0.018544	 0.014535	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43816	 43817	 0.018212	 0.014413	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43816	 43888	 0.019748	 0.013265	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43817	 90197	 0.011838	 0.015066	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43818	 43819	 0.001071	 0.003101	 0.00075	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43818	 43887	 0.007682	 0.020303	 0.00475	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43818	 90197	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43818	 90197	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43819	 43826	 0.001165	 0.003078	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43819	 90198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43819	 90198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43820	 43850	 0.012411	 0.009822	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43821	 90207	 0.008202	 0.01624	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43822	 43825	 0.002036	 0.005381	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43822	 43848	 0.001201	 0.00335	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43823	 43824	 0.0021	 0.005549	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43823	 43825	 0.000968	 0.002559	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43823	 90199	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43823	 90199	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43824	 43876	 0.001875	 0.007507	 0.00189	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43825	 43852	 0.002204	 0.005826	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43825	 43853	 0.002269	 0.00669	 0.00156	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43826	 43827	 0.000817	 0.002054	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43827	 43851	 0.001907	 0.005319	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43827	 90200	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43827	 90200	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43828	 43829	 0.012765	 0.010102	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90197	 43828	 0.00889	 0.012619	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43829	 43833	 0.007495	 0.01064	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90200	 43829	 0.008618	 0.017063	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90197	 43830	 0.023297	 0.024821	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43830	 90201	 0.013716	 0.00888	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43831	 43838	 0.005489	 0.014507	 0.0034	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43831	 43884	 0.002212	 0.005742	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43831	 90201	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43831	 90201	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90201	 43832	 0.018072	 0.0117	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43832	 90204	 0.023228	 0.018382	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43833	 90204	 0.024574	 0.019262	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43834	 43835	 0.000295	 0.001967	 0.00371	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43834	 90202	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43834	 90202	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43835	 90203	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43835	 90203	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43836	 43884	 0.004146	 0.010957	 0.00256	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43836	 90204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43836	 90204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43837	 43895	 0.016443	 0.021611	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90204	 43837	 0.007622	 0.01729	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43838	 43840	 0.001614	 0.00419	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43838	 90205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43838	 90205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43839	 90206	 0.026829	 0.019395	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43839	 90209	 0.016124	 0.019656	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43840	 43841	 0.000881	 0.002651	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43840	 90206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43840	 90206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90202	 43841	 0.001057	 0.003305	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43842	 43844	 0.003692	 0.010212	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90206	 43842	 0.003071	 0.01231	 0.00032	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43843	 43845	 0.012763	 0.011436	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43843	 43895	 0.014494	 0.024416	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90205	 43843	 0.004864	 0.016614	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43844	 43845	 0.029172	 0.023087	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43844	 43846	 0.021219	 0.037901	 0.00056	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43844	 43847	 0.013678	 0.014607	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43844	 90209	 0.032047	 0.062807	 0.00094	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43846	 43895	 0.011639	 0.019333	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43846	 44044	 0.03008	 0.0529	 0.00099	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43847	 44043	 0.025441	 0.019514	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43848	 90207	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43848	 90207	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43849	 43850	 0.01345	 0.010542	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90194	 43849	 0.009923	 0.033103	 0.00052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90198	 43849	 0.038961	 0.030833	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90207	 43849	 0.012581	 0.012708	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90200	 43850	 0.028273	 0.022375	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43851	 90208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43851	 90208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90193	 43852	 0.003201	 0.011156	 0.00259	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90202	 43852	 0.001444	 0.006111	 0.00138	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43852	 90209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43852	 90209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88823	 43853	 0.002033	 0.007991	 0.00209	 195.0	 195.0	 195.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90193	 43853	 0.005218	 0.016226	 0.00339	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43854	 44011	 0.021883	 0.1138	 0.00247	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43854	 90211	 0.016602	 0.093421	 0.00202	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43855	 43873	 0.10971	 0.086826	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43855	 90212	 0.041082	 0.10561	 0.00163	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43856	 43858	 0.004836	 0.01111	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43856	 43894	 0.08675	 0.1329	 0.00187	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43856	 90210	 0.009653	 0.028385	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43856	 90211	 0.064832	 0.059718	 0.00096	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43857	 90210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43857	 90210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43857	 90214	 0.003907	 0.0159	 0.00387	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43858	 43859	 0.00843	 0.019367	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43859	 43860	 0.013739	 0.031896	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90210	 43859	 0.008809	 0.025264	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43860	 90211	 0.009033	 0.016236	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43861	 43862	 0.001596	 0.004143	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43861	 90211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43861	 90211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43862	 90212	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43862	 90212	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43862	 90214	 0.004036	 0.01616	 0.00407	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43863	 43868	 0.0233	 0.015085	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43864	 43867	 0.019369	 0.012539	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43864	 43890	 0.023384	 0.019247	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43864	 90213	 0.008772	 0.029262	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43865	 43866	 0.001304	 0.004545	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43865	 43889	 0.003788	 0.010012	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43865	 43891	 0.00193	 0.00662	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43865	 43892	 0.005468	 0.016373	 0.00369	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43865	 90213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43865	 90213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43865	 90214	 0.011986	 0.033424	 0.00702	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43866	 43896	 0.001877	 0.007517	 0.00189	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43869	 90214	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90214	 43870	 0.003291	 0.01836	 0.00469	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43870	 90216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43870	 90216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43871	 43874	 0.008031	 0.023036	 0.00567	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43871	 90217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43871	 90217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43872	 43873	 0.014598	 0.022363	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90216	 43872	 0.018267	 0.060281	 0.00098	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43873	 90218	 0.011162	 0.028693	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43874	 90218	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43874	 90218	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88795	 43875	 0.001052	 0.007444	 0.00204	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88823	 43875	 0.001215	 0.008149	 0.00197	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43875	 90219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43875	 90219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88823	 43876	 0.00249	 0.009968	 0.00251	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88823	 43877	 0.001224	 0.010185	 0.00308	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43877	 90220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43877	 90220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43878	 90221	 0.006543	 0.012955	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43879	 90222	 0.029977	 0.023497	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43880	 90222	 0.027778	 0.021774	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43881	 43882	 0.022527	 0.017657	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43882	 43883	 0.054648	 0.043248	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43882	 90222	 0.01678	 0.03895	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90166	 43883	 0.17807	 0.31328	 0.00589	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90208	 43883	 0.075455	 0.10712	 0.00176	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43884	 43885	 0.00163	 0.004309	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43884	 43887	 0.003422	 0.009044	 0.00212	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43884	 90221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43884	 90221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43885	 43887	 0.0018	 0.004673	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43886	 90222	 0.029683	 0.023491	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43887	 90222	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43887	 90222	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43888	 43890	 0.017214	 0.017387	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43889	 90223	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43889	 90223	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90221	 43890	 0.040803	 0.032291	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43890	 90224	 0.008112	 0.02247	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43891	 90224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43891	 90224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43892	 43893	 0.005927	 0.016136	 0.00356	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43892	 43896	 0.004623	 0.012412	 0.00281	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43896	 43897	 0.003967	 0.009971	 0.00258	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90214	 43897	 0.005564	 0.014704	 0.00344	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43897	 90225	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43897	 90225	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43898	 51414	 0.010838	 0.02124	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43898	 51416	 0.009047	 0.023255	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43898	 90230	 0.031036	 0.072054	 0.00107	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43899	 43904	 0.03288	 0.11285	 0.02706	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43899	 43906	 0.010317	 0.043666	 0.00983	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43900	 43903	 0.17445	 0.13807	 0.00174	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88799	 43901	 0.08296	 0.065655	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43902	 43905	 0.015627	 0.063602	 0.0155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43902	 90231	 0.009618	 0.037804	 0.00989	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43903	 43925	 0.097603	 0.16279	 0.00237	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88799	 43903	 0.21177	 0.35331	 0.00514	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43903	 90232	 0.16884	 0.25869	 0.00363	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43904	 43905	 0.014047	 0.037126	 0.00869	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43906	 43919	 0.001715	 0.005057	 0.00118	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43906	 90226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43906	 90226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43906	 90227	 0.002866	 0.008912	 0.00186	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43907	 43915	 0.018232	 0.016337	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90226	 43907	 0.020982	 0.021192	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43908	 43911	 0.009081	 0.011818	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43908	 43913	 0.005506	 0.009834	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43909	 43910	 0.019024	 0.013996	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43910	 43912	 0.007091	 0.013184	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43910	 90230	 0.011681	 0.038548	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43910	 93096	 0.006876	 0.019722	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43911	 43912	 0.007464	 0.008935	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43912	 43914	 0.007035	 0.013928	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43913	 43914	 0.001255	 0.007626	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43913	 43915	 0.001361	 0.01132	 0.00021	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43914	 43916	 0.003892	 0.020737	 0.00036	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43915	 90228	 0.002607	 0.012935	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43916	 90230	 0.001713	 0.010525	 0.00024	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43916	 90232	 0.043866	 0.086852	 0.00127	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90226	 43917	 0.039393	 0.031175	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43917	 90228	 0.012703	 0.009346	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43918	 90227	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90228	 43918	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43918	 90229	 0.000254	 0.002573	 0.00518	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90227	 43919	 0.001527	 0.004284	 0.0011	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43920	 43924	 0.002209	 0.009347	 0.0021	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90227	 43920	 0.001011	 0.003843	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43921	 51410	 0.000376	 0.004337	 0.03802	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43921	 90229	 9.3e-05	 0.007407	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88820	 43922	 0.021015	 0.060275	 0.00093	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43922	 93098	 0.011741	 0.027254	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43923	 43925	 0.036025	 0.046883	 0.00066	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43923	 90232	 0.035928	 0.057348	 0.00132	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43924	 90231	 0.002435	 0.009748	 0.00246	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90228	 43925	 0.1158	 0.091647	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90226	 43926	 0.061233	 0.045052	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43927	 90231	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43928	 43932	 0.16469	 0.1759	 0.00372	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	43929	 43930	 0.14523	 0.10686	 0.00156	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43930	 43931	 0.027557	 0.036218	 0.0005	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90130	 43931	 0.037378	 0.14959	 0.00316	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90167	 43931	 0.18354	 0.36354	 0.00534	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90127	 43932	 0.23149	 0.2316	 0.00313	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43933	 43934	 0.2553	 0.20016	 0.00257	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43934	 49125	 0.08169	 0.31789	 0.00531	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43934	 90259	 0.1129	 0.29938	 0.0076	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43935	 43936	 0.016518	 0.05566	 0.01383	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43936	 43938	 0.017982	 0.060597	 0.01506	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88800	 43937	 0.25017	 0.1841	 0.00269	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43937	 90233	 0.066525	 0.12004	 0.00174	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43938	 90233	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43938	 90233	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43939	 43940	 0.001328	 0.00896	 0.0165	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88841	 43939	 0.001526	 0.010353	 0.01885	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43939	 90234	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43939	 90234	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43940	 90235	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90236	 43940	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43941	 43942	 0.063247	 0.069565	 0.00093	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89836	 43941	 0.045254	 0.13308	 0.00273	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90234	 43942	 0.028648	 0.12766	 0.00217	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43943	 43967	 0.015969	 0.040146	 0.0104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43944	 90237	 0.024608	 0.03928	 0.0009	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43945	 43966	 0.00361	 0.012581	 0.00292	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43945	 90237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43945	 90237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43946	 43949	 0.001999	 0.005282	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43946	 43967	 0.009069	 0.022798	 0.00591	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89835	 43946	 0.001112	 0.005892	 0.00149	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43946	 90238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43946	 90238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89836	 43947	 0.017812	 0.035267	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90238	 43947	 0.016556	 0.011121	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43947	 90239	 0.047249	 0.037392	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43948	 43949	 0.000921	 0.002368	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43948	 43951	 0.001386	 0.003774	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43949	 43950	 0.002149	 0.005681	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43950	 43962	 0.001013	 0.002757	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89835	 43950	 0.004766	 0.01482	 0.00309	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43950	 90239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43950	 90239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43951	 43961	 0.001105	 0.002919	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43951	 90240	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43951	 90240	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43952	 43953	 0.015063	 0.009752	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90240	 43952	 0.014145	 0.011194	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43952	 90241	 0.029893	 0.021993	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90238	 43953	 0.025223	 0.018557	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90238	 43954	 0.011194	 0.008858	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43955	 43975	 0.027127	 0.01961	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43955	 43976	 0.019109	 0.014979	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90238	 43955	 0.021893	 0.017326	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43956	 43957	 0.006006	 0.008187	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90238	 43956	 0.007004	 0.016091	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43957	 43972	 0.024311	 0.017886	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43958	 43959	 0.014409	 0.011403	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43958	 43970	 0.029507	 0.021709	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90238	 43958	 0.017358	 0.031319	 0.00045	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43959	 43960	 0.020379	 0.014435	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43959	 90241	 0.03771	 0.029843	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43960	 43965	 0.055648	 0.040228	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43960	 90241	 0.022813	 0.022818	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43961	 43966	 0.002385	 0.006302	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43961	 90241	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43961	 90241	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43962	 43966	 0.002642	 0.006368	 0.0018	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43962	 90242	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43962	 90242	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90239	 43963	 0.020072	 0.015733	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90242	 43963	 0.01496	 0.010815	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90184	 43964	 0.19731	 0.39085	 0.00574	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90237	 43964	 0.026251	 0.043604	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90239	 43964	 0.052804	 0.034186	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90241	 43964	 0.073377	 0.058071	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43965	 43968	 0.0327	 0.025878	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90237	 43965	 0.032399	 0.059341	 0.00102	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43967	 90243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43967	 90243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90243	 43968	 0.030983	 0.02452	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43969	 43970	 0.016936	 0.012991	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43971	 43972	 0.028517	 0.023472	 0.00048	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89836	 43971	 0.046498	 0.091129	 0.00137	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90243	 43971	 0.07042	 0.05573	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43972	 43974	 0.019322	 0.026338	 0.00058	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43973	 43974	 0.03164	 0.025039	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43974	 43975	 0.031488	 0.024681	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43974	 43983	 0.011975	 0.021389	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89836	 43974	 0.043661	 0.06622	 0.00095	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	43975	 43980	 0.03247	 0.025451	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43976	 90244	 0.010969	 0.012064	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43977	 43978	 0.001335	 0.003584	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89835	 43977	 0.002481	 0.006959	 0.00179	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43977	 90244	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43977	 90244	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43978	 90245	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43978	 90245	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43979	 43982	 0.003088	 0.008162	 0.00191	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43979	 90246	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43979	 90246	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43980	 43981	 0.016398	 0.012977	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90245	 43980	 0.024041	 0.015564	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43981	 43983	 0.013803	 0.009978	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43981	 43984	 0.021512	 0.017024	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89835	 43982	 0.008238	 0.021388	 0.00519	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90235	 43982	 0.002374	 0.01425	 0.00432	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	43982	 90247	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43982	 90247	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43983	 43985	 0.008702	 0.028715	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90247	 43984	 0.039896	 0.031573	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90234	 43985	 0.062994	 0.12346	 0.00185	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90236	 43985	 0.03278	 0.064902	 0.00095	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43986	 43989	 0.042888	 0.072249	 0.00103	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	43987	 43988	 0.11454	 0.074155	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43988	 43989	 0.056839	 0.10256	 0.00148	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88799	 43988	 0.076351	 0.25475	 0.00404	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43990	 43995	 0.000546	 0.006792	 0.06824	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43990	 43996	 0.000668	 0.00757	 0.06892	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43990	 90248	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43990	 90248	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90248	 43991	 0.013454	 0.031232	 0.00952	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43991	 90252	 0.004602	 0.013852	 0.00433	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43992	 90249	 0.12693	 0.13962	 0.00186	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43992	 90250	 0.35522	 0.23874	 0.00421	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43992	 90253	 0.074827	 0.067052	 0.00137	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43992	 93704	 0.82447	 0.65399	 0.00823	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43993	 90249	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43993	 90249	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43993	 90252	 0.019556	 0.052508	 0.0119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43994	 90250	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43994	 90250	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43994	 90251	 0.005844	 0.015689	 0.00356	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43995	 90251	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43995	 90251	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43996	 44083	 0.00239	 0.027616	 0.24249	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	43996	 90252	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43997	 44016	 0.009155	 0.031406	 0.00752	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	43997	 90254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43997	 90254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	43998	 43999	 0.02436	 0.019278	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43998	 44000	 0.017105	 0.017277	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	43998	 44005	 0.006284	 0.014586	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90254	 43998	 0.015621	 0.043268	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43999	 44000	 0.01828	 0.011834	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	43999	 44074	 0.65709	 0.52078	 0.00656	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44000	 44001	 0.00441	 0.009063	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88821	 44001	 0.003913	 0.008224	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44001	 90255	 0.005117	 0.009372	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44002	 44003	 0.021829	 0.017275	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44002	 44009	 0.025525	 0.017146	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90054	 44002	 0.21183	 0.28889	 0.00641	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44003	 44008	 0.010676	 0.021138	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44003	 90255	 0.019241	 0.018044	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44004	 90255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44004	 90255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88826	 44005	 0.001302	 0.005063	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90214	 44006	 0.016298	 0.090465	 0.02751	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44006	 90256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44006	 90256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44007	 44008	 0.004422	 0.007058	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88821	 44007	 0.003264	 0.014606	 0.0003	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90256	 44007	 0.00249	 0.020145	 0.00052	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90255	 44009	 0.043184	 0.033125	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44010	 44011	 0.038819	 0.090125	 0.00134	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90256	 44010	 0.016873	 0.039167	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44011	 90257	 0.069263	 0.15541	 0.00248	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44012	 90257	 0.057181	 0.11207	 0.00168	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44013	 90257	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44013	 90257	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88803	 44014	 0.11852	 0.16519	 0.00283	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90254	 44014	 0.15358	 0.12155	 0.00153	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90256	 44014	 0.087209	 0.13359	 0.00232	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90257	 44014	 0.0641	 0.049169	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90039	 44017	 0.20564	 0.20628	 0.00334	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44017	 90258	 0.20921	 0.25051	 0.00417	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44018	 44019	 0.073238	 0.17004	 0.00253	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90052	 44018	 0.086973	 0.19984	 0.00304	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44019	 44020	 0.085562	 0.14414	 0.00205	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90169	 44019	 0.066324	 0.18373	 0.00303	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44020	 90258	 0.064982	 0.04207	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44021	 44022	 0.004969	 0.019331	 0.00516	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44021	 90258	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44021	 90258	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44023	 44024	 0.018217	 0.049602	 0.01093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44023	 44025	 0.018972	 0.055942	 0.01302	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44023	 44027	 0.01982	 0.080675	 0.01966	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44023	 90259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44023	 90259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44024	 44025	 0.020672	 0.056289	 0.0124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44026	 44028	 0.22974	 0.18011	 0.00231	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44027	 44029	 0.002749	 0.008104	 0.00189	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44027	 90260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44027	 90260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90260	 44028	 0.011345	 0.074974	 0.00148	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44030	 90261	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44030	 90261	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90261	 44031	 0.23837	 0.15436	 0.00294	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44032	 44034	 0.057183	 0.047067	 0.00095	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90131	 44032	 0.16299	 0.3427	 0.00625	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44033	 44037	 0.038752	 0.025088	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44034	 90262	 0.051778	 0.061984	 0.00103	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44035	 44041	 0.065866	 0.051629	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44035	 90262	 0.026664	 0.02667	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44036	 44042	 0.011221	 0.029657	 0.00694	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44036	 44057	 0.052164	 0.176	 0.04382	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90178	 44036	 0.010803	 0.07773	 0.0206	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44036	 90262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44036	 90262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44037	 44038	 0.079535	 0.087481	 0.00117	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44037	 44039	 0.053381	 0.035858	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44037	 44040	 0.016387	 0.027605	 0.00039	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90262	 44037	 0.024157	 0.045656	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44040	 44041	 0.045026	 0.035633	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90262	 44040	 0.012749	 0.024985	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90262	 44041	 0.013011	 0.023476	 0.00034	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90178	 44042	 0.026992	 0.1115	 0.0264	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44044	 44045	 0.072986	 0.057761	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44046	 44047	 0.16702	 0.13093	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90219	 44046	 0.027511	 0.048381	 0.00091	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44048	 90263	 0.017704	 0.013877	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90203	 44049	 0.020558	 0.054337	 0.01272	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44049	 90263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44049	 90263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90263	 44050	 0.030384	 0.024045	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88818	 44051	 0.025321	 0.019848	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88818	 44052	 0.021317	 0.015684	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90263	 44052	 0.035329	 0.022872	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90163	 44053	 0.20241	 0.3377	 0.00491	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90263	 44053	 0.051825	 0.11853	 0.00289	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88818	 44054	 0.1628	 0.1633	 0.00264	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44055	 90264	 0.077889	 0.18084	 0.00269	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44056	 44058	 0.20661	 0.15204	 0.00222	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44056	 90264	 0.1988	 0.15735	 0.00198	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44057	 90264	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44057	 90264	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90264	 44058	 0.048532	 0.038042	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90132	 44059	 0.61097	 0.48413	 0.0061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90184	 44059	 0.30372	 0.51207	 0.0073	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90261	 44059	 0.48462	 0.63787	 0.00875	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90264	 44059	 0.10425	 0.082506	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90178	 44060	 0.050864	 0.12796	 0.03318	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44060	 90265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44060	 90265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44061	 44062	 0.30156	 0.23872	 0.00301	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90163	 44061	 0.12811	 0.30346	 0.00555	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90265	 44061	 0.074832	 0.19784	 0.00359	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44063	 44064	 0.009492	 0.041584	 0.00089	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44063	 44071	 0.024206	 0.062225	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44064	 90266	 0.004376	 0.029689	 0.00055	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44065	 44072	 0.004193	 0.021336	 0.00774	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44065	 44073	 0.016873	 0.057889	 0.01387	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44065	 90266	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44065	 90266	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44066	 44069	 0.014322	 0.011226	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44067	 44068	 0.005922	 0.03641	 0.00066	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44067	 44071	 0.040054	 0.074477	 0.00174	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44067	 44074	 0.088333	 0.1982	 0.00316	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44068	 44069	 0.004863	 0.012888	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44068	 44070	 0.019067	 0.044266	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90266	 44068	 0.016827	 0.056134	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90266	 44069	 0.012001	 0.040033	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44070	 90267	 0.058099	 0.16094	 0.00266	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44071	 44115	 0.16415	 0.20015	 0.00321	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88828	 44071	 0.18742	 0.37123	 0.00545	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44073	 90267	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44073	 90267	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90054	 44074	 0.098057	 0.19001	 0.00409	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90267	 44074	 0.075916	 0.18584	 0.00318	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44075	 44109	 0.017855	 0.047191	 0.01105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44075	 44462	 0.022022	 0.07556	 0.01811	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44075	 90268	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44075	 90268	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44075	 90371	 0.018822	 0.08911	 0.02144	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90268	 44077	 0.144	 0.14545	 0.00193	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44078	 44079	 0.050652	 0.13021	 0.00202	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44078	 44082	 0.38205	 0.29962	 0.00385	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88825	 44078	 0.861	 0.6242	 0.00946	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44079	 44080	 0.080894	 0.061289	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88825	 44079	 0.71142	 0.46163	 0.00878	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90036	 44079	 0.39529	 0.30338	 0.00407	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44080	 44081	 0.056815	 0.11249	 0.00165	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44080	 44082	 0.072727	 0.18697	 0.00289	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88825	 44080	 0.75729	 0.60049	 0.00756	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90036	 44081	 0.25036	 0.19817	 0.0025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90075	 44082	 0.11354	 0.29436	 0.00557	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44083	 44107	 0.000251	 0.003414	 0.06927	 1646.0	 1728.3	 1810.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44083	 90269	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 2.0	 1	 -30.0	 30.0;
	44084	 44085	 0.009536	 0.022582	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90270	 44084	 0.011253	 0.03387	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44085	 44086	 0.030659	 0.023228	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44085	 44092	 0.010404	 0.02129	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44087	 44090	 0.05473	 0.039564	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44088	 44089	 0.032443	 0.021004	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44088	 51397	 0.47379	 0.37524	 0.00472	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44089	 44096	 0.016586	 0.025407	 0.00036	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44090	 44091	 0.021002	 0.016621	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44090	 44096	 0.00586	 0.011485	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44092	 44093	 0.004344	 0.00931	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44093	 44094	 0.018114	 0.011727	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44093	 44097	 0.037459	 0.025162	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44094	 44095	 0.011397	 0.008934	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44095	 44097	 0.016953	 0.013416	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44096	 44097	 0.006598	 0.011603	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44096	 90271	 0.010431	 0.057443	 0.0013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44098	 44102	 0.002129	 0.011462	 0.00315	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44098	 51384	 0.002139	 0.01178	 0.00425	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44098	 51384	 0.002139	 0.01178	 0.00425	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90269	 44098	 0.001875	 0.009421	 0.00245	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90269	 44098	 0.001875	 0.009421	 0.00245	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44098	 90271	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44098	 90271	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44099	 44101	 0.026019	 0.020591	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90271	 44100	 0.003341	 0.016301	 0.00028	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44100	 90272	 0.005316	 0.029914	 0.00065	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44101	 90272	 0.023966	 0.02636	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44102	 90272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44102	 90272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44102	 90273	 0.001165	 0.010168	 0.00279	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90174	 44103	 0.28845	 0.28942	 0.00468	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44104	 44106	 0.000659	 0.007834	 0.07193	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44104	 44107	 0.000911	 0.01051	 0.09216	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90271	 44105	 0.027069	 0.053595	 0.00079	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44107	 90273	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44107	 90273	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44108	 44479	 0.004871	 0.03344	 0.00975	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44108	 90274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44108	 90274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44110	 90275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44110	 90275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44111	 44113	 0.014361	 0.040048	 0.00841	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44112	 44115	 0.019385	 0.030941	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88828	 44114	 0.021514	 0.093999	 0.00247	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88828	 44115	 0.062	 0.23262	 0.00418	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44116	 44118	 0.061224	 0.15739	 0.00244	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44116	 44120	 0.14603	 0.29897	 0.00736	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44116	 90276	 0.06589	 0.25638	 0.00428	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44117	 44343	 0.051192	 0.17271	 0.043	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44117	 44816	 0.020982	 0.085408	 0.02082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44117	 90276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44117	 90276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44118	 44121	 0.13777	 0.15155	 0.00202	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44118	 44338	 0.22466	 0.17236	 0.00231	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44119	 44120	 0.10592	 0.20761	 0.00311	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44119	 44899	 0.42793	 0.33887	 0.00427	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44119	 44996	 0.077671	 0.14443	 0.00338	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44120	 44121	 0.37846	 0.29966	 0.00377	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44120	 44899	 0.24375	 0.17938	 0.00262	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44122	 44129	 0.006412	 0.016483	 0.00408	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44122	 90277	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44122	 90277	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44123	 44124	 0.027578	 0.073096	 0.00185	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44123	 44128	 0.054109	 0.071116	 0.00097	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44123	 44808	 0.043859	 0.10077	 0.00153	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90277	 44123	 0.020553	 0.082251	 0.00174	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44124	 44126	 0.025557	 0.062558	 0.00107	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44125	 44128	 0.010348	 0.049453	 0.00108	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44125	 44151	 0.010485	 0.04672	 0.00079	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44126	 44150	 0.079566	 0.062968	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44126	 44204	 0.033714	 0.079835	 0.00146	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44127	 44128	 0.019307	 0.044817	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90277	 44127	 0.034557	 0.088835	 0.00137	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44128	 90278	 0.024516	 0.095746	 0.00212	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44129	 44145	 0.00883	 0.029753	 0.00739	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44129	 45288	 0.004823	 0.016877	 0.00559	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44129	 90278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44129	 90278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44130	 44137	 0.007765	 0.02774	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44130	 44138	 0.020957	 0.041071	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44130	 44139	 0.032657	 0.025598	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44130	 44169	 0.007546	 0.012603	 0.00021	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44130	 90284	 0.023246	 0.047772	 0.00091	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44131	 44150	 0.031998	 0.081377	 0.00129	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44131	 90620	 0.093948	 0.06655	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44132	 44133	 0.052881	 0.04771	 0.0008	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44132	 44186	 0.040672	 0.059266	 0.00134	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44133	 44150	 0.036421	 0.047398	 0.00066	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44134	 44135	 0.020892	 0.053706	 0.00083	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44134	 44138	 0.017238	 0.038673	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44135	 44142	 0.013017	 0.033462	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44136	 44137	 0.006094	 0.027153	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44136	 90279	 0.008144	 0.039294	 0.00069	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44140	 44141	 0.005678	 0.027706	 0.00048	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88979	 44140	 0.010628	 0.059717	 0.00111	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44141	 90280	 0.00943	 0.046018	 0.00079	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44142	 90280	 0.019382	 0.055592	 0.00085	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44143	 90279	 0.026082	 0.020641	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44144	 44145	 0.001031	 0.007417	 0.00197	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44144	 44686	 0.002223	 0.012195	 0.00322	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44144	 90279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44144	 90279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44145	 90280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44145	 90280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44146	 44149	 0.053931	 0.042681	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44146	 44153	 0.019914	 0.039427	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44146	 44182	 0.009752	 0.017528	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44147	 44148	 0.018491	 0.014633	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44147	 45368	 0.073908	 0.072317	 0.00102	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44148	 44153	 0.053635	 0.039461	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44150	 44151	 0.018227	 0.043163	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44151	 90284	 0.10642	 0.13373	 0.00201	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44152	 44153	 0.011397	 0.029297	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44152	 44188	 0.017756	 0.050927	 0.00078	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44152	 45109	 0.016987	 0.039437	 0.00059	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44154	 44155	 0.02017	 0.01581	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44154	 44158	 0.010692	 0.017067	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44154	 90281	 0.017459	 0.030703	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44154	 90426	 0.028097	 0.14214	 0.00247	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44155	 90425	 0.01032	 0.017385	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44156	 90281	 0.004781	 0.009466	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44156	 90425	 0.004721	 0.019293	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44157	 44165	 0.00087	 0.004511	 0.0011	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44157	 44686	 0.001414	 0.007794	 0.00182	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44157	 90281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44157	 90281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44159	 44163	 0.016484	 0.026873	 0.00041	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44159	 90283	 0.011594	 0.018506	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44160	 44165	 0.001679	 0.00653	 0.00174	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44160	 44167	 0.003153	 0.010625	 0.00264	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44160	 44683	 0.003122	 0.008252	 0.00193	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44160	 90282	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44160	 90282	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44161	 90285	 0.029564	 0.023396	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44162	 44163	 0.018818	 0.014257	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90282	 44162	 0.015135	 0.015179	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44163	 90284	 0.015926	 0.01593	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44164	 90283	 0.01012	 0.020037	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44165	 90283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44165	 90283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44166	 44176	 0.031608	 0.023255	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44166	 90284	 0.016094	 0.012615	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44167	 44171	 0.00327	 0.009117	 0.00191	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44167	 90284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44167	 90284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44168	 44177	 0.021464	 0.016986	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90284	 44168	 0.027669	 0.027947	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44168	 90285	 0.007004	 0.013867	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44169	 44173	 0.02261	 0.016634	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44170	 90285	 0.015743	 0.014649	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44171	 90285	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44171	 90285	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44171	 90288	 0.001691	 0.009381	 0.00285	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44172	 44175	 0.010788	 0.025041	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90284	 44172	 0.010626	 0.030152	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44174	 44186	 0.027751	 0.042512	 0.0006	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44175	 44186	 0.010625	 0.024662	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44176	 44178	 0.02749	 0.021755	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44177	 44178	 0.017432	 0.013795	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44178	 44179	 0.021792	 0.017082	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90285	 44178	 0.043397	 0.031928	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44179	 44180	 0.007174	 0.013558	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44180	 44190	 0.007082	 0.01801	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44181	 90286	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44181	 90286	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44181	 90288	 0.001608	 0.015433	 0.00449	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44182	 44184	 0.035344	 0.025036	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90286	 44182	 0.014853	 0.057141	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44183	 44185	 0.038811	 0.030422	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44185	 44186	 0.011847	 0.019957	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90286	 44186	 0.012155	 0.040548	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44187	 44188	 0.011163	 0.017418	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90286	 44187	 0.013974	 0.027668	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90286	 44188	 0.019332	 0.035945	 0.00084	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44189	 44193	 0.008587	 0.022074	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44189	 45122	 0.022154	 0.016015	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44190	 90289	 0.005289	 0.014019	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44190	 90290	 0.031182	 0.024677	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44191	 44623	 0.00106	 0.01201	 0.10937	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44191	 44654	 0.00068	 0.007569	 0.07138	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44191	 45129	 0.000304	 0.00344	 0.03131	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44191	 90287	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44192	 44679	 0.002801	 0.007519	 0.0017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44192	 45134	 0.010496	 0.034234	 0.00909	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90288	 44192	 0.001272	 0.005093	 0.00128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44192	 90290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44192	 90290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44193	 45123	 0.006464	 0.015006	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44193	 45125	 0.017359	 0.024642	 0.00041	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90289	 44193	 0.006221	 0.024682	 0.0007	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44194	 44195	 0.009125	 0.015372	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90290	 44194	 0.006501	 0.022747	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44194	 90388	 0.033068	 0.02617	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44195	 44196	 0.007945	 0.012681	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44195	 44199	 0.009055	 0.02597	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90290	 44195	 0.006524	 0.021762	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44196	 44198	 0.010854	 0.02149	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44196	 45125	 0.012869	 0.011854	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44197	 44537	 0.001396	 0.004552	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44197	 90291	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44197	 90291	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44198	 44199	 0.026346	 0.02085	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44198	 44200	 0.017171	 0.012413	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44198	 44203	 0.00565	 0.014935	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44199	 44200	 0.009307	 0.007365	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90291	 44199	 0.004945	 0.009791	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44201	 44202	 0.004998	 0.012849	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44201	 44709	 0.019725	 0.021695	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44202	 44203	 0.003492	 0.00888	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44203	 45124	 0.002227	 0.011263	 0.0002	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44204	 90318	 0.052529	 0.10401	 0.00153	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44205	 44800	 0.16337	 0.1293	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44206	 44207	 0.057841	 0.14159	 0.00242	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44206	 44973	 0.074051	 0.18834	 0.00298	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44207	 44209	 0.033899	 0.086211	 0.00136	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44208	 44209	 0.011964	 0.06801	 0.00123	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44208	 44212	 0.039629	 0.093844	 0.00172	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44208	 44214	 0.071644	 0.21071	 0.00432	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44209	 44210	 0.024379	 0.047778	 0.00072	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44209	 90510	 0.14565	 0.37456	 0.0058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44209	 90512	 0.096964	 0.39651	 0.00803	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44210	 44211	 0.0191	 0.054782	 0.00084	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44211	 44974	 0.034813	 0.13394	 0.00229	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44211	 44976	 0.20243	 0.20251	 0.00274	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44212	 44213	 0.052854	 0.13119	 0.00218	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44213	 44322	 0.077159	 0.19625	 0.0031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44214	 44877	 0.11932	 0.37904	 0.00665	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44214	 44878	 0.40691	 0.29956	 0.00438	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44215	 44222	 0.004708	 0.017894	 0.00501	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44216	 44217	 0.065072	 0.10472	 0.00164	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44216	 44218	 0.2978	 0.21917	 0.00321	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44216	 90292	 0.021902	 0.080984	 0.0015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44217	 44218	 0.20646	 0.13871	 0.00245	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44217	 44224	 0.31428	 0.24643	 0.00316	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44218	 44223	 0.39681	 0.3142	 0.00396	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44219	 44223	 0.082447	 0.064627	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44220	 90292	 0.013653	 0.022257	 0.00034	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44221	 90292	 0.038001	 0.07524	 0.0011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44222	 44847	 0.075874	 0.20088	 0.04712	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88966	 44222	 0.096756	 0.24395	 0.06342	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44222	 90292	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44222	 90292	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44223	 90474	 0.49797	 0.39066	 0.00502	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44224	 44821	 0.5486	 0.40408	 0.00591	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44225	 44230	 0.061121	 0.15842	 0.003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44225	 44896	 0.089688	 0.16184	 0.00234	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44226	 44228	 0.17571	 0.13906	 0.00175	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44227	 44228	 0.15552	 0.1007	 0.00192	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44227	 44906	 0.14798	 0.20176	 0.00448	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44227	 45309	 0.1981	 0.15679	 0.00197	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44227	 90488	 0.12481	 0.22865	 0.00395	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44228	 44231	 0.03925	 0.1009	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44229	 44231	 0.0321	 0.027434	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44230	 90294	 0.014985	 0.085182	 0.00154	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44231	 45305	 0.013958	 0.032406	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44231	 90294	 0.007104	 0.04365	 0.001	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44232	 45305	 0.00802	 0.026754	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88968	 44232	 0.00321	 0.014145	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44233	 90293	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44234	 44236	 0.21086	 0.15516	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44235	 44236	 0.25813	 0.23139	 0.00473	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44235	 45349	 0.10627	 0.21044	 0.00309	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44236	 44848	 0.50694	 0.40153	 0.00506	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44237	 90296	 0.048207	 0.094479	 0.00142	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44238	 44239	 0.00037	 0.003642	 0.00776	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44238	 44488	 0.007033	 0.068267	 0.24242	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44238	 90295	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90296	 44238	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88939	 44239	 0.000131	 0.001392	 0.00283	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44239	 90297	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90298	 44239	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44240	 44241	 0.001332	 0.004708	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44240	 44243	 0.002147	 0.007587	 0.00171	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44240	 90299	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44240	 90299	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90295	 44241	 0.001788	 0.007275	 0.00177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44241	 90302	 0.006447	 0.025812	 0.0065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90299	 44242	 0.010819	 0.018225	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44242	 90300	 0.006591	 0.011592	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44242	 90301	 0.029138	 0.023059	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44243	 44247	 0.001434	 0.003791	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44243	 44930	 0.001142	 0.003569	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90297	 44243	 0.002277	 0.008049	 0.00181	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44243	 90300	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44243	 90300	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44244	 44928	 0.060196	 0.047638	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44244	 90304	 0.014266	 0.028246	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44245	 44246	 0.13276	 0.097684	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88941	 44245	 0.11342	 0.2246	 0.0033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44245	 90305	 0.080377	 0.22812	 0.00358	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44246	 44251	 0.078878	 0.1546	 0.00232	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44247	 44252	 0.001166	 0.004062	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44247	 90301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44247	 90301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90301	 44248	 0.026345	 0.018661	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44248	 90304	 0.01846	 0.013582	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44249	 44250	 0.000589	 0.006671	 0.06073	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44249	 90302	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44249	 90302	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44250	 90303	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44250	 90303	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44251	 90365	 0.043721	 0.18779	 0.00344	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90302	 44252	 0.005614	 0.022845	 0.00557	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44252	 90304	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44252	 90304	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88984	 44253	 0.001289	 0.002992	 4e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44253	 90305	 0.013298	 0.024725	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44254	 44255	 0.002109	 0.005572	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44254	 90305	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44254	 90305	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44255	 44256	 0.002364	 0.006592	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44255	 44260	 0.01369	 0.046965	 0.01125	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44257	 44258	 0.005836	 0.015003	 0.00372	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44257	 45293	 0.017002	 0.082534	 0.01887	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44258	 44260	 0.013316	 0.033474	 0.00867	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44259	 44332	 0.02579	 0.086062	 0.02184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44259	 45161	 0.015261	 0.062111	 0.01514	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44259	 90306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44259	 90306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44260	 45414	 0.006877	 0.035651	 0.0087	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44261	 45230	 0.010216	 0.043241	 0.00973	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44261	 90307	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44261	 90307	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44262	 44267	 0.012765	 0.030763	 0.00869	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44263	 45224	 0.023188	 0.068187	 0.0014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88967	 44263	 0.098522	 0.072488	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88983	 44263	 0.011668	 0.045568	 0.00101	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44264	 44998	 0.041719	 0.14324	 0.03435	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44264	 90308	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44264	 90308	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44265	 44267	 0.016823	 0.057717	 0.01383	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44265	 90309	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44265	 90309	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90309	 44266	 0.22081	 0.1694	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44267	 90310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44267	 90310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88971	 44268	 0.013358	 0.034337	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44268	 90646	 0.098484	 0.28969	 0.00594	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44269	 44285	 0.006987	 0.036398	 0.00955	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44270	 44271	 0.071525	 0.056604	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88971	 44270	 0.020758	 0.059536	 0.00092	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44271	 90312	 0.094893	 0.1879	 0.00276	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44271	 90314	 0.027873	 0.092985	 0.00147	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44272	 44281	 0.11194	 0.072475	 0.00138	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44273	 44281	 0.016975	 0.04817	 0.00076	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44273	 90428	 0.028852	 0.074167	 0.00115	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44274	 44275	 0.02679	 0.017344	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44274	 44702	 0.035863	 0.025925	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44275	 44276	 0.023603	 0.018679	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44275	 90311	 0.040539	 0.026245	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44277	 44278	 0.024846	 0.019663	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44277	 44701	 0.038275	 0.058634	 0.00082	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44277	 90311	 0.030995	 0.03376	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44277	 90408	 0.04862	 0.038478	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44279	 44282	 0.001441	 0.008441	 0.0023	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44279	 44625	 0.005232	 0.013828	 0.00324	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44279	 90311	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44279	 90311	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44280	 44632	 0.026835	 0.045205	 0.00064	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88986	 44280	 0.015788	 0.030942	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44281	 90312	 0.02959	 0.026696	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44282	 44283	 0.003106	 0.010824	 0.00251	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44282	 90312	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44282	 90312	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44282	 90591	 0.011708	 0.031434	 0.00712	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44283	 44284	 0.003107	 0.023805	 0.00638	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44284	 44286	 0.002777	 0.025262	 0.00638	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44285	 45292	 0.005161	 0.03207	 0.00905	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44285	 90313	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44285	 90313	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44286	 45280	 0.004182	 0.040858	 0.01147	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44286	 90314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44286	 90314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44287	 44294	 0.050547	 0.13369	 0.03132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88966	 44287	 0.034284	 0.18843	 0.04992	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44287	 90315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44287	 90315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90315	 44288	 0.4898	 0.31744	 0.00604	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44289	 44290	 0.085939	 0.20353	 0.00372	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44289	 90459	 0.090611	 0.23296	 0.00361	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44290	 44291	 0.069176	 0.17171	 0.00285	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44291	 44292	 0.035083	 0.08145	 0.00121	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44292	 44293	 0.20788	 0.16297	 0.00209	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44292	 44348	 0.077133	 0.17643	 0.00431	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90315	 44292	 0.17267	 0.342	 0.00502	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44294	 44340	 0.034154	 0.091725	 0.0208	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44294	 44908	 0.076472	 0.19694	 0.04887	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44294	 90316	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44294	 90316	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44295	 44345	 0.13183	 0.10433	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44296	 45340	 0.30643	 0.24258	 0.00305	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90316	 44296	 0.15512	 0.23262	 0.00423	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44296	 90325	 0.3069	 0.24295	 0.00306	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44297	 44298	 0.072005	 0.14737	 0.00363	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44297	 45446	 0.052734	 0.13556	 0.0021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44297	 90317	 0.059569	 0.13829	 0.00263	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44298	 44830	 0.087766	 0.28269	 0.00482	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44299	 90317	 0.23631	 0.18527	 0.00238	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44300	 44867	 0.041428	 0.15014	 0.03225	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44300	 45338	 0.02839	 0.097428	 0.02335	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44300	 90317	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44300	 90317	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44301	 44804	 0.13493	 0.087363	 0.00166	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44302	 44303	 0.048311	 0.095654	 0.0014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44302	 45543	 0.30514	 0.22457	 0.00328	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44302	 90318	 0.1659	 0.26491	 0.0061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44303	 44304	 0.01473	 0.049138	 0.00078	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44304	 44306	 0.079528	 0.080328	 0.00106	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44304	 44807	 0.041485	 0.11899	 0.00183	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44305	 45364	 0.005077	 0.017107	 0.00425	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44305	 90318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44305	 90318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90318	 44306	 0.071913	 0.11017	 0.00155	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44307	 44308	 0.010409	 0.036422	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44307	 44309	 0.029002	 0.054814	 0.00089	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44308	 45370	 0.048197	 0.11188	 0.00213	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90318	 44308	 0.034083	 0.086679	 0.00137	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44309	 44310	 0.10168	 0.099892	 0.00169	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44310	 46408	 0.24496	 0.1939	 0.00244	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44311	 44320	 0.001554	 0.010783	 0.00308	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44311	 51899	 0.002114	 0.016201	 0.00434	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44311	 90319	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44311	 90319	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44312	 44313	 0.002488	 0.012139	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44312	 51890	 0.002295	 0.011022	 0.00021	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44313	 44314	 0.007326	 0.011223	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90319	 44313	 0.005815	 0.017856	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44315	 44316	 0.002878	 0.022431	 0.00042	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44315	 51911	 0.004748	 0.030635	 0.00098	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44316	 44318	 0.00498	 0.015293	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90319	 44316	 0.008008	 0.023549	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44317	 90320	 0.036093	 0.063474	 0.00119	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44318	 44319	 0.045634	 0.11606	 0.00184	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44319	 44323	 0.059962	 0.22174	 0.00411	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90319	 44319	 0.046183	 0.13581	 0.00278	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44320	 90320	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44320	 90320	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44320	 90511	 0.016558	 0.18801	 0.1061	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90320	 44321	 0.054256	 0.15562	 0.00239	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44321	 90495	 0.10845	 0.22291	 0.00425	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90320	 44322	 0.094653	 0.31584	 0.00501	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44323	 90510	 0.048856	 0.21773	 0.0037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44324	 44326	 0.20498	 0.31411	 0.00441	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88976	 44324	 0.26571	 0.26846	 0.00356	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44325	 44878	 0.40297	 0.31908	 0.00402	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88976	 44325	 0.40445	 0.32025	 0.00403	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44326	 90522	 0.099523	 0.23571	 0.00431	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44327	 90321	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44327	 90321	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90321	 44328	 0.22519	 0.17654	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90306	 44329	 0.10519	 0.20829	 0.00306	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44329	 90324	 0.052558	 0.13895	 0.00252	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44330	 45166	 0.007238	 0.036366	 0.00946	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44330	 90322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44330	 90322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44331	 44823	 0.021278	 0.077064	 0.01654	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44331	 90323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44331	 90323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44332	 90324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44332	 90324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44333	 44334	 0.04455	 0.091171	 0.00224	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90276	 44333	 0.10514	 0.21521	 0.0053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44334	 44337	 0.089979	 0.17817	 0.00262	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44334	 44348	 0.21343	 0.16893	 0.00213	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44335	 44348	 0.080706	 0.15818	 0.00237	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44335	 90325	 0.28069	 0.22008	 0.00283	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44336	 44337	 0.12414	 0.13655	 0.00182	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44336	 90325	 0.14222	 0.11256	 0.00142	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44338	 44339	 0.14585	 0.12006	 0.00243	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44339	 44342	 0.070118	 0.17834	 0.00282	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44339	 44347	 0.25659	 0.20117	 0.00258	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44340	 44343	 0.007204	 0.019341	 0.00438	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44340	 90325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44340	 90325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44341	 90326	 0.026035	 0.051546	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44342	 44345	 0.034857	 0.069015	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44342	 90326	 0.016971	 0.056615	 0.0009	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44343	 90326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44343	 90326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44343	 90487	 0.043318	 0.11455	 0.02683	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44344	 44345	 0.022169	 0.038987	 0.00073	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90325	 44344	 0.033437	 0.066203	 0.00097	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90326	 44344	 0.027984	 0.040776	 0.00092	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44345	 44346	 0.16576	 0.13119	 0.00165	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90326	 44345	 0.033988	 0.059773	 0.00112	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44346	 90488	 0.40553	 0.30743	 0.00423	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44347	 44905	 0.28414	 0.22278	 0.00286	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44349	 44354	 0.001251	 0.004361	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44349	 45094	 0.000671	 0.002337	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44350	 44351	 0.002022	 0.005638	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44350	 45092	 0.0012	 0.003114	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44351	 44352	 0.000993	 0.002553	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44351	 44368	 0.003604	 0.008685	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44351	 90327	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44351	 90327	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44352	 44353	 0.001237	 0.003368	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44353	 44354	 0.001015	 0.003386	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44353	 44357	 0.00075	 0.003995	 0.00112	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44353	 90328	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44353	 90328	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44354	 44355	 0.000687	 0.002291	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44354	 45158	 0.002599	 0.00687	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44355	 44356	 0.001272	 0.005833	 0.00149	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44355	 90329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44355	 90329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44356	 44358	 0.000638	 0.002927	 0.00075	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44356	 45395	 0.003181	 0.008257	 0.002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44356	 90330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44356	 90330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44357	 44359	 0.001274	 0.007459	 0.00203	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44358	 44359	 0.000737	 0.003286	 0.00089	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44359	 90331	 0.000274	 0.003877	 0.00128	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44360	 45412	 0.000452	 0.003167	 0.00539	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44360	 45437	 0.007452	 0.068668	 0.13095	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44360	 90331	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90332	 44360	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44360	 90526	 0.002492	 0.016621	 0.03133	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44361	 44366	 0.003066	 0.008104	 0.0019	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90331	 44361	 0.001037	 0.004151	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44361	 90333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44361	 90333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44361	 90632	 0.00158	 0.006324	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44362	 44363	 0.017365	 0.025418	 0.00039	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44362	 44364	 0.029365	 0.038594	 0.00053	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44362	 44370	 0.007385	 0.02873	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44362	 90334	 0.025307	 0.065056	 0.00101	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90332	 44363	 0.010697	 0.024836	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90333	 44364	 0.012633	 0.022217	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44365	 44366	 0.003928	 0.010953	 0.0023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44365	 90334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44365	 90334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44365	 90350	 0.002674	 0.015931	 0.00419	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44367	 45089	 0.020821	 0.024406	 0.00042	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90327	 44367	 0.007961	 0.015602	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44367	 90335	 0.036619	 0.02898	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44368	 44369	 0.002269	 0.005995	 0.0014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44368	 45099	 0.001544	 0.004146	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44368	 90335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44368	 90335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44369	 44377	 0.002853	 0.010329	 0.00222	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44369	 44601	 0.005967	 0.016247	 0.00358	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44369	 45099	 0.002222	 0.008047	 0.00173	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44369	 90336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44369	 90336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90327	 44370	 0.008016	 0.027382	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44370	 90337	 0.044736	 0.035404	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44371	 45263	 0.02377	 0.023776	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44372	 44397	 0.00879	 0.039167	 0.00067	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44372	 90589	 0.028936	 0.026107	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44373	 44374	 0.012136	 0.013348	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44373	 44393	 0.008338	 0.023914	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44373	 44397	 0.010065	 0.019928	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44373	 44405	 0.061151	 0.044991	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44373	 90340	 0.053615	 0.054153	 0.00072	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44374	 44390	 0.022649	 0.017924	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44375	 44390	 0.014068	 0.025128	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44375	 90341	 0.010474	 0.024316	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44376	 44379	 0.02959	 0.02096	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44376	 44401	 0.007141	 0.014138	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44377	 90337	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44377	 90337	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44377	 90350	 0.003784	 0.029495	 0.00882	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44378	 44389	 0.021658	 0.015656	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44379	 44380	 0.0447	 0.035375	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44379	 44381	 0.051022	 0.040378	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88948	 44379	 0.011247	 0.050118	 0.00085	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90336	 44380	 0.03359	 0.026583	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44381	 44382	 0.008303	 0.023815	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44381	 44383	 0.024547	 0.016489	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44382	 44384	 0.003962	 0.013863	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90337	 44382	 0.033538	 0.026542	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44383	 44387	 0.031212	 0.024701	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44384	 44385	 0.01093	 0.031349	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44384	 44386	 0.006354	 0.020967	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44385	 44386	 0.023931	 0.024171	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44385	 90352	 0.013037	 0.034554	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90334	 44386	 0.011147	 0.033551	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44387	 44389	 0.010814	 0.021411	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44388	 44389	 0.008382	 0.02404	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44388	 90341	 0.006153	 0.021529	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44389	 44402	 0.006204	 0.015948	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88948	 44389	 0.019952	 0.039504	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44390	 44391	 0.016691	 0.013209	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44390	 90340	 0.040653	 0.032172	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44392	 44398	 0.001612	 0.005378	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44392	 90338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44392	 90338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44393	 44394	 0.003932	 0.019187	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44394	 44406	 0.029657	 0.02441	 0.00049	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44394	 90339	 0.003392	 0.01807	 0.00032	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44395	 44399	 0.015337	 0.012137	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44396	 44399	 0.010794	 0.019771	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44396	 90341	 0.007522	 0.018411	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90338	 44397	 0.003096	 0.017421	 0.00038	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44398	 44408	 0.001587	 0.005774	 0.00177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44398	 90339	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44398	 90339	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88948	 44399	 0.013906	 0.021302	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44400	 90340	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44400	 90340	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44401	 44402	 0.006075	 0.01009	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44403	 44416	 0.001096	 0.003174	 0.00077	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44403	 44419	 0.002959	 0.008861	 0.002	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44403	 90341	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44403	 90341	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44404	 44405	 0.030856	 0.024419	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44405	 44417	 0.011931	 0.03067	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44406	 44421	 0.015568	 0.02046	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90338	 44407	 0.020768	 0.033149	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44407	 90342	 0.010194	 0.024139	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44408	 44409	 0.002454	 0.005913	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44408	 44414	 0.004519	 0.015503	 0.00371	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44408	 45277	 0.011822	 0.032967	 0.00692	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44408	 45278	 0.015021	 0.044288	 0.0103	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44408	 90342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44408	 90342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44408	 90350	 0.017709	 0.045527	 0.01127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44409	 44414	 0.002709	 0.009294	 0.00223	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44409	 90343	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44409	 90343	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44410	 44413	 0.007332	 0.01702	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90343	 44410	 0.012746	 0.025235	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44410	 90345	 0.03068	 0.060127	 0.0009	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44411	 44415	 0.005524	 0.01895	 0.00454	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44411	 44422	 0.001268	 0.00442	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44411	 90344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44411	 90344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44412	 44426	 0.009253	 0.01663	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90344	 44412	 0.03337	 0.024552	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44413	 44421	 0.014131	 0.027694	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44414	 44415	 0.004511	 0.012581	 0.00264	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88940	 44414	 0.031671	 0.1858	 0.05073	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44414	 90345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44414	 90345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44415	 44424	 0.005516	 0.016604	 0.00519	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88944	 44415	 0.021407	 0.073452	 0.0176	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44415	 90346	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44415	 90346	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44416	 44419	 0.001897	 0.005494	 0.00132	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44417	 44418	 0.017857	 0.012909	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44417	 90348	 0.004475	 0.019605	 0.00042	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90341	 44418	 0.034626	 0.027142	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44419	 44420	 0.002934	 0.007877	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44419	 44430	 0.002016	 0.006792	 0.00169	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44419	 90347	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44419	 90347	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44420	 44422	 0.001988	 0.005253	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44420	 44432	 0.001942	 0.005415	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90344	 44421	 0.026717	 0.026985	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44421	 90348	 0.02349	 0.018589	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44422	 44432	 0.00359	 0.00923	 0.00229	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44422	 90348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44422	 90348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44423	 44427	 0.057525	 0.038641	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90346	 44423	 0.042668	 0.043096	 0.00057	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44423	 90349	 0.013271	 0.035082	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44424	 44442	 0.003676	 0.01331	 0.00286	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44424	 45181	 0.015584	 0.051994	 0.01319	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44424	 90349	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44424	 90349	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44424	 90350	 0.01519	 0.036607	 0.01034	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90349	 44425	 0.029872	 0.027515	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90346	 44426	 0.01445	 0.037451	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44428	 44441	 0.010499	 0.036017	 0.00863	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44428	 90350	 0.005793	 0.020189	 0.00468	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44429	 44439	 0.000674	 0.007835	 0.06773	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44429	 45266	 0.001172	 0.013531	 0.11866	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44429	 90350	 0.000128	 0.010206	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44430	 44433	 0.001193	 0.004215	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44430	 90352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44430	 90352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44431	 90353	 0.017336	 0.013588	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44432	 44433	 0.002107	 0.005567	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44432	 90353	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44432	 90353	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44433	 44434	 0.001374	 0.004715	 0.00113	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90350	 44433	 0.004461	 0.015304	 0.00367	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90350	 44434	 0.003131	 0.010549	 0.00262	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44435	 44440	 0.000373	 0.004225	 0.03847	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44435	 90354	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90355	 44435	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44436	 44437	 0.002167	 0.005727	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44436	 90357	 0.002491	 0.008544	 0.00205	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90355	 44437	 0.001282	 0.003389	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44438	 90358	 0.049243	 0.034881	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44439	 44440	 0.000167	 0.001862	 0.01756	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44439	 90356	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88944	 44441	 0.003633	 0.012461	 0.00299	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44442	 44443	 0.006501	 0.022655	 0.00525	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44443	 45181	 0.004694	 0.018262	 0.00488	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44444	 44448	 0.063672	 0.12607	 0.00185	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44444	 44487	 0.30167	 0.19538	 0.00372	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44444	 90378	 0.21184	 0.16767	 0.00211	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44445	 44446	 0.010646	 0.027639	 0.00671	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88981	 44445	 0.022599	 0.075407	 0.01913	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44445	 90359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44445	 90359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44446	 45330	 0.0153	 0.049907	 0.01325	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44446	 90360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44446	 90360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44447	 44918	 0.010963	 0.037609	 0.00901	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44447	 90361	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44447	 90361	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44448	 44967	 0.027946	 0.080154	 0.00123	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88982	 44448	 0.021484	 0.09466	 0.00164	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90359	 44448	 0.033006	 0.085544	 0.00162	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44449	 44457	 0.01153	 0.030472	 0.00713	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44449	 90362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44449	 90362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88987	 44450	 0.043149	 0.21058	 0.00364	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44450	 90364	 0.034329	 0.15214	 0.00457	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44450	 90380	 0.10401	 0.2984	 0.00459	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44451	 44452	 0.075284	 0.10492	 0.00179	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44452	 90363	 0.044326	 0.045261	 0.0007	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44452	 90364	 0.022981	 0.045501	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44453	 44454	 0.005106	 0.012836	 0.00333	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44453	 44456	 0.00727	 0.029585	 0.00721	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44453	 44457	 0.012325	 0.029702	 0.00839	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44453	 90363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44453	 90363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44453	 90607	 0.06591	 0.2266	 0.05444	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44454	 44457	 0.007585	 0.020363	 0.00462	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44454	 90364	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44454	 90364	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90363	 44455	 0.15735	 0.12454	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44456	 44490	 0.021885	 0.1164	 0.02703	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44456	 45019	 0.014069	 0.037772	 0.00856	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44457	 44985	 0.044216	 0.11693	 0.02739	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44458	 44463	 0.013139	 0.034111	 0.00828	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90303	 44458	 0.01844	 0.051426	 0.0108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44459	 44461	 0.015462	 0.040143	 0.00974	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44459	 44888	 0.009471	 0.069988	 0.02021	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90303	 44459	 0.009556	 0.056932	 0.01498	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44459	 90365	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44459	 90365	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90365	 44460	 0.2773	 0.21951	 0.00276	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44460	 90366	 0.036485	 0.055891	 0.00078	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44461	 90366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44461	 90366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44462	 44463	 0.016006	 0.047194	 0.01098	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44463	 44477	 0.026504	 0.06664	 0.01727	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44464	 90367	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90368	 44464	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44464	 90455	 0.005882	 0.040535	 0.0716	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44464	 90502	 0.007564	 0.04914	 0.09799	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44465	 44969	 0.017684	 0.060672	 0.01454	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44465	 44970	 0.01664	 0.057089	 0.01368	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90367	 44465	 0.010365	 0.059451	 0.01977	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44465	 90369	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44465	 90369	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44466	 44468	 0.26711	 0.26987	 0.00357	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88962	 44466	 0.02477	 0.13889	 0.00383	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90369	 44466	 0.040678	 0.1248	 0.00338	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44466	 90508	 0.3149	 0.24929	 0.00314	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44467	 44468	 0.037991	 0.11172	 0.00229	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90368	 44467	 0.091161	 0.23438	 0.00363	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44469	 44793	 0.11275	 0.22327	 0.00328	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90368	 44469	 0.069961	 0.17986	 0.00278	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44470	 44477	 0.008965	 0.055636	 0.01348	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44470	 44479	 0.014817	 0.050833	 0.01218	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44470	 44918	 0.012058	 0.066178	 0.0175	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44470	 45332	 0.009541	 0.038202	 0.00962	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44471	 45360	 0.066429	 0.17218	 0.00326	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44471	 90370	 0.025166	 0.14306	 0.00259	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90268	 44472	 0.050613	 0.20688	 0.00419	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44472	 90373	 0.050782	 0.13055	 0.00202	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44473	 90370	 0.008735	 0.018718	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44473	 90373	 0.007172	 0.018438	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44474	 90370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44474	 90370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44474	 90371	 0.002377	 0.008646	 0.00265	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44475	 90371	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44476	 44478	 0.004272	 0.007824	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90372	 44476	 0.009675	 0.024871	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44476	 90373	 0.024456	 0.017679	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90371	 44477	 0.0017	 0.006807	 0.00171	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44477	 90373	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44477	 90373	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90372	 44478	 0.00759	 0.019511	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44479	 90374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44479	 90374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44480	 44481	 0.001941	 0.00504	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44480	 44482	 0.005904	 0.016561	 0.00426	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44480	 90375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44480	 90375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44481	 44483	 0.009348	 0.027562	 0.00641	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88937	 44482	 0.002785	 0.010587	 0.00296	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44482	 90376	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44482	 90376	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44483	 45352	 0.015948	 0.041	 0.01015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90376	 44484	 0.17647	 0.12758	 0.00193	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44485	 44487	 0.098322	 0.19271	 0.00289	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44485	 90377	 0.10833	 0.079706	 0.00117	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44486	 44489	 0.001012	 0.011272	 0.10632	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44486	 90377	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44486	 90377	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90360	 44487	 0.131	 0.25942	 0.00381	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44487	 90566	 0.38425	 0.24893	 0.00474	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44488	 44968	 0.002326	 0.015783	 0.02874	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44488	 90378	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44488	 90378	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44488	 90379	 0.000812	 0.008813	 0.01729	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44489	 44956	 0.00125	 0.014164	 0.12901	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44489	 90379	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44489	 90379	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44490	 44989	 0.013004	 0.049436	 0.01384	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44490	 90380	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44490	 90380	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88987	 44491	 0.055757	 0.14181	 0.00224	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90380	 44491	 0.10078	 0.19955	 0.00293	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44491	 90613	 0.39807	 0.31519	 0.00397	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44492	 44537	 0.001541	 0.00627	 0.00153	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44492	 44707	 0.00079	 0.002662	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44492	 90381	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44492	 90381	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90381	 44493	 0.021782	 0.016026	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44494	 44546	 0.005834	 0.010487	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44494	 44710	 0.017954	 0.014209	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44494	 44711	 0.021961	 0.017214	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44494	 44714	 0.032232	 0.024724	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90381	 44494	 0.007139	 0.018352	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44494	 90430	 0.003768	 0.009686	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44495	 44497	 0.005016	 0.012757	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44495	 44709	 0.016581	 0.016288	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44496	 44528	 0.016226	 0.012294	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44497	 44713	 0.002956	 0.00986	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44498	 44716	 0.008808	 0.011463	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44498	 90432	 0.02325	 0.0184	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44499	 90432	 0.01212	 0.009592	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44500	 44725	 0.00564	 0.00864	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44500	 90432	 0.012534	 0.012659	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44501	 44723	 0.01171	 0.008465	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44502	 90382	 0.011692	 0.009253	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44503	 44732	 0.000814	 0.002184	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44503	 44789	 0.001915	 0.004922	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44503	 90382	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44503	 90382	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44504	 44730	 0.005354	 0.006727	 0.0001	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44504	 90434	 0.003035	 0.007045	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44505	 44506	 0.008844	 0.005726	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44505	 44739	 0.003961	 0.005206	 7e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44505	 44743	 0.002267	 0.007561	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44507	 44741	 0.008705	 0.006889	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44507	 44748	 0.011081	 0.008769	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44508	 44511	 0.002093	 0.006909	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44508	 44748	 0.012226	 0.009584	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44508	 44750	 0.00888	 0.007028	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44509	 44512	 0.003586	 0.009217	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44509	 44787	 0.003981	 0.006212	 0.0001	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44510	 44511	 0.011657	 0.007546	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44511	 44512	 0.007221	 0.007942	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44511	 44761	 0.00747	 0.011444	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44511	 44762	 0.004374	 0.008572	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44511	 90390	 0.065156	 0.047102	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44512	 90383	 0.001839	 0.006135	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44513	 44514	 0.000805	 0.001869	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44513	 44515	 0.001192	 0.002997	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44513	 90383	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44513	 90383	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44514	 44756	 0.001549	 0.004318	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44514	 44786	 0.001278	 0.003378	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44514	 90384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44514	 90384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44515	 44764	 0.001273	 0.003364	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44515	 44773	 0.001096	 0.003761	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44515	 90385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44515	 90385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90385	 44516	 0.00738	 0.005785	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44516	 90444	 0.026689	 0.017278	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44517	 44775	 0.013354	 0.009825	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44518	 44766	 0.009238	 0.00933	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44518	 44772	 0.004087	 0.0084	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44518	 44777	 0.02095	 0.016422	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44519	 44768	 0.000841	 0.002886	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44519	 44778	 0.002028	 0.006957	 0.00167	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44520	 44522	 0.005263	 0.015094	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44520	 90386	 0.003586	 0.013797	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44521	 44595	 0.001081	 0.00425	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44521	 44779	 0.001373	 0.004132	 0.00129	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44521	 90386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44521	 90386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44522	 44523	 0.024928	 0.019728	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44522	 44526	 0.019919	 0.014399	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44522	 44774	 0.019814	 0.01568	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44524	 44589	 0.004574	 0.011632	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44524	 44776	 0.007627	 0.011114	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44525	 44592	 0.000996	 0.003519	 0.00079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44525	 44778	 0.00102	 0.003555	 0.00082	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44525	 90387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44525	 90387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44526	 44527	 0.021186	 0.016606	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44526	 44790	 0.034726	 0.02722	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44528	 44529	 0.006883	 0.01598	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44528	 45124	 0.005819	 0.010819	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44529	 90433	 0.007683	 0.017837	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44529	 90436	 0.040573	 0.030739	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44529	 90552	 0.012805	 0.025352	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44530	 44537	 0.000586	 0.003714	 0.00101	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44530	 44679	 0.000996	 0.005831	 0.00159	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90288	 44530	 0.001218	 0.009782	 0.00275	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44530	 90388	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44530	 90388	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44531	 44533	 0.00385	 0.014978	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44531	 90422	 0.003757	 0.017411	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44532	 44682	 0.015483	 0.011391	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44533	 44535	 0.011652	 0.02307	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44533	 44674	 0.01847	 0.015203	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44534	 44538	 0.008212	 0.027099	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90388	 44534	 0.005464	 0.018227	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90381	 44535	 0.026238	 0.020764	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90381	 44536	 0.005227	 0.012134	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44536	 90389	 0.003423	 0.01142	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44537	 90389	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44537	 90389	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44538	 44540	 0.005928	 0.015238	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44539	 44550	 0.004597	 0.015334	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44539	 44674	 0.0041	 0.015949	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44540	 44542	 0.011572	 0.012728	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44541	 44542	 0.019113	 0.015125	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44541	 44543	 0.015971	 0.012519	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44542	 44545	 0.015562	 0.012316	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44542	 44547	 0.029961	 0.023711	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44542	 44551	 0.031184	 0.024679	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44543	 44544	 0.011452	 0.008426	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44543	 44552	 0.010914	 0.02139	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44544	 44555	 0.025545	 0.020023	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44546	 44547	 0.009314	 0.011354	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44548	 44556	 0.022134	 0.016001	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44548	 44710	 0.014063	 0.013188	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44549	 44550	 0.01451	 0.011374	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44550	 44551	 0.009546	 0.013024	 0.00023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44551	 44552	 0.012556	 0.013408	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44551	 90414	 0.010466	 0.064344	 0.00116	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44552	 44553	 0.008849	 0.015563	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44552	 44652	 0.003063	 0.017861	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44553	 44554	 0.008542	 0.021957	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44553	 44653	 0.006499	 0.010948	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44554	 90412	 0.006325	 0.030866	 0.00053	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44555	 44558	 0.023615	 0.023852	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44555	 90414	 0.015487	 0.074723	 0.00132	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44556	 44557	 0.033849	 0.021914	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44557	 44559	 0.028934	 0.021921	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44557	 90441	 0.019147	 0.017274	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44558	 44560	 0.005266	 0.014944	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44559	 90449	 0.019029	 0.035964	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44560	 44561	 0.005362	 0.009675	 0.00014	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44560	 44566	 0.00981	 0.019226	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44561	 44562	 0.020464	 0.016195	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44561	 44565	 0.012689	 0.012465	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44562	 44644	 0.008167	 0.015435	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44563	 44564	 0.000559	 0.001917	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44563	 44573	 0.001001	 0.003373	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44564	 44780	 0.000713	 0.002228	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44565	 44781	 0.006046	 0.011579	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44566	 44568	 0.016006	 0.010363	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44566	 44781	 0.017794	 0.014082	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44566	 90391	 0.010051	 0.023801	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44567	 44568	 0.015882	 0.012569	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44567	 90441	 0.03511	 0.024871	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44568	 90390	 0.006756	 0.010783	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44569	 44571	 0.001461	 0.005292	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44569	 90390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44569	 90390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44570	 44572	 0.00441	 0.008731	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44570	 90391	 0.007609	 0.012145	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44571	 90391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44571	 90391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44571	 90406	 0.001651	 0.018262	 0.00548	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44572	 44765	 0.005975	 0.009153	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44573	 44574	 0.000953	 0.004035	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44574	 44575	 0.000664	 0.00266	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44574	 90392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44574	 90392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44575	 44635	 0.001507	 0.005729	 0.0016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44576	 44577	 0.019056	 0.01787	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90391	 44576	 0.023805	 0.017209	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44577	 44579	 0.009986	 0.017949	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44578	 44580	 0.011699	 0.019073	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44578	 44765	 0.021726	 0.017882	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44578	 44775	 0.017952	 0.014207	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44579	 90393	 0.009081	 0.030294	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44580	 44581	 0.017395	 0.012798	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44580	 44587	 0.01062	 0.021027	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44581	 44587	 0.013546	 0.017629	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44582	 44588	 0.006125	 0.018436	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44582	 90393	 0.003145	 0.013507	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44583	 90407	 0.040113	 0.031745	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44584	 44618	 0.001712	 0.006967	 0.0017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44584	 44778	 0.007778	 0.020194	 0.0049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44584	 90393	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44584	 90393	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44585	 44587	 0.020145	 0.022157	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44585	 44610	 0.007279	 0.020877	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44586	 44587	 0.010993	 0.01684	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44587	 44588	 0.005237	 0.013462	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44587	 44589	 0.00944	 0.013998	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44587	 90451	 0.007527	 0.044562	 0.00087	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44589	 44590	 0.003008	 0.010036	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44590	 44591	 0.002846	 0.011073	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44591	 44609	 0.003853	 0.016879	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44592	 44593	 0.000826	 0.002832	 0.00068	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44592	 90394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44592	 90394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44593	 44594	 0.000808	 0.002771	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44594	 44606	 0.001197	 0.004187	 0.00139	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44595	 44596	 0.000763	 0.002899	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44595	 90395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44595	 90395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44596	 44597	 0.000511	 0.002164	 0.00049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44597	 44606	 0.001335	 0.004578	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44597	 90396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44597	 90396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90386	 44598	 0.004908	 0.010315	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90395	 44598	 0.004461	 0.01092	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44599	 44600	 0.007234	 0.010966	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90395	 44599	 0.017562	 0.013471	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90396	 44600	 0.005841	 0.011565	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44601	 44602	 0.00194	 0.00676	 0.00157	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44601	 44604	 0.00383	 0.01147	 0.00258	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44602	 90397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44602	 90397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88948	 44603	 0.009734	 0.032473	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90397	 44603	 0.00981	 0.019226	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44603	 90398	 0.025791	 0.028367	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44603	 90399	 0.006893	 0.018832	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44603	 90400	 0.021693	 0.017167	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44604	 44605	 0.001076	 0.003508	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44605	 44607	 0.001401	 0.003638	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44605	 45260	 0.006641	 0.018519	 0.00389	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44605	 90398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44605	 90398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44606	 44607	 0.001	 0.005022	 0.00131	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44606	 90399	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44606	 90399	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44606	 90450	 0.000826	 0.003305	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44607	 90400	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44607	 90400	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44608	 44615	 0.004676	 0.012359	 0.00289	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44608	 90401	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44608	 90401	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44608	 90450	 0.000775	 0.002658	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90401	 44609	 0.00203	 0.012482	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90401	 44610	 0.006174	 0.027203	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44611	 44617	 0.018735	 0.014827	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44611	 90402	 0.017006	 0.019935	 0.00035	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44612	 44617	 0.033817	 0.033916	 0.00055	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44612	 90451	 0.016747	 0.030217	 0.00044	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44613	 44614	 0.016579	 0.012198	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90398	 44613	 0.017248	 0.01897	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44614	 90402	 0.021797	 0.01725	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44615	 44616	 0.00123	 0.00345	 0.00089	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44615	 90402	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44615	 90402	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44616	 45260	 0.001986	 0.005855	 0.00136	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44617	 90403	 0.048516	 0.035695	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44617	 90404	 0.004913	 0.015088	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44618	 44619	 0.001883	 0.006458	 0.00155	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44618	 90403	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44618	 90403	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44619	 44620	 0.00183	 0.007745	 0.00174	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44619	 90404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44619	 90404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44621	 90405	 0.017583	 0.012711	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44621	 90408	 0.025588	 0.024724	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44622	 44625	 0.003673	 0.009707	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44622	 44626	 0.002143	 0.008146	 0.00228	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44622	 90405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44622	 90405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44622	 90406	 0.001994	 0.00695	 0.00161	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44623	 45266	 0.000304	 0.002987	 0.05186	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44623	 90406	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44624	 44625	 0.001746	 0.004054	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44624	 90408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44624	 90408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44625	 90409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44625	 90409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44626	 90591	 0.004179	 0.017688	 0.00398	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44627	 44630	 0.003662	 0.016386	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44627	 90410	 0.0046	 0.024614	 0.00075	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44628	 90410	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44628	 90410	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44628	 90591	 0.001705	 0.007822	 0.002	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90407	 44629	 0.029336	 0.024146	 0.00049	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90410	 44629	 0.013834	 0.046148	 0.00073	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90403	 44630	 0.010065	 0.025874	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44631	 44632	 0.012057	 0.022084	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90409	 44631	 0.033889	 0.025675	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90410	 44632	 0.035992	 0.039587	 0.00053	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90392	 44633	 0.013791	 0.023232	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44633	 90411	 0.011973	 0.02152	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44634	 44635	 0.001693	 0.005902	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44634	 90411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44634	 90411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90406	 44635	 0.000732	 0.006278	 0.00179	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44636	 44637	 0.015221	 0.030136	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44636	 44640	 0.004063	 0.023094	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44636	 44700	 0.012974	 0.02341	 0.00034	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44637	 44641	 0.018564	 0.034001	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44637	 44643	 0.00607	 0.016087	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44638	 44641	 0.031132	 0.022052	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44639	 44641	 0.007714	 0.016214	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90411	 44639	 0.011274	 0.017995	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44640	 44703	 0.007923	 0.026431	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90408	 44640	 0.008223	 0.015289	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90405	 44641	 0.003594	 0.024387	 0.00046	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44642	 44643	 0.014094	 0.02699	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44642	 44646	 0.037633	 0.029782	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44644	 44646	 0.008644	 0.024793	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44645	 44646	 0.012117	 0.021153	 0.00033	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44645	 90412	 0.004956	 0.014215	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90411	 44646	 0.014048	 0.045235	 0.00077	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44647	 44652	 0.005032	 0.0223	 0.00067	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44647	 90414	 0.002158	 0.014638	 0.00027	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44648	 90412	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44648	 90412	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44648	 90413	 0.002417	 0.009679	 0.00244	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44649	 44650	 0.030682	 0.024281	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44649	 44651	 0.011608	 0.022983	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44649	 90414	 0.023038	 0.052258	 0.00104	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44649	 90418	 0.006523	 0.023302	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44649	 90420	 0.059931	 0.0388	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44651	 44652	 0.022016	 0.017423	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44654	 45266	 0.000924	 0.010515	 0.09498	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44654	 90413	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44655	 44659	 0.044177	 0.034961	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44656	 44658	 0.019995	 0.015824	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44657	 44659	 0.032573	 0.025532	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44658	 44659	 0.007996	 0.013354	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90414	 44659	 0.005513	 0.018389	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44660	 44661	 0.037832	 0.02994	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90414	 44660	 0.042238	 0.045002	 0.00064	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44660	 90419	 0.01419	 0.047338	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44662	 44666	 0.002664	 0.007041	 0.00165	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44662	 90415	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44662	 90415	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44663	 44664	 0.030459	 0.019719	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44663	 44688	 0.015484	 0.025823	 0.00038	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90415	 44664	 0.009722	 0.034731	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44664	 90416	 0.005546	 0.027064	 0.00047	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44665	 44670	 0.001566	 0.006269	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44665	 44686	 0.008042	 0.018667	 0.00569	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44665	 90416	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44665	 90416	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44666	 44667	 0.003189	 0.008892	 0.00187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90413	 44666	 0.010774	 0.028476	 0.00667	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44666	 90417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44666	 90417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44667	 44668	 0.000581	 0.002919	 0.00076	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44667	 44672	 0.000854	 0.005408	 0.00147	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44668	 44669	 0.001109	 0.004215	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44668	 90418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44668	 90418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44669	 44673	 0.00147	 0.005884	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44670	 44695	 0.004281	 0.018117	 0.00408	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44671	 44672	 0.000789	 0.004904	 0.00138	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44671	 44695	 0.002025	 0.016851	 0.0051	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44671	 90419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44671	 90419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44673	 44675	 0.003627	 0.00874	 0.00247	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44673	 90420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44673	 90420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90420	 44674	 0.006607	 0.025704	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44675	 44676	 0.001417	 0.003561	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44675	 90421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44675	 90421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44676	 44678	 0.00121	 0.004217	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44676	 90422	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44676	 90422	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44677	 44689	 0.016981	 0.030522	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90289	 44677	 0.046785	 0.092633	 0.00136	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90415	 44677	 0.016064	 0.02382	 0.00036	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44678	 44679	 0.001277	 0.00438	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44678	 90423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44678	 90423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90288	 44679	 0.000598	 0.004227	 0.00116	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90415	 44680	 0.012236	 0.02275	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90420	 44680	 0.035758	 0.028299	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90421	 44680	 0.028633	 0.022444	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44681	 44682	 0.00565	 0.011073	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90420	 44681	 0.023597	 0.015277	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90421	 44681	 0.011566	 0.020789	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44683	 90424	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44683	 90424	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44684	 44685	 0.014058	 0.02511	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90289	 44684	 0.006285	 0.025192	 0.00065	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90423	 44684	 0.015822	 0.016897	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90421	 44685	 0.018617	 0.022695	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90424	 44685	 0.03211	 0.024631	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44686	 90425	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44686	 90425	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44687	 44688	 0.004816	 0.023116	 0.00069	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44687	 44689	 0.003651	 0.010988	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90283	 44687	 0.014007	 0.023596	 0.00034	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44688	 44691	 0.012027	 0.05869	 0.00101	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90425	 44688	 0.014202	 0.028118	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44690	 44695	 0.002896	 0.019876	 0.0058	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44690	 45440	 0.002496	 0.011238	 0.00299	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88934	 44690	 0.006596	 0.07802	 0.02222	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44690	 90426	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44690	 90426	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90426	 44691	 0.014226	 0.079935	 0.00148	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44692	 44695	 0.004557	 0.020517	 0.00546	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44692	 44706	 0.01823	 0.047331	 0.01149	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44692	 45441	 0.003074	 0.021329	 0.00609	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44693	 44694	 0.030202	 0.10075	 0.0016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44694	 44696	 0.05381	 0.070723	 0.00097	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90414	 44694	 0.035589	 0.10208	 0.00157	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44696	 44697	 0.030135	 0.021346	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44696	 90427	 0.00791	 0.044961	 0.00081	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44698	 44704	 0.00307	 0.01117	 0.00342	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44698	 90427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44698	 90427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44699	 44700	 0.057739	 0.042481	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90414	 44699	 0.087105	 0.064087	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44701	 44702	 0.026047	 0.034233	 0.00047	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44701	 44703	 0.009659	 0.021909	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90427	 44701	 0.007603	 0.036682	 0.00065	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44704	 44705	 0.001235	 0.004946	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44705	 44706	 0.001917	 0.008112	 0.00183	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44705	 90428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44705	 90428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44706	 90429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44706	 90429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44707	 44708	 0.001304	 0.003277	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44707	 90430	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44707	 90430	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44708	 44720	 0.003395	 0.008814	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44708	 90431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44708	 90431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90431	 44709	 0.015966	 0.019463	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44709	 90436	 0.019618	 0.056268	 0.00087	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44710	 44711	 0.012339	 0.009764	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44711	 44784	 0.014679	 0.010799	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90431	 44711	 0.012371	 0.013474	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44712	 44715	 0.014522	 0.010684	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90431	 44712	 0.006663	 0.011717	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44713	 44717	 0.014048	 0.011117	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44713	 90433	 0.003001	 0.013222	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44714	 44718	 0.010079	 0.007976	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44715	 90432	 0.013698	 0.013701	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44716	 44721	 0.004096	 0.009507	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44718	 44719	 0.015966	 0.012635	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44719	 44723	 0.011441	 0.009054	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44719	 44784	 0.010857	 0.008592	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44719	 90432	 0.023	 0.016292	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44720	 44789	 0.001488	 0.004052	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44720	 90432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44720	 90432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44721	 44726	 0.008434	 0.008285	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44721	 90433	 0.005179	 0.022817	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44722	 90433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44722	 90433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44722	 90435	 0.000752	 0.002857	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90382	 44723	 0.009313	 0.010243	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44724	 44727	 0.015016	 0.011884	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44725	 44728	 0.002737	 0.009033	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44726	 90434	 0.005543	 0.009747	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90382	 44727	 0.012204	 0.009658	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44727	 90453	 0.011128	 0.01224	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44728	 90434	 0.001254	 0.005821	 0.00016	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44729	 44734	 0.002046	 0.005705	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44729	 90434	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44729	 90434	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44729	 90435	 0.001511	 0.005939	 0.00155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44730	 90440	 0.007111	 0.010661	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44731	 44782	 0.000639	 0.007011	 0.06811	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44731	 45046	 0.000131	 0.001443	 0.01401	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44731	 90435	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44732	 44736	 0.001257	 0.003322	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44732	 90437	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44732	 90437	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44733	 44738	 0.000652	 0.001677	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44733	 90438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44733	 90438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44734	 44735	 0.000993	 0.002552	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44734	 44738	 0.002015	 0.006913	 0.00166	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44734	 44744	 0.000724	 0.002098	 0.00051	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44734	 90439	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44734	 90439	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44735	 90440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44735	 90440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44736	 44780	 0.00594	 0.015269	 0.00378	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44736	 90441	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44736	 90441	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44737	 44741	 0.010629	 0.008332	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90438	 44737	 0.011617	 0.009105	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44738	 90442	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44738	 90442	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44739	 44788	 0.00902	 0.009022	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44740	 44748	 0.017617	 0.011405	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90437	 44740	 0.023066	 0.01697	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90442	 44741	 0.00468	 0.007885	 0.00011	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44742	 44749	 0.008819	 0.006488	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90442	 44742	 0.005145	 0.005659	 8e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44743	 44785	 0.014903	 0.011432	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44743	 90452	 0.002907	 0.011183	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44744	 44752	 0.000806	 0.002766	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44744	 44786	 0.001086	 0.003027	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44745	 44751	 0.01789	 0.011582	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90440	 44745	 0.019115	 0.014983	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44745	 90443	 0.010216	 0.008008	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44746	 44760	 0.030881	 0.019992	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90441	 44746	 0.023102	 0.018283	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44747	 44748	 0.008894	 0.007038	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44747	 44754	 0.01907	 0.013785	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44749	 44787	 0.008652	 0.008114	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44751	 90443	 0.00875	 0.006198	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44751	 90445	 0.013676	 0.009687	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44752	 44757	 0.001522	 0.004244	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44752	 44783	 0.001185	 0.004146	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44752	 90443	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44752	 90443	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44753	 44758	 0.015393	 0.011325	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44753	 90559	 0.009005	 0.014373	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44754	 44760	 0.008493	 0.014308	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44755	 90444	 0.006553	 0.008613	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44755	 90452	 0.016427	 0.013	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44756	 44757	 0.000744	 0.002025	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44756	 44764	 0.001	 0.002514	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44756	 90444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44756	 90444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44757	 45157	 0.001998	 0.006733	 0.00167	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44757	 90445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44757	 90445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44758	 44759	 0.005262	 0.010312	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44758	 44770	 0.017069	 0.013379	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90445	 44758	 0.003976	 0.007872	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44759	 90559	 0.005088	 0.008947	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44760	 44765	 0.01597	 0.016802	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90390	 44760	 0.009855	 0.019313	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44761	 44766	 0.005583	 0.01038	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44762	 44763	 0.002921	 0.007571	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90385	 44763	 0.001905	 0.005601	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44764	 44768	 0.000541	 0.001823	 0.00045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44764	 90446	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44764	 90446	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44766	 44772	 0.007772	 0.015388	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90385	 44767	 0.006447	 0.007091	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44767	 90447	 0.007345	 0.011252	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44769	 44771	 0.033314	 0.021567	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44769	 44774	 0.014374	 0.010182	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90444	 44769	 0.01683	 0.013319	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44770	 44771	 0.01888	 0.012223	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44771	 90542	 0.007003	 0.021505	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44772	 90447	 0.01473	 0.01116	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44772	 90448	 0.002702	 0.015183	 0.00028	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44773	 44779	 0.000995	 0.003244	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44773	 90447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44773	 90447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44775	 44776	 0.018102	 0.013318	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44776	 44777	 0.017394	 0.013765	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44778	 90448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44778	 90448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44780	 90449	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44780	 90449	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90449	 44781	 0.002084	 0.007635	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44782	 45266	 0.000406	 0.005849	 0.05366	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44782	 90450	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44783	 90527	 0.000763	 0.00474	 0.00134	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44785	 44787	 0.004214	 0.008343	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90384	 44785	 0.002779	 0.009724	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44786	 90452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44786	 90452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44787	 44788	 0.039954	 0.029395	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90436	 44788	 0.004829	 0.031431	 0.00064	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90435	 44789	 0.001788	 0.011517	 0.00302	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44789	 90453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44789	 90453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90451	 44790	 0.014197	 0.069276	 0.0012	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44790	 90542	 0.019524	 0.038657	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44792	 44794	 0.007651	 0.042175	 0.00986	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44792	 45907	 0.006007	 0.030684	 0.00772	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44793	 45426	 0.06709	 0.1904	 0.00299	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44793	 90454	 0.10273	 0.18538	 0.00268	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90367	 44794	 0.029743	 0.10208	 0.02447	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44794	 90454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44794	 90454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44794	 90456	 0.002366	 0.013596	 0.00385	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44795	 90455	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90456	 44795	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44796	 44798	 0.099308	 0.23521	 0.0043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90292	 44796	 0.063041	 0.17224	 0.00293	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44797	 44798	 0.13431	 0.20578	 0.00289	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44797	 44801	 0.18924	 0.23075	 0.0037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90315	 44798	 0.046481	 0.1079	 0.00205	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44799	 44802	 0.055123	 0.10803	 0.00162	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90315	 44799	 0.083398	 0.19751	 0.00361	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44800	 44801	 0.077324	 0.058585	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44800	 90512	 0.12479	 0.36714	 0.00753	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44802	 45356	 0.1452	 0.22025	 0.00316	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44803	 44898	 0.14927	 0.19621	 0.00269	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44804	 45002	 0.10707	 0.21201	 0.00311	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44805	 45281	 0.011789	 0.064934	 0.02345	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44805	 90457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44805	 90457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90457	 44806	 0.012982	 0.050503	 0.00084	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44807	 44809	 0.027096	 0.096797	 0.00192	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44808	 44809	 0.023238	 0.04884	 0.00089	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90457	 44809	 0.011291	 0.052324	 0.001	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44810	 44898	 0.21435	 0.15773	 0.00231	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44810	 45282	 0.14991	 0.11864	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44811	 90458	 0.5791	 0.4266	 0.00624	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44812	 44819	 0.021185	 0.057686	 0.01271	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44812	 44847	 0.074745	 0.20102	 0.04565	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88966	 44812	 0.013925	 0.046923	 0.01166	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44812	 90458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44812	 90458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90458	 44813	 0.5032	 0.37057	 0.00542	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44814	 44820	 0.008812	 0.045905	 0.01204	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44814	 45233	 0.006673	 0.033754	 0.0094	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44815	 45231	 0.19939	 0.20142	 0.00267	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90276	 44815	 0.30857	 0.52026	 0.00742	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44815	 90462	 0.081874	 0.21049	 0.00326	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44815	 90581	 0.56406	 0.44687	 0.00563	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88966	 44816	 0.003636	 0.034913	 0.01016	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44816	 90459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44816	 90459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90459	 44817	 0.029986	 0.10493	 0.00217	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90459	 44817	 0.029986	 0.10493	 0.00217	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44817	 90461	 0.012482	 0.048557	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44817	 90461	 0.012482	 0.048557	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44818	 45732	 0.002753	 0.049484	 0.51145	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44818	 90460	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44819	 44820	 0.003639	 0.040241	 0.01207	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88966	 44819	 0.002754	 0.025012	 0.00815	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44820	 90462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44820	 90462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90458	 44821	 0.41449	 0.26855	 0.00511	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44822	 90464	 0.008421	 0.023484	 0.00493	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44823	 44934	 0.00657	 0.049234	 0.01201	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44823	 90463	 0.011155	 0.039034	 0.01294	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44824	 44825	 0.000288	 0.004409	 0.10177	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44824	 90463	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44824	 90463	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44825	 90464	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44825	 90464	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44826	 44828	 0.28178	 0.18249	 0.00347	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44827	 44828	 0.016642	 0.0946	 0.00171	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44827	 44901	 0.059009	 0.13496	 0.0033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44827	 90485	 0.033556	 0.19076	 0.00345	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44828	 44829	 0.035602	 0.09152	 0.00142	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44828	 44999	 0.397	 0.31435	 0.00396	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90457	 44828	 0.55052	 0.43612	 0.00549	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44829	 45002	 0.10958	 0.16621	 0.00238	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44830	 44838	 0.020214	 0.015845	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44830	 90468	 0.018204	 0.020022	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44831	 44833	 0.007902	 0.019863	 0.00515	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44831	 45316	 0.01383	 0.036553	 0.00856	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44832	 45018	 0.20985	 0.28618	 0.00635	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44832	 45315	 0.12856	 0.27557	 0.00483	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44832	 45336	 0.04508	 0.15039	 0.00238	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44832	 90466	 0.27856	 0.21841	 0.0028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44833	 44834	 0.014688	 0.04096	 0.0086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44833	 44839	 0.015719	 0.056926	 0.01222	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44833	 45316	 0.021519	 0.055874	 0.01356	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44834	 90465	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44834	 90465	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44835	 44838	 0.014233	 0.02818	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44835	 90467	 0.01696	 0.034707	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44836	 44837	 0.006003	 0.015865	 0.00371	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44836	 90466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44836	 90466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44837	 44839	 0.002759	 0.011048	 0.00278	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44837	 44841	 0.004883	 0.033263	 0.01133	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44837	 90467	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44837	 90467	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44838	 90468	 0.016407	 0.018045	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44839	 90468	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44839	 90468	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44840	 44894	 0.013379	 0.044636	 0.01132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44840	 45170	 0.022923	 0.10521	 0.02697	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44840	 90469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44840	 90469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44841	 44850	 0.032294	 0.16244	 0.04234	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44841	 45171	 0.025078	 0.065118	 0.01581	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44841	 90470	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44841	 90470	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44842	 90471	 0.36847	 0.23869	 0.00454	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44843	 90471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44843	 90471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44843	 90516	 0.039315	 0.22404	 0.06509	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44844	 90473	 0.011071	 0.019899	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44845	 90472	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44846	 44847	 0.078015	 0.20657	 0.04846	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44846	 45256	 0.043382	 0.15349	 0.03463	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90472	 44846	 0.028246	 0.081037	 0.01995	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44847	 90474	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44847	 90474	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44848	 44849	 0.02668	 0.12808	 0.00383	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44848	 90475	 0.08818	 0.22671	 0.00351	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44848	 90615	 0.36719	 0.26558	 0.00403	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44849	 45447	 0.043605	 0.24455	 0.00674	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44849	 90615	 0.21811	 0.43208	 0.00635	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44850	 45339	 0.04092	 0.11417	 0.02398	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44850	 90475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44850	 90475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44851	 45251	 0.028512	 0.096102	 0.0239	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88978	 44852	 0.017647	 0.036266	 0.00069	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44852	 90585	 0.28029	 0.65154	 0.0097	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44853	 45732	 0.001878	 0.02062	 0.20049	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44853	 90476	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44854	 45192	 0.52632	 0.38763	 0.00567	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44855	 90478	 0.10527	 0.14672	 0.00251	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44855	 90596	 0.20288	 0.16058	 0.00202	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44856	 44875	 0.043328	 0.12089	 0.02539	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44856	 44926	 0.003241	 0.029427	 0.00959	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44856	 45280	 0.005037	 0.04921	 0.01381	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44856	 45295	 0.004996	 0.035339	 0.0097	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88940	 44856	 0.007173	 0.068886	 0.02004	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44857	 44858	 0.011111	 0.039276	 0.00885	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44857	 44859	 0.002023	 0.029205	 0.00927	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44857	 45173	 0.008664	 0.04808	 0.01462	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44857	 90478	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44857	 90478	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44858	 45175	 0.005668	 0.022681	 0.00766	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44858	 45359	 0.003259	 0.024217	 0.00924	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90295	 44859	 0.003484	 0.051216	 0.01566	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44860	 90494	 0.049029	 0.075108	 0.00105	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44861	 45447	 0.28226	 0.31058	 0.00415	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88955	 44861	 0.14539	 0.24497	 0.00349	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44863	 45446	 0.087063	 0.28738	 0.00466	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44863	 45448	 0.078022	 0.18115	 0.00269	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44863	 90479	 0.058433	 0.14861	 0.00235	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44864	 44865	 0.014022	 0.025045	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44864	 90479	 0.020555	 0.047714	 0.00091	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44866	 44867	 0.001047	 0.008976	 0.00255	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44866	 44868	 0.005858	 0.044128	 0.01225	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44867	 45170	 0.020402	 0.14914	 0.03838	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88964	 44867	 0.01358	 0.13486	 0.03672	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44867	 90479	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44867	 90479	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44868	 90480	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44868	 90480	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44869	 90493	 0.42012	 0.2722	 0.00518	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44870	 44872	 0.00772	 0.039286	 0.01424	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44870	 44875	 0.014132	 0.037941	 0.0086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44870	 45444	 0.011905	 0.040842	 0.00979	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44871	 90481	 0.037699	 0.074641	 0.0011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44871	 90564	 0.041241	 0.16045	 0.00268	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44872	 44873	 0.003045	 0.007654	 0.00198	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44872	 44874	 0.013016	 0.044652	 0.0107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44873	 90481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44873	 90481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44874	 45293	 0.007589	 0.047161	 0.01331	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44875	 90482	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44875	 90482	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90313	 44876	 0.047112	 0.15717	 0.00249	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90482	 44876	 0.008943	 0.035787	 0.00076	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44877	 44937	 0.088653	 0.22007	 0.00366	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44877	 90521	 0.12333	 0.31714	 0.00491	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44879	 90517	 0.40593	 0.32143	 0.00405	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44880	 90517	 0.48208	 0.38181	 0.00481	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44881	 44882	 0.023855	 0.14444	 0.00452	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44881	 93249	 0.042157	 0.39266	 0.00761	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44882	 45009	 0.099913	 0.38886	 0.0065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44882	 45011	 0.092706	 0.26312	 0.00414	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44882	 90517	 0.046063	 0.42399	 0.00842	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44883	 44884	 0.14132	 0.10841	 0.00146	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44883	 45416	 0.061077	 0.15534	 0.00246	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88956	 44883	 0.034708	 0.18495	 0.00324	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44884	 90483	 0.060984	 0.088866	 0.00201	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44885	 44886	 0.009209	 0.025681	 0.00539	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44885	 44887	 0.003406	 0.017112	 0.00445	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44885	 90483	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44885	 90483	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44887	 44888	 0.003342	 0.011465	 0.00275	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44889	 44890	 0.05306	 0.097186	 0.00168	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44889	 45433	 0.49621	 0.36542	 0.00534	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44889	 90646	 0.13756	 0.1376	 0.00186	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44890	 44891	 0.014064	 0.057479	 0.00116	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44891	 90484	 0.008171	 0.027258	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44892	 44894	 0.010333	 0.0323	 0.00936	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44892	 45167	 0.034661	 0.10784	 0.02252	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88934	 44892	 0.05659	 0.1424	 0.03693	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44892	 90484	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44892	 90484	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90484	 44893	 0.05095	 0.051461	 0.00068	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44895	 44897	 0.011387	 0.040251	 0.00907	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44895	 90485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44895	 90485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44896	 44899	 0.661	 0.52388	 0.0066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44896	 44901	 0.11434	 0.22642	 0.00332	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90485	 44896	 0.098015	 0.12883	 0.00177	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44896	 90599	 0.15009	 0.4307	 0.00663	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44897	 45283	 0.007159	 0.041579	 0.00979	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44897	 90486	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44897	 90486	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44898	 45282	 0.05419	 0.083003	 0.00144	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90485	 44898	 0.23953	 0.1896	 0.00239	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90486	 44898	 0.010748	 0.043085	 0.00111	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44899	 44900	 0.32524	 0.21857	 0.00386	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44900	 44901	 0.14592	 0.1747	 0.00291	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44900	 44905	 0.078973	 0.16163	 0.00398	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44902	 44903	 0.22009	 0.15913	 0.00241	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44903	 45343	 0.3448	 0.27298	 0.00344	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44903	 90490	 0.09981	 0.15291	 0.00215	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44904	 90487	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44905	 44906	 0.26784	 0.21202	 0.00267	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90488	 44905	 0.044663	 0.17722	 0.00506	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44907	 44908	 0.002266	 0.005988	 0.0014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44907	 45316	 0.070812	 0.16464	 0.05025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90487	 44907	 0.006737	 0.018343	 0.00404	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44907	 90489	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44907	 90489	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44908	 90490	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44908	 90490	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44909	 45312	 0.2059	 0.13332	 0.00254	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90489	 44909	 0.2458	 0.19457	 0.00245	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90490	 44909	 0.24789	 0.18785	 0.00259	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44911	 44912	 0.007262	 0.014232	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44911	 44915	 0.015124	 0.017728	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90374	 44911	 0.051232	 0.16908	 0.00274	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44913	 44914	 0.015418	 0.016794	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44913	 44915	 0.004458	 0.011064	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44914	 44917	 0.10564	 0.068395	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44915	 44916	 0.013104	 0.033684	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44915	 44917	 0.14358	 0.11364	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90374	 44916	 0.05777	 0.13681	 0.0025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88960	 44917	 0.053595	 0.13631	 0.00216	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44917	 90492	 0.08477	 0.15528	 0.00268	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88954	 44918	 0.01267	 0.032895	 0.00798	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88958	 44918	 0.012742	 0.033082	 0.00803	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44918	 90491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44918	 90491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88791	 44919	 0.012582	 0.037098	 0.00863	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88958	 44919	 0.012523	 0.067441	 0.01853	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44919	 90492	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44919	 90492	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88960	 44920	 0.16027	 0.11793	 0.00172	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88962	 44920	 0.058533	 0.10721	 0.00185	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90480	 44921	 0.27258	 0.17652	 0.00336	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44921	 90493	 0.31526	 0.2472	 0.00317	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88943	 44922	 0.2059	 0.16297	 0.00205	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44922	 90519	 0.30338	 0.24016	 0.00302	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44923	 44931	 0.025348	 0.075925	 0.01711	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44923	 90493	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44923	 90493	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44924	 45294	 0.12771	 0.2529	 0.00371	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90305	 44924	 0.023304	 0.090659	 0.00151	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44925	 44927	 0.088289	 0.10569	 0.00176	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44925	 45294	 0.37401	 0.24229	 0.00461	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88940	 44926	 0.003394	 0.036374	 0.01163	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44926	 90494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44926	 90494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88941	 44927	 0.037849	 0.12627	 0.002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90494	 44927	 0.015031	 0.038639	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44928	 44929	 0.01023	 0.021922	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88941	 44928	 0.018557	 0.047703	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88969	 44929	 0.01063	 0.030163	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44931	 44936	 0.012065	 0.029077	 0.00821	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44931	 45166	 0.028679	 0.15754	 0.04171	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88945	 44932	 0.25489	 0.20176	 0.00254	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44933	 44936	 0.011488	 0.033871	 0.00788	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44934	 44935	 0.004964	 0.013843	 0.00291	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44935	 44936	 0.003635	 0.009344	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44937	 90495	 0.098761	 0.25392	 0.00393	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44938	 52026	 0.071555	 0.21956	 0.00595	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44938	 52026	 0.071555	 0.21956	 0.00595	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44938	 90495	 0.043678	 0.16993	 0.00284	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44938	 90495	 0.043678	 0.16993	 0.00284	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44939	 45016	 0.03791	 0.15193	 0.03833	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44939	 90495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44939	 90495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44940	 44941	 0.002108	 0.00566	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44940	 44944	 0.001289	 0.003511	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44940	 90496	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44940	 90496	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44941	 44942	 0.0015	 0.004184	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44941	 44946	 0.002674	 0.009174	 0.0022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44942	 44949	 0.002169	 0.005575	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44943	 44950	 0.033018	 0.025881	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44943	 44951	 0.021862	 0.017994	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88961	 44943	 0.028068	 0.022212	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90496	 44943	 0.018662	 0.014769	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44943	 90497	 0.019274	 0.015253	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88981	 44944	 0.000896	 0.00302	 0.00075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44944	 90497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44944	 90497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44945	 44959	 0.001399	 0.003901	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44946	 44948	 0.004003	 0.010898	 0.0024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44946	 44972	 0.003665	 0.012954	 0.00292	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44946	 90498	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44946	 90498	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90498	 44947	 0.03782	 0.02993	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44947	 90499	 0.05468	 0.0354	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44947	 90500	 0.015939	 0.031237	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44948	 44952	 0.006324	 0.022038	 0.00511	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44948	 44969	 0.010951	 0.038168	 0.00885	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44948	 90499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44948	 90499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44949	 44952	 0.001996	 0.006847	 0.00164	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44949	 90500	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44949	 90500	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90500	 44950	 0.021644	 0.015924	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44951	 90501	 0.025144	 0.040134	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44952	 44953	 0.003481	 0.009706	 0.00204	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44952	 44971	 0.003964	 0.021749	 0.00575	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44953	 44971	 0.00295	 0.018305	 0.00443	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88981	 44953	 0.005277	 0.01778	 0.00442	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44953	 90501	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44953	 90501	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44954	 44955	 0.027276	 0.021586	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90497	 44954	 0.015949	 0.029212	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44954	 90504	 0.074166	 0.058695	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44956	 90502	 9.3e-05	 0.007407	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90503	 44956	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44957	 44968	 0.000895	 0.006105	 0.01099	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90502	 44957	 0.000522	 0.003386	 0.00674	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44957	 90504	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44957	 90504	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44958	 44959	 0.001183	 0.003127	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44958	 44965	 0.001643	 0.004411	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44959	 90505	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44959	 90505	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44960	 44961	 0.020571	 0.01628	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90505	 44960	 0.014773	 0.011691	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44961	 44962	 0.015479	 0.010021	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88961	 44961	 0.011037	 0.017617	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44963	 44972	 0.004926	 0.013223	 0.003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44963	 45355	 0.015517	 0.056193	 0.01206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44964	 44965	 0.001277	 0.003283	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90503	 44964	 0.002586	 0.006944	 0.00157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44964	 90506	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44964	 90506	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90506	 44966	 0.02296	 0.02988	 0.00042	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44966	 90507	 0.079225	 0.062699	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90504	 44967	 0.055686	 0.102	 0.00176	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44967	 90508	 0.1709	 0.26186	 0.00368	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44968	 90507	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44968	 90507	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44968	 90670	 0.00877	 0.056985	 0.11368	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44969	 45428	 0.006882	 0.037764	 0.00998	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	44970	 44971	 0.004549	 0.018782	 0.00444	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88958	 44970	 0.006822	 0.041262	 0.01053	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44970	 90508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44970	 90508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88958	 44971	 0.003456	 0.038272	 0.01245	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44971	 90509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44971	 90509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44972	 45355	 0.016644	 0.054292	 0.01442	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44973	 90512	 0.068218	 0.13507	 0.00198	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44974	 90510	 0.063115	 0.16225	 0.00251	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44974	 90514	 0.10453	 0.20699	 0.00304	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44975	 44979	 0.01691	 0.045402	 0.01029	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44975	 44980	 0.022416	 0.060188	 0.01364	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44975	 90510	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44975	 90510	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44976	 44984	 0.42837	 0.27755	 0.00528	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44977	 45321	 0.019674	 0.13629	 0.24256	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88965	 44977	 0.020898	 0.14747	 0.2534	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	44977	 90511	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90512	 44977	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 0	 -30.0	 30.0;
	44978	 44985	 0.016696	 0.044826	 0.01016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90511	 44978	 0.008524	 0.022928	 0.00643	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44978	 90513	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44978	 90513	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44979	 44980	 0.014752	 0.034246	 0.01043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44979	 90514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44979	 90514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44980	 44983	 0.00989	 0.027743	 0.00714	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44981	 45418	 0.11042	 0.36453	 0.00591	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88975	 44981	 0.022335	 0.05011	 0.0008	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	44982	 44989	 0.003455	 0.013581	 0.00355	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	44984	 44988	 0.24558	 0.15903	 0.00303	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90511	 44985	 0.025727	 0.069081	 0.01566	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44985	 90515	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44985	 90515	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90513	 44986	 0.23869	 0.18893	 0.00238	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44987	 45342	 0.11498	 0.26697	 0.00508	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90362	 44987	 0.067833	 0.17439	 0.0027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90380	 44988	 0.37722	 0.29867	 0.00376	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44990	 44994	 0.32436	 0.25679	 0.00323	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44991	 90517	 0.051019	 0.039991	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44992	 45160	 0.037701	 0.16801	 0.00285	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	44992	 90517	 0.037855	 0.10858	 0.00167	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44993	 90516	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90517	 44994	 0.024457	 0.036265	 0.00054	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90308	 44995	 0.095877	 0.22873	 0.00513	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44995	 90518	 0.15339	 0.30377	 0.00446	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44996	 44997	 0.073508	 0.17408	 0.00318	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90309	 44996	 0.2095	 0.2975	 0.0049	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44997	 44999	 0.3568	 0.23112	 0.0044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	44997	 90518	 0.11606	 0.22983	 0.00337	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44998	 45230	 0.043137	 0.21315	 0.05781	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	44998	 45465	 0.051556	 0.1771	 0.0425	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44998	 46650	 0.055191	 0.18962	 0.04552	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	44998	 90518	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	44998	 90518	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45000	 45001	 0.022745	 0.075058	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45000	 45542	 0.09261	 0.16647	 0.00299	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45003	 45004	 0.013061	 0.030319	 0.00924	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45004	 45005	 0.002266	 0.005989	 0.0014	 125.0	 125.0	 125.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45004	 45005	 0.002266	 0.005989	 0.0014	 125.0	 125.0	 125.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88964	 45004	 0.020752	 0.054851	 0.01284	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88964	 45004	 0.020752	 0.054851	 0.01284	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45005	 45006	 0.007497	 0.019463	 0.00472	 138.0	 179.0	 179.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45005	 45006	 0.007497	 0.019463	 0.00472	 138.0	 179.0	 179.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45006	 45187	 0.031102	 0.083523	 0.01894	 144.0	 179.0	 179.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45006	 45187	 0.031102	 0.083523	 0.01894	 144.0	 179.0	 179.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88942	 45007	 0.011624	 0.0353	 0.00773	 137.0	 137.0	 137.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45007	 90519	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45007	 90519	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45008	 45009	 0.034732	 0.037006	 0.00053	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45009	 45010	 0.034625	 0.027402	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45009	 51933	 0.004107	 0.023079	 0.00043	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45011	 51929	 0.067056	 0.22372	 0.00355	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45012	 45014	 0.006014	 0.027078	 0.00721	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45012	 51935	 0.009165	 0.098377	 0.02562	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90516	 45012	 0.030002	 0.14808	 0.0401	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45013	 45160	 0.068745	 0.23488	 0.00511	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45013	 90520	 0.006904	 0.026962	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45014	 45015	 0.014536	 0.05526	 0.01547	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45014	 90520	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45014	 90520	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45015	 45016	 0.015981	 0.055927	 0.01854	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45016	 90521	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45016	 90521	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90516	 45017	 0.059049	 0.15623	 0.03661	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45017	 90522	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45017	 90522	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45018	 45021	 0.053916	 0.11034	 0.00272	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45018	 45323	 0.036026	 0.19197	 0.00337	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45019	 45020	 0.016228	 0.042892	 0.01004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45019	 90523	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45019	 90523	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90523	 45021	 0.026448	 0.0701	 0.00178	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45022	 45130	 0.000381	 0.002669	 0.00454	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45022	 90524	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45022	 90524	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45022	 90526	 0.000183	 0.001231	 0.00227	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45023	 45024	 0.006529	 0.010001	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45023	 45025	 0.015329	 0.018687	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45023	 45138	 0.006719	 0.014398	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45024	 45038	 0.046013	 0.036068	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45025	 45026	 0.022645	 0.017921	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45025	 45037	 0.005088	 0.014593	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45025	 45136	 0.010907	 0.019605	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45026	 90525	 0.022371	 0.01716	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45027	 45055	 0.002707	 0.006284	 0.00191	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45027	 45135	 0.001832	 0.006174	 0.00153	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88946	 45027	 0.002441	 0.012422	 0.0045	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45027	 90525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45027	 90525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90525	 45028	 0.017236	 0.013511	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45029	 45035	 0.020975	 0.016599	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45030	 45045	 0.023305	 0.018443	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45031	 45043	 0.028213	 0.020757	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45031	 90555	 0.030381	 0.023814	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45032	 45043	 0.016613	 0.013147	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45033	 45038	 0.012698	 0.010049	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45034	 45035	 0.002735	 0.0084	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45034	 45040	 0.002061	 0.008248	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45035	 45036	 0.006263	 0.011471	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45035	 45146	 0.013014	 0.030208	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90525	 45035	 0.008098	 0.021408	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45036	 45041	 0.012357	 0.008753	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45037	 45051	 0.001997	 0.007492	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45038	 45155	 0.004427	 0.015816	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45039	 45155	 0.014069	 0.015474	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45040	 90529	 0.001622	 0.007185	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45041	 45042	 0.006836	 0.007446	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45042	 45043	 0.006778	 0.013419	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45042	 45056	 0.002522	 0.013438	 0.00024	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45043	 45044	 0.013406	 0.009691	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45044	 45045	 0.006062	 0.011609	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45045	 90556	 0.00376	 0.014628	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45046	 45131	 0.000225	 0.002471	 0.024	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45046	 90526	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90527	 45046	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90527	 45047	 0.001335	 0.003528	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45047	 90528	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45047	 90528	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45048	 45049	 0.005924	 0.006452	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90528	 45048	 0.002722	 0.006998	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45049	 45050	 0.009348	 0.006758	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45050	 45051	 0.017238	 0.013642	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45051	 45052	 0.008643	 0.00684	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45051	 45053	 0.018345	 0.011877	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45051	 90531	 0.012604	 0.023085	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45051	 90536	 0.017704	 0.031821	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45052	 45060	 0.003052	 0.006042	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45053	 45054	 0.011533	 0.009127	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45053	 45061	 0.004661	 0.009229	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45055	 45066	 0.000548	 0.003873	 0.00106	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45055	 90529	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45055	 90529	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45056	 45069	 0.005471	 0.010831	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90529	 45056	 0.002794	 0.011182	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45057	 45058	 0.001201	 0.002893	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45057	 45074	 0.001871	 0.005248	 0.00135	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90527	 45057	 0.000724	 0.002897	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45058	 45078	 0.002737	 0.007107	 0.00172	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45058	 90530	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45058	 90530	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45059	 45156	 0.002072	 0.004992	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88946	 45059	 0.003415	 0.011139	 0.00296	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90527	 45059	 0.002992	 0.008033	 0.00182	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45059	 90531	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45059	 90531	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45060	 45061	 0.01829	 0.01403	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45060	 45063	 0.001705	 0.005687	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45061	 45065	 0.004004	 0.007196	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45062	 45065	 0.008452	 0.006689	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45063	 90535	 0.017898	 0.013168	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45063	 90558	 0.001981	 0.006082	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45064	 45079	 0.008946	 0.006582	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45065	 45079	 0.009263	 0.006815	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45065	 90536	 0.001561	 0.008314	 0.00015	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45066	 45082	 0.001297	 0.004448	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45066	 45093	 0.000955	 0.003943	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45066	 90532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45066	 90532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45067	 45155	 0.002928	 0.008307	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90532	 45067	 0.00279	 0.005524	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45068	 45069	 0.003452	 0.008743	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45068	 45070	 0.02454	 0.019421	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45068	 90537	 0.004871	 0.018011	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45070	 45071	 0.015486	 0.012255	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45071	 45072	 0.015678	 0.012407	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45072	 45073	 0.004091	 0.010403	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45072	 45095	 0.004684	 0.012042	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45072	 90541	 0.019105	 0.037826	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45073	 90556	 0.009572	 0.018952	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45074	 45157	 0.00081	 0.002139	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45074	 90533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45074	 90533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45075	 45077	 0.016098	 0.01274	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90530	 45075	 0.014704	 0.010818	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45075	 90534	 0.010138	 0.007947	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45076	 45086	 0.001083	 0.003192	 0.00074	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45076	 45157	 0.001297	 0.004054	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45076	 90534	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45076	 90534	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90531	 45077	 0.017874	 0.01315	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45077	 90535	 0.011761	 0.009219	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45078	 45156	 0.001113	 0.002889	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45078	 90535	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45078	 90535	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45080	 90558	 0.010144	 0.008027	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45081	 90536	 0.010425	 0.00825	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45082	 45156	 0.00215	 0.005773	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88946	 45082	 0.000445	 0.002604	 0.00071	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45082	 90536	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45082	 90536	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88947	 45083	 0.007833	 0.005548	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45084	 45094	 0.001125	 0.003861	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45084	 90537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45084	 90537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45085	 90538	 0.011642	 0.009213	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45085	 90539	 0.023291	 0.017136	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45085	 90542	 0.033872	 0.02655	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45086	 45087	 0.000612	 0.002162	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45086	 90538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45086	 90538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45087	 45097	 0.001735	 0.004585	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88946	 45087	 0.003041	 0.010432	 0.0025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45087	 90539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45087	 90539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45088	 45089	 0.00711	 0.008826	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90539	 45088	 0.013314	 0.010537	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45089	 45090	 0.008959	 0.012718	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88947	 45089	 0.014989	 0.029678	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90539	 45089	 0.027661	 0.021682	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45090	 90540	 0.00454	 0.008989	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45091	 45156	 0.001419	 0.004782	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88946	 45091	 0.000356	 0.001886	 0.00063	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45091	 90540	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45091	 90540	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88946	 45092	 0.000857	 0.00239	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45093	 45094	 0.001537	 0.003703	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88946	 45093	 0.000524	 0.003944	 0.00109	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45095	 90541	 0.017273	 0.026461	 0.00037	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45095	 90560	 0.016413	 0.032497	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45096	 45158	 0.00156	 0.004376	 0.00113	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45096	 45399	 0.003699	 0.009775	 0.00229	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45096	 90541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45096	 90541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45097	 45098	 0.001147	 0.004054	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45097	 45099	 0.001123	 0.004412	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45098	 90542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45098	 90542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45100	 45101	 0.01271	 0.019471	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45100	 45368	 0.13297	 0.10423	 0.00134	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45100	 45372	 0.017426	 0.030645	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45101	 45102	 0.006333	 0.020309	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45101	 45106	 0.009209	 0.014106	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45102	 90543	 0.0026	 0.009289	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45102	 90544	 0.024748	 0.018207	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45103	 45104	 0.001142	 0.003185	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45103	 45374	 0.002827	 0.009222	 0.00245	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45103	 90543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45103	 90543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45104	 45153	 0.00428	 0.011312	 0.00265	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45104	 90544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45104	 90544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45105	 45147	 0.020212	 0.022231	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90544	 45105	 0.013957	 0.011488	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45105	 90625	 0.023591	 0.042137	 0.00062	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45106	 45108	 0.02487	 0.018297	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45107	 45108	 0.031863	 0.023033	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45107	 45111	 0.035178	 0.03553	 0.00047	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90544	 45107	 0.004094	 0.023002	 0.00043	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45108	 45109	 0.061927	 0.044767	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45109	 45112	 0.025747	 0.05046	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45110	 45111	 0.036699	 0.027001	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45110	 45116	 0.028999	 0.047535	 0.00084	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45111	 45142	 0.013247	 0.030754	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88947	 45111	 0.029688	 0.11881	 0.00251	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45112	 45113	 0.01086	 0.022825	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45112	 45116	 0.018848	 0.028873	 0.00041	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45113	 45119	 0.018115	 0.03318	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45113	 45133	 0.014957	 0.026884	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45114	 45115	 0.014301	 0.032855	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45114	 45120	 0.010742	 0.024938	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45115	 45116	 0.012327	 0.028618	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45116	 45117	 0.007799	 0.025113	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45117	 90545	 0.005162	 0.022876	 0.00069	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45118	 45119	 0.017073	 0.011053	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45119	 90552	 0.007196	 0.032066	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90286	 45120	 0.010287	 0.024359	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45121	 45123	 0.007426	 0.017242	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45121	 90545	 0.008103	 0.023241	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45124	 45127	 0.00451	 0.01735	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45124	 90546	 0.003032	 0.015336	 0.00027	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90287	 45126	 0.000883	 0.005959	 0.01097	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45126	 90545	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45126	 90545	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45126	 90547	 0.000325	 0.002169	 0.00409	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90545	 45127	 0.01175	 0.027278	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45127	 90548	 0.003455	 0.015394	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45128	 45129	 6.1e-05	 0.000676	 0.00638	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45128	 45131	 9.5e-05	 0.001094	 0.00959	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45128	 90546	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45128	 90546	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45129	 90547	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45130	 90549	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45130	 90549	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45130	 90550	 0.000285	 0.00194	 0.00349	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45131	 90550	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45132	 45137	 0.016182	 0.022078	 0.00039	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45133	 90553	 0.004897	 0.01298	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45134	 45135	 0.002307	 0.005929	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45134	 45148	 0.008567	 0.023891	 0.00501	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45134	 90553	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45134	 90553	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45135	 90554	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45135	 90554	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90553	 45136	 0.017985	 0.024516	 0.00054	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90554	 45136	 0.022977	 0.018183	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45137	 45138	 0.015163	 0.013587	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90524	 45137	 0.020604	 0.040381	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90549	 45138	 0.004214	 0.016393	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90524	 45139	 0.016082	 0.011832	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90524	 45140	 0.025272	 0.016361	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45141	 45142	 0.004344	 0.015199	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45141	 45145	 0.05477	 0.043344	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88947	 45141	 0.037838	 0.10853	 0.00167	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90553	 45141	 0.002308	 0.011081	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90525	 45143	 0.025835	 0.020251	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90525	 45144	 0.03964	 0.031371	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45145	 45146	 0.027247	 0.026659	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45145	 45147	 0.036479	 0.028869	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45147	 45152	 0.014909	 0.015059	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45147	 90556	 0.037854	 0.074949	 0.0011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45148	 45154	 0.001143	 0.003112	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45148	 90555	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45148	 90555	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45149	 45158	 0.003936	 0.015471	 0.00405	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45149	 45393	 0.001786	 0.004638	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45149	 90556	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45149	 90556	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45150	 90628	 0.023962	 0.018963	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45151	 45394	 0.009893	 0.01727	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90541	 45151	 0.006289	 0.018037	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45152	 90557	 0.006179	 0.011318	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45153	 45154	 0.001844	 0.004636	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45153	 45389	 0.001404	 0.003914	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45153	 90557	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45153	 90557	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88947	 45155	 0.005001	 0.02843	 0.00051	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90529	 45155	 0.01256	 0.012825	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45156	 90558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45156	 90558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45157	 90559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45157	 90559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90350	 45158	 0.007981	 0.047547	 0.01251	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45158	 90560	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45158	 90560	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45159	 45160	 0.068531	 0.2063	 0.00403	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90522	 45159	 0.10407	 0.2954	 0.00464	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45161	 45172	 0.017506	 0.068817	 0.01801	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45161	 90561	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45161	 90561	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45162	 45164	 0.006038	 0.037522	 0.01059	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45162	 45170	 0.005298	 0.028229	 0.00792	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45162	 90562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45162	 90562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45163	 45165	 0.096432	 0.32178	 0.0051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90561	 45163	 0.18856	 0.20542	 0.0028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90562	 45163	 0.034654	 0.044718	 0.0009	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45164	 45166	 0.007613	 0.059345	 0.01775	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90479	 45165	 0.075979	 0.25078	 0.00406	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45165	 90563	 0.16041	 0.22361	 0.00382	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45166	 90563	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45166	 90563	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45167	 45168	 0.015357	 0.048007	 0.01391	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45167	 45293	 0.027401	 0.072432	 0.01696	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45167	 90564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45167	 90564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45168	 45171	 0.008544	 0.036163	 0.00814	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45169	 45449	 0.052017	 0.20641	 0.0059	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90470	 45169	 0.055843	 0.17134	 0.00464	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45170	 45171	 0.004616	 0.029234	 0.00793	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45172	 45293	 0.014991	 0.050515	 0.01256	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45173	 45278	 0.002244	 0.022681	 0.00667	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45174	 45181	 0.004703	 0.01883	 0.00474	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45175	 45184	 0.009691	 0.038803	 0.00978	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45176	 45182	 0.00433	 0.015678	 0.00336	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45176	 45328	 0.015966	 0.056441	 0.01272	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45177	 45180	 0.005592	 0.013242	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45177	 90565	 0.015687	 0.032102	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45178	 45179	 0.024743	 0.017526	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45179	 90565	 0.032312	 0.021705	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90349	 45180	 0.18635	 0.1961	 0.00287	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45181	 90565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45181	 90565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45182	 45184	 0.003471	 0.009011	 0.00219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45182	 90566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45182	 90566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45183	 45185	 0.03259	 0.025545	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90566	 45183	 0.021716	 0.034663	 0.0008	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45184	 90567	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45184	 90567	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90567	 45185	 0.01495	 0.029599	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90519	 45186	 0.15311	 0.22316	 0.00504	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45186	 90568	 0.046857	 0.092776	 0.00136	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45187	 45188	 0.010154	 0.026836	 0.00628	 137.0	 180.0	 180.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45187	 45188	 0.010154	 0.026836	 0.00628	 137.0	 180.0	 180.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45187	 90568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45187	 90568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45188	 53258	 0.018511	 0.06544	 0.01475	 212.0	 212.0	 212.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45189	 45192	 0.15834	 0.24261	 0.00341	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45189	 90569	 0.063319	 0.1352	 0.00305	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45190	 90569	 0.28865	 0.2285	 0.00288	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90516	 45191	 0.067339	 0.23523	 0.05471	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45191	 90569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45191	 90569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90569	 45193	 0.47857	 0.37903	 0.00477	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45194	 45198	 0.035949	 0.025987	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45194	 90571	 0.040775	 0.026398	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45195	 45199	 0.004552	 0.016088	 0.00363	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45195	 45227	 0.006511	 0.027556	 0.0062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45196	 45197	 0.002809	 0.009791	 0.00227	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45196	 90570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45196	 90570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45197	 45226	 0.004466	 0.017554	 0.00459	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45197	 45258	 0.003573	 0.009442	 0.00221	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45198	 90572	 0.027162	 0.021291	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45199	 45200	 0.001633	 0.005915	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45199	 90571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45199	 90571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45200	 45203	 0.001888	 0.004991	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45200	 90572	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45200	 90572	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45201	 45207	 0.013579	 0.01479	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90570	 45201	 0.061566	 0.062184	 0.00082	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45202	 45208	 0.001873	 0.005223	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45202	 45258	 0.000854	 0.002293	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45202	 90573	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45202	 90573	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45203	 45206	 0.000782	 0.002011	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45203	 90574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45203	 90574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45204	 45207	 0.006712	 0.008822	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45204	 90576	 0.003768	 0.006798	 0.0001	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45205	 90575	 0.01238	 0.00895	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45205	 90576	 0.011137	 0.008194	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45206	 45208	 0.00118	 0.003169	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45206	 90575	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45206	 90575	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45207	 90577	 0.017724	 0.01304	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45208	 45210	 0.001831	 0.004917	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45208	 90576	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45208	 90576	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45209	 90577	 0.013964	 0.010945	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45210	 45211	 0.00115	 0.003038	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45210	 90577	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45210	 90577	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45211	 45257	 0.001607	 0.004171	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45212	 45727	 0.04252	 0.030737	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45213	 45225	 0.096625	 0.069852	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45213	 90587	 0.049242	 0.038969	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45214	 90587	 0.021935	 0.016138	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45215	 90587	 0.022903	 0.021477	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45215	 90588	 0.027171	 0.02548	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45216	 45218	 0.020118	 0.016558	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45216	 45220	 0.046747	 0.036995	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45216	 45223	 0.024661	 0.019331	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45217	 45218	 0.01995	 0.015788	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45218	 45219	 0.012668	 0.009321	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45218	 90588	 0.037437	 0.029627	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45220	 45224	 0.046854	 0.047324	 0.00063	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45220	 90578	 0.016096	 0.031545	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45221	 45222	 0.004985	 0.013174	 0.00308	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45221	 45735	 0.009222	 0.025716	 0.0054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45221	 90578	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45221	 90578	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45222	 90579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45222	 90579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45223	 45224	 0.022163	 0.039989	 0.00058	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45223	 90588	 0.082263	 0.064483	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90579	 45224	 0.073275	 0.05799	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45225	 45229	 0.079023	 0.18348	 0.00273	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90570	 45225	 0.06458	 0.053156	 0.00108	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45226	 45228	 0.014307	 0.042182	 0.00981	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90476	 45226	 0.027567	 0.0946	 0.02267	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90476	 45227	 0.010827	 0.052549	 0.01201	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45228	 45232	 0.023342	 0.078668	 0.01956	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45229	 90580	 0.039463	 0.15353	 0.00256	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45230	 45236	 0.028417	 0.1695	 0.04467	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90460	 45230	 0.025996	 0.19617	 0.05457	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45230	 90580	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45230	 90580	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45231	 90581	 0.41406	 0.29952	 0.00454	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88972	 45232	 0.020154	 0.07125	 0.01606	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45233	 45237	 0.001205	 0.003929	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88980	 45234	 0.009213	 0.021816	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45234	 90582	 0.032533	 0.051929	 0.0012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45235	 45236	 0.001413	 0.005657	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45235	 45237	 0.001645	 0.005115	 0.00107	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45235	 45238	 0.006042	 0.020727	 0.00497	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45236	 45238	 0.006881	 0.020288	 0.00472	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90460	 45236	 0.020176	 0.13006	 0.03413	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45236	 90581	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45236	 90581	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45238	 45239	 0.006505	 0.02686	 0.00636	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45238	 90582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45238	 90582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45239	 45240	 0.006025	 0.024122	 0.00608	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45240	 45242	 0.004233	 0.017225	 0.0042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88985	 45241	 0.020842	 0.016494	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45242	 45243	 0.001258	 0.005193	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45243	 45246	 0.002822	 0.010266	 0.00314	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45243	 90583	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45243	 90583	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45244	 45245	 0.077499	 0.061332	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90583	 45244	 0.025594	 0.05941	 0.00113	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45246	 45247	 0.004334	 0.017034	 0.00446	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45247	 90584	 0.00665	 0.026625	 0.00671	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45248	 90584	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45248	 90584	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45249	 45253	 0.27307	 0.21616	 0.00272	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88973	 45249	 0.070667	 0.071377	 0.00095	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45250	 45251	 0.00862	 0.039548	 0.01013	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88972	 45250	 0.002671	 0.012252	 0.00314	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45251	 45254	 0.027013	 0.084028	 0.01754	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45251	 90585	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45251	 90585	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90582	 45252	 0.36734	 0.26569	 0.00403	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45254	 45256	 0.058368	 0.15442	 0.03619	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45254	 90586	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45254	 90586	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90585	 45255	 0.30278	 0.22284	 0.00326	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90586	 45255	 0.086925	 0.17212	 0.00253	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45257	 45259	 0.0034	 0.008193	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45257	 45735	 0.002809	 0.009929	 0.00224	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45257	 90587	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45257	 90587	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45259	 90588	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45259	 90588	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45260	 45261	 0.001466	 0.006988	 0.00202	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45260	 90589	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45260	 90589	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45261	 45276	 0.006846	 0.01838	 0.00417	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45261	 90590	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45261	 90590	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45262	 45264	 0.039133	 0.030675	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88974	 45262	 0.02967	 0.058149	 0.00087	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90590	 45262	 0.025514	 0.028062	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45263	 45265	 0.017317	 0.031245	 0.00045	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90589	 45263	 0.028285	 0.028569	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45264	 90594	 0.022723	 0.024993	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45265	 90594	 0.013775	 0.045951	 0.00073	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45266	 90591	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45266	 90591	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45267	 45270	 0.005058	 0.014103	 0.00296	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90591	 45267	 0.004762	 0.012965	 0.00286	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45267	 90592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45267	 90592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88986	 45268	 0.01415	 0.018598	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90592	 45268	 0.074288	 0.058231	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45271	 45272	 0.006661	 0.022852	 0.00547	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45272	 45279	 0.003063	 0.022761	 0.00868	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90591	 45272	 0.011936	 0.043224	 0.00927	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90592	 45273	 0.061924	 0.043865	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45273	 90593	 0.062463	 0.049433	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45273	 90594	 0.083548	 0.06612	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45274	 45276	 0.001579	 0.006206	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45274	 45277	 0.001767	 0.010525	 0.00277	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45274	 90593	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45274	 90593	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88974	 45275	 0.06576	 0.052042	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45275	 90594	 0.047683	 0.03087	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45276	 90594	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45276	 90594	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45277	 45278	 0.003708	 0.02172	 0.00592	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45278	 90595	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45278	 90595	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45280	 90596	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45280	 90596	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88934	 45281	 0.006228	 0.059802	 0.0174	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45281	 90597	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45281	 90597	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90597	 45282	 0.047335	 0.10875	 0.00165	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45283	 45287	 0.004451	 0.024511	 0.00885	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45284	 45291	 0.01045	 0.028055	 0.00636	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88934	 45284	 0.005605	 0.033644	 0.01019	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90293	 45284	 0.013226	 0.034956	 0.00818	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45285	 45429	 0.002368	 0.022737	 0.00661	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88934	 45285	 0.002756	 0.033585	 0.0111	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45285	 90598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45285	 90598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88935	 45286	 0.040277	 0.13437	 0.00213	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90597	 45286	 0.028861	 0.12861	 0.00218	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90598	 45286	 0.018799	 0.047809	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45286	 90599	 0.03524	 0.11756	 0.00186	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88934	 45287	 0.001247	 0.013455	 0.00385	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45287	 90599	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45287	 90599	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45289	 45429	 0.001608	 0.011567	 0.00307	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45289	 90600	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45289	 90600	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88979	 45290	 0.03766	 0.054876	 0.00124	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90600	 45290	 0.01853	 0.039709	 0.0007	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45291	 45299	 0.004636	 0.012622	 0.00278	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45291	 90601	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45291	 90601	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45292	 45295	 0.00509	 0.032242	 0.00875	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45296	 45324	 0.018584	 0.014567	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90601	 45297	 0.018026	 0.030365	 0.00043	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45298	 45299	 0.002469	 0.00573	 0.00175	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45298	 45300	 0.002602	 0.006876	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45300	 45319	 0.005182	 0.013696	 0.00321	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45300	 90602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45300	 90602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45301	 45302	 0.013046	 0.013049	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45301	 90603	 0.008861	 0.017545	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45302	 45304	 0.011478	 0.012502	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45303	 45306	 0.002749	 0.007379	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90293	 45303	 0.004754	 0.017213	 0.00369	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45303	 90603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45303	 90603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45304	 45324	 0.01059	 0.020966	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45306	 45319	 0.005172	 0.014082	 0.0031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45306	 90604	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45306	 90604	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45307	 45308	 0.051082	 0.056185	 0.00075	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90603	 45308	 0.016889	 0.047927	 0.00075	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45309	 90606	 0.051335	 0.14568	 0.00229	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45310	 45312	 0.1785	 0.13134	 0.00192	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45310	 90608	 0.049575	 0.1422	 0.00219	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45311	 45312	 0.17573	 0.1245	 0.00197	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45311	 45313	 0.14557	 0.16012	 0.00214	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45311	 90608	 0.071495	 0.20508	 0.00315	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45313	 45314	 0.13163	 0.10318	 0.00132	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45314	 45323	 0.082224	 0.13126	 0.00302	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45314	 45347	 0.15424	 0.12207	 0.00154	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45314	 90608	 0.23052	 0.40568	 0.00763	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45315	 90605	 0.34051	 0.26958	 0.00339	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45316	 90605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45316	 90605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45317	 45320	 0.08049	 0.15937	 0.00234	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45318	 45433	 0.3408	 0.24152	 0.00382	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45318	 90608	 0.18438	 0.20087	 0.00274	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45319	 90606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45319	 90606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45319	 90607	 0.005063	 0.019243	 0.00539	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90605	 45320	 0.09194	 0.19632	 0.00443	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45320	 90608	 0.039508	 0.078224	 0.00115	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88933	 45321	 0.003408	 0.037212	 0.07221	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45321	 90607	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90608	 45321	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90602	 45322	 0.037977	 0.097625	 0.00151	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90294	 45324	 0.004722	 0.026531	 0.00049	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90360	 45325	 0.1104	 0.10354	 0.0016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45325	 90609	 0.038998	 0.10337	 0.00262	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45327	 90609	 0.0595	 0.047088	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45328	 45330	 0.002385	 0.008636	 0.00185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45328	 90609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45328	 90609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45329	 45330	 0.006379	 0.026338	 0.00623	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45329	 45332	 0.006376	 0.035149	 0.00822	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45330	 45363	 0.017149	 0.062103	 0.01333	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45330	 90610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45330	 90610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90610	 45331	 0.02673	 0.020952	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45332	 90611	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45332	 90611	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45333	 45334	 0.00978	 0.026627	 0.00587	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45333	 45339	 0.036068	 0.090702	 0.02351	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45333	 90612	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45333	 90612	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45334	 90613	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45334	 90613	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88987	 45335	 0.12275	 0.35218	 0.00542	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90613	 45335	 0.060007	 0.15864	 0.00288	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45335	 90614	 0.058854	 0.2623	 0.00446	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45335	 90615	 0.14201	 0.22673	 0.00522	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45336	 90614	 0.096285	 0.22804	 0.00417	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88970	 45337	 0.032702	 0.021967	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45337	 90614	 0.097667	 0.077295	 0.00097	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45338	 90614	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45338	 90614	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45339	 90615	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45339	 90615	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45340	 45345	 0.55451	 0.43511	 0.00559	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45340	 45357	 0.13498	 0.2673	 0.00392	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45341	 45342	 0.22415	 0.21025	 0.00325	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45341	 45343	 0.10922	 0.25361	 0.00377	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45341	 45358	 0.049592	 0.14928	 0.00292	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45342	 45345	 0.069647	 0.17905	 0.00277	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45344	 45345	 0.15852	 0.12546	 0.00158	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45344	 45347	 0.19116	 0.1513	 0.00191	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45345	 45346	 0.21958	 0.16846	 0.00226	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90488	 45345	 0.67346	 0.43689	 0.00831	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45348	 45349	 0.11644	 0.27039	 0.00402	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45348	 45418	 0.11051	 0.35458	 0.00878	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90612	 45348	 0.16987	 0.34784	 0.00856	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45350	 45535	 0.010441	 0.037807	 0.00811	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89003	 45350	 0.00968	 0.034216	 0.00771	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45350	 90616	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45350	 90616	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45351	 45354	 0.20621	 0.13352	 0.00254	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88995	 45351	 0.1976	 0.15491	 0.00199	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45352	 90617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45352	 90617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90507	 45353	 0.098177	 0.22796	 0.00339	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90617	 45353	 0.19582	 0.21542	 0.00288	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45354	 90618	 0.078361	 0.1368	 0.00212	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88994	 45355	 0.025358	 0.063757	 0.01652	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45355	 90618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45355	 90618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45356	 45357	 0.33724	 0.21844	 0.00416	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45357	 45358	 0.06194	 0.15924	 0.00246	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90512	 45358	 0.1028	 0.29491	 0.00454	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90513	 45358	 0.099842	 0.25396	 0.00402	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45359	 45363	 0.013889	 0.03606	 0.00875	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90303	 45359	 0.013734	 0.078092	 0.02261	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45360	 45361	 0.086923	 0.15625	 0.00281	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45361	 90619	 0.05279	 0.034176	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90478	 45362	 0.24104	 0.36941	 0.00519	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90609	 45362	 0.13698	 0.20053	 0.0031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45362	 90619	 0.010471	 0.026917	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90371	 45363	 0.022198	 0.12188	 0.03225	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45363	 90619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45363	 90619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45364	 90620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45364	 90620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45365	 45366	 0.056934	 0.041157	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45365	 45367	 0.016279	 0.037794	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90318	 45365	 0.042994	 0.081259	 0.00131	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90620	 45365	 0.012014	 0.025745	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45367	 45368	 0.021664	 0.049545	 0.00121	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45368	 45369	 0.069428	 0.046637	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45368	 90623	 0.044891	 0.17272	 0.00295	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45369	 45372	 0.019286	 0.044768	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45370	 45371	 0.021674	 0.095496	 0.00166	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45370	 46413	 0.14577	 0.14581	 0.00197	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45371	 90622	 0.020176	 0.1075	 0.00189	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45372	 90621	 0.005739	 0.03229	 0.0007	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45373	 90621	 0.019562	 0.02571	 0.00035	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45373	 90625	 0.039597	 0.031038	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45374	 45375	 0.001973	 0.010265	 0.00302	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45374	 90621	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45374	 90621	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45375	 45379	 0.002236	 0.013423	 0.00406	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45376	 90622	 0.055739	 0.044111	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45377	 45388	 0.018989	 0.048814	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45377	 90623	 0.014936	 0.058104	 0.00097	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45378	 45390	 0.016184	 0.041601	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45378	 90624	 0.010193	 0.057941	 0.00105	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45379	 45380	 0.001303	 0.005217	 0.00131	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45379	 45381	 0.00158	 0.005507	 0.00128	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45380	 90622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45380	 90622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45381	 90623	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45381	 90623	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45382	 45384	 0.007556	 0.018496	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90623	 45382	 0.009522	 0.019486	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45383	 90624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45383	 90624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45384	 45387	 0.007846	 0.00615	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88936	 45384	 0.005844	 0.022736	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88936	 45385	 0.012923	 0.0196	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88936	 45386	 0.012945	 0.010244	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45388	 90625	 0.00698	 0.020019	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45388	 90626	 0.014493	 0.023133	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45389	 90625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45389	 90625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45390	 90626	 0.007131	 0.016556	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45391	 45393	 0.001546	 0.004014	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45391	 45396	 0.002295	 0.006969	 0.00153	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45392	 45393	 0.001498	 0.004176	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45392	 90626	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45392	 90626	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45394	 90627	 0.030149	 0.021356	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45395	 45399	 0.001544	 0.009595	 0.00271	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88950	 45395	 0.002648	 0.015612	 0.01271	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45396	 45399	 0.002897	 0.010491	 0.00225	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45396	 90627	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45396	 90627	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45397	 45398	 0.017272	 0.013669	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90627	 45397	 0.029113	 0.02142	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45398	 45402	 0.021045	 0.023146	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45399	 90628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45399	 90628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45400	 45402	 0.037195	 0.029436	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90628	 45400	 0.010648	 0.019502	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45401	 45403	 0.033641	 0.026623	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90628	 45401	 0.025197	 0.019751	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45402	 45404	 0.055667	 0.043635	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45402	 45405	 0.011349	 0.032205	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45403	 45405	 0.026707	 0.019649	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88951	 45405	 0.013548	 0.092998	 0.0017	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45406	 45407	 0.056244	 0.10772	 0.00169	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45406	 46530	 0.07408	 0.058627	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88951	 45407	 0.029504	 0.098426	 0.00156	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45408	 45410	 0.002161	 0.007281	 0.00181	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45408	 90629	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45408	 90629	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45408	 90632	 0.00267	 0.007995	 0.0018	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88951	 45409	 0.035406	 0.03781	 0.0008	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45409	 90631	 0.032163	 0.025211	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45410	 45411	 0.001567	 0.005375	 0.00129	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45410	 90630	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45410	 90630	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88950	 45411	 0.002134	 0.007436	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45411	 90631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45411	 90631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45412	 90632	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45412	 90632	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45412	 90633	 0.000768	 0.004984	 0.00993	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45413	 90633	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45414	 45415	 0.002835	 0.020946	 0.00605	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88963	 45415	 0.013658	 0.068634	 0.01787	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45415	 90635	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45415	 90635	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90635	 45416	 0.017926	 0.059156	 0.00096	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45417	 45418	 0.11435	 0.12213	 0.00258	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45418	 51994	 0.0063	 0.022505	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45418	 51994	 0.0063	 0.022505	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45419	 45420	 0.067378	 0.15285	 0.00305	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90618	 45419	 0.078551	 0.22533	 0.00347	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45420	 45422	 0.034026	 0.044721	 0.00061	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45420	 45537	 0.1718	 0.14143	 0.00287	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45420	 90637	 0.12796	 0.09251	 0.0014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45421	 45424	 0.001608	 0.006438	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45421	 45427	 0.004369	 0.037473	 0.01067	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45421	 90636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45421	 90636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45422	 45423	 0.005643	 0.016014	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90636	 45422	 0.008106	 0.043188	 0.00076	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45423	 90637	 0.017734	 0.035113	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45424	 45425	 0.002748	 0.011183	 0.00272	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45425	 90637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45425	 90637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45425	 90783	 0.03668	 0.096978	 0.02271	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90637	 45426	 0.14989	 0.15141	 0.00201	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45427	 45428	 0.005478	 0.033682	 0.00971	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90367	 45427	 0.006958	 0.036202	 0.01066	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45428	 90638	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45428	 90638	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45429	 90639	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45429	 90639	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45430	 45431	 0.002053	 0.010695	 0.0028	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45430	 45432	 0.002062	 0.015453	 0.00377	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88934	 45431	 0.00389	 0.022115	 0.0064	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45432	 45439	 0.005595	 0.025668	 0.00658	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45432	 90640	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45432	 90640	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88935	 45433	 0.04599	 0.084237	 0.00145	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45434	 45435	 0.009068	 0.024345	 0.00552	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88934	 45434	 0.011565	 0.047065	 0.01147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45435	 45445	 0.017236	 0.046276	 0.01049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45436	 45438	 0.003962	 0.01677	 0.00377	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45436	 45444	 0.01726	 0.049998	 0.01206	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45436	 90641	 0.001785	 0.007954	 0.00216	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88933	 45437	 0.001587	 0.01963	 0.03938	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45437	 90641	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90642	 45437	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45438	 45444	 0.020579	 0.053431	 0.01297	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88934	 45438	 0.005258	 0.039074	 0.0149	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45439	 45440	 0.005039	 0.019154	 0.00536	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45440	 90643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45440	 90643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90641	 45441	 0.00235	 0.01907	 0.00607	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45441	 90644	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45441	 90644	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45442	 45443	 0.031303	 0.092052	 0.00189	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90429	 45442	 0.027876	 0.12213	 0.00263	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90642	 45442	 0.043496	 0.16922	 0.00283	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45443	 90645	 0.034449	 0.089282	 0.00169	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45444	 45445	 0.007284	 0.024988	 0.00599	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45444	 90645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45444	 90645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45445	 90646	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45445	 90646	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45446	 45448	 0.065288	 0.25403	 0.00424	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90470	 45446	 0.1423	 0.43728	 0.00821	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45447	 45448	 0.047906	 0.27238	 0.00493	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88955	 45447	 0.34299	 0.52069	 0.00747	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45447	 93686	 0.044026	 0.13507	 0.00366	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45447	 93686	 0.044026	 0.13507	 0.00366	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90475	 45448	 0.15897	 0.19737	 0.0043	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90479	 45449	 0.047003	 0.26724	 0.00484	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45450	 45452	 0.19674	 0.14477	 0.00212	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45450	 46841	 0.12746	 0.11954	 0.00185	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45451	 45453	 0.052772	 0.13566	 0.0021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45452	 45453	 0.22753	 0.17838	 0.00229	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45453	 46007	 0.31545	 0.22812	 0.00346	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45454	 45455	 0.049694	 0.12775	 0.00198	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45454	 45856	 0.051596	 0.13122	 0.00208	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45455	 45456	 0.17326	 0.13713	 0.00173	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45455	 46007	 0.12251	 0.17077	 0.00292	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45456	 45576	 0.21497	 0.17015	 0.00214	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45457	 45458	 0.2291	 0.16859	 0.00247	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45458	 45460	 0.033354	 0.14782	 0.00444	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45460	 45461	 0.031225	 0.17751	 0.00321	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45461	 45825	 0.63695	 0.46116	 0.00699	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45461	 90930	 0.057326	 0.39368	 0.00718	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45462	 90930	 0.31061	 0.24589	 0.0031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45463	 45474	 0.018398	 0.066949	 0.0205	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45464	 90648	 0.16814	 0.10887	 0.00207	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45465	 45468	 0.028603	 0.076807	 0.01741	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45465	 90647	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45465	 90647	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45466	 45467	 0.21136	 0.1673	 0.00211	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90647	 45466	 0.082428	 0.14874	 0.00215	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45467	 45469	 0.14781	 0.10876	 0.00159	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45467	 45471	 0.31234	 0.24726	 0.00311	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90647	 45467	 0.16595	 0.20605	 0.00449	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45467	 90648	 0.10743	 0.085018	 0.00107	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45468	 45559	 0.067476	 0.18843	 0.03962	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45468	 46650	 0.028499	 0.068695	 0.0194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45468	 90648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45468	 90648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45469	 45470	 0.07918	 0.079976	 0.00106	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90648	 45469	 0.008555	 0.028538	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45470	 46525	 0.26784	 0.21202	 0.00267	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45471	 45472	 0.12262	 0.17871	 0.00404	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45471	 45739	 0.078827	 0.183	 0.00348	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45471	 46416	 0.11045	 0.2165	 0.00325	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45472	 45473	 0.093827	 0.1032	 0.00138	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45473	 90960	 0.35786	 0.28063	 0.0036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45474	 45476	 0.015587	 0.053474	 0.01281	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45475	 45476	 0.022723	 0.060061	 0.01406	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45475	 45736	 0.032901	 0.076398	 0.02328	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45475	 90649	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45475	 90649	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45476	 90650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45476	 90650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45477	 45478	 0.042564	 0.20783	 0.00436	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90649	 45477	 0.10085	 0.28933	 0.00445	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45478	 46558	 0.043115	 0.19214	 0.00326	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45479	 45489	 8.7e-05	 0.000969	 0.00905	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45479	 45510	 0.000139	 0.001931	 0.01909	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45479	 45510	 0.000139	 0.001931	 0.01909	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45479	 46337	 0.006013	 0.067446	 0.64292	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45479	 90651	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45479	 90651	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45480	 45482	 0.003337	 0.018967	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45480	 45483	 0.003238	 0.009933	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90651	 45480	 0.003531	 0.02007	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45481	 45484	 0.005731	 0.009147	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45481	 45532	 0.006931	 0.013274	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45482	 90658	 0.006187	 0.031299	 0.00054	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45483	 45484	 0.009181	 0.018178	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45483	 45485	 0.009678	 0.016164	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45484	 45486	 0.005568	 0.008887	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45485	 45487	 0.019438	 0.015236	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45485	 45490	 0.010046	 0.0184	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45486	 45487	 0.004313	 0.011088	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45486	 45522	 0.025443	 0.020135	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45487	 90652	 0.002257	 0.009692	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45488	 45493	 0.001387	 0.003665	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89012	 45488	 0.000868	 0.003674	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45488	 90652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45488	 90652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45488	 90653	 0.003129	 0.008518	 0.00188	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45489	 90653	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45490	 45492	 0.014358	 0.011363	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90652	 45490	 0.012806	 0.014085	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45490	 90656	 0.011409	 0.011523	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45491	 45502	 0.006808	 0.017676	 0.00429	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45491	 45517	 0.003252	 0.008174	 0.00212	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90653	 45491	 0.000962	 0.003301	 0.00079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45491	 90655	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45491	 90655	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90655	 45492	 0.008667	 0.008754	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45493	 90656	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45493	 90656	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90656	 45494	 0.015664	 0.012396	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45495	 45502	 0.005544	 0.015459	 0.00324	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45495	 45517	 0.002697	 0.007241	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90653	 45495	 0.003849	 0.010333	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90655	 45496	 0.0251	 0.018467	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45497	 45498	 0.048791	 0.031587	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45497	 45500	 0.014447	 0.01589	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90655	 45497	 0.008266	 0.027277	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45498	 90781	 0.30507	 0.21617	 0.00342	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45499	 45507	 0.007525	 0.017468	 0.00532	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90653	 45499	 0.006536	 0.01643	 0.00426	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45500	 45501	 0.028349	 0.020857	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45501	 90659	 0.018065	 0.033088	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45502	 45513	 0.011892	 0.031927	 0.00724	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45502	 45515	 0.003277	 0.008661	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45503	 45521	 0.001215	 0.004774	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45504	 45505	 0.02228	 0.022504	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89000	 45504	 0.00473	 0.008663	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45505	 90663	 0.020024	 0.046489	 0.00069	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45505	 90664	 0.029262	 0.097617	 0.00155	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45505	 90913	 0.14251	 0.21606	 0.0045	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45506	 45526	 0.005427	 0.022084	 0.00538	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45507	 45897	 0.013315	 0.035191	 0.00824	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45508	 45509	 0.069135	 0.054713	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45508	 90658	 0.11465	 0.081214	 0.00128	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45509	 90665	 0.10066	 0.074059	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45510	 90657	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45511	 45512	 0.049321	 0.034937	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90658	 45511	 0.013061	 0.023475	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45513	 45898	 0.014714	 0.038201	 0.00927	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45514	 90659	 0.04639	 0.09185	 0.00135	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45515	 45516	 0.005144	 0.013594	 0.00318	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88990	 45515	 0.03633	 0.097572	 0.02212	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45516	 45521	 0.001859	 0.007566	 0.00184	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45516	 90659	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45516	 90659	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45517	 45518	 0.001146	 0.003076	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89012	 45517	 0.000753	 0.00296	 0.00077	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45518	 90660	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45518	 90660	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45519	 45520	 0.003916	 0.003099	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89000	 45519	 0.015563	 0.031983	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90660	 45519	 0.007874	 0.01828	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45519	 90661	 0.022837	 0.014785	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45521	 90661	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45521	 90661	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45523	 45532	 0.016114	 0.031904	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45523	 90663	 0.007614	 0.022918	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45524	 90662	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45524	 90662	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45525	 45529	 0.005008	 0.013634	 0.003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90662	 45525	 0.001678	 0.006828	 0.00166	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45525	 90663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45525	 90663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45526	 90664	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45526	 90664	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90664	 45527	 0.13381	 0.089892	 0.00159	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45528	 46323	 0.029341	 0.073775	 0.01912	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45528	 46371	 0.046613	 0.12327	 0.02888	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90653	 45528	 0.017523	 0.054499	 0.01137	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90657	 45528	 0.012479	 0.032399	 0.00786	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45528	 90665	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45528	 90665	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45529	 46371	 0.041713	 0.1103	 0.02583	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90662	 45529	 0.007638	 0.0192	 0.00497	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45529	 90666	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45529	 90666	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45530	 45531	 0.029854	 0.023626	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45530	 46378	 0.14587	 0.10733	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45531	 45532	 0.006277	 0.011497	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89013	 45532	 0.020146	 0.05717	 0.0009	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45533	 45534	 0.00147	 0.009921	 0.01827	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45533	 45765	 0.002637	 0.023073	 0.04207	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45533	 90667	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45533	 90667	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45533	 90670	 0.001008	 0.015721	 0.03378	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45534	 90668	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45534	 90668	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45535	 46397	 0.014642	 0.058629	 0.01477	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45535	 90669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45535	 90669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45536	 45750	 0.001226	 0.021407	 0.23188	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45536	 90670	 0.000119	 0.009523	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45537	 46610	 0.053296	 0.11379	 0.00257	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90671	 45537	 0.036473	 0.17799	 0.00307	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45538	 45540	 0.14663	 0.18925	 0.0038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45538	 90991	 0.63133	 0.44791	 0.00708	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45539	 46651	 0.21521	 0.17034	 0.00214	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45540	 45541	 0.15766	 0.11601	 0.0017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45540	 45542	 0.11186	 0.2215	 0.00325	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45541	 45542	 0.087684	 0.17362	 0.00255	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45541	 46407	 0.27565	 0.2182	 0.00275	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45542	 45543	 0.22736	 0.17996	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90518	 45542	 0.098921	 0.20247	 0.00498	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45543	 46408	 0.17181	 0.12642	 0.00185	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45544	 45551	 0.016831	 0.045828	 0.0101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45544	 45958	 0.02831	 0.073513	 0.01785	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45544	 45959	 0.013202	 0.031817	 0.00898	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45544	 90672	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45544	 90672	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90672	 45545	 0.062114	 0.11208	 0.00162	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45545	 90673	 0.078956	 0.07629	 0.00111	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45546	 46813	 0.01469	 0.022024	 0.0004	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45546	 90907	 0.007506	 0.013492	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45547	 45554	 0.016384	 0.012966	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45547	 46344	 0.008981	 0.016205	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45548	 46361	 0.12157	 0.089445	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90672	 45548	 0.20617	 0.16318	 0.00205	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45549	 45553	 0.01749	 0.033495	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45549	 46818	 0.036892	 0.067572	 0.00117	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45550	 90673	 0.10534	 0.08337	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45551	 90673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45551	 90673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45552	 45963	 0.10834	 0.085741	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90673	 45552	 0.22895	 0.18122	 0.00228	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45552	 90968	 0.11737	 0.22482	 0.00354	 41.0	 43.1	 45.1	 0.0	 0.0	 0	 -30.0	 30.0;
	45553	 46360	 0.012534	 0.035948	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45554	 90907	 0.041313	 0.026746	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45555	 45556	 0.003723	 0.012142	 0.00322	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45555	 45752	 0.002351	 0.008066	 0.00193	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45556	 45559	 0.00691	 0.018813	 0.00414	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45556	 45569	 0.022648	 0.13502	 0.03556	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45556	 90674	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45556	 90674	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89027	 45557	 0.08115	 0.054512	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90674	 45557	 0.046274	 0.050896	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45558	 45741	 0.018604	 0.044836	 0.01266	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45559	 46526	 0.036102	 0.12393	 0.02971	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45559	 90675	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45559	 90675	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45559	 90729	 0.016835	 0.056728	 0.0141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45560	 45749	 0.005988	 0.020542	 0.00492	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89027	 45561	 0.12502	 0.21064	 0.003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45562	 46601	 0.047286	 0.15165	 0.00375	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89030	 45562	 0.036388	 0.12139	 0.00192	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89030	 45564	 0.20854	 0.21299	 0.00332	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45564	 90960	 0.2822	 0.20406	 0.00309	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89025	 45565	 0.08083	 0.20781	 0.00322	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45566	 45567	 0.067609	 0.12153	 0.00218	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45566	 45989	 0.14505	 0.14652	 0.00194	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45566	 46604	 0.15714	 0.12054	 0.00162	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45567	 45570	 0.10573	 0.20724	 0.00311	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45567	 90676	 0.058431	 0.20448	 0.00424	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45568	 46601	 0.22325	 0.1838	 0.00372	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45568	 90676	 0.15079	 0.1982	 0.00272	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45569	 45572	 0.026172	 0.067959	 0.0165	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45569	 45979	 0.07664	 0.21411	 0.04504	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45569	 45981	 0.077917	 0.20631	 0.0484	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45569	 90676	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45569	 90676	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45570	 45988	 0.25382	 0.19474	 0.00261	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45571	 46832	 0.069933	 0.17979	 0.00278	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45571	 90677	 0.054768	 0.14079	 0.00218	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45572	 46428	 0.032134	 0.19174	 0.05056	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45572	 46836	 0.02683	 0.15269	 0.04427	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45572	 90677	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45572	 90677	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45572	 90737	 0.031061	 0.18221	 0.04974	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45572	 90898	 0.034276	 0.15741	 0.04039	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45573	 45747	 0.083696	 0.25709	 0.00483	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90677	 45573	 0.045206	 0.11621	 0.0018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45573	 90757	 0.084027	 0.21603	 0.00334	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45574	 45575	 0.010984	 0.033063	 0.01034	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45574	 45700	 0.031109	 0.084722	 0.01867	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45575	 45578	 0.009127	 0.03131	 0.0075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45576	 90678	 0.12425	 0.13667	 0.00182	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45577	 45578	 0.002004	 0.006753	 0.00168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45577	 45857	 0.025101	 0.14016	 0.03584	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45577	 90678	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45577	 90678	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45577	 90695	 0.048062	 0.12711	 0.02978	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45578	 46554	 0.032981	 0.11664	 0.0263	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45578	 90679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45578	 90679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45579	 45580	 0.078222	 0.11983	 0.00168	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45579	 46547	 0.08216	 0.16103	 0.00241	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90678	 45579	 0.059385	 0.042929	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90679	 45579	 0.081307	 0.064346	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45580	 90680	 0.12709	 0.10058	 0.00127	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45581	 90680	 0.047285	 0.10976	 0.00209	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45582	 45693	 0.011052	 0.03009	 0.00663	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45582	 90680	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45582	 90680	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45583	 45584	 0.17443	 0.13805	 0.00174	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45584	 45585	 0.041636	 0.082436	 0.00121	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45585	 90707	 0.073037	 0.2842	 0.00475	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45585	 90719	 0.062571	 0.12389	 0.00182	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45586	 45587	 0.06721	 0.19279	 0.00297	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45586	 45588	 0.10805	 0.21396	 0.00314	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45586	 46617	 0.17431	 0.17438	 0.00236	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88825	 45587	 0.041175	 0.1181	 0.00182	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45588	 45794	 0.063041	 0.1854	 0.0038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45588	 90681	 0.077841	 0.25972	 0.00412	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45589	 45590	 0.12606	 0.09977	 0.00126	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45589	 90681	 0.079354	 0.087282	 0.00117	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45589	 90746	 0.21499	 0.16855	 0.00216	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90036	 45590	 0.47071	 0.36925	 0.00474	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45590	 90681	 0.014976	 0.029651	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45591	 45796	 0.01616	 0.043388	 0.00983	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88824	 45591	 0.030133	 0.087307	 0.02107	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45591	 90681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45591	 90681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45592	 45593	 0.024499	 0.019388	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45593	 45594	 0.019469	 0.014074	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45593	 90686	 0.039273	 0.03108	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45594	 45603	 0.024697	 0.015989	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45594	 90682	 0.022481	 0.017791	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45595	 45600	 0.002487	 0.006574	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45595	 45659	 0.002838	 0.007295	 0.00181	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45595	 90682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45595	 90682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45596	 45662	 0.010028	 0.012225	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90682	 45596	 0.009438	 0.017286	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45596	 90703	 0.060342	 0.047299	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45597	 45599	 0.018726	 0.020397	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45597	 90686	 0.019419	 0.015368	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45598	 45599	 0.019116	 0.015128	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45598	 45608	 0.011648	 0.015309	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45598	 45612	 0.022029	 0.016207	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45599	 90685	 0.011611	 0.02953	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45600	 45606	 0.002458	 0.006599	 0.0015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45600	 45609	 0.005923	 0.015652	 0.00366	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45600	 45658	 0.005316	 0.014049	 0.00329	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45600	 90683	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45600	 90683	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45601	 45660	 0.038139	 0.024691	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90683	 45601	 0.017558	 0.011367	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45601	 90684	 0.012919	 0.02532	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45601	 90703	 0.031432	 0.031524	 0.00051	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45602	 45604	 0.00903	 0.017879	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90682	 45602	 0.051661	 0.036594	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90683	 45602	 0.024882	 0.019692	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45603	 45662	 0.063386	 0.049685	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90683	 45603	 0.01092	 0.021622	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45603	 90690	 0.039069	 0.07156	 0.00124	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45604	 90685	 0.003248	 0.014472	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89033	 45605	 0.009085	 0.023354	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45605	 90684	 0.010902	 0.02531	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45606	 45658	 0.002746	 0.008097	 0.00188	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45606	 90684	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45606	 90684	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45607	 45619	 0.003608	 0.009069	 0.00235	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45607	 90685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45607	 90685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45608	 45618	 0.02723	 0.02155	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90685	 45608	 0.011668	 0.023101	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45608	 90689	 0.068601	 0.051975	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45609	 45611	 0.001468	 0.003812	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45609	 90686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45609	 90686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45610	 45612	 0.013887	 0.01099	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45610	 45625	 0.03303	 0.02614	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90686	 45610	 0.025254	 0.019795	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45610	 90687	 0.003352	 0.00614	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45610	 90688	 0.01111	 0.014458	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45611	 45614	 0.00135	 0.003625	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45611	 90687	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45611	 90687	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45612	 45618	 0.030397	 0.022364	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45613	 45614	 0.000656	 0.00176	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45613	 45622	 0.00102	 0.002647	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45615	 45616	 0.001432	 0.004221	 0.00098	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45615	 45622	 0.001492	 0.003943	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45615	 90688	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45615	 90688	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45616	 45617	 0.000857	 0.002886	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45617	 45619	 0.003704	 0.009943	 0.00225	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45617	 45697	 0.003185	 0.00855	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45617	 90689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45617	 90689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90686	 45618	 0.050635	 0.040072	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90689	 45618	 0.041855	 0.030257	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45618	 90690	 0.01051	 0.027017	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45619	 45657	 0.005787	 0.013946	 0.00394	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45619	 90690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45619	 90690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45619	 90699	 0.010125	 0.027183	 0.00616	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45620	 45621	 0.019787	 0.01281	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45620	 90713	 0.004941	 0.005045	 8e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90689	 45621	 0.041601	 0.027945	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45621	 90713	 0.026676	 0.020462	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45622	 45623	 0.000337	 0.001221	 0.00026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45622	 90691	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45622	 90691	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45623	 45626	 0.000493	 0.001692	 0.00041	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45624	 45625	 0.008202	 0.006214	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90691	 45624	 0.011634	 0.008559	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45624	 90692	 0.003595	 0.007117	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90688	 45625	 0.017744	 0.011919	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90691	 45625	 0.005279	 0.004178	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45626	 45627	 0.000498	 0.001317	 0.00031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45626	 90692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45626	 90692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89035	 45628	 0.005496	 0.004349	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45629	 45650	 0.034373	 0.027202	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89035	 45629	 0.024045	 0.018848	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45629	 90693	 0.010672	 0.008446	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45629	 90694	 0.023022	 0.018219	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45630	 45632	 0.002166	 0.005723	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45630	 90693	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45630	 90693	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45631	 45632	 0.001418	 0.003418	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45631	 45642	 0.001433	 0.003719	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45631	 90695	 0.003715	 0.010115	 0.00223	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45632	 90694	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45632	 90694	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45633	 45634	 0.026398	 0.020249	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45633	 45650	 0.017027	 0.013475	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45633	 90696	 0.022437	 0.024678	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45634	 45635	 0.025932	 0.020523	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45634	 45636	 0.018809	 0.014885	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45635	 45664	 0.048898	 0.074908	 0.00105	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45635	 90696	 0.03465	 0.048291	 0.00083	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45636	 45637	 0.020136	 0.015783	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45637	 90696	 0.017275	 0.022705	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45638	 45653	 0.00042	 0.004653	 0.0443	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45638	 45774	 0.003632	 0.041251	 0.37699	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45638	 90695	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90696	 45639	 0.037263	 0.024124	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45639	 90697	 0.027463	 0.018448	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45640	 45669	 0.00309	 0.007768	 0.00201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90695	 45640	 0.00223	 0.005986	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45642	 45647	 0.003039	 0.011003	 0.00236	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45642	 90697	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45642	 90697	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45643	 45645	 0.032307	 0.020915	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45643	 45651	 0.016528	 0.018002	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45644	 45651	 0.016511	 0.01816	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45644	 45652	 0.020139	 0.015938	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45644	 90698	 0.028891	 0.022864	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45644	 90700	 0.011624	 0.033339	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90697	 45645	 0.027633	 0.019976	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45647	 45668	 0.002576	 0.006208	 0.00175	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45647	 90698	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45647	 90698	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45647	 90699	 0.002027	 0.008579	 0.00193	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45647	 90706	 0.00822	 0.022923	 0.00481	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45648	 45649	 0.020552	 0.016264	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90687	 45648	 0.007342	 0.014537	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90694	 45648	 0.097767	 0.076637	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90686	 45649	 0.014114	 0.014255	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90693	 45650	 0.045038	 0.034123	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90696	 45650	 0.048026	 0.038008	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45651	 45652	 0.0195	 0.015432	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45652	 90713	 0.019456	 0.015397	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45653	 90699	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45654	 45679	 0.005425	 0.019175	 0.00432	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90699	 45654	 0.002821	 0.009504	 0.00236	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45654	 90701	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45654	 90701	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45655	 45681	 0.07523	 0.12674	 0.00181	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90690	 45655	 0.034513	 0.07063	 0.00174	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90701	 45655	 0.080658	 0.058308	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45655	 90710	 0.034771	 0.068845	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90690	 45656	 0.048325	 0.038244	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45656	 90702	 0.015293	 0.025542	 0.00043	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45657	 45686	 0.004722	 0.016457	 0.00382	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45657	 90702	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45657	 90702	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45658	 45696	 0.001878	 0.008368	 0.00227	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45659	 90703	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45659	 90703	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45661	 45689	 0.064652	 0.16621	 0.00257	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45661	 45691	 0.099555	 0.078788	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90700	 45661	 0.26144	 0.26158	 0.00353	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90703	 45661	 0.0214	 0.03569	 0.00052	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45661	 90704	 0.20074	 0.14771	 0.00216	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45662	 45663	 0.010813	 0.013182	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45663	 45664	 0.045152	 0.035732	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45664	 90704	 0.087312	 0.068441	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45665	 45666	 0.003374	 0.009058	 0.00205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90695	 45665	 0.007278	 0.024522	 0.00609	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45665	 90704	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45665	 90704	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45666	 45693	 0.005353	 0.014147	 0.00331	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90680	 45667	 0.26286	 0.20807	 0.00262	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90704	 45667	 0.007804	 0.015451	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45668	 90706	 0.005698	 0.014792	 0.00359	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90695	 45669	 0.005278	 0.013947	 0.00326	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45669	 90705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45669	 90705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45669	 90706	 0.007425	 0.026885	 0.00577	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45670	 45671	 0.044255	 0.031992	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45670	 45674	 0.055366	 0.035844	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45671	 45672	 0.031782	 0.024912	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45671	 45673	 0.009327	 0.018467	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45672	 45673	 0.011925	 0.02337	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45672	 45674	 0.039288	 0.025435	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45672	 45675	 0.093907	 0.074318	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90705	 45673	 0.013668	 0.039203	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45674	 45675	 0.056352	 0.044596	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45674	 45676	 0.14819	 0.10904	 0.00159	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45674	 90707	 0.018043	 0.099364	 0.00224	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45675	 45676	 0.0919	 0.07273	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45676	 45835	 0.37683	 0.29836	 0.00376	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45677	 45679	 0.007107	 0.023708	 0.00601	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89001	 45677	 0.003398	 0.013605	 0.00343	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45678	 90706	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90707	 45678	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45678	 90740	 0.013004	 0.086938	 0.16443	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45679	 90708	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45679	 90708	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45680	 46519	 0.006609	 0.017466	 0.00409	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89001	 45680	 0.011302	 0.029053	 0.00719	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90708	 45681	 0.13842	 0.10955	 0.00138	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45681	 90709	 0.008996	 0.034998	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45682	 90709	 0.019693	 0.038989	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45682	 90710	 0.14676	 0.11615	 0.00146	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45683	 45684	 0.012226	 0.034094	 0.00716	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89001	 45683	 0.015898	 0.043286	 0.00954	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45683	 90709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45683	 90709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45684	 45685	 0.001862	 0.010388	 0.00265	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45684	 45805	 0.006825	 0.038079	 0.00973	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45685	 45686	 0.00247	 0.009707	 0.00254	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45685	 90710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45685	 90710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45687	 45696	 0.006928	 0.031784	 0.00814	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45687	 45806	 0.007577	 0.03807	 0.00991	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45688	 45689	 0.022312	 0.068521	 0.00129	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45688	 45692	 0.06671	 0.1715	 0.00265	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45688	 45819	 0.039685	 0.17685	 0.003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45690	 45691	 0.077588	 0.061403	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45691	 45692	 0.05001	 0.12719	 0.00201	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45692	 46550	 0.13039	 0.10221	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45693	 90711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45693	 90711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45694	 45695	 0.040131	 0.031759	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90705	 45694	 0.038161	 0.10945	 0.00168	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90680	 45695	 0.19588	 0.1316	 0.00232	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90711	 45695	 0.055709	 0.059492	 0.00126	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45696	 90712	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45696	 90712	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90699	 45697	 0.003741	 0.012604	 0.00313	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45697	 90713	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45697	 90713	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45698	 45711	 0.01181	 0.041163	 0.00955	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45698	 90714	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45698	 90714	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45699	 45701	 0.014013	 0.035226	 0.00913	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45699	 90715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45699	 90715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45700	 45704	 0.01716	 0.045355	 0.01062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45700	 90716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45700	 90716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45701	 45704	 0.004903	 0.012729	 0.00309	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45702	 45818	 0.18907	 0.14822	 0.0019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90716	 45702	 0.086053	 0.17039	 0.0025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45702	 90717	 0.22395	 0.17726	 0.00223	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45703	 45707	 0.042973	 0.085083	 0.00125	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45704	 90717	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45704	 90717	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90717	 45705	 0.018776	 0.020651	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45705	 90718	 0.029904	 0.023665	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45706	 45715	 0.0164	 0.042162	 0.01044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45706	 90718	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45706	 90718	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90718	 45707	 0.005005	 0.011619	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45708	 45709	 0.15245	 0.12066	 0.00152	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89015	 45708	 0.13837	 0.25349	 0.00438	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90718	 45708	 0.17405	 0.13776	 0.00173	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45709	 45710	 0.07632	 0.071572	 0.00111	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90715	 45709	 0.037485	 0.096362	 0.00149	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90714	 45710	 0.036587	 0.10494	 0.00161	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45712	 45713	 0.13744	 0.10878	 0.00137	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89015	 45712	 0.047281	 0.21071	 0.00358	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45712	 90998	 0.10784	 0.084533	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45714	 45716	 0.034371	 0.067362	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45714	 90719	 0.19539	 0.15465	 0.00195	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45715	 45836	 0.013496	 0.046301	 0.01109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45715	 90719	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45715	 90719	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45716	 45717	 0.022045	 0.015936	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45716	 45834	 0.023521	 0.022057	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45716	 45835	 0.021966	 0.036686	 0.00062	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45717	 45834	 0.011058	 0.011169	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45718	 45723	 0.053588	 0.14399	 0.03267	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45719	 45720	 0.18103	 0.14328	 0.0018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45720	 90720	 0.3101	 0.24549	 0.00309	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45720	 90811	 0.14494	 0.26553	 0.00459	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45721	 90720	 0.15571	 0.12323	 0.00155	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45722	 45725	 0.14549	 0.11514	 0.00145	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45722	 45726	 0.1604	 0.12695	 0.0016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45722	 45896	 0.17289	 0.13684	 0.00172	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45722	 90721	 0.24863	 0.19493	 0.0025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45723	 45897	 0.041654	 0.1082	 0.02628	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45723	 90720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45723	 90720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45724	 46002	 0.034054	 0.098678	 0.02381	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88990	 45724	 0.039312	 0.15756	 0.03975	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45724	 90721	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45724	 90721	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45726	 45999	 0.15963	 0.31615	 0.00464	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45726	 46321	 0.41302	 0.32705	 0.00412	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45727	 45728	 0.004576	 0.017606	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45727	 90724	 0.012427	 0.022422	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45728	 45733	 0.004398	 0.019678	 0.00041	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45729	 45730	 0.01707	 0.013509	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45730	 90724	 0.011992	 0.023744	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90578	 45731	 0.015657	 0.05223	 0.00083	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45731	 90723	 0.010964	 0.044809	 0.00091	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45732	 90722	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90723	 45733	 0.00526	 0.025248	 0.00075	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45734	 45736	 0.020981	 0.056333	 0.01277	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90722	 45734	 0.007103	 0.019069	 0.00432	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90722	 45735	 0.00154	 0.014783	 0.0043	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45735	 90724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45735	 90724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45737	 45738	 0.07376	 0.28384	 0.00485	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90723	 45737	 0.028549	 0.099962	 0.00277	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45738	 46647	 0.064676	 0.28826	 0.0049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45739	 46537	 0.1507	 0.29845	 0.00438	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45739	 90725	 0.21273	 0.21491	 0.00285	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45740	 46416	 0.51869	 0.40695	 0.00522	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45740	 46537	 0.076738	 0.14056	 0.00243	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45740	 90727	 0.080339	 0.15746	 0.00236	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45741	 90725	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45741	 90725	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45742	 45762	 0.012596	 0.042444	 0.01055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45742	 46397	 0.011647	 0.046635	 0.01175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45742	 90726	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45742	 90726	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45743	 46538	 0.030138	 0.088882	 0.02069	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45743	 46541	 0.036698	 0.12597	 0.03021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45743	 90727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45743	 90727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45743	 90729	 0.043735	 0.11249	 0.02788	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45744	 45745	 0.043996	 0.092471	 0.00168	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45744	 46399	 0.041478	 0.12485	 0.00244	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45745	 45746	 0.041639	 0.0301	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90726	 45745	 0.19968	 0.15804	 0.00199	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90727	 45745	 0.10168	 0.079706	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90726	 45746	 0.1903	 0.15062	 0.0019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90727	 45746	 0.026026	 0.051006	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45747	 45748	 0.066143	 0.16822	 0.00266	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45747	 90758	 0.41642	 0.32974	 0.00415	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45748	 90730	 0.052021	 0.10646	 0.00262	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45749	 90729	 0.006974	 0.027921	 0.00703	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45750	 46307	 0.003481	 0.039525	 0.3611	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45750	 90728	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90730	 45751	 0.046779	 0.065195	 0.00111	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45751	 90734	 0.050868	 0.039019	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45752	 45754	 0.002027	 0.007166	 0.00161	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45752	 45763	 0.003872	 0.010232	 0.00239	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45752	 90731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45752	 90731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90674	 45753	 0.03411	 0.061309	 0.0011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90731	 45753	 0.010561	 0.027149	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90729	 45754	 0.008123	 0.028713	 0.00647	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45754	 90732	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45754	 90732	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90732	 45755	 0.008321	 0.017028	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45755	 90733	 0.005652	 0.018652	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45755	 90734	 0.020644	 0.037812	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45756	 45758	 0.002639	 0.006975	 0.00163	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45756	 45766	 0.001256	 0.005029	 0.00127	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90729	 45756	 0.007654	 0.02023	 0.00474	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45756	 90733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45756	 90733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45756	 90737	 0.010143	 0.034796	 0.00834	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90733	 45757	 0.023042	 0.016953	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90729	 45758	 0.003859	 0.013642	 0.00307	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45758	 90734	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45758	 90734	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45759	 45761	 0.014324	 0.028073	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90732	 45760	 0.006953	 0.014228	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45760	 90738	 0.005231	 0.013447	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45761	 90735	 0.019572	 0.025723	 0.00035	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45761	 90738	 0.00286	 0.015415	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45762	 45763	 0.002132	 0.006385	 0.00144	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45762	 45764	 0.003124	 0.008386	 0.0019	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45763	 90735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45763	 90735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45764	 90736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45764	 90736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90728	 45765	 0.001895	 0.012304	 0.02451	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45765	 90737	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45765	 90737	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45766	 90738	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45766	 90738	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45767	 45768	 0.20392	 0.15986	 0.00205	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45767	 45789	 0.40507	 0.37341	 0.00599	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45767	 90808	 0.66261	 0.52017	 0.00668	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45769	 45776	 0.028047	 0.018157	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45769	 45787	 0.18871	 0.17029	 0.00285	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45769	 90739	 0.005458	 0.013359	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45770	 45786	 0.00676	 0.023894	 0.00538	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45770	 90739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45770	 90739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45771	 45772	 0.022154	 0.017533	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45771	 90742	 0.021008	 0.033532	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45773	 45775	 0.020055	 0.015871	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90739	 45773	 0.008207	 0.015032	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45774	 46307	 0.005617	 0.057546	 0.94839	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45774	 90740	 0.000104	 0.008333	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45775	 45776	 0.015735	 0.011577	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45775	 45777	 0.015656	 0.01239	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45776	 45778	 0.029986	 0.02124	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45777	 45778	 0.018605	 0.014723	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90742	 45778	 0.022698	 0.057725	 0.00091	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90739	 45779	 0.023487	 0.03749	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45780	 45781	 0.039595	 0.15234	 0.0026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90742	 45780	 0.019231	 0.092313	 0.00276	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45780	 90743	 0.15601	 0.20507	 0.00281	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45781	 45782	 0.026399	 0.052269	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45782	 45816	 0.049702	 0.050201	 0.00066	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45782	 90756	 0.09668	 0.14811	 0.00208	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45783	 45816	 0.062668	 0.1455	 0.00216	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45783	 45818	 0.24803	 0.18253	 0.00267	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45783	 90743	 0.014186	 0.086215	 0.00159	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45784	 90743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45784	 90743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45786	 46595	 0.020088	 0.071017	 0.01601	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45787	 46586	 0.044968	 0.11437	 0.00181	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89010	 45787	 0.031225	 0.061823	 0.00091	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45788	 46655	 0.006003	 0.024032	 0.00605	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45789	 46325	 0.30556	 0.1979	 0.00377	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45789	 90744	 0.40863	 0.29558	 0.00448	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45790	 45792	 0.41159	 0.32592	 0.0041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45790	 45993	 0.75065	 0.5952	 0.00749	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45790	 90744	 0.26533	 0.188	 0.00297	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45791	 45992	 0.048589	 0.12851	 0.03011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45791	 90744	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45791	 90744	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45791	 90903	 0.036116	 0.12774	 0.02881	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45792	 45929	 0.34339	 0.25276	 0.0037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90744	 45792	 0.18775	 0.1486	 0.00187	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45793	 46485	 0.009897	 0.045119	 0.01432	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45793	 90745	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45793	 90745	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90745	 45794	 0.037358	 0.12463	 0.00198	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90745	 45795	 0.037892	 0.14011	 0.00259	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45795	 90747	 0.07103	 0.27639	 0.00462	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45796	 45797	 0.017659	 0.04585	 0.01113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45796	 90746	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45796	 90746	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45797	 90747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45797	 90747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45798	 45799	 0.027115	 0.10549	 0.00176	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45798	 90749	 0.060373	 0.14017	 0.00208	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89014	 45799	 0.0389	 0.23907	 0.00546	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90746	 45799	 0.12511	 0.23649	 0.00383	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90747	 45800	 0.049266	 0.21956	 0.00373	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45800	 90750	 0.032752	 0.090603	 0.00211	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45801	 45802	 0.00323	 0.008302	 0.00206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45801	 45803	 0.010918	 0.032865	 0.01028	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45801	 90748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45801	 90748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45802	 45803	 0.010529	 0.036695	 0.00851	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45802	 90749	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45802	 90749	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45803	 90750	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45803	 90750	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90107	 45804	 0.12786	 0.13623	 0.00194	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45805	 45807	 0.007083	 0.036895	 0.00968	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45805	 90751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45805	 90751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45806	 45811	 0.008618	 0.047291	 0.0125	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45806	 90752	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45806	 90752	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45807	 45812	 0.014784	 0.039075	 0.00915	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45807	 90753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45807	 90753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45808	 45809	 0.016476	 0.03262	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45808	 45810	 0.036814	 0.055835	 0.0008	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45808	 90754	 0.031552	 0.081109	 0.00126	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45809	 45810	 0.053992	 0.039724	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88899	 45809	 0.038697	 0.21746	 0.00403	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90753	 45809	 0.099383	 0.12338	 0.00269	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45809	 90755	 0.32043	 0.20754	 0.00395	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90753	 45810	 0.07877	 0.11947	 0.00171	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45811	 90754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45811	 90754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45812	 90755	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45812	 90755	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45813	 46805	 0.018642	 0.050053	 0.01135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45813	 90756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45813	 90756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90756	 45814	 0.043984	 0.034808	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45815	 45816	 0.23043	 0.18065	 0.00232	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45817	 45818	 0.18781	 0.12161	 0.00231	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45817	 46005	 0.20044	 0.14492	 0.0022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45819	 45820	 0.095451	 0.19537	 0.00481	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45819	 45822	 0.053794	 0.16193	 0.00317	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90745	 45820	 0.069414	 0.17845	 0.00276	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45821	 45824	 0.057145	 0.14691	 0.00227	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45822	 45823	 0.09084	 0.15304	 0.00218	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45822	 45824	 0.022554	 0.092178	 0.00186	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45822	 46551	 0.059993	 0.30356	 0.00528	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90749	 45822	 0.059203	 0.2843	 0.0085	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45823	 45824	 0.05539	 0.17838	 0.00304	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90752	 45823	 0.10006	 0.25727	 0.00398	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45824	 45925	 0.033215	 0.1019	 0.00276	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45824	 45928	 0.47737	 0.34539	 0.00524	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45825	 45826	 0.21446	 0.15781	 0.00231	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45827	 46620	 0.15227	 0.27481	 0.00397	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45827	 90930	 0.14476	 0.33619	 0.005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45828	 46833	 0.081226	 0.24925	 0.00675	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45828	 90759	 0.044892	 0.21909	 0.00378	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45829	 45830	 0.01602	 0.044677	 0.00938	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45829	 45832	 0.012706	 0.033582	 0.00786	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45829	 90757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45829	 90757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45830	 90758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45830	 90758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45831	 46612	 0.10875	 0.21315	 0.0032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45831	 90759	 0.246	 0.1593	 0.00303	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45832	 90759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45832	 90759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45832	 90898	 0.022116	 0.077095	 0.01788	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45833	 45836	 0.014801	 0.038426	 0.00933	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45833	 45852	 0.003419	 0.020025	 0.00545	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45833	 90760	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45833	 90760	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90760	 45834	 0.007027	 0.027338	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89015	 45835	 0.018005	 0.047596	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90760	 45835	 0.022902	 0.03858	 0.00055	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45836	 45837	 0.006868	 0.02314	 0.00575	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90706	 45836	 0.019769	 0.06662	 0.01656	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45837	 45843	 0.008904	 0.023532	 0.00551	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89001	 45837	 0.005484	 0.037647	 0.01098	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45837	 90761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45837	 90761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90761	 45838	 0.081567	 0.064552	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45839	 45847	 0.004686	 0.01876	 0.00473	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89001	 45839	 0.006351	 0.026221	 0.0062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45840	 45844	 0.007839	 0.020717	 0.00485	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45840	 45851	 0.007965	 0.020022	 0.00519	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45840	 90762	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45840	 90762	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45841	 45842	 0.038771	 0.10277	 0.00261	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45841	 91026	 0.035384	 0.082137	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45842	 90765	 0.040707	 0.12253	 0.0024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45842	 90766	 0.14028	 0.11102	 0.0014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45843	 45844	 0.002912	 0.007817	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45843	 90763	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45843	 90763	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45844	 45848	 0.009412	 0.024435	 0.00593	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45845	 46521	 0.010046	 0.029617	 0.00689	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89001	 45845	 0.007815	 0.02681	 0.00642	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45846	 45848	 0.005042	 0.013535	 0.00307	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45846	 46631	 0.006391	 0.016429	 0.00407	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45847	 45848	 0.002102	 0.008416	 0.00212	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45847	 90764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45847	 90764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45848	 90765	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45848	 90765	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90763	 45849	 0.13159	 0.10414	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90764	 45849	 0.009462	 0.024324	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90765	 45849	 0.038409	 0.031614	 0.00064	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45850	 46630	 0.003341	 0.019903	 0.00524	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45850	 46752	 0.009235	 0.048953	 0.01634	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45850	 46756	 0.003826	 0.032811	 0.00934	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45850	 90766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45850	 90766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45852	 46745	 0.008483	 0.047071	 0.01431	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45852	 46763	 0.004814	 0.022451	 0.00556	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45854	 46310	 0.086505	 0.26043	 0.00509	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45854	 90767	 0.073772	 0.1326	 0.00238	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45855	 45856	 0.04129	 0.13775	 0.00218	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45856	 90767	 0.009792	 0.060167	 0.00137	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45857	 45858	 0.011923	 0.043175	 0.00926	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45857	 46311	 0.024676	 0.096039	 0.02567	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45857	 90767	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45857	 90767	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45858	 46613	 0.010528	 0.042153	 0.01062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45859	 46544	 0.064434	 0.14617	 0.00292	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90767	 45859	 0.037597	 0.12543	 0.00199	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45860	 45865	 0.000162	 0.001873	 0.01642	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45860	 46446	 0.00014	 0.001562	 0.01459	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45860	 90768	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45860	 90768	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45861	 45862	 0.015778	 0.011954	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90768	 45861	 0.028858	 0.046292	 0.00085	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45861	 90773	 0.049449	 0.032014	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45863	 90770	 0.027626	 0.019971	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45864	 46463	 0.007992	 0.022286	 0.00468	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88992	 45864	 0.010147	 0.028296	 0.00594	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45864	 90769	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45864	 90769	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45865	 45866	 9.2e-05	 0.001044	 0.00951	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45865	 90770	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45865	 90770	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45866	 45872	 4.9e-05	 0.000568	 0.00498	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45866	 90771	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45867	 45868	 0.004691	 0.007488	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90772	 45867	 0.010027	 0.018021	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45868	 45869	 0.006534	 0.012938	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45868	 90773	 0.024621	 0.019485	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45869	 45877	 0.016351	 0.017984	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45870	 45871	 0.001156	 0.003002	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45870	 45875	 0.000667	 0.001815	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90771	 45871	 0.001476	 0.005143	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45871	 90773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45871	 90773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45872	 45873	 4.4e-05	 0.000495	 0.00467	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45873	 45884	 9.8e-05	 0.001113	 0.01013	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90773	 45874	 0.020555	 0.016267	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45874	 90776	 0.017031	 0.027185	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45875	 45876	 0.00064	 0.001609	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45876	 45881	 0.000744	 0.001967	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45877	 45878	 0.008124	 0.006368	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45877	 90774	 0.027515	 0.027791	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45879	 45880	 0.001081	 0.008689	 0.00244	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45880	 45881	 0.001525	 0.004094	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45880	 45882	 0.001114	 0.003883	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88992	 45880	 0.004012	 0.016065	 0.00405	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45880	 90774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45880	 90774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45882	 45883	 0.001041	 0.003678	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90771	 45883	 0.004895	 0.012304	 0.00319	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45883	 90775	 0.001137	 0.003901	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45883	 90777	 0.00468	 0.012369	 0.0029	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45884	 90775	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88993	 45885	 0.023263	 0.041812	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90772	 45885	 0.075077	 0.056882	 0.00078	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88991	 45886	 9.3e-05	 0.000915	 0.00314	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45886	 90777	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45886	 90777	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90777	 45887	 0.006509	 0.022683	 0.00526	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45887	 90778	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45887	 90778	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45888	 45891	 0.00206	 0.012664	 0.00365	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45888	 90779	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45888	 90779	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45889	 45890	 0.01157	 0.035493	 0.00096	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90779	 45889	 0.020255	 0.059562	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45889	 90780	 0.075817	 0.049085	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89624	 45890	 0.027486	 0.045655	 0.00097	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90778	 45890	 0.060511	 0.11981	 0.00176	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45891	 45892	 0.003241	 0.012977	 0.00327	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45891	 90780	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45891	 90780	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45893	 45894	 0.008121	 0.044445	 0.00087	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45893	 46645	 0.012464	 0.047753	 0.00135	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45895	 45896	 0.082341	 0.065165	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45895	 90781	 0.096378	 0.18217	 0.00295	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88990	 45897	 0.027772	 0.08319	 0.01875	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45897	 90781	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45897	 90781	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88990	 45898	 0.011424	 0.041368	 0.00888	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45899	 45907	 0.005032	 0.020145	 0.00508	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45899	 45919	 0.001584	 0.013141	 0.00346	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45899	 90782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45899	 90782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45899	 90783	 0.000603	 0.005973	 0.00183	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45900	 46307	 0.001328	 0.018178	 0.18539	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45900	 90783	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45901	 45917	 0.005076	 0.02478	 0.00052	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90784	 45901	 0.007604	 0.037107	 0.00064	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45902	 45905	 0.027896	 0.0327	 0.00057	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45902	 45906	 0.015254	 0.009875	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90784	 45902	 0.008886	 0.024615	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90784	 45903	 0.008889	 0.0176	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45904	 45905	 0.02659	 0.021043	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90782	 45904	 0.065891	 0.052146	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45906	 45908	 0.023385	 0.018507	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45907	 90785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45907	 90785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45908	 45909	 0.003025	 0.007693	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90785	 45908	 0.001327	 0.009002	 0.00017	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45909	 45911	 0.005551	 0.013777	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45910	 45911	 0.015853	 0.014303	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45910	 45922	 0.062276	 0.04502	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90785	 45910	 0.010376	 0.026388	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45911	 90981	 0.18192	 0.33333	 0.00576	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45912	 45914	 0.082631	 0.16362	 0.0024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45912	 46308	 0.20281	 0.15559	 0.00209	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45913	 45918	 0.006636	 0.018068	 0.00398	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45913	 45923	 0.01039	 0.030094	 0.00726	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45914	 45915	 0.10111	 0.083223	 0.00169	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45914	 46612	 0.20022	 0.15847	 0.002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45914	 90786	 0.025193	 0.088208	 0.00244	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45915	 45916	 0.016317	 0.041944	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45915	 46612	 0.14978	 0.17933	 0.00299	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45916	 46611	 0.10408	 0.20609	 0.00303	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45916	 90786	 0.027462	 0.05863	 0.00132	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45917	 90786	 0.013037	 0.040036	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45918	 45919	 0.006231	 0.016017	 0.00397	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45919	 90786	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45919	 90786	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45919	 90898	 0.041467	 0.10771	 0.02616	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45920	 45921	 0.07884	 0.062394	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90782	 45920	 0.012081	 0.030725	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45923	 46618	 0.015396	 0.050221	 0.01333	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45924	 45928	 0.25728	 0.20365	 0.00256	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45925	 45926	 0.030902	 0.1377	 0.00234	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45926	 45927	 0.15425	 0.13824	 0.00283	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90748	 45926	 0.041821	 0.11995	 0.00184	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90749	 45926	 0.04523	 0.14927	 0.00242	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89557	 45927	 0.23586	 0.18491	 0.00237	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88899	 45928	 0.13432	 0.18723	 0.0032	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89557	 45928	 0.036688	 0.16418	 0.00338	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89884	 45928	 0.21102	 0.21168	 0.00342	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45929	 45930	 0.090356	 0.20761	 0.00315	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45929	 46327	 0.15663	 0.28696	 0.00496	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45930	 45933	 0.058018	 0.10469	 0.00151	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45931	 45932	 0.089949	 0.22879	 0.00362	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45931	 45934	 0.035778	 0.09099	 0.00144	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45932	 46315	 0.13729	 0.25152	 0.00434	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45933	 45934	 0.008315	 0.021375	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45933	 90802	 0.11344	 0.30079	 0.00763	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45935	 90787	 0.16789	 0.13288	 0.00167	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45935	 90902	 0.17806	 0.12873	 0.00195	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45936	 45937	 0.20146	 0.15945	 0.00201	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45936	 90787	 0.055407	 0.13121	 0.0024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45936	 90904	 0.43221	 0.34226	 0.00431	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45937	 46333	 0.24585	 0.17419	 0.00275	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45938	 45942	 0.27032	 0.19153	 0.00303	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45938	 46599	 0.31057	 0.20115	 0.00383	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45939	 45941	 0.011337	 0.041054	 0.00881	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45939	 46328	 0.02374	 0.066211	 0.0139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45939	 90787	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45939	 90787	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45940	 90788	 0.13271	 0.10503	 0.00132	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45940	 90807	 0.090497	 0.17919	 0.00263	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45941	 45944	 0.009053	 0.031057	 0.00744	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45942	 90788	 0.024019	 0.055763	 0.00083	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45943	 90788	 0.044331	 0.035083	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45944	 45982	 0.009681	 0.031577	 0.00838	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45944	 46603	 0.054205	 0.14338	 0.0336	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45944	 90788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45944	 90788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45945	 45948	 0.002736	 0.00855	 0.00248	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45945	 45956	 0.004045	 0.010501	 0.00255	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88990	 45945	 0.016793	 0.050999	 0.01117	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88990	 45945	 0.016793	 0.050999	 0.01117	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45945	 90789	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45945	 90789	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45946	 45947	 0.042881	 0.031549	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90789	 45946	 0.037862	 0.029678	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45948	 90790	 0.001169	 0.004011	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45948	 90790	 0.001169	 0.004011	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 0	 -30.0	 30.0;
	45949	 45950	 0.000483	 0.003386	 0.00576	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45949	 90790	 0.0	 1e-05	 0.0	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45949	 90790	 0.0	 1e-05	 0.0	 300.0	 300.0	 300.0	 0.0	 0.0	 0	 -30.0	 30.0;
	45950	 45961	 0.000574	 0.003633	 0.00761	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45950	 90791	 0.0	 0.0001	 0.0	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90792	 45950	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 0	 -30.0	 30.0;
	45951	 45952	 0.001648	 0.004356	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45951	 45952	 0.001648	 0.004356	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90791	 45951	 0.002969	 0.007847	 0.00184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45951	 90793	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45951	 90793	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45953	 45955	 0.027507	 0.021768	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45954	 45956	 0.002777	 0.007742	 0.00163	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45954	 45957	 0.007073	 0.021996	 0.00459	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45954	 90794	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45954	 90794	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90794	 45955	 0.026467	 0.032264	 0.00052	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45955	 90795	 0.038201	 0.030232	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45956	 90795	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45956	 90795	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45957	 45958	 0.012948	 0.036109	 0.00758	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88990	 45957	 0.00393	 0.015994	 0.0039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45958	 45959	 0.017581	 0.046468	 0.01088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88990	 45958	 0.011259	 0.04508	 0.01136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45959	 45960	 0.013289	 0.034162	 0.00846	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45960	 90796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45960	 90796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45961	 45962	 0.002233	 0.01523	 0.02743	 366.0	 384.3	 402.6	 1.0	 0.0	 0	 -30.0	 30.0;
	45962	 46583	 0.001392	 0.009167	 0.01774	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45962	 46804	 0.007769	 0.052749	 0.09615	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	45963	 46585	 0.04111	 0.078731	 0.00124	 41.0	 43.1	 45.1	 0.0	 0.0	 0	 -30.0	 30.0;
	90796	 45963	 0.12821	 0.15917	 0.00347	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45964	 45965	 0.004226	 0.015854	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45964	 45968	 0.008162	 0.016161	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45964	 90797	 0.028685	 0.028691	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45964	 90799	 0.0088	 0.020431	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45965	 45971	 0.00575	 0.019181	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45966	 90797	 0.014328	 0.036831	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45966	 90807	 0.032145	 0.076121	 0.00139	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45967	 45969	 0.001872	 0.009407	 0.00245	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45967	 45970	 0.003103	 0.010645	 0.00255	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45967	 45981	 0.01028	 0.02717	 0.00636	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45967	 45982	 0.003615	 0.02186	 0.00558	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	45967	 90797	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45967	 90797	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45968	 90798	 0.006512	 0.015116	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45969	 45980	 0.002779	 0.015736	 0.0039	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45969	 45981	 0.009747	 0.025759	 0.00603	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45969	 90798	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45969	 90798	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45970	 90799	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45970	 90799	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45971	 90802	 0.008208	 0.04612	 0.00085	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45971	 90803	 0.015502	 0.041088	 0.00104	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45972	 45973	 0.010734	 0.021253	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90799	 45972	 0.03495	 0.024757	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45973	 45977	 0.009378	 0.030947	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45974	 46337	 0.002488	 0.036188	 0.32824	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45974	 90800	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45975	 45976	 0.002626	 0.010843	 0.00257	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45975	 90802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45975	 90802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90800	 45976	 0.001739	 0.012846	 0.00371	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45976	 90803	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45976	 90803	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90801	 45977	 0.002712	 0.025247	 0.00049	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90803	 45977	 0.003697	 0.021034	 0.00065	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	45978	 46418	 0.009299	 0.060816	 0.01547	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89024	 45978	 0.002053	 0.016666	 0.00531	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45978	 90804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45978	 90804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45979	 45980	 0.010691	 0.027755	 0.00674	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89024	 45979	 0.004272	 0.023833	 0.00609	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	45979	 90805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45979	 90805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89024	 45980	 0.001509	 0.011887	 0.00348	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90800	 45980	 0.004972	 0.014402	 0.00347	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45981	 46603	 0.04383	 0.13319	 0.02919	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89024	 45981	 0.004624	 0.039656	 0.01129	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45981	 90806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45981	 90806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45982	 90807	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45982	 90807	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45983	 46569	 0.066464	 0.21936	 0.00355	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90802	 45983	 0.046658	 0.15566	 0.00247	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45984	 46569	 0.26019	 0.20595	 0.00259	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90805	 45985	 0.020152	 0.0898	 0.00152	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45985	 91044	 0.0517	 0.19892	 0.0034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45986	 45987	 0.051972	 0.17339	 0.00275	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90805	 45986	 0.031456	 0.11014	 0.00305	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	45987	 45988	 0.068326	 0.12914	 0.00209	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45988	 91045	 0.13891	 0.1528	 0.00204	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45989	 45990	 0.31432	 0.24646	 0.00316	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90806	 45990	 0.054948	 0.18332	 0.00291	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	45991	 90808	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45991	 90808	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45992	 90809	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45992	 90809	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45993	 45996	 0.28963	 0.22223	 0.00298	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45993	 46000	 0.51402	 0.40716	 0.00513	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45994	 45995	 0.2143	 0.16962	 0.00214	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45994	 46316	 0.27457	 0.21067	 0.00283	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45995	 45997	 0.097383	 0.16406	 0.00234	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	45996	 46000	 0.23619	 0.18695	 0.00235	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89018	 45996	 0.25645	 0.20299	 0.00256	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45997	 46319	 0.26091	 0.20653	 0.0026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	45997	 90810	 0.034353	 0.10539	 0.00285	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45998	 46323	 0.024671	 0.084657	 0.02029	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	45998	 90810	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	45998	 90810	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89018	 45999	 0.020584	 0.068668	 0.00109	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89018	 46000	 0.026897	 0.021083	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89026	 46000	 0.015478	 0.018528	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89026	 46001	 0.007904	 0.039983	 0.0007	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46001	 90811	 0.011767	 0.027319	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46002	 90811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46002	 90811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46003	 46004	 0.062246	 0.12325	 0.00181	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46003	 46784	 0.12989	 0.17073	 0.00234	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46004	 46005	 0.068752	 0.13613	 0.002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90679	 46005	 0.035544	 0.20207	 0.00366	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46006	 46007	 0.20004	 0.15833	 0.00199	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90679	 46006	 0.2198	 0.17232	 0.00221	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90678	 46007	 0.42629	 0.33757	 0.00425	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46008	 46564	 0.036732	 0.067278	 0.00116	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46008	 46567	 0.063285	 0.16269	 0.00252	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46009	 46564	 0.32556	 0.23962	 0.0035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46010	 46392	 0.032472	 0.064293	 0.00094	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46010	 90813	 0.03318	 0.021481	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46011	 46012	 0.000125	 0.001445	 0.01267	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46011	 46122	 0.000526	 0.005826	 0.05547	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46011	 90812	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46012	 90814	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46013	 46015	 0.001522	 0.00598	 0.00156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90812	 46013	 0.002446	 0.00635	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90814	 46013	 0.001417	 0.005996	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46014	 46688	 0.023217	 0.028819	 0.00063	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46014	 90816	 0.006962	 0.011995	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46015	 46016	 0.000808	 0.002772	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46015	 90816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46015	 90816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46016	 46019	 0.001444	 0.004323	 0.00097	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46016	 46020	 0.001297	 0.003616	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90816	 46017	 0.024532	 0.019415	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46018	 46688	 0.018985	 0.015024	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46018	 90817	 0.016026	 0.012683	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46019	 46218	 0.002043	 0.0054	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46019	 90817	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46019	 90817	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46020	 46032	 0.002178	 0.005474	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46020	 90818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46020	 90818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46021	 46028	 0.001152	 0.003841	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90812	 46021	 0.001289	 0.006937	 0.00191	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46021	 90819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46021	 90819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46022	 46024	 0.002872	 0.007221	 0.00187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90812	 46022	 0.001529	 0.005538	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46022	 90820	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46022	 90820	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46023	 46026	 0.004552	 0.013977	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90820	 46023	 0.022109	 0.024318	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46023	 90821	 0.007095	 0.017609	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46024	 46025	 0.001776	 0.007111	 0.00179	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46024	 90821	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46024	 90821	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46024	 90863	 0.00115	 0.009858	 0.00281	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46025	 46036	 0.000772	 0.00265	 0.00063	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46026	 46035	 0.019529	 0.012643	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46026	 90822	 0.020418	 0.015662	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46027	 46028	 0.000993	 0.002625	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46027	 46034	 0.001182	 0.002848	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46027	 90822	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46027	 90822	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46028	 46033	 0.001214	 0.003151	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46028	 90823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46028	 90823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46029	 46030	 0.008982	 0.009072	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90819	 46029	 0.00856	 0.016948	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46030	 46031	 0.012749	 0.008254	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90823	 46030	 0.020374	 0.016124	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46031	 90824	 0.011844	 0.007668	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46032	 46048	 0.000839	 0.002217	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46032	 90824	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46032	 90824	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46033	 46047	 0.001643	 0.004412	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46034	 46044	 0.000837	 0.002334	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46034	 90825	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46034	 90825	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90825	 46035	 0.018312	 0.014354	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46035	 90826	 0.017689	 0.013998	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46036	 46039	 0.001018	 0.002642	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46036	 90826	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46036	 90826	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46037	 46038	 0.008385	 0.011021	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46037	 90865	 0.007182	 0.01422	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46038	 46058	 0.008392	 0.013996	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46039	 46056	 0.001424	 0.003763	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46039	 90827	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46039	 90827	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46040	 46041	 0.011773	 0.009228	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90827	 46040	 0.012402	 0.009815	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46040	 90828	 0.010915	 0.008269	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46041	 90834	 0.016739	 0.013247	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46042	 90828	 0.012096	 0.009482	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46042	 90834	 0.011967	 0.00938	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46043	 46044	 0.000802	 0.002236	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46043	 46055	 0.001653	 0.004367	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46043	 90828	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46043	 90828	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46044	 90829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46044	 90829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90823	 46045	 0.029649	 0.023463	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90829	 46045	 0.017548	 0.013755	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90829	 46046	 0.013242	 0.010479	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46046	 90832	 0.013657	 0.010808	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46047	 46050	 0.00087	 0.002299	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46048	 46067	 0.001691	 0.004389	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46048	 90830	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46048	 90830	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46049	 46069	 0.017903	 0.012942	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90830	 46049	 0.011387	 0.011389	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46049	 90868	 0.029046	 0.018804	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46050	 46051	 0.001226	 0.003241	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46050	 90831	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46050	 90831	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46051	 46053	 0.001154	 0.002995	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46051	 46064	 0.00195	 0.004527	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46051	 90832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46051	 90832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90832	 46052	 0.011757	 0.009305	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46052	 90833	 0.013275	 0.010183	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46053	 46055	 0.000803	 0.002085	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46053	 46064	 0.001013	 0.00263	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46053	 90833	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46053	 90833	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90833	 46054	 0.011805	 0.008685	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46055	 46064	 0.001816	 0.004799	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46055	 90834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46055	 90834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46056	 46062	 0.001187	 0.002985	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46056	 90835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46056	 90835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46057	 46058	 0.011095	 0.012203	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90835	 46057	 0.013518	 0.010698	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46057	 90837	 0.015404	 0.012074	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46058	 46060	 0.019016	 0.015049	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46058	 46061	 0.014729	 0.010836	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90827	 46058	 0.017471	 0.022963	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46058	 90844	 0.033742	 0.066806	 0.00098	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46059	 46214	 0.000752	 0.002579	 0.00062	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46059	 90836	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46059	 90836	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46060	 46083	 0.00995	 0.0078	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46061	 46081	 0.016655	 0.010782	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46062	 90837	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46062	 90837	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46063	 46078	 0.011885	 0.009316	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46064	 46076	 0.001062	 0.002851	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46064	 46104	 0.001844	 0.005143	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46064	 90838	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46064	 90838	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46065	 46066	 0.01944	 0.012586	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46065	 46074	 0.013807	 0.010926	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90838	 46065	 0.012955	 0.008387	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46066	 46073	 0.016916	 0.012229	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90831	 46066	 0.017756	 0.014052	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46066	 90839	 0.018518	 0.014655	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46067	 46068	 0.000811	 0.002207	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46068	 46225	 0.002045	 0.004746	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46068	 90839	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46068	 90839	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46069	 46070	 0.012155	 0.009619	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90839	 46069	 0.009384	 0.010321	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46070	 46071	 0.019532	 0.015457	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46071	 46224	 0.025587	 0.018825	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46072	 46224	 0.014172	 0.011216	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90839	 46072	 0.012247	 0.009692	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46073	 90871	 0.013319	 0.008947	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46074	 46106	 0.005112	 0.00913	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46075	 90840	 0.008341	 0.006538	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46076	 46104	 0.000614	 0.002107	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46076	 90840	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46076	 90840	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46077	 46102	 0.006405	 0.006976	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90840	 46077	 0.003324	 0.006581	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46078	 46080	 0.013003	 0.01029	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46078	 46102	 0.005653	 0.010161	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90837	 46078	 0.016186	 0.012809	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46079	 46080	 0.008913	 0.007054	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46079	 46100	 0.010722	 0.008485	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90837	 46080	 0.011584	 0.007499	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46081	 46083	 0.010121	 0.007446	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46081	 90890	 0.017893	 0.01827	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46082	 46083	 0.010036	 0.007604	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46082	 46085	 0.003382	 0.007107	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46082	 46097	 0.004426	 0.008762	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46084	 46085	 0.004024	 0.006164	 0.00011	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90836	 46084	 0.009542	 0.012418	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46085	 46086	 0.008127	 0.008938	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46085	 46096	 0.011824	 0.009357	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46086	 46087	 0.007621	 0.005974	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46087	 46093	 0.016227	 0.010506	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46088	 46217	 0.000891	 0.002354	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46088	 90841	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46088	 90841	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46089	 46092	 0.019318	 0.019375	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46089	 46216	 0.018453	 0.014155	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90841	 46089	 0.014109	 0.011165	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46090	 46091	 0.011462	 0.009071	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90841	 46090	 0.016494	 0.012135	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46091	 46092	 0.009006	 0.009008	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46092	 46093	 0.011103	 0.008169	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46092	 46094	 0.010418	 0.00738	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46092	 46115	 0.010716	 0.007884	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46092	 46137	 0.02428	 0.031598	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46094	 46095	 0.0037	 0.005668	 8e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46095	 46096	 0.002042	 0.003669	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46096	 46290	 0.003222	 0.00638	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46097	 46098	 0.002409	 0.005592	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46097	 90890	 0.0088	 0.008986	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46098	 46099	 0.001953	 0.004105	 7e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46099	 46100	 0.005666	 0.004014	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46099	 46287	 0.008689	 0.009464	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46100	 46101	 0.005171	 0.005688	 8e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46101	 46102	 0.003858	 0.006499	 9e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46102	 90844	 0.006871	 0.024545	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46103	 46110	 0.0144	 0.009673	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46103	 90842	 0.008805	 0.006968	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46104	 46109	 0.00059	 0.002362	 0.0006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46104	 46225	 0.001793	 0.005981	 0.00152	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46104	 90842	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46104	 90842	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46104	 90843	 0.001254	 0.005309	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46105	 46106	 0.008904	 0.007046	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90842	 46105	 0.008356	 0.005409	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46106	 46107	 0.005355	 0.009021	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46107	 46108	 0.009216	 0.007293	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46107	 90844	 0.007311	 0.01672	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46109	 90843	 0.000666	 0.002749	 0.00065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46110	 46111	 0.009594	 0.007593	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46110	 46112	 0.002661	 0.008876	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46110	 46121	 0.008522	 0.00616	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46110	 90844	 0.00302	 0.012343	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46112	 46287	 0.002794	 0.007181	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46113	 46289	 0.008494	 0.005706	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46114	 46118	 0.008006	 0.006275	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46115	 46118	 0.009573	 0.007503	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46115	 46302	 0.004476	 0.003236	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46116	 46119	 0.004447	 0.007992	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46116	 46301	 0.003097	 0.006132	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46117	 46119	 0.006677	 0.005234	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46118	 46293	 0.010159	 0.020114	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46119	 46120	 0.007433	 0.005265	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46119	 46136	 0.012336	 0.009762	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46119	 46137	 0.008085	 0.008166	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46119	 90892	 0.003903	 0.012879	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46121	 46133	 0.003599	 0.006062	 9e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46122	 46204	 0.000513	 0.005808	 0.05288	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46122	 46300	 7.3e-05	 0.000771	 0.00804	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46122	 90843	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46123	 46124	 0.014106	 0.01082	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90844	 46123	 0.017862	 0.014001	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46125	 46229	 0.000698	 0.001947	 0.00041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46125	 46230	 0.002048	 0.005413	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46125	 90845	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46125	 90845	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46126	 46228	 0.013609	 0.010667	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46127	 46236	 0.016877	 0.012417	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46127	 90875	 0.039743	 0.031452	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46127	 90889	 0.033767	 0.026468	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46128	 46129	 0.010043	 0.009865	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90845	 46128	 0.011445	 0.009057	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46128	 90875	 0.012712	 0.011391	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90845	 46129	 0.012811	 0.010138	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46129	 90846	 0.008895	 0.029352	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46129	 90873	 0.017954	 0.011623	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46130	 90846	 0.010052	 0.007955	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90843	 46131	 0.001177	 0.003111	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46131	 90846	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46131	 90846	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46131	 90894	 0.000604	 0.002136	 0.00048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46132	 46133	 0.002152	 0.004218	 6e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90846	 46132	 0.002325	 0.005976	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46133	 46134	 0.00909	 0.007126	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46134	 46140	 0.000827	 0.004035	 7e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46134	 46141	 0.001788	 0.005963	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46134	 46294	 0.010684	 0.006917	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90846	 46134	 0.00422	 0.009993	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46135	 46293	 0.008626	 0.005794	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46135	 90892	 0.00335	 0.009608	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46137	 90897	 0.002762	 0.010745	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46138	 46288	 0.001806	 0.005067	 0.0013	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46138	 46297	 0.000462	 0.001585	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46138	 90847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46138	 90847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46139	 46140	 0.000761	 0.003713	 6e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90847	 46139	 0.000925	 0.003238	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90846	 46141	 0.010859	 0.008593	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46141	 90895	 0.006022	 0.011923	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46142	 46153	 0.001261	 0.003332	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46142	 90848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46142	 90848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46143	 46144	 0.004323	 0.008278	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89011	 46143	 0.010868	 0.015146	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46144	 46147	 0.008066	 0.006383	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46144	 46148	 0.003692	 0.010589	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46144	 90895	 0.001552	 0.007194	 0.00014	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46145	 90895	 0.013318	 0.01054	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46146	 46155	 0.007535	 0.012694	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46146	 46156	 0.003372	 0.006677	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46146	 90895	 0.00332	 0.014795	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46148	 46149	 0.011753	 0.008905	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46148	 46154	 0.010033	 0.00794	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90848	 46149	 0.008087	 0.0064	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46150	 46151	 0.000653	 0.001725	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46150	 46298	 0.000841	 0.002222	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46151	 46299	 0.00096	 0.002676	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46151	 90849	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46151	 90849	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90849	 46152	 0.009661	 0.006984	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46152	 90850	 0.008573	 0.006785	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46153	 46160	 0.000831	 0.002318	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46153	 90850	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46153	 90850	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46154	 46159	 0.007713	 0.006104	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90850	 46154	 0.009969	 0.00789	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46155	 46158	 0.011017	 0.008105	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46155	 46159	 0.014225	 0.011257	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46156	 90877	 0.015557	 0.012195	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46157	 46158	 0.008673	 0.006143	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46159	 46171	 0.009276	 0.006005	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46159	 90851	 0.010667	 0.008442	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46160	 46170	 0.000809	 0.002139	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46160	 90851	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46160	 90851	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90851	 46161	 0.008617	 0.006229	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46161	 90854	 0.00826	 0.007401	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46162	 46163	 0.000884	 0.002272	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46162	 46167	 0.000787	 0.002044	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46162	 46299	 0.00075	 0.002012	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46163	 46164	 0.001236	 0.002979	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46164	 46166	 0.000623	 0.0015	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46165	 46191	 0.010321	 0.006682	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46166	 46190	 0.001216	 0.00293	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46167	 90852	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46167	 90852	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46168	 46188	 0.000803	 0.002121	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46168	 46190	 0.001807	 0.00469	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46168	 90853	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46168	 90853	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46168	 90861	 0.001535	 0.008991	 0.00245	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46169	 46170	 0.000597	 0.00155	 0.00038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46169	 46188	 0.000805	 0.002128	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46169	 90854	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46169	 90854	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46170	 90855	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46170	 90855	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46172	 46173	 0.010081	 0.01325	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46172	 90856	 0.005123	 0.012717	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46173	 46181	 0.025965	 0.023916	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46173	 90877	 0.02738	 0.021668	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46174	 46254	 0.009928	 0.007782	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46174	 90856	 0.015357	 0.012037	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46175	 46181	 0.017874	 0.014145	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46175	 46245	 0.017035	 0.013067	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46176	 46245	 0.015648	 0.012384	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46177	 46178	 0.01171	 0.007581	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46177	 46242	 0.023434	 0.015171	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46178	 46251	 0.019361	 0.014851	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46179	 46180	 0.014468	 0.011449	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46179	 46181	 0.021632	 0.016956	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46179	 46247	 0.014866	 0.011652	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46180	 46251	 0.018999	 0.015036	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46180	 46252	 0.0146	 0.014746	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46181	 46182	 0.008352	 0.012795	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46182	 46255	 0.008379	 0.01506	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46183	 46185	 0.000654	 0.00305	 0.00076	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46183	 46248	 0.003455	 0.009635	 0.00202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46183	 90856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46183	 90856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46184	 46187	 0.009149	 0.010063	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90856	 46184	 0.011993	 0.011996	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46185	 46196	 0.000457	 0.002097	 0.00054	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46186	 46187	 0.004195	 0.010783	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90853	 46186	 0.016665	 0.010789	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46186	 90862	 0.009172	 0.028166	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90855	 46187	 0.011707	 0.009265	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46189	 46192	 0.003755	 0.011043	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90852	 46189	 0.004738	 0.011761	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90853	 46189	 0.012978	 0.01027	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46189	 90857	 0.01376	 0.008908	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46190	 46285	 0.001663	 0.004395	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46190	 90857	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46190	 90857	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90857	 46191	 0.016838	 0.013325	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46192	 46193	 0.01219	 0.009555	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46192	 46194	 0.004633	 0.010757	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46193	 90862	 0.007181	 0.023697	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46193	 90888	 0.008481	 0.016792	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46194	 90858	 0.003036	 0.007722	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46195	 46196	 0.001184	 0.00395	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46195	 90858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46195	 90858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46195	 90861	 0.000576	 0.003301	 0.0011	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46196	 90859	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46196	 90859	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90859	 46197	 0.004405	 0.008634	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46197	 90860	 0.005094	 0.013095	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46198	 46263	 0.005011	 0.013973	 0.00293	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46198	 90860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46198	 90860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46198	 90861	 0.001186	 0.004193	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46199	 46200	 5e-05	 0.0005	 0.00823	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46199	 46300	 0.000325	 0.003623	 0.03416	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46199	 90861	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46200	 46267	 7.3e-05	 0.000922	 0.01404	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46201	 46256	 0.01166	 0.008579	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46201	 46257	 0.015554	 0.015882	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46201	 46262	 0.030758	 0.024341	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90860	 46201	 0.004167	 0.014885	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46202	 46204	 7.7e-05	 0.000765	 0.01309	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46202	 46396	 8.3e-05	 0.000836	 0.01376	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46203	 90864	 0.015796	 0.011419	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46204	 90863	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46205	 46207	 0.006623	 0.025764	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46205	 46395	 0.026968	 0.036762	 0.00082	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90864	 46205	 0.010474	 0.026925	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46206	 46207	 0.016808	 0.016977	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90813	 46206	 0.02624	 0.028861	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90821	 46207	 0.039254	 0.030769	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46208	 46209	 0.005554	 0.01593	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90864	 46208	 0.005945	 0.026489	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90821	 46209	 0.007063	 0.013984	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46210	 46211	 0.000747	 0.003252	 0.00093	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46210	 46213	 0.001279	 0.003482	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46210	 90865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46210	 90865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46211	 46213	 0.001041	 0.004089	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90863	 46211	 0.001024	 0.010702	 0.00294	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46212	 90866	 0.00578	 0.01043	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46212	 90867	 0.026496	 0.020769	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46213	 46214	 0.000826	 0.00314	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46213	 90866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46213	 90866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46214	 46217	 0.001284	 0.003447	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46214	 90867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46214	 90867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46215	 46216	 0.014211	 0.011247	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90836	 46215	 0.013664	 0.016657	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90867	 46215	 0.004482	 0.008873	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46218	 46219	 0.001738	 0.004593	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46218	 46686	 0.005374	 0.013927	 0.00421	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46218	 90868	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46218	 90868	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46219	 46220	 0.001609	 0.004252	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46220	 46286	 0.002074	 0.005481	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46220	 90869	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46220	 90869	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46221	 46237	 0.001604	 0.004239	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46221	 46286	 0.001631	 0.004309	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46221	 90870	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46221	 90870	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46222	 46223	 0.01123	 0.008614	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46222	 46226	 0.026389	 0.020685	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90869	 46222	 0.033641	 0.024751	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46222	 90889	 0.025256	 0.019797	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46223	 46224	 0.010369	 0.007629	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46224	 90871	 0.005257	 0.008732	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46225	 46227	 0.002035	 0.004904	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46225	 90871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46225	 90871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46226	 90872	 0.013308	 0.010432	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46227	 46229	 0.001078	 0.002895	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46227	 90872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46227	 90872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90845	 46228	 0.019088	 0.015106	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90872	 46228	 0.015854	 0.012546	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46230	 46231	 0.000375	 0.001263	 0.00031	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46230	 46248	 0.001008	 0.003457	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46230	 90873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46230	 90873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46231	 46232	 0.001001	 0.002572	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46231	 90874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46231	 90874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46232	 90875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46232	 90875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46233	 46235	 0.010622	 0.010625	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90875	 46233	 0.003773	 0.007471	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46234	 46235	 0.012613	 0.009981	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46234	 46243	 0.011257	 0.008908	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46234	 46244	 0.024893	 0.0197	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46237	 46238	 0.001606	 0.004312	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46238	 46239	 0.00203	 0.005527	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46238	 90876	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46238	 90876	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46239	 46250	 0.002063	 0.005451	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46239	 91009	 0.003175	 0.010891	 0.00261	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46240	 46242	 0.013758	 0.012801	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46240	 46702	 0.01195	 0.030392	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46241	 46242	 0.011758	 0.009216	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46242	 46243	 0.011702	 0.009173	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90875	 46242	 0.041429	 0.032787	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46244	 46246	 0.008735	 0.006846	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90874	 46244	 0.008476	 0.016782	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90874	 46245	 0.01894	 0.013935	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46246	 46247	 0.01334	 0.010456	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46248	 90877	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46248	 90877	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46248	 90894	 0.000775	 0.005725	 0.00165	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46249	 46250	 0.001656	 0.004617	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46249	 46258	 0.001849	 0.005155	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46251	 90878	 0.022309	 0.037581	 0.00054	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46252	 46253	 0.018242	 0.014436	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46252	 90879	 0.009125	 0.028974	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46255	 46257	 0.003331	 0.014842	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90862	 46257	 0.006539	 0.026214	 0.00068	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46258	 46260	 0.002146	 0.005572	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46258	 46266	 0.00335	 0.00934	 0.00196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46258	 90878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46258	 90878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46259	 46706	 0.024157	 0.019118	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90878	 46259	 0.019567	 0.01386	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46260	 46261	 0.001611	 0.004385	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46261	 46263	 0.002492	 0.008684	 0.00201	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46261	 90879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46261	 90879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90879	 46262	 0.009178	 0.015044	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46262	 90880	 0.01371	 0.024738	 0.00036	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46263	 46304	 0.002016	 0.008534	 0.00192	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46263	 90880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46263	 90880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46264	 46714	 0.043925	 0.032317	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90879	 46264	 0.092593	 0.059947	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46264	 90896	 0.077231	 0.056822	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46265	 46266	 0.002858	 0.007554	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46265	 46303	 0.003125	 0.007857	 0.00204	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46267	 90881	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46268	 46275	 0.000818	 0.004874	 0.00128	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88989	 46268	 0.001236	 0.011868	 0.00345	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46268	 90883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46268	 90883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46269	 46271	 0.003456	 0.012516	 0.00269	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46269	 46304	 0.003117	 0.011285	 0.00242	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90881	 46269	 0.002357	 0.005925	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90883	 46270	 0.046015	 0.050612	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88989	 46271	 0.001923	 0.012384	 0.00325	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46272	 46278	 0.008895	 0.014197	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46272	 46282	 0.010413	 0.019072	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46272	 90884	 0.022926	 0.018143	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46272	 90887	 0.037317	 0.029532	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46273	 46274	 0.000944	 0.003711	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46273	 46283	 0.001031	 0.004364	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46273	 90884	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46273	 90884	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46274	 46275	 0.000563	 0.003088	 0.00082	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46274	 90885	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46274	 90885	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46276	 46278	 0.014545	 0.011511	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46277	 46278	 0.014216	 0.010905	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90885	 46277	 0.005522	 0.010934	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90883	 46278	 0.006172	 0.032884	 0.00058	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46279	 46280	 0.013689	 0.010833	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46280	 46282	 0.021888	 0.021893	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46280	 90886	 0.018187	 0.012216	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46281	 46283	 0.001061	 0.003711	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46281	 46285	 0.001536	 0.005562	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46281	 90886	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46281	 90886	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46282	 90887	 0.021641	 0.015922	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46283	 90887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46283	 90887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46284	 90888	 0.021319	 0.015412	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46285	 90888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46285	 90888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46286	 90889	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46286	 90889	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46287	 90891	 0.012146	 0.009612	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46288	 46292	 0.000857	 0.002066	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46288	 90890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46288	 90890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46289	 46293	 0.012224	 0.009581	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90890	 46290	 0.004964	 0.012624	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46291	 46294	 0.008431	 0.006672	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46292	 90891	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46292	 90891	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90890	 46293	 0.004576	 0.008225	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90847	 46295	 0.003868	 0.006952	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90891	 46295	 0.003817	 0.005956	 0.0001	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46296	 90892	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46296	 90892	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46297	 90894	 0.00075	 0.004752	 0.00129	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46298	 90893	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46298	 90893	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46300	 90894	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46301	 46302	 0.004152	 0.005217	 8e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46303	 90896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46303	 90896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46303	 90943	 0.015856	 0.052901	 0.01342	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46304	 46646	 0.045397	 0.16455	 0.03535	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90861	 46304	 0.007946	 0.019149	 0.00541	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46305	 90897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46305	 90897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46306	 90900	 0.15875	 0.10279	 0.00196	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46307	 90898	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46307	 90898	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46308	 90899	 0.029397	 0.046924	 0.00108	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46309	 46314	 0.014559	 0.036599	 0.00948	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90898	 46309	 0.008697	 0.028365	 0.00753	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46309	 90899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46309	 90899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46310	 46313	 0.25493	 0.20179	 0.00254	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90899	 46310	 0.04661	 0.19051	 0.00385	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46310	 90900	 0.020075	 0.039747	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90898	 46311	 0.014247	 0.057049	 0.01438	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46311	 90900	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46311	 90900	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90900	 46312	 0.20595	 0.1489	 0.00226	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46314	 46615	 0.018986	 0.050975	 0.01155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46315	 46316	 0.23252	 0.25581	 0.00341	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46316	 46318	 0.24008	 0.2212	 0.00355	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46317	 46318	 0.11253	 0.12377	 0.00165	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46318	 90901	 0.031293	 0.10439	 0.00165	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46319	 90901	 0.16126	 0.11866	 0.00174	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46320	 46321	 0.047978	 0.090678	 0.00147	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90810	 46320	 0.043206	 0.11107	 0.00172	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46321	 46322	 0.072897	 0.11167	 0.00157	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90810	 46321	 0.10695	 0.20963	 0.00314	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46321	 90901	 0.28531	 0.22585	 0.00284	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46322	 46324	 0.17844	 0.14123	 0.00178	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46323	 90901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46323	 90901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90665	 46324	 0.19578	 0.15348	 0.00197	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46325	 46326	 0.2326	 0.2559	 0.00342	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46326	 90904	 0.05573	 0.13197	 0.00241	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46327	 46338	 0.076089	 0.059643	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46327	 90904	 0.015925	 0.030854	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46328	 90902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46328	 90902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46328	 90903	 0.009669	 0.025553	 0.00598	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90902	 46329	 0.12944	 0.10147	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46329	 90904	 0.15586	 0.11809	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46330	 46338	 0.22816	 0.18059	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46331	 46336	 0.034583	 0.080278	 0.00153	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46331	 46624	 0.061075	 0.0953	 0.00159	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46332	 46334	 0.19897	 0.18662	 0.00288	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46332	 46336	 0.057973	 0.11478	 0.00168	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90902	 46332	 0.13825	 0.24139	 0.00374	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46333	 46334	 0.28064	 0.19885	 0.00314	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46333	 46335	 0.20205	 0.15992	 0.00201	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46333	 46431	 0.62398	 0.49447	 0.00623	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46334	 46431	 0.20475	 0.33392	 0.00509	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90902	 46335	 0.19093	 0.15112	 0.0019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46336	 46620	 0.24952	 0.19751	 0.00249	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46337	 90903	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90904	 46338	 0.014996	 0.028718	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46339	 46342	 0.001441	 0.003922	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46339	 90905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46339	 90905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46340	 46341	 0.006591	 0.013049	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46340	 46351	 0.008731	 0.011475	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90905	 46341	 0.003179	 0.006295	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46341	 90906	 0.020184	 0.020387	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46341	 90907	 0.038082	 0.030138	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46342	 46343	 0.001234	 0.004362	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46342	 90906	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46342	 90906	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46343	 46356	 0.001746	 0.006083	 0.00141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46344	 46357	 0.011178	 0.036888	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90906	 46344	 0.035271	 0.027913	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46345	 46350	 0.005844	 0.01517	 0.00368	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46345	 46356	 0.002527	 0.010433	 0.00247	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46345	 90907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46345	 90907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46346	 46811	 0.012233	 0.016078	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90907	 46346	 0.010108	 0.018167	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46347	 90908	 0.01654	 0.013089	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46348	 46350	 0.002841	 0.007375	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46348	 46350	 0.002841	 0.007375	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46348	 46810	 0.005228	 0.013816	 0.00323	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46348	 46810	 0.005228	 0.013816	 0.00323	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46348	 46817	 0.006449	 0.017043	 0.00399	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46348	 46817	 0.006449	 0.017043	 0.00399	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46348	 90908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46348	 90908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46349	 46351	 0.02089	 0.013524	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46349	 46365	 0.045744	 0.030728	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46349	 90909	 0.032924	 0.026056	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46350	 46352	 0.002755	 0.009451	 0.00226	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46350	 46371	 0.020878	 0.056058	 0.01271	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46350	 46422	 0.074034	 0.19253	 0.04682	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90662	 46350	 0.038224	 0.088769	 0.02706	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46350	 90909	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46350	 90909	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46352	 46354	 0.001192	 0.004091	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46352	 90910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46352	 90910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46353	 46366	 0.053137	 0.042052	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90910	 46353	 0.020728	 0.014682	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46354	 46355	 0.00127	 0.005242	 0.00124	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46354	 90911	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46354	 90911	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46355	 46359	 0.001482	 0.01028	 0.00293	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46355	 90912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46355	 90912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46357	 90913	 0.004568	 0.022267	 0.00042	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46358	 46359	 0.001022	 0.003013	 0.0007	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46359	 46364	 0.000803	 0.008257	 0.00234	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46359	 90913	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46359	 90913	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89021	 46360	 0.004904	 0.012998	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89023	 46360	 0.011937	 0.036658	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89023	 46361	 0.007341	 0.018668	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46363	 46364	 0.000714	 0.002497	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46363	 90914	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46363	 90914	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46364	 46377	 0.001355	 0.007785	 0.00221	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46365	 46366	 0.025142	 0.027384	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46366	 46373	 0.11641	 0.085652	 0.00125	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90912	 46366	 0.012321	 0.028599	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46367	 46372	 0.076105	 0.15069	 0.00221	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46367	 46374	 0.078369	 0.079156	 0.00105	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90909	 46367	 0.014274	 0.0338	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90909	 46368	 0.0209	 0.032016	 0.00045	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46368	 91038	 0.028744	 0.041884	 0.00095	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46369	 46370	 0.13582	 0.099934	 0.00146	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90909	 46369	 0.025463	 0.065456	 0.00101	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46371	 46422	 0.049371	 0.14569	 0.03393	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46371	 46772	 0.024993	 0.066065	 0.01547	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46371	 90915	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46371	 90915	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46372	 46376	 0.1796	 0.12985	 0.00197	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46373	 46374	 0.063005	 0.10508	 0.00153	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46373	 46378	 0.0523	 0.12385	 0.00226	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46373	 90916	 0.018136	 0.074123	 0.0015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46375	 46378	 0.078928	 0.086813	 0.00116	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46377	 90916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46377	 90916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90666	 46378	 0.1078	 0.085316	 0.00107	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46379	 46596	 0.009758	 0.02265	 0.0069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46379	 46653	 0.009674	 0.02487	 0.00616	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46379	 90919	 0.011366	 0.030039	 0.00703	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46380	 46383	 0.000293	 0.003258	 0.03072	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46380	 46597	 0.000373	 0.004304	 0.03773	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46381	 46654	 0.008413	 0.025195	 0.00568	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89008	 46381	 0.006053	 0.023791	 0.00622	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46382	 90917	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46382	 90917	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46383	 90918	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90919	 46383	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89009	 46384	 0.006711	 0.026109	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46384	 90920	 0.037906	 0.087088	 0.00132	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46385	 46389	 0.001403	 0.009777	 0.00368	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46385	 90920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46385	 90920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46385	 90921	 0.000698	 0.006093	 0.00241	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46386	 46396	 0.00042	 0.004238	 0.06976	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46386	 90921	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46386	 90921	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46387	 46388	 0.007152	 0.016605	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90920	 46387	 0.009214	 0.020901	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46388	 46390	 0.050484	 0.039953	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46388	 90923	 0.035565	 0.065141	 0.00112	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46389	 46393	 0.002378	 0.010705	 0.00285	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46389	 90922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46389	 90922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90920	 46390	 0.027886	 0.055212	 0.00081	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46390	 90996	 0.2192	 0.17185	 0.00221	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46391	 46395	 0.058813	 0.046544	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46391	 90923	 0.009069	 0.017957	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90922	 46392	 0.027489	 0.070663	 0.00109	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90814	 46393	 0.010019	 0.027938	 0.00586	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46393	 90923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46393	 90923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46394	 46395	 0.04399	 0.034813	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90923	 46394	 0.014637	 0.026809	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90668	 46397	 0.013848	 0.0366	 0.00857	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46397	 90924	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46397	 90924	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46398	 46406	 0.25135	 0.18174	 0.00276	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90617	 46398	 0.069044	 0.1775	 0.00275	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90669	 46398	 0.22982	 0.18191	 0.00229	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90924	 46398	 0.13995	 0.26807	 0.00422	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46399	 46406	 0.041625	 0.1422	 0.00309	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46400	 46405	 0.006487	 0.022608	 0.00524	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46400	 46541	 0.012449	 0.032321	 0.00785	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46401	 46541	 0.0085	 0.022464	 0.00526	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46401	 90925	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46401	 90925	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46402	 46403	 0.034413	 0.089188	 0.00169	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90925	 46402	 0.023354	 0.033153	 0.00055	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90358	 46403	 0.019751	 0.12143	 0.00219	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46404	 46406	 0.075264	 0.2085	 0.00344	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88938	 46404	 0.016923	 0.067725	 0.00143	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90376	 46404	 0.045533	 0.10571	 0.00157	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46405	 46538	 0.023054	 0.077695	 0.01932	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88937	 46405	 0.008065	 0.048046	 0.01264	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88950	 46405	 0.037275	 0.098554	 0.02308	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90737	 46405	 0.054885	 0.19157	 0.04451	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46407	 46409	 0.26073	 0.20639	 0.0026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90647	 46407	 0.27584	 0.21627	 0.00278	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46409	 46411	 0.1199	 0.086676	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46410	 46411	 0.18126	 0.14346	 0.00181	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46410	 46416	 0.1891	 0.14507	 0.00195	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46411	 46412	 0.06205	 0.099047	 0.00228	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46413	 46414	 0.058359	 0.13549	 0.00202	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88936	 46413	 0.048781	 0.21621	 0.00649	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46414	 46415	 0.084929	 0.11837	 0.00202	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46415	 46416	 0.027753	 0.097112	 0.00201	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46415	 46536	 0.050346	 0.16796	 0.00266	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46417	 46768	 0.064343	 0.18456	 0.00284	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90804	 46417	 0.12201	 0.24975	 0.00615	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46418	 46420	 0.005414	 0.031708	 0.00864	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46418	 46428	 0.009106	 0.038543	 0.00867	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46418	 90926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46418	 90926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46419	 90927	 0.035352	 0.022887	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46420	 46428	 0.008407	 0.021612	 0.00535	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46420	 90927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46420	 90927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90927	 46421	 0.027399	 0.041076	 0.00075	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46422	 46423	 0.00993	 0.034066	 0.00816	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46422	 46428	 0.010415	 0.057156	 0.01511	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46422	 46770	 0.010998	 0.043229	 0.01131	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46423	 46424	 0.004247	 0.011224	 0.00263	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46423	 46428	 0.006523	 0.026544	 0.00647	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46424	 90928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46424	 90928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90927	 46425	 0.005243	 0.032235	 0.00058	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90928	 46425	 0.004561	 0.031309	 0.00057	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46426	 46427	 0.022173	 0.017547	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90927	 46426	 0.027913	 0.020536	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46427	 90929	 0.089375	 0.065758	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46428	 46835	 0.009818	 0.034704	 0.00782	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46428	 46836	 0.010643	 0.03651	 0.00875	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46428	 90929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46428	 90929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90929	 46429	 0.083482	 0.1653	 0.00243	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46430	 46780	 0.067338	 0.14154	 0.00258	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90928	 46430	 0.064881	 0.21647	 0.00343	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46430	 91030	 0.33532	 0.26546	 0.00334	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46431	 46434	 0.25814	 0.20239	 0.0026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46431	 90930	 0.047913	 0.12185	 0.00193	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46432	 46528	 0.041339	 0.19311	 0.04793	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90903	 46432	 0.085031	 0.20539	 0.05814	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46432	 90930	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46432	 90930	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46433	 46434	 0.25445	 0.18398	 0.00279	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46433	 46436	 0.35814	 0.28355	 0.00357	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46433	 46560	 0.47651	 0.3738	 0.0048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90930	 46433	 0.31532	 0.31862	 0.00422	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90930	 46434	 0.18987	 0.31995	 0.00456	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46435	 46436	 0.32561	 0.25777	 0.00325	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46436	 46600	 0.10104	 0.23462	 0.00349	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46436	 90979	 0.57882	 0.37529	 0.00714	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46437	 46438	 0.019684	 0.01423	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46437	 90932	 0.005774	 0.008846	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46438	 90931	 0.009325	 0.00731	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46439	 46440	 0.002098	 0.005545	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46439	 46443	 0.001331	 0.004161	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46439	 90931	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46439	 90931	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46439	 90943	 0.008882	 0.022327	 0.00578	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46440	 46455	 0.000972	 0.003333	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46440	 90932	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46440	 90932	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46441	 46442	 0.004699	 0.008607	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90931	 46441	 0.014294	 0.010964	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46442	 46450	 0.003697	 0.010604	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46443	 90933	 0.000954	 0.005585	 0.00152	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90768	 46444	 0.049604	 0.050102	 0.00066	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46444	 90934	 0.011589	 0.02979	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46445	 46446	 8.2e-05	 0.000895	 0.00869	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46445	 90933	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46446	 90935	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46446	 90935	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46447	 90942	 0.032606	 0.023096	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46447	 90944	 0.064209	 0.050815	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46448	 46449	 0.013618	 0.010318	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46448	 46467	 0.035365	 0.027988	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90934	 46448	 0.007425	 0.0147	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46449	 46450	 0.002472	 0.006552	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90934	 46449	 0.004026	 0.01343	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46451	 46453	 0.000276	 0.001749	 0.00366	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88991	 46451	 0.003048	 0.021375	 0.0364	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46451	 90936	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90937	 46451	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46452	 46453	 0.0003	 0.002022	 0.00372	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46452	 46458	 0.000452	 0.003116	 0.0055	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46452	 90938	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90939	 46452	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46454	 46455	 0.000577	 0.001926	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46454	 46456	 0.000884	 0.00374	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90938	 46456	 0.001465	 0.00533	 0.00163	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46456	 90940	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46456	 90940	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46457	 46458	 0.000438	 0.003593	 0.00647	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88997	 46457	 0.000284	 0.002444	 0.0046	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46458	 90941	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46458	 90941	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46459	 46460	 0.00761	 0.013939	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90941	 46459	 0.008388	 0.020532	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90940	 46460	 0.027268	 0.027542	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46461	 46465	 0.009339	 0.023475	 0.00608	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88989	 46461	 0.005745	 0.019358	 0.00481	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46462	 46466	 0.037349	 0.02418	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46462	 46467	 0.066962	 0.052489	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90883	 46462	 0.074931	 0.12515	 0.00213	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90939	 46462	 0.04893	 0.038723	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90941	 46462	 0.021257	 0.038934	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90933	 46463	 0.002889	 0.007427	 0.00184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90935	 46463	 0.003568	 0.009262	 0.00225	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46463	 90942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46463	 90942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46463	 90943	 0.002472	 0.006894	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46464	 90943	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90943	 46465	 0.003468	 0.009165	 0.00215	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46466	 46467	 0.030852	 0.024183	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90937	 46466	 0.040156	 0.030423	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90942	 46467	 0.05499	 0.040458	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90944	 46467	 0.068947	 0.054045	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46468	 90945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46468	 90945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89016	 46469	 0.026558	 0.055818	 0.00102	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90945	 46469	 0.034006	 0.052093	 0.00073	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46470	 46714	 0.078342	 0.097251	 0.00212	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90896	 46470	 0.038522	 0.06149	 0.00142	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90945	 46470	 0.01774	 0.099465	 0.00274	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46471	 46472	 0.052229	 0.057446	 0.00077	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46471	 46477	 0.089715	 0.070325	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46471	 46716	 0.050901	 0.077976	 0.00109	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46472	 90946	 0.041185	 0.094621	 0.00144	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46473	 90946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46473	 90946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46474	 46475	 0.017466	 0.026756	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46474	 46639	 0.043037	 0.11154	 0.00211	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46475	 46476	 0.025427	 0.045878	 0.00066	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46475	 46478	 0.056958	 0.062648	 0.00084	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46476	 46639	 0.074111	 0.1183	 0.00273	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90779	 46476	 0.12209	 0.12332	 0.00163	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90946	 46476	 0.069599	 0.11625	 0.00197	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46477	 46479	 0.033107	 0.050716	 0.00071	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90946	 46477	 0.033831	 0.097033	 0.00149	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46478	 46479	 0.1134	 0.083432	 0.00122	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46479	 46626	 0.11399	 0.090213	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46479	 46712	 0.16909	 0.12442	 0.00182	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90945	 46480	 0.010437	 0.02759	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90946	 46480	 0.021657	 0.044506	 0.00085	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46481	 46482	 0.014015	 0.037628	 0.00853	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46481	 46613	 0.014587	 0.037872	 0.00919	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46481	 90947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46481	 90947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46482	 46483	 0.004907	 0.011824	 0.00334	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46482	 90948	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46482	 90948	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46483	 46484	 0.003409	 0.009152	 0.00207	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46484	 46485	 0.006646	 0.026122	 0.00683	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46484	 46554	 0.01579	 0.090756	 0.02572	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88824	 46484	 0.040895	 0.16092	 0.04216	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46484	 90949	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46484	 90949	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46486	 46488	 0.01523	 0.012053	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46487	 46488	 0.00451	 0.015043	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46487	 46493	 0.004743	 0.01312	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46488	 90951	 0.003565	 0.012473	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46489	 46495	 0.002097	 0.007194	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46489	 46496	 0.001381	 0.005531	 0.00139	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46490	 46491	 0.001747	 0.004392	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46490	 46498	 0.003951	 0.010442	 0.00244	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46491	 46492	 0.001514	 0.007164	 0.00172	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46491	 46495	 0.000893	 0.00811	 0.00264	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46491	 90950	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46491	 90950	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46492	 46501	 0.0015	 0.005432	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46493	 46494	 0.021279	 0.01684	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90950	 46493	 0.018778	 0.018966	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46493	 90953	 0.023331	 0.066916	 0.00103	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89028	 46495	 0.001975	 0.021839	 0.00655	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46495	 90951	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46495	 90951	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46496	 46502	 0.002795	 0.011192	 0.00282	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46497	 46517	 0.18047	 0.14284	 0.0018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46497	 90955	 0.091933	 0.06764	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46498	 46520	 0.008624	 0.022791	 0.00533	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46498	 90952	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46498	 90952	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46499	 90954	 0.12428	 0.094166	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46499	 90955	 0.010674	 0.065623	 0.00118	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46499	 90983	 0.078185	 0.26087	 0.00414	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46500	 46501	 0.002396	 0.008349	 0.00194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46500	 46521	 0.005728	 0.019649	 0.00471	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46500	 90953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46500	 90953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46501	 90954	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46501	 90954	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88999	 46502	 0.001809	 0.01124	 0.00317	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46502	 90955	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46502	 90955	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90022	 46503	 0.002658	 0.009264	 0.00215	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46503	 90956	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46503	 90956	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46504	 46508	 0.02111	 0.016706	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89034	 46504	 0.011877	 0.014924	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46505	 46509	 0.028124	 0.018208	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89034	 46505	 0.009055	 0.014842	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46506	 46511	 0.0017	 0.004494	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89034	 46507	 0.017868	 0.014006	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90956	 46507	 0.015575	 0.012326	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46509	 46510	 0.045304	 0.033332	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89029	 46509	 0.091178	 0.069941	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46510	 46516	 0.10853	 0.13232	 0.00212	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46511	 46513	 0.001171	 0.003041	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46512	 90957	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46512	 90957	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90957	 46513	 0.002818	 0.007565	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46514	 46515	 0.001898	 0.012021	 0.00326	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89028	 46514	 0.002931	 0.010359	 0.00233	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90022	 46514	 0.007271	 0.025341	 0.00588	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90957	 46514	 0.000897	 0.005682	 0.00154	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46515	 46523	 0.005836	 0.024701	 0.00556	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46515	 46633	 0.005343	 0.045831	 0.01304	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90022	 46515	 0.001768	 0.021796	 0.00704	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90025	 46516	 0.068575	 0.13578	 0.00199	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90755	 46516	 0.17747	 0.13912	 0.00179	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90755	 46517	 0.092492	 0.18314	 0.00269	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90751	 46518	 0.23239	 0.18395	 0.00232	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90753	 46518	 0.071506	 0.18955	 0.00481	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90952	 46518	 0.2776	 0.17978	 0.00342	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46518	 90958	 0.27529	 0.21584	 0.00277	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46519	 46520	 0.005117	 0.013525	 0.00317	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46519	 90958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46519	 90958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46521	 46632	 0.008649	 0.041977	 0.0096	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46521	 90959	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46521	 90959	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90953	 46522	 0.021921	 0.067249	 0.00182	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46522	 90985	 0.04613	 0.13091	 0.00206	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46523	 46633	 0.006369	 0.024211	 0.00678	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46525	 90960	 0.24861	 0.19679	 0.00248	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46526	 46528	 0.015001	 0.046894	 0.01358	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46526	 46650	 0.05611	 0.14843	 0.03478	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46526	 90960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46526	 90960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46527	 90961	 0.13194	 0.10343	 0.00133	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46528	 90961	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46528	 90961	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46529	 46530	 0.025495	 0.016505	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46530	 46531	 0.023176	 0.054881	 0.001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46530	 46532	 0.042848	 0.03391	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88936	 46530	 0.020705	 0.06907	 0.00109	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46531	 46542	 0.18855	 0.14924	 0.00188	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46533	 46534	 0.039934	 0.099119	 0.00165	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88936	 46533	 0.022557	 0.10051	 0.00171	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46534	 46535	 0.021588	 0.051119	 0.00093	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46534	 46536	 0.03696	 0.07891	 0.00178	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88936	 46534	 0.057068	 0.18834	 0.00305	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46535	 46536	 0.025368	 0.042308	 0.00062	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46536	 90962	 0.16514	 0.21707	 0.00298	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46537	 90962	 0.04142	 0.10534	 0.00167	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46538	 90962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46538	 90962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46539	 46540	 0.10143	 0.10246	 0.00136	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90925	 46539	 0.027688	 0.030454	 0.00041	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46539	 90963	 0.10892	 0.08538	 0.0011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88936	 46540	 0.03236	 0.1133	 0.00314	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46541	 90963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46541	 90963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90962	 46542	 0.15667	 0.15825	 0.0021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90963	 46542	 0.048984	 0.096986	 0.00142	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46543	 46544	 0.047578	 0.15873	 0.00252	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46543	 46546	 0.11005	 0.071248	 0.00136	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46543	 46547	 0.17061	 0.13374	 0.00172	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90678	 46543	 0.11183	 0.17854	 0.00411	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46544	 46553	 0.039501	 0.071274	 0.00103	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46544	 90965	 0.10128	 0.080153	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46545	 46554	 0.012614	 0.041144	 0.01092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46545	 90964	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46545	 90964	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46546	 46547	 0.029633	 0.058671	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90964	 46546	 0.025052	 0.051267	 0.00126	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90964	 46548	 0.11536	 0.11539	 0.00156	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46549	 46551	 0.064392	 0.1847	 0.00284	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46551	 46555	 0.22249	 0.16372	 0.00239	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46552	 46553	 0.028699	 0.098037	 0.00213	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90947	 46552	 0.045993	 0.20583	 0.00424	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46553	 90965	 0.01998	 0.036595	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46554	 90965	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46554	 90965	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46556	 46558	 0.06786	 0.19958	 0.00409	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46556	 46561	 0.11339	 0.20462	 0.00296	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46556	 46647	 0.12678	 0.23225	 0.00401	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46556	 90991	 0.53946	 0.42735	 0.00538	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46557	 46561	 0.24329	 0.15755	 0.003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46557	 46649	 0.20522	 0.13787	 0.00243	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46559	 46561	 0.17846	 0.18027	 0.00239	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46562	 46571	 0.13047	 0.10227	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46563	 46565	 0.12942	 0.10242	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46563	 46571	 0.17479	 0.13834	 0.00174	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46564	 46565	 0.028083	 0.044826	 0.00103	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46564	 46566	 0.075124	 0.082629	 0.0011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46564	 46567	 0.055483	 0.1851	 0.00293	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46565	 46566	 0.031545	 0.023208	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46565	 46570	 0.22693	 0.14695	 0.0028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46566	 46570	 0.23906	 0.17592	 0.00257	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46566	 46571	 0.18282	 0.1447	 0.00182	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90665	 46566	 0.49378	 0.39109	 0.00492	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46567	 46568	 0.056416	 0.11546	 0.00284	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46567	 46569	 0.094726	 0.22435	 0.0041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46568	 46569	 0.038351	 0.098586	 0.00153	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46569	 46570	 0.10395	 0.31933	 0.00599	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90803	 46569	 0.083884	 0.32282	 0.00551	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46570	 46766	 0.038078	 0.097886	 0.00152	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46571	 46572	 0.14072	 0.11137	 0.0014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90665	 46571	 0.14052	 0.19922	 0.00407	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46573	 46574	 0.000838	 0.001945	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46573	 46575	 0.001512	 0.004058	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46573	 46579	 0.002788	 0.007009	 0.00182	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46574	 46578	 0.000937	 0.002258	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46575	 46576	 0.001912	 0.004807	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46576	 46577	 0.002192	 0.005886	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46576	 90971	 0.002517	 0.007018	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46577	 46580	 0.003101	 0.008195	 0.00192	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46578	 46579	 0.001656	 0.004257	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89019	 46579	 0.00318	 0.008256	 0.002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46579	 90966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46579	 90966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46580	 46589	 0.004156	 0.016639	 0.00419	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89019	 46580	 0.00338	 0.009424	 0.00198	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89020	 46581	 0.027831	 0.022025	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90966	 46581	 0.046387	 0.030031	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46581	 90974	 0.028838	 0.052819	 0.00091	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89020	 46582	 0.008925	 0.006996	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46583	 90967	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46583	 90967	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46583	 90970	 0.001472	 0.009933	 0.01829	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90967	 46584	 0.07765	 0.056134	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46584	 90972	 0.14028	 0.11102	 0.0014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46585	 90969	 0.034521	 0.099012	 0.00152	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46586	 90968	 0.057114	 0.10306	 0.00149	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46587	 46588	 0.004589	 0.012493	 0.00275	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46587	 46589	 0.014467	 0.03637	 0.00942	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46587	 46595	 0.015766	 0.039635	 0.01027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46587	 90968	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46587	 90968	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 0	 -30.0	 30.0;
	46588	 46589	 0.010666	 0.02819	 0.0066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89006	 46588	 0.005834	 0.014998	 0.00371	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46588	 90969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46588	 90969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46589	 46593	 0.006367	 0.016529	 0.00401	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89006	 46589	 0.00318	 0.012731	 0.00321	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89007	 46590	 0.00728	 0.016898	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90969	 46590	 0.098911	 0.078279	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46591	 90970	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46592	 90973	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46593	 90975	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46593	 90975	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46593	 90978	 0.009465	 0.023794	 0.00616	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90975	 46594	 0.14026	 0.11101	 0.0014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46594	 90976	 0.14162	 0.1042	 0.00152	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46595	 46596	 0.010737	 0.029233	 0.00644	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46596	 90976	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46596	 90976	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46597	 90977	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90978	 46597	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90966	 46598	 0.020262	 0.015882	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46599	 90979	 0.28201	 0.22324	 0.00281	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46600	 46601	 0.090945	 0.22264	 0.00381	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46600	 46602	 0.096295	 0.15372	 0.00354	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46602	 90979	 0.09776	 0.077368	 0.00097	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46603	 90979	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46603	 90979	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90979	 46604	 0.09763	 0.077265	 0.00097	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46605	 46606	 0.036111	 0.12047	 0.00191	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46605	 46607	 0.32559	 0.25776	 0.00325	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46605	 46608	 0.068287	 0.109	 0.00251	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90730	 46605	 0.10519	 0.30176	 0.00464	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90758	 46605	 0.073059	 0.156	 0.00352	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90667	 46606	 0.065684	 0.21915	 0.00347	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46607	 46609	 0.092369	 0.15344	 0.00325	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46607	 46610	 0.057051	 0.14666	 0.00227	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46608	 46609	 0.22488	 0.14562	 0.00277	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46609	 46612	 0.20078	 0.15892	 0.002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90637	 46610	 0.12296	 0.24103	 0.00361	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90637	 46611	 0.058673	 0.12008	 0.00296	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46613	 90980	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46613	 90980	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90980	 46614	 0.056715	 0.18921	 0.003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46614	 90981	 0.058794	 0.15114	 0.00234	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46615	 46616	 0.0057	 0.027664	 0.00632	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46615	 90981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46615	 90981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46616	 46618	 0.006291	 0.03452	 0.00913	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46616	 90982	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46616	 90982	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88825	 46617	 0.089552	 0.27508	 0.00516	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90982	 46617	 0.016705	 0.066276	 0.00189	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46618	 46619	 0.003215	 0.0325	 0.00956	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88996	 46619	 0.000994	 0.01136	 0.00346	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46621	 46622	 0.21942	 0.17202	 0.00221	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46622	 46623	 0.46328	 0.3669	 0.00462	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46622	 46624	 0.25073	 0.25332	 0.00336	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90904	 46622	 0.083312	 0.32421	 0.00541	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46625	 46626	 0.022141	 0.039949	 0.00058	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46625	 46627	 0.025319	 0.076207	 0.00149	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46625	 46755	 0.12918	 0.10126	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89005	 46625	 0.062122	 0.27377	 0.00476	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46627	 46638	 0.023165	 0.10322	 0.00175	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46628	 90983	 0.12011	 0.095057	 0.0012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46628	 90984	 0.083749	 0.054221	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46629	 46630	 0.013827	 0.035899	 0.00871	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46629	 46634	 0.008872	 0.023034	 0.00559	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46629	 90983	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46629	 90983	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46630	 46632	 0.00272	 0.009331	 0.00224	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46630	 90984	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46630	 90984	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46631	 46632	 0.001794	 0.004742	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46632	 90985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46632	 90985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46633	 46634	 0.005243	 0.020992	 0.00529	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46633	 46644	 0.008051	 0.030604	 0.00857	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46633	 90986	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46633	 90986	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46634	 46635	 0.001202	 0.004961	 0.00117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46635	 46636	 0.002461	 0.009672	 0.00253	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46635	 46643	 0.007132	 0.02403	 0.00597	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46636	 46643	 0.005672	 0.015443	 0.0034	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46636	 90987	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46636	 90987	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46637	 46638	 0.008964	 0.029903	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90983	 46637	 0.015763	 0.076922	 0.00133	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90987	 46638	 0.012941	 0.057346	 0.00172	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46639	 46640	 0.026621	 0.070559	 0.00179	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46639	 46641	 0.022699	 0.058349	 0.0009	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46640	 46641	 0.0152	 0.043597	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46640	 90988	 0.015991	 0.053344	 0.00085	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46641	 46642	 0.017429	 0.040463	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90987	 46641	 0.022577	 0.11292	 0.00201	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46642	 46645	 0.011447	 0.059527	 0.00129	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46642	 90990	 0.017101	 0.072374	 0.00136	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46643	 46646	 0.00756	 0.01755	 0.00535	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46643	 90988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46643	 90988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46644	 46646	 0.003845	 0.016275	 0.00366	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46644	 90989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46644	 90989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46646	 90990	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46646	 90990	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46647	 46648	 0.10224	 0.18449	 0.00267	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46648	 46651	 0.33472	 0.26499	 0.00334	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46649	 90991	 0.21714	 0.1406	 0.00268	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46650	 90991	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46650	 90991	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90991	 46651	 0.19055	 0.15082	 0.0019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46652	 46653	 0.007387	 0.019832	 0.00449	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46652	 46654	 0.004957	 0.01287	 0.00312	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46652	 90992	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46652	 90992	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46654	 46670	 0.005709	 0.019236	 0.00478	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46655	 46658	 0.005529	 0.022498	 0.00548	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46655	 90993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46655	 90993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46656	 46672	 0.005784	 0.015285	 0.00358	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89019	 46656	 0.055048	 0.14792	 0.03356	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46656	 90994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46656	 90994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46657	 46659	 0.011855	 0.023233	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90992	 46657	 0.10667	 0.069063	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90993	 46657	 0.020359	 0.061277	 0.0012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46658	 46661	 0.002683	 0.008952	 0.00227	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46658	 90995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46658	 90995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46659	 46663	 0.016638	 0.018299	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46660	 90996	 0.009989	 0.019778	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46661	 46670	 0.007915	 0.02155	 0.00475	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46661	 90996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46661	 90996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46662	 46663	 0.022486	 0.015105	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90995	 46662	 0.010853	 0.017323	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90996	 46662	 0.011884	 0.01982	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90714	 46664	 0.027516	 0.14661	 0.00257	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90994	 46664	 0.041566	 0.095064	 0.00232	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46665	 46666	 0.004929	 0.01239	 0.00321	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46665	 46669	 0.003152	 0.008184	 0.00199	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46665	 90997	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46665	 90997	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46666	 46668	 0.007384	 0.02059	 0.00432	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46666	 90998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46666	 90998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90997	 46667	 0.032858	 0.054799	 0.0008	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46667	 91001	 0.076956	 0.060903	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46668	 46745	 0.008997	 0.023357	 0.00567	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46668	 90999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46668	 90999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46669	 46673	 0.009068	 0.023965	 0.00561	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46669	 91000	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46669	 91000	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46670	 46671	 0.003752	 0.012238	 0.00325	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46671	 46676	 0.004942	 0.016486	 0.00418	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46672	 46673	 0.004333	 0.01145	 0.00268	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46673	 46676	 0.012975	 0.033355	 0.00826	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46673	 91001	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46673	 91001	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89017	 46674	 0.14858	 0.11759	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90999	 46674	 0.071597	 0.091122	 0.00134	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89017	 46675	 0.085256	 0.067472	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91001	 46675	 0.15445	 0.12108	 0.00155	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46676	 46678	 0.002501	 0.00884	 0.00199	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89017	 46677	 0.017652	 0.034595	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46677	 91002	 0.053924	 0.055063	 0.00086	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46678	 46679	 0.002703	 0.006513	 0.00184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46679	 46682	 0.003327	 0.008362	 0.00217	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46680	 46683	 0.001589	 0.006465	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46680	 46685	 0.003746	 0.009709	 0.00294	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46681	 46682	 0.001341	 0.004856	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46682	 46684	 0.001619	 0.004515	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90814	 46682	 0.003667	 0.009426	 0.00233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46683	 46684	 0.003314	 0.008757	 0.00205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46683	 46686	 0.001713	 0.007714	 0.00205	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46684	 91002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46684	 91002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46685	 46690	 0.007674	 0.020281	 0.00475	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46685	 91003	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46685	 91003	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46686	 46687	 0.00249	 0.006684	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90814	 46686	 0.005154	 0.01796	 0.00416	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46687	 46689	 0.001813	 0.004707	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46687	 91004	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46687	 91004	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91004	 46688	 0.041412	 0.032773	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46689	 46693	 0.002468	 0.006626	 0.0015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46690	 46698	 0.00338	 0.008932	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46691	 46692	 0.032731	 0.025903	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91004	 46691	 0.056264	 0.044527	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46691	 91019	 0.017928	 0.047518	 0.00121	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46692	 46699	 0.052554	 0.038666	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46693	 46695	 0.003226	 0.008526	 0.002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46693	 91005	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46693	 91005	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91005	 46694	 0.031956	 0.025049	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46695	 46696	 0.002449	 0.006295	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46696	 46703	 0.003044	 0.008487	 0.00178	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46696	 91006	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46696	 91006	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46696	 91009	 0.003799	 0.011436	 0.00358	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90870	 46697	 0.01499	 0.026942	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91006	 46697	 0.040467	 0.029254	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46697	 91008	 0.014235	 0.026073	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46698	 91007	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46698	 91007	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46699	 46700	 0.021035	 0.016647	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91007	 46699	 0.037724	 0.024423	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91006	 46700	 0.01049	 0.020768	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46701	 46709	 0.071035	 0.045989	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46701	 46730	 0.047011	 0.036849	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46701	 91010	 0.022778	 0.037834	 0.0008	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46702	 91010	 0.006936	 0.026983	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46703	 91008	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46703	 91008	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46703	 91009	 0.001486	 0.005253	 0.00118	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46704	 91009	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91010	 46705	 0.023514	 0.034866	 0.00052	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46705	 91011	 0.045105	 0.032607	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46706	 91011	 0.02489	 0.027376	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46707	 91011	 0.020063	 0.020264	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91009	 46708	 0.004055	 0.011956	 0.00278	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46708	 91011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46708	 91011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46709	 46712	 0.11098	 0.085135	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46710	 46711	 0.032193	 0.025477	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46710	 46712	 0.058654	 0.037973	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46710	 46713	 0.040168	 0.029037	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46711	 46714	 0.056649	 0.040951	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46712	 46714	 0.10071	 0.079704	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46712	 46716	 0.021054	 0.041686	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91011	 46713	 0.025655	 0.033718	 0.00046	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46715	 46716	 0.049449	 0.044614	 0.00075	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46715	 46718	 0.093806	 0.074239	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46715	 46755	 0.073531	 0.047605	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46717	 46718	 0.012984	 0.02772	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46717	 91023	 0.025246	 0.083313	 0.00135	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46717	 91024	 0.059785	 0.043219	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46718	 91012	 0.054999	 0.043111	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46718	 91013	 0.059314	 0.046941	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46719	 91013	 0.040905	 0.032371	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46720	 46721	 0.013557	 0.016828	 0.00037	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46721	 46733	 0.043247	 0.034225	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46721	 46734	 0.030426	 0.023849	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46721	 91012	 0.009486	 0.027208	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46722	 46723	 0.001358	 0.003645	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46722	 46725	 0.004591	 0.012802	 0.00269	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46722	 46752	 0.007883	 0.032548	 0.0077	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46722	 46753	 0.00547	 0.018765	 0.0045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46722	 91012	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46722	 91012	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46723	 46753	 0.007663	 0.02383	 0.00497	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91009	 46723	 0.010111	 0.026251	 0.00637	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46723	 91013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46723	 91013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46724	 46726	 0.029062	 0.021008	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91013	 46724	 0.016223	 0.02303	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46724	 91014	 0.023842	 0.015435	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46725	 46728	 0.001629	 0.004373	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46725	 46759	 0.017671	 0.061596	 0.01429	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91009	 46725	 0.007879	 0.020823	 0.00487	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46725	 91014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46725	 91014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46726	 46727	 0.0092	 0.00728	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46727	 46734	 0.02495	 0.019745	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46728	 46731	 0.002322	 0.006136	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46729	 46730	 0.00652	 0.018702	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91007	 46729	 0.028494	 0.022549	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91014	 46730	 0.004672	 0.021209	 0.00046	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46731	 46732	 0.003875	 0.009338	 0.00264	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46731	 46738	 0.004348	 0.011287	 0.00274	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46731	 46739	 0.003448	 0.008863	 0.00219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91009	 46731	 0.011083	 0.02671	 0.00754	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46731	 91015	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46731	 91015	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46732	 46735	 0.005816	 0.014016	 0.00396	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46732	 46738	 0.002281	 0.00621	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46732	 91016	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46732	 91016	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91016	 46733	 0.009967	 0.019733	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91015	 46734	 0.013782	 0.020903	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46735	 46738	 0.005399	 0.014016	 0.0034	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46735	 46750	 0.002143	 0.007575	 0.00171	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46736	 46738	 0.004286	 0.01333	 0.00278	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46736	 46743	 0.003218	 0.011039	 0.00264	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46736	 91017	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46736	 91017	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46737	 46739	 0.003536	 0.009178	 0.00223	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46737	 46742	 0.003731	 0.010018	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46737	 46745	 0.009205	 0.03208	 0.00744	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46738	 91018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46738	 91018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46740	 91019	 0.027778	 0.021983	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46741	 46744	 0.042504	 0.046749	 0.00062	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91003	 46741	 0.052604	 0.041234	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46742	 91019	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46742	 91019	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46743	 46745	 0.003541	 0.012821	 0.00275	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46743	 91020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46743	 91020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91019	 46744	 0.08496	 0.062509	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91020	 46744	 0.020334	 0.047201	 0.0009	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46745	 91021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46745	 91021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46746	 46747	 0.011107	 0.021991	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46746	 46765	 0.026044	 0.069029	 0.00175	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46746	 91022	 0.066723	 0.052301	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91017	 46747	 0.050809	 0.04021	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46748	 91022	 0.048172	 0.048656	 0.00064	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46748	 91024	 0.090962	 0.071988	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46749	 46750	 0.001524	 0.008363	 0.00221	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46749	 46762	 0.002504	 0.013274	 0.00443	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46750	 91022	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46750	 91022	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46751	 46754	 0.00947	 0.031591	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46751	 91023	 0.013793	 0.048291	 0.00134	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46752	 46753	 0.002613	 0.014856	 0.0043	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46752	 46756	 0.003158	 0.023791	 0.0066	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46752	 91023	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46752	 91023	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46753	 91024	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46753	 91024	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46754	 46755	 0.01382	 0.027363	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46757	 46758	 0.028138	 0.05571	 0.00082	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90985	 46757	 0.086722	 0.23995	 0.00558	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46757	 91025	 0.041104	 0.071755	 0.00111	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91023	 46758	 0.051012	 0.067046	 0.00092	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46759	 46760	 0.004459	 0.015297	 0.00366	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46759	 46762	 0.003848	 0.00999	 0.00242	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46759	 91025	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46759	 91025	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46760	 46762	 0.001092	 0.00818	 0.002	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46760	 46763	 0.002229	 0.008473	 0.00237	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46760	 91026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46760	 91026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46761	 46765	 0.003725	 0.01788	 0.00053	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91026	 46761	 0.0353	 0.046394	 0.00064	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46761	 91028	 0.003145	 0.020786	 0.00041	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46762	 91027	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46762	 91027	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46763	 91028	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46763	 91028	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46764	 46765	 0.079855	 0.058753	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91021	 46765	 0.046012	 0.084277	 0.00146	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91027	 46765	 0.061451	 0.039784	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46766	 46776	 0.033868	 0.024918	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46767	 46769	 0.18277	 0.13214	 0.002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46768	 46769	 0.039821	 0.13142	 0.00213	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46769	 91029	 0.060119	 0.17061	 0.00268	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46770	 46775	 0.004279	 0.01741	 0.00424	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46771	 46779	 0.2443	 0.19338	 0.00243	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46771	 91030	 0.03047	 0.078327	 0.00121	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46772	 46775	 0.009374	 0.024775	 0.0058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46772	 91029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46772	 91029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46773	 46774	 0.16229	 0.12844	 0.00162	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46773	 46808	 0.177	 0.13875	 0.00178	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91029	 46773	 0.075362	 0.1209	 0.00223	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46774	 46777	 0.11175	 0.087595	 0.00112	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90915	 46774	 0.042093	 0.067189	 0.00155	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46775	 91030	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46775	 91030	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90915	 46776	 0.10886	 0.25783	 0.00472	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46778	 46779	 0.18965	 0.1228	 0.00234	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46778	 46808	 0.27286	 0.17671	 0.00336	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46780	 46784	 0.1894	 0.17091	 0.00286	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46781	 46784	 0.19829	 0.15695	 0.00198	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46782	 46783	 0.20991	 0.16614	 0.00209	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46783	 46784	 0.35016	 0.27723	 0.00349	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90756	 46783	 0.039251	 0.083802	 0.00189	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46785	 46786	 0.003518	 0.010089	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46785	 91034	 0.005471	 0.019543	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46786	 46787	 0.014968	 0.011733	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46786	 46789	 0.009858	 0.010527	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46787	 91031	 0.031284	 0.024757	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46788	 46790	 0.001384	 0.005036	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46788	 46790	 0.001384	 0.005036	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46788	 46799	 0.002612	 0.00993	 0.00278	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46788	 46799	 0.002612	 0.00993	 0.00278	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46788	 91031	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46788	 91031	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46789	 91032	 0.016185	 0.011908	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46790	 46795	 0.00104	 0.003624	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46790	 46795	 0.00104	 0.003624	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46790	 91032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46790	 91032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46791	 46792	 0.007509	 0.013497	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46791	 46793	 0.022208	 0.016054	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91031	 46791	 0.023809	 0.018842	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91032	 46791	 0.005516	 0.009701	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91031	 46792	 0.023061	 0.018981	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46792	 91035	 0.044333	 0.039999	 0.00067	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46793	 46794	 0.023927	 0.01549	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46794	 46802	 0.013357	 0.034334	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46794	 91033	 0.002419	 0.014107	 0.00028	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46795	 46796	 0.001378	 0.004871	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46795	 46796	 0.001378	 0.004871	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46796	 46797	 0.000571	 0.003736	 0.00095	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46796	 46797	 0.000571	 0.003736	 0.00095	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46796	 91033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46796	 91033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46797	 46798	 0.002079	 0.005797	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46797	 46798	 0.002079	 0.005797	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46797	 91036	 0.001814	 0.015557	 0.00443	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46798	 91034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46798	 91034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46799	 46800	 0.005265	 0.013234	 0.00343	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88990	 46799	 0.081055	 0.21466	 0.05037	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46799	 91041	 0.007697	 0.02787	 0.00598	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46799	 91043	 0.00623	 0.020782	 0.00527	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46800	 91035	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46800	 91035	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46801	 46802	 0.039908	 0.031282	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91034	 46801	 0.018782	 0.057679	 0.00108	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46801	 91037	 0.042018	 0.06707	 0.00154	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46802	 46803	 0.026745	 0.020515	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91035	 46803	 0.074136	 0.047997	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46804	 46825	 0.003421	 0.022818	 0.04301	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90740	 46804	 0.001202	 0.013948	 0.04958	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46804	 91036	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46804	 91036	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91036	 46805	 0.005798	 0.032835	 0.00814	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46805	 91037	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46805	 91037	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46806	 46807	 0.21223	 0.16082	 0.00221	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90756	 46806	 0.159	 0.12584	 0.00158	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91037	 46806	 0.061017	 0.10899	 0.00161	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46807	 46808	 0.16117	 0.12756	 0.00161	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91035	 46807	 0.073371	 0.10416	 0.00171	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89002	 46809	 0.036014	 0.071305	 0.00105	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46810	 91038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46810	 91038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46811	 46812	 0.031281	 0.024755	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46811	 46813	 0.024669	 0.019336	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90908	 46811	 0.034706	 0.027205	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46812	 46814	 0.022505	 0.01781	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46813	 46815	 0.027641	 0.021666	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46814	 46816	 0.010926	 0.008564	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46815	 46816	 0.033657	 0.026636	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89002	 46816	 0.025367	 0.049715	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46816	 91039	 0.005243	 0.011992	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46817	 91039	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46817	 91039	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46818	 46820	 0.025715	 0.025973	 0.00034	 33.0	 33.0	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46819	 46820	 0.020237	 0.014335	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46820	 46822	 0.020909	 0.018736	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46820	 46823	 0.032341	 0.024807	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89002	 46820	 0.019545	 0.038697	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46820	 91040	 0.003815	 0.011714	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46821	 91040	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46821	 91040	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46821	 91041	 0.00174	 0.006063	 0.00141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46822	 91042	 0.003608	 0.013882	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46824	 46825	 0.00027	 0.001753	 0.00349	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46824	 91041	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91042	 46824	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 0	 -30.0	 30.0;
	46825	 91043	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46825	 91043	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46826	 46827	 0.013135	 0.03302	 0.00855	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46826	 91044	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46826	 91044	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46827	 46829	 0.003687	 0.008557	 0.00261	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46828	 46831	 0.021756	 0.017217	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90898	 46829	 0.024391	 0.19252	 0.05646	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46829	 91045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46829	 91045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91045	 46830	 0.035175	 0.025879	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91045	 46831	 0.015934	 0.036986	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89032	 46832	 0.20474	 0.40557	 0.00596	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91045	 46832	 0.06478	 0.085141	 0.00117	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46833	 46834	 0.042354	 0.16478	 0.00275	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46834	 46842	 0.034934	 0.088488	 0.00175	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46837	 46838	 0.016065	 0.045586	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46838	 46839	 0.009843	 0.022847	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89032	 46838	 0.020021	 0.039641	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46839	 46840	 0.051722	 0.03739	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89032	 46842	 0.028004	 0.086002	 0.00161	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46843	 47329	 0.000197	 0.002646	 0.18128	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46843	 47454	 9.2e-05	 0.001103	 0.08274	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46843	 91046	 9.5e-05	 0.007586	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46843	 91046	 9.5e-05	 0.007586	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46844	 47322	 2.6e-05	 0.000507	 0.03653	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46844	 47572	 0.000231	 0.002757	 0.20688	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46844	 91049	 0.00012	 0.009565	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46844	 91049	 0.00012	 0.009565	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91050	 46844	 0.000278	 0.020855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91050	 46844	 0.000278	 0.020855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46845	 47286	 0.000112	 0.001391	 0.09533	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46845	 47454	 0.002007	 0.026133	 1.6862	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46845	 91051	 0.000196	 0.013749	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46845	 91051	 0.000196	 0.013749	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46846	 47174	 0.00096	 0.012427	 0.79499	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46846	 47399	 4e-05	 0.00074	 0.05995	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46846	 91055	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46846	 91055	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46847	 47067	 0.00024	 0.002769	 0.02427	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46847	 91058	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46847	 91058	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46848	 47428	 5e-05	 0.001242	 0.10305	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46848	 91059	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46848	 91059	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91060	 46848	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91060	 46848	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46849	 46851	 0.00051	 0.006452	 0.05755	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46849	 47275	 0.000287	 0.004132	 0.03791	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46849	 47577	 0.00069	 0.007532	 0.07395	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46849	 91061	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46849	 91061	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46850	 49032	 0.000591	 0.010363	 0.11089	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46850	 91064	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46850	 91064	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91065	 46850	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91065	 46850	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46851	 47275	 0.000225	 0.002885	 0.02714	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46851	 47761	 0.006399	 0.067218	 1.0639	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46851	 91066	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46851	 91066	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46852	 46882	 7.9e-05	 0.00052	 0.00101	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46852	 47323	 0.000712	 0.00626	 0.01306	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46852	 91068	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46852	 91068	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91069	 46852	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91069	 46852	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46853	 47097	 0.000326	 0.00455	 0.33189	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46853	 48041	 0.002321	 0.04743	 4.0532	 2840.0	 2982.0	 3124.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46853	 48465	 0.00106	 0.012665	 0.95286	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46853	 91070	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46853	 91070	 0.000278	 0.019465	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46854	 46865	 0.010183	 0.070664	 0.02017	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46854	 46875	 0.031405	 0.10482	 0.0266	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46854	 46876	 0.038312	 0.15835	 0.03752	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46854	 47129	 0.063545	 0.16815	 0.03942	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46854	 47131	 0.06383	 0.16891	 0.03959	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46854	 47271	 0.014214	 0.036842	 0.01115	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46854	 47272	 0.007478	 0.041492	 0.01261	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46854	 47280	 0.042182	 0.17438	 0.04133	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46854	 47281	 0.032453	 0.085795	 0.02009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46854	 47282	 0.033948	 0.10313	 0.0226	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46854	 47389	 0.007328	 0.049166	 0.01187	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46854	 91073	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46854	 91073	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46855	 47415	 0.009043	 0.04072	 0.01084	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46855	 91074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46855	 91074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46856	 47231	 0.000147	 0.00161	 0.01563	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46856	 91075	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46856	 91075	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91076	 46856	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91076	 46856	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46857	 47299	 0.018095	 0.06333	 0.02099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46857	 47689	 0.016232	 0.058782	 0.01261	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46857	 91077	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46857	 91077	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46858	 47067	 0.000786	 0.009076	 0.07958	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46858	 47656	 9.9e-05	 0.001089	 0.01057	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46858	 91078	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46858	 91078	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46859	 47578	 0.006443	 0.041843	 0.08341	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46859	 91080	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46859	 91080	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46859	 91459	 0.001445	 0.009952	 0.01757	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46859	 91461	 0.001289	 0.009036	 0.01538	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46859	 91484	 0.003802	 0.025656	 0.04725	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46860	 47460	 0.000144	 0.0016	 0.01509	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46860	 47519	 0.000278	 0.003051	 0.02964	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46860	 91081	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46860	 91081	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46861	 91082	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46861	 91082	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46861	 91481	 0.004698	 0.021552	 0.00552	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46862	 47079	 0.00321	 0.018801	 0.00512	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46862	 48765	 0.016938	 0.047238	 0.00992	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46862	 48767	 0.025555	 0.06862	 0.01555	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46862	 91083	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46862	 91083	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46863	 47525	 0.000307	 0.003255	 0.03396	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46863	 91084	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46863	 91084	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46863	 91381	 0.000873	 0.009895	 0.0901	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46864	 47120	 0.005642	 0.028348	 0.00738	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46864	 47122	 0.001871	 0.013676	 0.00403	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46864	 91087	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46864	 91087	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46865	 47380	 0.011763	 0.048978	 0.01527	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46865	 47619	 0.02952	 0.11826	 0.02982	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46865	 91088	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46865	 91088	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46866	 47027	 0.010303	 0.035907	 0.00833	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46866	 47293	 0.009058	 0.038337	 0.00863	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46866	 91089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46866	 91089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46866	 92101	 0.05694	 0.16808	 0.03916	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46867	 47327	 0.005289	 0.037101	 0.0632	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46867	 47456	 0.000855	 0.005832	 0.0105	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46867	 91090	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46867	 91090	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46868	 47237	 0.00033	 0.004517	 0.04603	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46868	 47275	 0.000488	 0.005634	 0.04939	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46868	 91091	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46868	 91091	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46869	 47108	 0.003455	 0.009634	 0.00202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46869	 47268	 0.033632	 0.15445	 0.03963	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46869	 91094	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46869	 91094	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46870	 47378	 0.001278	 0.008801	 0.01554	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46870	 91095	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46870	 91095	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91096	 46870	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91096	 46870	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46870	 92017	 0.0124	 0.083853	 0.15488	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46871	 47242	 0.006702	 0.023688	 0.00534	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46871	 47243	 0.006082	 0.039179	 0.01027	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46871	 47253	 0.009444	 0.039972	 0.00899	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46871	 91097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46871	 91097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46872	 47611	 0.007741	 0.029781	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46872	 91301	 0.012246	 0.058817	 0.00114	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46872	 91498	 0.011544	 0.048858	 0.00092	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46873	 47135	 0.002288	 0.01067	 0.00264	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46873	 47217	 0.019406	 0.070281	 0.01508	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46873	 47223	 0.025191	 0.084904	 0.02111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46873	 47421	 0.011699	 0.049517	 0.01114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46873	 91098	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46873	 91098	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46873	 91433	 0.011983	 0.080408	 0.01942	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46874	 47250	 0.003026	 0.010196	 0.00253	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46874	 47252	 0.003184	 0.009389	 0.00218	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46874	 91099	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46874	 91099	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46875	 47129	 0.018118	 0.059104	 0.01569	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46875	 47131	 0.023238	 0.060339	 0.01465	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46875	 47330	 0.006856	 0.027899	 0.0068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46875	 91100	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46875	 91100	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46876	 47280	 0.021678	 0.07438	 0.01782	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46876	 47282	 0.014085	 0.064628	 0.01656	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46876	 47430	 0.009309	 0.042707	 0.01094	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46876	 47432	 0.012161	 0.042385	 0.00983	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46876	 47444	 0.01468	 0.12355	 0.03664	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46876	 91101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46876	 91101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46877	 47023	 0.00219	 0.010365	 0.00249	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46877	 47024	 0.002649	 0.009086	 0.00218	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46877	 91102	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46877	 91102	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46878	 47546	 0.001527	 0.012479	 0.00339	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46878	 47554	 0.000684	 0.003373	 0.00091	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46878	 91103	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46878	 91103	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46879	 47374	 0.007939	 0.035748	 0.00951	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46879	 47647	 0.007663	 0.021978	 0.00541	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46879	 47672	 0.005356	 0.022669	 0.0051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46879	 91104	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46879	 91104	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46880	 47149	 0.00053	 0.005436	 0.01068	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46880	 91105	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46880	 91105	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91106	 46880	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91106	 46880	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46880	 91351	 0.002204	 0.019637	 0.03451	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46881	 47230	 0.000678	 0.007683	 0.06995	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46881	 47231	 0.000176	 0.002006	 0.01812	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46881	 91107	 0.0008	 0.039992	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46881	 91107	 0.0008	 0.039992	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91108	 46881	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91108	 46881	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46882	 47303	 0.002234	 0.015154	 0.02759	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46882	 91109	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46882	 91109	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91110	 46882	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91110	 46882	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46882	 91249	 0.009072	 0.061282	 0.11302	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46883	 47195	 0.017235	 0.051618	 0.01163	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46883	 47199	 0.013654	 0.041464	 0.00908	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46884	 46891	 1.8e-05	 0.000212	 0.01592	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46884	 48045	 0.000727	 0.010803	 0.69604	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46884	 91111	 0.000154	 0.011578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46884	 91111	 0.000154	 0.011578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46885	 47934	 0.000861	 0.008886	 0.13967	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46885	 47988	 0.000418	 0.004985	 0.08477	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46885	 48737	 0.000204	 0.002352	 0.02062	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46885	 91112	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46885	 91112	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46886	 47901	 0.000215	 0.0026	 0.02298	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46886	 91113	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46886	 91113	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46887	 47987	 0.003379	 0.021935	 0.0437	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46887	 48003	 0.001277	 0.009226	 0.0215	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46887	 48484	 0.001268	 0.008736	 0.01542	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46887	 48735	 0.002741	 0.017795	 0.03545	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46887	 91115	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46887	 91115	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46888	 47864	 0.00033	 0.00542	 0.05321	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46888	 47867	 0.000105	 0.001862	 0.0195	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46888	 91116	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46888	 91116	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91117	 46888	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91117	 46888	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46889	 47740	 0.002821	 0.035676	 0.3488	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46889	 47901	 0.004208	 0.047834	 0.43774	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46889	 48489	 0.000327	 0.004452	 0.04587	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46889	 48493	 0.001004	 0.01102	 0.10707	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46889	 91118	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46889	 91118	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91119	 46889	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91119	 46889	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46890	 48559	 0.000688	 0.010915	 0.11464	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91111	 46890	 2e-05	 0.000207	 0.00326	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46890	 91120	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46890	 91120	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91121	 46890	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91121	 46890	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46890	 91865	 0.000473	 0.005362	 0.04882	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46891	 48552	 0.000136	 0.001758	 0.11219	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46891	 91122	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46891	 91122	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91123	 46891	 0.000433	 0.032442	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91123	 46891	 0.000433	 0.032442	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46892	 46925	 0.003776	 0.044654	 0.09036	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46892	 47700	 0.001373	 0.01424	 0.03067	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46892	 47700	 0.001373	 0.01424	 0.03067	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46892	 48179	 0.00158	 0.023751	 0.10741	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46892	 91124	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46892	 91124	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91125	 46892	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91125	 46892	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46893	 48226	 0.003286	 0.044758	 0.09117	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46893	 91126	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46893	 91126	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46893	 91158	 0.000129	 0.001508	 0.00337	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46893	 91825	 0.000743	 0.004822	 0.0096	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46893	 91916	 0.004276	 0.027763	 0.05532	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46894	 48257	 0.001825	 0.013228	 0.02663	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46894	 91127	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46894	 91127	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46894	 91825	 0.000498	 0.005816	 0.02035	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46895	 46914	 1.5e-05	 0.000168	 0.00159	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46895	 47934	 0.000814	 0.009399	 0.08241	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46895	 91128	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46895	 91128	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91129	 46895	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91129	 46895	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46896	 46902	 0.0003	 0.003396	 0.03091	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46896	 47867	 0.000198	 0.002214	 0.02069	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46896	 47868	 0.000373	 0.004471	 0.04829	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46896	 48165	 0.001133	 0.014982	 0.24017	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46896	 57283	 0.001166	 0.014772	 0.25818	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46896	 91130	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46896	 91130	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46897	 47740	 0.002438	 0.032302	 0.51952	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46897	 48012	 0.000528	 0.005976	 0.05441	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46897	 91131	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46897	 91131	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46898	 46910	 0.000448	 0.004916	 0.04775	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46898	 47721	 0.00011	 0.002626	 0.04778	 1940.0	 2037.0	 2134.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46898	 91661	 0.000203	 0.002442	 0.02415	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46899	 47790	 0.00056	 0.006041	 0.01199	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46899	 91133	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46899	 91133	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46900	 48465	 9.1e-05	 0.001116	 0.07978	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46900	 91134	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46900	 91134	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46901	 48213	 0.001722	 0.018911	 0.18384	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91111	 46901	 3.9e-05	 0.000535	 0.00545	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91122	 46901	 6.8e-05	 0.000757	 0.00714	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46901	 91135	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46901	 91135	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46901	 91865	 0.000431	 0.004898	 0.04423	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46902	 47867	 0.000318	 0.004219	 0.06685	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46902	 57191	 0.001181	 0.015168	 0.25809	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46902	 91136	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46902	 91136	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91137	 46902	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91137	 46902	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46903	 48045	 1.1e-05	 0.000164	 0.0113	 1893.0	 1987.6	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46903	 91138	 0.000196	 0.013749	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46903	 91138	 0.000196	 0.013749	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91140	 46903	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91140	 46903	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46904	 47988	 0.000431	 0.004795	 0.04522	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46904	 91141	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46904	 91141	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46904	 91656	 0.001519	 0.017218	 0.15685	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46905	 46911	 1.9e-05	 0.000251	 0.00054	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46905	 91143	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46905	 91143	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46906	 48150	 0.000712	 0.008215	 0.07202	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46906	 91144	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46906	 91144	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46906	 91865	 0.000376	 0.004191	 0.03952	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46907	 47773	 0.000814	 0.004468	 0.00118	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46907	 47784	 0.001465	 0.009088	 0.0022	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46907	 47833	 0.001836	 0.004853	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91133	 46907	 5e-05	 0.00037	 0.00014	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46907	 91145	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46907	 91145	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46908	 91146	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46908	 91146	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91147	 46908	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91147	 46908	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46908	 91768	 9.3e-05	 0.001635	 0.0153	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46909	 47740	 0.003382	 0.036999	 0.36444	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46909	 48038	 0.002687	 0.026638	 0.45732	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46909	 48165	 0.000516	 0.00855	 0.08015	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46909	 91148	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46909	 91148	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46910	 47988	 0.001569	 0.018112	 0.15888	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46910	 91151	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46910	 91151	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46911	 47968	 0.001871	 0.012761	 0.02298	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46911	 91152	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46911	 91152	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91153	 46911	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91153	 46911	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46912	 47719	 0.007533	 0.019556	 0.00475	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46912	 91539	 0.000867	 0.004102	 0.00099	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46913	 48261	 0.011863	 0.046631	 0.0122	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46913	 48262	 0.003899	 0.013006	 0.0033	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46913	 48520	 0.018597	 0.04781	 0.01184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46913	 91154	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46913	 91154	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46914	 48044	 0.000102	 0.0017	 0.01571	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46914	 91155	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46914	 91155	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46915	 48050	 0.00134	 0.004876	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46915	 91551	 0.013221	 0.053806	 0.01311	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46916	 48126	 2.2e-05	 0.000506	 0.00954	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46916	 48410	 5.5e-05	 0.00096	 0.01027	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46916	 91156	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46916	 91156	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91157	 46916	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91157	 46916	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46917	 91637	 0.001607	 0.01035	 0.00271	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46917	 91644	 0.003197	 0.016929	 0.00429	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46918	 48675	 0.001097	 0.01198	 0.11765	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46918	 91158	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46918	 91158	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46918	 91824	 0.000265	 0.002907	 0.02824	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46919	 48670	 0.013109	 0.13366	 0.03448	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46919	 91161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46919	 91161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46920	 48496	 0.00252	 0.006542	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46920	 48517	 0.000904	 0.004149	 0.00106	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46920	 91162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46920	 91162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46921	 48173	 0.000181	 0.001267	 0.00216	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46921	 48179	 0.000523	 0.003531	 0.0065	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46921	 91163	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46921	 91163	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91164	 46921	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91164	 46921	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46921	 91659	 0.005174	 0.071296	 0.14242	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91136	 46922	 0.001289	 0.008366	 0.01666	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46922	 91165	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46922	 91165	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91166	 46922	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91166	 46922	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46922	 91586	 0.000556	 0.003832	 0.00676	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46923	 48423	 0.002093	 0.008712	 0.00272	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46923	 91758	 0.000251	 0.001377	 0.00036	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46924	 48176	 0.001934	 0.00502	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46924	 91167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46924	 91167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46924	 91709	 0.001147	 0.004361	 0.00122	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46925	 48179	 0.001729	 0.01173	 0.02136	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46925	 91168	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46925	 91168	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46926	 46927	 0.000995	 0.005182	 0.00136	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46926	 47727	 0.00262	 0.025159	 0.00732	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46926	 91539	 0.000848	 0.003394	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46928	 48722	 0.000359	 0.002582	 0.00068	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46928	 48724	 0.000643	 0.004311	 0.00104	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46929	 48158	 0.033618	 0.10313	 0.00279	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46929	 48158	 0.033618	 0.10313	 0.00279	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46929	 91833	 0.040549	 0.15776	 0.00263	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46929	 91833	 0.040549	 0.15776	 0.00263	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46930	 48455	 0.000389	 0.001529	 0.0004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46930	 91169	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46930	 91169	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46931	 47873	 0.004099	 0.014284	 0.00331	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46931	 47875	 0.002497	 0.010869	 0.0031	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46932	 47899	 0.004165	 0.04762	 0.01453	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46932	 91170	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46932	 91170	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46932	 91602	 0.006159	 0.026806	 0.00764	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46933	 91171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46933	 91171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46933	 91935	 0.000567	 0.002752	 0.00063	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46934	 47907	 0.001531	 0.01131	 0.00326	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46934	 91172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46934	 91172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46935	 48735	 0.004114	 0.027095	 0.05244	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46935	 91173	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46935	 91173	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91174	 46935	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91174	 46935	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46936	 48157	 0.026419	 0.13739	 0.00298	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46936	 91833	 0.024847	 0.058838	 0.00108	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46937	 48595	 0.002522	 0.031081	 0.01004	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46937	 48596	 0.001793	 0.009123	 0.00331	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46937	 48598	 0.000179	 0.002818	 0.00096	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46937	 48600	 0.001855	 0.012923	 0.00486	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46938	 48478	 0.002961	 0.021418	 0.01152	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46938	 48548	 0.00031	 0.003283	 0.00097	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46938	 91175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46938	 91175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46939	 47721	 0.000863	 0.009467	 0.09197	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46939	 48557	 0.000121	 0.001392	 0.01221	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46939	 48559	 0.000215	 0.003373	 0.03515	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46940	 47729	 0.039432	 0.21181	 0.00503	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46940	 48591	 0.010959	 0.048287	 0.00084	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46941	 48214	 0.068779	 0.18492	 0.04198	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46942	 48669	 0.019905	 0.015752	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46942	 48674	 0.044208	 0.090471	 0.00223	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46943	 48042	 0.036049	 0.082446	 0.00201	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46943	 48043	 0.005159	 0.013369	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46944	 48457	 0.003508	 0.024082	 0.00044	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46944	 48459	 0.003747	 0.023888	 0.00058	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46945	 49037	 0.002369	 0.028716	 0.25427	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46945	 91176	 0.000641	 0.033327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46945	 91176	 0.000641	 0.033327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46946	 48974	 0.000294	 0.007526	 0.51557	 2783.0	 2922.2	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46946	 91179	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46946	 91179	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46947	 49521	 0.00012	 0.00155	 0.09891	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46947	 49523	 0.000172	 0.002054	 0.15408	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46947	 91181	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46947	 91181	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91182	 46947	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91182	 46947	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46948	 47117	 0.000975	 0.025484	 2.3556	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46948	 47117	 0.000975	 0.025484	 2.3556	 3531.0	 3707.6	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46948	 50033	 0.000261	 0.006194	 0.5581	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46948	 91183	 7.2e-05	 0.005789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46948	 91183	 7.2e-05	 0.005789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 0	 -30.0	 30.0;
	91184	 46948	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 0	 -30.0	 30.0;
	91184	 46948	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 0	 -30.0	 30.0;
	46949	 49317	 0.000153	 0.002447	 0.00502	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46949	 91185	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46949	 91185	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91186	 46949	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91186	 46949	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46950	 48974	 0.003822	 0.049146	 3.5187	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46950	 49829	 0.000234	 0.006362	 0.43893	 2893.0	 3037.6	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46950	 91187	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46950	 91187	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91188	 46950	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91188	 46950	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46951	 49789	 0.001539	 0.018817	 0.03865	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46951	 91189	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46951	 91189	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91190	 46951	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91190	 46951	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46952	 49159	 4.9e-05	 0.000537	 0.00522	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46952	 91191	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46952	 91191	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46952	 92032	 7.8e-05	 0.000901	 0.0079	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46953	 48883	 0.001355	 0.013587	 0.22662	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46953	 48883	 0.001355	 0.013587	 0.22662	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46953	 49518	 0.000244	 0.003832	 0.03994	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46953	 91193	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46953	 91193	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46954	 47117	 0.000269	 0.003204	 0.24036	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46954	 48840	 0.000554	 0.00674	 0.48783	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46954	 49521	 0.000565	 0.007303	 0.46645	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46954	 91196	 0.000137	 0.010999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46954	 91196	 0.000137	 0.010999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46955	 48770	 0.002032	 0.018694	 0.03557	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46955	 49360	 0.004519	 0.031698	 0.05399	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46955	 91200	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46955	 91200	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46956	 49153	 0.000656	 0.006938	 0.10377	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46956	 49153	 0.000656	 0.006938	 0.10377	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46956	 49735	 0.00161	 0.019137	 0.17584	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46956	 50006	 0.002158	 0.025229	 0.24031	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46956	 91201	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46956	 91201	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46957	 49108	 0.00142	 0.011333	 0.00279	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46957	 49119	 0.001257	 0.014083	 0.00448	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46957	 91203	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46957	 91203	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46958	 49132	 0.001534	 0.015108	 0.0322	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46958	 49431	 0.018545	 0.12712	 0.23055	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46958	 91204	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46958	 91204	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91205	 46958	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91205	 46958	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46959	 49360	 0.000308	 0.002505	 0.00821	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46959	 91206	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46959	 91206	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46960	 49278	 0.000355	 0.004856	 0.04948	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46960	 91207	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46960	 91207	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46961	 48799	 0.004863	 0.058785	 0.12396	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46961	 48916	 0.001686	 0.018855	 0.03869	 543.0	 543.0	 543.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46961	 48916	 0.001686	 0.018855	 0.03869	 543.0	 543.0	 543.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46961	 91210	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46961	 91210	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46961	 91210	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91211	 46961	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 0	 -30.0	 30.0;
	91211	 46961	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 0	 -30.0	 30.0;
	46962	 48750	 0.011005	 0.089968	 0.02442	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46962	 49539	 0.002151	 0.020654	 0.00601	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46962	 49540	 0.001524	 0.012243	 0.00344	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46963	 48750	 0.026406	 0.07365	 0.01546	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46963	 48978	 0.019875	 0.09649	 0.02207	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46963	 49015	 0.014514	 0.05256	 0.01128	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46963	 91212	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46963	 91212	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46964	 46982	 0.010893	 0.039444	 0.00846	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46964	 48753	 0.0137	 0.054835	 0.01853	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46964	 91213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46964	 91213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46964	 93167	 0.081849	 0.24572	 0.05553	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46965	 49400	 0.000379	 0.004041	 0.05933	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46965	 49400	 0.000379	 0.004041	 0.05933	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46965	 49896	 0.000291	 0.003076	 0.046	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46965	 49896	 0.000291	 0.003076	 0.046	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46965	 91214	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46965	 91214	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46966	 49964	 0.010027	 0.048666	 0.01113	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46966	 49968	 0.007483	 0.035417	 0.00852	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46966	 91217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46966	 91217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46967	 48903	 0.003651	 0.017719	 0.00405	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46967	 48904	 0.008961	 0.031231	 0.00724	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46967	 48905	 0.006806	 0.019092	 0.00491	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46967	 48906	 0.003611	 0.012386	 0.00297	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46967	 49260	 0.009207	 0.055267	 0.01674	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46967	 50861	 0.040044	 0.10588	 0.0248	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46967	 91218	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46967	 91218	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46968	 48799	 0.011008	 0.076999	 0.13251	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46968	 49699	 0.006202	 0.059185	 0.2169	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46968	 91219	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46968	 91219	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91220	 46968	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91220	 46968	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46969	 48833	 0.000859	 0.00394	 0.00101	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46969	 48838	 0.00052	 0.006543	 0.00203	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46970	 48901	 0.000507	 0.003315	 0.00084	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46970	 48904	 0.006324	 0.039244	 0.00951	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46970	 49417	 0.012432	 0.057038	 0.01461	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46971	 48987	 0.004627	 0.012597	 0.00278	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46971	 48989	 0.002319	 0.00602	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46971	 91221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46971	 91221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46972	 48901	 0.005191	 0.020194	 0.00539	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46972	 49279	 0.005693	 0.019182	 0.00477	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46972	 49281	 0.002635	 0.013727	 0.0036	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46972	 49288	 0.011463	 0.041706	 0.01277	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46972	 91222	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46972	 91222	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46973	 48857	 0.040647	 0.094355	 0.0018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46973	 48982	 0.009499	 0.01952	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46973	 92044	 0.034773	 0.056999	 0.00101	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46974	 48758	 0.006297	 0.034462	 0.00067	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46974	 48761	 0.005295	 0.023465	 0.0007	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	46975	 49627	 0.003861	 0.010366	 0.00235	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46975	 49628	 0.002733	 0.007026	 0.00174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46976	 49371	 0.0024	 0.021262	 0.00566	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46976	 49441	 0.006618	 0.051899	 0.02373	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46976	 49442	 0.006537	 0.044873	 0.01309	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46977	 49584	 0.008452	 0.021943	 0.00533	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46977	 49586	 0.013003	 0.071689	 0.01676	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46977	 49687	 0.037696	 0.17996	 0.05225	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46977	 91223	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46977	 91223	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46978	 49091	 0.002426	 0.011484	 0.00276	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46978	 49105	 0.004437	 0.011153	 0.00289	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46978	 49106	 0.006036	 0.025546	 0.00575	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46978	 50018	 0.02075	 0.054847	 0.01284	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46979	 49015	 0.025396	 0.069155	 0.01524	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46979	 49123	 0.036502	 0.19045	 0.05006	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46979	 91224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46979	 91224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46980	 48790	 0.001879	 0.005539	 0.00129	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46980	 48795	 0.003913	 0.017618	 0.00469	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46980	 91225	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46980	 91225	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46981	 48911	 0.005452	 0.022186	 0.00541	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46981	 48913	 0.005831	 0.022918	 0.006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46981	 91226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46981	 91226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46982	 48753	 0.010574	 0.036273	 0.00869	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46982	 48816	 0.04854	 0.19469	 0.06597	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46982	 91227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46982	 91227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46983	 49057	 0.012507	 0.03798	 0.00832	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46983	 49124	 0.051501	 0.17376	 0.04326	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46983	 49539	 0.016736	 0.050122	 0.01129	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46983	 49540	 0.005688	 0.023486	 0.00556	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46984	 48888	 0.047762	 0.16403	 0.03936	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46984	 49288	 0.014217	 0.046374	 0.01231	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46984	 49312	 0.00239	 0.011807	 0.00345	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46984	 49313	 0.012478	 0.042044	 0.01045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46984	 49339	 0.00688	 0.026153	 0.00732	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46984	 49434	 0.01446	 0.084721	 0.02309	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46984	 49634	 0.003475	 0.024111	 0.00688	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46984	 91228	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46984	 91228	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46985	 49984	 0.000774	 0.008771	 0.07987	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46985	 91229	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46985	 91229	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46985	 91412	 0.002256	 0.026244	 0.2272	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	46986	 49668	 0.002932	 0.008826	 0.00276	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46986	 91232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46986	 91232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46987	 49054	 0.023942	 0.10786	 0.02872	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91177	 46987	 0.002403	 0.02061	 0.00587	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46987	 91233	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46987	 91233	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46988	 49367	 0.001192	 0.004685	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46988	 49370	 0.008407	 0.028838	 0.00691	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46988	 49371	 0.005528	 0.032378	 0.00882	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46988	 91234	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46988	 91234	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46989	 49029	 0.001886	 0.007412	 0.00194	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46989	 49030	 0.001858	 0.005477	 0.00127	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46989	 91235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46989	 91235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46990	 48800	 0.001549	 0.0062	 0.00156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46990	 48801	 0.002462	 0.008446	 0.00202	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46990	 48803	 0.00407	 0.010757	 0.00252	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46990	 48811	 0.019758	 0.057235	 0.01381	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46990	 91236	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46990	 91236	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46991	 49123	 0.033048	 0.087369	 0.02046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46991	 49467	 0.001434	 0.004998	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	46991	 91237	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46991	 91237	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46992	 49416	 0.024061	 0.064607	 0.01464	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46992	 49436	 0.004569	 0.01347	 0.00313	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	46992	 91238	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46992	 91238	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46993	 49243	 0.010561	 0.017613	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46993	 49301	 0.004186	 0.009616	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46993	 49302	 0.014021	 0.011096	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46994	 49235	 0.00539	 0.00948	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46994	 92128	 0.042599	 0.033712	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46994	 92129	 0.032168	 0.025458	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	46995	 49592	 0.003029	 0.012328	 0.003	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46995	 49601	 0.001111	 0.007265	 0.00185	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	46995	 91239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46995	 91239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	46996	 48844	 0.013281	 0.021199	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46996	 91984	 0.012495	 0.019943	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46996	 91986	 0.019667	 0.030686	 0.00051	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	46997	 48884	 0.016843	 0.056188	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46997	 48885	 0.014706	 0.04853	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46997	 92002	 0.006151	 0.023663	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46998	 49483	 0.049725	 0.34145	 0.00623	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	46998	 92265	 0.018894	 0.056869	 0.00111	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46999	 49620	 0.17943	 0.19738	 0.00263	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46999	 49621	 0.012102	 0.023176	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46999	 49980	 0.051881	 0.27649	 0.00485	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47000	 48871	 0.089744	 0.11796	 0.00162	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47000	 91994	 0.014545	 0.019116	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47001	 50114	 0.00049	 0.0042	 0.0012	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47001	 92435	 0.000282	 0.002062	 0.00061	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47002	 49242	 0.009014	 0.023822	 0.00558	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47002	 49306	 0.002423	 0.008162	 0.00203	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47002	 49339	 0.003067	 0.012056	 0.00315	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47002	 91240	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47002	 91240	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47003	 48965	 0.002942	 0.007637	 0.00185	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47003	 91241	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47003	 91241	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47004	 49938	 0.15074	 0.10897	 0.00165	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47004	 49939	 0.018825	 0.014755	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47004	 49940	 0.011736	 0.023236	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47004	 49941	 0.031887	 0.031894	 0.00043	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47004	 49942	 0.017298	 0.013689	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47005	 49995	 0.11034	 0.16904	 0.00237	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47005	 92391	 0.009715	 0.022555	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47005	 92392	 0.009426	 0.021883	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47006	 48792	 0.005484	 0.014495	 0.00339	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47006	 48801	 0.005754	 0.015207	 0.00356	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47006	 91242	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47006	 91242	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47007	 48927	 0.00021	 0.002291	 0.02249	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47007	 50597	 0.004705	 0.05374	 0.48848	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47007	 91243	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47007	 91243	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47008	 49143	 0.031504	 0.083284	 0.0195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47008	 91246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47008	 91246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47008	 92101	 0.002125	 0.004933	 0.0015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47009	 48860	 0.006255	 0.025044	 0.00631	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47009	 49496	 0.008783	 0.030612	 0.0071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47009	 49497	 0.006764	 0.03962	 0.01079	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47009	 49617	 0.035214	 0.13853	 0.03628	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47009	 91247	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47009	 91247	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47010	 48851	 0.061353	 0.15772	 0.00244	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47010	 48852	 0.065411	 0.16816	 0.0026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47010	 91988	 0.011207	 0.026018	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47011	 47322	 0.001039	 0.013448	 0.86066	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47011	 47340	 0.000329	 0.009091	 0.68222	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47011	 91248	 8.3e-05	 0.006666	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47011	 91248	 8.3e-05	 0.006666	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47012	 47015	 0.076854	 0.10486	 0.00187	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47012	 47016	 0.11161	 0.18615	 0.00271	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47013	 47014	 0.003365	 0.013692	 0.00334	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91068	 47013	 0.030871	 0.12755	 0.0302	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47013	 91252	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47013	 91252	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47014	 47458	 0.014765	 0.060969	 0.01443	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91252	 47015	 0.038676	 0.065153	 0.00093	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47016	 91253	 0.050158	 0.099312	 0.00146	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47017	 47018	 0.011976	 0.047951	 0.01208	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91250	 47017	 0.006238	 0.024976	 0.00629	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47017	 91253	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47017	 91253	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47018	 47345	 0.016406	 0.067748	 0.01603	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47018	 91254	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47018	 91254	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47019	 47021	 0.013882	 0.056496	 0.01377	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47019	 47203	 0.023617	 0.096143	 0.02344	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47020	 47021	 0.008047	 0.03163	 0.00827	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47020	 47204	 0.020276	 0.083738	 0.01982	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47021	 47022	 0.004295	 0.043764	 0.01128	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47021	 47023	 0.006096	 0.029585	 0.00676	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47022	 48254	 0.005315	 0.046044	 0.01653	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91159	 47024	 0.029574	 0.11512	 0.03077	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91102	 47025	 0.026661	 0.069098	 0.00131	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47025	 91506	 0.083087	 0.23834	 0.00367	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47026	 91256	 0.052645	 0.063022	 0.00105	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47026	 91258	 0.099343	 0.10927	 0.00146	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47027	 47028	 0.005393	 0.014253	 0.00334	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47027	 91255	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47027	 91255	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47028	 91256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47028	 91256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47029	 47034	 0.005982	 0.016286	 0.00359	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47029	 91257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47029	 91257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91089	 47030	 0.03931	 0.10875	 0.00253	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47030	 91503	 0.092274	 0.3079	 0.00488	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91089	 47031	 0.11861	 0.092979	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91255	 47032	 0.20958	 0.13571	 0.00258	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91256	 47033	 0.074579	 0.098022	 0.00134	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91095	 47034	 0.0071	 0.023922	 0.00595	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47034	 91258	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47034	 91258	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47035	 47037	 0.057187	 0.13275	 0.00253	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47035	 91269	 0.030246	 0.07775	 0.0012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47036	 47043	 0.084157	 0.064555	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47037	 91260	 0.008596	 0.028367	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47038	 91259	 0.011772	 0.042055	 0.00083	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47038	 91270	 0.013818	 0.044311	 0.0011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47039	 91259	 0.032785	 0.025946	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47040	 47041	 0.004058	 0.013674	 0.0034	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91058	 47040	 0.028018	 0.099071	 0.02234	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47040	 91259	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47040	 91259	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47041	 91260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47041	 91260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91260	 47042	 0.02462	 0.019484	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47043	 47049	 0.027226	 0.038592	 0.00079	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47043	 47051	 0.018799	 0.037221	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91260	 47043	 0.00737	 0.019534	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47044	 47045	 0.009151	 0.020928	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47044	 47050	 0.015703	 0.026454	 0.00038	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91260	 47044	 0.013179	 0.030596	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47045	 91261	 0.008562	 0.023685	 0.00055	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91259	 47046	 0.042647	 0.03375	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91259	 47047	 0.006298	 0.012889	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47047	 91261	 0.01088	 0.022265	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47048	 47075	 0.003604	 0.009525	 0.00223	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47048	 91261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47048	 91261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47049	 91263	 0.00906	 0.025986	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47050	 91262	 0.01354	 0.029016	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47052	 91262	 0.036177	 0.02863	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47053	 47055	 0.003571	 0.009721	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47053	 47072	 0.003873	 0.013048	 0.00324	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47053	 91262	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47053	 91262	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47054	 47055	 0.00196	 0.005466	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47054	 47056	 0.009273	 0.024508	 0.00574	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47054	 91263	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47054	 91263	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47056	 49468	 0.012586	 0.045578	 0.00978	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47056	 91264	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47056	 91264	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47057	 47058	 0.036141	 0.036903	 0.00057	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47057	 47061	 0.026918	 0.048081	 0.00071	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91264	 47057	 0.011685	 0.021728	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91263	 47058	 0.039419	 0.046208	 0.0008	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47059	 47060	 0.074857	 0.059241	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47059	 47064	 0.094833	 0.094859	 0.00128	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47060	 47061	 0.080699	 0.063866	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47061	 47063	 0.058435	 0.089519	 0.00126	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47062	 47063	 0.085848	 0.05558	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47063	 91268	 0.017443	 0.04484	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47064	 91265	 0.070033	 0.18004	 0.00279	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47065	 91265	 0.082981	 0.14823	 0.00219	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47065	 92211	 0.11398	 0.17462	 0.00245	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47066	 47073	 0.00998	 0.039225	 0.01026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91058	 47066	 0.00235	 0.009703	 0.0023	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47066	 91265	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47066	 91265	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47067	 50247	 0.001636	 0.021759	 0.34541	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47067	 91266	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47068	 47070	 0.031102	 0.020892	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91267	 47068	 0.02262	 0.052515	 0.00078	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91267	 47069	 0.04945	 0.032014	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91058	 47071	 0.00727	 0.029107	 0.00733	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91078	 47071	 0.008192	 0.033825	 0.008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47072	 47073	 0.003872	 0.017763	 0.00455	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47072	 91268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47072	 91268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91078	 47073	 0.007066	 0.032957	 0.00816	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91261	 47074	 0.058155	 0.042787	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47075	 47077	 0.004793	 0.01155	 0.00326	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47076	 47080	 0.027731	 0.029614	 0.00063	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47076	 47653	 0.016339	 0.054505	 0.00086	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47077	 47662	 0.004811	 0.014408	 0.00325	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47078	 47079	 0.005149	 0.02126	 0.00503	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47078	 47081	 0.00418	 0.016733	 0.00422	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47078	 91269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47078	 91269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47080	 47082	 0.028013	 0.055464	 0.00081	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91259	 47080	 0.023612	 0.043904	 0.00103	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47081	 47083	 0.010518	 0.026441	 0.00685	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47081	 91270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47081	 91270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47082	 91512	 0.039951	 0.11459	 0.00176	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47083	 47372	 0.018833	 0.048898	 0.01187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47084	 47085	 0.26197	 0.20737	 0.00261	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47084	 49989	 0.082298	 0.19108	 0.00284	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47084	 91271	 0.064652	 0.15311	 0.0028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47085	 47086	 0.23444	 0.22657	 0.00329	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91096	 47085	 0.072101	 0.32274	 0.00665	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47086	 47090	 0.12279	 0.10108	 0.00205	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47087	 47088	 0.006765	 0.023576	 0.00547	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47087	 47102	 0.018008	 0.058744	 0.0156	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47087	 91413	 0.006992	 0.039598	 0.00982	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47088	 91271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47088	 91271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91271	 47089	 0.019272	 0.044742	 0.00067	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91271	 47090	 0.016994	 0.043685	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47091	 47094	 0.10868	 0.109	 0.00176	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47091	 91272	 0.053643	 0.10621	 0.00156	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47092	 47093	 0.007282	 0.028331	 0.00757	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47092	 47126	 0.012143	 0.047729	 0.01249	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47092	 91272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47092	 91272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47093	 47095	 0.009353	 0.038061	 0.00927	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47094	 91323	 0.13642	 0.1486	 0.00202	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47095	 91273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47095	 91273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47095	 91505	 0.020273	 0.083726	 0.01982	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47096	 91276	 0.090961	 0.14521	 0.00334	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47097	 47322	 0.000939	 0.014503	 1.1202	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47097	 91274	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47097	 91274	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47098	 47099	 0.090841	 0.071207	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47099	 48768	 0.29186	 0.21106	 0.0032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91083	 47099	 0.026618	 0.052701	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47100	 47102	 0.017274	 0.047035	 0.01036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47100	 91277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47100	 91277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47101	 49974	 0.062492	 0.14509	 0.00216	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91277	 47101	 0.059849	 0.12826	 0.00225	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47103	 91278	 0.14862	 0.11762	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47104	 91320	 0.16081	 0.12606	 0.00162	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47105	 47106	 0.012024	 0.070442	 0.01919	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47105	 47198	 0.014078	 0.077269	 0.02043	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47105	 91278	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47105	 91278	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47106	 47998	 0.012601	 0.047904	 0.01341	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47106	 48732	 0.021454	 0.049807	 0.01518	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47107	 91279	 0.028521	 0.063126	 0.00104	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47107	 91280	 0.027745	 0.046272	 0.00067	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47108	 47110	 0.007798	 0.02675	 0.00641	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47108	 91279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47108	 91279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47108	 91358	 0.010744	 0.049291	 0.01263	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47109	 47279	 0.013521	 0.05886	 0.01677	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47109	 47411	 0.018326	 0.076318	 0.02381	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47110	 47111	 0.012505	 0.042137	 0.01047	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47110	 91280	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47110	 91280	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47111	 47410	 0.019352	 0.088807	 0.02276	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47111	 47415	 0.024526	 0.10131	 0.02398	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91066	 47111	 0.009459	 0.10649	 0.02799	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47111	 91281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47111	 91281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47112	 91285	 0.003278	 0.01504	 0.00385	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47112	 92055	 0.015887	 0.077117	 0.01763	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47113	 91284	 0.11607	 0.19555	 0.00279	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47113	 91286	 0.11365	 0.1829	 0.00287	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47114	 47115	 0.000611	 0.004428	 0.00891	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47114	 47262	 0.005103	 0.034047	 0.0642	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47114	 91282	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47114	 91282	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91197	 47115	 0.005803	 0.039994	 0.07065	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47115	 91283	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91284	 47115	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47116	 47117	 0.000134	 0.002214	 0.19416	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47116	 47259	 0.000111	 0.001826	 0.16012	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47116	 47555	 0.000641	 0.007656	 0.57496	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47117	 91285	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47118	 47289	 0.043224	 0.16563	 0.00468	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91087	 47118	 0.024488	 0.11117	 0.00241	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47119	 47120	 0.013087	 0.035632	 0.00785	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47119	 47628	 0.013745	 0.055035	 0.01387	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47119	 47641	 0.007279	 0.030053	 0.00711	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47120	 47627	 0.015686	 0.066401	 0.01495	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91087	 47121	 0.007952	 0.015745	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47122	 47123	 0.004614	 0.01795	 0.00479	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47122	 47678	 0.012564	 0.043965	 0.01457	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47122	 91287	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47122	 91287	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47123	 47678	 0.00796	 0.032393	 0.00789	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91287	 47124	 0.11334	 0.16068	 0.00328	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47125	 47194	 0.000602	 0.007992	 0.12667	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47125	 47320	 0.000358	 0.00518	 0.07957	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47125	 91288	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91288	 47126	 0.012861	 0.050555	 0.01323	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47127	 47130	 0.011608	 0.045626	 0.01194	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47127	 47632	 0.012258	 0.058023	 0.01395	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47127	 47891	 0.012328	 0.059834	 0.01368	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47128	 47130	 0.005776	 0.026008	 0.00692	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47128	 47412	 0.008605	 0.044829	 0.01176	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47129	 47131	 0.007783	 0.037774	 0.00864	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47129	 48718	 0.009192	 0.051291	 0.0131	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47129	 91290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47129	 91290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47130	 47131	 0.001682	 0.007574	 0.00202	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47132	 47134	 0.014452	 0.057868	 0.01458	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47132	 47208	 0.009967	 0.036262	 0.0111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47132	 47640	 0.012535	 0.062991	 0.0164	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47132	 91291	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47132	 91291	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47133	 47449	 0.092426	 0.18301	 0.00269	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91291	 47133	 0.1142	 0.17496	 0.00246	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47134	 47135	 0.002568	 0.012155	 0.00292	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47134	 47451	 0.013924	 0.055753	 0.01405	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91098	 47136	 0.060275	 0.12336	 0.00304	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47137	 47422	 0.005361	 0.042238	 0.01236	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47137	 47450	 0.005512	 0.031671	 0.00897	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47137	 91292	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47137	 91292	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47138	 47139	 0.001784	 0.005341	 0.0012	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91105	 47138	 0.001438	 0.005758	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47138	 91293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47138	 91293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47139	 91294	 0.002527	 0.00745	 0.00173	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91106	 47140	 0.023349	 0.018478	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91293	 47141	 0.031733	 0.025113	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47142	 91295	 0.029647	 0.047322	 0.00109	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47143	 47150	 0.000169	 0.002737	 0.02668	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47143	 47264	 0.000695	 0.010021	 0.09195	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47143	 91294	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47144	 91296	 0.045144	 0.069157	 0.00097	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47145	 47151	 0.010285	 0.028002	 0.00617	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47145	 47153	 0.008756	 0.030037	 0.0072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91105	 47145	 0.008895	 0.030515	 0.00731	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47145	 91296	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47145	 91296	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47146	 47147	 0.067626	 0.053519	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91293	 47147	 0.010501	 0.02438	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47148	 47154	 0.076121	 0.15072	 0.00221	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91106	 47148	 0.012067	 0.039823	 0.00065	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47149	 47436	 0.003533	 0.023843	 0.04391	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91052	 47149	 0.008344	 0.057531	 0.1017	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47149	 91297	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47149	 91297	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47150	 91298	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47150	 91298	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47150	 91422	 0.000497	 0.008148	 0.08	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47151	 47152	 0.016572	 0.04166	 0.01079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47151	 91421	 0.006039	 0.02418	 0.00609	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47152	 47397	 0.016185	 0.042021	 0.0102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47153	 47265	 0.011704	 0.042381	 0.00909	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47155	 47156	 0.001826	 0.019479	 0.03962	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47155	 47669	 0.004067	 0.028521	 0.04857	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47155	 91299	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47155	 91299	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47155	 91330	 0.002624	 0.020829	 0.04009	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47155	 93422	 0.009382	 0.10276	 0.20029	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47156	 47158	 0.001481	 0.015588	 0.03258	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47156	 47670	 0.002635	 0.017971	 0.03236	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47157	 47160	 0.029164	 0.074969	 0.00116	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47157	 91302	 0.042911	 0.1651	 0.00282	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47158	 52418	 0.013924	 0.11252	 0.38283	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47158	 91300	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47158	 91300	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47159	 47164	 0.001597	 0.005328	 0.00135	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47159	 47592	 0.002042	 0.01235	 0.00315	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91300	 47159	 0.001437	 0.014262	 0.00388	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47160	 47593	 0.012858	 0.033054	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47161	 47163	 0.002861	 0.018427	 0.00483	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47161	 47612	 0.00565	 0.025918	 0.00664	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47162	 47165	 0.006603	 0.025098	 0.00703	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91299	 47162	 0.011443	 0.048434	 0.0109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47163	 47164	 0.00277	 0.010885	 0.00285	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47163	 91301	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47163	 91301	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91108	 47165	 0.017554	 0.082953	 0.02656	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91300	 47165	 0.003312	 0.020976	 0.00569	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47165	 91302	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47165	 91302	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47166	 47167	 0.01807	 0.018251	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47166	 47173	 0.015272	 0.012086	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47167	 91304	 0.008034	 0.020432	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47168	 47169	 0.000362	 0.002459	 0.00448	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47168	 47177	 0.00081	 0.005259	 0.01048	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88717	 47168	 0.001135	 0.00782	 0.0138	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47168	 91303	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91304	 47168	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47169	 91305	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91306	 47169	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91306	 47170	 0.030757	 0.023302	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47171	 47185	 0.014505	 0.014811	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47172	 47185	 0.011671	 0.009236	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47174	 47559	 0.000115	 0.002355	 0.27643	 3627.0	 3808.3	 3989.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47174	 91307	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47174	 91307	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47175	 47184	 0.00744	 0.031487	 0.00709	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47175	 47439	 0.012703	 0.050865	 0.01282	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47176	 47180	 0.004527	 0.013345	 0.0031	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47176	 47182	 0.012584	 0.038215	 0.00837	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91307	 47177	 0.002478	 0.016901	 0.03043	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47177	 91308	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91309	 47177	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47178	 47181	 0.070664	 0.05539	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91304	 47178	 0.013454	 0.034585	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47179	 91310	 0.022603	 0.01663	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91308	 47180	 0.00477	 0.013817	 0.00333	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47180	 91310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47180	 91310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47182	 47402	 0.01716	 0.051392	 0.01158	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91309	 47183	 0.2019	 0.14856	 0.00217	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47184	 47186	 0.006792	 0.027194	 0.00685	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91304	 47185	 0.0104	 0.026733	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47186	 91315	 0.011181	 0.043949	 0.0115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47187	 47190	 0.000172	 0.002057	 0.15431	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47187	 47437	 0.000146	 0.003612	 0.29991	 3339.0	 3506.0	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47187	 47564	 0.000387	 0.005967	 0.45931	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47187	 91311	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47187	 91311	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47188	 91313	 0.072698	 0.16703	 0.00254	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47188	 91370	 0.13847	 0.32158	 0.00478	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47189	 91313	 0.066962	 0.052994	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47190	 47191	 4.4e-05	 0.000548	 0.03755	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47190	 91312	 0.00012	 0.009565	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47190	 91312	 0.00012	 0.009565	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47191	 47564	 0.000264	 0.004068	 0.31306	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47191	 91314	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91315	 47191	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47192	 47193	 0.011987	 0.047994	 0.01209	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47192	 47257	 0.01871	 0.074927	 0.01888	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47193	 47415	 0.013435	 0.053795	 0.01355	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91274	 47194	 0.00065	 0.009873	 0.17698	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47194	 91316	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47195	 91318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47195	 91318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47196	 47197	 0.005155	 0.024044	 0.00596	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47196	 47198	 0.016873	 0.077427	 0.01984	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47196	 91319	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47196	 91319	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47197	 47345	 0.012563	 0.054688	 0.01558	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47198	 47199	 0.011061	 0.027806	 0.0072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47198	 91320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47198	 91320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91320	 47200	 0.10164	 0.23602	 0.00351	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47200	 91322	 0.063523	 0.14748	 0.00219	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47201	 47203	 0.006829	 0.027343	 0.00689	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47201	 47342	 0.017208	 0.07004	 0.01707	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47202	 47204	 0.003929	 0.01573	 0.00396	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47202	 91321	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47202	 91321	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47202	 91383	 0.028468	 0.159	 0.04068	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47203	 91322	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47203	 91322	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47204	 91323	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47204	 91323	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47205	 47208	 0.006393	 0.027057	 0.00609	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47205	 47643	 0.009241	 0.039113	 0.0088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47206	 47209	 0.034425	 0.13393	 0.00224	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47206	 47214	 0.020365	 0.079228	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47207	 47208	 0.004149	 0.016309	 0.00427	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47207	 47213	 0.003377	 0.012287	 0.00376	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47208	 47217	 0.01046	 0.043189	 0.01022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91287	 47209	 0.098386	 0.26085	 0.00662	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47210	 47212	 0.005505	 0.025254	 0.00647	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47210	 47216	 0.004909	 0.017177	 0.00569	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47210	 91324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47210	 91324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47211	 91325	 0.090862	 0.20388	 0.00325	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47211	 91448	 0.025012	 0.12068	 0.00213	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47211	 91525	 0.073795	 0.20943	 0.00329	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47212	 47502	 0.00388	 0.018097	 0.00448	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47213	 47218	 0.002146	 0.008593	 0.00216	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47214	 47215	 0.029504	 0.058416	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91324	 47214	 0.012936	 0.056997	 0.00099	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47215	 91325	 0.0196	 0.035365	 0.00051	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47216	 47223	 0.001821	 0.007411	 0.00181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47216	 91325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47216	 91325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47217	 47224	 0.001575	 0.007764	 0.0021	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47217	 91326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47217	 91326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47218	 47221	 0.001699	 0.0068	 0.00171	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47219	 47222	 0.012798	 0.015886	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91326	 47219	 0.011089	 0.036991	 0.00059	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47220	 91327	 0.015723	 0.012443	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47221	 47223	 0.000871	 0.003486	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47221	 91327	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47221	 91327	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91327	 47222	 0.023476	 0.02507	 0.00053	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47223	 47227	 0.002956	 0.008479	 0.00209	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47224	 47225	 0.001238	 0.006222	 0.00162	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47225	 47229	 0.00413	 0.020154	 0.00557	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47226	 91328	 0.014351	 0.03975	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47226	 91329	 0.016995	 0.053963	 0.00095	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47227	 91328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47227	 91328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91325	 47228	 0.06074	 0.048069	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47229	 47547	 0.003112	 0.029883	 0.00869	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47229	 91329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47229	 91329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47230	 47656	 0.002599	 0.029476	 0.26887	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47230	 91330	 0.000125	 0.009999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91331	 47230	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47231	 47325	 0.000469	 0.005418	 0.0475	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47232	 47351	 0.01043	 0.03075	 0.00715	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47232	 47354	 0.02186	 0.06446	 0.015	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47232	 47612	 0.009071	 0.042308	 0.01048	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91076	 47232	 0.007146	 0.045265	 0.01229	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47233	 47623	 0.009319	 0.036628	 0.00958	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47233	 49542	 0.016736	 0.06579	 0.01722	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47234	 47292	 0.016968	 0.067945	 0.01712	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47234	 92098	 0.02315	 0.09102	 0.02382	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91097	 47235	 0.030518	 0.060422	 0.00089	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47236	 47254	 0.000271	 0.002976	 0.02891	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47236	 91332	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91333	 47236	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47237	 47254	 0.000606	 0.006943	 0.06877	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47237	 91334	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47237	 91334	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47238	 47239	 0.001977	 0.008163	 0.00193	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47238	 47248	 0.003085	 0.012351	 0.00311	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47239	 47240	 0.001855	 0.008512	 0.00218	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91333	 47239	 0.002911	 0.015676	 0.00431	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47240	 47241	 0.001875	 0.008162	 0.00233	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47240	 91335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47240	 91335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47241	 47242	 0.002099	 0.009627	 0.00247	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47241	 91336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47241	 91336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47242	 47244	 0.003379	 0.01576	 0.0039	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47243	 47430	 0.01954	 0.092513	 0.02226	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47243	 91337	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47243	 91337	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47244	 47279	 0.007579	 0.035349	 0.00876	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47245	 47246	 0.006106	 0.018732	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47245	 47251	 0.029382	 0.023253	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91336	 47245	 0.006534	 0.020044	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47245	 91339	 0.01568	 0.03073	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47246	 47247	 0.00747	 0.024919	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91335	 47246	 0.013343	 0.024809	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47247	 91338	 0.008994	 0.03213	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91092	 47248	 0.00714	 0.030221	 0.0068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47248	 91338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47248	 91338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91099	 47249	 0.011904	 0.023568	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91338	 47249	 0.014567	 0.037447	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47250	 91339	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47250	 91339	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91339	 47251	 0.013387	 0.024061	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47252	 91340	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47252	 91340	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47253	 91341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47253	 91341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47253	 91487	 0.017796	 0.075337	 0.01696	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47254	 91342	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91343	 47254	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47255	 47256	 0.02384	 0.06765	 0.00106	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47255	 91371	 0.043012	 0.12337	 0.0019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47256	 91345	 0.016515	 0.03777	 0.00092	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47257	 47574	 0.015994	 0.065095	 0.01586	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47257	 91344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47257	 91344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91085	 47258	 0.023176	 0.092823	 0.0234	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91316	 47258	 0.034154	 0.13685	 0.03452	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47258	 91345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47258	 91345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47259	 47437	 0.000554	 0.010777	 0.77837	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47259	 91346	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91347	 47259	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47260	 91350	 0.16178	 0.12682	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91282	 47261	 0.015496	 0.05891	 0.01649	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47261	 91348	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47261	 91348	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47261	 91352	 0.013806	 0.045032	 0.01196	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47262	 47263	 0.000371	 0.003927	 0.00899	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47262	 91353	 0.000182	 0.001813	 0.00605	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91346	 47263	 0.000773	 0.012563	 0.0248	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47263	 91349	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91350	 47263	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47264	 47267	 0.00035	 0.003836	 0.03726	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47264	 91351	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91352	 47264	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47264	 91476	 0.001489	 0.016587	 0.15651	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91349	 47265	 0.003429	 0.011439	 0.0029	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47266	 47267	 0.000115	 0.001303	 0.01186	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47266	 91353	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47266	 91353	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47267	 49032	 0.001612	 0.01769	 0.17196	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47268	 47272	 0.01666	 0.057158	 0.01369	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47268	 47432	 0.015633	 0.052678	 0.01309	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47268	 91354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47268	 91354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91073	 47269	 0.049936	 0.12837	 0.00199	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91354	 47269	 0.053957	 0.20993	 0.0035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47270	 47272	 0.003939	 0.015483	 0.00405	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47270	 47411	 0.013228	 0.060694	 0.01555	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47270	 47412	 0.025799	 0.066989	 0.01626	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47271	 47272	 0.004855	 0.028201	 0.00664	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47271	 47330	 0.011542	 0.046973	 0.01145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47272	 47281	 0.03818	 0.10399	 0.02292	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91063	 47273	 0.009098	 0.040711	 0.00084	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91061	 47274	 0.000817	 0.005728	 0.00975	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91091	 47274	 0.001422	 0.009702	 0.01747	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47274	 91355	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91356	 47274	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47274	 91484	 0.001668	 0.018	 0.03573	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47275	 91357	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47275	 91357	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91356	 47276	 0.032515	 0.064377	 0.00094	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91067	 47277	 0.042377	 0.081157	 0.00128	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47278	 53854	 0.010637	 0.098145	 0.39109	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91091	 47278	 0.001445	 0.012646	 0.02305	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47278	 91358	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47278	 91358	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47279	 91359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47279	 91359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47280	 47618	 0.013627	 0.05302	 0.01416	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47281	 47282	 0.00766	 0.026276	 0.0063	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47281	 91360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47281	 91360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47282	 91361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47282	 91361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47283	 47285	 0.001231	 0.008481	 0.01497	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47283	 47590	 0.011889	 0.083536	 0.14263	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47283	 91362	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91363	 47283	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47284	 47288	 0.007705	 0.037614	 0.00079	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91363	 47284	 0.01101	 0.042182	 0.00119	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91052	 47285	 0.001993	 0.018336	 0.03489	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47285	 91364	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47285	 91364	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47285	 91366	 0.002363	 0.014969	 0.03135	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47286	 47437	 0.000782	 0.009342	 0.70189	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47286	 91365	 0.000163	 0.012221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91367	 47286	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91364	 47287	 0.080016	 0.058872	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47288	 47289	 0.018485	 0.08237	 0.0014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91364	 47288	 0.026039	 0.10018	 0.00171	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47288	 91504	 0.13512	 0.32242	 0.00723	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47290	 47676	 0.13961	 0.25195	 0.00364	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47290	 47677	 0.096313	 0.22361	 0.00426	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91054	 47290	 0.028127	 0.17294	 0.00312	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47291	 91368	 0.23962	 0.18384	 0.00247	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47292	 47293	 0.010901	 0.043647	 0.011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47292	 47294	 0.011135	 0.045977	 0.01088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91362	 47292	 0.03122	 0.10524	 0.02617	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47292	 91368	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47292	 91368	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47294	 47627	 0.011673	 0.049408	 0.01112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47295	 47297	 0.011944	 0.046949	 0.01228	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47295	 47335	 0.01515	 0.059551	 0.01558	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47296	 91369	 0.046551	 0.03684	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47297	 47298	 0.01324	 0.034037	 0.00843	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91053	 47297	 0.008803	 0.039637	 0.01055	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47297	 91369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47297	 91369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47298	 91370	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47298	 91370	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91053	 47299	 0.011979	 0.050704	 0.01141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47300	 47370	 0.070161	 0.1266	 0.00183	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47300	 91380	 0.095481	 0.15653	 0.00276	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47301	 47319	 0.00021	 0.002693	 0.04579	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47301	 91371	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47301	 91371	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47301	 91381	 0.000313	 0.004237	 0.06455	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91371	 47302	 0.058617	 0.059205	 0.00078	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91050	 47303	 0.002749	 0.018334	 0.03456	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47303	 91372	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91373	 47303	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47303	 91382	 0.002294	 0.016083	 0.02738	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91373	 47304	 0.019005	 0.048854	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47305	 47306	 0.001977	 0.005225	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91109	 47305	 0.004911	 0.016846	 0.00404	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47306	 47308	 0.003295	 0.008846	 0.002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47306	 91374	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47306	 91374	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91374	 47307	 0.017932	 0.01476	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47307	 91375	 0.024755	 0.016026	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47308	 47313	 0.001752	 0.005272	 0.00165	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91372	 47308	 0.004079	 0.013993	 0.00335	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47308	 91375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47308	 91375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47309	 47310	 0.0028	 0.007399	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91372	 47309	 0.002179	 0.006112	 0.00157	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47310	 91376	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47310	 91376	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47311	 47312	 0.008731	 0.017287	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91376	 47311	 0.008959	 0.022784	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47312	 47315	 0.004691	 0.015482	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91375	 47312	 0.016254	 0.031128	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47313	 47314	 0.001273	 0.004368	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47314	 47317	 0.002027	 0.006613	 0.00176	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47315	 47318	 0.019606	 0.087365	 0.00148	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47315	 91378	 0.024598	 0.032329	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47316	 47317	 0.004472	 0.01346	 0.00421	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47316	 47343	 0.012247	 0.055147	 0.01468	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47316	 91377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47316	 91377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47317	 91378	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47317	 91378	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91110	 47318	 0.080017	 0.18579	 0.00276	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47318	 91379	 0.009225	 0.090405	 0.00177	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47319	 47320	 0.000202	 0.002551	 0.04455	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47320	 91379	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47320	 91379	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91068	 47321	 0.014185	 0.038621	 0.00851	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47321	 91380	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47321	 91380	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47322	 91381	 8.3e-05	 0.006666	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91382	 47322	 0.000182	 0.014599	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91070	 47323	 0.01051	 0.10131	 0.22869	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47323	 91383	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91384	 47323	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47324	 47325	 0.000916	 0.010198	 0.09619	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47324	 47656	 0.003532	 0.040863	 0.35952	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47324	 91385	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47324	 91385	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47324	 91390	 0.000767	 0.010113	 0.09025	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47324	 91414	 0.001191	 0.013749	 0.12058	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91046	 47325	 0.001246	 0.013194	 0.19742	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47325	 91386	 0.000125	 0.009999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47325	 91386	 0.000125	 0.009999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47326	 91388	 0.089325	 0.070692	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91386	 47327	 0.001117	 0.00982	 0.02048	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47327	 91387	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91388	 47327	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91386	 47328	 0.002069	 0.015974	 0.03251	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47328	 91389	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47328	 91389	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47328	 91391	 0.001284	 0.008565	 0.01614	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47329	 47414	 0.000587	 0.007007	 0.52608	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47329	 91390	 8.3e-05	 0.006666	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91391	 47329	 0.000182	 0.014599	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91100	 47331	 0.042936	 0.24411	 0.00442	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47331	 91404	 0.105	 0.26996	 0.00418	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47332	 47337	 0.002414	 0.009664	 0.00243	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47332	 91392	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47332	 91392	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47332	 91477	 0.011377	 0.045555	 0.01148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47333	 47623	 0.027736	 0.081794	 0.01903	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91367	 47333	 0.033672	 0.11239	 0.02853	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47333	 91393	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47333	 91393	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91393	 47334	 0.25657	 0.16615	 0.00316	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47335	 47336	 0.00575	 0.021858	 0.00612	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47336	 47337	 0.003586	 0.014806	 0.0035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47338	 47424	 0.00018	 0.002822	 0.2742	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47338	 47559	 0.000232	 0.003633	 0.35313	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47338	 91394	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47338	 91394	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47339	 47341	 0.014731	 0.041082	 0.00862	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47339	 47404	 0.027081	 0.062877	 0.01916	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47340	 47426	 0.000183	 0.003074	 0.299	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47340	 47559	 0.000306	 0.005234	 0.40755	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47340	 47564	 0.000135	 0.003037	 0.29175	 3627.0	 3808.3	 3989.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47340	 91395	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91395	 47341	 0.014991	 0.0348	 0.0106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47342	 47344	 0.00733	 0.031025	 0.00698	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47343	 47344	 0.004239	 0.01697	 0.00428	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91383	 47345	 0.020378	 0.066477	 0.01765	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47346	 47348	 0.17302	 0.22745	 0.00312	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91088	 47346	 0.010541	 0.037657	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91073	 47347	 0.036285	 0.19335	 0.00339	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91088	 47347	 0.034198	 0.098086	 0.00151	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47348	 47349	 0.23675	 0.1794	 0.00247	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91360	 47348	 0.12171	 0.43507	 0.00865	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47350	 47352	 0.014455	 0.061186	 0.01377	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91047	 47350	 0.005558	 0.04616	 0.01806	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47351	 47352	 0.008722	 0.026253	 0.00821	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47352	 47353	 0.008128	 0.03847	 0.00925	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47353	 47354	 0.004982	 0.023232	 0.00575	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47354	 47587	 0.019677	 0.080094	 0.01952	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47354	 91397	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47354	 91397	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91397	 47355	 0.088218	 0.06767	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47356	 47361	 0.072007	 0.079201	 0.00106	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47357	 47358	 0.016558	 0.049836	 0.00097	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47357	 91527	 0.025717	 0.073761	 0.00113	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47358	 47363	 0.019143	 0.06386	 0.00101	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47359	 47366	 0.006142	 0.027369	 0.00744	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47359	 47688	 0.008376	 0.038425	 0.00984	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47360	 47362	 0.001227	 0.011553	 0.0035	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47360	 47686	 0.00472	 0.042861	 0.01397	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47361	 47363	 0.008019	 0.026751	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47361	 91398	 0.014694	 0.057164	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47362	 47504	 0.004752	 0.025264	 0.00586	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47362	 47510	 0.003212	 0.019132	 0.00503	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47362	 91398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47362	 91398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91398	 47364	 0.050753	 0.040165	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47365	 47366	 0.004754	 0.021811	 0.00559	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47365	 91399	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47365	 91399	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47365	 91456	 0.006517	 0.029896	 0.00766	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47367	 47368	 0.054047	 0.12417	 0.00189	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47367	 47369	 0.10162	 0.22495	 0.00369	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47367	 91435	 0.026785	 0.11802	 0.00205	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47368	 47369	 0.04017	 0.12755	 0.00224	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91399	 47368	 0.046126	 0.15388	 0.00244	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47369	 91457	 0.026646	 0.15148	 0.00274	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47370	 47371	 0.23845	 0.17241	 0.00261	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47370	 91457	 0.14479	 0.20557	 0.00338	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47372	 47373	 0.013893	 0.03672	 0.0086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91331	 47373	 0.05233	 0.14605	 0.03069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47373	 91400	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47373	 91400	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91385	 47374	 0.022526	 0.12369	 0.03272	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91400	 47375	 0.20083	 0.22093	 0.00295	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47376	 47378	 0.002223	 0.015161	 0.0273	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47376	 47590	 0.00299	 0.019939	 0.03759	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47377	 47379	 0.21776	 0.17236	 0.00217	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47378	 49147	 0.011243	 0.074158	 0.14386	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91096	 47379	 0.076731	 0.12578	 0.00222	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47380	 47386	 0.001312	 0.00602	 0.00154	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47380	 47388	 0.002646	 0.018711	 0.00513	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47380	 91401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47380	 91401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91401	 47381	 0.032561	 0.025523	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47382	 47384	 0.037986	 0.029775	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47383	 47384	 0.005147	 0.017171	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47383	 91403	 0.010803	 0.02139	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47384	 91402	 0.00386	 0.018834	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47385	 47387	 0.025043	 0.01963	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47386	 91402	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47386	 91402	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47387	 47391	 0.03171	 0.034877	 0.00047	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91073	 47387	 0.041149	 0.23395	 0.00423	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91401	 47387	 0.014006	 0.036005	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47388	 47389	 0.007594	 0.033271	 0.01144	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47388	 47390	 0.012944	 0.05939	 0.01522	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47388	 53844	 0.002298	 0.016256	 0.00446	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47388	 91403	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47388	 91403	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47390	 47831	 0.015743	 0.070896	 0.01887	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47390	 50536	 0.012406	 0.042561	 0.0102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47390	 91404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47390	 91404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47392	 47394	 0.000518	 0.00592	 0.00282	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47392	 91405	 0.000526	 0.005788	 0.00296	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47393	 47396	 4e-05	 0.001092	 0.0753	 2893.0	 3037.6	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47393	 49555	 7.1e-05	 0.001871	 0.15415	 3031.0	 3182.6	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47393	 91405	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47394	 91408	 0.00059	 0.006203	 0.00348	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91406	 47395	 0.011856	 0.039124	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47395	 91409	 0.018152	 0.059902	 0.00097	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47396	 47399	 0.000113	 0.003072	 0.21186	 2893.0	 3037.6	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47396	 91407	 0.000261	 0.018248	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91408	 47396	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47397	 49033	 0.009604	 0.041805	 0.01191	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91065	 47397	 0.009802	 0.039247	 0.00989	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47398	 47400	 0.17652	 0.13971	 0.00176	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47399	 47437	 0.000854	 0.011045	 0.7062	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91057	 47400	 0.023089	 0.077025	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47401	 47402	 0.010766	 0.043107	 0.01086	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91056	 47401	 0.007375	 0.026706	 0.00573	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47402	 47433	 0.017789	 0.04472	 0.01159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91065	 47403	 0.011183	 0.031184	 0.00655	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47403	 91409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47403	 91409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47404	 47689	 0.026069	 0.062834	 0.01774	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47404	 91410	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47404	 91410	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47405	 47406	 0.086125	 0.19325	 0.00308	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47405	 47459	 0.058602	 0.13464	 0.00205	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91410	 47405	 0.07969	 0.24477	 0.00459	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47406	 47425	 0.13643	 0.27017	 0.00397	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91251	 47406	 0.13113	 0.30135	 0.00458	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47407	 47408	 0.045088	 0.20093	 0.00341	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47407	 47409	 0.052877	 0.18516	 0.00513	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91341	 47407	 0.12397	 0.31536	 0.00499	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47408	 47696	 0.06827	 0.31002	 0.00673	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47409	 47431	 0.068856	 0.22973	 0.00364	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47410	 47412	 0.010294	 0.048012	 0.01189	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47411	 91411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47411	 91411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47413	 47414	 0.000271	 0.003505	 0.2237	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47413	 49637	 0.00115	 0.028651	 2.9596	 1725.0	 1725.0	 1725.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47413	 49637	 0.00115	 0.028651	 2.9596	 1725.0	 1725.0	 1725.0	 0.0	 0.0	 0	 -30.0	 30.0;
	47413	 91412	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91413	 47413	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47414	 91414	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91275	 47415	 0.013858	 0.055491	 0.01398	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47415	 91416	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47415	 91416	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47416	 47418	 0.029168	 0.1292	 0.00295	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91416	 47416	 0.043826	 0.16794	 0.00475	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47417	 47631	 0.060851	 0.20083	 0.00325	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91074	 47417	 0.048959	 0.15036	 0.00282	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47418	 47420	 0.006827	 0.028343	 0.00074	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91074	 47419	 0.016634	 0.038618	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91074	 47420	 0.011701	 0.066511	 0.0012	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47421	 47532	 0.007825	 0.03133	 0.00789	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47422	 91487	 0.006753	 0.054262	 0.01526	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91343	 47423	 0.00755	 0.07108	 0.02154	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47423	 91528	 0.007443	 0.071478	 0.0208	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47424	 47426	 3.8e-05	 0.000647	 0.05234	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47425	 91418	 0.11349	 0.21106	 0.00494	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47426	 47428	 2.9e-05	 0.000557	 0.06531	 3450.0	 3622.5	 3795.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91060	 47427	 0.000552	 0.009229	 0.00523	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47427	 91417	 0.000449	 0.007332	 0.00437	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47428	 91417	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47428	 91417	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91052	 47429	 0.019501	 0.14237	 0.28956	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91059	 47429	 0.001615	 0.018942	 0.07642	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91249	 47429	 0.002823	 0.028596	 0.05758	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47429	 91418	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47429	 91418	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91101	 47431	 0.042934	 0.12184	 0.00191	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47433	 47439	 0.004139	 0.011112	 0.00252	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47434	 91420	 0.14763	 0.11573	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47435	 47436	 0.000409	 0.002778	 0.00506	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47435	 91419	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91420	 47435	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47435	 91423	 0.003139	 0.021408	 0.03855	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47436	 91421	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47436	 91421	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47437	 91422	 8.9e-05	 0.007096	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47437	 91422	 8.9e-05	 0.007096	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91370	 47438	 0.24644	 0.24656	 0.00333	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91424	 47438	 0.20083	 0.20091	 0.00271	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47439	 91425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47439	 91425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47440	 47444	 0.013763	 0.055107	 0.01388	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47440	 47588	 0.016598	 0.065246	 0.01707	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47440	 91426	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47440	 91426	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47441	 47442	 0.008396	 0.038519	 0.00987	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47441	 47443	 0.006109	 0.032355	 0.0082	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47441	 47617	 0.028706	 0.115	 0.02899	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91076	 47441	 0.024207	 0.17561	 0.09486	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47441	 91427	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47441	 91427	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47442	 47445	 0.013742	 0.07125	 0.0174	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47443	 47444	 0.008677	 0.044359	 0.01209	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47444	 47445	 0.013099	 0.050964	 0.01361	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47445	 47618	 0.005619	 0.052895	 0.01602	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47446	 91428	 0.34872	 0.22588	 0.0043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91048	 47447	 0.064475	 0.080036	 0.00174	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47448	 47452	 0.006792	 0.022883	 0.00569	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47448	 91428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47448	 91428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91428	 47449	 0.035223	 0.13703	 0.00229	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47450	 47451	 0.00426	 0.023637	 0.00719	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47451	 47452	 0.003189	 0.025125	 0.00735	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91047	 47452	 0.003044	 0.0256	 0.00758	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47452	 91429	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47452	 91429	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91048	 47453	 0.010565	 0.064953	 0.00117	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91429	 47453	 0.005637	 0.03869	 0.00071	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47454	 91430	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91432	 47455	 0.015527	 0.015572	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47456	 47684	 0.017484	 0.11978	 0.21705	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91430	 47456	 0.001035	 0.006812	 0.01318	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47456	 91433	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91434	 47456	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47457	 91526	 0.2889	 0.2287	 0.00288	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47458	 47687	 0.028249	 0.11316	 0.02853	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47458	 91435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47458	 91435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91435	 47459	 0.064823	 0.14894	 0.00226	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47460	 47525	 0.000276	 0.003189	 0.02796	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47460	 91436	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47461	 47521	 0.021132	 0.034452	 0.00053	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47461	 91473	 0.00896	 0.017739	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47462	 47463	 0.003691	 0.01436	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47462	 91473	 0.006237	 0.01789	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47463	 91443	 0.006249	 0.026086	 0.00075	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47464	 91438	 0.025185	 0.019931	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47465	 47467	 0.000988	 0.004532	 0.00116	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47465	 47468	 0.001137	 0.004733	 0.00148	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47466	 47492	 0.002616	 0.006724	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47466	 47553	 0.001255	 0.004437	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47467	 47554	 0.001837	 0.008428	 0.00216	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47468	 47469	 0.000629	 0.004051	 0.00106	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47468	 47553	 0.001115	 0.003825	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47468	 91438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47468	 91438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47469	 91439	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47469	 91439	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47469	 91442	 0.001338	 0.008226	 0.00237	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47470	 47481	 0.066715	 0.049085	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47470	 47482	 0.008978	 0.022832	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47470	 91443	 0.003064	 0.018837	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47471	 47530	 2.7e-05	 0.000351	 0.0224	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47471	 91440	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47472	 47480	 0.0088	 0.020431	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47472	 47482	 0.010316	 0.023949	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47473	 47474	 0.002736	 0.012193	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47473	 47480	 0.008119	 0.018848	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91439	 47473	 0.013708	 0.033554	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47474	 47475	 0.002688	 0.009846	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47475	 91475	 0.004321	 0.013857	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47476	 47479	 0.006745	 0.015425	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47476	 47539	 0.010848	 0.023247	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91103	 47476	 0.009022	 0.031569	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47477	 47479	 0.01353	 0.010707	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47478	 47479	 0.004123	 0.012409	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47478	 91444	 0.007553	 0.023982	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47481	 91463	 0.03808	 0.037407	 0.00063	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47483	 91444	 0.023618	 0.018513	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47484	 47526	 0.005598	 0.02027	 0.00435	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47484	 91444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47484	 91444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47485	 47489	 0.012029	 0.016765	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47485	 47490	 0.020001	 0.015153	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47485	 91472	 0.012449	 0.032001	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47486	 47488	 0.000583	 0.004391	 0.00122	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91436	 47486	 0.000796	 0.006099	 0.00163	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91081	 47487	 0.002135	 0.007895	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47488	 47498	 0.000726	 0.00547	 0.00152	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47488	 91445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47488	 91445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47489	 47491	 0.00636	 0.013629	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47489	 47499	 0.003514	 0.015657	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47491	 91446	 0.005886	 0.013666	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47492	 91446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47492	 91446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47493	 47496	 0.005499	 0.018148	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47493	 47500	 0.017575	 0.01293	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47493	 47517	 0.002884	 0.026532	 0.00053	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91445	 47493	 0.013047	 0.050755	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47494	 47495	 0.022341	 0.015825	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91446	 47495	 0.044932	 0.034042	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91446	 47496	 0.006335	 0.020116	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47497	 91447	 0.025937	 0.020526	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47498	 47511	 0.001119	 0.008992	 0.00253	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47498	 91447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47498	 91447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91447	 47499	 0.004109	 0.018312	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47501	 91450	 0.043143	 0.058862	 0.00105	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47502	 47518	 0.005535	 0.032419	 0.00883	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47502	 91448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47502	 91448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47503	 91449	 0.10032	 0.079398	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47504	 47505	 0.001473	 0.008339	 0.00207	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47504	 91449	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47504	 91449	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47505	 91450	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47505	 91450	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47505	 91456	 0.003342	 0.019909	 0.00524	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47506	 47509	 0.002066	 0.012493	 0.00319	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47506	 91451	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47506	 91451	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47506	 91456	 0.00216	 0.013404	 0.00325	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91451	 47507	 0.054652	 0.035382	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47508	 91452	 0.035361	 0.027718	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47509	 47510	 0.000966	 0.005549	 0.00157	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47509	 91452	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47509	 91452	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47511	 47516	 0.001511	 0.008848	 0.00241	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47511	 91453	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47511	 91453	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47512	 47513	 0.00372	 0.011196	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47512	 47515	 0.031842	 0.023018	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91453	 47512	 0.005797	 0.019129	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47513	 91454	 0.004126	 0.013765	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91451	 47514	 0.007854	 0.030555	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91451	 47514	 0.007854	 0.030555	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47514	 91454	 0.004211	 0.01638	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47514	 91454	 0.004211	 0.01638	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47516	 47518	 0.001624	 0.007449	 0.00191	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47516	 91454	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47516	 91454	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47517	 91455	 0.003901	 0.029465	 0.00087	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47518	 91455	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47518	 91455	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47519	 91456	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47519	 91456	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91085	 47520	 0.004398	 0.020814	 0.005	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47520	 91457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47520	 91457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91443	 47521	 0.007274	 0.040929	 0.00088	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47522	 47530	 0.000106	 0.001267	 0.09502	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47522	 47572	 8.6e-05	 0.001111	 0.07093	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47522	 91458	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91086	 47523	 0.059809	 0.047332	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47524	 47525	 0.000359	 0.003935	 0.03822	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47524	 47531	 0.000123	 0.001432	 0.01375	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91458	 47524	 0.000155	 0.001723	 0.01625	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47524	 91461	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47524	 91461	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47525	 91462	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47525	 91462	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47526	 47527	 0.002495	 0.009988	 0.00252	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91442	 47526	 0.005388	 0.017574	 0.00467	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47526	 91463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47526	 91463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47527	 47543	 0.001997	 0.007851	 0.00205	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47527	 47574	 0.009825	 0.041583	 0.00936	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91080	 47527	 4.2e-05	 0.000464	 0.00014	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47527	 91464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47527	 91464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47528	 47529	 0.00715	 0.01838	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91463	 47528	 0.018062	 0.026783	 0.0004	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47529	 91466	 0.008938	 0.018291	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47530	 91465	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47530	 91465	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91440	 47531	 0.000134	 0.001661	 0.01539	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91465	 47531	 6.7e-05	 0.000776	 0.0068	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47531	 91466	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47531	 91466	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47532	 47533	 0.006099	 0.023727	 0.00634	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47533	 47536	 0.008349	 0.033429	 0.00842	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47534	 91467	 0.005417	 0.026003	 0.00078	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47534	 91471	 0.008492	 0.052207	 0.00094	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47535	 47540	 0.002614	 0.012687	 0.0029	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47535	 47543	 0.005455	 0.021222	 0.00567	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47535	 47544	 0.003966	 0.010481	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47536	 47540	 0.001614	 0.010027	 0.00283	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47536	 91467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47536	 91467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91467	 47537	 0.045907	 0.02972	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47538	 47539	 0.026737	 0.019671	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47539	 47542	 0.01062	 0.021026	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47540	 91468	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47540	 91468	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91468	 47541	 0.021669	 0.016985	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91468	 47542	 0.009873	 0.017814	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47543	 91469	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47543	 91469	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47544	 47581	 0.003806	 0.01006	 0.00235	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47545	 91470	 0.036616	 0.072497	 0.00106	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47546	 47547	 0.002919	 0.017097	 0.00466	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47546	 91470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47546	 91470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47547	 47548	 0.001843	 0.007005	 0.00196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47548	 91471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47548	 91471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47549	 91472	 0.022372	 0.017705	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47550	 47552	 0.001315	 0.003876	 0.0009	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47550	 47553	 0.002538	 0.006524	 0.00162	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47550	 91472	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47550	 91472	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47551	 47552	 0.001644	 0.004343	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91436	 47551	 0.003	 0.007929	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47552	 91473	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47552	 91473	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47553	 91474	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47553	 91474	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47554	 91475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47554	 91475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47555	 47558	 0.00014	 0.001814	 0.11574	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47555	 49639	 0.000369	 0.004602	 0.31542	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47556	 47622	 0.14905	 0.22105	 0.00332	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47556	 91478	 0.070621	 0.20042	 0.00315	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47557	 91478	 0.063827	 0.064468	 0.00085	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47558	 91476	 8.3e-05	 0.006666	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91082	 47560	 0.013428	 0.052237	 0.00087	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91082	 47560	 0.013428	 0.052237	 0.00087	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47560	 91479	 0.015364	 0.047133	 0.00128	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47560	 91479	 0.015364	 0.047133	 0.00128	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91082	 47561	 0.066319	 0.11967	 0.00173	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91248	 47562	 0.001502	 0.02663	 0.43862	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91312	 47562	 0.000483	 0.008934	 0.08585	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47562	 91479	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47562	 91479	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47562	 91480	 0.000246	 0.002686	 0.02637	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91479	 47563	 0.056079	 0.043016	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47564	 91480	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91481	 47564	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47565	 47566	 0.033612	 0.032888	 0.00047	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47566	 47569	 0.015037	 0.033736	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47566	 91482	 0.007999	 0.028575	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47567	 47585	 0.005121	 0.020127	 0.00527	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91442	 47567	 0.016889	 0.055093	 0.01463	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47567	 91482	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47567	 91482	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47568	 47569	 0.011371	 0.023367	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47568	 91489	 0.033477	 0.066281	 0.00097	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47569	 47570	 0.034878	 0.027339	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47571	 47575	 0.019164	 0.035633	 0.00083	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47571	 91489	 0.021361	 0.039718	 0.00093	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47573	 47575	 0.036261	 0.067424	 0.00158	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91086	 47573	 0.054926	 0.15215	 0.00251	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47573	 91483	 0.033588	 0.076815	 0.00188	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47574	 91483	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47574	 91483	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47575	 47576	 0.014381	 0.047456	 0.00077	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91460	 47576	 0.015202	 0.058485	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91049	 47577	 0.001732	 0.020138	 0.17423	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47577	 91484	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47578	 47694	 0.003142	 0.048427	 0.10684	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91332	 47578	 0.001463	 0.020512	 0.03934	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91342	 47578	 0.000875	 0.013094	 0.03063	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47578	 91487	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91488	 47578	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47579	 47584	 0.15465	 0.1224	 0.00154	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91488	 47579	 0.27623	 0.19974	 0.00303	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91486	 47580	 0.18139	 0.11745	 0.00224	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47581	 47582	 0.003481	 0.00808	 0.00246	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47582	 91489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47582	 91489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47583	 47584	 0.063665	 0.049904	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91463	 47583	 0.060939	 0.14431	 0.00264	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91485	 47585	 0.005399	 0.021614	 0.00545	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47586	 91490	 0.038694	 0.053927	 0.00092	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47587	 47588	 0.009444	 0.038995	 0.00923	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47587	 91490	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47587	 91490	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91415	 47589	 0.16571	 0.34844	 0.00635	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47589	 91492	 0.1067	 0.24775	 0.00369	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47590	 91491	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91492	 47590	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91492	 47591	 0.026566	 0.13815	 0.003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47591	 91510	 0.026641	 0.13557	 0.00307	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47592	 47597	 0.00119	 0.005633	 0.00135	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47592	 91493	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47592	 91493	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91493	 47593	 0.006632	 0.02369	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47593	 91498	 0.10007	 0.13947	 0.00239	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47594	 91495	 0.003463	 0.011554	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47594	 91498	 0.050872	 0.10902	 0.00191	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47595	 47596	 0.000821	 0.003285	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47595	 47600	 0.001058	 0.004116	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47596	 47597	 0.000769	 0.00373	 0.00085	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47596	 91494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47596	 91494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47597	 47598	 0.001836	 0.005412	 0.00126	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47598	 47604	 0.004926	 0.013412	 0.00295	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91494	 47599	 0.005763	 0.015962	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47599	 91495	 0.00948	 0.022009	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47600	 91495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47600	 91495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47601	 47602	 0.002383	 0.01111	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91495	 47601	 0.002277	 0.015633	 0.00028	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47602	 47603	 0.027284	 0.021592	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47602	 91497	 0.003809	 0.014819	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47604	 47608	 0.002827	 0.011111	 0.00291	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47604	 91496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47604	 91496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47605	 47606	 0.000785	 0.003087	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47605	 91497	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47605	 91497	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47606	 47609	 0.002302	 0.006418	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47606	 47616	 0.013412	 0.035448	 0.0083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47606	 52850	 0.003352	 0.025118	 0.00613	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47607	 47611	 0.033094	 0.02619	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91047	 47608	 0.013835	 0.16753	 0.09538	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47608	 91498	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47608	 91498	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47609	 47610	 0.003177	 0.008395	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47609	 91499	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47609	 91499	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47610	 47616	 0.008162	 0.021913	 0.00497	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91498	 47611	 0.012237	 0.031457	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47613	 47614	 0.13716	 0.1494	 0.00203	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47614	 47615	 0.11207	 0.084908	 0.00117	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91498	 47614	 0.030372	 0.075385	 0.00125	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47616	 47617	 0.011421	 0.041552	 0.01272	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47616	 91500	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47616	 91500	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47618	 47620	 0.002754	 0.030987	 0.00814	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47619	 47620	 0.001785	 0.014812	 0.0039	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47619	 93409	 0.02347	 0.080531	 0.0193	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47620	 91501	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47620	 91501	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91360	 47621	 0.2824	 0.22355	 0.00281	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47622	 49543	 0.35127	 0.26957	 0.00362	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47622	 91502	 0.097928	 0.15003	 0.00211	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47623	 47624	 0.010228	 0.03336	 0.00886	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47623	 91502	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47623	 91502	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47624	 47625	 0.015106	 0.054704	 0.01174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91362	 47625	 0.01508	 0.051737	 0.0124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47626	 47628	 0.009845	 0.039419	 0.00993	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91491	 47626	 0.022717	 0.0758	 0.01923	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47626	 91503	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47626	 91503	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47628	 91504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47628	 91504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47629	 47630	 0.004295	 0.02865	 0.05402	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47629	 91505	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91506	 47629	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47629	 91916	 0.003645	 0.024315	 0.04584	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91070	 47630	 0.000126	 0.000958	 0.00174	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47630	 91507	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47630	 91507	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91072	 47631	 0.037078	 0.14425	 0.00241	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47632	 47889	 0.027092	 0.090409	 0.02294	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91071	 47632	 0.006828	 0.066718	 0.01873	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47632	 91508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47632	 91508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47633	 48676	 0.011267	 0.045095	 0.01524	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91071	 47633	 0.005414	 0.055165	 0.01422	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47634	 47635	 0.038667	 0.039055	 0.00052	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47634	 91509	 0.01523	 0.031166	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47636	 47637	 0.04737	 0.037488	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47637	 91509	 0.008059	 0.039324	 0.00068	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91071	 47638	 0.004479	 0.026881	 0.00814	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47638	 91509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47638	 91509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47639	 47640	 0.01052	 0.047369	 0.01261	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91491	 47639	 0.019657	 0.077278	 0.02022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47639	 91510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47639	 91510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47641	 47642	 0.006348	 0.026866	 0.00605	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47642	 47643	 0.008701	 0.035406	 0.00863	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47643	 91511	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47643	 91511	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47644	 91512	 0.038835	 0.069803	 0.00125	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47644	 91514	 0.16426	 0.12601	 0.00169	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47645	 47647	 0.00909	 0.027221	 0.00613	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47645	 91512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47645	 91512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47646	 47649	 0.002508	 0.006448	 0.0016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47646	 47672	 0.008816	 0.023299	 0.00545	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47648	 91513	 0.023113	 0.035407	 0.0005	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47648	 91515	 0.047165	 0.04423	 0.00068	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47649	 91513	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47649	 91513	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91078	 47650	 0.005866	 0.037158	 0.01009	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47650	 91514	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47650	 91514	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47651	 47652	 0.006282	 0.024441	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91514	 47651	 0.015603	 0.047917	 0.0009	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47651	 91515	 0.003414	 0.017755	 0.00038	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91514	 47653	 0.009052	 0.027799	 0.00052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47654	 47663	 0.007882	 0.020261	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47654	 47674	 0.022966	 0.017616	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47654	 91515	 0.023058	 0.035322	 0.0005	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47655	 47657	 0.002032	 0.006971	 0.00167	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47655	 91515	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47655	 91515	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47656	 91516	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47656	 91516	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47657	 47665	 0.005815	 0.015369	 0.0036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91078	 47657	 0.003311	 0.024461	 0.00706	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47658	 47667	 0.00228	 0.015384	 0.02833	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47658	 47668	 0.001438	 0.012452	 0.02316	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91229	 47658	 0.016256	 0.10592	 0.21215	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91266	 47658	 0.002758	 0.018034	 0.03539	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47659	 47661	 0.003078	 0.012323	 0.0031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91516	 47659	 0.007885	 0.031568	 0.00795	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47659	 91519	 0.001827	 0.017538	 0.0051	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47660	 91518	 0.026543	 0.034885	 0.00048	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91516	 47661	 0.004141	 0.018999	 0.00487	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91078	 47662	 0.004087	 0.018751	 0.0048	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47662	 91517	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47662	 91517	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91517	 47663	 0.012264	 0.031526	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47664	 47675	 0.010174	 0.023374	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47664	 91518	 0.004402	 0.018277	 0.00048	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47665	 91518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47665	 91518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91513	 47666	 0.008973	 0.017765	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91518	 47666	 0.005261	 0.012215	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47667	 47669	 0.001274	 0.00893	 0.0152	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47667	 91519	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47667	 91519	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47668	 47670	 0.0021	 0.014465	 0.02554	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47668	 93422	 0.006276	 0.075928	 0.1603	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47669	 91520	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47669	 91520	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47670	 91521	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47670	 91521	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91519	 47671	 0.00858	 0.023361	 0.00515	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47671	 91522	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47671	 91522	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91104	 47673	 0.17747	 0.14046	 0.00177	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91522	 47675	 0.013383	 0.034683	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47676	 47682	 0.081692	 0.14964	 0.00258	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47677	 47681	 0.10979	 0.14169	 0.00285	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47678	 47686	 0.005127	 0.034352	 0.01052	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47679	 47683	 0.077378	 0.072564	 0.00112	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47680	 47683	 0.062305	 0.048838	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47681	 47682	 0.062083	 0.14414	 0.00214	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47681	 91524	 0.04417	 0.092837	 0.00169	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91077	 47682	 0.023488	 0.13352	 0.00242	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47682	 91526	 0.038937	 0.17352	 0.00295	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47683	 91524	 0.014463	 0.033573	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88717	 47684	 0.020046	 0.1389	 0.24728	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91052	 47684	 0.004762	 0.050151	 0.10493	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47684	 91523	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91524	 47684	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47685	 47686	 0.005343	 0.047346	 0.01261	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91523	 47685	 0.001604	 0.013996	 0.00384	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47686	 47688	 0.005347	 0.031855	 0.00838	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47686	 91525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47686	 91525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91523	 47687	 0.008304	 0.033247	 0.00838	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47687	 91526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47687	 91526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47688	 91527	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47688	 91527	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91077	 47690	 0.034976	 0.025284	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91433	 47691	 0.001813	 0.019555	 0.0056	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91487	 47691	 0.010694	 0.1134	 0.03369	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91432	 47692	 0.05519	 0.043261	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47693	 91529	 0.14877	 0.11775	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91430	 47694	 0.000727	 0.010226	 0.04241	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47694	 91528	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47694	 91528	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91528	 47695	 0.015022	 0.053103	 0.01197	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47695	 91529	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47695	 91529	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91529	 47696	 0.02968	 0.16244	 0.00317	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47697	 91531	 0.031551	 0.10412	 0.00169	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47697	 91870	 0.058601	 0.1798	 0.00487	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91125	 47698	 0.004754	 0.018566	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91150	 47699	 0.014028	 0.086242	 0.00155	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91118	 47700	 0.008747	 0.082164	 0.31336	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91148	 47700	 0.000847	 0.013371	 0.02804	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47700	 91530	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47700	 91530	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91124	 47701	 0.005217	 0.053163	 0.0137	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47701	 91531	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47701	 91531	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47702	 47703	 0.016566	 0.050872	 0.00095	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47702	 48200	 0.045572	 0.082228	 0.00119	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91531	 47703	 0.011739	 0.081782	 0.00192	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47703	 91532	 0.018206	 0.048253	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47704	 47705	 0.00616	 0.016538	 0.00375	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47704	 91532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47704	 91532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47705	 47708	 0.004947	 0.020597	 0.00642	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91149	 47705	 0.015455	 0.053022	 0.0127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91530	 47705	 0.003044	 0.021118	 0.00603	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47705	 91533	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47705	 91533	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47706	 48681	 0.010747	 0.049306	 0.01263	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91530	 47706	 0.006253	 0.030346	 0.00694	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47706	 91534	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47706	 91534	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47707	 48169	 0.067937	 0.11948	 0.00225	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47708	 48683	 0.009086	 0.040912	 0.01089	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47709	 47712	 0.15003	 0.22986	 0.00323	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47709	 47739	 0.20552	 0.22609	 0.00302	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47710	 48513	 0.010216	 0.049583	 0.01134	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91530	 47710	 0.050215	 0.16941	 0.04217	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47710	 91535	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47710	 91535	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91535	 47711	 0.033367	 0.065393	 0.00098	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47712	 47713	 0.04265	 0.14934	 0.00414	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91535	 47712	 0.032204	 0.22109	 0.00403	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47713	 48163	 0.075376	 0.16684	 0.00274	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47714	 47716	 0.000415	 0.003696	 0.00649	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91139	 47714	 0.003181	 0.021219	 0.04	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47714	 91536	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47714	 91536	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47714	 91662	 0.003071	 0.019937	 0.03972	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47715	 47724	 0.001856	 0.010299	 0.00313	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91536	 47715	 0.002383	 0.015349	 0.00402	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47716	 48242	 0.000964	 0.006573	 0.01184	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91144	 47716	 0.007453	 0.050323	 0.09276	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47717	 47718	 0.003546	 0.008913	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47717	 91628	 0.006743	 0.019531	 0.00471	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91536	 47718	 0.001544	 0.012615	 0.00342	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47718	 91537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47718	 91537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47719	 91538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47719	 91538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91537	 47720	 0.008031	 0.035787	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91538	 47720	 0.012914	 0.036645	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47721	 91539	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47721	 91539	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47722	 47723	 0.009692	 0.024914	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47723	 91540	 0.006251	 0.037989	 0.0007	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91539	 47724	 0.004818	 0.022101	 0.00566	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91539	 47725	 0.003631	 0.014536	 0.00366	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47725	 91540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47725	 91540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47726	 91541	 0.017304	 0.044007	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47727	 47728	 0.003291	 0.011917	 0.00256	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47727	 91541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47727	 91541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47727	 91866	 0.006198	 0.030245	 0.00835	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47728	 91542	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47728	 91542	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91542	 47729	 0.04285	 0.22286	 0.00483	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91174	 47730	 0.048194	 0.23521	 0.00406	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47730	 91543	 0.062068	 0.20708	 0.00328	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47731	 47733	 0.008935	 0.037816	 0.00851	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47731	 48486	 0.008687	 0.03781	 0.01077	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47732	 91543	 0.020112	 0.067093	 0.00106	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47732	 91848	 0.050944	 0.17404	 0.00378	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47733	 47734	 0.00415	 0.020992	 0.00584	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47733	 91543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47733	 91543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91131	 47734	 0.015381	 0.071748	 0.01777	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47734	 91544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47734	 91544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47735	 48511	 0.014069	 0.053484	 0.01497	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91131	 47735	 0.006467	 0.030608	 0.00736	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47735	 91545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47735	 91545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47736	 47737	 0.12842	 0.10163	 0.00128	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47736	 47738	 0.12788	 0.17825	 0.00305	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91544	 47736	 0.032885	 0.10852	 0.00176	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91545	 47736	 0.035192	 0.13691	 0.00229	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47739	 91547	 0.037689	 0.16514	 0.00355	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47740	 47865	 0.000985	 0.013356	 0.20361	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47740	 91546	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47740	 91546	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47741	 47742	 0.002378	 0.010707	 0.00285	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47741	 48704	 0.008207	 0.032859	 0.00828	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91546	 47742	 0.002329	 0.013874	 0.00365	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47742	 91547	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47742	 91547	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47743	 48695	 0.016097	 0.063276	 0.01656	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91546	 47743	 0.002689	 0.01198	 0.00326	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91546	 47744	 0.009203	 0.080321	 0.02207	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47744	 91585	 0.007019	 0.050078	 0.01552	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91546	 47745	 0.006652	 0.050339	 0.02473	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47745	 91585	 0.003603	 0.038189	 0.01134	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47746	 47750	 0.003921	 0.025457	 0.05072	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47746	 48225	 0.002868	 0.026245	 0.05053	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47746	 91548	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91549	 47746	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91549	 47747	 0.045329	 0.11653	 0.0018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47748	 47749	 0.009384	 0.037574	 0.00947	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47748	 47763	 0.013184	 0.039685	 0.01242	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47748	 48726	 0.014739	 0.059984	 0.01462	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47748	 91550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47748	 91550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47749	 48261	 0.023147	 0.091008	 0.02382	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47750	 48021	 0.010387	 0.071657	 0.12677	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47750	 91551	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47750	 91551	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47751	 91552	 0.020028	 0.051483	 0.0008	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47751	 91558	 0.009214	 0.021818	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47752	 91552	 0.011482	 0.026653	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47753	 47769	 0.002417	 0.009677	 0.00244	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47753	 47773	 0.00465	 0.018277	 0.00478	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47753	 91552	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47753	 91552	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47753	 91554	 0.00397	 0.02104	 0.00702	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47754	 47755	 0.008141	 0.015955	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47755	 47756	 0.006824	 0.010451	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47755	 47757	 0.009973	 0.017538	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91552	 47755	 0.005031	 0.028596	 0.00052	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47757	 47779	 0.006274	 0.014413	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47758	 47795	 0.002489	 0.011418	 0.00292	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47758	 91553	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47758	 91553	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47758	 91554	 0.003286	 0.015948	 0.00365	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47759	 91564	 0.00917	 0.018157	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91553	 47760	 0.016561	 0.027619	 0.0004	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47761	 50380	 0.003604	 0.037168	 0.41333	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47761	 91554	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47762	 47763	 0.007075	 0.027808	 0.00727	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91554	 47762	 0.005182	 0.021394	 0.00506	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47763	 47809	 0.006907	 0.02687	 0.00718	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47764	 91556	 0.051634	 0.14653	 0.0023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47764	 91939	 0.035081	 0.15547	 0.00467	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91555	 47765	 0.025523	 0.06561	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47766	 48720	 0.00869	 0.025622	 0.00596	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91554	 47766	 0.00969	 0.032326	 0.0082	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47766	 91556	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47766	 91556	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47767	 47828	 0.046846	 0.084202	 0.00151	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47767	 91557	 0.018291	 0.056111	 0.00152	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47768	 47769	 0.006738	 0.026976	 0.0068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47768	 47829	 0.03315	 0.090282	 0.0199	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47768	 91557	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47768	 91557	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91554	 47769	 0.003167	 0.018196	 0.00515	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91552	 47770	 0.019826	 0.046947	 0.00086	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47771	 91938	 0.086912	 0.20177	 0.00384	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47772	 47778	 0.030625	 0.04025	 0.00055	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91552	 47772	 0.027785	 0.049629	 0.00073	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47772	 91574	 0.007668	 0.019502	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47773	 54094	 0.074652	 0.19414	 0.04722	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91133	 47773	 0.00026	 0.003787	 0.00121	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47773	 91558	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47773	 91558	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91145	 47774	 0.008917	 0.00656	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47775	 47785	 0.002733	 0.010632	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91145	 47775	 0.002723	 0.014506	 0.00025	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47776	 47778	 0.005853	 0.013448	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47776	 47832	 0.006147	 0.012919	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47777	 47779	 0.004742	 0.012569	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47777	 91574	 0.003942	 0.012094	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47778	 47781	 0.010801	 0.016546	 0.00023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47779	 47780	 0.019761	 0.01549	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47781	 91563	 0.005581	 0.014347	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47782	 47792	 0.022074	 0.01624	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47782	 91560	 0.009743	 0.024183	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47783	 47784	 0.000689	 0.003161	 0.00081	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47783	 47801	 0.003959	 0.010463	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47783	 91559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47783	 91559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91133	 47784	 0.001427	 0.008865	 0.0025	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47784	 91560	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47784	 91560	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47784	 91561	 0.001957	 0.008283	 0.00186	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91560	 47785	 0.004559	 0.010427	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47786	 47787	 0.006371	 0.01479	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91145	 47786	 0.008622	 0.028452	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91560	 47787	 0.036757	 0.029089	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47788	 47822	 0.015444	 0.027759	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47788	 91562	 0.005261	 0.029905	 0.00054	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47789	 91562	 0.008859	 0.017539	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47790	 91561	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91562	 47790	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47790	 92727	 0.008575	 0.055719	 0.11115	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47791	 47799	 0.023128	 0.018129	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91559	 47791	 0.003604	 0.011055	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47792	 47798	 0.023584	 0.018664	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47793	 47794	 0.000806	 0.002933	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47793	 91563	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47793	 91563	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47794	 47795	 0.000811	 0.003247	 0.0011	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47795	 91564	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47795	 91564	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47796	 47807	 0.012768	 0.022806	 0.00034	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91563	 47796	 0.005245	 0.016108	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91563	 47797	 0.005417	 0.020839	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47797	 91567	 0.006266	 0.017355	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47798	 91567	 0.012497	 0.023933	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91562	 47799	 0.014377	 0.023566	 0.00042	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47799	 91566	 0.00438	 0.016849	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47800	 47813	 0.012691	 0.029464	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91562	 47800	 0.004429	 0.019405	 0.00042	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91561	 47801	 0.001736	 0.004588	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47801	 91565	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47801	 91565	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47802	 47836	 0.024879	 0.016107	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91565	 47802	 0.006313	 0.01495	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47803	 47811	 0.00165	 0.006715	 0.00164	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91554	 47803	 0.009437	 0.042491	 0.01131	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47803	 91566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47803	 91566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47804	 47806	 0.003145	 0.008442	 0.00191	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47804	 47808	 0.002348	 0.007657	 0.00203	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91561	 47804	 0.005754	 0.015207	 0.00356	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47804	 91567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47804	 91567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47805	 47808	 0.001276	 0.005744	 0.00153	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91554	 47805	 0.006322	 0.03068	 0.00701	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47805	 91568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47805	 91568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47806	 47808	 0.003376	 0.008922	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47806	 47809	 0.009176	 0.036067	 0.00944	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47806	 91569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47806	 91569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91567	 47807	 0.007545	 0.017516	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91568	 47807	 0.011403	 0.024345	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47809	 91602	 0.008974	 0.065604	 0.01936	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47810	 47815	 0.003268	 0.01383	 0.00311	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47810	 47899	 0.007147	 0.032181	 0.00856	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47811	 47815	 0.001507	 0.006378	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47811	 91570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47811	 91570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47812	 47814	 0.010922	 0.027775	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47813	 47816	 0.009815	 0.039277	 0.00083	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91570	 47813	 0.006683	 0.023383	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91569	 47814	 0.02306	 0.058645	 0.00093	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47814	 91571	 0.007262	 0.023384	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47815	 91571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47815	 91571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47816	 91572	 0.010466	 0.03214	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47817	 47818	 0.006903	 0.026238	 0.00735	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47817	 47820	 0.00422	 0.021202	 0.00552	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47817	 47899	 0.011876	 0.04755	 0.01198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47818	 47900	 0.013297	 0.053242	 0.01342	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47819	 91572	 0.033918	 0.080318	 0.00147	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47820	 56381	 0.018909	 0.064876	 0.01555	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91561	 47820	 0.005292	 0.023034	 0.00656	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47820	 91572	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47820	 91572	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91572	 47821	 0.01299	 0.08814	 0.00164	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47823	 47834	 0.019484	 0.038577	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47824	 47829	 0.014626	 0.058565	 0.01476	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47824	 56381	 0.00807	 0.031398	 0.00839	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47824	 91573	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47824	 91573	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47825	 47826	 0.015835	 0.040706	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47825	 47827	 0.050987	 0.033009	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91558	 47826	 0.005178	 0.029433	 0.00053	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47829	 47830	 0.004376	 0.012902	 0.003	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47829	 47831	 0.010912	 0.037434	 0.00897	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47830	 47831	 0.008194	 0.029671	 0.00637	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91145	 47832	 0.008207	 0.020873	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91133	 47833	 0.001182	 0.004811	 0.00117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47833	 91574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47833	 91574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47834	 47835	 0.030104	 0.054109	 0.00097	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91558	 47834	 0.028599	 0.11126	 0.00186	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91573	 47834	 0.048935	 0.11361	 0.00169	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47837	 47838	 0.001908	 0.00532	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47837	 47840	 0.00091	 0.003185	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47837	 47844	 0.002605	 0.007091	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47837	 91575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47837	 91575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47838	 91576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47838	 91576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47838	 91587	 0.002769	 0.009787	 0.00221	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91576	 47839	 0.017389	 0.026638	 0.00037	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47840	 47842	 0.001398	 0.004796	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47840	 47851	 0.004254	 0.015402	 0.0033	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91575	 47841	 0.006856	 0.013575	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47842	 47853	 0.002112	 0.00575	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47842	 91577	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47842	 91577	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91116	 47843	 0.000731	 0.008643	 0.01898	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91136	 47843	 0.000986	 0.01022	 0.02201	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47843	 91578	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91579	 47843	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47843	 91586	 0.000765	 0.004962	 0.00988	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91578	 47844	 0.001898	 0.00619	 0.00164	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47844	 91580	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47844	 91580	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91577	 47845	 0.009573	 0.018954	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91580	 47845	 0.011668	 0.019656	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91579	 47846	 0.010916	 0.024161	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47847	 47848	 0.005742	 0.014761	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91580	 47847	 0.004128	 0.020143	 0.00035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47848	 47849	 0.008825	 0.013518	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47850	 47880	 0.05776	 0.043761	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47850	 91583	 0.008372	 0.02152	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91117	 47851	 0.006865	 0.031492	 0.00807	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47851	 91581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47851	 91581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47851	 91702	 0.011701	 0.087706	 0.0214	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91575	 47852	 0.023546	 0.033426	 0.00055	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47852	 91582	 0.018188	 0.023904	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47853	 47859	 0.005917	 0.030823	 0.00808	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91117	 47853	 0.00763	 0.035004	 0.00897	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47853	 91582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47853	 91582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91582	 47854	 0.02463	 0.10975	 0.00186	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47855	 47884	 0.008026	 0.029201	 0.00894	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91165	 47855	 0.003477	 0.030341	 0.00833	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91579	 47856	 0.013181	 0.024142	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91578	 47857	 0.003519	 0.013831	 0.00362	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47857	 91583	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47857	 91583	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91583	 47858	 0.010536	 0.026795	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47859	 47860	 0.001955	 0.017055	 0.00468	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47860	 48164	 0.002118	 0.018168	 0.00517	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47861	 91584	 0.025363	 0.054149	 0.00122	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47862	 47863	 0.002211	 0.007815	 0.00176	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91117	 47862	 0.004715	 0.016497	 0.00547	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47863	 91584	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47863	 91584	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47864	 47865	 0.000246	 0.004544	 0.04366	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47864	 47868	 0.000346	 0.004291	 0.03976	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47865	 91585	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47865	 91585	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47866	 91588	 0.01585	 0.02767	 0.00043	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47867	 91586	 9.3e-05	 0.007407	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47868	 91589	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47869	 47871	 0.001352	 0.005413	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91117	 47869	 0.003271	 0.023137	 0.00635	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91590	 47869	 0.000905	 0.009453	 0.0026	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47869	 91592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47869	 91592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47869	 92673	 0.011135	 0.072832	 0.02698	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91592	 47870	 0.018869	 0.016907	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47871	 47872	 0.001612	 0.006454	 0.00163	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47871	 91593	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47871	 91593	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47872	 47873	 0.001956	 0.005077	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47872	 47875	 0.00211	 0.014924	 0.0041	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91117	 47872	 0.001595	 0.01823	 0.00556	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91130	 47873	 0.001325	 0.005207	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47873	 91594	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47873	 91594	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91136	 47874	 0.000424	 0.004517	 0.00918	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91136	 47874	 0.000424	 0.004517	 0.00918	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47874	 91595	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47874	 91595	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47874	 92605	 0.002453	 0.032613	 0.06971	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91137	 47875	 0.002436	 0.008821	 0.00189	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47875	 91596	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47875	 91596	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47876	 47877	 0.048494	 0.096017	 0.00141	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91591	 47876	 0.049511	 0.14903	 0.00291	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91591	 47878	 0.084837	 0.21811	 0.00338	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91582	 47879	 0.037186	 0.029428	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47881	 47883	 0.009278	 0.042566	 0.01091	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47881	 48018	 0.019013	 0.051048	 0.01157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47881	 48471	 0.006971	 0.059791	 0.01702	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47882	 48467	 0.042567	 0.22139	 0.0048	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47882	 91597	 0.066226	 0.18996	 0.00292	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47883	 48218	 0.009288	 0.043321	 0.01073	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47883	 91597	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47883	 91597	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91595	 47884	 0.005152	 0.050489	 0.01582	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47884	 91702	 0.014808	 0.10479	 0.02877	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47885	 56684	 0.017547	 0.070267	 0.01771	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91595	 47885	 0.019002	 0.095508	 0.02487	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47886	 47887	 0.013598	 0.052907	 0.01413	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47886	 47894	 0.01996	 0.069574	 0.01614	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47886	 48018	 0.007394	 0.062194	 0.01843	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47887	 47888	 0.01017	 0.039973	 0.01046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47887	 91598	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47887	 91598	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47888	 47898	 0.015785	 0.063208	 0.01593	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47889	 48221	 0.026125	 0.069059	 0.01617	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47890	 47891	 0.005258	 0.02412	 0.00618	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47890	 47892	 0.008199	 0.033854	 0.00801	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47890	 48716	 0.011702	 0.046853	 0.0118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47892	 47893	 0.008489	 0.029705	 0.00984	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47892	 91599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47892	 91599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91548	 47893	 0.00998	 0.039957	 0.01007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47894	 47895	 0.004707	 0.016148	 0.00387	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47894	 91600	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47894	 91600	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47895	 91601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47895	 91601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47896	 47897	 0.058729	 0.074743	 0.0011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91601	 47896	 0.032206	 0.091394	 0.00144	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91174	 47897	 0.20321	 0.56344	 0.00931	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91601	 47897	 0.07624	 0.15096	 0.00222	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91173	 47898	 0.020095	 0.076405	 0.0214	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47900	 57314	 0.009909	 0.070098	 0.01924	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47900	 91602	 0.017554	 0.078242	 0.02127	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47901	 91602	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91603	 47902	 0.038188	 0.10095	 0.00183	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47902	 91604	 0.0758	 0.099626	 0.00137	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47903	 47904	 0.004121	 0.017157	 0.00535	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47903	 48527	 0.012097	 0.061848	 0.01686	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47903	 91604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47903	 91604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91113	 47904	 0.003511	 0.020134	 0.00669	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91604	 47905	 0.085864	 0.05559	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47906	 91605	 0.006285	 0.012318	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47906	 91619	 0.008498	 0.013675	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47907	 47909	 0.000666	 0.003055	 0.00078	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47907	 47914	 0.001799	 0.007204	 0.00181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47907	 47943	 0.001675	 0.007291	 0.00208	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47908	 47909	 0.000552	 0.003233	 0.00088	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91143	 47908	 0.000557	 0.003728	 0.00234	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47908	 91605	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47908	 91605	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47909	 91606	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47909	 91606	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47910	 47912	 0.000879	 0.004158	 0.001	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91152	 47910	 0.000908	 0.00558	 0.00204	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47910	 91607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47910	 91607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91606	 47911	 0.004862	 0.011288	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91607	 47911	 0.010182	 0.012639	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47912	 47918	 0.001026	 0.004706	 0.00121	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47913	 91608	 0.003962	 0.010185	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47914	 91608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47914	 91608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47915	 47916	 0.005475	 0.014073	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47915	 91640	 0.011946	 0.019582	 0.00035	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47916	 91610	 0.005173	 0.013155	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47917	 47919	 0.000672	 0.003136	 0.00078	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47917	 47924	 0.002502	 0.005807	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47917	 91609	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47917	 91609	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47918	 47919	 0.000889	 0.002898	 0.00077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47918	 91610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47918	 91610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47919	 91611	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47919	 91611	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47920	 47926	 0.020202	 0.015306	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47920	 91641	 0.006973	 0.013665	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47921	 47952	 0.003635	 0.009343	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47921	 47994	 0.004068	 0.011343	 0.00238	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47921	 91612	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47921	 91612	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47922	 47923	 0.007741	 0.008267	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91612	 47922	 0.008186	 0.019385	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47924	 47949	 0.001786	 0.005553	 0.00116	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47925	 47928	 0.001108	 0.002974	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47925	 47996	 0.001466	 0.004088	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47926	 47931	 0.013436	 0.017485	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47927	 47932	 0.000487	 0.003502	 0.00093	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47927	 47995	 0.001163	 0.004212	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47927	 48727	 0.00353	 0.00933	 0.00218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47928	 47933	 0.001196	 0.004329	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47929	 47930	 0.00273	 0.007215	 0.00169	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47929	 47933	 0.001196	 0.0039	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47929	 91613	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47929	 91613	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47930	 47952	 0.001625	 0.005573	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47930	 47992	 0.001232	 0.004227	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91613	 47931	 0.008493	 0.016052	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47932	 47967	 0.000607	 0.004166	 0.00122	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47933	 91614	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47933	 91614	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47933	 91629	 0.001886	 0.013336	 0.00366	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47934	 91615	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47935	 47936	 0.010721	 0.017574	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47935	 91619	 0.009553	 0.023711	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47936	 47997	 0.012801	 0.009254	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47936	 91619	 0.006361	 0.021221	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47936	 91632	 0.00748	 0.025549	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47937	 47971	 0.003388	 0.009449	 0.00198	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47937	 91617	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47937	 91617	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47938	 47974	 0.003946	 0.010745	 0.00237	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47938	 47977	 0.005553	 0.019355	 0.00449	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47938	 91618	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47938	 91618	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91143	 47939	 0.000755	 0.007208	 0.00265	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47939	 91619	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47939	 91619	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91619	 47940	 0.0111	 0.025767	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47941	 47942	 0.014647	 0.020762	 0.00042	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91617	 47942	 0.021113	 0.041801	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47942	 91620	 0.008293	 0.018605	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47943	 47944	 0.00185	 0.007272	 0.0019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47943	 91620	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47943	 91620	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47944	 47947	 0.002184	 0.006091	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47944	 91621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47944	 91621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47945	 47948	 0.001391	 0.00557	 0.0014	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47945	 47979	 0.002405	 0.011033	 0.00283	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91621	 47946	 0.003635	 0.018388	 0.00032	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47946	 91622	 0.014002	 0.025265	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47947	 47948	 0.001579	 0.004574	 0.0011	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47947	 47950	 0.001427	 0.004807	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47947	 47951	 0.002363	 0.006345	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47947	 47980	 0.00266	 0.013115	 0.00355	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47949	 47950	 0.001154	 0.003887	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47949	 47960	 0.002399	 0.006341	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47949	 91622	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47949	 91622	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47951	 47956	 0.001117	 0.003763	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47951	 47981	 0.003047	 0.01077	 0.00243	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47952	 91623	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47952	 91623	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47953	 47954	 0.030568	 0.022098	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91623	 47953	 0.032895	 0.036181	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47953	 91626	 0.011146	 0.028346	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47954	 47962	 0.014313	 0.033228	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47955	 47958	 0.004097	 0.010827	 0.00253	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47955	 47961	 0.00235	 0.005908	 0.00153	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47955	 47963	 0.002041	 0.008173	 0.00206	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47955	 91624	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47955	 91624	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47956	 47958	 0.001535	 0.00535	 0.00124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47957	 47961	 0.002007	 0.007095	 0.0016	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47957	 47985	 0.001177	 0.008322	 0.00228	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47957	 91625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47957	 91625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47958	 47959	 0.001708	 0.004763	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47959	 47983	 0.002573	 0.006615	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47960	 47961	 0.001719	 0.004679	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47961	 91626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47961	 91626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47962	 47969	 0.047936	 0.033956	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47962	 47993	 0.024022	 0.017673	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	47962	 91627	 0.0084	 0.019891	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47963	 47970	 0.002222	 0.010514	 0.00253	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47963	 91627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47963	 91627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47964	 48241	 0.000515	 0.005943	 0.05211	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91138	 47964	 0.000442	 0.005162	 0.0491	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47964	 91628	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47964	 91628	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47964	 91661	 0.000461	 0.00524	 0.04733	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47965	 91631	 0.016145	 0.031965	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47966	 47992	 0.001949	 0.007803	 0.00197	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47966	 91629	 0.003073	 0.012506	 0.00305	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47967	 91629	 0.001025	 0.00731	 0.00227	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47968	 48003	 0.003859	 0.034449	 0.0698	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91128	 47968	 0.000878	 0.005699	 0.01135	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91155	 47968	 0.000905	 0.006035	 0.01137	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47968	 91629	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91630	 47968	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91630	 47969	 0.012691	 0.072141	 0.00131	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91140	 47970	 0.001624	 0.01827	 0.0048	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	47970	 91631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47970	 91631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47971	 47972	 0.002192	 0.00987	 0.00263	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47971	 91632	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47971	 91632	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47972	 47974	 0.002231	 0.00848	 0.00237	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47972	 91637	 0.002239	 0.019837	 0.00528	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47973	 47974	 0.001362	 0.006247	 0.0016	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47973	 47989	 0.004269	 0.019585	 0.00502	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47975	 47978	 0.007935	 0.022984	 0.00554	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47975	 91633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47975	 91633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47975	 91636	 0.005195	 0.023831	 0.00611	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91633	 47976	 0.021533	 0.055353	 0.00086	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47977	 91634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47977	 91634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47978	 47979	 0.005032	 0.014032	 0.00295	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47979	 91737	 0.002465	 0.011099	 0.00295	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47980	 47981	 0.000832	 0.004478	 0.00123	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47980	 91737	 0.000757	 0.0067	 0.00368	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91625	 47982	 0.019596	 0.050374	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47983	 47984	 0.002004	 0.005296	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47984	 47985	 0.001886	 0.010349	 0.00274	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	47984	 91635	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47984	 91635	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91628	 47985	 0.000433	 0.004009	 0.00201	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91635	 47986	 0.019446	 0.044109	 0.00088	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47987	 47990	 0.001892	 0.011984	 0.0251	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47987	 91636	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47987	 91636	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47988	 48241	 0.001194	 0.01304	 0.12807	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	47988	 91637	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47988	 91637	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91636	 47989	 0.004778	 0.013325	 0.0028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47989	 91644	 0.005014	 0.023002	 0.00589	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47990	 91638	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47990	 91638	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91614	 47991	 0.00766	 0.014031	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47992	 91639	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47992	 91639	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91639	 47993	 0.010698	 0.021181	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47994	 47996	 0.001599	 0.00402	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47994	 48728	 0.004931	 0.012676	 0.00314	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	47994	 91640	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47994	 91640	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47995	 47996	 0.001267	 0.004587	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	47996	 91641	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47996	 91641	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47998	 48000	 0.006003	 0.027541	 0.00706	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	47998	 91642	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47998	 91642	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	47999	 48000	 0.010492	 0.041239	 0.01079	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	47999	 48521	 0.020544	 0.086975	 0.01958	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48001	 48002	 0.010084	 0.038334	 0.01073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48001	 48005	 0.011142	 0.043351	 0.01158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48002	 48004	 0.006766	 0.027535	 0.00671	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48002	 91643	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48002	 91643	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91112	 48003	 0.001254	 0.008638	 0.01525	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48003	 91644	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48003	 91644	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91644	 48004	 0.008501	 0.033415	 0.00874	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48005	 48555	 0.016286	 0.067253	 0.01592	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48005	 48556	 0.014784	 0.053791	 0.01647	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91638	 48005	 0.005696	 0.036076	 0.00979	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48006	 48007	 0.063051	 0.14421	 0.00352	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91132	 48006	 0.010771	 0.066218	 0.00119	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91535	 48007	 0.0599	 0.1231	 0.00235	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48008	 48009	 0.062315	 0.14466	 0.00275	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48008	 48570	 0.037722	 0.12449	 0.00202	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48009	 91645	 0.017821	 0.1013	 0.00183	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48010	 91645	 0.011893	 0.021784	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48011	 91645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48011	 91645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48011	 91646	 0.003468	 0.013886	 0.0035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48012	 91646	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48012	 91656	 0.002093	 0.026372	 0.46854	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48013	 48567	 0.00811	 0.037206	 0.00953	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48013	 48568	 0.004212	 0.02754	 0.007	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91646	 48013	 0.005516	 0.037865	 0.01104	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48014	 48016	 0.047868	 0.17102	 0.0034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48014	 91853	 0.049116	 0.18898	 0.00323	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48015	 48018	 0.008501	 0.039001	 0.00999	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48015	 48470	 0.023429	 0.09759	 0.03045	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48015	 91648	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48015	 91648	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48016	 48526	 0.027333	 0.16806	 0.00303	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91648	 48016	 0.006243	 0.020826	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91648	 48017	 0.23823	 0.17531	 0.00256	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48018	 91649	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48018	 91649	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91649	 48019	 0.108	 0.16546	 0.00232	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48020	 48023	 0.015492	 0.045678	 0.01063	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48020	 48741	 0.015515	 0.073444	 0.01767	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91119	 48020	 0.02449	 0.098089	 0.02472	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48021	 48022	 0.001687	 0.016812	 0.05611	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48021	 91650	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48021	 91650	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91118	 48022	 0.000687	 0.006839	 0.02282	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48023	 48024	 0.006078	 0.020479	 0.00509	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48024	 91840	 0.007649	 0.026238	 0.00629	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48025	 91655	 0.020793	 0.1182	 0.00214	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48026	 48031	 0.008779	 0.05664	 0.0018	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48026	 48588	 0.06325	 0.12524	 0.00184	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48026	 91658	 0.043873	 0.36514	 0.00691	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48027	 48587	 0.00535	 0.021418	 0.0054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48027	 91651	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48027	 91651	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48028	 48689	 0.032678	 0.098359	 0.00192	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48028	 91652	 0.01155	 0.060063	 0.0013	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48029	 91652	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48029	 91652	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48029	 91654	 0.002947	 0.020845	 0.00572	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48030	 48032	 0.004107	 0.022137	 0.00045	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48030	 48589	 0.005541	 0.044834	 0.00116	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48030	 91653	 0.012679	 0.042298	 0.00067	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48031	 48032	 0.003524	 0.021112	 0.00051	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48032	 91653	 0.004202	 0.018722	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48033	 48034	 0.012581	 0.012584	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48034	 48035	 0.006202	 0.012692	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48035	 91653	 0.005118	 0.01468	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48036	 91653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48036	 91653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48036	 91654	 0.004046	 0.018869	 0.00467	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91653	 48037	 0.01023	 0.02539	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48038	 91654	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48038	 91656	 0.001385	 0.022952	 0.21537	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48039	 48597	 0.002194	 0.028101	 0.00839	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91654	 48039	 0.001344	 0.017497	 0.00506	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48040	 48485	 0.080442	 0.12323	 0.00173	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48041	 48709	 0.001097	 0.020417	 1.3573	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48041	 91656	 7.1e-05	 0.005641	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48041	 91656	 7.1e-05	 0.005641	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48043	 91660	 0.007574	 0.019261	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91138	 48044	 0.000346	 0.004296	 0.04315	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91656	 48044	 0.000539	 0.006477	 0.10876	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48044	 91659	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48044	 91661	 0.000436	 0.004964	 0.04483	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48045	 91661	 0.00012	 0.009565	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48045	 91661	 0.00012	 0.009565	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91662	 48045	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48046	 48467	 0.089935	 0.19204	 0.00434	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48046	 91731	 0.09834	 0.25014	 0.00396	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48047	 48048	 0.009817	 0.04504	 0.01154	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48047	 91663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48047	 91663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48047	 91729	 0.011793	 0.05724	 0.01309	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48048	 48049	 0.00427	 0.016782	 0.00439	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48049	 48050	 0.003281	 0.013351	 0.00325	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48049	 48740	 0.02596	 0.089081	 0.02135	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48051	 48052	 0.017343	 0.014275	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48052	 48090	 0.006323	 0.012518	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48052	 91664	 0.012511	 0.01376	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48053	 48086	 0.001422	 0.004119	 0.00099	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48053	 48377	 0.001973	 0.007894	 0.00267	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48053	 91664	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48053	 91664	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91664	 48054	 0.003598	 0.006327	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48054	 91672	 0.019357	 0.015319	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48055	 91672	 0.007916	 0.017956	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48056	 48057	 0.008004	 0.018582	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48056	 48059	 0.00241	 0.007394	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48057	 91671	 0.005989	 0.014182	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48058	 48079	 0.001242	 0.004498	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48058	 48081	 0.000645	 0.002213	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48059	 91667	 0.001388	 0.006661	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48060	 48067	 0.000596	 0.002044	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48060	 91665	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48060	 91665	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48061	 48063	 0.001553	 0.005438	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48061	 91669	 0.001789	 0.010051	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48062	 48079	 0.00097	 0.004369	 0.00116	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48062	 91666	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48062	 91666	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48062	 91668	 0.001624	 0.007449	 0.00191	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48063	 48066	 0.001674	 0.010291	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48063	 48070	 0.005201	 0.013369	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48064	 48071	 0.005927	 0.012654	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48064	 91669	 0.006853	 0.033442	 0.00058	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48065	 48071	 0.008012	 0.013497	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91665	 48066	 0.002968	 0.011548	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48067	 48068	 0.000638	 0.001881	 0.00044	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48068	 91667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48068	 91667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48069	 48070	 0.007908	 0.006509	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48070	 91669	 0.002801	 0.009807	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48072	 91668	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48072	 91763	 0.001135	 0.012388	 0.12166	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48072	 91865	 0.000294	 0.003845	 0.0348	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48073	 48160	 0.004453	 0.011445	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48073	 48551	 0.007885	 0.016897	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48073	 91701	 0.002063	 0.01073	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48074	 48075	 0.008649	 0.009236	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48075	 48076	 0.003655	 0.009296	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48075	 91701	 0.004037	 0.02019	 0.00036	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91666	 48076	 0.005811	 0.013492	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48077	 48107	 0.006005	 0.015436	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91666	 48077	 0.004802	 0.009826	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48078	 91670	 0.01153	 0.008844	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48079	 91670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48079	 91670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48080	 48106	 0.002615	 0.008724	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91670	 48080	 0.002142	 0.012051	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48081	 48082	 0.001359	 0.003592	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48082	 48086	 0.00192	 0.006788	 0.00153	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48082	 91671	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48082	 91671	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48083	 48084	 0.004014	 0.006761	 0.0001	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48083	 48101	 0.010433	 0.009783	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48083	 48118	 0.023596	 0.031012	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91671	 48084	 0.001816	 0.006959	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48085	 91672	 0.0105	 0.008054	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48086	 91672	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48086	 91672	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48086	 91680	 0.005553	 0.014907	 0.00338	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48087	 48098	 0.003181	 0.007533	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48087	 48099	 0.007416	 0.011361	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48087	 48100	 0.002068	 0.006224	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91664	 48088	 0.011755	 0.009214	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48089	 48095	 0.004816	 0.007686	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91672	 48089	 0.016123	 0.012367	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48090	 91673	 0.003491	 0.008267	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48091	 48092	 0.001156	 0.003056	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48091	 48377	 0.000685	 0.002742	 0.00093	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48091	 91673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48091	 91673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48092	 48094	 0.000502	 0.001691	 0.00042	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48092	 91674	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48092	 91674	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91673	 48093	 0.004092	 0.006206	 9e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91674	 48093	 0.016261	 0.011964	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48094	 48096	 0.000992	 0.0039	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48094	 91675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48094	 91675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91672	 48095	 0.016555	 0.019817	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91675	 48095	 0.002373	 0.007278	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48096	 48125	 0.000633	 0.002534	 0.00064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48096	 91676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48096	 91676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48097	 48098	 0.007514	 0.007536	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48098	 48123	 0.009484	 0.018777	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91676	 48098	 0.004659	 0.015373	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48099	 91682	 0.005431	 0.013962	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48100	 48101	 0.005271	 0.010094	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48100	 48103	 0.015059	 0.01521	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48102	 48104	 0.015882	 0.012449	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48103	 48118	 0.013053	 0.01033	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48104	 48105	 0.00705	 0.008594	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48104	 48118	 0.007214	 0.016748	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48105	 48106	 0.003826	 0.006354	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48107	 91677	 0.005346	 0.010584	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48108	 48109	 0.000674	 0.001782	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48108	 91677	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48108	 91677	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48109	 48110	 0.001021	 0.002846	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48110	 91678	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48110	 91678	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48110	 91696	 0.002345	 0.008492	 0.00182	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48111	 48112	 0.007271	 0.012249	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48111	 91679	 0.003153	 0.008018	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48112	 48113	 0.010495	 0.0106	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91678	 48113	 0.017859	 0.013998	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48114	 48117	 0.001842	 0.004869	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48114	 91696	 0.002817	 0.007242	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48115	 91679	 0.013729	 0.009925	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48116	 91679	 0.011234	 0.02027	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48117	 91679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48117	 91679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48117	 91680	 0.000906	 0.003106	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91677	 48118	 0.053869	 0.042631	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48118	 91681	 0.004595	 0.018777	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48119	 48150	 0.000214	 0.002486	 0.02149	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48119	 48161	 0.000149	 0.001658	 0.01564	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48119	 91680	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48119	 91865	 0.0006	 0.007174	 0.07173	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48120	 48121	 0.001212	 0.003147	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48120	 48122	 0.001082	 0.00281	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91680	 48120	 0.001501	 0.004186	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48121	 91682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48121	 91682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48122	 48124	 0.001252	 0.003894	 0.00081	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91681	 48123	 0.031086	 0.03906	 0.00059	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91682	 48123	 0.015709	 0.011356	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48123	 91683	 0.003043	 0.007821	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48124	 91683	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48124	 91683	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48124	 91685	 0.000731	 0.003095	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48125	 91685	 0.001058	 0.004236	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48126	 48161	 0.000167	 0.001831	 0.01778	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48126	 91684	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48127	 48128	 0.000298	 0.001298	 0.00037	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48127	 48134	 0.001351	 0.003508	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48127	 48280	 0.000251	 0.001615	 0.00042	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48128	 91687	 0.000766	 0.002582	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48129	 48131	 0.00016	 0.001095	 0.00197	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48129	 91687	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91688	 48129	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91688	 48130	 0.005291	 0.005306	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48131	 48424	 0.000724	 0.004883	 0.00899	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48131	 91689	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48131	 91689	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48132	 48138	 0.000555	 0.002587	 0.00064	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91689	 48132	 0.00031	 0.001424	 0.00036	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48133	 48136	 0.000647	 0.001664	 0.00041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91689	 48133	 0.000709	 0.002204	 0.00046	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48134	 48135	 0.00093	 0.00224	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48135	 48378	 0.001583	 0.00407	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48135	 91690	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48135	 91690	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48136	 48431	 0.001134	 0.00389	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48136	 91691	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48136	 91691	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91691	 48137	 0.00394	 0.015389	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48137	 91692	 0.006353	 0.016332	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48137	 91811	 0.002629	 0.013668	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48138	 48139	 0.000564	 0.002586	 0.00066	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48139	 48140	 0.000797	 0.002884	 0.00062	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48140	 48142	 0.00119	 0.003446	 0.00083	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48140	 91692	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48140	 91692	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48140	 91699	 0.005314	 0.021274	 0.00536	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48141	 91693	 0.010047	 0.007612	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48142	 48144	 0.000683	 0.002342	 0.00056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48142	 91693	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48142	 91693	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91692	 48143	 0.006912	 0.013547	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48144	 48145	 0.000418	 0.001626	 0.00043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48145	 48146	 0.000639	 0.002638	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48146	 91694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48146	 91694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48146	 91699	 0.003006	 0.01379	 0.00353	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91694	 48147	 0.002465	 0.007562	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48147	 91695	 0.007723	 0.019852	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48148	 91695	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48148	 91695	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48148	 91699	 0.002553	 0.010805	 0.00243	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91695	 48149	 0.004664	 0.009545	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48150	 91696	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91696	 48151	 0.001665	 0.006328	 0.00177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48151	 91698	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48151	 91698	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91698	 48152	 0.013306	 0.034205	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48153	 91700	 0.019582	 0.034976	 0.00052	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91695	 48154	 0.004485	 0.011405	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91694	 48155	 0.007721	 0.019848	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91692	 48156	 0.002199	 0.015094	 0.00028	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48157	 48159	 0.01961	 0.038826	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48158	 91722	 0.060013	 0.2335	 0.0039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48158	 91722	 0.060013	 0.2335	 0.0039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91697	 48160	 0.014402	 0.033087	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48161	 91699	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91668	 48162	 0.000692	 0.002768	 0.00094	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48162	 91701	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48162	 91701	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91150	 48163	 0.036574	 0.16367	 0.00337	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48164	 91702	 0.00301	 0.028024	 0.00868	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48165	 91702	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48165	 91702	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91149	 48166	 0.011808	 0.044887	 0.01257	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48166	 91703	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48166	 91703	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91149	 48167	 0.004811	 0.019262	 0.00485	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48167	 91704	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48167	 91704	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91704	 48168	 0.017848	 0.032204	 0.00047	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91704	 48169	 0.010623	 0.041327	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48170	 48171	 0.005886	 0.013461	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48170	 48172	 0.003859	 0.017194	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48170	 48177	 0.003526	 0.013716	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48170	 48177	 0.003526	 0.013716	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48170	 48211	 0.005352	 0.017855	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48171	 48212	 0.008378	 0.017144	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48172	 91706	 0.004098	 0.012572	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48173	 91705	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91706	 48173	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48174	 48203	 0.017958	 0.032278	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48174	 91707	 0.00367	 0.014277	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48174	 91708	 0.003384	 0.023229	 0.00042	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48175	 48199	 0.000536	 0.002603	 0.00059	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91705	 48175	 0.001407	 0.006122	 0.00174	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48175	 91707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48175	 91707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91163	 48176	 0.000262	 0.001563	 0.00041	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48176	 91708	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48176	 91708	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91164	 48177	 0.004511	 0.013839	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91164	 48177	 0.004511	 0.013839	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48177	 91712	 0.007457	 0.013865	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91167	 48178	 0.004867	 0.016237	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48178	 91712	 0.00563	 0.014473	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48179	 91709	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91710	 48179	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48180	 48181	 0.001841	 0.007163	 0.00191	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91709	 48180	 0.001877	 0.007945	 0.00179	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48180	 91711	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48180	 91711	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48181	 48582	 0.004018	 0.019015	 0.00457	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48182	 48183	 0.002679	 0.007899	 0.00184	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91709	 48182	 0.002942	 0.010398	 0.00234	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48182	 91712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48182	 91712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48183	 91713	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48183	 91713	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48184	 48212	 0.017082	 0.030702	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48184	 48585	 0.019747	 0.045368	 0.00069	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91713	 48184	 0.017757	 0.029495	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48185	 48204	 0.010127	 0.033418	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48185	 91715	 0.012621	 0.071745	 0.0013	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48185	 91923	 0.033672	 0.1179	 0.00326	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48186	 48187	 0.016204	 0.046476	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48186	 48689	 0.015579	 0.095779	 0.00173	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48186	 91714	 0.007591	 0.046666	 0.00084	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48187	 91716	 0.006882	 0.030796	 0.00063	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48188	 48189	 0.002461	 0.007408	 0.00232	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48188	 91714	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48188	 91714	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91168	 48189	 0.001	 0.0045	 0.0012	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48189	 91715	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48189	 91715	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48190	 48191	 0.000899	 0.003807	 0.00086	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48190	 91716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48190	 91716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48191	 48196	 0.001069	 0.004415	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48192	 48587	 0.004181	 0.016741	 0.00422	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91168	 48192	 0.001389	 0.011913	 0.00339	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48192	 91717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48192	 91717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91717	 48193	 0.012467	 0.052038	 0.0015	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91168	 48194	 0.001631	 0.007721	 0.00186	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48194	 91718	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48194	 91718	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48195	 48197	 0.014459	 0.037169	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91706	 48195	 0.00542	 0.026014	 0.00078	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48196	 48199	 0.001033	 0.004741	 0.00121	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91707	 48198	 0.012149	 0.023809	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48200	 48202	 0.03079	 0.072911	 0.00133	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91709	 48201	 0.00452	 0.019674	 0.00561	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48201	 91719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48201	 91719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48202	 48204	 0.018717	 0.048113	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91719	 48202	 0.006794	 0.026534	 0.00059	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91719	 48204	 0.023583	 0.072424	 0.00136	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48205	 48206	 0.022944	 0.053268	 0.00079	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91531	 48205	 0.050277	 0.11673	 0.00174	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91167	 48206	 0.009077	 0.040445	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91710	 48207	 0.027456	 0.058838	 0.00103	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48207	 91720	 0.019977	 0.042811	 0.00075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48208	 48578	 0.003412	 0.011382	 0.00289	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48208	 91720	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48208	 91720	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91711	 48209	 0.022662	 0.03471	 0.0006	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91720	 48209	 0.027342	 0.043643	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91710	 48210	 0.030198	 0.078264	 0.00148	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91720	 48210	 0.095165	 0.075314	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48210	 91876	 0.02924	 0.083865	 0.00129	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91706	 48211	 0.012061	 0.030672	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91712	 48212	 0.019057	 0.04939	 0.00093	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91718	 48212	 0.005038	 0.039264	 0.00073	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91111	 48213	 0.00173	 0.01893	 0.18385	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48213	 91721	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48214	 91723	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48214	 91723	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48215	 48217	 0.005046	 0.021962	 0.00626	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91721	 48215	 0.004936	 0.025712	 0.00674	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48215	 91724	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48215	 91724	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48216	 48217	 0.00577	 0.025712	 0.00699	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48216	 91725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48216	 91725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48218	 48219	 0.004252	 0.037106	 0.01019	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48218	 91831	 0.037058	 0.17305	 0.04294	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48219	 48220	 0.003085	 0.030136	 0.00846	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48219	 91726	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48219	 91726	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48220	 48486	 0.013933	 0.063927	 0.01638	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48220	 48515	 0.014214	 0.064011	 0.01704	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48221	 48677	 0.005317	 0.033038	 0.00932	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48221	 91728	 0.00528	 0.038561	 0.00991	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48222	 48223	 0.005116	 0.023472	 0.00601	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91548	 48222	 0.01239	 0.032747	 0.00767	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48223	 48224	 0.003061	 0.012637	 0.00299	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48223	 91727	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48223	 91727	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48224	 91728	 0.001686	 0.007511	 0.00204	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48225	 48226	 0.000654	 0.004463	 0.00804	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48225	 91728	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48225	 91728	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48226	 91729	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91730	 48226	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48227	 48680	 0.019348	 0.11715	 0.00367	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91730	 48227	 0.01647	 0.093625	 0.00169	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48228	 48229	 0.003216	 0.009481	 0.00221	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48228	 91731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48228	 91731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91728	 48229	 0.003187	 0.011106	 0.00258	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91663	 48230	 0.033647	 0.1309	 0.00219	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91727	 48230	 0.047081	 0.064234	 0.00115	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91731	 48230	 0.010677	 0.047043	 0.00082	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48231	 48656	 0.001074	 0.008631	 0.01872	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48231	 91732	 0.001422	 0.00936	 0.01811	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48232	 91734	 0.02172	 0.050419	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48233	 48238	 0.000484	 0.005572	 0.0546	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48233	 48610	 0.001788	 0.020596	 0.202	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48233	 91732	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48233	 91732	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48234	 48235	 0.003101	 0.012417	 0.00313	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91638	 48234	 0.006328	 0.025335	 0.00638	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48235	 91733	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48235	 91733	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48235	 91735	 0.004941	 0.020912	 0.00471	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91733	 48236	 0.027281	 0.054014	 0.00079	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48237	 91736	 0.012415	 0.031913	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48238	 48239	 0.000259	 0.002982	 0.02922	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48238	 91734	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48238	 91734	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48239	 48240	 0.0001	 0.00119	 0.0119	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48239	 91735	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48240	 48241	 9.5e-05	 0.001177	 0.0109	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48241	 91737	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48242	 48247	 0.002189	 0.014772	 0.0272	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91736	 48243	 0.025904	 0.10078	 0.00168	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91738	 48244	 0.023855	 0.038077	 0.00088	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91635	 48245	 0.02884	 0.073345	 0.00116	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48246	 48657	 0.001776	 0.011843	 0.02232	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48246	 91739	 0.003027	 0.10896	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48246	 91739	 0.003027	 0.10896	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48247	 91740	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48247	 91740	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48247	 91913	 0.00325	 0.021101	 0.04204	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48248	 91853	 0.16991	 0.43702	 0.00677	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48249	 48521	 0.014338	 0.048312	 0.01201	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48249	 91741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48249	 91741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48250	 48251	 0.020821	 0.015051	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48250	 48252	 0.034642	 0.027415	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91741	 48250	 0.054803	 0.11216	 0.00276	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48253	 91742	 0.29869	 0.23645	 0.00298	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48254	 91742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48254	 91742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48254	 91743	 0.003091	 0.033504	 0.01047	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91160	 48255	 0.18946	 0.20842	 0.00278	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48256	 48260	 0.008471	 0.020059	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48256	 91744	 0.003784	 0.022995	 0.00042	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48257	 91743	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91744	 48257	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91127	 48258	 0.019023	 0.062055	 0.01648	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48258	 91745	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48258	 91745	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48259	 91821	 0.054407	 0.098171	 0.00142	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48261	 48739	 0.024364	 0.064402	 0.01508	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91551	 48261	 0.021771	 0.08862	 0.0216	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48261	 91746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48261	 91746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48262	 48264	 0.009642	 0.029022	 0.00908	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48262	 48266	 0.019038	 0.051117	 0.01159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91113	 48262	 0.033774	 0.11386	 0.02832	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48262	 91747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48262	 91747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91154	 48263	 0.079142	 0.12634	 0.00291	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48263	 91852	 0.31645	 0.25052	 0.00315	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48264	 48265	 0.004457	 0.011778	 0.00276	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48265	 48266	 0.001223	 0.005609	 0.00144	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48265	 48267	 0.001018	 0.004939	 0.00113	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91650	 48266	 0.008039	 0.068959	 0.01963	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48267	 48268	 0.010244	 0.04972	 0.01137	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48268	 48269	 0.015	 0.060065	 0.01514	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48268	 48531	 0.015319	 0.06022	 0.01576	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91119	 48269	 0.017663	 0.071893	 0.01752	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48270	 48271	 0.005731	 0.004536	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48270	 91748	 0.003596	 0.008515	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48272	 91748	 0.009141	 0.006725	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48273	 48378	 0.001836	 0.005526	 0.00173	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48273	 91748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48273	 91748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48273	 91749	 0.000459	 0.003245	 0.00089	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48274	 48275	 0.003209	 0.009205	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91690	 48274	 0.004149	 0.009826	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48275	 91750	 0.001777	 0.008671	 0.00015	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48276	 48277	 0.009281	 0.006828	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48277	 91751	 0.003702	 0.007607	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48278	 48424	 0.000606	 0.004089	 0.00753	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48278	 91749	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91750	 48278	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48278	 91860	 0.000544	 0.003818	 0.0065	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48279	 48280	 0.0007	 0.005035	 0.00133	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48279	 91751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48279	 91751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48279	 91861	 0.000894	 0.006321	 0.00173	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48281	 48287	 0.000811	 0.002704	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48281	 48288	 0.000656	 0.001934	 0.00045	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48282	 48283	 0.009438	 0.006944	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48282	 91859	 0.006432	 0.012606	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48283	 91753	 0.009194	 0.007276	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48284	 48286	 0.000628	 0.00189	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48284	 48542	 0.000604	 0.002072	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48285	 91752	 0.009792	 0.007749	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48286	 48287	 0.000529	 0.001583	 0.00036	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48286	 91752	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48286	 91752	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48287	 91753	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48287	 91753	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48288	 48289	 0.001407	 0.004827	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48288	 91754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48288	 91754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48289	 48319	 0.00065	 0.001917	 0.00045	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48290	 48291	 0.009527	 0.00754	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48290	 48294	 0.012521	 0.009814	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48291	 48426	 0.00695	 0.004499	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91754	 48291	 0.005848	 0.005906	 8e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48292	 48293	 0.009435	 0.006942	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48292	 48294	 0.013734	 0.010869	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48292	 48295	 0.007621	 0.005509	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91754	 48293	 0.012562	 0.009942	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48294	 48321	 0.00246	 0.006813	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48294	 91774	 0.006891	 0.015631	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48296	 48297	 0.000192	 0.001283	 0.00242	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48296	 48299	 0.000245	 0.003253	 0.00695	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48296	 48301	 0.000326	 0.00221	 0.00402	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48296	 48328	 0.000152	 0.000965	 0.00202	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48296	 91755	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48296	 91755	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48297	 48298	 0.000146	 0.001633	 0.00335	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48297	 91756	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91757	 48297	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48298	 48301	 0.000226	 0.001554	 0.00274	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91146	 48298	 0.000609	 0.007527	 0.0151	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48298	 91758	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48298	 91758	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48299	 91759	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91760	 48299	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48299	 91771	 0.000358	 0.002761	 0.00562	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48300	 91773	 0.008351	 0.015068	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48301	 91761	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48301	 91761	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48302	 91765	 0.010322	 0.016105	 0.00027	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48302	 91773	 0.016688	 0.039516	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48303	 91767	 0.016887	 0.013364	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48304	 91893	 0.036124	 0.083854	 0.0016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91760	 48305	 0.003829	 0.008798	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48305	 91765	 0.002872	 0.006155	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48306	 91766	 0.005102	 0.008143	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48306	 91773	 0.009305	 0.023918	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48307	 48312	 0.00044	 0.004302	 0.00121	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48307	 48313	 0.000399	 0.003356	 0.00099	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48307	 91762	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48307	 91762	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91762	 48308	 0.005048	 0.009246	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48308	 91769	 0.007371	 0.018948	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48309	 48315	 2.1e-05	 0.000266	 0.01823	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48309	 48645	 0.000182	 0.00311	 0.2421	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48309	 91763	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91764	 48309	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48310	 48317	 0.010622	 0.008406	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48311	 48312	 0.000424	 0.004201	 0.00129	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91761	 48311	 0.000376	 0.003728	 0.00114	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48311	 91765	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48311	 91765	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48312	 91766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48312	 91766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91764	 48313	 0.000362	 0.002956	 0.0008	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91763	 48314	 5.2e-05	 0.000587	 0.00534	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48314	 91767	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48314	 91767	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48314	 91768	 9.1e-05	 0.001288	 0.01228	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48314	 91904	 0.000629	 0.006489	 0.10197	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48315	 48318	 4.4e-05	 0.000574	 0.03666	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48315	 91768	 0.00012	 0.009565	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48315	 91768	 0.00012	 0.009565	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48316	 48317	 0.014963	 0.029626	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91769	 48316	 0.002543	 0.014834	 0.0003	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48316	 91773	 0.002991	 0.020532	 0.00037	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48318	 48552	 0.000451	 0.005833	 0.37243	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48318	 48707	 0.000786	 0.01568	 1.0823	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48318	 91770	 8.9e-05	 0.007096	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48319	 48331	 0.000509	 0.001344	 0.00031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48320	 48321	 0.002728	 0.005401	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48320	 91775	 0.006118	 0.008041	 0.00011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48322	 48323	 0.007816	 0.006127	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48323	 91774	 0.015111	 0.011959	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48324	 48325	 0.000425	 0.001951	 0.0005	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48324	 48333	 0.000913	 0.003865	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48324	 48347	 0.001162	 0.00465	 0.00157	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91756	 48324	 0.001655	 0.007717	 0.00191	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48324	 91774	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48324	 91774	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48325	 48326	 0.000356	 0.001634	 0.00042	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91756	 48326	 0.000944	 0.004466	 0.00107	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48327	 48328	 9.4e-05	 0.000608	 0.00121	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48327	 48339	 0.000114	 0.000796	 0.00136	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48329	 48330	 0.00987	 0.00639	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48330	 48340	 0.007039	 0.013088	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91757	 48330	 0.00476	 0.012236	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48331	 48332	 0.00059	 0.001559	 0.00036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48331	 48348	 0.000284	 0.001118	 0.00029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48332	 91775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48332	 91775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48333	 48345	 0.000493	 0.001784	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48333	 91776	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48333	 91776	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91775	 48334	 0.002226	 0.005722	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91776	 48334	 0.002728	 0.00646	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48335	 48336	 0.002561	 0.004762	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91776	 48335	 0.003147	 0.006167	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91774	 48336	 0.003697	 0.009504	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48337	 48339	 9.6e-05	 0.001075	 0.0022	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48337	 48436	 0.000312	 0.001974	 0.00413	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48337	 91777	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48337	 91777	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48338	 91780	 0.008319	 0.016472	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48338	 91809	 0.016125	 0.011657	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48339	 91778	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91779	 48339	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91779	 48340	 0.004079	 0.00947	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48341	 48342	 0.000444	 0.001879	 0.00042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48341	 48428	 0.000525	 0.002103	 0.00053	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91756	 48342	 0.001792	 0.007173	 0.00181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48342	 91780	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48342	 91780	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91775	 48343	 0.008284	 0.006556	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48344	 48345	 0.00033	 0.001168	 0.00026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48344	 48350	 0.000434	 0.001306	 0.00041	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48346	 48347	 0.000549	 0.001851	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48346	 48428	 0.000473	 0.002238	 0.00054	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48347	 48350	 0.001235	 0.003751	 0.00082	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48347	 48354	 0.000872	 0.003492	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48348	 48425	 0.000462	 0.001957	 0.00044	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48348	 91781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48348	 91781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48349	 48356	 0.00963	 0.007621	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91781	 48349	 0.011881	 0.007692	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48350	 48352	 0.000144	 0.001019	 0.00028	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48351	 91782	 0.008098	 0.005854	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48352	 48353	 0.000129	 0.000814	 0.00022	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48353	 48357	 0.000219	 0.001344	 0.00039	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48354	 48358	 0.000399	 0.001622	 0.0004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48354	 91782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48354	 91782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48355	 48359	 0.006686	 0.007354	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48356	 91783	 0.012794	 0.010028	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48357	 48365	 0.000426	 0.001855	 0.00053	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48357	 91783	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48357	 91783	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48358	 48366	 0.000397	 0.001616	 0.00039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48359	 48371	 0.021294	 0.016852	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48359	 91787	 0.003841	 0.007605	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48360	 48364	 0.00077	 0.003028	 0.00079	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48360	 48368	 0.00134	 0.00388	 0.00094	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48360	 91784	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48360	 91784	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48361	 91791	 0.010073	 0.007971	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48362	 48377	 0.000794	 0.003704	 0.00092	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48362	 91813	 0.000835	 0.003635	 0.00104	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48363	 91785	 0.010702	 0.00847	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48364	 91785	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48364	 91785	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48364	 91813	 0.000563	 0.003023	 0.00074	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48365	 48369	 0.000457	 0.001831	 0.00046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48365	 91786	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48365	 91786	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48366	 48435	 0.000414	 0.001686	 0.00041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48367	 48371	 0.005541	 0.005596	 7e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48368	 48376	 0.000435	 0.001693	 0.00045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48368	 91787	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48368	 91787	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48369	 48389	 0.00044	 0.00173	 0.00045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48370	 48435	 0.000411	 0.001598	 0.00043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48370	 91788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48370	 91788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48370	 91789	 0.000558	 0.002233	 0.00056	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91788	 48371	 0.00278	 0.0069	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48372	 48436	 0.000667	 0.004677	 0.00796	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91684	 48372	 0.000325	 0.002668	 0.00481	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48372	 91789	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48372	 91789	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48373	 91790	 0.008094	 0.006345	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48374	 48376	 0.000636	 0.002546	 0.00064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48374	 48421	 0.000519	 0.002079	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48374	 91790	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48374	 91790	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91784	 48375	 0.014576	 0.011425	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48377	 48422	 0.001122	 0.005733	 0.00156	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48377	 91791	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48377	 91791	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48378	 48379	 0.000534	 0.001498	 0.00039	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48378	 48382	 0.001083	 0.003649	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48379	 48380	 0.000363	 0.001224	 0.0003	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48379	 48429	 0.000639	 0.001782	 0.00037	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48380	 48381	 0.000315	 0.00108	 0.00026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48381	 48385	 0.000399	 0.001367	 0.00033	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48382	 48387	 0.000635	 0.001872	 0.00044	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48382	 91792	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48382	 91792	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91792	 48383	 0.003609	 0.005283	 8e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48383	 91793	 0.004247	 0.008408	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48384	 48389	 0.000695	 0.001613	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48384	 91793	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48384	 91793	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48385	 48432	 0.000511	 0.00185	 0.0004	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48386	 48387	 0.00041	 0.001407	 0.00034	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48386	 48431	 0.000953	 0.003369	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48387	 48395	 0.000817	 0.003456	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48387	 91794	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48387	 91794	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91794	 48388	 0.006396	 0.004531	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48389	 48396	 0.000275	 0.001237	 0.00033	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48390	 48392	 0.000437	 0.001806	 0.00043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48390	 48432	 0.00042	 0.001711	 0.00042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48391	 91795	 0.008803	 0.006967	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48392	 48394	 0.000604	 0.002073	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48392	 48434	 0.001971	 0.005118	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48392	 91795	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48392	 91795	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48393	 91796	 0.007468	 0.005854	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48394	 48400	 0.000566	 0.001973	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48394	 91796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48394	 91796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48395	 91798	 0.000468	 0.001875	 0.00047	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48396	 48402	 0.000545	 0.001483	 0.00033	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48396	 48411	 0.000753	 0.003187	 0.00072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48397	 48399	 0.000383	 0.001581	 0.00037	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48397	 48434	 0.000248	 0.000851	 0.0002	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48398	 91797	 0.011451	 0.007413	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48399	 48406	 0.000643	 0.002503	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48400	 91797	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48400	 91797	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48400	 91798	 0.000416	 0.001939	 0.00048	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48401	 91798	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48401	 91798	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48401	 91800	 0.000207	 0.001404	 0.00256	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48402	 48407	 0.000797	 0.002141	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48403	 48404	 0.003357	 0.006149	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48403	 48405	 0.003182	 0.0063	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48403	 91812	 0.004285	 0.008398	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48404	 48408	 0.003157	 0.006635	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48405	 91799	 0.004634	 0.009174	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48406	 91799	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48406	 91799	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48406	 91801	 0.000522	 0.00235	 0.00063	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48407	 48409	 0.000722	 0.00213	 0.0005	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48408	 91802	 0.004889	 0.014023	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48409	 48411	 0.000457	 0.001523	 0.00039	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48409	 91804	 0.000883	 0.004049	 0.00104	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48410	 48543	 0.000325	 0.005285	 0.05151	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48410	 91800	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48411	 91803	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48411	 91803	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91803	 48412	 0.010172	 0.006585	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48413	 48417	 0.01069	 0.00846	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91803	 48413	 0.010804	 0.00781	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48414	 91805	 0.018291	 0.012287	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48415	 48416	 0.010743	 0.008421	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91802	 48415	 0.008891	 0.008893	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48415	 91805	 0.004848	 0.008167	 0.00012	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48417	 91806	 0.008665	 0.007406	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91156	 48418	 5.8e-05	 0.000683	 0.00275	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91684	 48418	 0.000229	 0.001546	 0.00285	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91800	 48418	 0.000191	 0.001452	 0.00264	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48418	 91804	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91805	 48418	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48419	 48420	 0.00775	 0.005602	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91686	 48420	 0.010901	 0.009317	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91685	 48421	 0.00094	 0.00388	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48421	 91806	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48421	 91806	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91777	 48422	 0.001186	 0.005285	 0.00144	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91778	 48423	 0.000607	 0.002571	 0.00058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91156	 48424	 0.000556	 0.006043	 0.01313	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48424	 91807	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91808	 48424	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91807	 48425	 0.000691	 0.002851	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91754	 48427	 0.01046	 0.024769	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91757	 48427	 0.003056	 0.015162	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48428	 91809	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48428	 91809	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91807	 48429	 0.001113	 0.002797	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48429	 91810	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48429	 91810	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91793	 48430	 0.004121	 0.006941	 0.0001	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91810	 48430	 0.007224	 0.009494	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48432	 91811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48432	 91811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91793	 48433	 0.008967	 0.007096	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48434	 91812	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48434	 91812	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48436	 91813	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48436	 91813	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91773	 48437	 0.022521	 0.02112	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48438	 48439	 0.000877	 0.0062	 0.0017	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48438	 48473	 0.00128	 0.005123	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48438	 91814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48438	 91814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48439	 48464	 0.000453	 0.005013	 0.0015	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48439	 91815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48439	 91815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48440	 48442	 0.000999	 0.004581	 0.00117	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48440	 91816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48440	 91816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48440	 91826	 0.00479	 0.027519	 0.0078	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48441	 48444	 0.002596	 0.024165	 0.00047	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48441	 91823	 0.003526	 0.034143	 0.00068	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48442	 48477	 0.001223	 0.005787	 0.00139	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48442	 91817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48442	 91817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91817	 48443	 0.002411	 0.022442	 0.00043	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48443	 91830	 0.004951	 0.032721	 0.00064	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48444	 48445	 0.01821	 0.014274	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48444	 48474	 0.005801	 0.017796	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48444	 48474	 0.005801	 0.017796	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48444	 91830	 0.002946	 0.013128	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48446	 48472	 0.002562	 0.009857	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48446	 48472	 0.002562	 0.009857	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48446	 48474	 0.004001	 0.015392	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48446	 48474	 0.004001	 0.015392	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48447	 48472	 0.007946	 0.025585	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48447	 91832	 0.00909	 0.027914	 0.00052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48448	 48472	 0.002752	 0.014312	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48448	 91832	 0.004203	 0.020174	 0.0006	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91815	 48449	 0.002725	 0.01992	 0.00037	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48449	 91830	 0.004153	 0.021009	 0.00037	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48450	 48453	 0.002561	 0.011749	 0.00301	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91126	 48450	 0.003559	 0.02769	 0.00719	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48450	 91818	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48450	 91818	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48451	 48454	 0.01491	 0.058006	 0.00097	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48451	 48454	 0.01491	 0.058006	 0.00097	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48451	 48680	 0.041514	 0.12496	 0.00244	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48451	 91819	 0.005606	 0.042591	 0.00097	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48452	 91819	 0.01035	 0.036215	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48452	 91819	 0.01035	 0.036215	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48452	 91820	 0.006761	 0.024998	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48452	 91820	 0.006761	 0.024998	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48453	 48466	 0.011112	 0.043234	 0.01155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48453	 91819	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48453	 91819	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91169	 48454	 0.009682	 0.037666	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91169	 48454	 0.009682	 0.037666	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48455	 91820	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48455	 91820	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48456	 48457	 0.003911	 0.013683	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48456	 48457	 0.003911	 0.013683	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91814	 48456	 0.002179	 0.018504	 0.00043	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91820	 48456	 0.008938	 0.024759	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48457	 48458	 0.014223	 0.02816	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91820	 48458	 0.006532	 0.02513	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91820	 48458	 0.006532	 0.02513	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48458	 91832	 0.013172	 0.051242	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48458	 91832	 0.013172	 0.051242	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48459	 91832	 0.00432	 0.026251	 0.00048	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48460	 48463	 0.003541	 0.014988	 0.00337	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48460	 91821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48460	 91821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48461	 91822	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48461	 91822	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48461	 91826	 0.010896	 0.043626	 0.01099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91816	 48462	 0.008987	 0.023103	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91127	 48463	 0.00137	 0.013852	 0.00407	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48464	 91823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48464	 91823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48464	 91826	 0.001506	 0.020511	 0.00733	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48465	 91824	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48465	 91824	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48466	 91828	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48466	 91828	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48467	 48468	 0.04057	 0.13534	 0.00215	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48467	 91832	 0.022379	 0.13601	 0.00251	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48468	 48469	 0.034423	 0.097685	 0.00153	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91828	 48469	 0.018935	 0.084376	 0.00143	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48470	 48477	 0.003521	 0.016155	 0.00414	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91826	 48470	 0.011935	 0.057929	 0.01324	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48471	 91829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48471	 91829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48471	 91831	 0.004047	 0.034712	 0.00988	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48473	 91830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48473	 91830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48475	 91832	 0.01979	 0.039182	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48476	 48489	 0.003128	 0.040829	 0.68153	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91824	 48476	 0.000499	 0.006624	 0.10497	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48476	 91831	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48478	 48479	 0.025617	 0.10073	 0.02637	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48478	 91833	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48478	 91833	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48480	 48482	 0.014416	 0.080999	 0.0015	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48480	 91834	 0.00284	 0.018572	 0.00043	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48481	 48561	 0.049106	 0.19106	 0.00319	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91174	 48481	 0.061553	 0.24428	 0.00698	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48482	 48485	 0.026328	 0.11732	 0.00199	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91174	 48482	 0.092873	 0.47006	 0.00918	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91142	 48483	 0.051195	 0.067285	 0.00092	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48484	 91834	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48484	 91834	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48485	 48564	 0.056209	 0.19203	 0.00418	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48486	 91835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48486	 91835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48487	 91841	 0.019042	 0.035407	 0.00083	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48488	 91837	 0.050826	 0.099612	 0.00149	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48488	 91841	 0.11962	 0.093768	 0.0012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48489	 48493	 0.000602	 0.006925	 0.06786	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48489	 91836	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48490	 48491	 0.019967	 0.058876	 0.0137	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91119	 48490	 0.004108	 0.027556	 0.00665	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48490	 91838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48490	 91838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48491	 48513	 0.015838	 0.071327	 0.01898	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91836	 48491	 0.004647	 0.025497	 0.00674	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48491	 91839	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48491	 91839	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91162	 48492	 0.004188	 0.016291	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48492	 91843	 0.003779	 0.012606	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48493	 91840	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91841	 48494	 0.018252	 0.052349	 0.00081	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91841	 48495	 0.005077	 0.028463	 0.00078	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48495	 91842	 0.002558	 0.014341	 0.0004	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48496	 91842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48496	 91842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48497	 48498	 0.001971	 0.009858	 0.00018	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48497	 91844	 0.00261	 0.013968	 0.00042	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48497	 91850	 0.004558	 0.015959	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48498	 91843	 0.001447	 0.007743	 0.00023	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48499	 48501	 0.001567	 0.005377	 0.00129	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48499	 91843	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48499	 91843	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48500	 48502	 0.007781	 0.018066	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91839	 48500	 0.016806	 0.056064	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48501	 48516	 0.001941	 0.009419	 0.00215	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48502	 91844	 0.013726	 0.034907	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48503	 91846	 0.007954	 0.027849	 0.00077	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48504	 48506	 0.001408	 0.004975	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48504	 91844	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48504	 91844	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48505	 48506	 0.002164	 0.009926	 0.00254	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48505	 48511	 0.012496	 0.050033	 0.01261	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48505	 91845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48505	 91845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48506	 48509	 0.002624	 0.011813	 0.00314	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48506	 91846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48506	 91846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48507	 91850	 0.026439	 0.02908	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91845	 48508	 0.012063	 0.026698	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48508	 91847	 0.018469	 0.06161	 0.00098	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91840	 48509	 0.003491	 0.018486	 0.00469	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48509	 91847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48509	 91847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91840	 48510	 0.009439	 0.0393	 0.01226	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48510	 91848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48510	 91848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91839	 48512	 0.064529	 0.11599	 0.00208	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48513	 91849	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48513	 91849	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91849	 48514	 0.11484	 0.18827	 0.00332	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91840	 48515	 0.005954	 0.027769	 0.00688	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48516	 48518	 0.002082	 0.009279	 0.00252	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48517	 91850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48517	 91850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91836	 48518	 0.003764	 0.016774	 0.00456	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48518	 91851	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48518	 91851	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48519	 48520	 0.009159	 0.027428	 0.00618	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91113	 48519	 0.014545	 0.058243	 0.01468	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48520	 91852	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48520	 91852	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91127	 48521	 0.007747	 0.098042	 0.0507	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48521	 91853	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48521	 91853	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91853	 48522	 0.012973	 0.049704	 0.0014	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48523	 48525	 0.082934	 0.077775	 0.0012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48524	 48526	 0.029866	 0.15532	 0.00337	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91821	 48524	 0.031282	 0.17228	 0.00389	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91822	 48525	 0.074583	 0.20378	 0.00346	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91829	 48526	 0.094227	 0.21879	 0.00325	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48527	 48529	 0.014429	 0.040239	 0.00845	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48527	 48530	 0.015353	 0.051734	 0.01286	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48527	 91854	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48527	 91854	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48528	 48533	 0.077699	 0.30235	 0.00505	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91854	 48528	 0.1226	 0.24277	 0.00356	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48528	 91855	 0.023567	 0.091686	 0.00153	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48529	 48532	 0.018011	 0.081118	 0.02159	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91113	 48529	 0.015099	 0.11033	 0.02838	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48529	 91855	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48529	 91855	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48530	 48531	 0.007311	 0.025079	 0.00601	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48530	 91856	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48530	 91856	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48531	 48532	 0.0068	 0.032186	 0.00774	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48532	 48694	 0.005199	 0.042197	 0.01344	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48533	 91925	 0.0986	 0.25351	 0.00392	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48534	 48535	 0.13215	 0.10459	 0.00132	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48534	 91858	 0.016612	 0.042248	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48536	 91857	 0.007294	 0.032503	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48536	 91863	 0.003891	 0.015136	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48537	 48549	 0.000566	 0.005998	 0.00178	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91147	 48537	 0.001026	 0.009082	 0.00499	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48537	 91857	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48537	 91857	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48538	 48540	 0.011606	 0.026945	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91857	 48538	 0.007918	 0.016272	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48539	 91864	 0.017666	 0.013551	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48540	 91858	 0.005768	 0.013392	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91146	 48541	 0.001057	 0.008535	 0.01586	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48541	 91858	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48541	 91858	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48541	 91860	 0.000924	 0.005853	 0.01226	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48542	 48544	 0.000834	 0.00272	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48542	 91859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48542	 91859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91770	 48543	 0.00019	 0.003093	 0.03015	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48543	 91860	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48544	 48545	 0.000775	 0.003104	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48545	 48547	 0.000682	 0.002885	 0.00065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91862	 48546	 0.003117	 0.008013	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48547	 48549	 0.000579	 0.002277	 0.0006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48548	 48549	 0.000277	 0.002747	 0.00084	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48548	 91863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48548	 91863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48549	 91864	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48549	 91864	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48550	 91868	 0.053943	 0.04269	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91669	 48551	 0.005289	 0.021617	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48552	 91865	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48552	 91865	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91697	 48553	 0.049397	 0.039092	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91697	 48554	 0.015586	 0.036179	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48555	 48647	 0.009684	 0.045837	 0.01102	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48556	 48648	 0.009662	 0.045733	 0.011	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48557	 91866	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91866	 48558	 0.00312	 0.014315	 0.00367	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48560	 48665	 0.001451	 0.015929	 0.15481	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91122	 48560	 0.000375	 0.004114	 0.03996	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91865	 48560	 0.0003	 0.003487	 0.03014	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48560	 91868	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48560	 91868	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48561	 91869	 0.032398	 0.15633	 0.00276	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48562	 48563	 0.018027	 0.047647	 0.01115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91646	 48562	 0.012586	 0.03379	 0.00766	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48563	 91869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48563	 91869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91647	 48564	 0.18893	 0.43886	 0.00653	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91869	 48564	 0.043461	 0.12466	 0.00192	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48565	 48581	 0.00952	 0.033179	 0.00769	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91646	 48565	 0.021567	 0.097144	 0.02586	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48566	 48573	 0.002562	 0.011536	 0.00307	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91646	 48566	 0.006753	 0.048581	 0.01288	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48566	 91870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48566	 91870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48567	 48579	 0.009463	 0.037194	 0.00973	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91124	 48568	 0.001934	 0.02383	 0.0077	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48568	 91871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48568	 91871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48569	 48570	 0.007703	 0.025698	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91871	 48569	 0.017894	 0.050778	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48570	 48571	 0.002177	 0.011078	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91125	 48571	 0.017385	 0.053332	 0.00144	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91125	 48571	 0.017385	 0.053332	 0.00144	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48572	 91872	 0.023429	 0.080032	 0.00174	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48572	 91873	 0.04863	 0.1129	 0.00168	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48573	 91872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48573	 91872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91872	 48574	 0.006686	 0.017005	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48575	 48576	 0.010376	 0.019292	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91872	 48576	 0.005739	 0.022326	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91872	 48577	 0.021606	 0.084053	 0.0014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48577	 91874	 0.024235	 0.080848	 0.00128	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48578	 48579	 0.003971	 0.013623	 0.00326	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48578	 91873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48578	 91873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48579	 91874	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48579	 91874	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48580	 48583	 0.005475	 0.043709	 0.01077	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91657	 48580	 0.006209	 0.049884	 0.01402	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48581	 48582	 0.005172	 0.018728	 0.00402	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48581	 91875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48581	 91875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48582	 48586	 0.002228	 0.01039	 0.00257	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48582	 91876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48582	 91876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48583	 48584	 0.004899	 0.020228	 0.00479	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48583	 48586	 0.003648	 0.017706	 0.00405	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48583	 91877	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48583	 91877	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48584	 91878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48584	 91878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91710	 48585	 0.054969	 0.12629	 0.00192	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91878	 48585	 0.018795	 0.096479	 0.00183	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48587	 91879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48587	 91879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91878	 48588	 0.038508	 0.071603	 0.00168	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91879	 48589	 0.006403	 0.059613	 0.00115	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48590	 48591	 0.1908	 0.17757	 0.00336	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48591	 48592	 0.015614	 0.036249	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48591	 91880	 0.026575	 0.076223	 0.00117	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48592	 48593	 0.009027	 0.031607	 0.00088	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48593	 91880	 0.002301	 0.012311	 0.00037	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48594	 48595	 0.00229	 0.029326	 0.00875	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91657	 48594	 0.016909	 0.16541	 0.0465	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48594	 91880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48594	 91880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48597	 48598	 0.001348	 0.017266	 0.00515	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48598	 91881	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48598	 91881	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91881	 48599	 0.050464	 0.03267	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48600	 91882	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48600	 91882	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48601	 48602	 0.019396	 0.01535	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91882	 48601	 0.02246	 0.044469	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48603	 91892	 0.041739	 0.096891	 0.00184	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48604	 48607	 0.003312	 0.017539	 0.00445	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48604	 48710	 0.0097	 0.04222	 0.01203	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48604	 48711	 0.008479	 0.0389	 0.00997	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48605	 48613	 0.004445	 0.032488	 0.00958	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48605	 91935	 0.00769	 0.054393	 0.01493	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48606	 91883	 0.027397	 0.050942	 0.00119	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48606	 91933	 0.069973	 0.20071	 0.00309	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48607	 91883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48607	 91883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48607	 91889	 0.005162	 0.032074	 0.00905	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48608	 48644	 0.029572	 0.052821	 0.00078	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48608	 91886	 0.030096	 0.10752	 0.00213	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48609	 48614	 0.012956	 0.030073	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48609	 48638	 0.019834	 0.041685	 0.00076	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48610	 48611	 0.000194	 0.00213	 0.02069	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48610	 91884	 8.1e-05	 0.006451	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48611	 48618	 0.000719	 0.010433	 0.09437	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48611	 48665	 0.000886	 0.00982	 0.09351	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48611	 91887	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91888	 48611	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91884	 48612	 0.001471	 0.009981	 0.01817	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91887	 48612	 0.000765	 0.005218	 0.00939	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48612	 91889	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48612	 91889	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48613	 48617	 0.003229	 0.014052	 0.004	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91889	 48613	 0.002747	 0.011177	 0.00272	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91886	 48614	 0.012565	 0.076364	 0.00141	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48615	 48617	 0.001544	 0.006285	 0.00153	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91888	 48615	 0.002914	 0.011668	 0.00294	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48616	 48617	 0.001141	 0.00532	 0.00132	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48616	 48641	 0.005049	 0.017597	 0.00408	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48616	 91890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48616	 91890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48618	 48637	 0.000147	 0.001976	 0.03531	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48618	 91891	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48618	 91934	 0.00076	 0.012806	 0.23235	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48619	 48621	 0.005645	 0.018832	 0.00478	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48619	 48634	 0.004961	 0.018046	 0.00552	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91891	 48619	 0.004001	 0.03014	 0.00836	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48620	 48621	 0.003269	 0.008777	 0.00199	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48620	 48631	 0.003572	 0.008291	 0.00253	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48622	 91893	 0.025035	 0.059284	 0.00108	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48623	 48624	 0.030016	 0.021698	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48623	 91894	 0.007226	 0.016526	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48624	 91897	 0.026934	 0.05512	 0.00136	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48625	 48626	 0.002567	 0.02001	 0.00037	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48625	 48628	 0.003076	 0.01794	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48626	 91900	 0.004319	 0.041817	 0.00084	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48627	 48634	 0.006826	 0.02733	 0.00689	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48627	 91893	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48627	 91893	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48628	 48629	 0.006502	 0.016714	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48628	 91897	 0.018607	 0.047831	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48629	 91894	 0.011671	 0.019661	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48630	 48631	 0.001214	 0.003259	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48630	 91894	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48630	 91894	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48631	 91895	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48631	 91895	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48632	 91896	 0.017408	 0.024262	 0.00041	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48633	 48634	 0.001199	 0.00832	 0.00237	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48633	 91896	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48633	 91896	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48633	 91899	 0.001052	 0.008201	 0.00245	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48634	 91897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48634	 91897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48635	 48645	 3.5e-05	 0.000422	 0.03166	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48635	 91898	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48636	 91901	 0.032161	 0.052718	 0.00093	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91898	 48637	 0.000521	 0.00606	 0.05239	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48637	 91901	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48637	 91901	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48637	 91904	 0.000341	 0.005977	 0.06395	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48638	 48639	 0.006324	 0.021097	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48639	 91902	 0.003984	 0.015329	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48640	 48642	 0.001493	 0.005676	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48640	 91902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48640	 91902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48641	 48642	 0.002347	 0.007909	 0.00197	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48642	 91903	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48642	 91903	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91901	 48643	 0.027471	 0.084365	 0.00158	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91903	 48643	 0.010759	 0.027361	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91902	 48644	 0.007748	 0.022223	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48645	 91904	 0.000154	 0.011578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48645	 91904	 0.000154	 0.011578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48646	 48647	 0.002696	 0.025888	 0.00753	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48646	 91931	 0.004078	 0.034973	 0.00995	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48647	 48648	 0.012552	 0.041877	 0.01062	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48648	 48650	 0.005488	 0.025975	 0.00625	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48648	 91931	 0.007444	 0.072746	 0.02042	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48649	 91905	 0.00554	 0.042449	 0.01137	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48649	 91931	 0.005464	 0.039678	 0.01371	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48650	 48652	 0.005324	 0.020923	 0.00547	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48651	 48655	 0.000841	 0.008496	 0.01928	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91884	 48651	 0.003249	 0.021089	 0.04201	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48651	 91905	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48651	 91905	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48652	 91907	 0.007382	 0.028059	 0.00785	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48653	 48654	 0.004056	 0.013912	 0.00333	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48653	 91907	 0.004984	 0.012813	 0.00317	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48654	 91906	 0.003895	 0.013574	 0.00315	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48655	 48662	 0.001047	 0.007144	 0.01286	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48655	 91906	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48655	 91906	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48656	 48657	 0.000683	 0.004432	 0.00883	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48656	 91907	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91908	 48656	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48656	 91913	 0.002082	 0.014047	 0.02586	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48657	 48662	 0.001152	 0.007479	 0.0149	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48657	 91909	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48657	 91909	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48658	 48659	 0.022257	 0.018319	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48658	 48660	 0.010447	 0.020684	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91908	 48659	 0.022908	 0.052629	 0.0008	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48660	 91912	 0.014932	 0.030556	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91907	 48661	 0.007678	 0.020613	 0.00467	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48661	 91910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48661	 91910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48661	 91911	 0.002512	 0.008463	 0.0021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48662	 91911	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91912	 48662	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91912	 48663	 0.030981	 0.10335	 0.00164	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91909	 48664	 0.071244	 0.056382	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91910	 48664	 0.08059	 0.063779	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48665	 91913	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91914	 48665	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48666	 48667	 0.13205	 0.24192	 0.00418	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91741	 48666	 0.12908	 0.33192	 0.00514	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48667	 48668	 0.12898	 0.28944	 0.00462	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91600	 48668	 0.11441	 0.25328	 0.00415	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48669	 91915	 0.002328	 0.01136	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48670	 91915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48670	 91915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91915	 48671	 0.007819	 0.026083	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91725	 48672	 0.004778	 0.011314	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91721	 48673	 0.031435	 0.15658	 0.05064	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91274	 48675	 0.001986	 0.031884	 0.31998	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48675	 91916	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48676	 48677	 0.008521	 0.038368	 0.01021	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48677	 48678	 0.00952	 0.041439	 0.01181	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48678	 48679	 0.012795	 0.043112	 0.01072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48678	 91918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48678	 91918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91126	 48679	 0.007921	 0.038444	 0.00879	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48679	 91919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48679	 91919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91919	 48680	 0.056582	 0.16058	 0.00252	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48681	 48685	 0.009678	 0.03261	 0.0081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48681	 91920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48681	 91920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91703	 48682	 0.11974	 0.30789	 0.00477	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48683	 48684	 0.005467	 0.024614	 0.00655	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48683	 91921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48683	 91921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48684	 91922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48684	 91922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48685	 48686	 0.003682	 0.014741	 0.00371	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48685	 91923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48685	 91923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48686	 48687	 0.001554	 0.005185	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48687	 91924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48687	 91924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48688	 48691	 0.019631	 0.076372	 0.00127	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91922	 48688	 0.024713	 0.096142	 0.0016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91924	 48688	 0.004619	 0.031706	 0.00058	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48690	 48691	 0.043964	 0.080526	 0.00139	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91652	 48691	 0.028323	 0.14241	 0.00387	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91922	 48692	 0.034745	 0.15483	 0.00263	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91838	 48693	 0.064005	 0.22869	 0.00454	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48693	 91927	 0.063034	 0.1808	 0.00278	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48694	 48696	 0.004349	 0.037296	 0.01061	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48694	 50513	 0.013489	 0.06385	 0.01536	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48694	 91925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48694	 91925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48695	 48698	 0.007612	 0.030475	 0.00768	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48696	 48697	 0.001708	 0.010613	 0.003	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48697	 48698	 0.00307	 0.012495	 0.00304	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48697	 48702	 0.005327	 0.022545	 0.00507	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48697	 91926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48697	 91926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91119	 48699	 0.011772	 0.12002	 0.03095	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48699	 91927	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48699	 91927	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48700	 48702	 0.001252	 0.005838	 0.00145	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48700	 48704	 0.006309	 0.029426	 0.00729	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91927	 48701	 0.030022	 0.14651	 0.00253	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48701	 91928	 0.008083	 0.033034	 0.00067	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48702	 91928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48702	 91928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91927	 48703	 0.053849	 0.1102	 0.00271	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48705	 91929	 0.040583	 0.1164	 0.00179	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48706	 48707	 0.000114	 0.001939	 0.1509	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48706	 48709	 0.000274	 0.005083	 0.33573	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48706	 48714	 0.000182	 0.002332	 0.17493	 1813.0	 1903.7	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48706	 91929	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48706	 91929	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48707	 91930	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48707	 91930	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48708	 91932	 0.051155	 0.093697	 0.00162	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48709	 91931	 0.000127	 0.010176	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48709	 91931	 0.000127	 0.010176	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91931	 48710	 0.009888	 0.04713	 0.01365	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48710	 91933	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48710	 91933	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48711	 91935	 0.00605	 0.029361	 0.00671	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48712	 91936	 0.01207	 0.030696	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91171	 48713	 0.00548	 0.019173	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48714	 91934	 0.000115	 0.009166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91936	 48715	 0.024202	 0.049527	 0.00122	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48716	 48717	 0.015879	 0.044282	 0.0093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48716	 91937	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48716	 91937	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48717	 48718	 0.002183	 0.00983	 0.00262	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48717	 48719	 0.007882	 0.036162	 0.00926	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48717	 91938	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48717	 91938	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48719	 48721	 0.010991	 0.048981	 0.01331	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48719	 91939	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48719	 91939	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48720	 48722	 0.005517	 0.022777	 0.00539	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48721	 48724	 0.006026	 0.025505	 0.00574	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48723	 91940	 0.029428	 0.019052	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48724	 48725	 0.000854	 0.00342	 0.00086	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48724	 91940	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48724	 91940	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48725	 48726	 0.006427	 0.026536	 0.00628	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91548	 48726	 0.016711	 0.077955	 0.01931	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48727	 48728	 0.002351	 0.009241	 0.00242	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48727	 48730	 0.007558	 0.02189	 0.00528	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48727	 91941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48727	 91941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91615	 48728	 0.001526	 0.011868	 0.00308	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91657	 48728	 0.017474	 0.061156	 0.02027	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91616	 48729	 0.028674	 0.095656	 0.00152	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91129	 48730	 0.001883	 0.016145	 0.00459	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91129	 48731	 0.002416	 0.020048	 0.00527	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48732	 91942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48732	 91942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48733	 48734	 0.038147	 0.14841	 0.00248	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91942	 48733	 0.039557	 0.15219	 0.0026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91745	 48734	 0.050762	 0.20317	 0.00429	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48735	 91943	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91944	 48735	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91174	 48736	 0.16656	 0.17526	 0.00257	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48737	 91945	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48737	 91945	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91831	 48738	 0.033855	 0.16447	 0.03765	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48738	 91946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48738	 91946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91650	 48739	 0.027339	 0.073413	 0.01664	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48739	 91947	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48739	 91947	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48740	 48741	 0.00141	 0.006466	 0.00166	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48740	 91948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48740	 91948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48742	 48745	 0.11865	 0.084049	 0.00133	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48743	 48746	 0.042609	 0.091311	 0.0016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48743	 49978	 0.1036	 0.24057	 0.00358	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48744	 48933	 0.050151	 0.20444	 0.04993	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48744	 49123	 0.075679	 0.22712	 0.0513	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91210	 48744	 0.020914	 0.19051	 0.0482	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48744	 91949	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48744	 91949	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48745	 48747	 0.011454	 0.029444	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48745	 49426	 0.15537	 0.28042	 0.00405	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91949	 48745	 0.017909	 0.043837	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48746	 48747	 0.024842	 0.041848	 0.0006	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91949	 48746	 0.012541	 0.048788	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48747	 48748	 0.006595	 0.01208	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48749	 48814	 0.009939	 0.049973	 0.00136	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48749	 49016	 0.098741	 0.18363	 0.0043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48749	 91950	 0.018444	 0.12661	 0.00231	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48750	 91950	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48750	 91950	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48751	 49138	 0.17563	 0.17937	 0.00279	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91950	 48751	 0.11705	 0.1174	 0.0019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91212	 48752	 0.26478	 0.20959	 0.00264	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91224	 48752	 0.24963	 0.22529	 0.00377	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91950	 48752	 0.065391	 0.095288	 0.00215	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48753	 49539	 0.024995	 0.10176	 0.02481	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48753	 91951	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48753	 91951	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91213	 48754	 0.066042	 0.14153	 0.00248	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91227	 48754	 0.050423	 0.07158	 0.00118	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91951	 48754	 0.14724	 0.2256	 0.00317	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48754	 93177	 0.049802	 0.24033	 0.00424	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48755	 49584	 0.009481	 0.042252	 0.01148	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91219	 48755	 0.001036	 0.008888	 0.00253	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91219	 48756	 0.013903	 0.047697	 0.01143	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48756	 91952	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48756	 91952	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48757	 91973	 0.036167	 0.071608	 0.00105	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91952	 48758	 0.0248	 0.11097	 0.00229	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48758	 91953	 0.020693	 0.056531	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48759	 48811	 0.021175	 0.055969	 0.0131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48759	 91953	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48759	 91953	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48760	 48761	 0.013038	 0.05072	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48760	 48810	 0.39651	 0.2919	 0.00427	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91953	 48760	 0.014406	 0.043361	 0.00085	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48761	 48851	 0.16566	 0.17432	 0.00255	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48762	 49973	 0.16806	 0.22091	 0.00303	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48762	 91955	 0.25485	 0.19981	 0.00257	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48763	 48764	 0.006484	 0.022243	 0.00533	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48763	 48766	 0.011752	 0.040961	 0.0095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48764	 49443	 0.004073	 0.017726	 0.00505	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48764	 49445	 0.019611	 0.050917	 0.01236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91206	 48764	 0.06274	 0.17102	 0.03773	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48764	 91954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48764	 91954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48765	 48766	 0.015752	 0.041633	 0.00975	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48766	 48767	 0.012636	 0.031765	 0.00823	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48767	 91955	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48767	 91955	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48768	 49973	 0.22464	 0.15093	 0.00266	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48769	 91957	 0.073952	 0.090154	 0.00144	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48770	 91956	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48770	 91956	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48770	 92449	 0.00953	 0.084012	 0.17588	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91200	 48771	 0.027846	 0.08662	 0.01808	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48771	 91957	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48771	 91957	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48772	 48774	 0.003726	 0.033017	 0.00879	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91204	 48772	 0.019987	 0.068576	 0.01643	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48772	 92008	 0.004439	 0.036864	 0.01442	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48773	 91958	 0.14796	 0.14537	 0.00245	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48774	 48775	 0.01105	 0.044243	 0.01115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48774	 49997	 0.029288	 0.121	 0.02865	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48774	 91958	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48774	 91958	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48775	 49996	 0.017839	 0.072606	 0.0177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48776	 48779	 0.069889	 0.14978	 0.00262	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48776	 49514	 0.070103	 0.20109	 0.00309	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48776	 91959	 0.057656	 0.19029	 0.00308	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48777	 48778	 0.008039	 0.031275	 0.00835	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48777	 49127	 0.014216	 0.044212	 0.00923	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48777	 49563	 0.010382	 0.040806	 0.01068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48777	 91959	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48777	 91959	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48777	 92093	 0.024189	 0.081521	 0.02027	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48778	 48780	 0.011042	 0.044212	 0.01114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48778	 48781	 0.018559	 0.063677	 0.01526	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48778	 91960	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48778	 91960	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48778	 92093	 0.0177	 0.079714	 0.02122	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91960	 48779	 0.10094	 0.19987	 0.00293	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48779	 91961	 0.14642	 0.1753	 0.00292	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48780	 49133	 0.015729	 0.061831	 0.01618	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48781	 48865	 0.021546	 0.055942	 0.01358	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48781	 49133	 0.012206	 0.049675	 0.0121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48781	 91961	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48781	 91961	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48782	 48783	 0.001079	 0.016141	 0.03776	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48782	 92186	 0.012164	 0.085114	 0.14656	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48782	 92245	 0.001932	 0.021012	 0.04568	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91193	 48783	 0.005109	 0.050354	 0.10745	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48783	 91962	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91963	 48783	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91963	 48784	 0.24252	 0.19196	 0.00242	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48785	 48786	 0.004837	 0.012006	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91225	 48785	 0.026508	 0.020778	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91242	 48785	 0.00306	 0.010209	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48785	 91972	 0.048379	 0.038286	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48786	 48813	 0.004403	 0.010116	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91225	 48787	 0.001741	 0.003448	 5e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48788	 48797	 0.0198	 0.030031	 0.00043	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48788	 48807	 0.17322	 0.13709	 0.00173	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91225	 48788	 0.007192	 0.016695	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48789	 48812	 0.014958	 0.019659	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48790	 48800	 0.006286	 0.016613	 0.00389	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48790	 91964	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48790	 91964	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48790	 91968	 0.003753	 0.009647	 0.00239	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48791	 48813	 0.02475	 0.019587	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48791	 91965	 0.015299	 0.030291	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48792	 48803	 0.009273	 0.024896	 0.00564	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48792	 91965	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48792	 91965	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48793	 48813	 0.015886	 0.039429	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48794	 48795	 0.002213	 0.009365	 0.00211	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48794	 48796	 0.00276	 0.009298	 0.00231	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48795	 48806	 0.004847	 0.019408	 0.00489	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48795	 91966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48795	 91966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48796	 91967	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48796	 91967	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48796	 91968	 0.003617	 0.015311	 0.00345	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91967	 48797	 0.026765	 0.017328	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91967	 48798	 0.01069	 0.021164	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48798	 91969	 0.015441	 0.036564	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48799	 48990	 0.008161	 0.055114	 0.10162	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48799	 91968	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91969	 48799	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48800	 48803	 0.004231	 0.011799	 0.00248	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48800	 91970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48800	 91970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48801	 91971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48801	 91971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91968	 48802	 0.004099	 0.010305	 0.00267	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48802	 91972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48802	 91972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48803	 48855	 0.014975	 0.048846	 0.01297	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91970	 48804	 0.13695	 0.10838	 0.00136	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48804	 91989	 0.074442	 0.1459	 0.00219	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91965	 48805	 0.029837	 0.16432	 0.00371	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48805	 92043	 0.052101	 0.14414	 0.00335	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48806	 48858	 0.016904	 0.068799	 0.01677	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48807	 49630	 0.39527	 0.39951	 0.00529	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91969	 48807	 0.13495	 0.099296	 0.00145	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91966	 48808	 0.095559	 0.089616	 0.00138	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91969	 48808	 0.041484	 0.10664	 0.00165	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48808	 92045	 0.089725	 0.1886	 0.00344	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91971	 48809	 0.18544	 0.15266	 0.00309	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91236	 48810	 0.044859	 0.1026	 0.0025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48810	 91973	 0.057007	 0.11173	 0.00167	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48811	 49627	 0.032545	 0.095988	 0.02234	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91219	 48811	 0.054302	 0.14592	 0.03311	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48811	 91973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48811	 91973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91225	 48812	 0.016234	 0.012847	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91964	 48812	 0.003926	 0.008035	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91225	 48813	 0.002704	 0.013193	 0.00023	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48814	 48815	 0.009614	 0.032071	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48814	 48821	 0.006089	 0.022512	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48815	 91974	 0.014373	 0.047431	 0.00077	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48816	 48838	 0.003699	 0.01481	 0.00373	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48816	 50644	 0.005061	 0.021421	 0.00482	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48816	 91974	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48816	 91974	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48817	 48825	 0.004926	 0.012664	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91974	 48817	 0.00825	 0.020476	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48818	 48824	 0.017969	 0.01422	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48819	 48821	 0.0108	 0.025072	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48819	 48822	 0.006029	 0.017293	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48820	 48821	 0.008068	 0.02074	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48820	 48828	 0.012294	 0.031603	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48820	 91978	 0.014137	 0.06229	 0.00108	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91974	 48821	 0.031126	 0.066455	 0.0015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48822	 48825	 0.009301	 0.021591	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48822	 48826	 0.005836	 0.013819	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48822	 48827	 0.012829	 0.017488	 0.00039	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48823	 48824	 0.015636	 0.011504	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48823	 48825	 0.005134	 0.011364	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48823	 91978	 0.009016	 0.027686	 0.00052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48824	 48825	 0.018919	 0.013919	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91974	 48825	 0.011806	 0.026999	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48826	 48827	 0.007425	 0.014701	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48826	 48829	 0.004091	 0.01672	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48826	 91978	 0.00706	 0.027467	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48829	 48830	 0.005201	 0.021254	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48829	 48831	 0.011621	 0.03072	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48830	 91975	 0.005652	 0.017338	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48830	 91975	 0.005652	 0.017338	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48830	 91978	 0.002267	 0.018344	 0.00047	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48831	 48836	 0.044963	 0.11559	 0.00179	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48832	 91975	 0.004252	 0.016359	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48832	 91976	 0.006242	 0.021842	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48833	 48834	 0.000785	 0.004157	 0.00105	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48833	 91975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48833	 91975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48834	 48837	 0.004936	 0.031266	 0.00849	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48834	 91976	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48834	 91976	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48835	 48836	 0.049281	 0.14135	 0.00217	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48835	 48981	 0.12737	 0.16007	 0.00241	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48836	 91977	 0.02457	 0.13246	 0.00267	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91179	 48837	 0.00187	 0.024565	 0.02274	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48837	 91977	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48837	 91977	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48838	 91978	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48838	 91978	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48839	 91983	 0.040512	 0.086495	 0.00195	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48840	 49637	 0.000262	 0.003389	 0.21629	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48840	 49639	 0.000432	 0.005586	 0.35665	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48840	 50013	 0.000464	 0.005795	 0.39726	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48840	 91979	 8.9e-05	 0.007096	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48840	 91979	 8.9e-05	 0.007096	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48841	 48847	 0.079052	 0.1199	 0.00172	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48842	 48846	 0.000207	 0.002339	 0.0213	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91979	 48842	 0.000557	 0.005902	 0.06157	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48842	 91982	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48842	 92269	 0.001145	 0.012498	 0.12274	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48842	 92400	 0.001445	 0.020178	 0.19778	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91982	 48843	 0.00261	 0.007006	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48843	 91984	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48843	 91984	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91199	 48845	 0.051046	 0.084791	 0.0018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91196	 48846	 0.000961	 0.010933	 0.09875	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48846	 91985	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91986	 48847	 0.010077	 0.023046	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91283	 48848	 0.025454	 0.066094	 0.01605	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91985	 48848	 0.015032	 0.040928	 0.00902	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48848	 91987	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48848	 91987	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48849	 48850	 0.27808	 0.22013	 0.00277	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48849	 49464	 0.064295	 0.25017	 0.00418	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48849	 92003	 0.14924	 0.3466	 0.00516	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48849	 92037	 0.18196	 0.36041	 0.00529	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48850	 92037	 0.034285	 0.13721	 0.0029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91178	 48852	 0.030237	 0.086726	 0.00133	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48853	 48854	 0.002659	 0.0094	 0.00212	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48853	 48855	 0.009005	 0.031383	 0.00728	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91177	 48853	 0.003392	 0.035447	 0.01193	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48854	 48855	 0.006547	 0.022058	 0.00548	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48854	 91988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48854	 91988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48855	 91989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48855	 91989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48856	 48857	 0.058402	 0.12516	 0.00219	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91989	 48856	 0.028826	 0.15186	 0.00273	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48857	 48982	 0.052382	 0.12162	 0.00181	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91233	 48857	 0.098129	 0.24024	 0.00411	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48858	 48996	 0.004332	 0.016466	 0.00461	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48859	 48868	 0.024984	 0.070899	 0.00111	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91247	 48859	 0.010906	 0.067049	 0.00121	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48859	 91990	 0.020874	 0.081207	 0.00136	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48859	 92219	 0.15145	 0.19908	 0.00273	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48860	 48863	 0.009518	 0.038733	 0.00944	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48860	 91990	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48860	 91990	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48861	 48862	 0.008498	 0.058335	 0.00106	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48861	 48868	 0.013662	 0.083994	 0.00151	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48862	 91991	 0.006337	 0.043496	 0.00079	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48863	 48866	 0.001283	 0.020343	 0.01287	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48863	 91991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48863	 91991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48864	 48867	 0.096641	 0.19136	 0.00281	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91990	 48864	 0.032115	 0.065721	 0.00162	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48865	 91992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48865	 91992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48866	 49010	 0.002279	 0.038127	 0.02162	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48867	 49612	 0.24126	 0.24374	 0.00323	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48868	 48869	 0.046326	 0.089759	 0.00193	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91990	 48868	 0.025994	 0.060348	 0.0009	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91992	 48869	 0.052317	 0.12147	 0.00181	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48870	 48873	 0.000545	 0.005975	 0.05804	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48870	 48875	 0.000701	 0.007943	 0.07232	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48870	 49557	 0.001209	 0.013271	 0.12896	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48870	 91993	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48870	 91993	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48871	 92247	 0.35544	 0.3742	 0.00548	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48872	 49950	 0.011727	 0.041453	 0.00934	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91962	 48872	 0.017064	 0.05307	 0.01108	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48873	 48874	 0.000147	 0.001663	 0.01514	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48873	 91994	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48873	 91994	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48874	 48875	 0.000371	 0.00422	 0.03811	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48874	 91995	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48874	 91995	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48875	 91996	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91997	 48875	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48876	 48880	 0.000746	 0.007602	 0.00196	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91997	 48876	 0.001576	 0.015134	 0.0044	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48877	 48880	 0.000277	 0.002751	 0.00075	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48877	 91998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48877	 91998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48877	 92001	 0.001257	 0.01207	 0.00351	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91998	 48878	 0.029135	 0.023057	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91998	 48879	 0.008909	 0.01171	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48881	 91999	 0.009906	 0.024247	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91995	 48882	 0.000482	 0.00585	 0.01894	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48882	 91999	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48882	 91999	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48882	 92000	 0.000392	 0.004512	 0.01629	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48883	 92000	 8.6e-05	 0.006896	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91998	 48885	 0.006782	 0.018528	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48886	 92003	 0.3374	 0.26712	 0.00336	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48886	 92004	 0.10026	 0.1689	 0.00241	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48886	 92011	 0.14688	 0.26909	 0.00465	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48887	 48915	 0.049934	 0.13935	 0.02928	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48887	 49632	 0.022606	 0.059753	 0.01399	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48887	 92003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48887	 92003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48888	 92004	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48888	 92004	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48889	 48890	 0.12776	 0.25044	 0.00375	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91981	 48889	 0.061823	 0.23789	 0.00406	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48890	 92237	 0.33769	 0.31443	 0.00595	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48891	 48894	 0.032708	 0.025885	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48891	 48895	 0.009654	 0.032204	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48891	 49265	 0.012215	 0.040309	 0.00065	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48892	 48893	 0.021278	 0.016839	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48893	 48896	 0.008203	 0.033525	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48893	 49268	 0.0088	 0.018009	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48895	 92006	 0.0223	 0.068412	 0.00185	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48895	 92917	 0.038924	 0.069962	 0.00126	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48896	 48897	 0.0169	 0.048471	 0.00075	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48896	 48909	 0.068776	 0.053911	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48896	 92007	 0.024885	 0.11135	 0.00229	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48897	 48898	 0.020526	 0.047654	 0.00071	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48897	 48899	 0.018483	 0.056702	 0.00154	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48897	 49343	 0.064087	 0.064731	 0.00086	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91222	 48897	 0.034385	 0.12032	 0.00249	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48898	 48909	 0.01282	 0.03138	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91218	 48898	 0.038886	 0.11035	 0.00173	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91209	 48899	 0.007819	 0.038153	 0.00066	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48899	 92005	 0.050848	 0.077895	 0.00109	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91209	 48900	 0.049934	 0.094377	 0.00153	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48900	 92005	 0.0342	 0.064638	 0.00105	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48900	 92192	 0.062593	 0.16091	 0.00249	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91208	 48901	 0.002	 0.008005	 0.00202	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48901	 92005	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48901	 92005	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48902	 48904	 0.008336	 0.030328	 0.00929	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48902	 92008	 0.0086	 0.033803	 0.00884	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48903	 92009	 0.003458	 0.013843	 0.00349	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48904	 92009	 0.000806	 0.005008	 0.00141	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48905	 92006	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48905	 92006	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48906	 92007	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48906	 92007	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91218	 48907	 0.052387	 0.13467	 0.00208	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48908	 48910	 0.002618	 0.016996	 0.03386	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48908	 92008	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48908	 92008	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48910	 92009	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48910	 92009	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48910	 92956	 0.003617	 0.023483	 0.04679	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48911	 48912	 0.012838	 0.051404	 0.01295	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91204	 48912	 0.027632	 0.12685	 0.03253	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48912	 92010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48912	 92010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48913	 49009	 0.016131	 0.064594	 0.01628	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48914	 49462	 0.051939	 0.11089	 0.0025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91211	 48914	 0.06697	 0.29849	 0.00507	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48914	 92011	 0.037139	 0.1979	 0.00347	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48915	 92011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48915	 92011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48915	 92012	 0.020897	 0.055235	 0.01293	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48916	 49132	 0.011799	 0.13328	 0.24586	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48916	 49132	 0.011799	 0.13328	 0.24586	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48916	 92012	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92013	 48916	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 0	 -30.0	 30.0;
	48917	 49444	 0.14743	 0.10848	 0.00159	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48917	 92014	 0.055396	 0.10147	 0.00175	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48918	 49109	 0.006466	 0.022855	 0.00515	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48918	 49972	 0.013399	 0.038812	 0.00936	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48918	 92014	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48918	 92014	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48919	 48920	 0.004588	 0.012795	 0.00269	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48919	 92015	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48919	 92015	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91244	 48920	 0.006192	 0.017267	 0.00362	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48920	 92016	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48920	 92016	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92016	 48921	 0.023176	 0.03046	 0.00042	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48921	 92021	 0.012722	 0.032703	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48922	 48923	 0.023482	 0.032726	 0.00056	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48922	 92020	 0.014816	 0.038086	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92016	 48923	 0.099231	 0.078532	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48924	 48928	 0.002947	 0.011202	 0.00314	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48924	 92018	 0.004656	 0.017696	 0.00495	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48925	 48927	 0.000366	 0.004148	 0.03776	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48925	 48930	 0.000497	 0.005449	 0.05293	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48925	 92017	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92018	 48925	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48926	 48927	 0.000191	 0.002125	 0.02004	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48926	 92019	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48927	 92021	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48927	 92021	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91244	 48928	 0.005148	 0.02179	 0.0049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48928	 92022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48928	 92022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92022	 48929	 0.066683	 0.14291	 0.0025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48930	 49984	 0.000574	 0.006304	 0.06123	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48931	 48932	 0.31772	 0.25153	 0.00317	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48931	 49448	 0.058599	 0.23255	 0.00664	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90261	 48931	 0.0648	 0.39858	 0.00719	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48931	 92023	 0.034986	 0.082848	 0.00151	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48932	 92023	 0.074174	 0.1184	 0.00273	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48933	 92023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48933	 92023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48934	 92024	 0.019962	 0.020383	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48934	 92035	 0.011975	 0.030782	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48935	 48936	 0.019601	 0.023894	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48935	 49588	 0.016996	 0.022337	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48936	 48945	 0.004164	 0.0162	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48936	 92024	 0.010862	 0.036236	 0.00057	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48937	 92024	 0.019127	 0.021038	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48938	 92024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48938	 92024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48938	 92034	 0.002274	 0.009105	 0.00229	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48939	 48941	 0.00159	 0.003997	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48939	 48943	 0.002488	 0.009681	 0.00259	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91185	 48939	 0.001766	 0.011182	 0.00303	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48939	 92025	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48939	 92025	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48940	 92026	 0.018538	 0.018724	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48941	 92026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48941	 92026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48942	 48959	 0.007317	 0.016988	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48942	 48977	 0.009042	 0.020993	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48942	 92036	 0.019718	 0.060553	 0.00114	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48943	 48947	 0.001314	 0.005856	 0.00159	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48943	 92027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48943	 92027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48943	 92034	 0.003846	 0.017318	 0.00461	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92027	 48944	 0.032784	 0.023699	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48945	 48951	 0.006832	 0.017562	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48945	 92028	 0.002685	 0.01526	 0.00028	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92027	 48946	 0.008457	 0.011528	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48947	 48948	 0.002465	 0.006913	 0.00178	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48947	 92028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48947	 92028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48948	 92029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48948	 92029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48949	 48950	 0.003972	 0.01325	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92028	 48949	 0.004377	 0.013426	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92029	 48950	 0.011373	 0.021146	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48951	 49587	 0.006814	 0.022733	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48952	 48953	 0.006342	 0.036052	 0.00065	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48952	 48956	 0.052674	 0.038078	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48952	 48958	 0.010014	 0.038527	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48952	 48958	 0.010014	 0.038527	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48952	 48961	 0.021341	 0.052238	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48953	 48959	 0.01274	 0.027302	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92027	 48953	 0.011016	 0.042857	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48954	 48955	 0.013975	 0.022306	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48955	 49593	 0.012524	 0.024797	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92029	 48955	 0.003985	 0.017759	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48957	 48958	 0.006041	 0.0235	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48957	 48958	 0.006041	 0.0235	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48957	 92031	 0.024164	 0.094005	 0.00157	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48957	 92031	 0.024164	 0.094005	 0.00157	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48957	 92256	 0.014202	 0.049692	 0.00103	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48959	 48960	 0.020897	 0.027196	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48961	 48968	 0.044336	 0.044781	 0.00059	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48962	 48963	 0.010729	 0.025406	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48962	 48964	 0.019288	 0.025101	 0.00035	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48962	 48968	 0.048325	 0.039776	 0.00081	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91241	 48962	 0.030301	 0.089106	 0.00183	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48962	 92036	 0.045772	 0.11361	 0.00189	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48965	 49312	 0.011307	 0.029884	 0.007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48965	 49592	 0.017782	 0.069904	 0.01829	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48965	 92030	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48965	 92030	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48966	 48967	 0.017756	 0.03805	 0.00067	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48966	 48969	 0.037706	 0.14669	 0.00245	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48966	 48971	 0.042039	 0.07082	 0.00101	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48967	 49631	 0.08982	 0.15002	 0.00255	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91228	 48967	 0.029018	 0.1286	 0.00386	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	48969	 48972	 0.019517	 0.091782	 0.00171	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92030	 48970	 0.035902	 0.092291	 0.00143	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48972	 92031	 0.009475	 0.03686	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48972	 92258	 0.051069	 0.14493	 0.00228	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48973	 49605	 0.006807	 0.02881	 0.00648	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48973	 92031	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48973	 92031	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48974	 92032	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48975	 49313	 0.007203	 0.01961	 0.00432	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91185	 48975	 0.000734	 0.008085	 0.00414	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	48975	 92036	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48975	 92036	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48976	 48977	 0.032165	 0.032172	 0.00043	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92030	 48976	 0.05815	 0.092822	 0.00214	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92036	 48977	 0.010345	 0.036221	 0.001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48978	 49632	 0.050695	 0.13408	 0.03141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48978	 92037	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48978	 92037	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48979	 48980	 0.074435	 0.1254	 0.00179	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92037	 48979	 0.087022	 0.13892	 0.0032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48980	 48981	 0.12368	 0.12493	 0.00165	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92037	 48980	 0.1187	 0.21421	 0.0031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48980	 92258	 0.078698	 0.2953	 0.00531	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48982	 48983	 0.045324	 0.037306	 0.00076	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48982	 92044	 0.039652	 0.043613	 0.00058	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48983	 48991	 0.046311	 0.098877	 0.00223	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48983	 92042	 0.030159	 0.071417	 0.00131	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48984	 48987	 0.002097	 0.008535	 0.00208	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48984	 48996	 0.001393	 0.004647	 0.00118	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48984	 92038	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48984	 92038	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48984	 92041	 0.004725	 0.025441	 0.00699	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91221	 48985	 0.013659	 0.035112	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92038	 48985	 0.00461	 0.013876	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48985	 92040	 0.029128	 0.057086	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48985	 92044	 0.0101	 0.022909	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48986	 48988	 0.040921	 0.045008	 0.0006	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48986	 92039	 0.007802	 0.03302	 0.00062	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48987	 92039	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48987	 92039	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91221	 48988	 0.010592	 0.034953	 0.00057	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48988	 92043	 0.14177	 0.1122	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48989	 48995	 0.012536	 0.033133	 0.00776	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48989	 92040	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48989	 92040	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91176	 48990	 0.002502	 0.032324	 0.07328	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48990	 92041	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92042	 48990	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48991	 48992	 0.049103	 0.11017	 0.00176	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48992	 49494	 0.073908	 0.1716	 0.00255	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48993	 48994	 0.073608	 0.11275	 0.00196	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92039	 48993	 0.0244	 0.05778	 0.00106	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	48994	 49494	 0.03576	 0.17452	 0.00301	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48994	 92043	 0.096365	 0.16235	 0.00231	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	48994	 92222	 0.21595	 0.17779	 0.0036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48995	 49503	 0.017624	 0.045758	 0.01111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48995	 92043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48995	 92043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92041	 48996	 0.004248	 0.02488	 0.00678	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48996	 92044	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48996	 92044	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48997	 48998	 0.013928	 0.041066	 0.00955	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48997	 49502	 0.018287	 0.048335	 0.01132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	48998	 49140	 0.006399	 0.030286	 0.00728	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	48998	 92045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48998	 92045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	48999	 49000	 0.008047	 0.039266	 0.00068	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	48999	 49001	 0.095942	 0.18998	 0.00279	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	48999	 49940	 0.58315	 0.46203	 0.00582	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	48999	 49944	 0.26039	 0.23342	 0.00478	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91969	 48999	 0.14397	 0.37024	 0.00573	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49000	 49001	 0.11138	 0.22056	 0.00324	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92045	 49000	 0.006138	 0.029463	 0.00088	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49001	 49561	 0.062139	 0.24178	 0.00404	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49002	 49006	 0.006837	 0.027371	 0.0069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49002	 49055	 0.009359	 0.038085	 0.00928	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49002	 92046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49002	 92046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49003	 49050	 0.009754	 0.025075	 0.00621	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49003	 50007	 0.014874	 0.054119	 0.01657	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49003	 92047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49003	 92047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49004	 49007	 0.01075	 0.043043	 0.01084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49004	 50010	 0.018466	 0.078173	 0.0176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49005	 49572	 0.011169	 0.034733	 0.00725	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49005	 92048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49005	 92048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49006	 49007	 0.01207	 0.049837	 0.01179	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49006	 92049	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49006	 92049	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49008	 49009	 0.019211	 0.050777	 0.01189	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49008	 49112	 0.016377	 0.042103	 0.01043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49008	 92050	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49008	 92050	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49009	 49441	 0.037053	 0.097967	 0.02294	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49010	 49011	 0.006591	 0.038608	 0.01052	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49010	 92051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49010	 92051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49011	 49012	 0.005445	 0.040804	 0.00995	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49011	 92259	 0.011627	 0.044197	 0.01237	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49012	 49106	 0.016816	 0.066106	 0.0173	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49012	 49113	 0.041332	 0.11125	 0.03122	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49013	 49014	 0.076687	 0.15695	 0.00386	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49013	 49121	 0.16115	 0.29525	 0.0051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49013	 49126	 0.10745	 0.27627	 0.00428	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49013	 92052	 0.048627	 0.27648	 0.005	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49013	 92091	 0.19522	 0.35774	 0.00618	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49015	 92052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49015	 92052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91212	 49016	 0.049149	 0.11639	 0.00213	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92052	 49016	 0.073846	 0.15522	 0.00283	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49017	 49020	 0.001257	 0.020509	 0.01224	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49017	 49959	 0.003961	 0.062811	 0.03975	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49018	 92053	 0.049122	 0.11405	 0.0017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49019	 49020	 0.000281	 0.004391	 0.00287	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49019	 49581	 0.002707	 0.040711	 0.02864	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49019	 92053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49019	 92053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49021	 49549	 0.022477	 0.074999	 0.01903	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49021	 50027	 0.016706	 0.051956	 0.01084	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49022	 92054	 0.091254	 0.1424	 0.00238	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49023	 50021	 0.019198	 0.056609	 0.01317	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91095	 49023	 0.04128	 0.16547	 0.04175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49023	 92054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49023	 92054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49024	 49025	 0.002944	 0.007401	 0.00192	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49024	 49522	 0.013989	 0.036318	 0.00882	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49025	 49026	 0.011645	 0.030777	 0.0072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91198	 49026	 0.008581	 0.022276	 0.00541	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49027	 49029	 0.009751	 0.037935	 0.01013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49027	 49522	 0.014545	 0.051417	 0.01159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91285	 49027	 0.015901	 0.040878	 0.01012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91235	 49028	 0.022959	 0.014863	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49030	 49031	 0.009403	 0.032258	 0.00773	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49031	 92055	 0.009379	 0.032176	 0.00771	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49032	 92055	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49032	 92055	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49032	 92242	 0.000651	 0.011855	 0.11754	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91347	 49033	 0.008316	 0.038151	 0.00977	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49034	 49035	 0.001443	 0.011227	 0.02251	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91187	 49034	 0.000457	 0.003764	 0.00776	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49034	 92056	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49034	 92056	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49035	 92057	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49035	 92057	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49035	 92058	 0.000909	 0.005899	 0.01175	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92057	 49036	 0.007087	 0.039819	 0.00074	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49036	 92062	 0.023092	 0.042937	 0.001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49036	 92064	 0.088028	 0.1743	 0.00256	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49037	 49403	 0.002265	 0.02617	 0.22975	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49037	 92058	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49038	 49051	 0.12618	 0.2126	 0.00303	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92060	 49038	 0.072675	 0.17791	 0.00304	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49038	 92395	 0.056718	 0.13168	 0.00196	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92059	 49039	 0.012418	 0.042601	 0.01021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49039	 92061	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49039	 92061	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92061	 49040	 0.031523	 0.15947	 0.00277	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49040	 92065	 0.039032	 0.11195	 0.00172	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49041	 49042	 0.003105	 0.010463	 0.0026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49041	 92062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49041	 92062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49042	 49047	 0.004633	 0.017609	 0.00493	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92056	 49043	 0.004791	 0.019183	 0.00483	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49043	 92063	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49043	 92063	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49044	 49923	 0.004402	 0.020196	 0.00517	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92056	 49044	 0.003901	 0.017896	 0.00458	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49045	 49395	 0.06207	 0.12165	 0.00182	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92063	 49045	 0.026703	 0.088121	 0.00143	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49045	 92064	 0.059994	 0.1261	 0.0023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49046	 49047	 0.002631	 0.015412	 0.0042	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49046	 49048	 0.003208	 0.018787	 0.00512	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92059	 49047	 0.014018	 0.055103	 0.01442	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49047	 92064	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49047	 92064	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49048	 92397	 0.010153	 0.0631	 0.01781	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92064	 49049	 0.067427	 0.19341	 0.00297	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49049	 92065	 0.036117	 0.077398	 0.00136	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49050	 92065	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49050	 92065	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49051	 49052	 0.0394	 0.080971	 0.00154	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91233	 49051	 0.036468	 0.25037	 0.00457	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49052	 49053	 0.077898	 0.17898	 0.00272	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49053	 92066	 0.1198	 0.14606	 0.00234	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49053	 92067	 0.079306	 0.1814	 0.00443	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49054	 49055	 0.005054	 0.021392	 0.00481	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49054	 92066	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49054	 92066	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49055	 92067	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49055	 92067	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49056	 49126	 0.11846	 0.27509	 0.00409	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91212	 49056	 0.25466	 0.31057	 0.00498	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49056	 92068	 0.065579	 0.16859	 0.00261	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49057	 92068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49057	 92068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49058	 49059	 0.000876	 0.002725	 0.00057	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49058	 49065	 0.001616	 0.004271	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49058	 92069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49058	 92069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49059	 49060	 0.000945	 0.003294	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49059	 92070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49059	 92070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49060	 49070	 0.00127	 0.004141	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49060	 92071	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49060	 92071	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49061	 49074	 0.024547	 0.019426	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92069	 49061	 0.008666	 0.019818	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49061	 92090	 0.003705	 0.022778	 0.00041	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49062	 49063	 0.003613	 0.008264	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49062	 92075	 0.003091	 0.011894	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92069	 49063	 0.006669	 0.010115	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49064	 49076	 0.013012	 0.012202	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92069	 49064	 0.003748	 0.013388	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49064	 92072	 0.007485	 0.014147	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49065	 49116	 0.001338	 0.00459	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49065	 92072	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49065	 92072	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49066	 49067	 0.010539	 0.020866	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92072	 49066	 0.007433	 0.014716	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49067	 49068	 0.006762	 0.017382	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92070	 49067	 0.008589	 0.013157	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49068	 49069	 0.008204	 0.021088	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92071	 49068	 0.016152	 0.016156	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49068	 92089	 0.005408	 0.013699	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49069	 92079	 0.004553	 0.022773	 0.00041	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49070	 49071	 0.000618	 0.003201	 0.00078	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49070	 92073	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49070	 92073	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49071	 49072	 0.000359	 0.001932	 0.00053	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49072	 92074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49072	 92074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49072	 92082	 0.000789	 0.006403	 0.00204	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49073	 49086	 0.030129	 0.019505	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92074	 49073	 0.007087	 0.017348	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92073	 49074	 0.012699	 0.019261	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49075	 49088	 0.001435	 0.004682	 0.00124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49075	 49119	 0.001256	 0.005653	 0.0015	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49075	 92075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49075	 92075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49076	 92080	 0.008908	 0.0229	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49077	 49117	 0.013724	 0.018037	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49078	 49079	 0.002322	 0.007574	 0.00201	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49078	 49090	 0.001205	 0.007487	 0.00211	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91244	 49078	 0.008693	 0.031627	 0.00968	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49078	 92076	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49078	 92076	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49079	 49118	 0.001385	 0.005442	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49080	 49081	 0.001265	 0.004971	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49080	 49091	 0.002435	 0.011169	 0.00286	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49080	 92077	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49080	 92077	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49081	 49082	 0.001221	 0.004801	 0.00126	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49082	 49083	 0.001177	 0.004861	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49082	 92078	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49082	 92078	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91244	 49083	 0.002182	 0.011038	 0.00307	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49083	 92079	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49083	 92079	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92074	 49084	 0.017026	 0.012527	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49085	 49086	 0.011509	 0.02672	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49085	 92083	 0.006475	 0.028851	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49086	 92090	 0.009392	 0.030243	 0.00052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92075	 49087	 0.022896	 0.01812	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49088	 49089	 0.001501	 0.004305	 0.00106	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49089	 92080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49089	 92080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49089	 92085	 0.003712	 0.012735	 0.00305	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49090	 49116	 0.000868	 0.002977	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49090	 92085	 0.00134	 0.006109	 0.00194	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91244	 49092	 0.005587	 0.017375	 0.00363	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49092	 92081	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49092	 92081	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49093	 49095	 0.010221	 0.026489	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92078	 49093	 0.010388	 0.022261	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49094	 49104	 0.002062	 0.013061	 0.02736	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91243	 49094	 0.000194	 0.002672	 0.00532	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49094	 92082	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92083	 49094	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91245	 49095	 0.003692	 0.016452	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49096	 49099	 0.006248	 0.032491	 0.0007	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91245	 49096	 0.001875	 0.009148	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49097	 49098	 0.002902	 0.02414	 0.00046	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91203	 49097	 0.00347	 0.034003	 0.00067	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49098	 49099	 0.003797	 0.025092	 0.00049	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49100	 49101	 0.022585	 0.024063	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91203	 49101	 0.007661	 0.019483	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49102	 92090	 0.015331	 0.028505	 0.00067	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49103	 49114	 0.011347	 0.030893	 0.00681	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49103	 49441	 0.040269	 0.097091	 0.02743	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49103	 92084	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49103	 92084	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49104	 49115	 0.001389	 0.009375	 0.01726	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49104	 92085	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49104	 92085	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49105	 92086	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49105	 92086	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92081	 49107	 0.057309	 0.087793	 0.00123	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49108	 49110	 0.003601	 0.014415	 0.00363	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49108	 92087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49108	 92087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49109	 49110	 0.001715	 0.007257	 0.00163	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92087	 49111	 0.050344	 0.092212	 0.00159	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49112	 49113	 0.008878	 0.02417	 0.00533	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49112	 49441	 0.032632	 0.08627	 0.0202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49113	 49114	 0.008338	 0.022035	 0.00516	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49115	 49608	 0.005603	 0.038611	 0.0682	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49115	 92088	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49115	 92088	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92080	 49117	 0.007616	 0.018034	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91244	 49118	 0.004251	 0.022035	 0.00538	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49118	 92089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49118	 92089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49119	 92090	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49119	 92090	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49120	 49979	 0.11714	 0.22961	 0.00344	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49120	 92091	 0.027102	 0.10427	 0.00178	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49121	 49122	 0.046034	 0.043169	 0.00067	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49121	 92091	 0.10098	 0.079915	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49122	 92091	 0.044767	 0.032936	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49123	 92091	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49123	 92091	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49124	 92092	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49124	 92092	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49125	 49126	 0.031399	 0.11217	 0.00223	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92092	 49126	 0.082203	 0.13655	 0.00289	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49127	 49424	 0.019546	 0.056068	 0.0138	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49128	 49131	 0.042973	 0.085083	 0.00125	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91959	 49128	 0.10437	 0.26549	 0.0042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49128	 92094	 0.026346	 0.067726	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49129	 49131	 0.066526	 0.15446	 0.0023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49129	 92192	 0.13849	 0.31827	 0.00484	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91205	 49130	 0.089184	 0.070581	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91205	 49131	 0.039766	 0.15471	 0.00258	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91205	 49131	 0.039766	 0.15471	 0.00258	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49131	 92094	 0.004091	 0.025153	 0.00045	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49132	 92093	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92094	 49132	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 0	 -30.0	 30.0;
	49132	 92449	 0.009008	 0.075322	 0.13112	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49133	 49134	 0.003101	 0.019244	 0.00466	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49134	 49135	 0.004553	 0.024133	 0.00805	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49135	 49720	 0.044494	 0.13127	 0.03057	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49135	 92095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49135	 92095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49135	 92259	 0.004455	 0.043527	 0.01222	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49136	 49137	 0.031345	 0.080577	 0.00125	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49136	 49138	 0.14089	 0.25426	 0.00368	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91951	 49136	 0.060414	 0.26926	 0.00457	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49137	 49138	 0.19727	 0.19928	 0.00264	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91950	 49138	 0.2786	 0.30357	 0.00413	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49139	 49140	 0.01052	 0.049795	 0.01197	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91210	 49139	 0.013776	 0.088764	 0.02328	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92012	 49139	 0.014179	 0.055734	 0.01458	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49139	 92096	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49139	 92096	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49140	 49943	 0.060573	 0.15743	 0.03826	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92096	 49141	 0.053231	 0.1054	 0.00155	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49142	 49149	 0.002281	 0.024327	 0.04948	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49142	 49149	 0.002281	 0.024327	 0.04948	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49142	 49994	 0.001797	 0.019826	 0.03767	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49142	 49994	 0.001797	 0.019826	 0.03767	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49143	 92097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49143	 92097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49144	 92102	 0.089944	 0.1781	 0.00261	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49145	 49549	 0.021136	 0.062322	 0.0145	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49145	 92098	 0.009854	 0.033201	 0.00825	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49146	 49149	 0.000702	 0.004555	 0.00907	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49146	 92098	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49146	 92098	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49147	 49149	 0.002287	 0.015057	 0.02913	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91366	 49147	 0.01426	 0.097543	 0.17638	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49147	 92099	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92100	 49147	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91246	 49148	 0.00693	 0.017814	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49149	 92101	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92102	 49149	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49150	 50010	 0.010304	 0.041256	 0.01039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91201	 49150	 0.010013	 0.043586	 0.01242	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49151	 49152	 0.002136	 0.02051	 0.00597	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49151	 92104	 0.004638	 0.047262	 0.01218	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49152	 49731	 0.004413	 0.02585	 0.00704	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49152	 92103	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49152	 92103	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49153	 92104	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49153	 92104	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49153	 92400	 0.000782	 0.008072	 0.12686	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49153	 92400	 0.000782	 0.008072	 0.12686	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91192	 49154	 0.003418	 0.013151	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92035	 49154	 0.010931	 0.027798	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49154	 92151	 0.003886	 0.01192	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49155	 49158	 0.035699	 0.028251	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49155	 49318	 0.020958	 0.041075	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49155	 92105	 0.011771	 0.009227	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49155	 92153	 0.005433	 0.013967	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49156	 49157	 0.000787	 0.00208	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49156	 92105	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49156	 92105	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49156	 92152	 0.001388	 0.004762	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49157	 92106	 0.002009	 0.00547	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49158	 92107	 0.016832	 0.011923	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49159	 49278	 0.001115	 0.012479	 0.11663	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49159	 92106	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49160	 49314	 0.000363	 0.001244	 0.0003	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49160	 49319	 0.00054	 0.001853	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49161	 49166	 0.000896	 0.003902	 0.00111	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92106	 49161	 0.000783	 0.003802	 0.00087	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92105	 49162	 0.004904	 0.012605	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49162	 92108	 0.00554	 0.014242	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49162	 92153	 0.011582	 0.026885	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49163	 49164	 0.00655	 0.012968	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49164	 92153	 0.007018	 0.03739	 0.00066	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49165	 92108	 0.008421	 0.009343	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49166	 49167	 0.000764	 0.003507	 0.0009	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49166	 92108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49166	 92108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49167	 49326	 0.000511	 0.002048	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49168	 49322	 0.004882	 0.01156	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49168	 49328	 0.003601	 0.008526	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49169	 49178	 0.004382	 0.007707	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49169	 49327	 0.00355	 0.009124	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49170	 92155	 0.005663	 0.011589	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49170	 92157	 0.004252	 0.007788	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49171	 49320	 0.00021	 0.001417	 0.00261	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91207	 49171	 0.005608	 0.038267	 0.06894	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49171	 92109	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92110	 49171	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49172	 49329	 0.005087	 0.009144	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92110	 49172	 0.00579	 0.015345	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49173	 49187	 0.004234	 0.008383	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49173	 49340	 0.003209	 0.008249	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49174	 49175	 0.00044	 0.002017	 0.00052	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49174	 49324	 0.000668	 0.003118	 0.00077	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49174	 92111	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49174	 92111	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49175	 49331	 0.00049	 0.002319	 0.00056	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49175	 92112	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49175	 92112	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49176	 49178	 0.011593	 0.009087	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92111	 49176	 0.011621	 0.008401	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49177	 49179	 0.011599	 0.009179	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92112	 49177	 0.011628	 0.009202	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49178	 49179	 0.002043	 0.007859	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49178	 49328	 0.00579	 0.014882	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49179	 49180	 0.007557	 0.009932	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49179	 49183	 0.002249	 0.011981	 0.00021	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49180	 92113	 0.006492	 0.012854	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49181	 49326	 0.000769	 0.003253	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49181	 49333	 0.001352	 0.004894	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49181	 92113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49181	 92113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49182	 49183	 0.011085	 0.007177	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49183	 92114	 0.003849	 0.012394	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49184	 49185	 0.000774	 0.003223	 0.00101	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49184	 49194	 0.000698	 0.003142	 0.00084	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49184	 92114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49184	 92114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49185	 49331	 0.000606	 0.002869	 0.00069	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49185	 92115	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49185	 92115	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49186	 49187	 0.009456	 0.009458	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49186	 92159	 0.014537	 0.019106	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49187	 49340	 0.006185	 0.014356	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92115	 49187	 0.008747	 0.006922	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49187	 92117	 0.00832	 0.021388	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49188	 49189	 0.005114	 0.010022	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49188	 92116	 0.008573	 0.00672	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49189	 92159	 0.00349	 0.008875	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49190	 49202	 0.00815	 0.014648	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49190	 92116	 0.004172	 0.009685	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49191	 49192	 0.000865	 0.002967	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49191	 49330	 0.000786	 0.003605	 0.00092	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49191	 92116	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49191	 92116	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49192	 49194	 0.001941	 0.00499	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49192	 49204	 0.00168	 0.007566	 0.00201	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92109	 49192	 0.002664	 0.011994	 0.00319	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49192	 92117	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49192	 92117	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92117	 49193	 0.016687	 0.013206	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49193	 92118	 0.011608	 0.009187	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49194	 49198	 0.000878	 0.004028	 0.00103	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49194	 92118	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49194	 92118	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92118	 49195	 0.013495	 0.01068	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49196	 49197	 0.003475	 0.012412	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49196	 49348	 0.013224	 0.030701	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49196	 92160	 0.004064	 0.023103	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49197	 49206	 0.006694	 0.0137	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49198	 49205	 0.000853	 0.0038	 0.00103	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49198	 92119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49198	 92119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49199	 49200	 0.004095	 0.007202	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92119	 49199	 0.005657	 0.008281	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49199	 92121	 0.006927	 0.017194	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49200	 49201	 0.003211	 0.008166	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49201	 49202	 0.010733	 0.009617	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92117	 49201	 0.006229	 0.01475	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49203	 92120	 0.020689	 0.016373	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49204	 49209	 0.000897	 0.003525	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49204	 92120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49204	 92120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49205	 49208	 0.000882	 0.00397	 0.00106	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49205	 92121	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49205	 92121	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49206	 49207	 0.00483	 0.012283	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92121	 49206	 0.010706	 0.018035	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49207	 92124	 0.012371	 0.022236	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49208	 49209	 0.001614	 0.004264	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49208	 49213	 0.001313	 0.004755	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49208	 49214	 0.002188	 0.005625	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49209	 50759	 0.002042	 0.008176	 0.00206	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49209	 92122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49209	 92122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49210	 49211	 0.008529	 0.01539	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92120	 49210	 0.007193	 0.019925	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49211	 49212	 0.015357	 0.013125	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92122	 49212	 0.005078	 0.014563	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49212	 92123	 0.023004	 0.015453	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49213	 92123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49213	 92123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92034	 49214	 0.010068	 0.046192	 0.01183	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49214	 92124	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49214	 92124	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49215	 49220	 0.028587	 0.022623	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92123	 49215	 0.007135	 0.014126	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49216	 49217	 0.016712	 0.0131	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49216	 49219	 0.005686	 0.018968	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92123	 49216	 0.003524	 0.020032	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49216	 92901	 0.016886	 0.039204	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49218	 49219	 0.008162	 0.012504	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49218	 49221	 0.006195	 0.024099	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92124	 49218	 0.011205	 0.039231	 0.00109	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49220	 92125	 0.037354	 0.028652	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49221	 49266	 0.011613	 0.026961	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49221	 49335	 0.008999	 0.017816	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92124	 49222	 0.028247	 0.02853	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49222	 92125	 0.02286	 0.024899	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49223	 49224	 0.001628	 0.004303	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49223	 92125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49223	 92125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49224	 49260	 0.003245	 0.008575	 0.00201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49225	 49245	 0.001675	 0.005747	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49225	 49325	 0.001932	 0.009146	 0.0022	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49225	 92126	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49225	 92126	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92126	 49226	 0.03072	 0.031028	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49226	 92134	 0.019563	 0.015482	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49227	 49240	 0.00503	 0.019568	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49227	 92134	 0.009684	 0.021967	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49228	 92127	 0.011768	 0.023299	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49228	 92130	 0.00856	 0.019873	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49229	 49230	 0.001169	 0.004234	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49229	 49237	 0.002758	 0.008997	 0.00239	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91185	 49229	 0.000899	 0.008632	 0.00251	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49229	 92127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49229	 92127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49230	 49231	 0.00225	 0.006041	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49230	 49237	 0.003192	 0.007692	 0.00217	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49231	 92128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49231	 92128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49232	 49233	 0.008879	 0.023472	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49232	 49305	 0.023715	 0.026313	 0.00051	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91186	 49232	 0.017481	 0.077463	 0.00233	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49233	 49234	 0.025829	 0.020441	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92128	 49233	 0.003841	 0.014943	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92128	 49234	 0.045471	 0.035985	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49234	 92148	 0.023474	 0.046476	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49235	 49236	 0.024958	 0.019752	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49236	 92129	 0.004873	 0.01263	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49237	 92129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49237	 92129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49238	 49239	 0.000881	 0.004043	 0.00104	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91185	 49238	 0.001952	 0.012766	 0.00325	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49238	 92130	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49238	 92130	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49239	 49241	 0.001752	 0.005164	 0.0012	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49239	 92131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49239	 92131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92131	 49240	 0.003039	 0.01483	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49241	 49242	 0.001388	 0.003669	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49241	 92132	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49241	 92132	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49242	 92133	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49242	 92133	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92133	 49243	 0.008092	 0.0208	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92133	 49244	 0.018289	 0.03081	 0.00044	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49245	 49247	 0.001466	 0.005028	 0.0012	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49245	 92134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49245	 92134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49246	 49338	 0.023698	 0.031146	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92134	 49246	 0.006187	 0.012661	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49247	 92135	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49247	 92135	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49248	 49249	 0.029318	 0.029612	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49248	 49250	 0.029384	 0.019023	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49248	 49297	 0.041351	 0.045482	 0.00061	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92135	 49248	 0.004364	 0.021295	 0.00037	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49249	 49251	 0.010127	 0.025755	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49249	 92145	 0.00619	 0.024079	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49251	 49253	 0.022497	 0.016552	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49252	 49253	 0.02296	 0.017395	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49252	 49254	 0.028228	 0.02234	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49252	 49334	 0.018332	 0.028078	 0.00049	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49254	 49255	 0.011647	 0.02994	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49254	 92145	 0.011675	 0.038946	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49255	 49336	 0.00719	 0.017025	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92124	 49255	 0.01572	 0.043545	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49256	 49257	 0.009877	 0.01513	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92124	 49256	 0.034439	 0.068187	 0.001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49257	 49258	 0.012804	 0.013471	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49257	 49259	 0.005613	 0.010436	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49258	 49259	 0.025324	 0.020041	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49258	 49261	 0.015774	 0.012484	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49258	 49262	 0.023785	 0.023272	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49259	 49350	 0.01193	 0.030667	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49260	 49298	 0.008932	 0.027125	 0.00594	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49260	 92136	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49260	 92136	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49261	 49262	 0.00869	 0.013179	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49262	 49263	 0.006911	 0.016044	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49262	 49344	 0.020118	 0.039832	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92136	 49262	 0.008434	 0.021362	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49263	 49269	 0.010502	 0.017692	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49264	 49267	 0.013282	 0.033779	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92136	 49264	 0.002677	 0.011175	 0.00032	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92136	 49265	 0.020391	 0.046846	 0.00071	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49266	 49267	 0.010351	 0.017194	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49268	 49269	 0.009807	 0.017695	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91209	 49270	 0.041219	 0.060064	 0.00136	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91222	 49270	 0.01374	 0.025167	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49270	 92142	 0.14501	 0.10272	 0.00162	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49271	 49343	 0.040517	 0.032065	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49271	 92139	 0.022243	 0.040134	 0.00058	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49272	 49273	 0.001054	 0.004218	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49272	 49298	 0.001368	 0.005648	 0.00134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49273	 49276	 0.001913	 0.00892	 0.00221	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49273	 92137	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49273	 92137	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49274	 49344	 0.016166	 0.041113	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49274	 49350	 0.012279	 0.031228	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92137	 49274	 0.003286	 0.018679	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49275	 92138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49275	 92138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49275	 92140	 0.001821	 0.007412	 0.00181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49276	 92139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49276	 92139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49276	 92140	 0.001951	 0.00895	 0.00229	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49277	 49346	 0.013773	 0.018102	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92138	 49277	 0.019408	 0.020726	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49278	 92140	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49279	 49282	 0.008256	 0.021223	 0.00526	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49279	 92142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49279	 92142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92142	 49280	 0.02033	 0.043565	 0.00076	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49280	 92192	 0.1088	 0.21545	 0.00316	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49281	 49282	 0.002887	 0.008978	 0.00187	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92140	 49281	 0.002137	 0.008123	 0.00227	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49282	 92143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49282	 92143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49283	 49284	 0.089611	 0.070919	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49283	 49291	 0.093938	 0.067909	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49283	 49292	 0.09303	 0.073624	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49284	 49285	 0.013856	 0.035239	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49284	 49309	 0.030154	 0.076686	 0.00121	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49285	 49286	 0.060836	 0.072828	 0.00121	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49285	 49439	 0.054937	 0.10877	 0.0016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49286	 49289	 0.013237	 0.032854	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49287	 92144	 0.017667	 0.045415	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49288	 92144	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49288	 92144	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49289	 49291	 0.037644	 0.029791	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49289	 49293	 0.044847	 0.035492	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92144	 49289	 0.005872	 0.020058	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49290	 49293	 0.039383	 0.03087	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49290	 49307	 0.011953	 0.023665	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49290	 49347	 0.011797	 0.023357	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92144	 49290	 0.0126	 0.03239	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49291	 49292	 0.02627	 0.026533	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49292	 49294	 0.017821	 0.04581	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49293	 49351	 0.01676	 0.032847	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49294	 49351	 0.009175	 0.017776	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92143	 49294	 0.004759	 0.02668	 0.00074	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49295	 49296	 0.043517	 0.043953	 0.00058	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49295	 49300	 0.017846	 0.024871	 0.00043	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49296	 49341	 0.013747	 0.045365	 0.00073	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49296	 49345	 0.029742	 0.023537	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49297	 49338	 0.035044	 0.027469	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92141	 49297	 0.029803	 0.091432	 0.00248	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49298	 92145	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49298	 92145	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49299	 49300	 0.014538	 0.028783	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49299	 49301	 0.004716	 0.018142	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49300	 49304	 0.014431	 0.025378	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49300	 92161	 0.0465	 0.11954	 0.00185	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92133	 49301	 0.003588	 0.01866	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49302	 49303	 0.01406	 0.011021	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49303	 49305	 0.018137	 0.035909	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91240	 49305	 0.00471	 0.022985	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49306	 49339	 0.005556	 0.015494	 0.00325	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49306	 92146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49306	 92146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92146	 49307	 0.013416	 0.034488	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91228	 49308	 0.02382	 0.050855	 0.00115	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92146	 49308	 0.11272	 0.12398	 0.00165	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49308	 92161	 0.042284	 0.05764	 0.00128	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91228	 49309	 0.022641	 0.11048	 0.00191	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92146	 49309	 0.17146	 0.13441	 0.00173	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92144	 49310	 0.045908	 0.036331	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92146	 49310	 0.030727	 0.046603	 0.00067	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92144	 49311	 0.023594	 0.031009	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49312	 49339	 0.006665	 0.019958	 0.0045	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49312	 92147	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49312	 92147	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49313	 92148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49313	 92148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49314	 92149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49314	 92149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92110	 49315	 0.004162	 0.010787	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49315	 92155	 0.005232	 0.015746	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49315	 93048	 0.008887	 0.020632	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49316	 49320	 0.000213	 0.001925	 0.00379	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91191	 49316	 0.000149	 0.002053	 0.00409	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49316	 92150	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92151	 49316	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91191	 49317	 0.000628	 0.004188	 0.00789	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49317	 92152	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92153	 49317	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92130	 49318	 0.01494	 0.018212	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92131	 49318	 0.020066	 0.028485	 0.00047	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49319	 49321	 0.000433	 0.002047	 0.00049	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49319	 92154	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49319	 92154	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92033	 49320	 0.000588	 0.004979	 0.0097	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49320	 92155	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49320	 92155	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92150	 49321	 0.000595	 0.002651	 0.00072	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49322	 49327	 0.006225	 0.017854	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92108	 49322	 0.00573	 0.011229	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92151	 49322	 0.004844	 0.018844	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49322	 92156	 0.007317	 0.011679	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49323	 49324	 0.000872	 0.004126	 0.00099	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92150	 49323	 0.000687	 0.003092	 0.00082	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49323	 92156	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49323	 92156	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92109	 49324	 0.001606	 0.004504	 0.00116	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49324	 92157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49324	 92157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49325	 49333	 0.002306	 0.005987	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91185	 49325	 0.002333	 0.020009	 0.00569	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49325	 92158	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49325	 92158	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92157	 49328	 0.008894	 0.007321	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92109	 49330	 0.001543	 0.006949	 0.00185	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49330	 92159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49330	 92159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92131	 49332	 0.018599	 0.018992	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49333	 92160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49333	 92160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49334	 49348	 0.009639	 0.019726	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92124	 49334	 0.05465	 0.040208	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49337	 49348	 0.008001	 0.020347	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92126	 49337	 0.008821	 0.018052	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49339	 92161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49339	 92161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92110	 49340	 0.002424	 0.013781	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92137	 49341	 0.01645	 0.042287	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92138	 49341	 0.008687	 0.022514	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92141	 49341	 0.021008	 0.053427	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92138	 49342	 0.006004	 0.012287	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92139	 49342	 0.010618	 0.019085	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92143	 49346	 0.025634	 0.050752	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92158	 49349	 0.028511	 0.022563	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49352	 49354	 0.002778	 0.011757	 0.00265	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49352	 49361	 0.002214	 0.006527	 0.00152	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49352	 92162	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49352	 92162	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49352	 92164	 0.005616	 0.020335	 0.00436	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92162	 49353	 0.010753	 0.024965	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49353	 92163	 0.014097	 0.027911	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49354	 49366	 0.003903	 0.016517	 0.00372	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49354	 92163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49354	 92163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49355	 49356	 0.030864	 0.030954	 0.0005	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49355	 49528	 0.017662	 0.045403	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49355	 92165	 0.032999	 0.11008	 0.00175	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49355	 92168	 0.030069	 0.077297	 0.0012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49356	 49357	 0.004137	 0.012692	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49357	 49358	 0.011158	 0.020133	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49357	 92166	 0.003635	 0.020663	 0.00037	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49358	 49359	 0.005227	 0.011953	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49359	 92165	 0.007063	 0.043425	 0.00078	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91266	 49360	 0.013494	 0.087816	 0.17557	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49360	 92164	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92165	 49360	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92164	 49361	 0.002685	 0.01252	 0.0031	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49361	 92166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49361	 92166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92166	 49362	 0.029563	 0.023395	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49363	 49364	 0.002924	 0.015542	 0.00361	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92164	 49363	 0.002797	 0.014288	 0.00359	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91200	 49364	 0.011607	 0.054941	 0.01321	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92163	 49365	 0.024572	 0.04865	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49366	 49373	 0.007889	 0.027604	 0.00915	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49367	 49369	 0.003231	 0.009526	 0.00222	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49367	 49373	 0.016519	 0.043661	 0.01022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49367	 92167	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49367	 92167	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91234	 49368	 0.019124	 0.023313	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49368	 92169	 0.041132	 0.11797	 0.00181	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49369	 49370	 0.007076	 0.0187	 0.00438	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91206	 49370	 0.013728	 0.055872	 0.01362	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49370	 92168	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49370	 92168	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49371	 92169	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49371	 92169	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92167	 49372	 0.1492	 0.16412	 0.00219	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91200	 49373	 0.004364	 0.033191	 0.01043	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49374	 49375	 0.050513	 0.049621	 0.00084	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49375	 49386	 0.018375	 0.071761	 0.00159	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91216	 49375	 0.014708	 0.066767	 0.00145	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49375	 92181	 0.014598	 0.097563	 0.00216	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49376	 49383	 0.001457	 0.005536	 0.00155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91215	 49376	 0.001415	 0.011296	 0.00278	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49376	 92170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49376	 92170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49377	 49898	 0.001139	 0.005227	 0.00134	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49377	 92171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49377	 92171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49378	 49381	 0.038397	 0.027757	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49379	 49401	 0.015157	 0.058965	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91216	 49379	 0.013476	 0.047154	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91216	 49379	 0.013476	 0.047154	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49379	 92182	 0.035314	 0.12365	 0.00342	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91216	 49380	 0.004321	 0.018929	 0.00041	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49380	 92356	 0.009476	 0.041753	 0.00073	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49381	 49382	 0.008057	 0.01543	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92170	 49382	 0.006795	 0.030276	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49383	 92172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49383	 92172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49384	 49389	 0.01455	 0.041731	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92172	 49384	 0.009581	 0.027189	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49385	 49388	 0.010132	 0.021712	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49385	 49918	 0.015389	 0.039558	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49386	 49387	 0.008448	 0.027091	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49387	 92175	 0.011129	 0.03894	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49388	 49389	 0.013396	 0.030053	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49388	 49922	 0.011408	 0.043888	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49389	 92173	 0.012974	 0.033351	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49390	 92176	 0.009722	 0.022567	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49391	 49393	 0.002745	 0.009156	 0.00232	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49391	 92173	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49391	 92173	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49391	 92174	 0.005337	 0.018309	 0.00439	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49392	 49399	 0.001395	 0.008836	 0.0185	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49392	 49921	 0.002092	 0.014191	 0.02584	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49392	 92174	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92175	 49392	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49393	 92176	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49393	 92176	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49394	 49919	 0.003041	 0.012175	 0.00307	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92174	 49394	 0.002444	 0.009781	 0.0033	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49395	 49396	 0.018745	 0.075014	 0.00158	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49395	 92178	 0.030073	 0.08534	 0.00134	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49395	 92398	 0.054416	 0.30941	 0.0056	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49396	 92364	 0.014025	 0.059357	 0.00112	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49397	 49410	 0.007256	 0.026397	 0.00808	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49397	 92177	 0.001505	 0.01629	 0.00686	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49397	 92184	 0.004104	 0.029525	 0.00782	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49398	 92178	 0.056946	 0.057518	 0.00076	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49399	 92177	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92178	 49399	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49400	 49403	 0.000201	 0.00233	 0.02476	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91183	 49400	 0.00068	 0.006857	 0.11287	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91183	 49400	 0.00068	 0.006857	 0.11287	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 0	 -30.0	 30.0;
	49401	 92181	 0.014873	 0.053131	 0.00105	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49402	 92181	 0.027206	 0.04983	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49403	 92179	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49404	 49405	 0.000784	 0.006302	 0.00177	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49404	 49415	 0.00253	 0.019717	 0.0059	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49405	 49406	 0.00098	 0.005881	 0.00178	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49405	 92182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49405	 92182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92180	 49406	 0.002098	 0.013018	 0.00315	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92182	 49407	 0.014422	 0.033483	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49407	 92185	 0.026316	 0.053854	 0.00133	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49408	 49411	 0.000379	 0.004289	 0.03905	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91183	 49408	 0.00085	 0.009806	 0.08598	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49408	 92183	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49409	 49410	 0.006381	 0.025546	 0.00644	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49409	 92187	 0.004322	 0.018294	 0.00412	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49411	 92186	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49412	 49413	 0.003136	 0.017268	 0.00623	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49412	 49415	 0.009189	 0.035751	 0.00955	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49412	 92189	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49412	 92189	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49413	 49728	 0.004609	 0.029194	 0.00792	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49414	 92190	 0.13324	 0.10545	 0.00133	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91184	 49415	 0.002514	 0.020196	 0.00568	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49415	 92190	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49415	 92190	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49416	 92191	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49416	 92191	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49416	 92193	 0.009295	 0.031888	 0.00764	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49417	 49423	 0.020559	 0.057679	 0.01485	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49417	 92192	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49417	 92192	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91207	 49418	 0.004366	 0.035093	 0.07616	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49418	 92193	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92194	 49418	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49419	 49423	 0.011305	 0.040937	 0.00878	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92193	 49419	 0.006995	 0.019623	 0.00505	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49419	 92195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49419	 92195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92194	 49420	 0.043134	 0.088273	 0.00217	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92195	 49420	 0.012631	 0.03247	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49420	 92196	 0.053453	 0.13741	 0.00213	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92194	 49421	 0.05099	 0.085898	 0.00122	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92195	 49421	 0.032394	 0.023418	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92195	 49422	 0.069025	 0.14127	 0.00348	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49422	 92196	 0.012567	 0.024348	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49422	 92249	 0.050904	 0.12946	 0.00205	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49422	 92250	 0.11218	 0.26049	 0.00387	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92093	 49423	 0.017791	 0.072413	 0.01765	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49424	 49562	 0.007722	 0.033609	 0.00958	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92193	 49424	 0.006772	 0.056347	 0.01707	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49424	 92196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49424	 92196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49425	 49426	 0.093022	 0.18232	 0.00273	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49425	 49472	 0.1228	 0.31576	 0.00489	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49427	 92200	 0.034569	 0.08186	 0.0015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49428	 49431	 0.002368	 0.015977	 0.02942	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49428	 50024	 0.003859	 0.025054	 0.04992	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49428	 92197	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49428	 92197	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49429	 49617	 0.009973	 0.084967	 0.02121	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92197	 49429	 0.007986	 0.031071	 0.0083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49429	 92198	 0.003924	 0.015712	 0.00396	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49430	 92199	 0.023011	 0.045559	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49431	 92198	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92199	 49431	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49432	 50015	 0.021653	 0.084264	 0.02252	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92198	 49432	 0.002268	 0.007937	 0.00263	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49432	 92200	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49432	 92200	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49433	 49438	 0.05566	 0.11699	 0.00213	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49433	 49633	 0.15087	 0.18731	 0.00408	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49434	 49435	 0.013398	 0.043701	 0.0116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49434	 49436	 0.014732	 0.038936	 0.00911	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49434	 92201	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49434	 92201	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49435	 49943	 0.020075	 0.053061	 0.01242	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49436	 92202	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49436	 92202	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49437	 49438	 0.23604	 0.23101	 0.00327	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92191	 49437	 0.098111	 0.15031	 0.00211	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92202	 49437	 0.10999	 0.10315	 0.00159	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49438	 49439	 0.10204	 0.080755	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91222	 49438	 0.13176	 0.33882	 0.00525	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91228	 49438	 0.054081	 0.25222	 0.00581	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49438	 92370	 0.48152	 0.53021	 0.00708	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49440	 92203	 0.034243	 0.10505	 0.00285	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49441	 92203	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49441	 92203	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49442	 49443	 0.005801	 0.027056	 0.0067	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49442	 92204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49442	 92204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49444	 49446	 0.025814	 0.086114	 0.00137	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92203	 49444	 0.029639	 0.10378	 0.00287	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49445	 92205	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49445	 92205	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92205	 49446	 0.006479	 0.025206	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49447	 49448	 0.095713	 0.22224	 0.00331	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49447	 49483	 0.18391	 0.4272	 0.00636	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92023	 49447	 0.09395	 0.3135	 0.00497	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49448	 49449	 0.13287	 0.17293	 0.00242	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49448	 49450	 0.31222	 0.30181	 0.00438	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49448	 92376	 0.087179	 0.44394	 0.01007	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49449	 49450	 0.25124	 0.19697	 0.00253	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49449	 49485	 0.36099	 0.349	 0.00507	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49450	 49483	 0.16751	 0.25666	 0.0036	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49451	 49456	 0.090865	 0.17992	 0.00264	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49451	 49457	 0.096384	 0.16952	 0.00319	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49451	 92254	 0.03898	 0.14998	 0.00256	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49452	 50001	 0.05026	 0.12303	 0.0021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49452	 92208	 0.16401	 0.16568	 0.00219	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49453	 49454	 0.008152	 0.035484	 0.01011	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49453	 49584	 0.014577	 0.066887	 0.01714	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91177	 49453	 0.015531	 0.16482	 0.04902	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49453	 92206	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49453	 92206	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49454	 49455	 0.009383	 0.032189	 0.00771	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49454	 92207	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49454	 92207	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49455	 49709	 0.005856	 0.022783	 0.00609	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49455	 92208	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49455	 92208	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49456	 49457	 0.041732	 0.10728	 0.00166	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92206	 49456	 0.083858	 0.19468	 0.00371	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92207	 49456	 0.031507	 0.080993	 0.00125	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92208	 49456	 0.053453	 0.1241	 0.00185	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49457	 49705	 0.071166	 0.15252	 0.00267	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49458	 49461	 0.10475	 0.17648	 0.00251	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49458	 49980	 0.25647	 0.39309	 0.00552	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49459	 49460	 0.24162	 0.19125	 0.00241	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49459	 49461	 0.30459	 0.24113	 0.00304	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49459	 49463	 0.19235	 0.19295	 0.00312	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49460	 49461	 0.038751	 0.069651	 0.00125	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49461	 49462	 0.049869	 0.11578	 0.00172	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91211	 49461	 0.1332	 0.43983	 0.00713	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92091	 49463	 0.40585	 0.32136	 0.00405	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49463	 92209	 0.029214	 0.094075	 0.0016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91237	 49464	 0.01571	 0.052407	 0.00083	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49465	 49466	 0.016183	 0.024262	 0.00044	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91237	 49466	 0.001066	 0.004359	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49466	 92209	 0.009266	 0.021287	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49467	 92209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49467	 92209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49468	 49535	 0.022277	 0.059816	 0.01356	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49468	 92210	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49468	 92210	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49469	 49471	 0.013193	 0.035921	 0.00791	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49469	 49532	 0.015226	 0.038277	 0.00992	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49470	 49471	 0.008278	 0.028965	 0.0096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91058	 49470	 0.020684	 0.078645	 0.02202	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49470	 92211	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49470	 92211	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49471	 49533	 0.020296	 0.053646	 0.01256	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49471	 92212	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49471	 92212	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49472	 49475	 0.053008	 0.18939	 0.00376	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49473	 92213	 0.28162	 0.22293	 0.00281	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49474	 49476	 0.00901	 0.025127	 0.00527	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91210	 49474	 0.012686	 0.06005	 0.01444	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49474	 92213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49474	 92213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92213	 49475	 0.017984	 0.087757	 0.00151	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49475	 92214	 0.029976	 0.077057	 0.00119	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49476	 49962	 0.032284	 0.11696	 0.02511	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91210	 49476	 0.008064	 0.054105	 0.01306	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49476	 92214	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49476	 92214	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49477	 49478	 0.000464	 0.004679	 0.07701	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49477	 49478	 0.000464	 0.004679	 0.07701	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49477	 50011	 0.000931	 0.009938	 0.14597	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49477	 50011	 0.000931	 0.009938	 0.14597	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49478	 49732	 0.000418	 0.005292	 0.09241	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49478	 92215	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92216	 49479	 0.11319	 0.09317	 0.00189	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49480	 49547	 0.084736	 0.15521	 0.00268	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92067	 49480	 0.13277	 0.2237	 0.00319	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49481	 49482	 0.059933	 0.15407	 0.00238	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49481	 92239	 0.049985	 0.19448	 0.00325	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49482	 49576	 0.055612	 0.12912	 0.00192	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49483	 49485	 0.032081	 0.056419	 0.00106	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49483	 49486	 0.11575	 0.11692	 0.00155	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49483	 92217	 0.06523	 0.1335	 0.00329	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49484	 92376	 0.24765	 0.26394	 0.00376	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49485	 49486	 0.19267	 0.1525	 0.00192	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49486	 49490	 0.019518	 0.049637	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49487	 92217	 0.023462	 0.023467	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49488	 49490	 0.011225	 0.017196	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49489	 49622	 0.006612	 0.025724	 0.00687	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49489	 92217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49489	 92217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49490	 49623	 0.03086	 0.1235	 0.00261	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92217	 49490	 0.011168	 0.036854	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49491	 49492	 0.058166	 0.14793	 0.00234	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49491	 49620	 0.13424	 0.24592	 0.00425	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92092	 49492	 0.08301	 0.21341	 0.0033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49493	 49546	 0.018183	 0.086082	 0.02071	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49493	 49611	 0.018521	 0.075383	 0.01837	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49493	 92218	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49493	 92218	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49494	 92220	 0.006407	 0.062779	 0.00123	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49495	 49516	 0.11266	 0.08831	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91247	 49495	 0.022856	 0.073294	 0.00181	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91247	 49495	 0.022856	 0.073294	 0.00181	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49495	 92220	 0.021093	 0.064709	 0.00175	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49495	 92220	 0.021093	 0.064709	 0.00175	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49496	 92219	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49496	 92219	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49497	 49504	 0.011989	 0.055007	 0.01409	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49497	 92220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49497	 92220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49498	 49499	 0.037018	 0.07255	 0.00109	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49499	 92225	 0.065895	 0.2564	 0.00428	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49500	 49501	 0.074448	 0.11405	 0.0016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49501	 49519	 0.073543	 0.15052	 0.0037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49502	 49503	 0.010097	 0.029768	 0.00693	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49502	 92221	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49502	 92221	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49503	 49504	 0.005753	 0.026395	 0.00676	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49503	 92222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49503	 92222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49505	 49515	 0.076856	 0.2032	 0.00369	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91966	 49505	 0.18395	 0.47318	 0.00733	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49506	 49507	 0.1328	 0.17456	 0.00239	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49506	 92265	 0.07409	 0.15164	 0.00373	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49507	 49508	 0.088717	 0.17567	 0.00258	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49507	 92376	 0.27032	 0.27047	 0.00365	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49508	 92266	 0.10511	 0.21605	 0.00412	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91220	 49509	 0.0915	 0.2093	 0.00511	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91952	 49509	 0.37578	 0.29753	 0.00375	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49509	 92223	 0.030572	 0.11894	 0.00199	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91177	 49510	 0.007048	 0.082043	 0.02413	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49510	 92223	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49510	 92223	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49511	 50002	 0.016599	 0.086493	 0.02269	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49511	 50005	 0.017399	 0.081169	 0.02011	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91177	 49511	 0.008816	 0.054787	 0.01546	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49512	 50001	 0.05433	 0.11119	 0.00274	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92223	 49512	 0.027647	 0.14069	 0.00319	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49513	 49515	 0.042834	 0.094805	 0.00155	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92222	 49513	 0.11027	 0.28352	 0.00439	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49514	 49515	 0.032236	 0.10754	 0.0017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49514	 49517	 0.1191	 0.17858	 0.00324	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49515	 49517	 0.068901	 0.19554	 0.00307	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91992	 49517	 0.040541	 0.15773	 0.00263	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49518	 49954	 0.000347	 0.003806	 0.03697	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49518	 92224	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49518	 92228	 0.000799	 0.012687	 0.13327	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49519	 92227	 0.020098	 0.077323	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91181	 49520	 0.000302	 0.003484	 0.03054	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49520	 92226	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49520	 92228	 0.000474	 0.005179	 0.05084	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49521	 92228	 8.6e-05	 0.006874	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49521	 92228	 8.6e-05	 0.006874	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92230	 49521	 0.000144	 0.011532	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92230	 49522	 0.012209	 0.041137	 0.01022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49523	 49550	 0.000146	 0.002441	 0.15945	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49523	 92231	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49523	 92231	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49524	 49525	 0.002539	 0.006817	 0.00155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49524	 49533	 0.006475	 0.017114	 0.00401	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49525	 49526	 0.003604	 0.009356	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49526	 49531	 0.010731	 0.033373	 0.00696	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49526	 92232	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49526	 92232	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49527	 49534	 0.009373	 0.032154	 0.0077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49527	 92233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49527	 92233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49529	 49530	 0.003466	 0.014309	 0.00339	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49529	 49531	 0.009095	 0.029665	 0.00788	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49529	 49532	 0.016888	 0.056908	 0.01414	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92164	 49529	 0.002478	 0.015238	 0.00439	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49530	 49533	 0.017135	 0.062055	 0.01332	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91206	 49530	 0.004083	 0.02321	 0.00672	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91058	 49533	 0.047834	 0.1562	 0.04153	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49534	 49535	 0.007564	 0.026363	 0.00611	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49534	 92234	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49534	 92234	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49536	 92235	 0.1404	 0.19935	 0.00328	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49537	 49538	 0.048087	 0.098825	 0.00188	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91951	 49537	 0.06491	 0.28606	 0.00497	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49537	 92235	 0.058865	 0.13524	 0.00205	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49538	 92235	 0.007361	 0.024556	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49539	 92235	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49539	 92235	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49540	 92236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49540	 92236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49541	 49542	 0.016869	 0.064134	 0.01796	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49541	 49960	 0.015262	 0.064603	 0.01454	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49541	 92237	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49541	 92237	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49542	 92238	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49542	 92238	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91233	 49544	 0.076625	 0.11737	 0.00204	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49545	 49547	 0.047485	 0.15292	 0.00261	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91233	 49545	 0.037129	 0.21109	 0.00382	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92041	 49546	 0.005804	 0.033995	 0.00926	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49546	 92239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49546	 92239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49548	 49988	 0.16059	 0.25063	 0.00419	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91096	 49548	 0.060448	 0.23166	 0.00655	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49548	 92240	 0.16783	 0.24463	 0.00553	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49549	 92240	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49549	 92240	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49550	 49554	 0.000208	 0.003469	 0.22661	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49550	 92241	 9.5e-05	 0.007586	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49550	 92241	 9.5e-05	 0.007586	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49551	 49554	 0.000157	 0.002029	 0.12951	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49551	 92242	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49552	 49553	 0.027629	 0.046543	 0.00066	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92244	 49553	 0.060874	 0.13809	 0.00276	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49554	 49555	 7.4e-05	 0.001322	 0.09386	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49556	 92247	 0.24951	 0.19562	 0.00251	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49556	 92248	 0.11207	 0.087851	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49557	 49723	 0.001556	 0.017082	 0.16604	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49557	 49724	 0.001185	 0.013002	 0.12635	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49557	 92245	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49557	 92245	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49558	 49559	 0.0022	 0.005815	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92246	 49558	 0.010441	 0.024236	 0.00738	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49558	 92248	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49558	 92248	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49559	 49560	 0.016119	 0.04185	 0.01016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91993	 49560	 0.013649	 0.037162	 0.00819	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49561	 92249	 0.059233	 0.19762	 0.00313	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49561	 92250	 0.033364	 0.14701	 0.00255	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49561	 92370	 0.053715	 0.25051	 0.00577	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49562	 49567	 0.009785	 0.033568	 0.00804	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49562	 92249	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49562	 92249	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49563	 49571	 0.009159	 0.037817	 0.00895	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49564	 49565	 0.075548	 0.097492	 0.00196	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49565	 92250	 0.02123	 0.065198	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49566	 49568	 0.018082	 0.0277	 0.00039	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49567	 49571	 0.001602	 0.005495	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49567	 92250	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49567	 92250	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49568	 49569	 0.018773	 0.020648	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92250	 49568	 0.005898	 0.022947	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92250	 49570	 0.01778	 0.042104	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49572	 49573	 0.005359	 0.013471	 0.00349	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49573	 49574	 0.01098	 0.031803	 0.00767	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49574	 49580	 0.0009	 0.005532	 0.0016	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49574	 92251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49574	 92251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49575	 49579	 0.0013	 0.008075	 0.00228	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92041	 49575	 0.042165	 0.17868	 0.04028	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49575	 92252	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49575	 92252	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92252	 49576	 0.039309	 0.090311	 0.00137	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49577	 49578	 0.009209	 0.047042	 0.01183	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49577	 92253	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49577	 92253	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49577	 92389	 0.014322	 0.065716	 0.01684	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49578	 49579	 0.002779	 0.014774	 0.00343	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49579	 49580	 0.001207	 0.00491	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49580	 49581	 0.001149	 0.019223	 0.0109	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49582	 49583	 0.034595	 0.088932	 0.00138	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49582	 92254	 0.23857	 0.24102	 0.00319	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49583	 49623	 0.24854	 0.30311	 0.00486	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91223	 49583	 0.018257	 0.087635	 0.00262	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91223	 49585	 0.012461	 0.02619	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49586	 92254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49586	 92254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49587	 92255	 0.006995	 0.026799	 0.00076	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92035	 49588	 0.016015	 0.053426	 0.00085	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92034	 49589	 0.005709	 0.020672	 0.00444	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49589	 92255	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49589	 92255	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49589	 93043	 0.003141	 0.011104	 0.0025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92255	 49590	 0.015758	 0.026546	 0.00038	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49591	 49596	 0.006295	 0.027581	 0.00059	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92255	 49591	 0.010322	 0.031066	 0.00061	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49592	 49601	 0.003797	 0.019078	 0.00496	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49592	 92256	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49592	 92256	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49594	 49598	 0.011695	 0.019702	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49595	 49596	 0.008117	 0.023282	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49595	 49599	 0.005755	 0.023031	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49595	 49602	 0.007372	 0.028363	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49595	 49602	 0.007372	 0.028363	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49596	 49598	 0.013208	 0.030664	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49597	 49598	 0.012229	 0.009678	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92255	 49598	 0.01973	 0.076755	 0.00128	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92256	 49598	 0.009861	 0.030251	 0.00082	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92256	 49598	 0.009861	 0.030251	 0.00082	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49599	 49600	 0.039145	 0.030979	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92255	 49599	 0.031811	 0.073083	 0.00111	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49601	 49604	 0.00107	 0.016862	 0.00575	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91239	 49602	 0.004202	 0.039123	 0.00076	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92256	 49602	 0.038448	 0.068674	 0.00101	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49603	 50890	 0.014345	 0.081545	 0.00148	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92031	 49603	 0.2501	 0.25023	 0.00338	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49603	 92257	 0.008219	 0.056415	 0.00103	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91179	 49604	 0.003001	 0.033963	 0.01907	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49604	 92257	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49604	 92257	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91179	 49605	 0.006205	 0.057772	 0.0179	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49605	 92258	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49605	 92258	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91180	 49606	 0.044886	 0.070038	 0.00117	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92010	 49607	 0.18224	 0.46876	 0.00726	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49607	 92260	 0.1246	 0.20054	 0.00314	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49608	 92259	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92260	 49608	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49609	 49610	 0.087675	 0.20357	 0.00303	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92088	 49609	 0.087398	 0.16253	 0.0038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91226	 49610	 0.052172	 0.2423	 0.00662	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49611	 49614	 0.008115	 0.032475	 0.01097	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49611	 92261	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49611	 92261	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92261	 49612	 0.16443	 0.16449	 0.00222	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92253	 49613	 0.034959	 0.079952	 0.00195	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49613	 92263	 0.024249	 0.068812	 0.00108	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49614	 49616	 0.003112	 0.01223	 0.0032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49614	 49617	 0.004961	 0.022758	 0.00583	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49615	 49616	 0.001977	 0.007915	 0.00199	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49615	 92262	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49615	 92262	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49615	 92389	 0.018068	 0.071028	 0.01859	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49616	 92263	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49616	 92263	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49617	 92264	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49617	 92264	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92264	 49618	 0.048169	 0.095373	 0.0014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92262	 49619	 0.036785	 0.072831	 0.00107	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91219	 49622	 0.014683	 0.094613	 0.02482	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91220	 49623	 0.059173	 0.29941	 0.00521	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49623	 92376	 0.25717	 0.50957	 0.00749	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91219	 49624	 0.019822	 0.052391	 0.01226	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49624	 92265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49624	 92265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92213	 49625	 0.11982	 0.25189	 0.00459	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49625	 92266	 0.14941	 0.11825	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49625	 92267	 0.18999	 0.1398	 0.00204	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91211	 49626	 0.084426	 0.12934	 0.00182	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91210	 49627	 0.003913	 0.050927	 0.01472	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49627	 92266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49627	 92266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49628	 92267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49628	 92267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49629	 49630	 0.097299	 0.10702	 0.00143	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92266	 49629	 0.007967	 0.030523	 0.00086	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92267	 49630	 0.041022	 0.087911	 0.00154	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49631	 92268	 0.099636	 0.18251	 0.00315	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49632	 49634	 0.015393	 0.06265	 0.01527	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49633	 92268	 0.050838	 0.13069	 0.00202	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49634	 92268	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49634	 92268	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91202	 49635	 0.093816	 0.18577	 0.00273	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49636	 92402	 0.17718	 0.23291	 0.00319	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49637	 92269	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49637	 92269	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 0	 -30.0	 30.0;
	49638	 92271	 0.25373	 0.20084	 0.00253	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49639	 92270	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92271	 49640	 0.17207	 0.12661	 0.00185	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91190	 49641	 0.025791	 0.086036	 0.00136	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49641	 92307	 0.028855	 0.055907	 0.0012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49642	 49643	 0.029955	 0.022978	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49643	 49645	 0.009242	 0.021453	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49644	 49645	 0.017083	 0.018789	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49644	 49650	 0.026088	 0.020646	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49645	 49646	 0.003841	 0.007861	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49645	 92273	 0.008266	 0.01514	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49646	 49648	 0.025679	 0.020322	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49646	 92273	 0.031977	 0.025306	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49646	 92317	 0.011499	 0.038358	 0.00061	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49647	 49649	 0.001125	 0.003861	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49647	 92272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49647	 92272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49647	 92316	 0.002818	 0.011074	 0.0029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92272	 49648	 0.00398	 0.010232	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49649	 49651	 0.001656	 0.004446	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49649	 92273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49649	 92273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49650	 49652	 0.062642	 0.049102	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49650	 92274	 0.009493	 0.018604	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49651	 49656	 0.002433	 0.006533	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49651	 92274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49651	 92274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49652	 49653	 0.029519	 0.023361	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49652	 92278	 0.007863	 0.026231	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92273	 49653	 0.042815	 0.043245	 0.00057	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92274	 49653	 0.025749	 0.024147	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92274	 49654	 0.006644	 0.013021	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49655	 49676	 0.011669	 0.016262	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92272	 49655	 0.018061	 0.03308	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92274	 49655	 0.032578	 0.025782	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49656	 49677	 0.001804	 0.004684	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49657	 49658	 0.011783	 0.023093	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49657	 49659	 0.018969	 0.019159	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49657	 49665	 0.040863	 0.032031	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49657	 49666	 0.027371	 0.021661	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49657	 92326	 0.02342	 0.04637	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49658	 49659	 0.004805	 0.012351	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49658	 92317	 0.017957	 0.041683	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49658	 92326	 0.016736	 0.031631	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92272	 49659	 0.00753	 0.017481	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49660	 49661	 0.005071	 0.025651	 0.00045	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49660	 49664	 0.066593	 0.052702	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49660	 92369	 0.008327	 0.054206	 0.0011	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49661	 49663	 0.005713	 0.019991	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49661	 92281	 0.009286	 0.024613	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49662	 49678	 0.002376	 0.00639	 0.00179	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49662	 49683	 0.002889	 0.008104	 0.00209	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49662	 92275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49662	 92275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49662	 92368	 0.00412	 0.022145	 0.00545	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49663	 92277	 0.006277	 0.021977	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49663	 92284	 0.016888	 0.038622	 0.00094	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49665	 49666	 0.011628	 0.01071	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49665	 49667	 0.021937	 0.021942	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49665	 92276	 0.009317	 0.030746	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49667	 49669	 0.008733	 0.015697	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49667	 49676	 0.011136	 0.027641	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92275	 49667	 0.010324	 0.033107	 0.00082	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49668	 92276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49668	 92276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49669	 49670	 0.009091	 0.015314	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92276	 49669	 0.017204	 0.036868	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49669	 92280	 0.006817	 0.015825	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92275	 49670	 0.007252	 0.020799	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92276	 49670	 0.014854	 0.027619	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49671	 49719	 0.00293	 0.011135	 0.00312	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49671	 92277	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49671	 92277	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49672	 49674	 0.002734	 0.015361	 0.00028	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92277	 49672	 0.003084	 0.017531	 0.00032	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49673	 92284	 0.017687	 0.035019	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49674	 49701	 0.015656	 0.02911	 0.00068	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49674	 92284	 0.008005	 0.018586	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49675	 49718	 0.002117	 0.005496	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49675	 92278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49675	 92278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49676	 49717	 0.020078	 0.016526	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49677	 49718	 0.002854	 0.009307	 0.00247	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49677	 92279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49677	 92279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49678	 92280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49678	 92280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49679	 49680	 0.009627	 0.01599	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92278	 49679	 0.011495	 0.020741	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92279	 49679	 0.034175	 0.027046	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92280	 49679	 0.005706	 0.019036	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49680	 49717	 0.022588	 0.015173	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49681	 49682	 0.007531	 0.025122	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49681	 49685	 0.0055	 0.012339	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92278	 49681	 0.013415	 0.020547	 0.00036	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49681	 92289	 0.015388	 0.015543	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49682	 49691	 0.010748	 0.022589	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49682	 92281	 0.010374	 0.026382	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49682	 92282	 0.018892	 0.048565	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49683	 92281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49683	 92281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49684	 49685	 0.005984	 0.013244	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92280	 49684	 0.006955	 0.014617	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92281	 49684	 0.009407	 0.019251	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49686	 92282	 0.013016	 0.025509	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49687	 49688	 0.002153	 0.013634	 0.0037	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49688	 49689	 0.000712	 0.005034	 0.00138	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49689	 49718	 0.002061	 0.014579	 0.004	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49689	 92282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49689	 92282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49689	 92285	 0.001212	 0.01039	 0.00296	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49690	 49692	 0.001112	 0.003628	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49690	 92283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49690	 92283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49690	 92285	 0.001146	 0.005256	 0.00135	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49691	 49696	 0.00387	 0.017243	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49692	 49693	 0.001205	 0.004133	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49693	 92284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49693	 92284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49694	 49695	 0.004571	 0.01175	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49694	 49696	 0.013894	 0.01245	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92283	 49695	 0.006202	 0.027636	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92284	 49696	 0.00572	 0.020434	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92281	 49697	 0.019319	 0.038251	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92284	 49697	 0.007427	 0.031897	 0.00058	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49698	 49705	 0.054787	 0.074748	 0.00134	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49698	 92286	 0.018602	 0.033226	 0.00049	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49699	 49932	 0.002679	 0.018272	 0.0329	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49699	 92285	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92286	 49699	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49700	 49701	 0.067006	 0.053028	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49700	 49707	 0.023435	 0.035544	 0.00051	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49700	 49711	 0.025323	 0.034518	 0.00077	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49701	 49702	 0.009008	 0.020914	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49701	 49704	 0.031745	 0.025122	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49701	 49715	 0.06457	 0.0511	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49702	 49707	 0.085722	 0.067841	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92286	 49702	 0.010494	 0.024849	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49703	 49704	 0.042898	 0.027772	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49703	 49711	 0.033812	 0.034151	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49703	 49715	 0.045521	 0.035681	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49705	 49707	 0.025814	 0.05993	 0.00089	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92208	 49705	 0.033767	 0.11265	 0.00179	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49706	 49708	 0.011687	 0.027133	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92208	 49706	 0.039521	 0.10051	 0.00159	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92286	 49706	 0.15923	 0.11512	 0.00175	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49707	 49713	 0.022551	 0.04615	 0.00114	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92286	 49707	 0.045357	 0.063213	 0.00108	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49708	 49713	 0.007996	 0.026674	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49708	 92287	 0.014625	 0.044018	 0.00086	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49709	 50003	 0.004003	 0.018364	 0.0047	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49709	 92287	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49709	 92287	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49710	 49713	 0.014311	 0.033224	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49710	 49716	 0.016615	 0.06392	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49711	 49713	 0.00631	 0.027962	 0.00084	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49712	 49713	 0.007294	 0.028374	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92287	 49712	 0.006169	 0.03507	 0.00063	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49714	 49719	 0.00855	 0.034232	 0.00862	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91188	 49714	 0.002851	 0.020506	 0.00543	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49714	 92288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49714	 92288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92277	 49715	 0.028922	 0.070793	 0.00121	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92288	 49716	 0.023145	 0.11168	 0.00197	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92279	 49717	 0.013624	 0.01333	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49718	 92289	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49718	 92289	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91204	 49720	 0.006671	 0.045449	 0.01548	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49720	 92290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49720	 92290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92010	 49721	 0.08519	 0.19574	 0.00297	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92290	 49721	 0.079962	 0.20338	 0.00322	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92095	 49722	 0.10429	 0.26813	 0.00415	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92290	 49722	 0.059937	 0.22488	 0.00404	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49723	 49724	 0.000785	 0.00808	 0.08953	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49723	 49734	 0.000336	 0.006432	 0.10849	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91183	 49723	 0.000469	 0.005941	 0.10375	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49723	 92291	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49723	 92291	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91183	 49724	 0.000932	 0.010178	 0.09994	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49724	 92292	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49724	 92292	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49725	 49726	 0.00878	 0.042612	 0.00974	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92292	 49725	 0.003744	 0.017462	 0.00433	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92215	 49726	 0.008794	 0.070662	 0.01987	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49726	 92293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49726	 92293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49727	 49733	 0.043085	 0.18985	 0.0033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92181	 49727	 0.071518	 0.27412	 0.00775	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92291	 49727	 0.027791	 0.097305	 0.00269	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49727	 92294	 0.016594	 0.073503	 0.00168	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49728	 49729	 0.001997	 0.01306	 0.00332	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49729	 49737	 0.00235	 0.019497	 0.00513	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49729	 92294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49729	 92294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49730	 49731	 0.005038	 0.028943	 0.0082	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49730	 49736	 0.001775	 0.00828	 0.00205	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49730	 92295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49730	 92295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49732	 49735	 0.000231	 0.003131	 0.04771	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49733	 92297	 0.00572	 0.021916	 0.00062	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49734	 49735	 4.8e-05	 0.000935	 0.01498	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49735	 92296	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49736	 49737	 0.002112	 0.008454	 0.00286	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92296	 49737	 0.007121	 0.033214	 0.00823	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49738	 92301	 0.017598	 0.041673	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49739	 49740	 0.000998	 0.004578	 0.00117	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49739	 49745	 0.001453	 0.007051	 0.00161	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49740	 50127	 0.001062	 0.004733	 0.00129	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49741	 49743	 0.002142	 0.00566	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49741	 92298	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49741	 92298	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49742	 49775	 0.006979	 0.016201	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49742	 92299	 0.007249	 0.01683	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49742	 92301	 0.007339	 0.028549	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49743	 49744	 0.001166	 0.004669	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49743	 92299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49743	 92299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49744	 49745	 0.001457	 0.005832	 0.00197	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49744	 92300	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49744	 92300	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91189	 49745	 0.003181	 0.026049	 0.01675	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49745	 92301	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49745	 92301	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49746	 49747	 0.009181	 0.015311	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92301	 49746	 0.038808	 0.030419	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92301	 49747	 0.006138	 0.01425	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49747	 92302	 0.012818	 0.02623	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49748	 49750	 0.010099	 0.025961	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49748	 92304	 0.010401	 0.030587	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49749	 49751	 0.001711	 0.00587	 0.00141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49749	 49752	 0.001654	 0.007448	 0.00198	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49749	 92302	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49749	 92302	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49750	 49762	 0.003246	 0.012626	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49750	 92303	 0.004405	 0.01963	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49751	 92303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49751	 92303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91189	 49752	 0.00326	 0.022615	 0.00645	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49752	 92304	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49752	 92304	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49753	 92305	 0.006405	 0.016931	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49753	 92307	 0.008547	 0.029925	 0.00083	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49753	 92308	 0.028573	 0.031427	 0.00042	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49754	 49755	 0.000816	 0.003807	 0.00094	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49754	 49757	 0.000602	 0.002808	 0.0007	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49755	 49759	 0.000681	 0.003224	 0.00078	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49755	 92305	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49755	 92305	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49756	 49757	 0.00044	 0.001962	 0.00053	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49756	 49760	 0.000913	 0.00443	 0.00101	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49756	 92306	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49756	 92306	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49758	 49759	 0.00177	 0.007368	 0.0023	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91189	 49758	 0.001676	 0.014092	 0.00417	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49758	 92307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49758	 92307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49759	 92308	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49759	 92308	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49760	 49761	 0.000989	 0.004536	 0.00116	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49761	 49773	 0.001074	 0.004301	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49762	 49774	 0.003586	 0.018249	 0.00041	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49762	 92313	 0.01515	 0.035172	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49763	 49764	 0.004827	 0.012276	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49763	 92309	 0.00921	 0.023423	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49763	 92311	 0.011307	 0.020711	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49763	 92312	 0.005142	 0.025092	 0.00043	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49765	 49766	 0.0008	 0.003784	 0.00091	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91189	 49765	 0.003582	 0.031251	 0.00858	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49765	 92309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49765	 92309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49766	 49767	 0.001166	 0.003929	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49766	 92310	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49766	 92310	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49767	 92311	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49767	 92311	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49768	 49769	 0.015701	 0.016032	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49768	 49770	 0.017038	 0.038226	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92310	 49768	 0.008315	 0.022715	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92311	 49768	 0.014508	 0.024439	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49770	 92317	 0.013066	 0.037476	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49771	 92312	 0.011976	 0.027165	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49771	 92317	 0.026636	 0.06184	 0.00092	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49772	 49933	 0.00052	 0.004838	 0.0015	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91189	 49772	 0.004197	 0.031759	 0.0156	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49772	 92312	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49772	 92312	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49773	 49786	 0.001304	 0.005219	 0.00131	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49773	 92313	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49773	 92313	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49774	 49776	 0.002679	 0.01187	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49774	 92315	 0.004541	 0.017664	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49775	 49776	 0.003489	 0.007476	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49776	 49777	 0.004678	 0.015605	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49776	 49785	 0.005022	 0.019538	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49777	 49779	 0.002044	 0.010224	 0.00018	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92300	 49777	 0.018605	 0.032719	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49778	 49779	 0.001284	 0.011957	 0.00023	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49778	 49780	 0.004464	 0.017175	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49778	 92437	 0.013926	 0.045957	 0.00074	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49779	 49784	 0.00636	 0.021217	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92299	 49779	 0.004635	 0.017757	 0.0005	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49780	 49781	 0.00468	 0.008701	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49780	 50059	 0.002953	 0.009068	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49780	 92314	 0.004507	 0.017532	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49781	 49783	 0.006673	 0.013655	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49782	 49797	 0.001425	 0.006538	 0.00167	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49782	 92314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49782	 92314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49783	 49784	 0.003585	 0.017296	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49783	 92319	 0.002365	 0.016048	 0.0003	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49784	 49787	 0.006789	 0.019265	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49785	 92319	 0.009901	 0.048316	 0.00083	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49786	 92315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49786	 92315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49787	 49796	 0.003077	 0.018627	 0.00058	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92315	 49787	 0.005971	 0.018318	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92315	 49787	 0.005971	 0.018318	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49788	 49791	 0.00085	 0.005223	 0.00151	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49788	 92316	 0.001552	 0.009385	 0.00239	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49789	 49932	 0.002867	 0.018157	 0.03803	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49789	 92316	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92317	 49789	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49790	 49820	 0.007627	 0.022956	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49790	 92325	 0.004987	 0.022224	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49791	 49792	 0.000819	 0.00519	 0.00141	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49792	 49809	 0.000632	 0.004072	 0.00107	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49793	 49808	 0.001879	 0.010056	 0.0003	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49793	 92318	 0.003927	 0.023868	 0.00044	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49794	 49795	 0.000412	 0.003462	 0.00103	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49794	 49933	 0.000477	 0.004988	 0.00137	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49794	 92318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49794	 92318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49795	 49803	 0.000315	 0.003028	 0.00088	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49796	 92322	 0.003014	 0.022899	 0.00052	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49797	 92319	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49797	 92319	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49797	 92321	 0.001585	 0.007273	 0.00186	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49798	 50052	 0.006257	 0.011633	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92314	 49798	 0.004263	 0.014221	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49799	 49800	 0.000453	 0.002485	 0.00066	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49799	 50049	 0.001101	 0.002831	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49799	 50055	 0.001369	 0.005959	 0.0017	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49800	 49801	 0.00072	 0.003869	 0.00095	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49800	 92320	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49800	 92320	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49801	 92321	 0.000934	 0.004949	 0.00125	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49802	 92321	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92322	 49802	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49802	 92330	 0.000567	 0.003865	 0.00696	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49803	 49804	 0.000385	 0.003694	 0.00107	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49804	 49806	 0.000597	 0.003499	 0.00095	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92321	 49804	 0.00076	 0.004025	 0.00102	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49805	 49807	 0.005462	 0.011176	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49805	 92323	 0.003135	 0.007477	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49805	 92325	 0.021474	 0.049336	 0.00075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49805	 92333	 0.029105	 0.044585	 0.00063	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49806	 92323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49806	 92323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49806	 92331	 0.000636	 0.004263	 0.00103	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49807	 49808	 0.008969	 0.01885	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92319	 49807	 0.024109	 0.061313	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49807	 92324	 0.005956	 0.019867	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49808	 92332	 0.008283	 0.046538	 0.00086	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49809	 92324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49809	 92324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49809	 92331	 0.001221	 0.007981	 0.00203	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49810	 92325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49810	 92325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49810	 92331	 0.002755	 0.012406	 0.0033	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49811	 49812	 0.003248	 0.015671	 0.00028	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49811	 49814	 0.00505	 0.012981	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49811	 49815	 0.013999	 0.027717	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92325	 49811	 0.012797	 0.021373	 0.00036	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49812	 49813	 0.00493	 0.011674	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49812	 92332	 0.009301	 0.028562	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49813	 92332	 0.011424	 0.029052	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49814	 49815	 0.012373	 0.014503	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49815	 49817	 0.037108	 0.029367	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49815	 49818	 0.011392	 0.020556	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49816	 49817	 0.010312	 0.02394	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91232	 49816	 0.01742	 0.040442	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49817	 49818	 0.010921	 0.015914	 0.00036	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49818	 49820	 0.005977	 0.020913	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92276	 49818	 0.037311	 0.069376	 0.00162	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92325	 49818	 0.004948	 0.026364	 0.00046	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92316	 49819	 0.002321	 0.009029	 0.00241	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49819	 92326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49819	 92326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92326	 49820	 0.002331	 0.0217	 0.00042	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49821	 49822	 0.022131	 0.028166	 0.00041	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49821	 49826	 0.018514	 0.036656	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49821	 49854	 0.035662	 0.082796	 0.00123	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49821	 92332	 0.029045	 0.074663	 0.00116	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49822	 92327	 0.013322	 0.023945	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49822	 92329	 0.02333	 0.059973	 0.00093	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49823	 49824	 0.002156	 0.005699	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49823	 92327	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49823	 92327	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49824	 49931	 0.001914	 0.008778	 0.00225	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49824	 92328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49824	 92328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49825	 92329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49825	 92329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49825	 92331	 0.002476	 0.009733	 0.00255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92329	 49826	 0.008887	 0.022844	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49827	 49828	 0.001094	 0.004762	 0.00136	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49827	 49847	 0.002287	 0.008282	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49828	 92331	 0.000928	 0.004391	 0.00106	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49829	 50033	 0.00023	 0.00274	 0.20557	 1725.0	 1811.2	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49829	 92330	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49829	 92330	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49830	 49831	 0.001354	 0.003516	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92321	 49830	 0.001486	 0.005005	 0.00124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49830	 92333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49830	 92333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49831	 49838	 0.001439	 0.004241	 0.00099	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92333	 49832	 0.008343	 0.017813	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49832	 92334	 0.015412	 0.018449	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49833	 49834	 0.014885	 0.009637	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92320	 49833	 0.017709	 0.013029	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49834	 50046	 0.015734	 0.012451	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49834	 92334	 0.003117	 0.012473	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49835	 49838	 0.001056	 0.005123	 0.00117	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49835	 92334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49835	 92334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49836	 50044	 0.007258	 0.018458	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49836	 50046	 0.013749	 0.013886	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49837	 49838	 0.000913	 0.003588	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49837	 49841	 0.001364	 0.00563	 0.00133	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92331	 49838	 0.001457	 0.010823	 0.00413	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49838	 92335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49838	 92335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49839	 49846	 0.0155	 0.014277	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92335	 49839	 0.008976	 0.014328	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49840	 92336	 0.006208	 0.010917	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49840	 92338	 0.017682	 0.014554	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49841	 50125	 0.000966	 0.003869	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49841	 92336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49841	 92336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92336	 49842	 0.005254	 0.012198	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49842	 92337	 0.005558	 0.011682	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49843	 49844	 0.001232	 0.0032	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49843	 49879	 0.001506	 0.003981	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49843	 50043	 0.001296	 0.004692	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49843	 92337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49843	 92337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49843	 92440	 0.003038	 0.010135	 0.00257	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49844	 49845	 0.001172	 0.003041	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49845	 49878	 0.002124	 0.005613	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49845	 92338	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49845	 92338	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92338	 49846	 0.010003	 0.013146	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49847	 49878	 0.00244	 0.006325	 0.00191	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49848	 49873	 0.028775	 0.028782	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92329	 49848	 0.016102	 0.053713	 0.00085	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49848	 92347	 0.026585	 0.02839	 0.0006	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49849	 49850	 0.002948	 0.007792	 0.00182	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49849	 49868	 0.003167	 0.00796	 0.00206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49850	 49851	 0.001799	 0.006172	 0.00148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49851	 92339	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49851	 92339	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49851	 92368	 0.006053	 0.027767	 0.00711	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49852	 49864	 0.001282	 0.003575	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49852	 92340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49852	 92340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92339	 49853	 0.010615	 0.021017	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49854	 49855	 0.008259	 0.021232	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49854	 49856	 0.011054	 0.019745	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49854	 49857	 0.013807	 0.028375	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49854	 92367	 0.009512	 0.024452	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92328	 49855	 0.012	 0.02757	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92339	 49855	 0.017576	 0.029312	 0.00043	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49856	 49857	 0.007714	 0.016532	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92340	 49857	 0.006658	 0.021973	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49857	 92343	 0.013665	 0.031721	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49858	 49925	 0.010827	 0.028696	 0.00073	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49858	 92343	 0.01628	 0.037797	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49858	 92360	 0.020369	 0.047289	 0.0007	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49859	 49860	 0.00131	 0.004744	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49859	 49861	 0.001435	 0.005743	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49859	 49865	 0.000871	 0.003923	 0.00104	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49859	 92341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49859	 92341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49860	 92342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49860	 92342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49861	 49863	 0.001299	 0.004456	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49861	 49919	 0.002765	 0.011072	 0.00279	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49862	 49866	 0.052768	 0.04176	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49862	 49867	 0.028585	 0.028872	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92342	 49862	 0.004398	 0.013492	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49863	 49869	 0.00112	 0.0034	 0.00074	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49864	 49865	 0.00085	 0.004127	 0.00094	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49864	 49927	 0.000932	 0.007085	 0.00223	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49864	 92343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49864	 92343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49866	 92344	 0.005929	 0.020746	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49866	 92345	 0.002987	 0.015335	 0.00029	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49867	 92345	 0.013416	 0.034486	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49868	 92344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49868	 92344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49869	 49870	 0.002594	 0.006022	 0.00183	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49870	 92345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49870	 92345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49870	 92361	 0.001507	 0.009046	 0.00274	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49871	 49912	 0.007761	 0.019264	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49871	 92346	 0.02349	 0.016639	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49872	 49874	 0.001199	 0.004114	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49872	 49911	 0.001726	 0.005758	 0.00146	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49872	 92346	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49872	 92346	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92342	 49873	 0.096354	 0.097323	 0.00129	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92344	 49873	 0.012452	 0.021737	 0.00034	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49873	 92347	 0.006005	 0.011634	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49874	 92347	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49874	 92347	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49875	 49876	 0.009051	 0.021014	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49875	 49877	 0.006365	 0.014778	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49876	 49934	 0.011648	 0.015892	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92346	 49876	 0.006576	 0.014092	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49876	 92359	 0.00271	 0.013228	 0.00028	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49877	 49881	 0.010173	 0.012628	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92347	 49877	 0.028426	 0.03154	 0.00062	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49877	 92348	 0.015332	 0.027664	 0.0004	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49878	 49879	 0.001536	 0.005009	 0.00133	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92331	 49878	 0.004677	 0.022698	 0.00519	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49878	 92348	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49878	 92348	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49879	 49884	 0.001591	 0.004608	 0.00111	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49880	 49881	 0.021828	 0.014131	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49880	 49883	 0.009448	 0.018516	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92337	 49880	 0.012111	 0.028117	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92348	 49881	 0.00638	 0.013621	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49882	 49883	 0.008795	 0.017413	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49882	 49934	 0.006554	 0.015216	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49883	 49885	 0.006684	 0.022298	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49884	 49886	 0.002085	 0.007268	 0.00169	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49885	 49889	 0.007272	 0.018692	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49885	 49908	 0.006726	 0.022197	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49885	 92349	 0.005286	 0.01516	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49886	 49890	 0.001654	 0.008615	 0.00226	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49886	 92349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49886	 92349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49887	 49890	 0.001027	 0.004238	 0.001	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49887	 50034	 0.001507	 0.005079	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49888	 49889	 0.004034	 0.010455	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49888	 92350	 0.006174	 0.017078	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49890	 49901	 0.000644	 0.005524	 0.00157	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49890	 92350	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49890	 92350	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49890	 92412	 0.001555	 0.007814	 0.00203	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49891	 92355	 0.015248	 0.05932	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49891	 92410	 0.011585	 0.022705	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49891	 92413	 0.011163	 0.025915	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49892	 49921	 0.000957	 0.01288	 0.02684	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49892	 92351	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49892	 92351	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49892	 92353	 0.0002	 0.002046	 0.0065	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49892	 92411	 0.000316	 0.003445	 0.0139	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49893	 49915	 0.009849	 0.025048	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49893	 92355	 0.005691	 0.034587	 0.00064	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49894	 49917	 0.012684	 0.025113	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92171	 49894	 0.005863	 0.029479	 0.0008	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49894	 92352	 0.005066	 0.022995	 0.0005	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49895	 49902	 0.001435	 0.006463	 0.00172	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49895	 92352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49895	 92352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49895	 92354	 0.000894	 0.004338	 0.00099	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49896	 92353	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49897	 49899	 0.002537	 0.015599	 0.00028	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92352	 49897	 0.003919	 0.022277	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91215	 49898	 0.001084	 0.008121	 0.00198	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49898	 92356	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49898	 92356	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92356	 49899	 0.005607	 0.034471	 0.00062	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92356	 49900	 0.0114	 0.014836	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92351	 49901	 0.000519	 0.004527	 0.00124	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49902	 49904	 0.000933	 0.004201	 0.00112	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49903	 49904	 0.000904	 0.004071	 0.00108	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49903	 49906	 0.001587	 0.005444	 0.0013	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49903	 92357	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49903	 92357	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49905	 49908	 0.003819	 0.017017	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92357	 49905	 0.002806	 0.015766	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49905	 92358	 0.003115	 0.010908	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49906	 49907	 0.000817	 0.003323	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49906	 92358	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49906	 92358	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49907	 49909	 0.001417	 0.004862	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49909	 49910	 0.00157	 0.004883	 0.00102	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49910	 49911	 0.001694	 0.004476	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49911	 92359	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49911	 92359	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49911	 92361	 0.003208	 0.014716	 0.00377	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49912	 49913	 0.010407	 0.026972	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92359	 49912	 0.022232	 0.029219	 0.0004	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49913	 92362	 0.007451	 0.026616	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92359	 49914	 0.023473	 0.053927	 0.00082	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49914	 92362	 0.009913	 0.049579	 0.00088	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49915	 49916	 0.00217	 0.016487	 0.00038	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92358	 49915	 0.007172	 0.025622	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92171	 49916	 0.006202	 0.055527	 0.00116	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49918	 49935	 0.023639	 0.019456	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92172	 49918	 0.006091	 0.028399	 0.00065	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49919	 92360	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49919	 92360	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92176	 49920	 0.016376	 0.03045	 0.00071	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92360	 49920	 0.049151	 0.064599	 0.00089	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49920	 92362	 0.012342	 0.029227	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91214	 49921	 0.001002	 0.010923	 0.04407	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49921	 92361	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92362	 49921	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92362	 49922	 0.007087	 0.021332	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49923	 49936	 0.002727	 0.012278	 0.00327	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49923	 92363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49923	 92363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91188	 49924	 0.003156	 0.038904	 0.01257	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92174	 49924	 0.003577	 0.021632	 0.00552	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49924	 92364	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49924	 92364	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49925	 92365	 0.005021	 0.019532	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49926	 49930	 0.001699	 0.013785	 0.00439	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91188	 49926	 0.00364	 0.029547	 0.00941	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49927	 49928	 0.001389	 0.005733	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49927	 49929	 0.001143	 0.005745	 0.00149	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49928	 49936	 0.001727	 0.007925	 0.00203	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49928	 92365	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49928	 92365	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49929	 49930	 0.00145	 0.007555	 0.00198	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49930	 92366	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49930	 92366	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49931	 92367	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49931	 92367	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49931	 92368	 0.003086	 0.014158	 0.00363	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91187	 49932	 0.000916	 0.013712	 0.05003	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92330	 49932	 0.003048	 0.020566	 0.03787	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49932	 92368	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92369	 49932	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92348	 49934	 0.020776	 0.044522	 0.00078	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92359	 49934	 0.004744	 0.015826	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49937	 49944	 0.078857	 0.18675	 0.00341	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92013	 49937	 0.092652	 0.21194	 0.00518	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49938	 49939	 0.14026	 0.11101	 0.0014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92004	 49938	 0.14212	 0.28145	 0.00413	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49939	 49942	 0.03163	 0.025031	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92011	 49939	 0.15213	 0.37253	 0.00637	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49939	 92370	 0.056962	 0.17495	 0.00328	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49941	 49944	 0.10672	 0.1635	 0.0023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49943	 92370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49943	 92370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49945	 49946	 0.063408	 0.14722	 0.00219	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49945	 49948	 0.10312	 0.23139	 0.00369	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91949	 49946	 0.10154	 0.26106	 0.00404	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49947	 49948	 0.029536	 0.021731	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91949	 49948	 0.13878	 0.45826	 0.00743	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49949	 49956	 0.000894	 0.012901	 0.0041	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92001	 49949	 0.000708	 0.008088	 0.00385	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49949	 92371	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49949	 92371	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49950	 49964	 0.015522	 0.063174	 0.01539	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49950	 92372	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49950	 92372	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92372	 49951	 0.029669	 0.11542	 0.00193	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49951	 92377	 0.035297	 0.11319	 0.0028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49952	 49955	 0.00209	 0.030173	 0.00958	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49952	 49957	 0.00154	 0.022647	 0.00693	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49953	 92374	 0.017108	 0.043979	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49954	 92373	 0.000641	 0.033327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49954	 92373	 0.000641	 0.033327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49955	 49956	 0.001454	 0.02033	 0.00689	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91194	 49957	 0.0006	 0.009209	 0.00258	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49957	 92374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49957	 92374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91195	 49958	 0.013195	 0.021061	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49959	 49960	 0.002899	 0.045968	 0.02908	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91980	 49960	 0.059877	 0.21721	 0.04671	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49960	 92375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49960	 92375	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49961	 92376	 0.22544	 0.17844	 0.00225	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89036	 49962	 0.032771	 0.15525	 0.03738	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91210	 49962	 0.03724	 0.15169	 0.03701	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49962	 92376	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49962	 92376	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92214	 49963	 0.11267	 0.25889	 0.00393	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92376	 49963	 0.15098	 0.22391	 0.00336	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49964	 92377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49964	 92377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49965	 49969	 0.000721	 0.008317	 0.07292	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49965	 50011	 0.001211	 0.013292	 0.12916	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49965	 92378	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49965	 92378	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49966	 92379	 0.074054	 0.097331	 0.00133	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91217	 49967	 0.010477	 0.030048	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49968	 92379	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49968	 92379	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49968	 92381	 0.00124	 0.006016	 0.00138	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92228	 49969	 0.001478	 0.015662	 0.16347	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49969	 92380	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92381	 49969	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92229	 49970	 0.003459	 0.023834	 0.04208	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92380	 49970	 0.002072	 0.014131	 0.02544	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91198	 49971	 0.011271	 0.045867	 0.01118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92381	 49971	 0.007493	 0.030494	 0.00743	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49972	 49977	 0.015444	 0.054594	 0.0123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49972	 92382	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49972	 92382	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49973	 92383	 0.036204	 0.093068	 0.00144	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49974	 92383	 0.06453	 0.1182	 0.00204	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49975	 49977	 0.009416	 0.030712	 0.00815	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91230	 49975	 0.006089	 0.030023	 0.00812	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	49975	 92383	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49975	 92383	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91231	 49976	 0.07344	 0.071858	 0.00102	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49978	 49980	 0.054977	 0.12764	 0.0019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49979	 49980	 0.06918	 0.094305	 0.00209	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	49981	 49982	 0.003131	 0.010739	 0.00257	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91230	 49981	 0.002488	 0.00996	 0.00251	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49981	 92384	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49981	 92384	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49982	 92386	 0.003385	 0.011613	 0.00278	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49983	 49984	 0.000325	 0.003623	 0.03417	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49983	 92385	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92386	 49983	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49984	 92387	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49984	 92387	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92384	 49985	 0.060707	 0.10954	 0.00158	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49986	 49988	 0.29954	 0.23486	 0.00302	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49986	 92388	 0.19915	 0.15763	 0.00198	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92387	 49987	 0.075058	 0.14862	 0.00218	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49989	 92388	 0.026493	 0.049261	 0.00115	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91230	 49990	 0.005135	 0.017895	 0.00415	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	49990	 92388	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49990	 92388	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49991	 49993	 0.001705	 0.019149	 0.03504	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49991	 49993	 0.001705	 0.019149	 0.03504	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49991	 92389	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49991	 92389	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49991	 92396	 0.017167	 0.12089	 0.20708	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92375	 49992	 0.23494	 0.42257	 0.00759	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49993	 49994	 0.002039	 0.021456	 0.04484	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49993	 49994	 0.002039	 0.021456	 0.04484	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49993	 50024	 0.004152	 0.026305	 0.05511	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	49994	 92390	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49994	 92390	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92010	 49995	 0.053979	 0.15318	 0.00241	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	49995	 92392	 0.13204	 0.17356	 0.00238	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	49996	 49999	 0.013205	 0.052873	 0.01332	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49997	 49998	 0.002008	 0.007025	 0.00233	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49997	 50574	 0.025775	 0.064805	 0.01679	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	49997	 92391	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49997	 92391	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49998	 50000	 0.009326	 0.037954	 0.00925	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	49998	 92392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	49998	 92392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91956	 49999	 0.019261	 0.079543	 0.01883	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91956	 50000	 0.016547	 0.068332	 0.01617	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92223	 50001	 0.065945	 0.23095	 0.0064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50001	 92393	 0.046264	 0.11893	 0.00184	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50002	 50003	 0.006147	 0.026754	 0.00762	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50002	 50005	 0.010382	 0.027439	 0.00642	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50002	 92393	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50002	 92393	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50003	 92394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50003	 92394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92394	 50004	 0.068693	 0.10523	 0.00148	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50004	 92395	 0.081598	 0.16157	 0.00237	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50005	 92395	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50005	 92395	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50006	 92396	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92397	 50007	 0.011586	 0.046389	 0.01169	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50008	 50009	 0.03487	 0.080957	 0.0012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92398	 50008	 0.056991	 0.14651	 0.00227	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50009	 92399	 0.087247	 0.18699	 0.00327	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50010	 92399	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50010	 92399	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91979	 50011	 0.000942	 0.016439	 0.17798	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50012	 50014	 0.011344	 0.045422	 0.01144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50012	 92401	 0.011717	 0.046054	 0.01205	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50013	 92400	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91980	 50014	 0.011527	 0.046912	 0.01143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50015	 50017	 0.007148	 0.026006	 0.00796	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50016	 92404	 0.063685	 0.12482	 0.00187	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50017	 50020	 0.005834	 0.021223	 0.0065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50017	 92403	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50017	 92403	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50018	 92404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50018	 92404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50019	 50022	 0.044688	 0.083094	 0.00194	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92081	 50019	 0.07285	 0.13547	 0.00317	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50020	 50021	 0.014639	 0.03528	 0.00996	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50020	 92405	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50020	 92405	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92405	 50022	 0.047636	 0.088576	 0.00207	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92236	 50023	 0.17861	 0.35376	 0.00519	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91243	 50024	 0.011035	 0.074991	 0.13687	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50024	 92406	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50024	 92406	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50025	 50026	 0.0151	 0.037961	 0.00984	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91095	 50025	 0.075138	 0.25139	 0.064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92406	 50025	 0.008082	 0.039851	 0.01078	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50025	 92407	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50025	 92407	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50026	 50027	 0.015038	 0.045037	 0.01015	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50027	 92408	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50027	 92408	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50028	 50029	 0.00491	 0.006693	 0.00015	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50028	 92410	 0.004351	 0.008904	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50029	 50036	 0.01525	 0.012069	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50030	 50032	 0.000914	 0.004921	 0.00135	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50030	 50038	 0.000803	 0.003214	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50030	 92409	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50030	 92409	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50031	 50091	 0.000709	 0.002951	 0.00092	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50031	 92412	 0.000897	 0.004243	 0.00102	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50032	 92410	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50032	 92410	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50032	 92412	 0.000334	 0.001892	 0.00047	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50033	 92411	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50033	 92411	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50034	 50035	 0.000517	 0.002373	 0.00061	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50034	 50038	 0.001344	 0.004529	 0.00113	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50035	 50084	 0.000764	 0.003058	 0.00077	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50035	 92414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50035	 92414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50037	 50090	 0.022252	 0.017609	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50037	 92415	 0.003161	 0.005251	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50038	 92415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50038	 92415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92414	 50039	 0.011363	 0.017407	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50039	 92424	 0.016137	 0.012771	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50040	 50042	 0.000643	 0.002166	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50040	 50125	 0.000704	 0.002487	 0.00056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50041	 50125	 0.001347	 0.003864	 0.00095	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50041	 92440	 0.000987	 0.003839	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50042	 92440	 0.000912	 0.003072	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50043	 50084	 0.001045	 0.003783	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92336	 50044	 0.004656	 0.013211	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50044	 92416	 0.010122	 0.017439	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50045	 50078	 0.000432	 0.003705	 0.00105	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50045	 92416	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50045	 92416	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50045	 92440	 0.000468	 0.005182	 0.00169	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92334	 50046	 0.007848	 0.022508	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50046	 92417	 0.004348	 0.009989	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50046	 92423	 0.018847	 0.02073	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50047	 50048	 0.000705	 0.002111	 0.00048	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50047	 50078	 0.001271	 0.0033	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50047	 92417	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50047	 92417	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50048	 50049	 0.000833	 0.002322	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50050	 50051	 0.007919	 0.012131	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50050	 50079	 0.004885	 0.00878	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50051	 92418	 0.011467	 0.015071	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50052	 50053	 0.002856	 0.00663	 0.0001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50053	 92418	 0.005054	 0.010386	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50054	 92418	 0.003357	 0.008629	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50054	 92437	 0.005335	 0.012386	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50055	 50057	 0.001114	 0.002893	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50055	 92418	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50055	 92418	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50056	 50079	 0.003999	 0.008406	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92418	 50056	 0.003145	 0.007302	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50057	 50074	 0.001005	 0.002735	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50058	 50059	 0.003486	 0.008094	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50058	 50060	 0.002635	 0.006055	 9e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50060	 50061	 0.003337	 0.007387	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50061	 50062	 0.003859	 0.008865	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50062	 92420	 0.009148	 0.016507	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50062	 92437	 0.004591	 0.012168	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50063	 50065	 0.002001	 0.012913	 0.00041	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50063	 92437	 0.002814	 0.020251	 0.00066	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50064	 50065	 0.010802	 0.008548	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92298	 50065	 0.00142	 0.011065	 0.00021	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50066	 50069	 0.005778	 0.014854	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50066	 92419	 0.006129	 0.014229	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50067	 50124	 0.000846	 0.003682	 0.00105	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50067	 50127	 0.003096	 0.015553	 0.00405	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50067	 92419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50067	 92419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50068	 50070	 0.000832	 0.002454	 0.00057	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50068	 50075	 0.00134	 0.003597	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50068	 50126	 0.001647	 0.004959	 0.00155	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50068	 92420	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50068	 92420	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50069	 50072	 0.01675	 0.013256	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50069	 92421	 0.003486	 0.00896	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50070	 50071	 0.00118	 0.003289	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50070	 92421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50070	 92421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50071	 50128	 0.001286	 0.003398	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50071	 92422	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50071	 92422	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92422	 50072	 0.00443	 0.008772	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50073	 50109	 0.005196	 0.009339	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92421	 50073	 0.016556	 0.020183	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50074	 50080	 0.000753	 0.0021	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50075	 50076	 0.000904	 0.00252	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50076	 50112	 0.001534	 0.004176	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50077	 92432	 0.012781	 0.010114	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50078	 92423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50078	 92423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50079	 50107	 0.009066	 0.019428	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92423	 50079	 0.007923	 0.020366	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50080	 50081	 0.001139	 0.003101	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50081	 50105	 0.001726	 0.004338	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92416	 50082	 0.002941	 0.011442	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50082	 92441	 0.00186	 0.012764	 0.00023	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50083	 50085	 0.00207	 0.005487	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50083	 92425	 0.001737	 0.007653	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50084	 92424	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50084	 92424	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50085	 92441	 0.00306	 0.010208	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50086	 50087	 0.001163	 0.003244	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50086	 92425	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50086	 92425	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50087	 50089	 0.00114	 0.004128	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50088	 50094	 0.000526	 0.002173	 0.00051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50088	 50095	 0.000384	 0.003349	 0.00092	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92412	 50088	 0.001747	 0.012123	 0.00346	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50088	 92426	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50088	 92426	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50089	 50094	 0.000812	 0.00325	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92412	 50089	 0.001271	 0.008987	 0.00247	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50089	 92427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50089	 92427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92409	 50090	 0.002529	 0.009033	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92427	 50090	 0.003167	 0.008053	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50090	 92428	 0.00788	 0.020257	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50091	 50092	 0.000402	 0.001751	 0.0005	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50092	 50093	 0.000338	 0.002473	 0.00073	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92412	 50092	 0.002056	 0.008488	 0.00201	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50093	 50116	 0.000384	 0.002231	 0.00053	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50094	 92428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50094	 92428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50095	 50100	 0.000355	 0.003046	 0.00087	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50096	 50098	 0.010582	 0.010613	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50097	 50098	 0.002867	 0.005867	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92428	 50097	 0.002665	 0.006187	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50098	 50099	 0.00627	 0.012414	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92428	 50098	 0.005314	 0.01366	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50098	 92434	 0.006603	 0.00774	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50098	 92436	 0.011452	 0.020974	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50100	 50101	 0.00029	 0.002284	 0.00067	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50101	 50103	 0.000329	 0.002505	 0.00079	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50102	 92433	 0.003884	 0.011141	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50102	 92442	 0.00598	 0.011839	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50103	 50105	 0.000311	 0.002034	 0.00075	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50103	 92429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50103	 92429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50104	 50111	 0.00039	 0.001941	 0.00063	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50104	 50113	 0.000879	 0.004979	 0.00123	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50105	 92430	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50105	 92430	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50106	 50107	 0.002538	 0.005025	 7e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92423	 50106	 0.009118	 0.023438	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92430	 50106	 0.007464	 0.009714	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50107	 50108	 0.008881	 0.007028	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92430	 50107	 0.008318	 0.011593	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92430	 50109	 0.004309	 0.011421	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50109	 92431	 0.013786	 0.012698	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50109	 92439	 0.026986	 0.029681	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50110	 92439	 0.014916	 0.011804	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50111	 50112	 0.000616	 0.002112	 0.00051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50111	 92431	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50111	 92431	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50112	 92432	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50112	 92432	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50113	 92433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50113	 92433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50113	 92435	 0.00132	 0.006405	 0.00146	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50114	 50131	 0.000276	 0.002367	 0.00067	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50115	 50118	 0.003086	 0.012004	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92433	 50115	 0.002907	 0.009696	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50116	 92434	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50116	 92434	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50116	 92435	 0.000777	 0.003566	 0.00091	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50117	 50118	 0.005056	 0.008517	 0.00012	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92434	 50118	 0.004844	 0.01147	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50118	 92436	 0.00142	 0.004973	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50119	 50129	 0.000796	 0.005486	 0.00968	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92411	 50119	 0.000648	 0.005484	 0.01068	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50119	 92435	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92436	 50119	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50120	 50122	 0.000788	 0.003064	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50120	 50131	 0.000291	 0.00265	 0.00067	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50120	 50132	 0.00111	 0.00298	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50121	 50123	 0.001428	 0.006045	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50121	 50131	 0.000884	 0.004123	 0.00102	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50122	 50123	 0.000728	 0.002962	 0.00072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50123	 50124	 0.000754	 0.003909	 0.00095	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92331	 50126	 0.006118	 0.029692	 0.00679	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50126	 92437	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50126	 92437	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50127	 92438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50127	 92438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50128	 50132	 0.001454	 0.003842	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50128	 92439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50128	 92439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92330	 50129	 0.001758	 0.012329	 0.02099	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92411	 50129	 0.00047	 0.00431	 0.01701	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50129	 92440	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92441	 50129	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92435	 50130	 0.003244	 0.009563	 0.00222	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50130	 92442	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50130	 92442	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92412	 50131	 0.002568	 0.023362	 0.0059	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50131	 92443	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50131	 92443	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50132	 92444	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50132	 92444	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92435	 50133	 0.001822	 0.00511	 0.00132	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50134	 50135	 0.002916	 0.038692	 0.62343	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50134	 50140	 0.003248	 0.034473	 0.51779	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50134	 50140	 0.003248	 0.034473	 0.51779	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50134	 50160	 0.001495	 0.016415	 0.15954	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50134	 52364	 0.006552	 0.068515	 1.097	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50134	 52364	 0.006552	 0.068515	 1.097	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50134	 92445	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50134	 92445	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50135	 50985	 0.000666	 0.011199	 0.11587	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50135	 92447	 0.000128	 0.010206	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50135	 92447	 0.000128	 0.010206	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50136	 50935	 0.00055	 0.005822	 0.08707	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50136	 50935	 0.00055	 0.005822	 0.08707	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50136	 92449	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50136	 92449	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92450	 50136	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92450	 50136	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50137	 50689	 0.00018	 0.001901	 0.02843	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50137	 50689	 0.00018	 0.001901	 0.02843	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50137	 50714	 0.001565	 0.015495	 0.26548	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50137	 50714	 0.001565	 0.015495	 0.26548	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50137	 51227	 0.002606	 0.026953	 0.4247	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50137	 51227	 0.002606	 0.026953	 0.4247	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50137	 92451	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50137	 92451	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50138	 50597	 0.000106	 0.001157	 0.01136	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50138	 92453	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50138	 92453	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50139	 50891	 0.000654	 0.00895	 0.09121	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50139	 51288	 0.000258	 0.003722	 0.03415	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92032	 50139	 0.000418	 0.004822	 0.04227	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50139	 92455	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50139	 92455	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50140	 50616	 0.001558	 0.016643	 0.24461	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50140	 50616	 0.001558	 0.016643	 0.24461	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50140	 92457	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50140	 92457	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50141	 50690	 0.008558	 0.036224	 0.00815	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50141	 50692	 0.003725	 0.014492	 0.00387	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50141	 92458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50141	 92458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50142	 50144	 5e-05	 0.000502	 0.00826	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50142	 50144	 5e-05	 0.000502	 0.00826	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50142	 50903	 0.000537	 0.005317	 0.09101	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50142	 50903	 0.000537	 0.005317	 0.09101	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50142	 92459	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50142	 92459	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50143	 50717	 0.000265	 0.003	 0.02732	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50143	 50733	 0.00252	 0.028581	 0.26068	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50143	 50931	 0.001078	 0.010881	 0.17916	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50143	 50931	 0.001078	 0.010881	 0.17916	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50143	 92460	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50143	 92460	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50144	 50731	 0.003683	 0.038165	 0.60311	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50144	 50731	 0.003683	 0.038165	 0.60311	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50144	 92461	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50144	 92461	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50145	 51045	 0.000832	 0.009135	 0.08875	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50145	 92462	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50145	 92462	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50146	 50731	 0.00068	 0.006857	 0.11288	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50146	 50731	 0.00068	 0.006857	 0.11288	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50146	 92463	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50146	 92463	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50147	 50606	 0.008918	 0.033899	 0.00949	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50147	 50940	 0.020098	 0.085085	 0.01915	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50147	 50976	 0.013993	 0.08866	 0.02407	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50147	 51829	 0.052215	 0.19886	 0.05582	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50147	 92465	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50147	 92465	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50147	 92993	 0.027683	 0.16511	 0.04351	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50148	 50861	 0.00392	 0.015693	 0.00395	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50148	 50864	 0.002117	 0.010709	 0.00298	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50148	 50865	 0.001228	 0.014579	 0.00508	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50148	 50866	 0.003967	 0.014432	 0.00442	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92445	 50148	 0.0087	 0.15476	 0.07803	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50148	 92466	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50148	 92466	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50149	 50936	 0.003091	 0.023159	 0.00565	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50149	 50937	 0.002013	 0.016706	 0.00439	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92445	 50149	 0.048148	 0.17546	 0.05383	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50149	 92467	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50149	 92467	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50150	 50990	 0.000782	 0.004076	 0.00107	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50150	 50999	 0.000462	 0.003326	 0.00088	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50150	 92468	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50150	 92468	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50150	 92980	 0.000922	 0.00977	 0.0029	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50151	 50602	 0.019433	 0.076399	 0.01999	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50151	 51007	 0.019016	 0.076152	 0.01919	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50151	 92469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50151	 92469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50152	 50645	 0.026975	 0.081936	 0.01795	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50152	 50737	 0.005516	 0.037005	 0.00893	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50152	 51178	 0.00635	 0.02913	 0.00746	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50152	 51213	 0.007819	 0.035871	 0.00919	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92445	 50152	 0.057734	 0.23894	 0.05672	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50152	 92470	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50152	 92470	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50153	 50567	 0.007412	 0.017206	 0.00524	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50153	 92471	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50153	 92471	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50154	 51252	 0.000115	 0.000777	 0.00141	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92033	 50154	 0.000793	 0.005381	 0.0098	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50154	 92472	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50154	 92472	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50154	 92848	 0.006685	 0.058556	 0.10691	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50155	 50637	 0.011332	 0.038184	 0.00949	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50155	 92473	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50155	 92473	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50156	 50673	 0.000102	 0.001177	 0.01032	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50156	 92474	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50156	 92474	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50157	 50920	 0.000257	 0.002276	 0.00061	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50157	 50999	 0.011532	 0.081591	 0.0224	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50158	 50689	 0.000168	 0.001839	 0.01805	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50158	 51045	 0.002128	 0.023816	 0.2228	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50158	 92475	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50158	 92475	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50159	 50630	 0.025432	 0.084866	 0.02153	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50159	 50881	 0.012321	 0.044616	 0.00957	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50159	 50884	 0.006999	 0.038408	 0.01015	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92445	 50159	 0.073014	 0.29345	 0.07432	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50159	 92477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50159	 92477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50160	 92478	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50160	 92478	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50161	 51276	 0.000142	 0.000554	 0.00015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50161	 51279	 0.001315	 0.005567	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50161	 92479	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50161	 92479	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50162	 93021	 0.014587	 0.082917	 0.0015	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50163	 50164	 0.000523	 0.002096	 0.00053	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50163	 50724	 0.020264	 0.094542	 0.02343	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50163	 92480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50163	 92480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50164	 50561	 0.019953	 0.051805	 0.01257	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50164	 92481	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50164	 92481	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50164	 92982	 0.061058	 0.22151	 0.04764	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50165	 50645	 0.001471	 0.00904	 0.00261	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50165	 50646	 0.001669	 0.01769	 0.00525	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50165	 50649	 0.001595	 0.00788	 0.0023	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50165	 51196	 0.032023	 0.10991	 0.02635	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50165	 51213	 0.027574	 0.094623	 0.02268	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92445	 50165	 0.058794	 0.24335	 0.05777	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50165	 92482	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50165	 92482	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50166	 50733	 0.001044	 0.012048	 0.10565	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50166	 92483	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50166	 92483	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50167	 50168	 0.000481	 0.004619	 0.00134	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50167	 51083	 0.001285	 0.008609	 0.00264	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50167	 51141	 0.001123	 0.006904	 0.00199	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50167	 51143	 0.005625	 0.02138	 0.00598	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50168	 51141	 0.002993	 0.011981	 0.00302	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50168	 51232	 0.008375	 0.080431	 0.02341	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50169	 50950	 0.006133	 0.032937	 0.00078	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50169	 50951	 0.002632	 0.005386	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50170	 50859	 0.001659	 0.009883	 0.0026	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50170	 50863	 0.00099	 0.006998	 0.00192	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50170	 92484	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50170	 92484	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50171	 50580	 0.003556	 0.016315	 0.00418	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50171	 50585	 0.001582	 0.006436	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50172	 92868	 0.003515	 0.008159	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50173	 50963	 0.006921	 0.024723	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50173	 92968	 0.014691	 0.034106	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50174	 92863	 0.01354	 0.045169	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50174	 92864	 0.006361	 0.011652	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50175	 50587	 0.001094	 0.005309	 0.00121	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50175	 50588	 0.000629	 0.003215	 0.00081	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50176	 50961	 0.021294	 0.054738	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50176	 92969	 0.2086	 0.16511	 0.00208	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50177	 92865	 0.03682	 0.072901	 0.00107	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50178	 51231	 0.003065	 0.049324	 0.01612	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50178	 51232	 0.00047	 0.007034	 0.00236	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50178	 51233	 0.002245	 0.008825	 0.00231	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50179	 51229	 0.005227	 0.043959	 0.01302	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50179	 51233	 0.001192	 0.004851	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50179	 51234	 0.003327	 0.032961	 0.0101	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50180	 50183	 0.00078	 0.014147	 0.14147	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50180	 51943	 0.00914	 0.1338	 1.4353	 717.0	 789.0	 789.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50180	 92485	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50180	 92485	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50180	 95334	 0.004829	 0.090017	 2.0927	 1959.0	 2056.9	 2154.9	 0.0	 0.0	 0	 -30.0	 30.0;
	50180	 95334	 0.004829	 0.090017	 2.0927	 736.0	 772.8	 809.6	 0.0	 0.0	 0	 -30.0	 30.0;
	50181	 51966	 0.000313	 0.003429	 0.03331	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50181	 52007	 0.001158	 0.018395	 0.30241	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50182	 50183	 0.001959	 0.023558	 0.23334	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50182	 51966	 0.000189	 0.003308	 0.03539	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50182	 92486	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50182	 92486	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50183	 92487	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50183	 92487	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50184	 50185	 3.9e-05	 0.000448	 0.00393	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50184	 51968	 0.000663	 0.016092	 0.27783	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50184	 92488	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50184	 92488	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50185	 92489	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50185	 92489	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50186	 51921	 0.024945	 0.086963	 0.02017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50186	 51957	 0.011723	 0.10059	 0.02864	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50186	 52001	 0.015132	 0.16349	 0.08768	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50186	 53162	 0.032858	 0.14809	 0.03946	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50186	 92490	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50186	 92490	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50187	 50200	 0.000136	 0.000349	 9e-05	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50187	 50201	 0.00011	 0.000387	 9e-05	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50187	 51978	 0.032729	 0.12873	 0.03371	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50187	 51980	 0.026566	 0.10641	 0.02683	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50188	 51956	 0.072597	 0.19797	 0.0437	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50188	 51986	 0.05694	 0.2285	 0.05775	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50188	 92491	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50188	 92491	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50189	 50190	 0.005172	 0.038436	 0.01466	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50189	 50194	 0.000617	 0.002471	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50189	 51914	 0.008587	 0.12407	 0.03944	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50190	 50197	 0.001803	 0.010341	 0.00344	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50190	 51853	 0.031989	 0.10979	 0.02632	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50190	 51948	 0.014722	 0.076334	 0.01864	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50191	 51963	 0.027246	 0.075995	 0.01595	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50191	 52044	 0.005584	 0.035369	 0.0096	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50191	 92492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50191	 92492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50192	 51962	 0.002806	 0.02939	 0.05531	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50192	 52042	 0.005745	 0.087509	 0.19923	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50192	 92493	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50192	 92493	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50192	 93241	 0.005472	 0.037335	 0.06726	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50193	 51962	 0.003395	 0.036063	 0.06595	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50193	 52017	 0.009536	 0.092777	 0.33062	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50193	 92494	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50193	 92494	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92495	 50193	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92495	 50193	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50194	 51854	 0.014367	 0.056474	 0.01478	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50194	 92496	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50194	 92496	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50195	 51921	 0.017163	 0.091262	 0.02118	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50195	 51953	 0.013814	 0.055315	 0.01394	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50195	 51954	 0.021111	 0.11373	 0.03127	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50195	 52021	 0.040996	 0.16946	 0.04016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50196	 51976	 0.00753	 0.030149	 0.0076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92487	 50196	 0.007435	 0.026282	 0.00592	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50197	 52025	 0.018012	 0.13812	 0.03705	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50197	 92497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50197	 92497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50198	 50204	 0.016667	 0.032665	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50198	 51884	 0.07611	 0.15998	 0.00291	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92495	 50198	 0.005839	 0.020858	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92496	 50199	 8e-05	 0.00038	 1e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50200	 51975	 0.078817	 0.215	 0.04748	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50200	 92498	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50200	 92498	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50201	 92499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50201	 92499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50202	 51968	 0.0002	 0.002313	 0.02028	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50202	 92500	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50202	 92500	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50203	 51971	 0.00475	 0.048405	 0.01247	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50203	 51976	 0.006582	 0.052887	 0.01487	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92495	 50204	 0.004851	 0.01733	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50205	 51852	 0.006023	 0.068128	 0.02624	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50205	 52018	 0.000276	 0.003396	 0.0011	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50206	 50208	 0.000533	 0.008891	 0.17301	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50206	 50560	 0.001695	 0.027555	 0.56941	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50206	 51725	 0.00036	 0.005208	 0.08	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50206	 51754	 0.000887	 0.01059	 0.18014	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50207	 51570	 0.004434	 0.046034	 0.72939	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50207	 51570	 0.004434	 0.046034	 0.72939	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50207	 51734	 0.00186	 0.021482	 0.1885	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50207	 92501	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50207	 92501	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92502	 50207	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92502	 50207	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50208	 50210	 0.000783	 0.012072	 0.21063	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50208	 51725	 0.00048	 0.007416	 0.16845	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50208	 51731	 0.000131	 0.002126	 0.04375	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50209	 51401	 0.011073	 0.066472	 0.02014	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50209	 51498	 0.007097	 0.053465	 0.01484	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50209	 51837	 0.000696	 0.011924	 0.00343	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50209	 51839	 0.002322	 0.023662	 0.0061	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50210	 92503	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50210	 92503	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50211	 51588	 0.01449	 0.070711	 0.00122	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50211	 51590	 0.011895	 0.049385	 0.00129	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50211	 51594	 0.00633	 0.035984	 0.00065	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50211	 51595	 0.025808	 0.079255	 0.00149	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50212	 51364	 0.029974	 0.097807	 0.02598	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50212	 51623	 0.015562	 0.051921	 0.01317	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50212	 51624	 0.010145	 0.026811	 0.00628	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50212	 53319	 0.026298	 0.069515	 0.01627	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50213	 51572	 0.000148	 0.002709	 0.04993	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50213	 51725	 0.001854	 0.026223	 0.4247	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50213	 92506	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50213	 92506	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50214	 51320	 0.000176	 0.001929	 0.01874	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50214	 51372	 0.000944	 0.010309	 0.10123	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50214	 92507	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50214	 92507	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50215	 51410	 7.8e-05	 0.000896	 0.00785	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50215	 92508	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50215	 92508	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50216	 51652	 0.00354	 0.018084	 0.00455	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50216	 51674	 0.002344	 0.010554	 0.00281	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50216	 92510	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50216	 92510	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50217	 51354	 0.011232	 0.047543	 0.0107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50217	 92511	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50217	 92511	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50217	 93186	 0.001081	 0.002943	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50218	 51411	 0.002989	 0.011967	 0.00301	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50218	 51418	 0.000553	 0.001896	 0.00045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50218	 51424	 0.001878	 0.006443	 0.00154	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50218	 51425	 0.00317	 0.00884	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90227	 50218	 0.002701	 0.015351	 0.00444	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50218	 92512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50218	 92512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50219	 51584	 0.002709	 0.007158	 0.00168	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50219	 51585	 0.002395	 0.00556	 0.00169	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50219	 51599	 0.027782	 0.072142	 0.01751	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50219	 92513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50219	 92513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50220	 51625	 0.003543	 0.013923	 0.00364	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50220	 51659	 0.00271	 0.012824	 0.00308	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50220	 51693	 0.005503	 0.014543	 0.0034	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50221	 50959	 0.010798	 0.041048	 0.01149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50221	 92514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50221	 92514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50222	 51379	 0.00386	 0.044682	 0.39341	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50222	 92515	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50222	 92515	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50223	 51571	 0.006994	 0.060593	 0.02176	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50223	 51696	 0.002138	 0.015051	 0.00856	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50223	 51756	 0.008874	 0.043843	 0.01281	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50223	 51759	 0.005923	 0.044614	 0.01238	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50224	 51829	 0.008591	 0.034396	 0.00867	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50224	 51830	 0.009252	 0.027277	 0.00635	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50225	 51431	 0.003224	 0.01267	 0.00331	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50225	 51491	 0.001907	 0.0101	 0.00256	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50225	 51777	 0.000744	 0.003147	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50225	 92517	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50225	 92517	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50226	 51330	 0.18008	 0.41829	 0.00622	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50226	 51618	 0.019707	 0.09138	 0.0019	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50226	 51619	 0.007744	 0.015847	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50227	 93184	 0.018014	 0.067576	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50227	 93184	 0.018014	 0.067576	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50227	 93185	 0.004768	 0.021009	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50227	 93187	 0.014374	 0.0553	 0.00094	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50227	 93188	 0.013741	 0.04584	 0.00073	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50228	 51705	 0.006572	 0.025565	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50228	 51705	 0.006572	 0.025565	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50228	 93171	 0.067537	 0.25988	 0.00444	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50228	 93171	 0.067537	 0.25988	 0.00444	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50229	 51731	 0.000114	 0.001255	 0.01219	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50229	 51732	 3.6e-05	 0.000397	 0.00375	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50229	 92518	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50229	 92518	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50230	 51389	 0.089696	 0.23716	 0.00431	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50230	 93086	 0.058495	 0.098541	 0.0014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50231	 51401	 0.005161	 0.013855	 0.00314	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50231	 51404	 0.001761	 0.004426	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50231	 51405	 0.001769	 0.007083	 0.00178	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50231	 51407	 0.003288	 0.013164	 0.00332	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50231	 92519	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50231	 92519	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50232	 51323	 0.000727	 0.005843	 0.00164	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50232	 51324	 0.001511	 0.007333	 0.00168	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50232	 92520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50232	 92520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50232	 93061	 0.003639	 0.014807	 0.00361	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50233	 51319	 0.006075	 0.020266	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50233	 51321	 0.006777	 0.011318	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50233	 93062	 0.010483	 0.021453	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50234	 51397	 0.60708	 0.46056	 0.00634	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50234	 51715	 0.57309	 0.45404	 0.00572	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50234	 93215	 0.018984	 0.02088	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50235	 51391	 0.006988	 0.049433	 0.01357	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50235	 51699	 0.005848	 0.037671	 0.00988	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50236	 51393	 0.009813	 0.027366	 0.00574	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50236	 51395	 0.018591	 0.053854	 0.01299	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50236	 92521	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50236	 92521	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50237	 51752	 0.016751	 0.10299	 0.00186	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50237	 93190	 0.000742	 0.002968	 6e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50238	 52451	 0.00013	 0.001973	 0.03534	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50238	 52452	 0.000349	 0.003454	 0.05913	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50238	 52452	 0.000349	 0.003454	 0.05913	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50238	 52454	 0.000139	 0.001925	 0.01903	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50238	 92522	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50238	 92522	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50239	 50243	 0.001091	 0.027221	 0.44708	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50239	 52361	 0.00052	 0.009159	 0.15213	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50239	 52364	 0.000521	 0.009222	 0.1515	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50239	 52752	 0.0004	 0.009712	 0.16756	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50239	 92523	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50239	 92523	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50240	 50247	 9.6e-05	 0.001182	 0.01873	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50240	 52439	 0.000108	 0.001849	 0.03261	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50241	 52838	 0.000105	 0.001684	 0.01686	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50241	 52944	 0.00144	 0.015246	 0.22817	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50241	 52944	 0.00144	 0.015246	 0.22817	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50241	 53088	 0.000822	 0.009154	 0.08633	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50241	 92524	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50241	 92524	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50242	 52082	 0.010543	 0.17251	 0.10339	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50242	 52150	 0.005092	 0.048894	 0.01422	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50242	 52417	 0.017704	 0.062587	 0.01411	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50242	 52420	 0.038718	 0.12047	 0.02516	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50242	 52810	 0.012715	 0.092887	 0.02389	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50242	 92526	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50242	 92526	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50243	 52402	 0.000681	 0.008417	 0.13344	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50243	 52625	 0.000951	 0.009409	 0.1611	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50243	 52625	 0.000951	 0.009409	 0.1611	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50243	 52716	 1.1e-05	 0.000148	 0.00254	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50243	 92527	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50243	 92527	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50244	 52063	 0.000624	 0.007178	 0.07033	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50244	 52313	 0.003923	 0.045305	 0.44614	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50244	 52779	 0.000564	 0.005584	 0.09559	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50244	 92528	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50244	 92528	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50245	 92530	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50245	 92530	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92531	 50245	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92531	 50245	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50245	 92548	 0.000179	 0.001826	 0.0058	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50245	 93276	 0.013789	 0.11141	 0.37899	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50245	 93603	 0.000435	 0.005981	 0.01192	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50245	 93652	 0.00268	 0.033731	 0.08068	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50246	 52178	 0.004763	 0.01907	 0.0048	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50246	 52183	 0.001521	 0.01222	 0.00343	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50246	 52206	 0.004813	 0.017428	 0.00374	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50246	 52583	 0.005332	 0.027776	 0.00729	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50246	 52698	 0.005738	 0.030572	 0.00858	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50246	 92532	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50246	 92532	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50247	 50597	 0.003407	 0.03382	 0.5817	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50247	 52439	 0.000219	 0.002839	 0.04707	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50247	 52828	 0.000672	 0.012863	 0.2171	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50247	 92533	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50247	 92533	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50248	 53040	 0.00041	 0.004341	 0.06492	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50248	 53063	 0.000116	 0.002029	 0.02196	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50248	 92534	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50248	 92534	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50249	 52381	 0.009039	 0.031502	 0.0073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50249	 52382	 0.004312	 0.033402	 0.0117	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50249	 52384	 0.008649	 0.026896	 0.00561	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50249	 52388	 0.025833	 0.10347	 0.02608	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50249	 92537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50249	 92537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50250	 52293	 0.014859	 0.079888	 0.01966	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50250	 53097	 0.008162	 0.032081	 0.00839	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50251	 50263	 0.000116	 0.001335	 0.01171	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50251	 52348	 0.00246	 0.027426	 0.25907	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50251	 92538	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50251	 92538	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50252	 93282	 0.027425	 0.13874	 0.00241	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50252	 93365	 0.043426	 0.3175	 0.00586	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50252	 93659	 0.039514	 0.20109	 0.00456	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50253	 52334	 0.001	 0.010977	 0.10665	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50253	 92539	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50253	 92539	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50254	 53097	 0.006069	 0.023609	 0.00631	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50254	 56423	 0.089488	 0.24085	 0.05475	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50254	 92541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50254	 92541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50255	 52325	 0.01129	 0.038041	 0.00945	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50255	 92542	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50255	 92542	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50255	 93296	 0.016727	 0.049319	 0.01147	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50256	 52238	 0.012628	 0.063455	 0.01652	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50256	 52247	 0.013616	 0.046714	 0.01119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50256	 92543	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50256	 92543	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50257	 52071	 0.011111	 0.089296	 0.02511	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50257	 52073	 0.01578	 0.0907	 0.02571	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50257	 58390	 0.024176	 0.084279	 0.01955	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50257	 92544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50257	 92544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50258	 52923	 0.000163	 0.001055	 0.0021	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50258	 92545	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50258	 92545	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50258	 93598	 0.000549	 0.004458	 0.00819	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50259	 52334	 0.00129	 0.014891	 0.1306	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50259	 53093	 0.001772	 0.018934	 0.27837	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50259	 53093	 0.001772	 0.018934	 0.27837	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50259	 56634	 0.00741	 0.082239	 0.81229	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50259	 92546	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50259	 92546	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50260	 52105	 0.001861	 0.022215	 0.20252	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50260	 52348	 0.00365	 0.042528	 0.36906	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50260	 92547	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50260	 92547	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50261	 52944	 0.000581	 0.006469	 0.061	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50261	 52948	 0.000102	 0.001312	 0.02201	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50261	 92548	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50261	 92548	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92549	 50261	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92549	 50261	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50262	 52237	 0.003963	 0.016364	 0.00387	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50262	 52240	 0.001831	 0.009537	 0.0025	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50262	 52241	 0.00236	 0.007696	 0.00204	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50262	 52863	 0.008805	 0.089739	 0.02314	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50263	 92550	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50263	 92550	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50264	 50273	 0.000277	 0.000965	 0.00022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50264	 52095	 0.001022	 0.003974	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50264	 52323	 0.011719	 0.082913	 0.02276	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50264	 92551	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50264	 92551	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50265	 52680	 0.002475	 0.031703	 0.00946	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50265	 52681	 0.001634	 0.017319	 0.00514	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50265	 92552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50265	 92552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50265	 93405	 0.001899	 0.025404	 0.00695	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50266	 52358	 4.8e-05	 0.000483	 0.00805	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50266	 52358	 4.8e-05	 0.000483	 0.00805	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50266	 52360	 6.8e-05	 0.000856	 0.01494	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50266	 52361	 8.7e-05	 0.001092	 0.01664	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50266	 92553	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50266	 92553	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50267	 52696	 0.00058	 0.003456	 0.00091	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50267	 52697	 0.001082	 0.00361	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50268	 52417	 0.00302	 0.010526	 0.00244	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50268	 92554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50268	 92554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50269	 52298	 0.006597	 0.015313	 0.00467	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50269	 52308	 0.008815	 0.026398	 0.00595	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50269	 92555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50269	 92555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50270	 52333	 0.01366	 0.068646	 0.01787	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50270	 53095	 0.034028	 0.13249	 0.03543	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50270	 53096	 0.007043	 0.056233	 0.01386	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50271	 52415	 0.010223	 0.059884	 0.01632	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50271	 93409	 0.002486	 0.020912	 0.00619	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50271	 93410	 0.002011	 0.027571	 0.01109	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50272	 52430	 0.009209	 0.10944	 0.03816	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50272	 53096	 0.004326	 0.031593	 0.00812	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50272	 53098	 0.004932	 0.033085	 0.00799	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50273	 52095	 0.001698	 0.005279	 0.0011	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50273	 52321	 0.013901	 0.058843	 0.01324	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50273	 92556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50273	 92556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50274	 52139	 0.036952	 0.093977	 0.00149	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50274	 52140	 0.052625	 0.16162	 0.00303	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50274	 93646	 0.055366	 0.093271	 0.00133	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50275	 52438	 0.005584	 0.028544	 0.00778	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50275	 52441	 0.001802	 0.011781	 0.003	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50275	 52442	 0.004241	 0.017656	 0.00551	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50275	 92557	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50275	 92557	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50276	 52105	 0.00097	 0.01085	 0.1014	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50276	 52577	 6.6e-05	 0.000716	 0.00702	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50276	 92558	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50276	 92558	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50277	 52091	 0.009194	 0.047895	 0.01256	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50277	 52278	 0.015329	 0.039407	 0.00976	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50277	 52280	 0.005286	 0.015911	 0.00498	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50277	 52281	 0.003555	 0.019598	 0.00458	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50278	 52852	 0.004233	 0.014262	 0.00354	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50278	 52853	 0.011885	 0.029877	 0.00774	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50278	 92559	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50278	 92559	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50279	 52361	 0.000259	 0.004536	 0.04305	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50279	 52366	 0.000503	 0.008657	 0.08548	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50279	 92560	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50279	 92560	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50280	 52265	 0.026437	 0.10805	 0.00219	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50280	 52748	 0.069718	 0.13804	 0.00203	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50280	 53052	 0.046129	 0.04614	 0.00062	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50280	 93519	 0.11382	 0.24307	 0.00549	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50281	 52441	 0.002719	 0.012472	 0.00319	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92533	 50281	 0.003888	 0.01934	 0.00624	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50282	 52427	 0.013223	 0.048112	 0.01473	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50282	 52462	 0.011698	 0.044469	 0.01245	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50282	 92561	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50282	 92561	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50283	 52335	 0.008583	 0.036329	 0.00817	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50283	 52381	 0.007905	 0.023305	 0.00542	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50283	 52851	 0.022668	 0.073953	 0.01964	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50283	 52855	 0.009478	 0.032515	 0.00779	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50283	 92562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50283	 92562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50284	 52611	 0.000525	 0.006655	 0.11622	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50284	 52713	 4.6e-05	 0.000735	 0.01207	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50284	 92563	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50284	 92563	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92564	 50284	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92564	 50284	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50285	 52460	 0.005044	 0.027806	 0.0065	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50285	 93426	 0.003127	 0.008105	 0.00245	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50285	 93427	 0.005242	 0.013476	 0.00334	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50286	 52767	 0.001388	 0.008614	 0.00209	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50286	 52768	 0.002311	 0.014638	 0.00397	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50287	 52088	 0.003653	 0.04708	 0.44508	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50287	 52170	 0.001982	 0.028171	 0.26692	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50287	 52806	 0.000483	 0.005685	 0.09932	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50287	 92565	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50287	 92565	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92566	 50287	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92566	 50287	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50288	 52754	 0.006907	 0.017755	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50288	 93522	 0.017187	 0.015831	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50289	 52286	 0.010572	 0.042328	 0.01067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50289	 52443	 0.002192	 0.008615	 0.00225	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50289	 92567	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50289	 92567	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50290	 52460	 0.012064	 0.040651	 0.0101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50290	 52462	 0.006702	 0.034262	 0.00934	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50290	 52852	 0.017237	 0.044754	 0.01086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50290	 92568	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50290	 92568	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50291	 50301	 0.033317	 0.24029	 0.06391	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50291	 51993	 0.026402	 0.19164	 0.1036	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50291	 53157	 0.013394	 0.13431	 0.04478	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50291	 53167	 0.012383	 0.040391	 0.01072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50291	 53294	 0.02739	 0.15756	 0.04471	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50292	 50301	 0.01583	 0.041839	 0.00979	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50292	 53113	 0.023736	 0.077438	 0.02057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50292	 53116	 0.009542	 0.060448	 0.01641	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50292	 53157	 0.026652	 0.070452	 0.0165	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50292	 53193	 0.052878	 0.17841	 0.04442	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50293	 53224	 0.002104	 0.017693	 0.00524	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50293	 53227	 0.003772	 0.019268	 0.00485	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50293	 53253	 0.006532	 0.040161	 0.01158	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50293	 53259	 0.000687	 0.007523	 0.00209	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50294	 53178	 0.000232	 0.002674	 0.02344	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50294	 53180	 0.000509	 0.005664	 0.05342	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50294	 53299	 0.007959	 0.091715	 0.84448	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50294	 53305	 0.000961	 0.012105	 0.18457	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50294	 92569	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50294	 92569	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50295	 53144	 0.036331	 0.17653	 0.04042	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50295	 53154	 0.021808	 0.054826	 0.01421	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50296	 53135	 0.019266	 0.15033	 0.04502	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50296	 53154	 0.026416	 0.070934	 0.01608	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50296	 92572	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50296	 92572	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50297	 53136	 0.066942	 0.1407	 0.00256	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50297	 53137	 0.023691	 0.039909	 0.00057	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50297	 53138	 0.074269	 0.14705	 0.00216	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50297	 93744	 0.096848	 0.29723	 0.00805	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50297	 93745	 0.12535	 0.28805	 0.00438	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50297	 93746	 0.30305	 0.3096	 0.00482	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50298	 53141	 0.002199	 0.005528	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50298	 53142	 0.000603	 0.001692	 0.00044	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50298	 53143	 0.004196	 0.011424	 0.00252	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50298	 92573	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50298	 92573	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50299	 53127	 0.00072	 0.009122	 0.15934	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50299	 92574	 0.000529	 0.028567	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50299	 92574	 0.000529	 0.028567	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92575	 50299	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92575	 50299	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50300	 53101	 0.020161	 0.08535	 0.01921	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50300	 53153	 0.021976	 0.13931	 0.03786	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50300	 53188	 0.001919	 0.017862	 0.00553	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50301	 53112	 0.007893	 0.031601	 0.00796	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50301	 53258	 0.028183	 0.22259	 0.06534	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50302	 53102	 0.023055	 0.10273	 0.00174	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50302	 53104	 0.024113	 0.061986	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50302	 53105	 0.005553	 0.03414	 0.00062	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50302	 93667	 0.010072	 0.050374	 0.0009	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50302	 93678	 0.93692	 0.6796	 0.0103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50303	 53185	 0.000254	 0.001922	 0.00094	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50303	 93697	 0.012341	 0.1009	 0.0274	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50304	 51716	 0.003065	 0.041923	 0.85825	 1646.0	 1728.3	 1810.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50304	 53132	 0.000254	 0.003033	 0.05157	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50304	 92576	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50304	 92576	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50305	 53219	 0.000987	 0.011865	 0.1174	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50305	 92578	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50305	 92578	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92579	 50305	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92579	 50305	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50306	 53121	 0.013606	 0.026666	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50306	 53122	 0.018944	 0.034049	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50306	 93674	 0.068068	 0.15569	 0.0038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50307	 53286	 0.00592	 0.020308	 0.00487	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50307	 92580	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50307	 92580	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50307	 93728	 0.001757	 0.007254	 0.00172	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50308	 53106	 0.038623	 0.1877	 0.04299	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50308	 53175	 0.009499	 0.03803	 0.00958	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50308	 53185	 0.013927	 0.074871	 0.01842	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50309	 93701	 0.009584	 0.0294	 0.0008	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50309	 93702	 0.054362	 0.22221	 0.0045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50310	 50361	 0.002657	 0.026154	 0.45536	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50310	 50361	 0.002657	 0.026154	 0.45536	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50310	 53910	 0.001037	 0.015778	 0.28302	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50310	 53994	 0.000876	 0.013547	 0.30794	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50310	 57029	 0.000393	 0.006704	 0.1183	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50310	 92581	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50310	 92581	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50311	 50346	 0.0002	 0.002116	 0.03164	 1500.0	 1570.0	 1650.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50311	 50346	 0.0002	 0.002116	 0.03164	 1500.0	 1570.0	 1650.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50311	 56574	 0.000268	 0.002769	 0.04351	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50311	 56574	 0.000268	 0.002769	 0.04351	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50311	 56580	 0.000311	 0.003207	 0.05039	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50311	 56580	 0.000311	 0.003207	 0.05039	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50311	 92583	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50311	 92583	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50312	 50329	 0.001638	 0.023741	 0.36546	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50312	 53945	 0.00173	 0.022367	 0.37617	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50312	 92584	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50312	 92584	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50313	 56743	 0.005714	 0.063109	 0.61899	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50313	 56852	 0.000944	 0.016567	 0.15734	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50313	 92587	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50313	 92587	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50314	 50387	 0.00165	 0.016335	 0.2799	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50314	 50387	 0.00165	 0.016335	 0.2799	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50314	 50520	 0.000543	 0.00596	 0.05789	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50314	 55522	 0.000778	 0.011209	 0.10286	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50314	 56392	 0.000757	 0.008578	 0.07811	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50314	 57460	 0.000435	 0.007897	 0.07895	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50314	 92590	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50314	 92590	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50315	 50385	 9e-06	 9.7e-05	 0.00152	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50315	 55762	 2e-05	 0.00028	 0.00453	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50315	 55768	 0.00042	 0.00364	 0.06814	 1072.0	 1072.0	 1072.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50315	 55940	 0.000187	 0.00432	 0.08272	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50315	 92592	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50315	 92592	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50316	 53854	 0.009086	 0.10323	 0.2078	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50316	 92593	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50316	 92593	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92594	 50316	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92594	 50316	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50316	 94653	 0.000191	 0.003046	 0.00625	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50317	 52223	 0.005588	 0.076215	 0.15554	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50317	 58427	 0.002064	 0.031797	 0.0701	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50317	 92595	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50317	 92595	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92596	 50317	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92596	 50317	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50318	 50324	 1.3e-05	 0.000145	 0.00141	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50318	 92597	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50318	 92597	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50319	 55031	 0.004438	 0.030113	 0.05485	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50319	 92600	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50319	 92600	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92601	 50319	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92601	 50319	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50319	 92732	 0.004102	 0.041492	 0.09423	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50319	 93932	 0.004338	 0.049146	 0.09852	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50320	 50361	 2e-05	 0.000342	 0.00744	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50320	 55310	 0.000232	 0.005782	 0.09468	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50320	 55355	 0.000278	 0.003524	 0.06154	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50320	 55366	 0.000485	 0.005318	 0.05166	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50320	 56026	 0.000695	 0.007008	 0.11536	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50320	 56026	 0.000695	 0.007008	 0.11536	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50320	 92602	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50320	 92602	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50321	 57283	 3.6e-05	 0.000509	 0.00486	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50321	 92605	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50321	 92605	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50322	 50407	 0.000358	 0.00413	 0.03621	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50322	 55381	 0.000243	 0.002655	 0.02606	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50322	 56852	 0.001563	 0.019809	 0.34648	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50322	 92606	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50322	 92606	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50323	 50327	 0.000239	 0.005615	 0.10648	 1940.0	 2037.0	 2134.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50323	 54088	 0.000336	 0.005288	 0.05511	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50323	 55378	 0.000483	 0.006538	 0.11518	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50323	 56586	 0.001675	 0.016591	 0.28429	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50323	 56586	 0.001675	 0.016591	 0.28429	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50323	 58553	 0.000442	 0.008673	 0.13901	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50323	 92609	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50323	 92609	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50324	 58446	 0.001876	 0.023341	 0.23477	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50324	 92611	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50324	 92611	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50325	 50505	 0.000525	 0.006098	 0.05856	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50325	 57337	 0.002033	 0.022328	 0.21713	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50325	 57419	 0.004796	 0.052871	 0.51706	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50325	 92614	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50325	 92614	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50326	 50333	 8e-06	 0.000125	 0.00122	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50326	 53544	 0.000512	 0.00542	 0.08106	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50326	 53544	 0.000512	 0.00542	 0.08106	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50326	 92616	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50326	 92616	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50327	 54088	 0.000337	 0.004239	 0.06461	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50327	 57162	 0.000288	 0.003908	 0.05954	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50327	 92617	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50327	 92617	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50328	 53374	 0.000994	 0.016192	 0.25297	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50328	 56290	 0.002682	 0.027739	 0.43716	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50328	 56290	 0.002682	 0.027739	 0.43716	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50328	 58185	 0.003446	 0.039861	 0.35064	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50328	 92618	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50328	 92618	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50329	 53945	 0.000611	 0.006923	 0.06303	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50329	 55537	 0.000697	 0.007763	 0.07321	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50329	 56250	 0.003008	 0.03043	 0.50271	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50329	 56250	 0.003008	 0.03043	 0.50271	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50329	 92621	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50329	 92621	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50330	 55941	 4.4e-05	 0.000633	 0.00581	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50330	 92622	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50330	 92622	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92623	 50330	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92623	 50330	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50331	 50333	 3e-06	 4.3e-05	 0.00069	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50331	 50485	 0.000272	 0.003377	 0.03129	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50331	 92624	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50331	 92624	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50332	 53980	 0.000576	 0.004041	 0.00688	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50332	 92625	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50332	 92625	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92626	 50332	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92626	 50332	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50332	 95295	 0.008341	 0.05664	 0.10327	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50333	 53549	 0.000185	 0.002933	 0.04816	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50334	 58352	 0.021803	 0.14975	 0.27236	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50334	 92627	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50334	 92627	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92628	 50334	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92628	 50334	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50334	 93807	 0.011323	 0.079538	 0.13577	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50335	 57327	 0.003638	 0.049557	 0.10097	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50335	 57681	 0.000199	 0.001982	 0.00661	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50335	 57710	 0.001745	 0.019754	 0.03956	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50335	 92629	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50335	 92629	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50336	 54784	 0.000128	 0.002144	 0.02024	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50336	 54814	 0.000407	 0.004031	 0.069	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50336	 54814	 0.000407	 0.004031	 0.069	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50336	 57443	 0.000259	 0.003936	 0.07053	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50336	 92630	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50336	 92630	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50337	 50439	 4.2e-05	 0.000661	 0.00674	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50337	 56634	 0.001932	 0.021208	 0.20622	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50337	 57158	 0.002229	 0.025276	 0.23043	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50337	 92632	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50337	 92632	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50338	 55085	 0.004544	 0.051139	 0.01343	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50338	 55092	 0.014032	 0.080646	 0.02286	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50338	 55099	 0.008296	 0.03806	 0.00975	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50338	 55100	 0.006475	 0.034419	 0.00799	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50338	 55102	 0.000649	 0.006234	 0.00181	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50338	 55104	 0.003799	 0.014932	 0.00391	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50338	 92635	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50338	 92635	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50339	 54011	 0.002102	 0.035768	 0.36394	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50339	 56810	 0.001869	 0.02158	 0.18937	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50339	 92636	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50339	 92636	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92637	 50339	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92637	 50339	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50340	 50476	 0.000297	 0.003307	 0.03118	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50340	 58311	 0.002806	 0.030834	 0.30019	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50340	 92638	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50340	 92638	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50341	 57145	 0.00279	 0.029158	 0.00981	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50341	 57149	 0.000646	 0.007962	 0.00257	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50341	 57150	 0.000939	 0.009013	 0.00262	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50341	 57151	 0.00367	 0.02596	 0.00712	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50342	 56531	 9.6e-05	 0.001114	 0.00963	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50342	 92640	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50342	 92640	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50343	 50354	 0.002658	 0.030155	 0.27509	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50343	 57192	 0.001395	 0.016106	 0.14127	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50343	 92643	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50343	 92643	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50344	 58422	 0.003493	 0.039663	 0.36238	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50344	 58565	 0.00034	 0.003735	 0.03628	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50344	 58567	 9.5e-05	 0.001595	 0.02893	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50344	 92644	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50344	 92644	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50345	 56932	 0.000263	 0.003022	 0.02961	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50345	 92645	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50345	 92645	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50346	 56574	 7.4e-05	 0.0012	 0.01873	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50346	 56732	 0.000346	 0.005553	 0.11107	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50346	 56743	 0.0009	 0.008909	 0.15253	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50346	 56743	 0.0009	 0.008909	 0.15253	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50346	 57783	 0.002517	 0.025436	 0.41973	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50346	 57783	 0.002517	 0.025436	 0.41973	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50346	 92646	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50346	 92646	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50347	 57327	 0.001283	 0.016144	 0.03859	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50347	 92647	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50347	 92647	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92648	 50347	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92648	 50347	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50347	 92725	 0.000362	 0.005886	 0.01162	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50348	 54309	 0.000277	 0.003919	 0.03738	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50348	 92649	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50348	 92649	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50349	 50427	 0.014601	 0.037909	 0.0092	 132.0	 132.0	 132.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50349	 57196	 0.003236	 0.025998	 0.00731	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50349	 92658	 0.01282	 0.11365	 0.03028	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50350	 56693	 0.000494	 0.007116	 0.06529	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50350	 56704	 9.5e-05	 0.002383	 0.03921	 1940.0	 2037.0	 2134.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50350	 57302	 0.000114	 0.001909	 0.03511	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50350	 92652	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50350	 92652	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92653	 50350	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92653	 50350	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50351	 56432	 0.004931	 0.036952	 0.00901	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50351	 56434	 0.003581	 0.014338	 0.00361	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50351	 56436	 0.0046	 0.01808	 0.00473	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50351	 56787	 0.009891	 0.084274	 0.02104	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50351	 57183	 0.010119	 0.026014	 0.00644	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50351	 92654	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50351	 92654	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50352	 50354	 0.000605	 0.006979	 0.06119	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50352	 92655	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50352	 92655	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50353	 55696	 0.000355	 0.002705	 0.00492	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50353	 55854	 0.000147	 0.001307	 0.0023	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50353	 92656	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50353	 92656	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50354	 50397	 0.000189	 0.00245	 0.05481	 1646.0	 1728.3	 1810.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50354	 50452	 0.003051	 0.034623	 0.31606	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50354	 54126	 0.002304	 0.023283	 0.38404	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50354	 54126	 0.002304	 0.023283	 0.38404	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50354	 92657	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50354	 92657	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50355	 50385	 0.00033	 0.0029	 0.05377	 1072.0	 1072.0	 1072.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50355	 54102	 0.000189	 0.002072	 0.02013	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50355	 55764	 0.000144	 0.001916	 0.03037	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50355	 56863	 0.00052	 0.006715	 0.11271	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50355	 92660	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50355	 92660	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92661	 50355	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92661	 50355	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92657	 50356	 0.005367	 0.05571	 0.12017	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50356	 92662	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50356	 92662	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50356	 94919	 0.002199	 0.030254	 0.06031	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50357	 55389	 0.009751	 0.038328	 0.01003	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50357	 56839	 0.064492	 0.16233	 0.04212	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50357	 57051	 0.025793	 0.093426	 0.02005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50357	 92663	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50357	 92663	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50358	 57237	 0.04991	 0.17143	 0.04114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50358	 58437	 0.041522	 0.15802	 0.04431	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92637	 50358	 0.003841	 0.028932	 0.00803	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50358	 92664	 0.004395	 0.017272	 0.00452	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92636	 50359	 0.001966	 0.01245	 0.02607	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50359	 92664	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50359	 92664	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50359	 94793	 0.005539	 0.038171	 0.06742	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50360	 57481	 0.003725	 0.015509	 0.00484	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50360	 57486	 0.001272	 0.013717	 0.00393	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50361	 55375	 0.000418	 0.004419	 0.06609	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50361	 55900	 0.000889	 0.009408	 0.14073	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50361	 55900	 0.000889	 0.009408	 0.14073	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50361	 92665	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50361	 92665	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50362	 56760	 0.000181	 0.004496	 0.07362	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50362	 57500	 0.000226	 0.005236	 0.0988	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50362	 92666	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50362	 92666	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50363	 53997	 0.0004	 0.006082	 0.10899	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50363	 56761	 6.2e-05	 0.001509	 0.02574	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50363	 57940	 0.000138	 0.002339	 0.05082	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50363	 57963	 6.1e-05	 0.001015	 0.01868	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50363	 92667	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50363	 92667	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50364	 50441	 0.000721	 0.00806	 0.07531	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50364	 55046	 0.003942	 0.050834	 0.48099	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50364	 57569	 0.000724	 0.008203	 0.07469	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50364	 92668	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50364	 92668	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92669	 50364	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92669	 50364	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50365	 52089	 0.000738	 0.0116	 0.12093	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50365	 92670	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50365	 92670	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92671	 50365	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92671	 50365	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50366	 50373	 4.1e-05	 0.000445	 0.00432	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50366	 57198	 6.1e-05	 0.000679	 0.0064	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50366	 92672	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50366	 92672	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50367	 56711	 0.0005	 0.011609	 0.21913	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50367	 57191	 0.000248	 0.003497	 0.05649	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50367	 92673	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50367	 92673	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50368	 58173	 0.001555	 0.010711	 0.01891	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50368	 58218	 0.000912	 0.009233	 0.01858	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50368	 92675	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50368	 92675	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92676	 50368	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92676	 50368	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50369	 57194	 0.002396	 0.036796	 0.0103	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50369	 57499	 0.025091	 0.066323	 0.01553	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92662	 50369	 0.005525	 0.022813	 0.0054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50370	 58273	 0.002048	 0.005414	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50370	 58278	 0.001922	 0.007553	 0.00198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50370	 58279	 0.002238	 0.009975	 0.00271	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50370	 58280	 0.002763	 0.029282	 0.00869	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50370	 92677	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50370	 92677	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50371	 50422	 9e-06	 0.000107	 0.00097	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50371	 58185	 0.001356	 0.015102	 0.14248	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50371	 92678	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50371	 92678	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50372	 50461	 0.0001	 0.001138	 0.01036	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50372	 55698	 0.000878	 0.012663	 0.11622	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50372	 55747	 0.000167	 0.002101	 0.03202	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50372	 92681	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50372	 92681	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92682	 50372	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92682	 50372	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50373	 57198	 9.7e-05	 0.001077	 0.01016	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50373	 57275	 0.000186	 0.003079	 0.02886	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50373	 92683	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50373	 92683	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50374	 56810	 0.00175	 0.019211	 0.18676	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50374	 57198	 0.000923	 0.010649	 0.09338	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50374	 92685	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50374	 92685	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50375	 53566	 0.001135	 0.013107	 0.11494	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50375	 92686	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50375	 92686	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50376	 50499	 0.000693	 0.00785	 0.07148	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50376	 54309	 0.002467	 0.02851	 0.25036	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50376	 58185	 0.00059	 0.00647	 0.06285	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50376	 92688	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50376	 92688	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50377	 55940	 5e-05	 0.00063	 0.0096	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50377	 92690	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50377	 92690	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92691	 50377	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92691	 50377	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50378	 55537	 0.000328	 0.00329	 0.05483	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50378	 57105	 0.001118	 0.018202	 0.28445	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50378	 92692	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50378	 92692	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50379	 53350	 0.002324	 0.036618	 0.38296	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50379	 57460	 0.000241	 0.004146	 0.04093	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50379	 92694	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50379	 92694	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50380	 54097	 0.00059	 0.006474	 0.06289	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50380	 56392	 0.001738	 0.0197	 0.1795	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50380	 92696	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50380	 92696	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92697	 50380	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92697	 50380	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50381	 55933	 9.8e-05	 0.001573	 0.01575	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50381	 92698	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50381	 92698	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92699	 50381	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92699	 50381	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50382	 53904	 0.00041	 0.002872	 0.00489	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50382	 53908	 0.00028	 0.003376	 0.00711	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50382	 92700	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50382	 92700	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50383	 50416	 0.004005	 0.044731	 0.42379	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50383	 56932	 0.002658	 0.029209	 0.2843	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50383	 92701	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50383	 92701	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50384	 57270	 0.018492	 0.084858	 0.02175	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50384	 57489	 0.006549	 0.02772	 0.00624	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50384	 94944	 0.005239	 0.030686	 0.00836	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55766	 50385	 0.00034	 0.00363	 0.06182	 1088.0	 1088.0	 1088.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50386	 56741	 0.000323	 0.003542	 0.0344	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50386	 56743	 8.7e-05	 0.000958	 0.00931	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50386	 92703	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50386	 92703	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50387	 57135	 0.005642	 0.060259	 0.91358	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50387	 57135	 0.005642	 0.060259	 0.91358	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50387	 92705	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50387	 92705	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92640	 50388	 0.0002	 0.001331	 0.00251	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50388	 92708	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50388	 92708	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50388	 94696	 0.000171	 0.00207	 0.004	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50389	 50453	 0.002488	 0.028945	 0.25066	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50389	 50477	 4.1e-05	 0.000468	 0.0041	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50389	 55051	 0.00018	 0.002829	 0.02949	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50389	 92709	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50389	 92709	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50390	 50485	 3e-06	 4.7e-05	 0.00083	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50390	 53832	 0.000524	 0.007392	 0.11941	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50390	 92710	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50390	 92710	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50391	 55837	 8e-05	 0.001092	 0.01112	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50391	 55853	 1.3e-05	 0.000217	 0.00394	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50392	 53406	 0.013858	 0.14702	 0.04371	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50392	 57434	 0.003399	 0.01361	 0.00343	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50392	 57438	 0.005094	 0.048654	 0.01786	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50392	 92712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50392	 92712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50392	 94805	 0.022788	 0.12723	 0.03253	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50393	 53334	 0.001528	 0.022134	 0.34062	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50393	 56932	 0.00396	 0.045172	 0.4098	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50393	 92713	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50393	 92713	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50394	 56442	 0.003855	 0.015436	 0.00389	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50394	 56444	 0.003148	 0.012603	 0.00318	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50394	 56448	 0.005735	 0.022313	 0.00596	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50394	 56453	 0.004298	 0.031206	 0.01078	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50394	 56537	 0.006456	 0.022821	 0.00514	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50394	 56542	 0.010166	 0.048119	 0.01157	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50394	 56545	 0.003272	 0.015484	 0.00372	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50394	 92715	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50394	 92715	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50395	 92716	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50395	 92716	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92717	 50395	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92717	 50395	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50395	 93276	 0.008266	 0.094387	 0.18761	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50395	 93287	 0.005022	 0.068461	 0.13964	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50395	 93313	 0.021497	 0.1425	 0.27844	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50395	 95321	 0.011334	 0.075725	 0.1431	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50396	 53566	 0.000546	 0.007146	 0.06468	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50396	 53827	 0.001563	 0.017406	 0.16425	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50396	 54309	 0.000661	 0.007492	 0.06822	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50396	 92718	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50396	 92718	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50397	 50431	 0.000139	 0.001374	 0.02352	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50397	 50431	 0.000139	 0.001374	 0.02352	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50398	 92721	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50398	 92721	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92722	 50398	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92722	 50398	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50398	 92736	 0.000237	 0.001583	 0.00298	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50398	 92837	 0.000181	 0.001632	 0.00322	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50399	 55522	 0.000188	 0.002171	 0.01903	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50399	 58236	 0.00144	 0.015718	 0.1544	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50399	 92723	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50399	 92723	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92724	 50399	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92724	 50399	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50400	 54921	 0.002119	 0.034486	 0.33706	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50400	 57309	 0.001325	 0.015012	 0.13673	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50400	 92725	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50400	 92725	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92726	 50400	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92726	 50400	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50401	 56392	 0.000263	 0.002929	 0.02762	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50401	 92727	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50401	 92727	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92728	 50401	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92728	 50401	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50402	 55392	 0.020061	 0.082849	 0.01961	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50402	 56941	 0.062283	 0.25415	 0.06216	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50402	 58563	 0.002579	 0.016863	 0.00429	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92713	 50402	 6.2e-05	 0.000605	 0.00019	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50403	 54761	 0.000363	 0.004268	 0.07455	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50403	 54784	 0.000361	 0.004662	 0.07824	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50403	 56777	 0.000713	 0.007781	 0.0764	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50403	 92729	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50403	 92729	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50404	 57196	 0.010793	 0.041993	 0.01122	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50404	 57453	 0.016657	 0.13533	 0.04314	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92658	 50404	 0.010943	 0.048767	 0.01325	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50404	 92731	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50404	 92731	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50405	 53994	 0.001004	 0.011182	 0.10548	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50405	 53995	 0.000431	 0.004729	 0.04594	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50405	 57275	 0.003855	 0.042426	 0.4139	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50405	 92732	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50405	 92732	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92733	 50405	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92733	 50405	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50406	 50442	 4e-05	 0.000463	 0.00406	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50406	 55421	 5.9e-05	 0.00067	 0.0061	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50406	 55435	 0.000181	 0.002046	 0.01862	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50406	 55459	 6.5e-05	 0.000876	 0.01335	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50407	 54513	 0.003825	 0.040637	 0.61145	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50407	 54513	 0.003825	 0.040637	 0.61145	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50407	 55381	 0.000304	 0.003538	 0.03058	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50407	 92734	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50407	 92734	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92735	 50407	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92735	 50407	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50408	 50538	 2e-05	 0.000276	 0.00275	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50408	 92736	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50408	 92736	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92737	 50408	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92737	 50408	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50409	 57500	 9.3e-05	 0.002315	 0.03791	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50409	 57568	 0.001722	 0.017056	 0.29228	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50409	 57568	 0.001722	 0.017056	 0.29228	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50409	 92738	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50409	 92738	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50410	 57249	 0.00112	 0.004359	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50410	 57252	 0.000751	 0.004839	 0.00127	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50411	 55573	 0.00483	 0.054032	 0.51303	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50411	 56395	 0.002489	 0.028226	 0.25743	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50411	 92739	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50411	 92739	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50412	 50462	 0.005446	 0.018348	 0.00456	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50412	 50486	 0.018252	 0.07429	 0.01811	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50412	 57496	 0.023443	 0.08044	 0.01928	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50412	 92741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50412	 92741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50412	 92746	 0.041062	 0.22161	 0.06108	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50413	 57001	 0.003052	 0.031168	 0.09904	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50413	 92742	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50413	 92742	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92743	 50413	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92743	 50413	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50414	 58019	 0.000784	 0.002689	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50414	 58021	 0.000801	 0.002749	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50414	 58022	 8.6e-05	 0.000574	 0.00018	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50414	 58044	 0.004885	 0.01134	 0.00345	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50414	 92744	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50414	 92744	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50415	 92745	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50415	 92745	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50415	 94919	 0.000799	 0.006419	 0.01392	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50416	 52348	 0.00291	 0.051148	 1.0682	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50416	 55573	 0.00292	 0.036383	 0.36668	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50416	 92746	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50416	 92746	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50417	 55055	 0.004343	 0.050308	 0.44347	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50417	 58254	 0.004837	 0.067606	 1.1674	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50417	 92748	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50417	 92748	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50418	 57339	 0.005332	 0.061889	 0.54713	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50418	 57571	 0.002488	 0.028217	 0.25734	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50418	 92749	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50418	 92749	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50419	 56723	 0.027018	 0.097867	 0.02101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50419	 56724	 0.048177	 0.16251	 0.04045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50419	 56839	 0.087072	 0.23762	 0.0525	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50419	 58351	 0.064481	 0.16762	 0.04075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50419	 58353	 0.057247	 0.15384	 0.03491	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50419	 58372	 0.037332	 0.12815	 0.03073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50419	 92750	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50419	 92750	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50420	 53895	 0.001798	 0.019627	 0.03807	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50420	 53993	 0.013905	 0.094597	 0.17292	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50420	 55371	 0.006528	 0.046208	 0.09794	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50420	 92751	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50420	 92751	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50421	 55466	 0.020254	 0.073353	 0.01574	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50421	 56607	 0.004062	 0.018943	 0.00469	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50421	 57077	 0.011906	 0.082604	 0.04847	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50422	 53374	 0.003939	 0.043353	 0.42302	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50422	 92752	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50422	 92752	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50423	 54716	 0.000108	 0.001301	 0.01287	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50423	 57685	 0.000685	 0.00791	 0.06934	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50423	 92753	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50423	 92753	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50424	 57196	 0.001865	 0.009049	 0.00207	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92655	 50424	 0.011129	 0.061353	 0.01434	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50425	 58349	 0.001959	 0.007843	 0.00198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50425	 58359	 0.001259	 0.004403	 0.00146	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50425	 92756	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50425	 92756	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50426	 50486	 0.004803	 0.012695	 0.00297	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50426	 57090	 0.022976	 0.080422	 0.02666	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50426	 57497	 0.00488	 0.019537	 0.00492	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50426	 57498	 0.004505	 0.0157	 0.00364	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50427	 57090	 0.01973	 0.049601	 0.01285	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92662	 50427	 0.005145	 0.021243	 0.00503	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50428	 50451	 0.007186	 0.026021	 0.00558	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50428	 56607	 0.025621	 0.071459	 0.015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92669	 50428	 0.002729	 0.026666	 0.00748	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50429	 57324	 0.000557	 0.007296	 0.06604	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50429	 57584	 0.000549	 0.006135	 0.05732	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50429	 57891	 0.000179	 0.00207	 0.01814	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50429	 92757	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50429	 92757	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50430	 50474	 0.009468	 0.037909	 0.00955	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50430	 50492	 0.002461	 0.006388	 0.00155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50430	 56607	 0.001514	 0.012591	 0.00381	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50430	 92774	 0.050168	 0.13269	 0.03109	 128.0	 128.0	 128.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50431	 50437	 0.000144	 0.00161	 0.01504	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50431	 57960	 0.000747	 0.007715	 0.12125	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50431	 57960	 0.000747	 0.007715	 0.12125	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50432	 57076	 0.003332	 0.030832	 0.05803	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50432	 92758	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50432	 92758	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92759	 50432	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92759	 50432	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50432	 94919	 0.020061	 0.13616	 0.25284	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50433	 57499	 0.007081	 0.028814	 0.00702	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92643	 50433	 0.011631	 0.049229	 0.01108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50434	 57309	 0.000761	 0.011721	 0.2045	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50434	 58567	 0.00039	 0.007036	 0.11105	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50434	 92760	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50434	 92760	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50435	 56629	 0.002055	 0.020939	 0.0054	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50435	 56631	 0.001474	 0.00767	 0.00226	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50435	 56633	 0.004538	 0.015566	 0.00373	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50436	 50451	 0.003922	 0.014909	 0.00417	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50436	 55466	 0.010666	 0.056494	 0.01432	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92669	 50436	 0.004265	 0.040766	 0.01344	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50437	 57968	 0.00039	 0.004341	 0.04094	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50438	 50469	 0.009112	 0.024081	 0.00564	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50438	 52872	 0.014824	 0.060331	 0.0147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50438	 55581	 0.018334	 0.042562	 0.01297	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50439	 57419	 0.000563	 0.0064	 0.0578	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50439	 92762	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50439	 92762	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50440	 92763	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50440	 92763	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50440	 92767	 0.000249	 0.002294	 0.00562	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50440	 94755	 0.0006	 0.004192	 0.0072	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50441	 50480	 0.00041	 0.00406	 0.06949	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50441	 50480	 0.00041	 0.00406	 0.06949	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50442	 55421	 8.6e-05	 0.000992	 0.0087	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50442	 55941	 0.001157	 0.013115	 0.11944	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50442	 92764	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50442	 92764	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50443	 58282	 0.008036	 0.029098	 0.00624	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50443	 58291	 0.000897	 0.009504	 0.00282	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50443	 92765	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50443	 92765	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50444	 55376	 0.003798	 0.028612	 0.00794	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50444	 58382	 0.018242	 0.047362	 0.0115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50444	 92766	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50444	 92766	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50444	 93891	 0.017897	 0.049913	 0.01048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50445	 56685	 5.2e-05	 0.000594	 0.00536	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50445	 56693	 0.000192	 0.002218	 0.01945	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50445	 56719	 0.000865	 0.009805	 0.08928	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50445	 92767	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50445	 92767	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50446	 57192	 0.000315	 0.00557	 0.09149	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50446	 57968	 0.000211	 0.003212	 0.05755	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50446	 92768	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50446	 92768	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50447	 55297	 0.003906	 0.041399	 0.01229	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50447	 57193	 0.003183	 0.008875	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50447	 57194	 0.003258	 0.015421	 0.00371	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92745	 50447	 0.013966	 0.035903	 0.00889	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50447	 94920	 0.001568	 0.016113	 0.0051	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50448	 53882	 0.000736	 0.009327	 0.16293	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50448	 53900	 0.000366	 0.004146	 0.03774	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50448	 92769	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50448	 92769	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92770	 50448	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92770	 50448	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50449	 53907	 0.000143	 0.002425	 0.02459	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50449	 92771	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50449	 92771	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50450	 57196	 0.002482	 0.026776	 0.00766	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50450	 92772	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50450	 92772	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50450	 92832	 0.000533	 0.005612	 0.00315	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50450	 94920	 0.011282	 0.033786	 0.00761	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50452	 57192	 0.00217	 0.023831	 0.2318	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50452	 92773	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50452	 92773	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50453	 55167	 0.00914	 0.1338	 1.4353	 717.0	 717.0	 717.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50453	 58311	 0.000221	 0.002554	 0.02238	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50453	 92776	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50453	 92776	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50453	 95332	 0.002357	 0.045551	 0.90024	 1000.0	 1000.0	 1000.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50453	 95332	 0.002357	 0.045551	 0.90024	 1000.0	 1000.0	 1000.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50454	 56574	 0.000135	 0.001778	 0.02847	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50454	 56743	 0.000612	 0.007951	 0.13183	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50454	 57584	 0.000864	 0.015223	 0.25299	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50454	 92777	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50454	 92777	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50455	 55769	 9.4e-05	 0.001658	 0.02753	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50455	 55938	 8.9e-05	 0.001103	 0.01022	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50455	 55941	 0.000159	 0.002107	 0.03375	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50456	 56817	 0.002491	 0.029586	 0.01031	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50456	 56818	 0.009285	 0.042596	 0.01091	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50456	 56824	 0.000136	 0.001716	 0.00053	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50456	 92778	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50456	 92778	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50457	 55586	 0.003079	 0.029565	 0.0086	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50457	 55589	 0.002479	 0.018757	 0.00921	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50457	 55591	 0.006661	 0.025321	 0.00709	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50457	 55592	 0.004198	 0.016805	 0.00423	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50457	 92779	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50457	 92779	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50458	 55114	 0.00241	 0.02554	 0.00758	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50458	 55202	 0.004556	 0.043746	 0.01273	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50458	 55206	 0.002734	 0.013964	 0.00351	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50458	 55207	 0.000464	 0.006542	 0.00224	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50458	 55218	 0.002561	 0.0282	 0.01443	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50458	 92780	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50458	 92780	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50459	 56853	 0.005853	 0.035401	 0.00903	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50459	 56854	 0.00268	 0.020531	 0.0055	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50459	 56857	 0.007654	 0.031146	 0.00759	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50459	 57346	 0.011943	 0.065847	 0.01539	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50459	 92781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50459	 92781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50460	 55757	 0.000525	 0.006423	 0.01319	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50460	 92782	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50460	 92782	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50460	 94426	 0.001116	 0.007071	 0.01481	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50460	 94501	 0.000185	 0.001384	 0.00536	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50461	 55748	 0.000165	 0.002762	 0.02607	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50461	 92783	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50461	 92783	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92784	 50461	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92784	 50461	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50462	 53835	 0.018015	 0.0701	 0.01873	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50462	 55460	 0.018585	 0.075643	 0.01843	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50462	 57497	 0.016469	 0.057637	 0.01911	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50463	 54181	 0.000222	 0.002938	 0.04706	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50463	 54185	 0.000204	 0.002397	 0.04187	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50463	 54189	 0.00021	 0.002778	 0.0445	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50463	 56622	 0.000341	 0.005706	 0.10498	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50463	 92785	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50463	 92785	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92748	 50464	 0.007831	 0.050447	 0.01323	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50464	 94973	 0.003846	 0.015396	 0.00388	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50465	 53900	 0.000159	 0.001807	 0.01632	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50465	 53907	 0.000109	 0.001718	 0.0179	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50465	 92786	 0.000529	 0.028567	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50465	 92786	 0.000529	 0.028567	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50466	 55182	 0.006344	 0.016469	 0.004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50466	 55194	 0.001472	 0.009321	 0.00253	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50466	 92789	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50466	 92789	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50466	 94225	 0.000314	 0.003203	 0.00083	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50467	 57196	 0.00301	 0.013101	 0.00373	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50468	 50471	 0.021106	 0.06354	 0.01988	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50468	 55475	 0.01299	 0.097889	 0.02718	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50468	 56633	 0.017919	 0.061479	 0.01473	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50468	 92790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50468	 92790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50469	 52869	 0.03361	 0.13221	 0.03462	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50469	 56629	 0.049517	 0.20994	 0.04735	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50469	 92791	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50469	 92791	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50470	 56980	 0.001084	 0.011239	 0.02158	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50470	 92792	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50470	 92792	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50471	 54090	 0.004651	 0.016209	 0.00376	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50472	 55421	 5e-05	 0.000581	 0.00509	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50472	 55437	 0.000465	 0.005098	 0.04952	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50472	 92793	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50472	 92793	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50473	 57342	 0.019852	 0.11022	 0.03353	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50473	 94973	 0.012031	 0.055198	 0.01414	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50474	 56598	 0.00783	 0.039611	 0.01103	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50474	 56601	 0.005811	 0.019935	 0.00478	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50474	 56603	 0.001566	 0.005696	 0.00174	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50475	 92794	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50475	 92794	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92795	 50475	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92795	 50475	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50475	 94502	 0.000259	 0.002102	 0.00386	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50476	 57339	 0.000625	 0.007429	 0.06821	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50477	 92796	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50477	 92796	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92797	 50477	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92797	 50477	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50478	 57090	 0.006915	 0.027688	 0.00698	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92662	 50478	 0.002626	 0.018732	 0.00581	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50479	 55660	 0.000123	 0.001391	 0.01267	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50479	 55747	 0.000323	 0.003733	 0.03272	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50479	 92798	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50479	 92798	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92799	 50479	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92799	 50479	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50480	 53968	 0.005328	 0.05684	 0.86042	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50480	 53968	 0.005328	 0.05684	 0.86042	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50480	 57192	 0.002661	 0.02924	 0.2846	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50480	 57569	 0.001049	 0.011511	 0.11184	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50480	 92800	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50480	 92800	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50481	 57304	 0.000444	 0.004695	 0.07021	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50481	 57304	 0.000444	 0.004695	 0.07021	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50481	 57305	 0.000143	 0.00217	 0.03888	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50481	 57331	 0.000543	 0.010449	 0.17439	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50482	 53994	 7.6e-05	 0.000875	 0.00767	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50482	 53995	 0.00054	 0.005924	 0.05754	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50482	 92801	 0.0008	 0.039992	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50482	 92801	 0.0008	 0.039992	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50483	 55298	 0.006951	 0.084483	 0.02277	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50483	 57496	 0.015501	 0.041619	 0.00943	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50483	 57499	 0.00672	 0.036184	 0.00994	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50484	 54929	 0.000533	 0.002199	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50484	 54930	 0.000551	 0.00328	 0.00086	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50484	 54932	 0.001059	 0.007734	 0.00199	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50484	 92802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50484	 92802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50485	 53549	 0.000509	 0.005666	 0.05343	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50485	 92803	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50485	 92803	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50486	 57498	 0.004168	 0.014525	 0.00337	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92643	 50486	 0.008884	 0.078733	 0.02097	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50487	 56848	 0.001801	 0.012632	 0.02151	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92618	 50487	 0.003699	 0.025941	 0.04418	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50487	 92804	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50487	 92804	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50488	 55267	 0.025761	 0.062092	 0.01753	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50488	 94188	 0.020138	 0.079171	 0.02072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50488	 94246	 0.011263	 0.065982	 0.01798	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50489	 53334	 0.001004	 0.012718	 0.22223	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50489	 55062	 0.000615	 0.007939	 0.13327	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50489	 58540	 0.000815	 0.008063	 0.13805	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50489	 58540	 0.000815	 0.008063	 0.13805	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50490	 55299	 0.020834	 0.052378	 0.01357	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50490	 55583	 0.048505	 0.30859	 0.08429	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50490	 92805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50490	 92805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50491	 55940	 4.8e-05	 0.000529	 0.00514	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50491	 92806	 0.000357	 0.024997	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 0	 -30.0	 30.0;
	50491	 92806	 0.000357	 0.024997	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 0	 -30.0	 30.0;
	92807	 50491	 0.001184	 0.059188	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92807	 50491	 0.001184	 0.059188	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50493	 55591	 0.002304	 0.019165	 0.0058	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50493	 56649	 0.006364	 0.03391	 0.00952	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50493	 94737	 0.004282	 0.022197	 0.00542	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50494	 53601	 0.002298	 0.009199	 0.00232	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50494	 53623	 0.00108	 0.006324	 0.00172	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50494	 53625	 0.002498	 0.007165	 0.00176	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50494	 53627	 0.002677	 0.009368	 0.0031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50494	 53636	 0.001977	 0.01392	 0.00791	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50494	 92808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50494	 92808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50495	 55433	 0.012836	 0.033925	 0.00794	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92764	 50495	 0.000294	 0.001023	 0.00024	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50495	 92809	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50495	 92809	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50496	 53977	 0.014369	 0.060823	 0.01369	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50496	 53979	 0.011272	 0.043853	 0.01171	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50496	 56882	 0.015682	 0.066383	 0.01494	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50496	 56885	 0.002922	 0.026579	 0.00671	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50496	 92810	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50496	 92810	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50497	 56244	 0.000118	 0.001714	 0.0155	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50497	 56290	 0.000747	 0.01022	 0.15292	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50497	 92811	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50497	 92811	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92812	 50497	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92812	 50497	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50498	 92813	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50498	 92813	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50498	 94832	 0.002357	 0.008333	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50499	 58180	 5.2e-05	 0.000634	 0.01016	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50499	 58185	 0.000123	 0.001368	 0.0129	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50499	 92814	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50499	 92814	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92782	 50500	 0.002821	 0.011295	 0.00285	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50500	 94428	 0.000962	 0.009723	 0.00286	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50500	 94495	 0.000661	 0.007127	 0.00204	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50501	 54071	 0.000905	 0.00305	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50501	 92815	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50501	 92815	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50502	 52873	 0.002794	 0.029625	 0.44446	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50502	 52873	 0.002794	 0.029625	 0.44446	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50502	 57158	 0.000605	 0.006638	 0.06448	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50502	 57159	 0.000369	 0.0042	 0.03793	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50502	 92816	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50502	 92816	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50503	 53915	 0.001749	 0.017816	 0.00459	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50503	 93905	 0.001705	 0.016713	 0.00524	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50504	 57507	 0.10579	 0.31852	 0.00623	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92816	 50504	 0.015878	 0.04038	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50505	 55573	 0.001281	 0.017211	 0.30794	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50505	 92817	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50505	 92817	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50506	 55810	 0.002741	 0.007862	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50506	 55811	 0.006925	 0.017611	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50506	 94510	 0.005154	 0.010548	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50507	 57200	 0.010044	 0.026965	 0.00611	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50507	 57251	 0.003598	 0.009509	 0.00223	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50507	 92819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50507	 92819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50508	 53881	 0.000427	 0.004684	 0.04549	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50508	 53882	 9e-05	 0.001131	 0.01102	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50508	 55435	 0.001045	 0.012067	 0.10582	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50508	 92820	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50508	 92820	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50509	 57273	 0.000334	 0.002333	 0.004	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50509	 92821	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50509	 92821	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50509	 94793	 0.002398	 0.016816	 0.02863	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50510	 54807	 0.004355	 0.012358	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50510	 94122	 0.002958	 0.008484	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50511	 94752	 6.9e-05	 0.000611	 0.00034	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50511	 94951	 0.001526	 0.023431	 0.00656	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50512	 57250	 0.001842	 0.006319	 0.00151	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50512	 57268	 0.005152	 0.018655	 0.004	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50513	 57189	 0.026691	 0.10691	 0.02695	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50513	 92822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50513	 92822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50514	 54097	 0.000393	 0.004857	 0.07699	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50514	 58236	 0.000603	 0.006619	 0.0643	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50514	 92823	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50514	 92823	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50515	 55757	 5e-05	 0.000608	 0.00118	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50515	 92824	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50515	 92824	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92825	 50515	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92825	 50515	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50515	 94435	 0.00065	 0.006928	 0.01255	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50516	 53982	 0.002732	 0.009373	 0.00225	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50516	 53983	 0.002787	 0.014515	 0.00381	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50517	 56711	 0.000244	 0.002714	 0.0256	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50517	 56720	 0.000133	 0.001512	 0.01365	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50517	 92826	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50517	 92826	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50518	 56703	 0.000787	 0.003329	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50518	 56706	 0.000948	 0.003793	 0.00128	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50519	 94753	 0.006218	 0.014435	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50519	 94759	 0.009674	 0.024867	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50520	 55531	 0.000534	 0.008893	 0.09394	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50520	 92829	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50520	 92829	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92830	 50520	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92830	 50520	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50521	 56704	 3.1e-05	 0.000506	 0.0051	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50521	 56705	 4.8e-05	 0.00079	 0.00775	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50521	 92831	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50521	 92831	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50522	 50547	 0.001023	 0.003139	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50523	 92832	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50523	 92832	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50523	 93920	 0.010175	 0.093824	 0.37356	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50523	 94919	 0.001092	 0.009691	 0.01717	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50524	 57286	 0.005604	 0.019223	 0.00461	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50524	 94947	 0.000342	 0.004455	 0.00129	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50524	 94951	 0.000764	 0.008279	 0.00508	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50525	 55475	 0.00148	 0.009376	 0.00254	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50525	 55479	 0.006041	 0.038914	 0.0102	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50525	 56423	 0.068653	 0.1817	 0.04261	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50526	 55818	 0.01025	 0.023797	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50526	 94453	 0.004118	 0.009461	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50527	 56599	 0.28116	 0.22256	 0.0028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50527	 94718	 0.027632	 0.065432	 0.0012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50527	 94719	 0.049353	 0.11195	 0.00223	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50528	 57324	 0.000124	 0.002272	 0.04187	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50528	 57335	 2.5e-05	 0.00061	 0.01052	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50528	 92833	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50528	 92833	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50529	 58251	 0.000599	 0.006812	 0.06152	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50529	 92834	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50529	 92834	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50530	 57557	 0.055396	 0.16675	 0.00326	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50530	 58570	 0.23039	 0.51034	 0.00838	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50531	 55582	 0.13645	 0.41895	 0.01136	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50531	 56628	 0.22547	 0.24564	 0.00335	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50531	 94726	 0.006029	 0.026414	 0.00057	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50532	 57199	 8.6e-05	 0.000977	 0.00889	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50532	 57275	 6.7e-05	 0.000739	 0.00718	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50532	 92835	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50532	 92835	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50533	 56642	 0.002011	 0.012734	 0.00346	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50533	 56644	 0.01118	 0.052918	 0.01273	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50533	 57472	 0.009006	 0.065782	 0.01691	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50534	 94431	 0.016953	 0.043113	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50535	 56611	 0.02446	 0.12447	 0.00282	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50535	 56612	 0.014361	 0.047907	 0.00076	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50535	 56616	 0.031723	 0.024866	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50535	 56617	 0.00724	 0.040681	 0.00075	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50536	 53852	 0.005296	 0.032908	 0.00929	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50536	 54091	 0.006273	 0.028779	 0.00737	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92824	 50537	 0.000738	 0.003443	 0.00085	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50537	 92836	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50537	 92836	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50537	 94432	 0.000329	 0.003756	 0.00115	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50537	 94440	 0.001534	 0.005119	 0.0013	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50538	 57198	 0.000567	 0.00817	 0.07496	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50538	 92837	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50538	 92837	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50539	 58291	 0.009469	 0.037219	 0.00974	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50539	 93933	 0.009559	 0.038902	 0.00948	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50540	 56513	 0.06125	 0.10174	 0.00216	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50540	 93936	 0.069774	 0.069792	 0.00094	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50541	 56568	 0.046019	 0.17519	 0.04914	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50541	 58563	 0.002136	 0.008395	 0.0022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50542	 56888	 0.016975	 0.03051	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50542	 56890	 0.004974	 0.021914	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50542	 56901	 0.002154	 0.013524	 0.0003	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50542	 56902	 0.004409	 0.017154	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50542	 56902	 0.004409	 0.017154	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50542	 94357	 0.053914	 0.33157	 0.00598	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50542	 94823	 0.010438	 0.040605	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50542	 94823	 0.010438	 0.040605	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50543	 55030	 0.056773	 0.22089	 0.00369	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50543	 55030	 0.056773	 0.22089	 0.00369	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50543	 56843	 0.066067	 0.54368	 0.01055	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50543	 58283	 0.015507	 0.060325	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50543	 58284	 0.14699	 0.11634	 0.00146	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50543	 58286	 0.024935	 0.11111	 0.00189	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50543	 95247	 0.035545	 0.17064	 0.0051	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50544	 53920	 0.001293	 0.003251	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50544	 53923	 0.000511	 0.001391	 0.00031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50544	 53924	 0.001562	 0.006355	 0.00155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50545	 56554	 0.019324	 0.09214	 0.02671	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50545	 56556	 0.008024	 0.033962	 0.00764	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50545	 56557	 0.00622	 0.021986	 0.00495	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92742	 50545	 0.000286	 0.003062	 0.00098	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50545	 92840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50545	 92840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50546	 54104	 0.009825	 0.074024	 0.02055	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50546	 56671	 0.001488	 0.016667	 0.0053	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50546	 92841	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50546	 92841	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50546	 94770	 0.00684	 0.027387	 0.0069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50547	 94728	 0.007219	 0.024081	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50547	 94731	 0.005608	 0.018709	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50548	 57199	 7.5e-05	 0.000846	 0.0077	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50548	 92842	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50548	 92842	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50549	 58413	 0.001288	 0.004895	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50549	 58414	 0.002103	 0.011139	 0.00282	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50549	 92843	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50549	 92843	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50550	 92844	 0.27571	 0.21825	 0.00275	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50550	 92845	 0.095634	 0.17518	 0.00302	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50550	 92942	 0.12471	 0.38319	 0.0072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50551	 50553	 0.007431	 0.025491	 0.00611	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50551	 50608	 0.015072	 0.088309	 0.02407	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50551	 92844	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50551	 92844	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50552	 50556	 0.12405	 0.28807	 0.00429	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92844	 50552	 0.012277	 0.036951	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50553	 50554	 0.005044	 0.019621	 0.00524	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50553	 92845	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50553	 92845	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50554	 92966	 0.012607	 0.032675	 0.00989	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50555	 50556	 0.072742	 0.18701	 0.00289	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92467	 50555	 0.077143	 0.27019	 0.00748	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50557	 50577	 0.001367	 0.016971	 0.15734	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50557	 50893	 0.001094	 0.012129	 0.11551	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50557	 92846	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92847	 50557	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91977	 50558	 0.022346	 0.13731	 0.00314	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50558	 92850	 0.007804	 0.030023	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50558	 92850	 0.007804	 0.030023	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50558	 92898	 0.079407	 0.38144	 0.01141	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50559	 50560	 9.4e-05	 0.001735	 0.01667	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50559	 50893	 0.000652	 0.008222	 0.08015	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50559	 92848	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50559	 92848	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50560	 92849	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50561	 50562	 0.014012	 0.0631	 0.01679	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50561	 50988	 0.018797	 0.073897	 0.01934	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50561	 92851	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50561	 92851	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50562	 93661	 0.019816	 0.09245	 0.02291	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50563	 51224	 0.00495	 0.08793	 0.04425	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50563	 92852	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50563	 92852	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50563	 92990	 0.017141	 0.12339	 0.03273	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50564	 51030	 0.085903	 0.24642	 0.00379	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92471	 50564	 0.037976	 0.12669	 0.00201	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92471	 50565	 0.056324	 0.13077	 0.00194	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92852	 50565	 0.076268	 0.16882	 0.00277	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50566	 50569	 0.027816	 0.018008	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50567	 50570	 0.003728	 0.010008	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50568	 50569	 0.009715	 0.017528	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50569	 92853	 0.009078	 0.021497	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50570	 50977	 0.032716	 0.086491	 0.02025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92459	 50570	 0.051132	 0.19929	 0.05336	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50570	 92853	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50570	 92853	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50571	 50572	 0.05513	 0.16915	 0.00458	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50571	 92942	 0.038262	 0.13398	 0.00371	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50572	 50625	 0.087302	 0.23145	 0.00587	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50573	 92854	 0.040471	 0.08013	 0.00118	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50574	 50623	 0.017414	 0.069734	 0.01757	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92450	 50574	 0.017401	 0.13992	 0.03938	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50574	 92854	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50574	 92854	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92854	 50575	 0.03237	 0.042544	 0.00058	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50576	 92856	 0.028186	 0.071683	 0.00113	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50577	 51754	 0.000594	 0.007487	 0.11412	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50577	 92855	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50578	 50642	 0.014092	 0.049814	 0.01123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92855	 50578	 0.009713	 0.033319	 0.00798	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50579	 50585	 0.009036	 0.032873	 0.01006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50579	 50720	 0.021419	 0.085751	 0.02898	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50580	 50587	 0.003849	 0.017659	 0.00452	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50580	 50589	 0.009547	 0.04041	 0.00909	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92457	 50580	 0.009032	 0.092053	 0.02373	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50580	 92857	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50580	 92857	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50581	 50582	 0.002495	 0.009808	 0.00257	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50581	 51148	 0.001229	 0.007434	 0.0019	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50581	 93007	 0.010941	 0.051785	 0.01245	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50582	 50588	 0.006637	 0.026086	 0.00682	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50582	 92858	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50582	 92858	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50583	 50584	 0.049366	 0.049862	 0.00066	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50584	 92859	 0.010373	 0.024083	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50585	 92859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50585	 92859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50586	 51161	 0.16653	 0.16822	 0.00223	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92857	 50586	 0.099833	 0.18288	 0.00316	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50588	 50589	 0.005702	 0.020746	 0.00635	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50589	 50591	 0.005383	 0.024698	 0.00633	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50590	 51151	 0.10312	 0.075875	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50591	 50613	 0.008347	 0.040511	 0.00926	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50591	 92860	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50591	 92860	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50592	 50913	 0.015476	 0.076477	 0.02235	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50592	 50924	 0.030977	 0.091359	 0.02126	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50592	 50925	 0.032536	 0.10968	 0.02728	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50593	 50669	 0.49036	 0.32972	 0.00582	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50593	 92964	 0.35166	 0.32411	 0.0052	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50594	 50630	 0.006024	 0.030268	 0.00788	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50594	 92861	 0.009704	 0.051589	 0.01197	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50595	 50596	 0.093188	 0.11156	 0.00186	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50596	 50633	 0.059605	 0.26565	 0.00451	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50596	 92862	 0.037691	 0.14664	 0.00245	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50596	 92933	 0.1319	 0.26121	 0.00383	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50597	 92861	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92454	 50598	 0.026492	 0.052453	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92454	 50599	 0.027315	 0.069468	 0.0011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50600	 51220	 0.005109	 0.0834	 0.04981	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50600	 51564	 0.023847	 0.10743	 0.02861	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50600	 93137	 0.046337	 0.1824	 0.04781	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50601	 50691	 0.086082	 0.34463	 0.00728	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50601	 92954	 0.12254	 0.47704	 0.00797	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50601	 93383	 0.066869	 0.39902	 0.01116	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50602	 50603	 0.005038	 0.015666	 0.00327	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50602	 92863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50602	 92863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50603	 51026	 0.028323	 0.084842	 0.01912	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50603	 92864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50603	 92864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92465	 50604	 0.08	 0.14435	 0.00209	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92469	 50604	 0.091294	 0.25912	 0.00407	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50605	 50606	 0.003185	 0.012391	 0.00331	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50605	 51009	 0.018527	 0.072836	 0.01906	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92465	 50607	 0.068491	 0.12545	 0.00217	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50607	 92959	 0.3692	 0.39467	 0.00835	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92445	 50608	 0.003674	 0.013366	 0.00409	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92450	 50608	 0.065559	 0.23791	 0.05119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92478	 50608	 0.044839	 0.11858	 0.02778	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50608	 92865	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50608	 92865	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92446	 50609	 0.10262	 0.15722	 0.00221	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50610	 50914	 0.032742	 0.086561	 0.02027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50610	 51248	 0.014169	 0.083012	 0.02262	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92445	 50610	 0.002644	 0.022674	 0.00645	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50611	 50877	 0.004117	 0.057716	 0.0469	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50611	 52333	 0.00497	 0.088274	 0.04442	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50612	 92867	 0.19958	 0.26237	 0.0036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50613	 92866	 0.006768	 0.030849	 0.00979	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50614	 50617	 0.000149	 0.00257	 0.0442	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50614	 50619	 0.000174	 0.002934	 0.0532	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50615	 92868	 0.049177	 0.04967	 0.00066	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50616	 50617	 6.1e-05	 0.001081	 0.01795	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50616	 51114	 0.001917	 0.027856	 0.25236	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50616	 92866	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50617	 92868	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50617	 92868	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50618	 50621	 0.000414	 0.007346	 0.00369	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50618	 92869	 0.000363	 0.006202	 0.00336	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50619	 50622	 0.000124	 0.002131	 0.0371	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50619	 92869	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50619	 92869	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50620	 92871	 0.081627	 0.0646	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50621	 92870	 0.000233	 0.003904	 0.00221	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50622	 52360	 0.000828	 0.010943	 0.17534	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50622	 52366	 0.00048	 0.005896	 0.09447	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50622	 92870	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50623	 50626	 0.007937	 0.032299	 0.00787	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50623	 92872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50623	 92872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50624	 50625	 0.041761	 0.077651	 0.00182	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92872	 50624	 0.13801	 0.24097	 0.00373	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50625	 92873	 0.027744	 0.11742	 0.00221	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50626	 50629	 0.002999	 0.01588	 0.00403	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50626	 92873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50626	 92873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91200	 50627	 0.001682	 0.021154	 0.00655	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91956	 50627	 0.006011	 0.049131	 0.01333	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92450	 50627	 0.046273	 0.24728	 0.06969	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50627	 92874	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50627	 92874	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50628	 50631	 0.006747	 0.032553	 0.00057	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92874	 50628	 0.007485	 0.036525	 0.00063	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50629	 50630	 0.003191	 0.014641	 0.00375	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50630	 92875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50630	 92875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50631	 50632	 0.015221	 0.010782	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92875	 50631	 0.0083	 0.040503	 0.0007	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92874	 50633	 0.008756	 0.053834	 0.00097	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50634	 50635	 0.002407	 0.01896	 0.00555	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50634	 51219	 0.018104	 0.11845	 0.03015	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50635	 50989	 0.029433	 0.12465	 0.02807	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50635	 51749	 0.024886	 0.10537	 0.02372	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50636	 50639	 0.056698	 0.10543	 0.00247	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92863	 50636	 0.068904	 0.33635	 0.00581	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50637	 92876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50637	 92876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50638	 50639	 0.02583	 0.039563	 0.00069	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92473	 50638	 0.015091	 0.035736	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50638	 92994	 0.32989	 0.36304	 0.00485	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92473	 50639	 0.030515	 0.054504	 0.0008	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50640	 50641	 0.054858	 0.15568	 0.00245	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92473	 50640	 0.078605	 0.18061	 0.00274	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50640	 92886	 0.086107	 0.33509	 0.0056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50641	 50955	 0.13794	 0.26422	 0.00416	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50641	 92950	 0.15624	 0.36286	 0.0054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50642	 50643	 0.011656	 0.039275	 0.00976	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50643	 50644	 0.012986	 0.035357	 0.00779	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92849	 50644	 0.01825	 0.074281	 0.0181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50645	 50649	 0.003597	 0.010604	 0.00247	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50645	 50901	 0.006466	 0.04013	 0.00972	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50646	 50659	 0.002525	 0.00866	 0.00207	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50646	 50662	 0.00429	 0.028777	 0.00695	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50646	 92877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50646	 92877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50647	 50649	 0.001669	 0.006072	 0.00186	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50647	 50657	 0.001289	 0.00516	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50648	 50650	 0.006092	 0.017473	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50648	 50654	 0.029618	 0.029915	 0.0004	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50648	 92879	 0.021039	 0.016491	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50649	 92878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50649	 92878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50650	 50652	 0.009308	 0.022041	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92877	 50650	 0.013029	 0.034442	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92878	 50650	 0.002701	 0.011969	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92482	 50651	 0.043501	 0.047846	 0.00064	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50652	 50653	 0.020588	 0.022644	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92482	 50652	 0.007106	 0.022788	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92878	 50652	 0.026273	 0.018993	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92878	 50653	 0.042014	 0.032227	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50654	 50666	 0.034913	 0.02763	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50655	 50664	 0.16387	 0.11847	 0.0018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50655	 50666	 0.016592	 0.03285	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50656	 50658	 0.025504	 0.019991	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50656	 50666	 0.074684	 0.052903	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50657	 50659	 0.001283	 0.005136	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50657	 92879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50657	 92879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92879	 50658	 0.015625	 0.023936	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50660	 50661	 0.07185	 0.056862	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92877	 50660	 0.009608	 0.032051	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50660	 92880	 0.035826	 0.092097	 0.00143	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50662	 50803	 0.004874	 0.027195	 0.00695	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50662	 92880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50662	 92880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92880	 50663	 0.076833	 0.12763	 0.0027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50665	 51214	 0.14579	 0.15881	 0.00216	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92482	 50665	 0.038274	 0.10978	 0.00169	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92482	 50666	 0.017031	 0.052248	 0.00142	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50667	 50978	 0.029897	 0.086622	 0.0209	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92483	 50667	 0.029721	 0.09919	 0.02517	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50667	 92881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50667	 92881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92881	 50668	 0.069643	 0.11732	 0.00167	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50669	 92892	 0.15783	 0.28918	 0.00499	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50670	 50672	 0.08769	 0.11526	 0.00158	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50670	 92884	 0.073607	 0.15775	 0.00276	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50670	 92992	 0.090022	 0.3217	 0.00639	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50671	 92882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50671	 92882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50671	 92883	 0.00518	 0.013907	 0.00315	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50672	 50674	 0.019454	 0.068072	 0.00141	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92882	 50672	 0.006235	 0.024255	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92882	 50672	 0.006235	 0.024255	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50672	 92991	 0.062429	 0.27675	 0.00831	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50673	 50733	 0.003812	 0.043482	 0.39433	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50673	 51031	 0.001491	 0.01792	 0.17739	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50673	 51045	 0.005274	 0.058197	 0.56997	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50673	 92883	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50674	 51030	 0.19993	 0.39603	 0.00582	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92884	 50675	 0.033842	 0.097065	 0.00149	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50675	 93035	 0.12748	 0.36189	 0.00569	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50676	 51010	 0.016567	 0.067427	 0.01643	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92461	 50676	 0.014911	 0.058613	 0.01534	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50677	 51032	 0.011665	 0.091944	 0.02691	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92459	 50677	 0.006119	 0.049159	 0.01382	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50678	 50683	 0.009744	 0.025297	 0.00614	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50678	 50716	 0.01942	 0.075571	 0.02019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50678	 50886	 0.033469	 0.13165	 0.03447	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92475	 50678	 0.01754	 0.048917	 0.01027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50679	 50683	 0.006104	 0.01417	 0.00432	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92475	 50679	 0.006026	 0.016406	 0.00361	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50680	 50681	 0.0129	 0.013172	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50680	 50686	 0.008848	 0.013555	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50680	 50687	 0.025099	 0.01686	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50680	 50688	 0.042698	 0.030866	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92476	 50680	 0.010841	 0.02757	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50681	 50682	 0.018198	 0.013389	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92476	 50684	 0.03204	 0.082363	 0.00127	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50685	 50686	 0.10478	 0.082928	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50689	 50717	 0.001915	 0.021027	 0.20446	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92483	 50690	 0.004581	 0.024349	 0.00565	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92458	 50691	 0.02833	 0.13155	 0.00359	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50692	 50695	 0.004299	 0.014748	 0.00353	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92483	 50692	 0.009776	 0.053895	 0.0126	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50693	 92885	 0.032242	 0.074854	 0.00111	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92460	 50694	 0.12885	 0.29921	 0.00445	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50694	 92885	 0.035601	 0.076292	 0.00134	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50695	 92885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50695	 92885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92458	 50696	 0.011102	 0.028235	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50697	 50698	 0.038763	 0.075969	 0.00114	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50697	 50973	 0.0906	 0.21457	 0.00392	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50698	 50700	 0.019177	 0.045412	 0.00083	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50698	 50701	 0.12961	 0.17036	 0.00234	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92877	 50698	 0.10952	 0.36548	 0.0058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50699	 50700	 0.03979	 0.035655	 0.00073	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50701	 50939	 0.082159	 0.21123	 0.00327	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50702	 51017	 0.020667	 0.054627	 0.01279	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50702	 51026	 0.014649	 0.050256	 0.01204	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50702	 92886	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50702	 92886	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50703	 50704	 0.021693	 0.015367	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50704	 50705	 0.026489	 0.040578	 0.00057	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92886	 50704	 0.014381	 0.034054	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92886	 50706	 0.040919	 0.026491	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50707	 51022	 0.072306	 0.057223	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92886	 50707	 0.032824	 0.027017	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92886	 50708	 0.097909	 0.14998	 0.00261	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50708	 92986	 0.08181	 0.16744	 0.00412	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92886	 50709	 0.029598	 0.076085	 0.00118	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50710	 92887	 0.15406	 0.24598	 0.00567	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50711	 50886	 0.005193	 0.084775	 0.05063	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50711	 51219	 0.023282	 0.13532	 0.0319	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50711	 92887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50711	 92887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50712	 50713	 0.086395	 0.16547	 0.0026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50712	 92970	 0.15105	 0.49882	 0.00809	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50712	 93027	 0.047821	 0.21073	 0.00366	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50712	 93035	 0.22636	 0.48548	 0.00851	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50713	 51028	 0.5091	 0.5148	 0.00682	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50714	 92888	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50714	 92888	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50715	 51226	 0.003889	 0.061666	 0.03902	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92888	 50715	 0.000384	 0.006091	 0.00385	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50716	 92889	 0.018404	 0.074909	 0.01826	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50717	 92889	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50717	 92889	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50718	 50722	 0.005405	 0.096027	 0.04833	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50718	 51240	 0.004911	 0.087232	 0.04389	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50718	 92890	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50718	 92890	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50719	 50720	 0.005555	 0.040338	 0.01394	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50719	 50914	 0.010613	 0.08364	 0.02448	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50720	 50721	 0.00713	 0.032711	 0.00838	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50720	 92891	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50720	 92891	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92457	 50721	 0.019923	 0.082282	 0.01947	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50721	 92892	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50721	 92892	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50722	 50957	 0.009042	 0.14782	 0.08848	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50722	 92893	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50722	 92893	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50723	 50725	 0.21919	 0.16609	 0.00229	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50723	 93033	 0.11648	 0.33418	 0.00514	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50724	 51230	 0.053846	 0.14243	 0.03337	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50724	 52060	 0.017425	 0.089103	 0.0243	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50724	 92894	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50724	 92894	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92894	 50725	 0.056416	 0.11057	 0.00166	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50726	 50729	 0.00197	 0.010432	 0.00264	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50726	 50925	 0.011376	 0.070606	 0.01711	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50727	 50728	 0.002531	 0.010134	 0.00255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50727	 92895	 0.004095	 0.016094	 0.00421	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50728	 50729	 0.004045	 0.014096	 0.00327	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50728	 92896	 0.002208	 0.017399	 0.00509	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50730	 50921	 0.0028	 0.01929	 0.03406	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50730	 92895	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50730	 92895	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50731	 92896	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50731	 92896	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50732	 51170	 0.025736	 0.10631	 0.02517	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92451	 50732	 0.026646	 0.10849	 0.02645	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50733	 92897	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50733	 92897	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50734	 50735	 0.003467	 0.014676	 0.0033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92447	 50734	 0.027574	 0.10843	 0.02839	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92847	 50734	 0.008192	 0.070274	 0.02	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92447	 50735	 0.024896	 0.10135	 0.02471	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50735	 92898	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50735	 92898	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92448	 50736	 0.067469	 0.20722	 0.00389	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92898	 50736	 0.061651	 0.14101	 0.00344	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50737	 50739	 0.010718	 0.051229	 0.01794	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50737	 92899	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50737	 92899	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50738	 50740	 0.049289	 0.10909	 0.00179	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92899	 50738	 0.058048	 0.11377	 0.00171	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92847	 50739	 0.009228	 0.048875	 0.01239	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92482	 50740	 0.054633	 0.16779	 0.00315	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50740	 92938	 0.040604	 0.10762	 0.00273	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50741	 50742	 0.014938	 0.059814	 0.01507	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50741	 51844	 0.021562	 0.086355	 0.02176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50742	 50941	 0.003245	 0.05295	 0.03161	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50742	 51223	 0.022554	 0.095491	 0.0215	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50743	 50744	 0.026496	 0.020968	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50743	 50753	 0.009496	 0.036942	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50743	 93059	 0.005544	 0.020798	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50744	 50745	 0.004891	 0.009094	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50744	 51281	 0.006456	 0.013212	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50745	 50746	 0.012031	 0.012284	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50745	 92900	 0.006343	 0.014726	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50746	 50748	 0.005039	 0.014453	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50746	 51282	 0.004873	 0.019032	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50747	 50776	 0.005439	 0.014602	 0.00331	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50747	 51317	 0.004086	 0.013768	 0.00342	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50747	 92900	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50747	 92900	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50747	 93051	 0.002816	 0.019916	 0.00546	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50748	 50749	 0.008359	 0.020747	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50748	 50778	 0.014129	 0.017224	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50749	 50750	 0.024008	 0.017006	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50749	 50755	 0.008831	 0.014096	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50749	 50775	 0.019937	 0.014122	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50750	 50754	 0.009294	 0.018402	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50750	 50755	 0.011005	 0.018279	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92900	 50750	 0.006997	 0.016241	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50751	 50752	 0.023023	 0.01822	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92900	 50751	 0.011109	 0.01379	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50753	 92901	 0.00614	 0.017008	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50754	 50758	 0.008549	 0.015424	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50755	 50771	 0.007244	 0.01862	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50756	 50757	 0.007199	 0.014732	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50756	 50764	 0.008836	 0.014104	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50757	 50762	 0.015487	 0.025866	 0.00044	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92900	 50757	 0.008262	 0.033063	 0.0007	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50757	 92902	 0.043532	 0.042061	 0.00061	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50758	 92901	 0.010699	 0.018023	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50759	 50760	 0.001065	 0.004794	 0.00128	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50759	 92901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50759	 92901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50760	 50761	 0.001474	 0.00676	 0.00173	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50760	 92902	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50760	 92902	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50761	 50831	 0.00133	 0.007298	 0.00193	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50761	 92903	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50761	 92903	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50762	 50767	 0.029135	 0.027322	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50763	 50765	 0.016225	 0.031798	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92900	 50763	 0.012681	 0.055874	 0.00097	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92903	 50763	 0.060584	 0.047945	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50764	 50765	 0.017857	 0.023238	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50764	 50768	 0.022205	 0.017573	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50765	 50766	 0.013648	 0.017938	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50765	 50773	 0.025745	 0.020375	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50765	 92914	 0.006162	 0.022011	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50766	 50767	 0.016454	 0.017311	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92903	 50767	 0.011359	 0.017724	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50768	 50772	 0.005021	 0.012906	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50768	 50774	 0.006979	 0.012976	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50769	 50772	 0.015243	 0.018247	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50769	 50792	 0.027989	 0.01812	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50770	 50774	 0.007535	 0.017493	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50770	 50786	 0.011342	 0.014079	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50770	 50813	 0.027097	 0.027369	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50771	 50772	 0.002718	 0.012112	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50771	 50775	 0.005159	 0.018431	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50773	 50774	 0.018008	 0.014115	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50775	 50777	 0.008344	 0.00852	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92900	 50775	 0.014674	 0.037722	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50775	 92904	 0.010567	 0.018993	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50776	 50779	 0.001287	 0.005152	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50776	 92904	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50776	 92904	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92904	 50777	 0.006167	 0.011084	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50778	 92905	 0.008945	 0.017711	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50779	 50784	 0.001775	 0.006088	 0.00146	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50779	 92905	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50779	 92905	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50780	 51284	 0.014627	 0.015931	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50781	 51287	 0.009913	 0.038137	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92905	 50781	 0.006503	 0.015094	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50781	 92906	 0.027938	 0.02211	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50782	 50783	 0.010483	 0.026948	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50782	 50787	 0.020385	 0.030917	 0.00044	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50782	 50796	 0.049896	 0.039111	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50783	 50794	 0.008113	 0.020634	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92904	 50783	 0.007181	 0.01629	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50783	 93052	 0.021349	 0.094066	 0.00163	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50784	 51286	 0.002187	 0.007132	 0.00189	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50784	 92906	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50784	 92906	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92906	 50785	 0.039248	 0.028372	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50786	 92913	 0.010719	 0.024884	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50786	 92928	 0.027652	 0.036342	 0.0005	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50787	 50790	 0.026991	 0.022216	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50788	 50794	 0.023167	 0.016747	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50789	 50791	 0.017849	 0.016104	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50789	 50795	 0.023498	 0.015213	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50790	 50791	 0.012022	 0.015801	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50790	 92907	 0.008674	 0.024878	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50791	 50792	 0.021595	 0.01709	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50792	 50871	 0.010187	 0.025906	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50792	 92928	 0.014195	 0.040713	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50793	 50871	 0.004636	 0.010761	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92904	 50793	 0.005685	 0.016131	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50794	 50795	 0.008818	 0.017282	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50796	 50799	 0.045421	 0.035946	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50796	 50872	 0.015473	 0.033158	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50796	 93053	 0.028493	 0.064632	 0.00129	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50797	 50798	 0.004392	 0.015306	 0.00355	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50797	 50815	 0.005205	 0.013755	 0.00322	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50797	 92907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50797	 92907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50798	 50803	 0.006977	 0.029532	 0.00665	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50798	 92908	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50798	 92908	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50799	 50800	 0.017977	 0.041736	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50799	 50801	 0.011797	 0.023356	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50799	 93053	 0.035098	 0.071827	 0.00177	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92908	 50800	 0.016516	 0.030709	 0.00072	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50801	 50802	 0.00881	 0.017444	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50802	 51312	 0.015489	 0.039816	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50803	 92909	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50803	 92909	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50804	 50805	 0.040849	 0.044929	 0.0006	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50804	 92925	 0.03637	 0.10074	 0.00166	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50805	 92910	 0.031091	 0.033864	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50806	 50855	 0.021805	 0.014116	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50807	 50808	 0.001438	 0.003861	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50807	 92910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50807	 92910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50808	 50811	 0.001747	 0.004055	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50808	 92911	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50808	 92911	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92910	 50809	 0.006553	 0.015214	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50809	 92923	 0.006404	 0.019665	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50810	 50816	 0.009821	 0.022563	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92911	 50810	 0.008192	 0.015232	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50811	 50848	 0.000904	 0.004984	 0.00116	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50811	 50870	 0.002953	 0.012292	 0.00383	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50811	 92912	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50811	 92912	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92911	 50812	 0.01581	 0.028526	 0.00041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50812	 92928	 0.027353	 0.03595	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50813	 50814	 0.017539	 0.017715	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50813	 50822	 0.023407	 0.018524	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50814	 92913	 0.008838	 0.017499	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50815	 50823	 0.006264	 0.016817	 0.00381	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50815	 50870	 0.001995	 0.005272	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50815	 92913	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50815	 92913	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92913	 50816	 0.005184	 0.011109	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50817	 50818	 0.018056	 0.01806	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50817	 50821	 0.004123	 0.014426	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92913	 50817	 0.011962	 0.027483	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50818	 50819	 0.021832	 0.020109	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50819	 50825	 0.006408	 0.011914	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50819	 50827	 0.010545	 0.019027	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50820	 50844	 0.017185	 0.018718	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50821	 50833	 0.004111	 0.015993	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50822	 92914	 0.017786	 0.017965	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50823	 50828	 0.001954	 0.005165	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50823	 92914	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50823	 92914	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50824	 50825	 0.006111	 0.012843	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92914	 50824	 0.007517	 0.01745	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50826	 50827	 0.006148	 0.01205	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50826	 92919	 0.007714	 0.01983	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50828	 50831	 0.002791	 0.007377	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50828	 92915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50828	 92915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92915	 50829	 0.01618	 0.016227	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50829	 92916	 0.021172	 0.025809	 0.00041	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50830	 50839	 0.008071	 0.018738	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92915	 50830	 0.007639	 0.024497	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50830	 92919	 0.01048	 0.024331	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50831	 50832	 0.001143	 0.006809	 0.00179	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50832	 50835	 0.000784	 0.005128	 0.0013	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50832	 92916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50832	 92916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50833	 50844	 0.018055	 0.018236	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50833	 50850	 0.006428	 0.016523	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50833	 50851	 0.010297	 0.023907	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92912	 50833	 0.028842	 0.028849	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50834	 50847	 0.0444	 0.035138	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50834	 92917	 0.14587	 0.10545	 0.0016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50834	 92922	 0.052749	 0.053279	 0.00071	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50835	 50836	 0.002066	 0.008271	 0.00208	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50835	 50838	 0.001993	 0.007978	 0.00201	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50836	 50838	 0.001943	 0.007778	 0.00196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50836	 92917	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50836	 92917	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50836	 92926	 0.001728	 0.015749	 0.00572	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50837	 50842	 0.023398	 0.018517	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92917	 50837	 0.009773	 0.02331	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50837	 92918	 0.035267	 0.025494	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50838	 50840	 0.002283	 0.005927	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50838	 50841	 0.00161	 0.004322	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50838	 92918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50838	 92918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92918	 50839	 0.007251	 0.014902	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50840	 50841	 0.001618	 0.004276	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50840	 92919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50840	 92919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50841	 50852	 0.009352	 0.025155	 0.00705	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50841	 92920	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50841	 92920	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50843	 50845	 0.01802	 0.018024	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92919	 50843	 0.014509	 0.013001	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50844	 50845	 0.018608	 0.020466	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50844	 50846	 0.020445	 0.034442	 0.00049	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50846	 50847	 0.012068	 0.024801	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92920	 50846	 0.031064	 0.024583	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50847	 50869	 0.019539	 0.05405	 0.00126	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50848	 50852	 0.001176	 0.004576	 0.00122	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50848	 50859	 0.004034	 0.016151	 0.00407	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50848	 92921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50848	 92921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50849	 50853	 0.011612	 0.023862	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50849	 50867	 0.027731	 0.051563	 0.00121	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92921	 50850	 0.005034	 0.014438	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50851	 50854	 0.023315	 0.016854	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50851	 92922	 0.007083	 0.018773	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50852	 50857	 0.001734	 0.004494	 0.00136	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50852	 50859	 0.002667	 0.012233	 0.00313	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50852	 92922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50852	 92922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92922	 50853	 0.007252	 0.016835	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50855	 50858	 0.009486	 0.01598	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50855	 92923	 0.014985	 0.011859	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92921	 50856	 0.006303	 0.011912	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50856	 92923	 0.006832	 0.013527	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50857	 50859	 0.00266	 0.010981	 0.0026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50857	 92923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50857	 92923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92484	 50858	 0.02912	 0.074858	 0.00116	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92923	 50858	 0.009335	 0.0143	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50859	 50865	 0.003329	 0.019981	 0.00605	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92466	 50860	 0.040894	 0.032363	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50861	 50863	 0.000674	 0.003829	 0.00111	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50861	 50866	 0.001762	 0.008998	 0.00226	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92484	 50862	 0.011318	 0.028783	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50862	 92924	 0.007116	 0.020409	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50863	 50864	 0.001408	 0.00634	 0.00169	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50863	 92924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50863	 92924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50865	 92925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50865	 92925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50866	 50932	 0.003406	 0.027191	 0.0067	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50867	 50933	 0.025261	 0.11257	 0.00191	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92484	 50867	 0.027378	 0.080509	 0.00165	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50868	 92926	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92927	 50868	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50868	 92956	 0.001633	 0.010343	 0.02166	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50868	 92976	 0.022885	 0.15646	 0.28805	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92927	 50869	 0.01677	 0.06524	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50870	 92928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50870	 92928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50870	 93051	 0.00711	 0.045804	 0.01201	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92907	 50872	 0.014252	 0.0265	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92452	 50873	 0.079908	 0.31095	 0.00519	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92893	 50873	 0.18674	 0.39269	 0.00716	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50874	 50875	 0.05285	 0.17632	 0.0028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50874	 93020	 0.15914	 0.32584	 0.00802	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50875	 50876	 0.053709	 0.17918	 0.00284	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50875	 51006	 0.037466	 0.17908	 0.00392	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92480	 50876	 0.16731	 0.26931	 0.00422	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92483	 50877	 0.033854	 0.11855	 0.03933	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50877	 92929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50877	 92929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50878	 50879	 0.016917	 0.034765	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92477	 50878	 0.034969	 0.092687	 0.00235	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50879	 92930	 0.016692	 0.038174	 0.00093	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50879	 92931	 0.034592	 0.045465	 0.00062	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50880	 50881	 0.004566	 0.016534	 0.00355	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50880	 50965	 0.009379	 0.037553	 0.00946	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50880	 92930	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50880	 92930	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50881	 50882	 0.001684	 0.009396	 0.0024	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50881	 92931	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50881	 92931	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50882	 92961	 0.027304	 0.10937	 0.02757	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50883	 50884	 0.011904	 0.054616	 0.01399	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50883	 52252	 0.016599	 0.070265	 0.01581	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50883	 92932	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50883	 92932	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50884	 92933	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50884	 92933	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92933	 50885	 0.091437	 0.13869	 0.00199	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50886	 50967	 0.049771	 0.1389	 0.02918	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50886	 92997	 0.034504	 0.10337	 0.0233	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50887	 50888	 0.00149	 0.009356	 0.0002	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50887	 50889	 0.010608	 0.024371	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50887	 50890	 0.005346	 0.012225	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50888	 92940	 0.004992	 0.031348	 0.00069	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50889	 92935	 0.019554	 0.045397	 0.00068	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50890	 50892	 0.005623	 0.021874	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50891	 50902	 0.000238	 0.003362	 0.03206	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50891	 92934	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92935	 50892	 0.006051	 0.023541	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50893	 50902	 0.000303	 0.004731	 0.04985	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50893	 92936	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50893	 92936	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50894	 50895	 0.007668	 0.031206	 0.0076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50894	 50900	 0.006607	 0.033199	 0.00864	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92936	 50894	 0.003381	 0.02996	 0.00798	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50895	 50896	 0.003337	 0.013361	 0.00337	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92934	 50895	 0.003311	 0.013256	 0.00334	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92455	 50896	 0.010603	 0.043781	 0.01036	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50897	 50901	 0.004234	 0.021063	 0.0068	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50897	 51313	 0.004986	 0.0236	 0.00567	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50897	 92937	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50897	 92937	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50898	 51310	 0.068771	 0.0895	 0.00125	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92937	 50898	 0.093969	 0.094915	 0.00126	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50898	 92938	 0.052816	 0.10809	 0.00266	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92909	 50899	 0.054138	 0.11379	 0.00207	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50899	 92939	 0.031684	 0.081448	 0.00126	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50900	 50901	 0.004832	 0.018993	 0.00497	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50900	 92938	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50900	 92938	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50901	 92939	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50901	 92939	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50902	 92940	 0.001096	 0.056989	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50902	 92940	 0.001096	 0.056989	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50903	 51031	 0.002163	 0.023758	 0.23108	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50903	 51572	 0.005413	 0.056651	 0.8919	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50903	 51572	 0.005413	 0.056651	 0.8919	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50903	 92941	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50903	 92941	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50904	 50905	 0.012382	 0.051126	 0.0121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92450	 50904	 0.011651	 0.044288	 0.0124	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50905	 92942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50905	 92942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50906	 51235	 0.033687	 0.13116	 0.03507	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50906	 92943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50906	 92943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50907	 50911	 0.000524	 0.004799	 0.00192	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92478	 50907	 0.0018	 0.020578	 0.00628	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50908	 50909	 0.00165	 0.007808	 0.00188	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50908	 50913	 0.005534	 0.016657	 0.00521	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50908	 50914	 0.012607	 0.042479	 0.01056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50909	 50911	 0.002665	 0.010476	 0.00274	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50909	 50913	 0.004979	 0.02284	 0.00585	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92478	 50909	 0.00344	 0.033611	 0.00943	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50909	 92944	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50909	 92944	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92944	 50910	 0.041159	 0.031571	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50911	 50914	 0.002458	 0.026642	 0.00833	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50912	 51239	 0.018924	 0.080111	 0.01803	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92478	 50912	 0.009142	 0.041504	 0.01441	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50912	 92945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50912	 92945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50914	 92946	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50914	 92946	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50915	 92948	 0.016499	 0.067151	 0.01636	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50915	 92995	 0.016727	 0.065087	 0.01739	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50916	 50918	 0.012074	 0.046974	 0.01255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50916	 92995	 0.008884	 0.033769	 0.00945	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50917	 92947	 0.076692	 0.12572	 0.00222	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50917	 92996	 0.12257	 0.28042	 0.00685	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50918	 50919	 0.001956	 0.009493	 0.00217	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50918	 92947	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50918	 92947	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50919	 50920	 0.000769	 0.00373	 0.00085	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50920	 92948	 0.006132	 0.035916	 0.00978	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50921	 50998	 0.005125	 0.034965	 0.06299	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50921	 51044	 0.005679	 0.046129	 0.08485	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50921	 92948	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92949	 50921	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92876	 50922	 0.076614	 0.23509	 0.00637	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50922	 92950	 0.044434	 0.15559	 0.00431	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92949	 50923	 0.42768	 0.33867	 0.00426	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50923	 92951	 0.093165	 0.23953	 0.00371	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50924	 50925	 0.012363	 0.049503	 0.01247	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50924	 92950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50924	 92950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50925	 92951	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50925	 92951	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50926	 92953	 0.11231	 0.25807	 0.00392	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50926	 92965	 0.07073	 0.32788	 0.00629	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50927	 50929	 0.005435	 0.032621	 0.00988	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50927	 92952	 0.00653	 0.041361	 0.01123	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50928	 92952	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92953	 50928	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50928	 92976	 0.004194	 0.037382	 0.06572	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50929	 51577	 0.009092	 0.051688	 0.01496	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50930	 92954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50930	 92954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50930	 92955	 0.00073	 0.011905	 0.0071	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50930	 93280	 0.004017	 0.060436	 0.04254	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50931	 92955	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50931	 92955	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50932	 50937	 0.003842	 0.029948	 0.00895	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92467	 50933	 0.052819	 0.2055	 0.00343	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92467	 50933	 0.052819	 0.2055	 0.00343	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50933	 92957	 0.015099	 0.072475	 0.00217	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50934	 50935	 0.000585	 0.006186	 0.09252	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50934	 50935	 0.000585	 0.006186	 0.09252	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50934	 51288	 0.001719	 0.019854	 0.17419	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50934	 92956	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92450	 50936	 0.006008	 0.053244	 0.01418	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50936	 92958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50936	 92958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92467	 50938	 0.11979	 0.077558	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92958	 50939	 0.064059	 0.1311	 0.00323	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50940	 50941	 0.014898	 0.059653	 0.01503	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92941	 50941	 0.013469	 0.093484	 0.0267	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50941	 92959	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50941	 92959	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50942	 50944	 0.001605	 0.018063	 0.00522	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50942	 93040	 0.003178	 0.030324	 0.01229	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92932	 50943	 0.12721	 0.29541	 0.00439	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50943	 92960	 0.071062	 0.16327	 0.00248	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50944	 92960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50944	 92960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50944	 92961	 0.008619	 0.034509	 0.00869	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92960	 50945	 0.052814	 0.041797	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50946	 50947	 0.015137	 0.032438	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92960	 50946	 0.007767	 0.04039	 0.00088	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50947	 92962	 0.037359	 0.083818	 0.00134	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50948	 92961	 9.7e-05	 0.007789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50949	 92963	 0.018486	 0.0366	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92962	 50950	 0.039786	 0.19417	 0.00335	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50951	 92963	 0.004001	 0.011353	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50952	 50953	 0.000885	 0.007111	 0.002	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92961	 50952	 0.004125	 0.035997	 0.00989	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50952	 92963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50952	 92963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50953	 52468	 0.00315	 0.018452	 0.00503	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50954	 53085	 0.003879	 0.027437	 0.00753	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92961	 50954	 0.008901	 0.04907	 0.01147	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50954	 92964	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50954	 92964	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50955	 50956	 0.04932	 0.13073	 0.00332	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92950	 50955	 0.16339	 0.46891	 0.00722	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50955	 92986	 0.097861	 0.46052	 0.00858	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92945	 50956	 0.064186	 0.28129	 0.00605	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50957	 93031	 0.024617	 0.14309	 0.03373	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50957	 93567	 0.004895	 0.07991	 0.04772	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92514	 50958	 0.087142	 0.15015	 0.00239	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50959	 50960	 0.012323	 0.06077	 0.01643	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50959	 51733	 0.016514	 0.075775	 0.01942	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50959	 92965	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50959	 92965	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92447	 50960	 0.004448	 0.074441	 0.04223	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92855	 50960	 0.02238	 0.11903	 0.02764	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50962	 51247	 0.003572	 0.034003	 0.06044	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92449	 50962	 0.007057	 0.06265	 0.26655	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50962	 92966	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92967	 50962	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50963	 51244	 0.16288	 0.16453	 0.00218	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92967	 50963	 0.016247	 0.063208	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50964	 50965	 0.008584	 0.049862	 0.01174	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92966	 50964	 0.003157	 0.018489	 0.00504	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50964	 92968	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50964	 92968	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50965	 92969	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50965	 92969	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50966	 50967	 0.012722	 0.049498	 0.01322	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50966	 51029	 0.022901	 0.05888	 0.01458	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50966	 51237	 0.031884	 0.13504	 0.03042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92897	 50967	 0.017443	 0.078559	 0.02091	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50968	 51237	 0.047961	 0.23711	 0.06435	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50968	 92970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50968	 92970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50968	 93129	 0.01506	 0.10454	 0.02986	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50969	 50973	 0.08108	 0.18826	 0.0028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50969	 51215	 0.037122	 0.12384	 0.00196	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50970	 50972	 0.010717	 0.052017	 0.01189	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50970	 51213	 0.011976	 0.054946	 0.01408	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50971	 92971	 0.12249	 0.096943	 0.00122	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92478	 50972	 0.011254	 0.061987	 0.02239	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50972	 92971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50972	 92971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92971	 50973	 0.030813	 0.1568	 0.00355	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50974	 51032	 0.030679	 0.11669	 0.03269	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50974	 51600	 0.058475	 0.2736	 0.06807	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50974	 92972	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50974	 92972	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50975	 92973	 0.13113	 0.23066	 0.00434	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50976	 51043	 0.019289	 0.075058	 0.02005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50976	 92973	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50976	 92973	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50977	 50978	 0.012617	 0.039238	 0.00819	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50979	 51568	 0.10738	 0.41794	 0.00698	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50979	 92974	 0.026589	 0.11253	 0.00212	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92970	 50980	 0.14152	 0.36394	 0.00563	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50980	 92974	 0.11592	 0.14132	 0.00227	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50980	 93136	 0.1116	 0.39888	 0.00793	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50981	 92974	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50981	 92974	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50981	 93129	 0.043287	 0.18345	 0.04135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50982	 92975	 0.021273	 0.094793	 0.00161	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50982	 92987	 0.10207	 0.20211	 0.00297	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50983	 51021	 0.010875	 0.049895	 0.01278	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50983	 51238	 0.011757	 0.048544	 0.01149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92447	 50983	 0.005039	 0.048385	 0.01408	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50983	 92975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50983	 92975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50984	 51193	 0.22231	 0.35508	 0.00818	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92448	 50984	 0.002093	 0.01176	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50984	 92986	 0.15546	 0.39981	 0.00619	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50985	 92976	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50985	 92976	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92481	 50986	 0.098128	 0.32745	 0.00519	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50986	 92977	 0.027804	 0.14065	 0.00245	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50987	 50988	 0.000373	 0.006247	 0.00354	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50987	 51225	 0.003979	 0.063095	 0.03993	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50988	 92977	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50988	 92977	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50989	 93137	 0.023874	 0.095589	 0.03231	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50990	 50991	 0.001408	 0.005961	 0.00134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50990	 50999	 0.001525	 0.006456	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50991	 50992	 0.001225	 0.004287	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50992	 50996	 0.002426	 0.009711	 0.00245	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50992	 51000	 0.001485	 0.012355	 0.00374	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50992	 92978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50992	 92978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50993	 50994	 0.022998	 0.016625	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50994	 50995	 0.009967	 0.019734	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92978	 50994	 0.007783	 0.021558	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50995	 50997	 0.00315	 0.012256	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50995	 92979	 0.00742	 0.018871	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50995	 92981	 0.029932	 0.06948	 0.00132	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50996	 92979	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50996	 92979	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50996	 92980	 0.00097	 0.003885	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50997	 51001	 0.018462	 0.036554	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50998	 51002	 0.001558	 0.012202	 0.02411	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50998	 92980	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50998	 92980	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50999	 92981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50999	 92981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51000	 51004	 0.004643	 0.037307	 0.01049	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92468	 51001	 0.010016	 0.098151	 0.00192	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51002	 92982	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92983	 51002	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92981	 51003	 0.04557	 0.08931	 0.00134	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51004	 51012	 0.00486	 0.039045	 0.01098	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51004	 92984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51004	 92984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92984	 51005	 0.073466	 0.21607	 0.00443	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51005	 93030	 0.13311	 0.27984	 0.0051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92983	 51006	 0.030054	 0.17085	 0.00309	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51007	 51009	 0.007119	 0.02798	 0.00732	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51008	 51009	 0.005147	 0.028345	 0.01023	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51008	 51727	 0.012353	 0.080795	 0.02055	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51010	 51011	 0.006359	 0.026912	 0.00606	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51011	 51012	 0.006513	 0.026075	 0.00657	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92461	 51012	 0.044077	 0.17348	 0.04547	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51013	 92987	 0.013235	 0.021125	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51014	 51015	 0.000783	 0.002836	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51014	 51023	 0.001118	 0.003895	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51015	 51018	 0.001307	 0.004403	 0.00109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51015	 92985	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51015	 92985	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51016	 51019	 0.00907	 0.012856	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51016	 51020	 0.017104	 0.022479	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51016	 92987	 0.007365	 0.024568	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51017	 51023	 0.003595	 0.014391	 0.00363	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51017	 51026	 0.015675	 0.041428	 0.0097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51018	 51021	 0.007014	 0.023634	 0.00587	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51019	 51020	 0.003887	 0.007119	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51020	 92986	 0.019292	 0.067503	 0.0014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51021	 92986	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51021	 92986	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51022	 92988	 0.049713	 0.12169	 0.00208	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51023	 92987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51023	 92987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92864	 51024	 0.20476	 0.4757	 0.00708	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92985	 51024	 0.040711	 0.041119	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92987	 51024	 0.047083	 0.043369	 0.0007	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51025	 51026	 0.013713	 0.056626	 0.0134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51025	 51242	 0.025176	 0.10084	 0.02542	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92447	 51026	 0.02917	 0.1521	 0.03995	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51026	 92988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51026	 92988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51027	 51028	 0.043429	 0.2288	 0.00411	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92974	 51027	 0.06402	 0.32874	 0.00622	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92474	 51028	 0.036043	 0.26111	 0.00656	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51029	 92989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51029	 92989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51029	 92990	 0.05143	 0.17666	 0.0424	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92989	 51030	 0.097844	 0.22198	 0.00443	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51031	 92990	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51032	 92992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51032	 92992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51033	 51044	 0.00149	 0.015439	 0.02965	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92976	 51033	 0.008691	 0.085759	 0.29593	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51033	 92993	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92994	 51033	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92973	 51034	 0.10195	 0.3402	 0.00539	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92994	 51034	 0.00733	 0.028199	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51035	 51037	 0.010104	 0.025972	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92994	 51035	 0.011201	 0.028485	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51036	 51037	 0.013573	 0.010741	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92994	 51038	 0.02937	 0.074694	 0.00118	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51039	 51041	 0.021405	 0.032465	 0.00047	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51040	 51041	 0.021629	 0.015636	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51041	 51042	 0.024546	 0.025824	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92994	 51041	 0.006433	 0.022509	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92876	 51042	 0.17849	 0.30077	 0.00429	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92993	 51043	 0.004572	 0.016633	 0.00509	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51044	 92995	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92996	 51044	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51045	 92997	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51045	 92997	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51046	 51047	 0.000512	 0.003857	 0.00107	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51046	 51115	 0.000454	 0.003867	 0.00096	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51047	 51048	 0.000388	 0.002791	 0.00074	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51048	 51049	 0.000835	 0.003281	 0.00086	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51048	 51050	 0.001668	 0.005722	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51048	 92998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51048	 92998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51049	 51050	 0.000822	 0.002977	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51049	 51079	 0.00144	 0.005764	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51049	 51096	 0.002358	 0.023621	 0.00786	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51049	 92999	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51049	 92999	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51049	 93007	 0.001186	 0.013545	 0.00644	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	51050	 93000	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51050	 93000	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51051	 51112	 0.01808	 0.014308	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93000	 51051	 0.008398	 0.011448	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93000	 51052	 0.014963	 0.011841	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51053	 51109	 0.017114	 0.013544	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93000	 51053	 0.0219	 0.021964	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51054	 51055	 0.023808	 0.018262	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51055	 51059	 0.003607	 0.009173	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93000	 51055	 0.00608	 0.017878	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92998	 51056	 0.026473	 0.019477	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51057	 93001	 0.004396	 0.009971	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51057	 93002	 0.025061	 0.02559	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51058	 51063	 0.008062	 0.015962	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51058	 51064	 0.003977	 0.01197	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92999	 51058	 0.00309	 0.018779	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51059	 51060	 0.004608	 0.011439	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51059	 51063	 0.009408	 0.008666	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51060	 51062	 0.003932	 0.010108	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51061	 51074	 0.008083	 0.014805	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51061	 51107	 0.01464	 0.028987	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51061	 51108	 0.016284	 0.010542	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93000	 51061	 0.014637	 0.044949	 0.00084	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51062	 51074	 0.00374	 0.009282	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51063	 51073	 0.011645	 0.009128	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51064	 51065	 0.005935	 0.014054	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51064	 51076	 0.00473	 0.0184	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51065	 51066	 0.005286	 0.013443	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51065	 51071	 0.01787	 0.013539	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51066	 93001	 0.004809	 0.011164	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51067	 51068	 0.000641	 0.002519	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51067	 51079	 0.001473	 0.005898	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51067	 51123	 0.000886	 0.004525	 0.00114	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51067	 93001	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51067	 93001	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51068	 51123	 0.000493	 0.001972	 0.0005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51069	 51070	 0.003486	 0.008962	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93001	 51069	 0.005309	 0.013648	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51070	 51081	 0.006719	 0.0156	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51070	 93002	 0.044546	 0.035253	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51072	 51078	 0.007467	 0.018913	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51072	 51093	 0.011802	 0.030013	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51072	 93002	 0.004127	 0.023222	 0.0005	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51074	 51075	 0.005266	 0.009501	 0.00014	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51074	 51098	 0.008258	 0.015815	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51074	 51099	 0.019158	 0.013849	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51075	 51093	 0.007492	 0.007514	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51076	 51092	 0.003024	 0.011765	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51077	 51078	 0.005011	 0.011866	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51077	 51080	 0.025609	 0.023588	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51079	 93002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51079	 93002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51080	 51082	 0.007955	 0.01575	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51080	 51087	 0.016032	 0.033695	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51080	 51089	 0.018929	 0.037478	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51080	 51090	 0.026631	 0.021075	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51080	 93011	 0.005931	 0.035115	 0.00068	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51081	 93011	 0.008894	 0.018692	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51083	 51124	 0.00198	 0.011376	 0.00322	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51083	 93003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51083	 93003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51084	 51085	 0.022646	 0.016661	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51084	 51087	 0.018818	 0.039551	 0.00072	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51086	 51087	 0.006324	 0.029323	 0.00061	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51086	 51152	 0.007674	 0.037448	 0.00065	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93003	 51087	 0.005821	 0.029448	 0.00051	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51088	 51089	 0.048219	 0.031217	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51089	 51091	 0.019187	 0.02049	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51091	 51095	 0.003683	 0.009468	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51092	 51095	 0.006058	 0.018235	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51093	 51094	 0.005108	 0.013132	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51093	 51097	 0.028469	 0.020945	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51094	 51095	 0.00635	 0.012445	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51095	 93004	 0.011852	 0.030467	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51096	 51104	 0.004278	 0.010996	 0.00272	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51096	 51147	 0.006546	 0.032278	 0.00873	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51096	 51150	 0.003534	 0.009175	 0.00223	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51096	 51229	 0.015655	 0.064646	 0.0153	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51096	 93004	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51096	 93004	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51097	 51098	 0.017215	 0.013623	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51098	 51100	 0.022997	 0.018199	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51101	 51107	 0.017894	 0.014161	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51102	 51107	 0.007467	 0.020682	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51102	 93006	 0.007113	 0.013941	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51103	 51105	 0.00324	 0.007808	 0.0022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51103	 51148	 0.004324	 0.012059	 0.00253	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51103	 93005	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51103	 93005	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51104	 51105	 0.002943	 0.008206	 0.00172	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51104	 51150	 0.001594	 0.004212	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51104	 93006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51104	 93006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51105	 51148	 0.003313	 0.011711	 0.00264	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51105	 51150	 0.003213	 0.008341	 0.00202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51106	 51110	 0.034165	 0.02678	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51107	 51157	 0.011185	 0.028752	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51109	 51110	 0.012641	 0.010405	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51110	 51111	 0.01187	 0.027554	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51111	 51169	 0.004497	 0.03087	 0.00056	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51111	 93008	 0.008361	 0.058248	 0.00137	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51113	 93019	 0.007993	 0.018558	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51114	 53093	 0.006337	 0.073738	 0.65424	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	51114	 93007	 9.5e-05	 0.007589	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93007	 51115	 0.00071	 0.00812	 0.00248	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51115	 93009	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51115	 93009	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51116	 51117	 0.00673	 0.017837	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93009	 51116	 0.002624	 0.013352	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51117	 51118	 0.016959	 0.013421	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51117	 51119	 0.022176	 0.022398	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51117	 51120	 0.035778	 0.028314	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51119	 51121	 0.015265	 0.020063	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51121	 93010	 0.010182	 0.017544	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51122	 51123	 0.000631	 0.003998	 0.00109	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51122	 51126	 0.001251	 0.007187	 0.00204	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51122	 93010	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51122	 93010	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51123	 51124	 0.001077	 0.007617	 0.00209	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51123	 51126	 0.001591	 0.009777	 0.00357	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51124	 51141	 0.001101	 0.009156	 0.00277	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93007	 51124	 0.003911	 0.033542	 0.00955	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51124	 93011	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51124	 93011	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51125	 51138	 0.005893	 0.031401	 0.00055	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93011	 51125	 0.033187	 0.043618	 0.0006	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51125	 93015	 0.012914	 0.041004	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51126	 51130	 0.000778	 0.006028	 0.00211	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51126	 51134	 0.003346	 0.023667	 0.00649	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51126	 93012	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51126	 93012	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51127	 51128	 0.040094	 0.03173	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93012	 51127	 0.020147	 0.020349	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51128	 51129	 0.018159	 0.018163	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51128	 51131	 0.006418	 0.013133	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51128	 51132	 0.023464	 0.018569	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51128	 93013	 0.008204	 0.035234	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51129	 51139	 0.017914	 0.018094	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92463	 51130	 0.002189	 0.025018	 0.00763	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51130	 93013	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51130	 93013	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51131	 51133	 0.023374	 0.015132	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51134	 51136	 0.001682	 0.011543	 0.00337	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92463	 51134	 0.002556	 0.020892	 0.00567	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51135	 51136	 0.002184	 0.009834	 0.00262	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92463	 51135	 0.006955	 0.031704	 0.01006	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51136	 51143	 0.00315	 0.025306	 0.00711	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51136	 93014	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51136	 93014	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51137	 51138	 0.008549	 0.024519	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51137	 51139	 0.023427	 0.025517	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93014	 51137	 0.006361	 0.024371	 0.00069	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93014	 51138	 0.016556	 0.050844	 0.00095	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93013	 51140	 0.021724	 0.017028	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51141	 93015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51141	 93015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51142	 51143	 0.001663	 0.015218	 0.00609	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51142	 51230	 0.005309	 0.043395	 0.01178	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93003	 51144	 0.055215	 0.10932	 0.0016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51145	 51146	 0.017137	 0.022523	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51145	 51152	 0.010068	 0.030917	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51146	 93016	 0.032384	 0.053083	 0.00094	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51147	 51229	 0.008017	 0.032624	 0.00795	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51147	 93016	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51147	 93016	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51148	 93017	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51148	 93017	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93017	 51149	 0.023353	 0.018481	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93004	 51151	 0.023784	 0.06114	 0.00095	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51153	 51169	 0.001961	 0.014164	 0.00027	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51153	 93018	 0.003505	 0.021551	 0.00039	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51154	 51155	 0.022999	 0.018201	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51154	 51156	 0.00373	 0.014511	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51154	 51168	 0.003175	 0.01235	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51156	 51157	 0.002477	 0.008261	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51158	 51159	 0.00272	 0.010888	 0.00274	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51158	 93018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51158	 93018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93007	 51159	 0.002071	 0.009784	 0.00313	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51159	 93019	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51159	 93019	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93005	 51160	 0.016893	 0.03094	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93018	 51161	 0.044897	 0.088895	 0.0013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51162	 51163	 0.001975	 0.025709	 0.00743	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92896	 51162	 0.001254	 0.020978	 0.01189	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93007	 51162	 0.002022	 0.027043	 0.00739	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92463	 51163	 0.001531	 0.016578	 0.00698	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93007	 51163	 0.002066	 0.018028	 0.00495	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92464	 51164	 0.15544	 0.12303	 0.00155	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92463	 51165	 0.003912	 0.015375	 0.00402	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51165	 93020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51165	 93020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51166	 51167	 0.13543	 0.14897	 0.00199	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93020	 51166	 0.06102	 0.12488	 0.00307	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51168	 51169	 0.001854	 0.008947	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51170	 51171	 0.010495	 0.044423	 0.01	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51170	 93021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51170	 93021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51171	 51174	 0.00077	 0.006065	 0.00177	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51171	 93031	 0.015441	 0.07203	 0.01784	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51172	 93022	 0.029771	 0.045606	 0.00064	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51173	 51174	 0.001924	 0.008573	 0.00233	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51173	 52869	 0.016735	 0.067013	 0.01689	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51173	 93022	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51173	 93022	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51174	 93280	 0.02024	 0.099844	 0.02701	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51175	 51176	 0.019995	 0.015824	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51175	 51189	 0.017006	 0.013459	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51176	 51191	 0.017556	 0.013894	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51176	 51216	 0.021786	 0.015432	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51177	 51191	 0.026896	 0.019788	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51177	 51192	 0.004346	 0.011008	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51177	 51216	 0.023658	 0.018147	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51178	 51207	 0.016565	 0.046197	 0.0097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51178	 93023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51178	 93023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51179	 51180	 0.056982	 0.044666	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93023	 51179	 0.039256	 0.039649	 0.00053	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51180	 51181	 0.010086	 0.025926	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51180	 51204	 0.020724	 0.053274	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92470	 51180	 0.006672	 0.037543	 0.00081	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51181	 51182	 0.006395	 0.012532	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51182	 51183	 0.027177	 0.021507	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51183	 51184	 0.022907	 0.018129	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51183	 51185	 0.036608	 0.028695	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51183	 51216	 0.023627	 0.018698	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51184	 51185	 0.028594	 0.022629	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51184	 51201	 0.016514	 0.018163	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51184	 51203	 0.009233	 0.021116	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51185	 51189	 0.035552	 0.0257	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51185	 51199	 0.032418	 0.02541	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51185	 93026	 0.040968	 0.067156	 0.00119	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51186	 51189	 0.018173	 0.019794	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51186	 51197	 0.010998	 0.019768	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51187	 51188	 0.007498	 0.012631	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51187	 51198	 0.013353	 0.025572	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51188	 51199	 0.017917	 0.014044	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51189	 51190	 0.006423	 0.012716	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51190	 51194	 0.005829	 0.014985	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51190	 51217	 0.036808	 0.024725	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51191	 51217	 0.020325	 0.015591	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93023	 51192	 0.006566	 0.017404	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51193	 51195	 0.023727	 0.030877	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51193	 51211	 0.061977	 0.049048	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51193	 93024	 0.067035	 0.052546	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51194	 51195	 0.005676	 0.014088	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51194	 51197	 0.025562	 0.016549	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51195	 93024	 0.007541	 0.015432	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51196	 51207	 0.017916	 0.047354	 0.01108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51196	 51212	 0.003788	 0.013718	 0.00294	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51196	 93024	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51196	 93024	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93024	 51197	 0.007801	 0.020052	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51198	 51210	 0.01497	 0.027011	 0.00039	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93024	 51198	 0.00533	 0.021782	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51198	 93026	 0.054419	 0.058115	 0.00123	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51199	 51200	 0.019927	 0.015619	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51200	 51201	 0.024334	 0.019258	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51201	 51202	 0.031971	 0.021476	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51202	 51203	 0.018851	 0.037324	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92470	 51203	 0.012216	 0.046805	 0.00132	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51204	 51205	 0.09557	 0.069089	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51204	 51206	 0.10978	 0.071074	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93023	 51206	 0.04361	 0.086345	 0.00127	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51207	 51212	 0.013607	 0.035963	 0.00842	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92447	 51207	 0.008432	 0.062304	 0.01799	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51208	 93025	 0.14822	 0.11619	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51209	 51210	 0.063491	 0.042649	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93024	 51211	 0.011351	 0.017388	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51211	 93025	 0.013568	 0.028968	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92447	 51212	 0.029398	 0.10089	 0.02418	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51212	 93025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51212	 93025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51213	 93026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51213	 93026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92470	 51214	 0.02226	 0.035708	 0.00066	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93026	 51215	 0.018761	 0.057552	 0.00156	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92470	 51216	 0.027308	 0.087936	 0.0015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93023	 51217	 0.012956	 0.033303	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51218	 51219	 0.014071	 0.037188	 0.00871	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51218	 93027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51218	 93027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51220	 51221	 0.001728	 0.028196	 0.01682	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51221	 51240	 0.004809	 0.08229	 0.04465	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51221	 93028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51221	 93028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51222	 51568	 0.11889	 0.38301	 0.00653	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51222	 93029	 0.043004	 0.11399	 0.00289	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51223	 51326	 0.047772	 0.18807	 0.04931	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51223	 93029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51223	 93029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51224	 51225	 0.002232	 0.036421	 0.02173	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51224	 93030	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51224	 93030	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51226	 52153	 0.01121	 0.18814	 0.10718	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51227	 93031	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51228	 52870	 0.11991	 0.4905	 0.00993	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93032	 51228	 0.019501	 0.12246	 0.00268	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51230	 51232	 0.010686	 0.038877	 0.0119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51230	 93033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51230	 93033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51231	 52329	 0.00691	 0.076544	 0.02491	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51231	 52368	 0.035162	 0.092962	 0.02177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51234	 52368	 0.007524	 0.05298	 0.03013	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92866	 51234	 0.004357	 0.062904	 0.01998	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92869	 51234	 0.002458	 0.028424	 0.01761	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51235	 93034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51235	 93034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51235	 93137	 0.047788	 0.2197	 0.05645	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93034	 51236	 0.071958	 0.14727	 0.00362	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51237	 93035	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51237	 93035	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51238	 51239	 0.013882	 0.055584	 0.01401	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51241	 51242	 0.011537	 0.060105	 0.01577	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51241	 51830	 0.026977	 0.105	 0.02806	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51241	 93036	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51241	 93036	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92952	 51242	 0.02538	 0.091928	 0.01973	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51242	 93037	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51242	 93037	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92462	 51243	 0.035822	 0.15963	 0.00271	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92890	 51243	 0.10147	 0.39055	 0.00667	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51245	 51247	 0.002307	 0.015192	 0.0294	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	51245	 93038	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93039	 51245	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93039	 51246	 0.023002	 0.059129	 0.00092	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51247	 93040	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51247	 93040	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93038	 51248	 0.020408	 0.093657	 0.024	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51248	 93041	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51248	 93041	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93041	 51249	 0.17304	 0.11204	 0.00213	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51250	 51260	 0.001335	 0.00472	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92034	 51250	 0.001449	 0.008235	 0.00238	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92472	 51250	 0.000501	 0.005305	 0.00157	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51250	 93042	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51250	 93042	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93042	 51251	 0.022427	 0.043953	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51251	 93047	 0.025592	 0.0185	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51252	 93043	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51252	 93043	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51253	 51254	 0.000432	 0.001698	 0.00044	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51253	 51305	 0.001797	 0.00541	 0.00169	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93043	 51253	 0.00094	 0.003225	 0.00077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51254	 51256	 0.00046	 0.00175	 0.00049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51255	 51256	 0.001526	 0.004033	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51255	 51304	 0.001326	 0.003561	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51256	 51257	 0.001759	 0.00479	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51256	 51263	 0.000643	 0.002721	 0.00061	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51257	 51262	 0.000644	 0.002577	 0.00065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92472	 51257	 0.000515	 0.004182	 0.00133	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51257	 93044	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51257	 93044	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51258	 51259	 0.010166	 0.010268	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93044	 51258	 0.012978	 0.013109	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93042	 51259	 0.012835	 0.012036	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51260	 51261	 0.00064	 0.002197	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51261	 51267	 0.000495	 0.001699	 0.00041	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51262	 51266	 0.000691	 0.002689	 0.00072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51263	 51265	 0.000825	 0.003356	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51264	 51265	 0.001475	 0.003707	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51264	 51289	 0.001439	 0.005857	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51264	 93051	 0.001604	 0.006303	 0.00165	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51265	 93045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51265	 93045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51265	 93051	 0.002365	 0.010008	 0.00225	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51266	 51271	 0.00035	 0.002174	 0.00061	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51266	 93046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51266	 93046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51267	 51269	 0.000581	 0.002054	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51267	 93047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51267	 93047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93047	 51268	 0.012044	 0.008861	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51269	 51270	 0.000534	 0.001668	 0.00048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51270	 51271	 0.000569	 0.00228	 0.00057	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51270	 51274	 0.000521	 0.002084	 0.00053	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51271	 51273	 0.000557	 0.002228	 0.00056	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92479	 51272	 0.008242	 0.019134	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93045	 51272	 0.006618	 0.014648	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51273	 51276	 0.000838	 0.003546	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51274	 51275	 0.000719	 0.002928	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51275	 51280	 0.001068	 0.004345	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51275	 93048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51275	 93048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51276	 93049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51276	 93049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51276	 93051	 0.002757	 0.007287	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92479	 51277	 0.007544	 0.014257	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51278	 51285	 0.017807	 0.011528	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51278	 93050	 0.019179	 0.015178	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51278	 93052	 0.012239	 0.024231	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51279	 93050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51279	 93050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51280	 51317	 0.001564	 0.00626	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51281	 93059	 0.006151	 0.016259	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51282	 51283	 0.019708	 0.015597	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93050	 51282	 0.003411	 0.016626	 0.00031	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92905	 51284	 0.012913	 0.037036	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51284	 93052	 0.00979	 0.040009	 0.00081	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51286	 51294	 0.001481	 0.005079	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51287	 93052	 0.007213	 0.027749	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51288	 93051	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51289	 51304	 0.000949	 0.003731	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51290	 51291	 0.001852	 0.004973	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51290	 51298	 0.00236	 0.006237	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93051	 51291	 0.003206	 0.008606	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51292	 51296	 0.006778	 0.017424	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51292	 93053	 0.010892	 0.027699	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51293	 51297	 0.020128	 0.047664	 0.00087	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51293	 93053	 0.00887	 0.017562	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51293	 93057	 0.051948	 0.036797	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51294	 51307	 0.00511	 0.012846	 0.00333	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92455	 51294	 0.0041	 0.029496	 0.00782	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51294	 93053	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51294	 93053	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51295	 51296	 0.006469	 0.016629	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51295	 93054	 0.005036	 0.012945	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51296	 51297	 0.00749	 0.01483	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51296	 51299	 0.012729	 0.028172	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93053	 51296	 0.017629	 0.045317	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51297	 51299	 0.005883	 0.013656	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51297	 51309	 0.033134	 0.023952	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51297	 93055	 0.011461	 0.029461	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51298	 51300	 0.001177	 0.004103	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51298	 93054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51298	 93054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51299	 51306	 0.012063	 0.029526	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51299	 93055	 0.007327	 0.022054	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51300	 51301	 0.001019	 0.005968	 0.00163	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51300	 93055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51300	 93055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92455	 51301	 0.001215	 0.007829	 0.00205	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51301	 93056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51301	 93056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93056	 51302	 0.011048	 0.00837	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93052	 51303	 0.08342	 0.066019	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93055	 51303	 0.022915	 0.025203	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93056	 51303	 0.006252	 0.0159	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92455	 51304	 0.00163	 0.007793	 0.00273	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92455	 51305	 0.001606	 0.005356	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92456	 51306	 0.019751	 0.050773	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51307	 51313	 0.003153	 0.010625	 0.00264	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51307	 93057	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51307	 93057	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51308	 51309	 0.041026	 0.032467	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51308	 51311	 0.07919	 0.062074	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51310	 51311	 0.053834	 0.054374	 0.00072	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92456	 51311	 0.042343	 0.086655	 0.00213	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51312	 51314	 0.003013	 0.014535	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51313	 93058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51313	 93058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93057	 51314	 0.092027	 0.072831	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93058	 51314	 0.006464	 0.034052	 0.00061	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93050	 51315	 0.007811	 0.020079	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51315	 93059	 0.009532	 0.022571	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51316	 93059	 0.012601	 0.009972	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51317	 93059	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51317	 93059	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51318	 51323	 0.00268	 0.020183	 0.0056	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51318	 93060	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51318	 93060	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51318	 93066	 0.008477	 0.073442	 0.02637	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51319	 51322	 0.026644	 0.028453	 0.0006	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93060	 51319	 0.026454	 0.10291	 0.00172	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51320	 51342	 0.001411	 0.020341	 0.18679	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51320	 93061	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92520	 51322	 0.002318	 0.010327	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51324	 51326	 0.003922	 0.032987	 0.00977	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93061	 51324	 0.001994	 0.016983	 0.00424	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93062	 51325	 0.018272	 0.046969	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51326	 51843	 0.01438	 0.054668	 0.01531	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51327	 51328	 0.013218	 0.045345	 0.01086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51327	 51622	 0.019896	 0.094196	 0.02266	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51328	 51329	 0.009551	 0.031863	 0.00808	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51329	 51717	 0.035393	 0.093574	 0.02191	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51329	 51845	 0.037814	 0.098212	 0.02385	 212.0	 212.0	 212.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51330	 51578	 0.24152	 0.5081	 0.00927	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51330	 51581	 0.2515	 0.42392	 0.00604	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51331	 51621	 0.56235	 0.44552	 0.00561	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51332	 51708	 0.17156	 0.44126	 0.00683	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51332	 93212	 0.17228	 0.49446	 0.00761	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51333	 51334	 0.023229	 0.052691	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51333	 93175	 0.09385	 0.36671	 0.00814	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51335	 51336	 0.017398	 0.06967	 0.01756	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51335	 51387	 0.034122	 0.13422	 0.03515	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51336	 51722	 0.011887	 0.1162	 0.03264	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51336	 51824	 0.018577	 0.12155	 0.03094	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51336	 93063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51336	 93063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51337	 51578	 0.1569	 0.60428	 0.01033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93063	 51337	 0.031266	 0.088725	 0.00139	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51337	 93209	 0.19595	 0.56253	 0.00866	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51338	 51603	 0.013983	 0.06787	 0.01552	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51338	 53170	 0.010683	 0.087333	 0.02371	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92576	 51338	 0.016209	 0.068615	 0.01544	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92516	 51339	 0.016901	 0.039237	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51340	 51381	 0.028237	 0.1656	 0.04519	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51340	 51834	 0.04328	 0.17635	 0.04304	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51340	 93064	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51340	 93064	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51340	 93066	 0.010855	 0.064676	 0.01702	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51341	 51389	 0.22755	 0.34872	 0.0049	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51341	 93069	 0.069011	 0.17482	 0.00346	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51342	 51344	 0.000295	 0.005353	 0.05351	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	51342	 93065	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51343	 51348	 0.031107	 0.024618	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51344	 51615	 0.000923	 0.010126	 0.09838	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	51344	 93068	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51345	 51349	 0.01796	 0.035198	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51346	 51350	 0.013321	 0.051823	 0.00087	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51346	 51350	 0.013321	 0.051823	 0.00087	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93069	 51346	 0.009027	 0.035117	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93069	 51346	 0.009027	 0.035117	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51347	 51348	 0.004819	 0.012388	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93069	 51347	 0.019183	 0.04453	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51349	 51350	 0.013193	 0.030625	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51350	 93143	 0.044838	 0.17252	 0.00295	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51350	 93143	 0.044838	 0.17252	 0.00295	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51351	 51352	 0.013244	 0.04796	 0.01029	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51351	 93070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51351	 93070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51352	 51353	 0.013696	 0.057974	 0.01305	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51352	 51837	 0.011186	 0.073156	 0.01861	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90176	 51352	 0.013815	 0.068133	 0.01843	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51353	 51377	 0.026485	 0.07387	 0.01551	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51353	 51832	 0.012805	 0.052873	 0.01251	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51353	 93071	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51353	 93071	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51354	 51355	 0.004203	 0.017352	 0.00411	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51355	 51356	 0.009016	 0.036691	 0.00894	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51355	 93072	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51355	 93072	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51356	 51819	 0.015855	 0.055263	 0.01282	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51357	 51362	 0.019074	 0.054706	 0.00084	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51357	 51770	 0.053937	 0.12523	 0.00186	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51358	 51801	 0.005855	 0.035979	 0.01316	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51358	 51802	 0.007787	 0.0296	 0.00829	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92504	 51358	 0.002108	 0.021679	 0.00615	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51359	 51360	 0.082942	 0.14588	 0.00274	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51359	 51687	 0.089759	 0.23077	 0.00357	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51359	 93168	 0.064968	 0.16839	 0.00318	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51359	 93205	 0.029757	 0.11449	 0.00195	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51360	 51688	 0.12513	 0.32177	 0.00498	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92505	 51360	 0.054437	 0.24261	 0.00412	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92503	 51361	 0.000786	 0.009181	 0.01902	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92518	 51361	 0.001612	 0.01829	 0.04016	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92505	 51362	 0.02365	 0.076158	 0.0013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51363	 51398	 0.045862	 0.12346	 0.03466	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51363	 53318	 0.011642	 0.053075	 0.01684	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51364	 51623	 0.035403	 0.091945	 0.02233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51364	 51842	 0.025935	 0.088996	 0.02133	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51365	 51564	 0.01855	 0.10229	 0.02392	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51365	 93182	 0.015244	 0.080825	 0.02699	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92569	 51366	 0.012671	 0.11724	 0.46915	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51366	 93073	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93074	 51366	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51367	 51607	 0.016806	 0.14679	 0.04037	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93073	 51367	 0.014171	 0.12162	 0.03464	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51368	 51722	 0.034977	 0.13759	 0.03604	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51368	 93075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51368	 93075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51368	 93182	 0.065301	 0.29217	 0.07984	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51369	 51370	 0.015165	 0.032498	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51369	 51621	 0.27168	 0.63149	 0.0094	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93075	 51369	 0.0379	 0.097429	 0.00151	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51370	 51396	 0.10502	 0.5129	 0.00886	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93075	 51370	 0.037245	 0.095744	 0.00148	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92507	 51371	 0.007282	 0.060438	 0.0159	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51371	 93076	 0.005364	 0.046012	 0.01309	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51372	 93076	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51373	 51374	 0.013572	 0.045732	 0.01137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51373	 51827	 0.008967	 0.051523	 0.0146	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51373	 93078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51373	 93078	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51374	 51375	 0.008193	 0.028107	 0.00673	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51375	 93079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51375	 93079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51376	 51378	 0.22562	 0.22793	 0.00302	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93078	 51376	 0.090442	 0.25945	 0.00399	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51376	 93210	 0.19076	 0.25076	 0.00344	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51376	 93215	 0.15963	 0.37074	 0.00706	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51377	 51399	 0.012419	 0.047209	 0.01322	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51377	 93080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51377	 93080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51377	 93173	 0.030696	 0.15991	 0.04718	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93080	 51378	 0.11174	 0.21403	 0.00337	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51379	 93081	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51380	 93083	 0.10043	 0.2396	 0.00537	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51380	 93085	 0.15941	 0.48021	 0.0094	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93081	 51381	 0.006357	 0.052755	 0.01388	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51381	 93083	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51381	 93083	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93064	 51382	 0.080425	 0.40703	 0.00709	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93082	 51382	 0.059755	 0.28695	 0.00858	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93083	 51382	 0.1173	 0.26955	 0.0041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51383	 51384	 0.001209	 0.004147	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51383	 53314	 0.018364	 0.047679	 0.01157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51384	 51385	 0.001052	 0.0084	 0.00207	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51385	 51386	 0.0088	 0.034588	 0.00905	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51385	 93173	 0.094736	 0.23882	 0.06208	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51386	 51398	 0.023678	 0.059531	 0.01543	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51386	 51833	 0.009747	 0.04389	 0.01168	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51387	 51388	 0.002807	 0.033189	 0.00945	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51387	 51826	 0.031145	 0.14538	 0.03605	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51388	 53298	 0.012888	 0.080107	 0.02262	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51388	 93084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51388	 93084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51388	 93737	 0.01746	 0.16277	 0.05052	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51390	 51391	 0.006912	 0.038354	 0.01166	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51390	 51392	 0.004804	 0.019836	 0.00469	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51392	 51393	 0.020781	 0.064636	 0.01349	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51392	 93085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51392	 93085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93068	 51393	 0.038158	 0.15293	 0.03858	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51393	 93086	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51393	 93086	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92521	 51394	 0.057994	 0.12429	 0.00218	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93086	 51394	 0.016264	 0.025959	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51395	 51569	 0.026106	 0.095018	 0.02911	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51395	 93087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51395	 93087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51396	 51578	 0.22483	 0.57234	 0.00906	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51396	 93183	 0.08878	 0.6101	 0.01114	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51397	 53136	 0.3098	 0.24291	 0.00312	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51397	 93746	 0.31921	 0.2503	 0.00321	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51398	 51841	 0.027247	 0.070058	 0.01735	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51398	 51842	 0.017982	 0.043339	 0.01224	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51398	 53314	 0.034062	 0.08759	 0.0217	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51399	 51840	 0.01506	 0.069103	 0.01771	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51399	 93088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51399	 93088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93079	 51400	 0.14926	 0.2956	 0.00434	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93088	 51400	 0.057944	 0.15831	 0.00269	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51401	 51404	 0.004747	 0.012745	 0.00289	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51401	 51552	 0.007604	 0.030945	 0.00754	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51401	 51840	 0.006427	 0.035268	 0.00932	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51401	 93089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51401	 93089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51402	 51405	 0.001667	 0.005615	 0.0014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51402	 51407	 0.001548	 0.005309	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92519	 51403	 0.011986	 0.03081	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51403	 93090	 0.013887	 0.015274	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51405	 93090	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51405	 93090	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92519	 51406	 0.003638	 0.009351	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51407	 93091	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51407	 93091	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51408	 51409	 0.008508	 0.01582	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92509	 51408	 0.002768	 0.007316	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51409	 51412	 0.014431	 0.011312	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51409	 93093	 0.005017	 0.011255	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51410	 93092	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51411	 51413	 0.005134	 0.013568	 0.00318	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92508	 51411	 0.004145	 0.016867	 0.00411	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51413	 51458	 0.002007	 0.008492	 0.00191	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51413	 51461	 0.001499	 0.005142	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93092	 51413	 0.001413	 0.005657	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51413	 93094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51413	 93094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93093	 51414	 0.007797	 0.020044	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51415	 51416	 0.005246	 0.008035	 0.00014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51415	 51452	 0.00834	 0.009173	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51416	 51450	 0.008259	 0.027551	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93093	 51416	 0.007368	 0.028229	 0.0008	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51417	 51418	 0.001634	 0.004556	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93092	 51417	 0.001491	 0.012542	 0.00371	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51417	 93095	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51417	 93095	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51418	 93096	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51418	 93096	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51419	 51441	 0.003776	 0.008766	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93096	 51419	 0.005248	 0.012057	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51420	 51424	 0.000879	 0.002359	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51420	 93097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51420	 93097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93096	 51421	 0.018297	 0.013461	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92512	 51422	 0.009355	 0.006882	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92512	 51423	 0.004818	 0.014795	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51423	 93098	 0.006193	 0.017763	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51424	 51425	 0.001139	 0.003011	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51424	 51431	 0.00295	 0.007921	 0.0018	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51425	 51427	 0.001378	 0.004989	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51425	 93098	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51425	 93098	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51426	 51432	 0.003483	 0.008859	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93098	 51426	 0.005917	 0.013738	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51426	 93099	 0.011327	 0.018079	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51427	 51428	 0.000879	 0.002962	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51428	 51761	 0.001866	 0.006288	 0.00156	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51428	 93099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51428	 93099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51429	 51430	 0.007599	 0.015046	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92517	 51429	 0.013639	 0.035061	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93099	 51429	 0.005923	 0.012121	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51429	 93100	 0.022174	 0.02333	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51431	 93100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51431	 93100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93100	 51432	 0.008192	 0.010168	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51433	 51440	 0.011956	 0.012076	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93097	 51433	 0.003822	 0.007491	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51434	 51435	 0.003645	 0.008463	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51434	 51439	 0.006206	 0.014408	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93100	 51435	 0.007252	 0.020799	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51436	 51437	 0.007962	 0.015763	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51436	 51438	 0.006543	 0.011761	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51436	 51439	 0.009287	 0.021991	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51436	 51488	 0.005169	 0.010234	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51437	 51446	 0.010544	 0.013419	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51437	 51487	 0.008384	 0.016599	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51438	 51444	 0.003944	 0.010137	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51439	 51442	 0.012912	 0.013041	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93095	 51439	 0.00971	 0.022206	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51440	 51441	 0.003982	 0.0061	 0.00011	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93095	 51441	 0.006136	 0.012026	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51442	 51443	 0.006719	 0.006062	 0.0001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51443	 51444	 0.010693	 0.009849	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51443	 51450	 0.005991	 0.011741	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51444	 51445	 0.011155	 0.009181	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51444	 93101	 0.006201	 0.015769	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51444	 93102	 0.006187	 0.015903	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51446	 51447	 0.005316	 0.010526	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51447	 51468	 0.003739	 0.011254	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51447	 93101	 0.004732	 0.014531	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51448	 51449	 0.001031	 0.002874	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51448	 51455	 0.000804	 0.003221	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51448	 93101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51448	 93101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51449	 93102	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51449	 93102	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51450	 51451	 0.011133	 0.008191	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51452	 51453	 0.007929	 0.007304	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51453	 51454	 0.007717	 0.010142	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51453	 51460	 0.007708	 0.015106	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51454	 93103	 0.019181	 0.014112	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51455	 51458	 0.000961	 0.003848	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51456	 51457	 0.002771	 0.010781	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51456	 51474	 0.006905	 0.017895	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51457	 51467	 0.004431	 0.007964	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51457	 93103	 0.005067	 0.013026	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51458	 51459	 0.000618	 0.002476	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51458	 93103	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51458	 93103	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51459	 51461	 0.000705	 0.002913	 0.00069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93094	 51460	 0.003791	 0.010759	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51461	 51463	 0.000846	 0.00358	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51461	 93104	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51461	 93104	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51462	 51463	 0.000518	 0.002645	 0.00067	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51462	 51465	 0.000701	 0.003726	 0.00086	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51463	 51464	 0.000344	 0.003648	 0.00108	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92508	 51464	 0.00036	 0.003696	 0.00117	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51465	 51493	 0.001261	 0.005338	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51465	 51498	 0.001511	 0.009002	 0.00237	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51465	 93105	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51465	 93105	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51466	 51467	 0.004261	 0.00872	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51466	 51472	 0.007178	 0.013346	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93104	 51466	 0.003818	 0.020344	 0.00036	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	51468	 51475	 0.009493	 0.015992	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51469	 51496	 0.002504	 0.008589	 0.00206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51469	 51498	 0.001648	 0.005376	 0.00143	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51469	 93106	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51469	 93106	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51470	 51474	 0.004728	 0.011573	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51470	 51516	 0.030882	 0.02444	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93105	 51471	 0.004276	 0.014605	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93106	 51471	 0.01234	 0.031721	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51471	 93114	 0.011358	 0.022487	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93105	 51472	 0.00687	 0.016816	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93106	 51472	 0.00659	 0.020237	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51473	 51474	 0.005309	 0.016304	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51473	 51524	 0.007824	 0.017975	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51473	 93107	 0.004679	 0.018201	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51474	 51475	 0.011966	 0.013161	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51474	 93114	 0.017419	 0.04996	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51476	 51477	 0.002953	 0.010694	 0.00229	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51476	 51482	 0.00184	 0.00513	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92508	 51476	 0.00554	 0.028857	 0.00757	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51476	 93107	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51476	 93107	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51477	 51506	 0.001542	 0.005609	 0.00172	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51477	 51523	 0.000999	 0.003998	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51477	 93108	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51477	 93108	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93107	 51478	 0.012532	 0.024812	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93108	 51478	 0.01027	 0.0173	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51479	 51483	 0.006702	 0.014361	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93108	 51479	 0.006131	 0.017583	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51480	 51484	 0.019325	 0.015148	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51481	 51484	 0.008164	 0.023416	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93107	 51481	 0.003515	 0.017152	 0.0003	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51482	 51486	 0.001513	 0.003998	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51483	 93121	 0.004189	 0.009724	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51484	 51485	 0.027392	 0.021677	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51484	 51546	 0.0204	 0.033885	 0.00072	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51484	 93121	 0.009134	 0.020491	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51486	 51538	 0.002445	 0.006145	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51486	 93109	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51486	 93109	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93109	 51487	 0.012315	 0.018865	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51487	 93110	 0.012327	 0.024407	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51488	 93110	 0.005642	 0.012962	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51489	 51490	 0.001013	 0.002629	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51489	 93110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51489	 93110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51490	 51491	 0.001196	 0.003211	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51491	 51787	 0.001924	 0.011634	 0.00297	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51491	 93111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51491	 93111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51492	 51493	 0.002348	 0.009134	 0.00244	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51492	 51839	 0.005779	 0.020221	 0.0067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92508	 51493	 0.001577	 0.0098	 0.00277	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51494	 51496	 0.001089	 0.00414	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51494	 51499	 0.003832	 0.013876	 0.00298	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51494	 51502	 0.002619	 0.010815	 0.00256	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51494	 93112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51494	 93112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51495	 51513	 0.004617	 0.013578	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93112	 51495	 0.005801	 0.016638	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51495	 93113	 0.004026	 0.012363	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51496	 51498	 0.002076	 0.008312	 0.00209	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51496	 51514	 0.001202	 0.005089	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51496	 93113	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51496	 93113	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93113	 51497	 0.0046	 0.011825	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51497	 93114	 0.008716	 0.020639	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51498	 93114	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51498	 93114	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51499	 51503	 0.002181	 0.00873	 0.0022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51499	 93115	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51499	 93115	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51500	 51511	 0.006491	 0.019914	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93112	 51500	 0.004459	 0.025347	 0.00046	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93115	 51500	 0.011525	 0.026756	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51501	 51549	 0.004921	 0.016416	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93115	 51501	 0.004103	 0.015963	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51501	 93117	 0.018602	 0.047819	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51502	 51839	 0.004268	 0.027907	 0.0071	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51502	 93116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51502	 93116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51503	 51553	 0.003706	 0.015687	 0.00353	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51503	 93117	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51503	 93117	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51504	 93118	 0.006959	 0.02137	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51504	 93124	 0.005272	 0.016905	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51505	 93118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51505	 93118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51505	 93120	 0.002847	 0.009498	 0.00241	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51506	 51507	 0.000958	 0.003957	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51506	 93119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51506	 93119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51507	 93120	 0.00099	 0.004088	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90229	 51508	 0.001368	 0.016912	 0.03393	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92503	 51508	 0.002865	 0.030561	 0.0554	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51508	 93120	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93121	 51508	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51509	 51516	 0.006718	 0.011204	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51509	 51524	 0.015421	 0.015575	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51510	 51526	 0.023419	 0.015731	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51510	 51529	 0.023024	 0.018047	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93118	 51510	 0.007116	 0.017418	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51511	 51517	 0.005798	 0.01663	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51511	 51549	 0.008758	 0.01734	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51512	 93123	 0.022946	 0.017986	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51513	 93122	 0.006633	 0.011665	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51513	 93123	 0.005249	 0.020419	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51514	 51519	 0.001138	 0.004818	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51514	 93122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51514	 93122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93106	 51515	 0.003855	 0.015293	 0.00044	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93122	 51515	 0.002642	 0.012891	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93122	 51516	 0.008183	 0.013666	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51517	 51551	 0.003525	 0.01553	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51517	 93123	 0.007149	 0.0175	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51517	 93124	 0.013688	 0.022437	 0.0004	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51518	 51519	 0.001355	 0.004649	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51518	 51522	 0.001236	 0.00403	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51518	 93123	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51518	 93123	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51519	 51523	 0.000931	 0.003622	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51520	 51521	 0.023295	 0.015081	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51521	 51525	 0.025425	 0.025431	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51521	 51550	 0.025537	 0.024986	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51521	 51551	 0.004111	 0.014685	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93118	 51521	 0.025995	 0.039821	 0.00056	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51522	 93124	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51522	 93124	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51523	 93125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51523	 93125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93125	 51524	 0.016464	 0.017322	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51525	 51526	 0.017606	 0.0138	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93119	 51527	 0.00732	 0.016995	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93124	 51527	 0.007303	 0.016954	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51528	 51530	 0.031795	 0.021358	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51530	 51531	 0.008262	 0.018741	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93118	 51530	 0.014647	 0.029974	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51531	 51532	 0.009475	 0.01857	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51531	 51561	 0.012054	 0.022413	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51531	 51563	 0.033762	 0.033771	 0.00046	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51532	 51533	 0.006348	 0.014735	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51533	 51534	 0.006425	 0.015214	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51534	 51542	 0.007296	 0.013165	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93121	 51534	 0.009566	 0.025355	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93121	 51535	 0.00567	 0.016262	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51535	 93127	 0.005412	 0.012566	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93121	 51536	 0.027613	 0.020921	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51537	 51546	 0.007891	 0.012698	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51537	 93126	 0.006535	 0.016799	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51538	 51547	 0.00121	 0.003198	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51538	 93126	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51538	 93126	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51539	 51540	 0.023306	 0.018444	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51540	 51541	 0.006439	 0.014606	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51540	 51791	 0.014795	 0.024924	 0.00036	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51541	 51542	 0.005829	 0.013331	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51542	 51800	 0.017626	 0.012741	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51542	 93127	 0.006455	 0.018513	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51543	 51544	 0.00066	 0.003866	 0.00105	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51543	 51798	 0.004889	 0.027683	 0.00686	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93120	 51543	 0.001685	 0.005896	 0.00195	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51543	 93127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51543	 93127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51544	 51788	 0.00102	 0.005402	 0.00137	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93120	 51544	 0.002526	 0.006087	 0.00172	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51545	 51546	 0.00876	 0.017343	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51546	 93128	 0.006522	 0.016766	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51546	 93201	 0.013703	 0.018009	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51547	 51780	 0.00128	 0.00357	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51547	 93128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51547	 93128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51548	 51549	 0.004906	 0.016367	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51548	 51557	 0.011242	 0.027903	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93123	 51549	 0.015016	 0.034856	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51552	 51553	 0.005646	 0.023898	 0.00538	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51554	 51558	 0.055416	 0.035876	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51555	 51556	 0.029128	 0.057671	 0.00085	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51556	 51797	 0.044235	 0.074518	 0.00106	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93121	 51556	 0.055182	 0.11293	 0.00278	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51557	 51558	 0.009155	 0.021252	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51558	 51559	 0.01243	 0.02461	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93121	 51558	 0.045728	 0.1163	 0.00184	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51559	 51560	 0.026228	 0.020559	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51560	 51561	 0.023432	 0.018544	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51561	 51562	 0.023328	 0.015102	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51565	 51566	 0.13804	 0.20209	 0.00312	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51565	 51757	 0.07018	 0.24561	 0.00509	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51566	 51598	 0.22932	 0.42678	 0.01	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93077	 51566	 0.05706	 0.30065	 0.0054	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	51567	 51568	 0.068778	 0.19519	 0.00307	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51567	 93136	 0.039386	 0.32722	 0.008	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51567	 93143	 0.047988	 0.2127	 0.00639	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51567	 93144	 0.061002	 0.18717	 0.00507	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51568	 93144	 0.15493	 0.42349	 0.0072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51569	 51706	 0.017833	 0.15311	 0.04364	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51569	 51751	 0.017979	 0.081647	 0.02835	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51570	 93129	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51570	 93129	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51571	 51574	 0.004442	 0.033457	 0.00928	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51571	 51613	 0.014729	 0.062348	 0.01403	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51572	 93130	 0.000905	 0.048849	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51572	 93130	 0.000905	 0.048849	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93130	 51573	 0.008692	 0.076612	 0.00166	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51573	 93131	 0.002193	 0.021491	 0.00042	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51574	 51575	 0.000967	 0.007771	 0.00218	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51575	 51576	 0.00058	 0.004739	 0.00129	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51576	 51577	 0.008626	 0.052171	 0.01331	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92506	 51576	 0.002406	 0.020841	 0.00748	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51576	 93131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51576	 93131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51579	 51708	 0.17451	 0.40533	 0.00603	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51579	 93139	 0.17586	 0.41669	 0.00762	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92521	 51580	 0.20593	 0.22654	 0.00302	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51581	 93141	 0.27262	 0.54025	 0.00794	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51582	 51835	 0.021139	 0.083108	 0.02175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51582	 51845	 0.024538	 0.093309	 0.02613	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93066	 51583	 0.023452	 0.092208	 0.02413	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51583	 93132	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51583	 93132	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51584	 93133	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51584	 93133	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51585	 93134	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51585	 93134	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51586	 51587	 0.009856	 0.032525	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93133	 51586	 0.026263	 0.034178	 0.00048	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93134	 51586	 0.015613	 0.023917	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51587	 51588	 0.019708	 0.05012	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93132	 51587	 0.01747	 0.086686	 0.00207	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51589	 51590	 0.00632	 0.016247	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51590	 51591	 0.024119	 0.017745	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51590	 51594	 0.026996	 0.027003	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93134	 51590	 0.015826	 0.028987	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51591	 51592	 0.05539	 0.043835	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51591	 51594	 0.030803	 0.03355	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92513	 51591	 0.00513	 0.018327	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51592	 51598	 0.095543	 0.17175	 0.00308	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51592	 51721	 0.21382	 0.36035	 0.00513	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92513	 51592	 0.002853	 0.016052	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93133	 51592	 0.017753	 0.033553	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51593	 51594	 0.010162	 0.038121	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51593	 51598	 0.090142	 0.16512	 0.00285	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51594	 51595	 0.17071	 0.13511	 0.0017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51595	 51596	 0.056298	 0.18782	 0.00298	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93060	 51595	 0.060071	 0.1845	 0.00346	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93067	 51596	 0.052042	 0.23193	 0.00394	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93132	 51596	 0.30636	 0.22548	 0.0033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51597	 93135	 0.053324	 0.10558	 0.00155	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51598	 93135	 0.040424	 0.10392	 0.00161	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51599	 51849	 0.027603	 0.096236	 0.02233	 164.0	 164.0	 164.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93061	 51599	 0.031454	 0.11124	 0.02508	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51599	 93135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51599	 93135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93129	 51600	 0.014771	 0.10631	 0.02819	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51600	 93136	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51600	 93136	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51600	 93142	 0.010896	 0.10683	 0.03349	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51601	 93138	 0.13943	 0.40008	 0.00616	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51601	 93171	 0.13157	 0.43444	 0.00704	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92501	 51602	 0.00701	 0.064433	 0.25535	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51602	 93137	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93138	 51602	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51603	 51605	 0.013306	 0.052301	 0.01368	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51604	 51605	 0.012093	 0.061182	 0.01704	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51604	 51845	 0.029477	 0.12003	 0.02927	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51604	 93139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51604	 93139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92576	 51605	 0.03077	 0.17894	 0.04221	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51605	 93140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51605	 93140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92577	 51606	 0.26473	 0.68146	 0.01056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93139	 51606	 0.072688	 0.22326	 0.00419	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93140	 51606	 0.065722	 0.15032	 0.00367	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51607	 51709	 0.018765	 0.097784	 0.02566	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51607	 51831	 0.030457	 0.10664	 0.03537	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51607	 93141	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51607	 93141	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51608	 51609	 0.24764	 0.19602	 0.00247	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51609	 51825	 0.1176	 0.27855	 0.00509	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93132	 51609	 0.12932	 0.30031	 0.00447	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51610	 51611	 0.007751	 0.030154	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51610	 93192	 0.055918	 0.33995	 0.00627	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51611	 51612	 0.006637	 0.029573	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93036	 51612	 0.040898	 0.19635	 0.00587	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51612	 93211	 0.33912	 0.51997	 0.00731	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51613	 51614	 0.009694	 0.038812	 0.00978	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51614	 51733	 0.013368	 0.060199	 0.01602	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51614	 93176	 0.008834	 0.06528	 0.01885	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51615	 93142	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93142	 51616	 0.008826	 0.029442	 0.00747	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51616	 93144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51616	 93144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51617	 51618	 0.007733	 0.022179	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51617	 93183	 0.095803	 0.31968	 0.00507	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51620	 51755	 0.042066	 0.14443	 0.03464	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51620	 53309	 0.012486	 0.12838	 0.04066	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92515	 51620	 0.019381	 0.1164	 0.03528	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51621	 51811	 0.16141	 0.6217	 0.01063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93075	 51621	 0.27229	 0.6329	 0.00942	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51622	 51623	 0.029179	 0.097382	 0.02471	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51622	 51624	 0.032924	 0.082789	 0.02146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92576	 51622	 0.01136	 0.13504	 0.04711	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51623	 51739	 0.02132	 0.077217	 0.01657	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51625	 51638	 0.001268	 0.005236	 0.00124	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51625	 93145	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51625	 93145	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51626	 51637	 0.002264	 0.005877	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51626	 51638	 0.001004	 0.003816	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51626	 93146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51626	 93146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51627	 51628	 0.002643	 0.008107	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93146	 51627	 0.002162	 0.010025	 0.00021	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51628	 93157	 0.02776	 0.065735	 0.0012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51629	 51632	 0.004285	 0.009799	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51629	 51634	 0.003448	 0.01321	 0.00037	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51629	 51662	 0.003954	 0.017619	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51629	 93157	 0.027397	 0.063606	 0.00095	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51630	 51631	 0.002312	 0.008995	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51630	 93158	 0.009836	 0.025014	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51631	 51648	 0.002232	 0.008682	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51632	 51633	 0.015159	 0.011153	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51632	 51647	 0.002706	 0.008309	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51634	 93148	 0.002775	 0.015188	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93146	 51635	 0.006728	 0.01562	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51635	 93147	 0.005855	 0.015479	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51635	 93148	 0.005768	 0.008748	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51636	 51637	 0.000639	 0.002132	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51636	 51641	 0.001041	 0.004051	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51636	 93147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51636	 93147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51637	 93148	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51637	 93148	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51638	 93149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51638	 93149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51639	 51640	 0.009356	 0.013282	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93149	 51639	 0.018276	 0.011832	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51640	 51692	 0.005865	 0.016022	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93145	 51640	 0.032032	 0.047496	 0.00071	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51641	 51642	 0.000707	 0.003899	 0.00091	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51641	 93150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51641	 93150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51642	 51679	 0.000861	 0.004562	 0.00116	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51643	 51644	 0.006716	 0.014393	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51643	 51645	 0.00898	 0.017779	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93147	 51643	 0.00485	 0.012822	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93150	 51643	 0.006389	 0.016424	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51644	 51655	 0.002877	 0.010068	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51644	 93154	 0.065937	 0.048512	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51645	 93155	 0.028537	 0.018475	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51646	 51650	 0.000864	 0.003517	 0.00086	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51646	 51653	 0.000722	 0.002892	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51646	 93151	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51646	 93151	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93151	 51647	 0.00292	 0.009636	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51648	 51649	 0.002587	 0.009052	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93151	 51649	 0.003927	 0.008692	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51649	 93152	 0.004194	 0.005512	 8e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51649	 93154	 0.003047	 0.015415	 0.00027	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51650	 51651	 0.000511	 0.002226	 0.00063	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51650	 51652	 0.000882	 0.003532	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51650	 93152	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51650	 93152	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51651	 51663	 0.004249	 0.017984	 0.00405	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51651	 93153	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51651	 93153	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51652	 93154	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51652	 93154	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51653	 51654	 0.000733	 0.002984	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51653	 93155	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51653	 93155	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51654	 51658	 0.000896	 0.003701	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51655	 51657	 0.00403	 0.016128	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51656	 51657	 0.010136	 0.010138	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51657	 51678	 0.004819	 0.010812	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51657	 51682	 0.00569	 0.022136	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51657	 93159	 0.037725	 0.041091	 0.00056	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51657	 93162	 0.014287	 0.030027	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51658	 51674	 0.001028	 0.004717	 0.00121	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51659	 51660	 0.003897	 0.010298	 0.00241	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51660	 51661	 0.002402	 0.007191	 0.00162	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51661	 93156	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51661	 93156	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93156	 51662	 0.003742	 0.012048	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51663	 51665	 0.002778	 0.007746	 0.00163	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51663	 93157	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51663	 93157	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51663	 93186	 0.0491	 0.17894	 0.05491	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93156	 51664	 0.002972	 0.008435	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51664	 93158	 0.004658	 0.013218	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51665	 93158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51665	 93158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51666	 51698	 0.010481	 0.022029	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51666	 51847	 0.35676	 0.70744	 0.0104	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93158	 51666	 0.022379	 0.057527	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93158	 51667	 0.013631	 0.020877	 0.00036	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51668	 51698	 0.036919	 0.040606	 0.00054	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51669	 51670	 0.018779	 0.025598	 0.00057	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93153	 51670	 0.007589	 0.0193	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93154	 51671	 0.034217	 0.025174	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93154	 51672	 0.006402	 0.022871	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51672	 93159	 0.003904	 0.010036	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51672	 93161	 0.010846	 0.025684	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92510	 51673	 0.007106	 0.013609	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51674	 51677	 0.001174	 0.004613	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51674	 93159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51674	 93159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51675	 51677	 0.000882	 0.003969	 0.00106	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51675	 51686	 0.000664	 0.003773	 0.00109	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51675	 93160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51675	 93160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92510	 51676	 0.002814	 0.017035	 0.00053	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93159	 51676	 0.010129	 0.024793	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93160	 51676	 0.004368	 0.014006	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51677	 93161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51677	 93161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51678	 51681	 0.003537	 0.013758	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51679	 51680	 0.000474	 0.003989	 0.00118	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51679	 93162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51679	 93162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51680	 93163	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51680	 93163	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51680	 93167	 0.001552	 0.01322	 0.0033	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93161	 51681	 0.004106	 0.012597	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51681	 93166	 0.002686	 0.011903	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51682	 93165	 0.00353	 0.015731	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93163	 51683	 0.004178	 0.016253	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51683	 93164	 0.003989	 0.013625	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51684	 51685	 0.00104	 0.005318	 0.00145	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51684	 93164	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51684	 93164	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51684	 93167	 0.001197	 0.00884	 0.00255	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51685	 51686	 0.000797	 0.003492	 0.0012	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51685	 93165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51685	 93165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51686	 51696	 0.002502	 0.031037	 0.01344	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51686	 93166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51686	 93166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93145	 51687	 0.017017	 0.032162	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51688	 51691	 0.013878	 0.022151	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93162	 51688	 0.037868	 0.037877	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51689	 51697	 0.000867	 0.009249	 0.01881	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51689	 51744	 0.013535	 0.085951	 0.18068	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	51689	 93167	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51689	 93167	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93165	 51690	 0.037001	 0.02621	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51691	 51692	 0.003113	 0.012352	 0.00035	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93162	 51691	 0.005447	 0.016395	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51693	 93168	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51693	 93168	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93157	 51694	 0.041274	 0.029236	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93157	 51695	 0.054611	 0.10813	 0.00159	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51697	 51730	 0.001456	 0.01607	 0.03389	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93157	 51698	 0.009	 0.025539	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51699	 51702	 0.008875	 0.050901	 0.01692	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51700	 51701	 0.006967	 0.054312	 0.01624	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51700	 51709	 0.016418	 0.081136	 0.02371	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51700	 51831	 0.053011	 0.18587	 0.06176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92502	 51700	 0.005244	 0.050355	 0.01465	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51701	 51702	 0.002731	 0.014212	 0.00419	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51701	 93169	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51701	 93169	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51702	 93170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51702	 93170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51703	 51704	 0.005774	 0.02573	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93170	 51703	 0.004989	 0.01941	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93169	 51704	 0.005271	 0.029618	 0.00055	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93170	 51705	 0.002419	 0.023708	 0.00046	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92502	 51706	 0.004453	 0.054893	 0.01774	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51706	 93171	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51706	 93171	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93169	 51707	 0.20773	 0.53445	 0.00828	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51707	 93212	 0.1558	 0.36182	 0.00689	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93082	 51708	 0.18084	 0.41567	 0.00632	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51710	 51711	 0.002161	 0.008495	 0.00222	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51710	 51828	 0.003702	 0.028363	 0.0076	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51710	 51841	 0.028258	 0.076954	 0.01696	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51710	 93173	 0.001186	 0.013553	 0.00413	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51711	 51717	 0.02308	 0.062846	 0.01385	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51711	 51739	 0.032222	 0.085183	 0.01995	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51711	 93172	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51711	 93172	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51711	 93173	 0.003277	 0.019521	 0.00514	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51712	 51714	 0.006414	 0.018396	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93172	 51712	 0.011883	 0.039641	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51713	 51714	 0.030614	 0.055238	 0.0008	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51714	 51715	 0.006338	 0.012548	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51715	 93174	 0.008039	 0.02466	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51715	 93174	 0.008039	 0.02466	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51715	 93175	 0.063854	 0.2457	 0.0042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51715	 93175	 0.063854	 0.2457	 0.0042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51716	 93173	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93173	 51717	 0.019801	 0.052338	 0.01225	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51718	 51740	 0.004342	 0.044641	 0.01689	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93173	 51718	 0.003253	 0.048688	 0.01637	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51718	 93175	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51718	 93175	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51719	 51721	 0.1573	 0.14097	 0.00288	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51719	 51723	 0.076623	 0.1902	 0.00316	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93135	 51719	 0.27317	 0.46049	 0.00656	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51720	 51721	 0.24174	 0.18952	 0.00243	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51720	 51723	 0.22922	 0.40964	 0.00605	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93133	 51720	 0.089929	 0.19274	 0.00338	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51721	 93188	 0.25582	 0.65846	 0.01021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51722	 51816	 0.034252	 0.13725	 0.03461	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93175	 51723	 0.13101	 0.58438	 0.00994	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51724	 93177	 0.051731	 0.13299	 0.00206	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51725	 93176	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51726	 51727	 0.005011	 0.042681	 0.01065	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93076	 51726	 0.009054	 0.074015	 0.02009	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51727	 93178	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51727	 93178	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51728	 93180	 0.048379	 0.095788	 0.00141	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51729	 51730	 0.001155	 0.013555	 0.03025	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51729	 93179	 0.001877	 0.022359	 0.0484	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51731	 93179	 9.6e-05	 0.007692	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51732	 93181	 0.001136	 0.049987	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51732	 93181	 0.001136	 0.049987	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51734	 93182	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51735	 51736	 0.016699	 0.051282	 0.00096	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93143	 51735	 0.043316	 0.24627	 0.00446	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51736	 51737	 0.024581	 0.06319	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93172	 51738	 0.086376	 0.22207	 0.00344	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51740	 51741	 0.004076	 0.045075	 0.01352	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51741	 51742	 0.002617	 0.022441	 0.00639	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51742	 51746	 0.001982	 0.011611	 0.00316	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51742	 93184	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51742	 93184	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51743	 51745	 0.006193	 0.014375	 0.00438	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51743	 93185	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51743	 93185	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51743	 93186	 0.003473	 0.013201	 0.0037	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90175	 51744	 0.010354	 0.086122	 0.27325	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93065	 51744	 0.020838	 0.13986	 0.26603	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	51744	 93186	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93187	 51744	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51745	 51746	 0.001867	 0.007904	 0.00178	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93186	 51745	 0.003278	 0.013125	 0.00331	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51745	 93188	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51745	 93188	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51746	 51747	 0.01579	 0.063228	 0.01593	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51747	 51748	 0.009474	 0.038556	 0.00939	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51748	 51846	 0.012914	 0.053324	 0.01262	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51749	 51751	 0.006515	 0.027575	 0.0062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51750	 93189	 0.022358	 0.056859	 0.0009	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51751	 93189	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51751	 93189	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93177	 51752	 0.052701	 0.29966	 0.00542	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92514	 51753	 0.033349	 0.12974	 0.00217	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51753	 93190	 0.058017	 0.22323	 0.00381	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51754	 93190	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51754	 93190	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92515	 51755	 0.027743	 0.093511	 0.02325	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51756	 93191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51756	 93191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51757	 51822	 0.027956	 0.12458	 0.00212	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51758	 51759	 0.009624	 0.048359	 0.01259	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51758	 51849	 0.022865	 0.11495	 0.02994	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92506	 51759	 0.003317	 0.047885	 0.0152	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51759	 93192	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51759	 93192	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92517	 51760	 0.092314	 0.059766	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93099	 51760	 0.068831	 0.054472	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51760	 93193	 0.017454	 0.031371	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51761	 51765	 0.001199	 0.004039	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51762	 51765	 0.000955	 0.003822	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51762	 51775	 0.001055	 0.004145	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88819	 51762	 0.002725	 0.017259	 0.00468	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51763	 51775	 0.00161	 0.004255	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51763	 51776	 0.001174	 0.004968	 0.00112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90231	 51763	 0.004959	 0.023703	 0.0083	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51764	 93198	 0.071256	 0.068849	 0.001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51764	 93199	 0.013346	 0.01348	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51765	 93193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51765	 93193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51766	 51774	 0.001814	 0.006323	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51766	 51786	 0.001841	 0.007792	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51766	 93194	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51766	 93194	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51767	 51769	 0.001563	 0.006258	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51767	 51775	 0.001435	 0.00564	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51767	 51777	 0.003955	 0.011029	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51768	 93195	 0.015817	 0.022044	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51769	 51774	 0.000801	 0.003206	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51769	 93195	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51769	 93195	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51769	 93196	 0.001853	 0.009653	 0.00253	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51770	 51772	 0.014453	 0.028615	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51770	 51773	 0.025332	 0.020047	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93195	 51770	 0.013442	 0.017667	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90229	 51771	 0.001495	 0.016484	 0.03132	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92503	 51771	 0.000888	 0.009682	 0.03906	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51771	 93196	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51771	 93196	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51772	 93198	 0.00714	 0.016573	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51772	 93199	 0.07063	 0.063291	 0.00129	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51773	 93197	 0.017196	 0.011551	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51774	 93197	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51774	 93197	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93196	 51776	 0.003832	 0.014566	 0.00408	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51776	 93198	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51776	 93198	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51777	 93199	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51777	 93199	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51778	 51779	 0.005135	 0.015768	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92517	 51778	 0.001589	 0.005302	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51779	 51781	 0.006988	 0.018111	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51780	 51783	 0.001999	 0.005189	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93128	 51781	 0.006705	 0.019232	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51782	 51783	 0.001038	 0.005406	 0.00142	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51782	 51787	 0.001665	 0.00428	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51782	 51788	 0.001481	 0.005082	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51782	 51789	 0.001093	 0.004156	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51783	 51785	 0.001559	 0.005084	 0.00135	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51783	 93200	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51783	 93200	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92517	 51784	 0.005031	 0.020999	 0.00061	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93194	 51784	 0.018688	 0.036624	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51785	 51786	 0.001199	 0.004802	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51787	 51788	 0.001022	 0.004091	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51787	 93201	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51787	 93201	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51789	 51790	 0.001457	 0.00554	 0.00155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51790	 51802	 0.003325	 0.014071	 0.00317	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51791	 51792	 0.004924	 0.016248	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51791	 51799	 0.007886	 0.016137	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51792	 51793	 0.009958	 0.016323	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51793	 51796	 0.03434	 0.026918	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51794	 51795	 0.03697	 0.04859	 0.00067	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51794	 93202	 0.017702	 0.041097	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93121	 51795	 0.028548	 0.065288	 0.00159	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51796	 93202	 0.056273	 0.04068	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51797	 93202	 0.019604	 0.040119	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51797	 93204	 0.063585	 0.15783	 0.00262	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51798	 51801	 0.008584	 0.022687	 0.00531	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51798	 93202	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51798	 93202	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93127	 51799	 0.008036	 0.024187	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51801	 51807	 0.009493	 0.039198	 0.00927	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93091	 51803	 0.021165	 0.084701	 0.00179	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51803	 93203	 0.047318	 0.1309	 0.00304	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93072	 51804	 0.072145	 0.22137	 0.006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51804	 93203	 0.029417	 0.13109	 0.00223	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51805	 51806	 0.010315	 0.037351	 0.00801	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51805	 93203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51805	 93203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51806	 51807	 0.013842	 0.040096	 0.00967	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51806	 93204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51806	 93204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51807	 93205	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51807	 93205	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51808	 93206	 0.13425	 0.14767	 0.00197	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51809	 51812	 0.006456	 0.026273	 0.0064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51809	 51826	 0.032316	 0.15698	 0.03593	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51810	 93206	 0.10215	 0.20909	 0.00515	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51811	 51817	 0.06795	 0.12137	 0.00179	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51811	 51818	 0.04429	 0.093088	 0.0017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51812	 51816	 0.003896	 0.015598	 0.00393	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51813	 93206	 0.036991	 0.037362	 0.00049	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51814	 93206	 0.042622	 0.027594	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51815	 51818	 0.015423	 0.025758	 0.00044	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51816	 93206	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51816	 93206	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93206	 51817	 0.011182	 0.043501	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93206	 51818	 0.013146	 0.050576	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51819	 93207	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51819	 93207	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51820	 51821	 0.02037	 0.039011	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51820	 51822	 0.040002	 0.15391	 0.00263	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93207	 51820	 0.010774	 0.044032	 0.00089	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93191	 51822	 0.034441	 0.18352	 0.00322	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	51823	 51824	 0.029597	 0.11257	 0.03154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93073	 51823	 0.052297	 0.21323	 0.05209	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51823	 93208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51823	 93208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51824	 93209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51824	 93209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93064	 51825	 0.12045	 0.29491	 0.00504	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51827	 51828	 0.005062	 0.042012	 0.01105	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51827	 93210	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51827	 93210	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51828	 51841	 0.017875	 0.053808	 0.01684	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51829	 51830	 0.012774	 0.051146	 0.01289	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93076	 51829	 0.008776	 0.097102	 0.02914	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51829	 93211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51829	 93211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51831	 93212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51831	 93212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51832	 51833	 0.008185	 0.036475	 0.00991	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51832	 93213	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51832	 93213	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51834	 51835	 0.0035	 0.014014	 0.00353	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51836	 93214	 0.046395	 0.04686	 0.00062	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51837	 51840	 0.005922	 0.037508	 0.01018	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51837	 93214	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51837	 93214	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93214	 51838	 0.054715	 0.076256	 0.0013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51841	 51842	 0.010738	 0.024926	 0.00759	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90273	 51841	 0.064459	 0.16592	 0.04115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51842	 93215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51842	 93215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51843	 51844	 0.012281	 0.04998	 0.01218	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51846	 51849	 0.015369	 0.050133	 0.01331	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51846	 93216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51846	 93216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51847	 51848	 0.064032	 0.046289	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93216	 51847	 0.01311	 0.052013	 0.00149	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51847	 93217	 0.062753	 0.1457	 0.00217	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93216	 51848	 0.058914	 0.10791	 0.00186	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51848	 93217	 0.037834	 0.097257	 0.00151	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51849	 93217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51849	 93217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51850	 53177	 0.0717	 0.23982	 0.06103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51850	 53291	 0.051459	 0.1551	 0.04861	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51850	 93257	 0.02624	 0.20141	 0.0541	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51851	 51854	 0.002263	 0.02267	 0.00755	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51851	 51912	 0.005864	 0.057301	 0.01608	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51852	 51853	 0.002943	 0.039359	 0.01076	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51853	 51854	 0.000651	 0.00669	 0.00212	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51855	 51858	 0.049683	 0.27367	 0.00618	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51855	 51925	 0.094642	 0.31581	 0.00501	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51855	 93250	 0.22418	 0.29184	 0.00408	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51856	 51984	 0.081411	 0.20707	 0.00327	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51856	 51985	 0.18154	 0.38176	 0.00696	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51857	 51858	 0.11222	 0.26579	 0.00486	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51857	 51982	 0.11578	 0.38224	 0.0062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51858	 51983	 0.13069	 0.29901	 0.0073	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51858	 52046	 0.18941	 0.37137	 0.00557	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51859	 51928	 0.5352	 0.42396	 0.00534	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51859	 93260	 0.18142	 0.35934	 0.00528	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51860	 51861	 0.076073	 0.060204	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51860	 51862	 0.21832	 0.51746	 0.00947	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51860	 51999	 0.31519	 0.41451	 0.00568	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51862	 93268	 0.12506	 0.33164	 0.00842	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51863	 52014	 0.070285	 0.18898	 0.04291	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51863	 53291	 0.10516	 0.29426	 0.06202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51863	 93218	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51863	 93218	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93218	 51864	 0.1908	 0.15102	 0.0019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51865	 93245	 0.25958	 0.597	 0.00908	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51866	 51867	 0.001294	 0.004509	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51866	 51870	 0.001523	 0.005306	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51866	 93219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51866	 93219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51866	 93243	 0.006427	 0.022716	 0.00512	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51867	 51868	 0.001423	 0.003761	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51867	 51874	 0.001161	 0.004565	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51868	 51870	 0.002521	 0.008649	 0.00207	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51868	 51874	 0.001214	 0.004772	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51868	 51877	 0.001594	 0.006383	 0.00161	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93219	 51869	 0.025056	 0.019829	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51869	 93220	 0.009957	 0.019714	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51870	 51967	 0.003352	 0.014934	 0.00406	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51870	 93220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51870	 93220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93219	 51871	 0.043	 0.03403	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51871	 93244	 0.024933	 0.063408	 0.001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51872	 51873	 0.003213	 0.015503	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93219	 51872	 0.003345	 0.019016	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51873	 51881	 0.04113	 0.073928	 0.00133	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51873	 93221	 0.011906	 0.03028	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51874	 51882	 0.00142	 0.015218	 0.00486	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92500	 51874	 0.003665	 0.029445	 0.00828	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51874	 93221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51874	 93221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51875	 51877	 0.001842	 0.007373	 0.00186	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92494	 51875	 0.018282	 0.071871	 0.01881	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51876	 51880	 0.002744	 0.022274	 0.00709	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51876	 51883	 0.011995	 0.070273	 0.01915	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51876	 93222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51876	 93222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51877	 51879	 0.000935	 0.006834	 0.00202	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93220	 51878	 0.023041	 0.018234	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51879	 51880	 0.008089	 0.020335	 0.00527	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92500	 51879	 0.001573	 0.012854	 0.00349	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92494	 51880	 0.012797	 0.058717	 0.01505	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92500	 51880	 0.00245	 0.016816	 0.0049	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51882	 51926	 0.017966	 0.15694	 0.04317	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51883	 51951	 0.048588	 0.13238	 0.02919	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51883	 51954	 0.03558	 0.19557	 0.05182	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51884	 52003	 0.35097	 0.53817	 0.00756	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51885	 51886	 0.007608	 0.011652	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51885	 51887	 0.009962	 0.016638	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51885	 51890	 0.008324	 0.032024	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51885	 51890	 0.008324	 0.032024	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90320	 51885	 0.003236	 0.012448	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90320	 51885	 0.003236	 0.012448	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51886	 51887	 0.007426	 0.007912	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51887	 51888	 0.011882	 0.032912	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51888	 93223	 0.008041	 0.058772	 0.00108	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51889	 51891	 0.019229	 0.015218	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51890	 51893	 0.002436	 0.007472	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51890	 51893	 0.002436	 0.007472	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51891	 93223	 0.007712	 0.019824	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51892	 51895	 0.001276	 0.004376	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51892	 51901	 0.000971	 0.008059	 0.00212	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51892	 51902	 0.00189	 0.007692	 0.00187	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51892	 93223	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51892	 93223	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51892	 93234	 0.010782	 0.18494	 0.10073	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51892	 93234	 0.010782	 0.18494	 0.10073	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51893	 51894	 0.00272	 0.01058	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51893	 51894	 0.00272	 0.01058	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93223	 51893	 0.003627	 0.02651	 0.00049	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51894	 93224	 0.003286	 0.012783	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51894	 93224	 0.003286	 0.012783	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51895	 51898	 0.001919	 0.005071	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51895	 93224	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51895	 93224	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51896	 51900	 0.022092	 0.014302	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93223	 51896	 0.015266	 0.035073	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93224	 51896	 0.007709	 0.017896	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51896	 93226	 0.007334	 0.021035	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93224	 51897	 0.003282	 0.018443	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51897	 93225	 0.001616	 0.008174	 0.00014	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51897	 93227	 0.004006	 0.01431	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51897	 93227	 0.004006	 0.01431	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51898	 93225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51898	 93225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51899	 51910	 0.000461	 0.003471	 0.00096	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51899	 93226	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51899	 93226	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51901	 51903	 0.000396	 0.003801	 0.00111	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51901	 51909	 0.000976	 0.005082	 0.00133	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51901	 93227	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51901	 93227	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51903	 51906	 0.000631	 0.00616	 0.00173	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93227	 51904	 0.005642	 0.017308	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93227	 51904	 0.005642	 0.017308	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51904	 93228	 0.003673	 0.014288	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51904	 93228	 0.003673	 0.014288	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51905	 51906	 0.000605	 0.005926	 0.00186	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51905	 51915	 0.002004	 0.022909	 0.00642	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51906	 93228	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51906	 93228	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93228	 51907	 0.012793	 0.016508	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51908	 51909	 0.001287	 0.006468	 0.00168	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51908	 51910	 0.000673	 0.005728	 0.00143	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51908	 51916	 0.001029	 0.014378	 0.00487	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51908	 93229	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51908	 93229	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93229	 51911	 0.001615	 0.013716	 0.00032	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51912	 51914	 0.005812	 0.055812	 0.01624	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51913	 93230	 0.34357	 0.272	 0.00342	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51914	 51915	 0.007292	 0.053878	 0.01555	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51914	 51916	 0.007896	 0.058689	 0.02239	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51914	 51917	 0.010307	 0.059116	 0.01965	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51914	 93230	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51914	 93230	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51915	 52025	 0.021981	 0.12069	 0.03193	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51916	 51917	 0.005544	 0.039885	 0.01057	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51917	 51991	 0.008042	 0.051809	 0.01358	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51918	 51919	 0.047627	 0.072236	 0.00104	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92499	 51919	 0.076354	 0.17726	 0.00338	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51920	 93237	 0.067458	 0.35548	 0.00638	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	51920	 93255	 0.11692	 0.2715	 0.00404	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51921	 51922	 0.003524	 0.032057	 0.00809	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51921	 51953	 0.039809	 0.10238	 0.02537	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51922	 53125	 0.010879	 0.088941	 0.02414	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51923	 52049	 0.86233	 0.56015	 0.01065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51924	 51959	 0.18745	 0.62602	 0.00994	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92486	 51924	 0.082246	 0.50586	 0.01158	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51924	 93258	 0.16218	 0.63166	 0.01056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51925	 93232	 0.10447	 0.29972	 0.00461	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51926	 51957	 0.017712	 0.15207	 0.04335	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51926	 93231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51926	 93231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51926	 93683	 0.06761	 0.17894	 0.04195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51927	 51948	 0.011328	 0.11457	 0.03372	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51927	 52016	 0.023695	 0.094902	 0.02392	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51927	 52047	 0.018036	 0.14504	 0.04083	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51927	 93232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51927	 93232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51929	 51933	 0.002545	 0.012162	 0.00027	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	51929	 93233	 0.009517	 0.037025	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51929	 93233	 0.009517	 0.037025	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51930	 51931	 0.010061	 0.012489	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51931	 93233	 0.006185	 0.012657	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51932	 93233	 0.009518	 0.024207	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51933	 51934	 0.001505	 0.012518	 0.00024	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51934	 51939	 0.000849	 0.00706	 0.00013	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51935	 93233	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51935	 93233	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51935	 93234	 0.001388	 0.022677	 0.01121	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51936	 51939	 0.001502	 0.013982	 0.00027	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93233	 51936	 0.006288	 0.024464	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93233	 51936	 0.006288	 0.024464	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93233	 51937	 0.009073	 0.017964	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51938	 51939	 0.0208	 0.016304	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51940	 51941	 0.019515	 0.021464	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93233	 51941	 0.016824	 0.041181	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51942	 52027	 0.083308	 0.25565	 0.00693	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51942	 93235	 0.043611	 0.19109	 0.00411	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51943	 93234	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51943	 93234	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95334	 51943	 0.005343	 0.10397	 2.2882	 1959.0	 2056.9	 2154.9	 0.0	 0.0	 0	 -30.0	 30.0;
	95334	 51943	 0.005343	 0.10397	 2.2882	 736.0	 772.8	 809.6	 0.0	 0.0	 0	 -30.0	 30.0;
	95334	 51943	 0.005343	 0.10397	 2.2882	 736.0	 772.8	 809.6	 0.0	 0.0	 0	 -30.0	 30.0;
	51944	 52015	 0.087684	 0.26909	 0.00729	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51944	 93235	 0.063283	 0.1905	 0.00373	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51945	 51946	 0.010762	 0.048459	 0.0129	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93234	 51945	 0.014388	 0.057612	 0.01452	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51946	 51975	 0.025588	 0.10417	 0.0254	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51946	 93235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51946	 93235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51947	 51971	 0.023476	 0.12891	 0.03411	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51947	 52004	 0.022494	 0.11964	 0.02778	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51948	 93236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51948	 93236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51949	 93258	 0.66706	 0.5287	 0.00666	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51950	 93259	 0.57811	 0.45803	 0.00577	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51951	 52047	 0.067299	 0.17811	 0.04176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51952	 51953	 0.013218	 0.088598	 0.02716	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51952	 51989	 0.018678	 0.094525	 0.02633	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51952	 93237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51952	 93237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51953	 93261	 0.015749	 0.10303	 0.02622	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92491	 51955	 0.76894	 0.54596	 0.00863	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51955	 93238	 0.23338	 0.37279	 0.00859	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92493	 51956	 0.052464	 0.20661	 0.05419	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51956	 93238	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51956	 93238	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51958	 51973	 0.25547	 0.20222	 0.00255	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51959	 51960	 0.037013	 0.08304	 0.00132	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51960	 51961	 0.59081	 0.46812	 0.00589	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51960	 93270	 0.21195	 0.4458	 0.00813	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92485	 51962	 0.000537	 0.008161	 0.0185	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51962	 93239	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93240	 51962	 0.000318	 0.023855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51963	 51974	 0.074241	 0.25947	 0.06039	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51963	 52044	 0.026016	 0.098936	 0.02771	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92493	 51963	 0.006456	 0.058733	 0.01483	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51964	 51965	 0.008565	 0.033666	 0.00881	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92489	 51964	 0.022653	 0.061683	 0.01359	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92493	 51964	 0.0256	 0.068742	 0.01558	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	51965	 93242	 0.002615	 0.011069	 0.00249	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51966	 93241	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93242	 51966	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 0	 -30.0	 30.0;
	92487	 51967	 0.006583	 0.082844	 0.02568	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92500	 51967	 0.002514	 0.009881	 0.00258	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51967	 93243	 0.002256	 0.012123	 0.00298	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51968	 51969	 0.000344	 0.003551	 0.05581	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51969	 53147	 0.002603	 0.048323	 0.46689	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	51969	 93243	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93244	 51970	 0.082643	 0.18749	 0.00374	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51970	 93256	 0.31364	 0.56444	 0.01015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51971	 93257	 0.014735	 0.11617	 0.03401	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51972	 51973	 0.12259	 0.26181	 0.00591	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92486	 51972	 0.10646	 0.52885	 0.01263	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51972	 93245	 0.2495	 0.48934	 0.00734	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51973	 93245	 0.64264	 0.47355	 0.00692	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51974	 93245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 -1.0	 1	 -30.0	 30.0;
	51974	 93245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 -1.0	 1	 -30.0	 30.0;
	51975	 93246	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51975	 93246	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92487	 51976	 0.007176	 0.028204	 0.00738	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51977	 51979	 0.13717	 0.22881	 0.00333	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51977	 93247	 0.083021	 0.27701	 0.00439	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51978	 93247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51978	 93247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51979	 93248	 0.084977	 0.16655	 0.0025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51980	 52030	 0.022695	 0.092383	 0.02252	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51980	 93248	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51980	 93248	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51981	 52029	 0.017752	 0.067493	 0.0189	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51981	 93249	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51981	 93249	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92491	 51982	 0.013056	 0.066047	 0.00115	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93238	 51983	 0.11375	 0.44279	 0.0074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51984	 93250	 0.007602	 0.033305	 0.00072	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92499	 51985	 0.12183	 0.46902	 0.00801	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92499	 51985	 0.12183	 0.46902	 0.00801	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51985	 93250	 0.024627	 0.20454	 0.005	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51986	 52047	 0.061366	 0.22263	 0.04789	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51986	 93250	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51986	 93250	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51987	 51989	 0.005878	 0.048903	 0.01481	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51987	 51991	 0.007901	 0.07439	 0.02254	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51987	 93251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51987	 93251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51988	 93252	 0.11859	 0.092959	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	51989	 52001	 0.017514	 0.074141	 0.01669	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51989	 93252	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51989	 93252	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51990	 52043	 0.15062	 0.29527	 0.00443	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51991	 51992	 0.005036	 0.036439	 0.0196	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51992	 51993	 0.008461	 0.067986	 0.01911	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	51992	 51996	 0.021344	 0.074403	 0.01726	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	51993	 93253	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51993	 93253	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51994	 51995	 0.035379	 0.1691	 0.0037	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93253	 51994	 0.004403	 0.043145	 0.00084	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51995	 93254	 0.043091	 0.20011	 0.00546	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	51996	 53294	 0.017585	 0.085365	 0.01952	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	51996	 93254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51996	 93254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51997	 51998	 0.062358	 0.16031	 0.00248	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	51997	 51999	 0.065205	 0.12125	 0.00284	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	51997	 52000	 0.078234	 0.20113	 0.00311	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92491	 51997	 0.12463	 0.41597	 0.0066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	51998	 52022	 0.29694	 0.39048	 0.00535	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92491	 52000	 0.066081	 0.22047	 0.0035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52001	 93255	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52001	 93255	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52002	 53216	 0.49567	 0.32125	 0.00611	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93255	 52002	 0.31449	 0.21134	 0.00373	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52003	 52046	 0.083847	 0.30722	 0.00777	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93238	 52003	 0.76216	 0.51323	 0.00905	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93240	 52003	 0.12224	 0.51779	 0.00977	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52004	 53146	 0.038238	 0.11518	 0.03607	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52004	 93256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52004	 93256	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93231	 52005	 0.24368	 0.43831	 0.00788	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93256	 52005	 0.083865	 0.32636	 0.00545	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93218	 52006	 0.41521	 0.32565	 0.00418	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52007	 53221	 0.007418	 0.079813	 1.2232	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52007	 93257	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52008	 93259	 0.03739	 0.096117	 0.00149	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52009	 52010	 0.008591	 0.022085	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52009	 93260	 0.13414	 0.24575	 0.00424	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52010	 52011	 0.011712	 0.017763	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52010	 52012	 0.007681	 0.029882	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93258	 52012	 0.050118	 0.34415	 0.00628	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52012	 93259	 0.021489	 0.061634	 0.00095	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52013	 52014	 0.020954	 0.073043	 0.01694	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93257	 52013	 0.014842	 0.079104	 0.02221	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52013	 93259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52013	 93259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52014	 93260	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52014	 93260	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92497	 52015	 0.049289	 0.19177	 0.0032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52016	 52020	 0.018242	 0.073049	 0.01841	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52016	 93261	 0.021416	 0.1014	 0.0244	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52017	 93261	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52017	 93261	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52018	 52019	 0.000421	 0.005296	 0.00164	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52018	 52021	 0.00277	 0.009501	 0.00228	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52019	 52020	 0.00066	 0.007842	 0.00273	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93261	 52020	 0.005284	 0.050505	 0.01665	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52023	 52024	 0.007013	 0.041077	 0.01119	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93234	 52023	 0.010604	 0.064141	 0.01637	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52024	 52025	 0.008437	 0.048481	 0.01374	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52025	 93262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52025	 93262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93262	 52026	 0.025051	 0.097456	 0.00163	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93262	 52026	 0.025051	 0.097456	 0.00163	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52027	 93263	 0.038592	 0.12875	 0.00204	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52028	 93263	 0.042464	 0.033606	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52029	 52030	 0.010707	 0.042869	 0.0108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52029	 93263	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52029	 93263	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52030	 93264	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52030	 93264	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93248	 52031	 0.11313	 0.32455	 0.00499	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93264	 52031	 0.035846	 0.076533	 0.00173	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92498	 52032	 0.21688	 0.3655	 0.00521	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93246	 52032	 0.73922	 0.58053	 0.00745	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52033	 52034	 0.001987	 0.007554	 0.00211	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52033	 52040	 0.001307	 0.005997	 0.00154	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52034	 93265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52034	 93265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52034	 93267	 0.012289	 0.048306	 0.01264	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52035	 52036	 0.015742	 0.024115	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52035	 52041	 0.048228	 0.1108	 0.00168	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93265	 52035	 0.012874	 0.036532	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52036	 52037	 0.015468	 0.012731	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52037	 52038	 0.00585	 0.019515	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52038	 52045	 0.39186	 0.29705	 0.00409	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52038	 93266	 0.006098	 0.029269	 0.00087	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92492	 52039	 0.092423	 0.24503	 0.00622	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52039	 93266	 0.00752	 0.015806	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52040	 52044	 0.005401	 0.047186	 0.01869	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52040	 93266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52040	 93266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52041	 93268	 0.063166	 0.10535	 0.00153	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52042	 93267	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93268	 52042	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93245	 52043	 0.17658	 0.36159	 0.0089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93268	 52043	 0.26204	 0.38215	 0.00864	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92492	 52045	 0.1206	 0.3101	 0.0048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93245	 52045	 0.8812	 0.69923	 0.0088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52046	 93269	 0.11202	 0.28802	 0.00446	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93239	 52047	 0.016931	 0.17864	 0.10079	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52047	 93269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52047	 93269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52048	 52050	 0.42588	 0.33725	 0.00425	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52049	 52051	 0.12271	 0.24053	 0.00361	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52050	 52051	 0.14167	 0.30369	 0.00532	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93245	 52050	 0.1424	 0.6353	 0.01081	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52050	 93270	 0.1214	 0.25926	 0.00585	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52051	 93270	 0.012456	 0.048458	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52052	 52053	 0.01514	 0.012461	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52053	 93270	 0.010675	 0.025277	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93241	 52054	 0.02259	 0.15357	 0.28585	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52054	 93270	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52054	 93270	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 0	 -30.0	 30.0;
	52055	 52056	 0.009489	 0.031973	 0.00795	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52055	 52291	 0.011212	 0.039634	 0.00893	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52056	 52058	 0.016404	 0.055275	 0.01374	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52056	 93271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52056	 93271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52057	 52146	 0.12346	 0.2867	 0.00426	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52057	 93272	 0.045253	 0.072233	 0.00166	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52058	 52059	 0.006501	 0.021687	 0.0055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52058	 93272	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52058	 93272	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52059	 52143	 0.037961	 0.1034	 0.02279	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52059	 52851	 0.016154	 0.064688	 0.0163	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52060	 52061	 0.011869	 0.047524	 0.01197	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52060	 93273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52060	 93273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52061	 52062	 0.012529	 0.057483	 0.01473	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52061	 93274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52061	 93274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52062	 52429	 0.010162	 0.06307	 0.01528	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52062	 93275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52062	 93275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52063	 93276	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93277	 52063	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52064	 52065	 0.00169	 0.012909	 0.04798	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93276	 52064	 0.001749	 0.020839	 0.04511	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52064	 93278	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52064	 93278	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52065	 52080	 0.00203	 0.021048	 0.04534	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52065	 93279	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52065	 93279	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52066	 93544	 0.14801	 0.23632	 0.00544	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52067	 93280	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93281	 52067	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52067	 94729	 0.013184	 0.14158	 0.29085	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52067	 94729	 0.013184	 0.14158	 0.29085	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52068	 56875	 0.052465	 0.29831	 0.0054	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93281	 52068	 0.054631	 0.23361	 0.00528	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93281	 52069	 0.07419	 0.11365	 0.0016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52070	 52071	 0.002779	 0.023369	 0.00692	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52070	 53089	 0.005926	 0.043315	 0.01278	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52070	 93282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52070	 93282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52071	 52073	 0.014204	 0.048729	 0.01168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52072	 93283	 0.096782	 0.2747	 0.00432	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52072	 95276	 0.078362	 0.413	 0.00742	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52073	 52330	 0.012576	 0.064246	 0.01616	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52073	 93283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52073	 93283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52074	 52075	 0.013614	 0.052968	 0.01415	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52074	 52429	 0.026398	 0.074067	 0.01907	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52074	 52431	 0.024541	 0.064868	 0.01519	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52075	 52077	 0.011965	 0.061126	 0.01538	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52075	 52292	 0.013463	 0.053908	 0.01358	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52075	 52430	 0.014138	 0.073577	 0.02167	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52076	 93284	 0.018139	 0.09742	 0.00231	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52076	 93395	 0.084775	 0.24061	 0.00378	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52077	 52078	 0.015709	 0.066495	 0.01497	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52077	 52280	 0.036032	 0.12368	 0.02966	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52077	 93284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52077	 93284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52078	 52098	 0.016603	 0.065266	 0.01708	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52078	 52281	 0.015493	 0.053151	 0.01273	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52079	 56818	 0.023807	 0.1008	 0.02269	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52079	 93285	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52079	 93285	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52079	 93286	 0.007262	 0.045996	 0.01249	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52079	 93289	 0.009225	 0.056693	 0.02073	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52080	 93286	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52080	 93286	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52081	 94318	 0.17961	 0.1408	 0.00181	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52082	 52084	 0.001524	 0.015829	 0.00489	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52082	 52085	 0.003285	 0.02363	 0.00626	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52082	 52355	 0.007349	 0.05791	 0.01694	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52082	 52435	 0.012006	 0.054063	 0.01439	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52083	 52088	 0.000288	 0.003159	 0.03069	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52083	 54921	 0.002405	 0.030941	 0.52809	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52083	 93287	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52083	 93287	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52084	 52085	 0.002415	 0.008283	 0.00198	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52084	 93289	 0.003118	 0.016512	 0.00419	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52085	 93288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52085	 93288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52085	 93289	 0.000841	 0.008346	 0.00227	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52086	 52087	 0.027651	 0.030413	 0.00041	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93288	 52086	 0.005352	 0.013611	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52088	 52089	 0.000479	 0.00618	 0.10373	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52088	 93289	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52088	 93289	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52089	 55491	 0.000641	 0.007294	 0.06587	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52089	 93290	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93291	 52089	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52090	 52091	 0.008291	 0.048564	 0.01323	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92547	 52090	 0.012008	 0.074632	 0.02107	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52091	 93292	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52091	 93292	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52092	 52373	 0.016404	 0.056279	 0.01348	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92538	 52092	 0.019222	 0.069615	 0.01494	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52093	 52373	 0.032988	 0.085668	 0.0208	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92547	 52093	 0.007187	 0.019296	 0.00437	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92556	 52094	 0.023295	 0.059882	 0.00093	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92547	 52095	 0.004125	 0.02345	 0.00679	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52095	 93293	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52095	 93293	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92543	 52096	 0.043631	 0.12515	 0.00192	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93293	 52096	 0.080569	 0.18429	 0.0045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52097	 52242	 0.076662	 0.178	 0.00265	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52097	 93377	 0.048691	 0.14656	 0.00287	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52098	 52103	 0.014112	 0.059733	 0.01344	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92552	 52099	 0.067961	 0.17472	 0.0027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52099	 93294	 0.09013	 0.17847	 0.00262	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52100	 52102	 0.005005	 0.019671	 0.00515	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52100	 52372	 0.009555	 0.049775	 0.01306	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52100	 93294	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52100	 93294	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52100	 93296	 0.009982	 0.045797	 0.01173	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52101	 93295	 0.008622	 0.022164	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52102	 52103	 0.000984	 0.003867	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52103	 52104	 0.000704	 0.003537	 0.00092	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52104	 93295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52104	 93295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52104	 93296	 0.003147	 0.019032	 0.00486	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52105	 93296	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52106	 52107	 0.015536	 0.017087	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93297	 52106	 0.089319	 0.25623	 0.00394	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52106	 93298	 0.040078	 0.063972	 0.00147	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52107	 52689	 0.026512	 0.06091	 0.00093	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52108	 52109	 0.002175	 0.009205	 0.00207	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52108	 52690	 0.003168	 0.013408	 0.00302	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52108	 93298	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52108	 93298	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52109	 52111	 0.000908	 0.003634	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52109	 93299	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52109	 93299	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52110	 52118	 0.04624	 0.036593	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52110	 93300	 0.007665	 0.012801	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52111	 52112	 0.002071	 0.008429	 0.00205	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52111	 93300	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52111	 93300	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52112	 52115	 0.001916	 0.007455	 0.00199	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92558	 52112	 0.000593	 0.005178	 0.00142	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52113	 52115	 0.001397	 0.005309	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52113	 52121	 0.002249	 0.009152	 0.00223	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52113	 93301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52113	 93301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92558	 52114	 0.001685	 0.005955	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52114	 93302	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52114	 93302	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52115	 52126	 0.006437	 0.01795	 0.00377	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52115	 93303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52115	 93303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93302	 52116	 0.00679	 0.022651	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52116	 93305	 0.023325	 0.054153	 0.00081	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93303	 52117	 0.027758	 0.02603	 0.0004	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52118	 52119	 0.031636	 0.021251	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93301	 52118	 0.010166	 0.021704	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52119	 52120	 0.021341	 0.016889	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93299	 52119	 0.010729	 0.021242	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93303	 52119	 0.059821	 0.051128	 0.00096	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93301	 52120	 0.012623	 0.024992	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93296	 52121	 0.007638	 0.039045	 0.01064	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52122	 52126	 0.001847	 0.00726	 0.0019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52122	 52698	 0.002421	 0.009691	 0.00244	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52123	 52126	 0.002103	 0.008418	 0.00212	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52123	 52325	 0.009629	 0.036604	 0.01025	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52123	 93304	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52123	 93304	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93304	 52124	 0.033819	 0.037197	 0.0005	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52125	 93305	 0.020192	 0.018936	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52126	 93305	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52126	 93305	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52127	 52132	 0.000634	 0.006956	 0.06757	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52127	 93306	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52128	 52129	 0.01621	 0.042842	 0.01003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52128	 52867	 0.017433	 0.04047	 0.01233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52128	 93309	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52128	 93309	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52129	 52130	 0.010686	 0.027743	 0.00673	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52129	 93310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52129	 93310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52130	 52408	 0.019196	 0.057493	 0.01295	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52130	 93311	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52130	 93311	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52131	 52133	 0.017025	 0.04776	 0.0123	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52131	 93312	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52131	 93312	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52131	 93314	 0.007863	 0.030905	 0.00809	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52132	 52313	 0.001774	 0.019473	 0.18932	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52132	 58567	 0.006724	 0.076878	 0.7095	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52132	 93313	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52133	 52406	 0.010389	 0.060859	 0.01658	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52133	 52432	 0.010605	 0.04316	 0.01052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93314	 52133	 0.002877	 0.028109	 0.00789	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52133	 93316	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52133	 93316	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93315	 52134	 0.011272	 0.057355	 0.0013	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93316	 52134	 0.009755	 0.059976	 0.00108	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52135	 52136	 0.012533	 0.028119	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52135	 52137	 0.003155	 0.009679	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93315	 52136	 0.016261	 0.073818	 0.0016	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93315	 52137	 0.008655	 0.034339	 0.00098	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52138	 52141	 0.009533	 0.037468	 0.0098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52138	 52441	 0.013295	 0.050542	 0.01415	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52140	 52142	 0.049867	 0.050367	 0.00067	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52141	 52143	 0.003279	 0.013341	 0.00325	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52141	 93317	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52141	 93317	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52142	 93318	 0.01422	 0.029101	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52143	 93318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52143	 93318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93317	 52144	 0.07866	 0.08381	 0.0012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52145	 52146	 0.089386	 0.12185	 0.0027	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52145	 93561	 0.093381	 0.17105	 0.00295	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93318	 52146	 0.072059	 0.17065	 0.00312	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52146	 93428	 0.028957	 0.14646	 0.00286	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92526	 52147	 0.053941	 0.053954	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52148	 52151	 0.14049	 0.1682	 0.0028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52148	 93319	 0.040644	 0.10448	 0.00162	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52149	 52150	 0.000812	 0.008763	 0.003	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52149	 56817	 0.004825	 0.057067	 0.01625	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52149	 93319	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52149	 93319	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52150	 52809	 0.018245	 0.083725	 0.02146	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52152	 52153	 0.015093	 0.060434	 0.01523	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52152	 94901	 0.08049	 0.32378	 0.08209	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52153	 54350	 0.033003	 0.13223	 0.03335	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52154	 52155	 0.001847	 0.008912	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52154	 93320	 0.002262	 0.011314	 0.0002	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52155	 52161	 0.001458	 0.007116	 0.00012	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52156	 52157	 0.001509	 0.003989	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52156	 52158	 0.001851	 0.007411	 0.00187	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52156	 52177	 0.001615	 0.007965	 0.00215	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52157	 52158	 0.000578	 0.00366	 0.00099	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52157	 52177	 0.002794	 0.011186	 0.00282	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52158	 52168	 0.000251	 0.001819	 0.00098	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52158	 93320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52158	 93320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52159	 52160	 0.007988	 0.015654	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52159	 52173	 0.007763	 0.02384	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52159	 93324	 0.002896	 0.016269	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52161	 93321	 0.002379	 0.011607	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52162	 52170	 9.9e-05	 0.001732	 0.01853	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52162	 52204	 0.00021	 0.003404	 0.03317	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52162	 93321	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52162	 93321	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52163	 52164	 0.008618	 0.017063	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52163	 52175	 0.010867	 0.025228	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52163	 93322	 0.013664	 0.035124	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93320	 52164	 0.007225	 0.018571	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52165	 52166	 0.006266	 0.016107	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52165	 52176	 0.024868	 0.030869	 0.00067	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52165	 52410	 0.082593	 0.15819	 0.00249	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52166	 93322	 0.005018	 0.012899	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52167	 93322	 0.001753	 0.00814	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52167	 93324	 0.00269	 0.016541	 0.0003	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52168	 93322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52168	 93322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52168	 93323	 0.000429	 0.006244	 0.002	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52169	 93324	 0.01064	 0.027352	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52170	 52214	 0.000308	 0.003424	 0.03229	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52170	 93323	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93321	 52171	 0.010979	 0.04271	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52171	 93339	 0.02449	 0.10518	 0.00192	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52172	 52173	 0.010434	 0.029925	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52172	 52211	 0.013784	 0.035724	 0.00068	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52174	 52175	 0.004928	 0.016439	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52174	 93326	 0.004967	 0.02201	 0.00066	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52175	 52176	 0.010059	 0.023354	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52177	 52178	 0.004271	 0.013929	 0.0037	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52177	 52205	 0.001532	 0.010264	 0.00314	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52177	 93325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52177	 93325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52178	 93326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52178	 93326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52179	 93327	 0.009927	 0.00817	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52180	 52181	 0.001007	 0.003957	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52180	 52195	 0.001309	 0.005092	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52180	 93327	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52180	 93327	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52181	 52200	 0.000879	 0.004033	 0.00103	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52181	 93328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52181	 93328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52182	 52185	 0.02611	 0.020663	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52182	 93329	 0.008157	 0.021562	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52183	 52188	 0.001611	 0.00586	 0.00179	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52183	 93329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52183	 93329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92532	 52184	 0.006951	 0.02432	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93329	 52184	 0.008418	 0.024143	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52185	 52186	 0.010522	 0.017725	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93328	 52185	 0.009879	 0.01956	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52186	 93331	 0.026108	 0.020464	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92532	 52187	 0.019741	 0.065855	 0.00104	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52188	 52191	 0.001253	 0.004298	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93329	 52189	 0.01162	 0.028842	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52189	 93330	 0.011357	 0.016624	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52190	 52196	 0.001201	 0.003348	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52190	 52586	 0.001564	 0.004132	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52190	 93330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52190	 93330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52191	 52591	 0.001463	 0.005019	 0.0012	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52192	 52589	 0.006986	 0.008672	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93330	 52192	 0.009695	 0.017492	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52193	 52194	 0.014301	 0.018454	 0.00037	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52193	 93472	 0.011518	 0.029609	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52194	 52198	 0.028416	 0.022488	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52194	 52199	 0.01024	 0.017077	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52195	 52196	 0.001262	 0.005136	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52195	 93331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52195	 93331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52196	 93332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52196	 93332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52197	 52198	 0.009335	 0.020004	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52197	 93475	 0.006124	 0.032629	 0.00057	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52198	 93335	 0.013619	 0.020863	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52199	 93333	 0.009992	 0.01803	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52199	 93335	 0.012729	 0.022386	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52200	 52201	 0.001062	 0.003196	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52200	 93333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52200	 93333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52200	 93336	 0.002551	 0.010027	 0.00262	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52201	 52202	 0.000985	 0.004436	 0.00118	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52201	 93334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52201	 93334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52201	 93336	 0.001477	 0.007851	 0.00182	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52202	 93335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52202	 93335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52202	 93474	 0.004052	 0.015764	 0.00421	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93335	 52203	 0.030972	 0.02451	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52204	 52611	 0.00039	 0.005334	 0.05435	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52204	 93336	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52204	 93336	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93336	 52205	 0.001183	 0.006926	 0.00189	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52205	 93337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52205	 93337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52206	 93338	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52206	 93338	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93337	 52207	 0.009662	 0.020307	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93338	 52207	 0.008291	 0.017767	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52208	 52209	 0.006197	 0.025586	 0.00605	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52208	 52608	 0.007348	 0.024758	 0.00615	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52208	 52805	 0.021237	 0.085051	 0.02144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52208	 93339	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52208	 93339	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52208	 93474	 0.010331	 0.036006	 0.00835	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52209	 52705	 0.005683	 0.017106	 0.00535	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52209	 93539	 0.005652	 0.042577	 0.01181	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52210	 52211	 0.03031	 0.10828	 0.00215	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52210	 93542	 0.0352	 0.18306	 0.00397	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52212	 52213	 0.065998	 0.11909	 0.00172	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52212	 93340	 0.024762	 0.082604	 0.00131	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52213	 52215	 0.1098	 0.12078	 0.00161	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52213	 52314	 0.4772	 0.37794	 0.00476	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52213	 52414	 0.18787	 0.20466	 0.00279	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52213	 93543	 0.041897	 0.17125	 0.00346	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52214	 52313	 0.002138	 0.024863	 0.21521	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52214	 52412	 0.00048	 0.005262	 0.05112	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52214	 93340	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52214	 93340	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52215	 52413	 0.084084	 0.066544	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92528	 52216	 0.004244	 0.063412	 0.01877	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93278	 52216	 0.007317	 0.050231	 0.01465	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52216	 93341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52216	 93341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52217	 52783	 0.060868	 0.12457	 0.00307	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93341	 52217	 0.062214	 0.17845	 0.00274	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52218	 52228	 0.005925	 0.008786	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52218	 52236	 0.038437	 0.030129	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52218	 93344	 0.014095	 0.026638	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52218	 93346	 0.044096	 0.07755	 0.00146	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52218	 93350	 0.019392	 0.044551	 0.00068	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52219	 52220	 0.013074	 0.020027	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52220	 52221	 0.004925	 0.016428	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52220	 52226	 0.015932	 0.016092	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52221	 52222	 0.006534	 0.016797	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52221	 52224	 0.008468	 0.019656	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52221	 93343	 0.012064	 0.040246	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52222	 93343	 0.008738	 0.02915	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52223	 93342	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93343	 52223	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52225	 52233	 0.018592	 0.03681	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93343	 52225	 0.012183	 0.054288	 0.00092	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52226	 52232	 0.014999	 0.018284	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52226	 93344	 0.003221	 0.007628	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93342	 52227	 0.004626	 0.018522	 0.00467	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52227	 93344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52227	 93344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52228	 52229	 0.005317	 0.008957	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52229	 52230	 0.005712	 0.009117	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52229	 52231	 0.01822	 0.011796	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52230	 52249	 0.005309	 0.009872	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93344	 52230	 0.004375	 0.013436	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52232	 52233	 0.016108	 0.010428	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52233	 52234	 0.016072	 0.016233	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52234	 52249	 0.028575	 0.022398	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52234	 93347	 0.0289	 0.064838	 0.00103	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52235	 52249	 0.006065	 0.01408	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52235	 93347	 0.026462	 0.058567	 0.00096	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52237	 52250	 0.018712	 0.049458	 0.01158	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93342	 52237	 0.008084	 0.028288	 0.00937	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52237	 93345	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52237	 93345	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52238	 52240	 0.003512	 0.014502	 0.00343	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52238	 93346	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52238	 93346	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52239	 52240	 0.001963	 0.016331	 0.00495	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52239	 52864	 0.004355	 0.037349	 0.01063	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52240	 52247	 0.004788	 0.03322	 0.00948	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52241	 93347	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52241	 93347	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52242	 93350	 0.03469	 0.21085	 0.00389	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52243	 52246	 0.003808	 0.027165	 0.00842	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92550	 52243	 0.002251	 0.019947	 0.00531	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52243	 93348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52243	 93348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93343	 52244	 0.046617	 0.11984	 0.00185	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52245	 52874	 0.017438	 0.066297	 0.01856	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93342	 52245	 0.01618	 0.055511	 0.0133	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93342	 52246	 0.002918	 0.021978	 0.0061	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92538	 52247	 0.010871	 0.079412	 0.02042	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52247	 93349	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52247	 93349	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93342	 52248	 0.007229	 0.029418	 0.00717	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52248	 93350	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52248	 93350	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93344	 52249	 0.014127	 0.02797	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52250	 52251	 0.018446	 0.048754	 0.01141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52251	 58424	 0.0132	 0.064068	 0.01465	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52251	 93351	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52251	 93351	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52252	 52253	 0.016047	 0.065312	 0.01592	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52252	 93352	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52252	 93352	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52253	 52443	 0.024809	 0.085129	 0.0204	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52253	 52836	 0.01274	 0.051013	 0.01285	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52253	 93353	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52253	 93353	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52254	 52255	 0.02323	 0.043904	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52254	 52256	 0.03577	 0.070823	 0.00104	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92567	 52254	 0.069682	 0.23249	 0.00369	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93353	 52254	 0.099102	 0.14069	 0.00232	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52256	 93367	 0.033161	 0.091734	 0.00213	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52257	 52946	 0.006367	 0.021841	 0.00523	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52257	 93354	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52257	 93354	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52257	 93359	 0.002743	 0.021896	 0.0054	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52257	 93602	 0.001411	 0.00998	 0.00274	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52257	 93604	 0.00471	 0.018324	 0.00489	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93354	 52258	 0.013109	 0.031043	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93354	 52259	 0.013132	 0.033757	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52260	 52271	 0.005035	 0.032432	 0.0085	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52260	 52276	 0.004707	 0.019434	 0.0046	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52260	 93359	 0.002236	 0.017965	 0.00505	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52261	 93360	 0.013399	 0.026528	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52262	 52267	 0.007553	 0.030239	 0.00762	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52262	 52268	 0.004743	 0.018988	 0.00478	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52263	 52267	 0.006983	 0.027958	 0.00704	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52263	 52749	 0.008349	 0.040519	 0.00926	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52263	 52765	 0.006883	 0.028656	 0.00894	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52263	 93355	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52263	 93355	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52264	 52265	 0.023213	 0.1017	 0.00219	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93355	 52264	 0.026863	 0.10335	 0.00176	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52265	 52266	 0.043552	 0.10313	 0.00189	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52266	 93358	 0.030692	 0.062809	 0.00155	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52267	 93356	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52267	 93356	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52268	 52269	 0.004256	 0.01732	 0.00422	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52269	 52270	 0.002777	 0.029434	 0.00874	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52269	 52271	 0.005236	 0.030672	 0.00836	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52269	 93357	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52269	 93357	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52270	 52472	 0.014954	 0.068616	 0.01758	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52270	 52473	 0.010846	 0.057446	 0.01456	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52272	 52273	 0.001602	 0.010747	 0.00259	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52272	 52943	 0.001736	 0.012276	 0.00337	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52272	 53051	 0.00203	 0.007718	 0.00216	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52273	 93358	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52273	 93358	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52273	 93359	 0.002358	 0.00998	 0.00225	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52274	 93359	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93360	 52274	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52274	 93603	 0.000803	 0.006248	 0.02239	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93360	 52275	 0.013667	 0.035133	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52276	 53025	 0.004076	 0.021669	 0.00503	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93360	 52277	 0.04654	 0.036481	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52278	 52279	 0.008616	 0.035577	 0.00842	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52278	 93361	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52278	 93361	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52279	 52282	 0.008687	 0.034144	 0.00893	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52279	 53089	 0.015375	 0.055942	 0.01713	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52279	 93362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52279	 93362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52280	 93363	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52280	 93363	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52281	 93364	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52281	 93364	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52282	 52294	 0.015961	 0.063915	 0.01611	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52282	 93365	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52282	 93365	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52283	 52285	 0.005377	 0.023962	 0.00651	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52283	 52289	 0.010801	 0.039112	 0.00839	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52284	 52746	 0.095522	 0.15955	 0.00271	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52284	 93366	 0.083894	 0.092276	 0.00123	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52285	 52287	 0.008949	 0.02365	 0.00554	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92453	 52285	 0.014801	 0.12704	 0.03619	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52285	 93366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52285	 93366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52286	 52287	 0.006292	 0.025605	 0.00624	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52286	 93367	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52286	 93367	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52287	 52745	 0.007424	 0.024214	 0.00643	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92567	 52288	 0.05075	 0.12423	 0.00212	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52289	 52291	 0.011567	 0.047761	 0.0113	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52289	 93368	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52289	 93368	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92557	 52290	 0.074396	 0.19126	 0.00296	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52292	 53097	 0.034272	 0.16651	 0.03812	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52293	 52294	 0.015215	 0.05981	 0.01565	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52295	 52296	 0.10036	 0.37667	 0.00677	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52295	 56876	 0.2463	 0.44469	 0.00643	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92540	 52295	 0.079431	 0.30909	 0.00516	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52296	 52811	 0.13003	 0.43399	 0.00688	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52297	 52298	 0.00246	 0.008288	 0.00206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52297	 52308	 0.009636	 0.029262	 0.00641	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52297	 52429	 0.018939	 0.082456	 0.0235	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52297	 93369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52297	 93369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52298	 52301	 0.005765	 0.033766	 0.0092	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52298	 93370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52298	 93370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52298	 93372	 0.003509	 0.024442	 0.00919	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52299	 52300	 0.008984	 0.023094	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93369	 52300	 0.007278	 0.018509	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52301	 52328	 0.007023	 0.060239	 0.01715	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52301	 93372	 0.00615	 0.035333	 0.01001	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52302	 52306	 0.00028	 0.004251	 0.07618	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52302	 52404	 0.0008	 0.009425	 0.16469	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52302	 93371	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52302	 93371	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52303	 52305	 0.014704	 0.026429	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52303	 52307	 0.032684	 0.066887	 0.00165	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93370	 52303	 0.01224	 0.047616	 0.00079	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93369	 52304	 0.016658	 0.025519	 0.00036	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52306	 52364	 0.001476	 0.020199	 0.30257	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52306	 93372	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52306	 93372	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52309	 93374	 0.016803	 0.046861	 0.00984	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52309	 93534	 0.016755	 0.046727	 0.00981	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52310	 52311	 0.026273	 0.052019	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52310	 52414	 0.16732	 0.16902	 0.00224	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52311	 93375	 0.029142	 0.10204	 0.00283	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52312	 93375	 0.034325	 0.088239	 0.00137	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52313	 93373	 8.1e-05	 0.006451	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52314	 52411	 0.17447	 0.17624	 0.00233	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93375	 52314	 0.059529	 0.26532	 0.00451	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52315	 52316	 0.037224	 0.088147	 0.00161	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52315	 52317	 0.11981	 0.23725	 0.00348	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52315	 52866	 0.094606	 0.22407	 0.0041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52316	 52322	 0.11576	 0.20809	 0.00374	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52316	 52411	 0.060902	 0.13815	 0.00276	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93375	 52317	 0.10159	 0.25842	 0.00409	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52318	 52319	 0.013885	 0.032236	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52318	 52327	 0.009856	 0.032523	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92551	 52318	 0.040792	 0.25083	 0.00452	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52318	 93378	 0.015835	 0.085044	 0.00202	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52319	 93376	 0.01868	 0.034732	 0.00081	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52320	 52321	 0.003888	 0.015824	 0.00386	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52320	 93376	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52320	 93376	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52321	 93377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52321	 93377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92543	 52322	 0.13957	 0.48878	 0.01013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93376	 52322	 0.064699	 0.19476	 0.00381	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52323	 52325	 0.004504	 0.034253	 0.01076	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52323	 93378	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52323	 93378	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92542	 52324	 0.007445	 0.013637	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52325	 93379	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52325	 93379	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52326	 52409	 0.04237	 0.078783	 0.00184	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93379	 52326	 0.02249	 0.084366	 0.00152	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93376	 52327	 0.017157	 0.035111	 0.00086	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52328	 52329	 0.007945	 0.058082	 0.01714	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52328	 93380	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52328	 93380	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52329	 93381	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52329	 93381	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52330	 52331	 0.010316	 0.047332	 0.01213	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52331	 52347	 0.017474	 0.066434	 0.0186	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52331	 93382	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52331	 93382	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52332	 54118	 0.12463	 0.38293	 0.00719	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93382	 52332	 0.12697	 0.29484	 0.00439	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92539	 52333	 0.012191	 0.0516	 0.01161	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52334	 93383	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52334	 93383	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52335	 52382	 0.012012	 0.047215	 0.01235	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52335	 52462	 0.035471	 0.089199	 0.02312	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52335	 93384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52335	 93384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52336	 52338	 0.048887	 0.1881	 0.00321	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93384	 52336	 0.061245	 0.15874	 0.003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52336	 93429	 0.10256	 0.18436	 0.00331	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92561	 52337	 0.024887	 0.13367	 0.00317	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52337	 93527	 0.044248	 0.21595	 0.00373	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52338	 93397	 0.099532	 0.21333	 0.00374	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52339	 52475	 0.009197	 0.038926	 0.00876	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52339	 52772	 0.021362	 0.083985	 0.02198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52340	 52342	 0.013544	 0.076214	 0.00165	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52340	 93528	 0.048311	 0.24588	 0.00557	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52341	 52845	 0.005106	 0.020068	 0.00525	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52341	 52848	 0.005134	 0.029499	 0.00836	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52341	 93385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52341	 93385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93385	 52342	 0.009626	 0.059182	 0.00107	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52343	 52848	 0.011508	 0.084068	 0.02162	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92528	 52343	 0.0177	 0.088958	 0.02316	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52343	 93386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52343	 93386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52344	 52875	 0.009857	 0.038744	 0.01014	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52344	 93388	 0.002906	 0.014105	 0.00322	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52345	 93387	 0.070466	 0.075253	 0.00159	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52346	 52347	 0.014707	 0.057813	 0.01513	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52346	 55583	 0.021248	 0.086492	 0.02108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52347	 93387	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52347	 93387	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52347	 93388	 0.004491	 0.017979	 0.00453	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52348	 58422	 0.003665	 0.042299	 0.41626	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52348	 93388	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52349	 52350	 0.041916	 0.033172	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52349	 52351	 0.016515	 0.030249	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93389	 52349	 0.019098	 0.049093	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93310	 52352	 0.12022	 0.16757	 0.00287	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52352	 93390	 0.15692	 0.26441	 0.00377	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52353	 57093	 0.02298	 0.059083	 0.01463	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52353	 93390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52353	 93390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52354	 52868	 0.10602	 0.18509	 0.00287	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93351	 52354	 0.082446	 0.36752	 0.00624	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93390	 52354	 0.10055	 0.23349	 0.00347	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93279	 52355	 0.006943	 0.049112	 0.01348	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52355	 93391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52355	 93391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52356	 52357	 0.075966	 0.16281	 0.00285	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93391	 52356	 0.041283	 0.17473	 0.00329	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52357	 52445	 0.090435	 0.20998	 0.00312	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52358	 52364	 0.000172	 0.002607	 0.04671	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92553	 52359	 0.011339	 0.014903	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52360	 52366	 0.000573	 0.008255	 0.07575	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92553	 52362	 0.019533	 0.034889	 0.00051	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92553	 52363	 0.016001	 0.028139	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52364	 93392	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93392	 52365	 0.009529	 0.037454	 0.0098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52365	 93394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52365	 93394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93394	 52367	 0.038378	 0.11552	 0.00226	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93392	 52368	 0.005937	 0.058012	 0.01628	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52369	 52370	 0.005787	 0.052645	 0.01329	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93371	 52369	 0.005297	 0.05443	 0.01722	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52370	 52371	 0.003697	 0.032262	 0.00886	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52370	 93395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52370	 93395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52371	 52372	 0.003845	 0.021099	 0.00558	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52373	 52374	 0.01594	 0.060599	 0.01697	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52374	 53090	 0.016034	 0.065259	 0.0159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52374	 93396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52374	 93396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93389	 52375	 0.10593	 0.30389	 0.00467	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93396	 52375	 0.084129	 0.15645	 0.00366	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52376	 52378	 0.009242	 0.061931	 0.01898	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52376	 52382	 0.016181	 0.073476	 0.02551	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52376	 93397	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52376	 93397	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52377	 52378	 0.01306	 0.05528	 0.01244	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52377	 52770	 0.011837	 0.046525	 0.01217	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52377	 93398	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52377	 93398	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52378	 52808	 0.008308	 0.052626	 0.01429	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52378	 93399	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52378	 93399	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52379	 93401	 0.046591	 0.091313	 0.00137	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52380	 93560	 0.097316	 0.077017	 0.00097	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52382	 52387	 0.014932	 0.061662	 0.01459	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52382	 93400	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52382	 93400	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52383	 52386	 0.047889	 0.094817	 0.00139	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52384	 52857	 0.013577	 0.036965	 0.00814	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52384	 93401	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52384	 93401	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52385	 52386	 0.020304	 0.051636	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92537	 52386	 0.044381	 0.17267	 0.00288	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52387	 52389	 0.010158	 0.038615	 0.01081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52388	 52389	 0.011011	 0.042837	 0.01144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52389	 52390	 0.009661	 0.058435	 0.01491	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52390	 52415	 0.012858	 0.076619	 0.02016	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52391	 52397	 0.001475	 0.017623	 0.03481	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52391	 53048	 0.0043	 0.059227	 0.11821	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52391	 93402	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52391	 93402	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52392	 52403	 0.007311	 0.058372	 0.01439	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52392	 52764	 0.010832	 0.042142	 0.01126	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52392	 52768	 0.012283	 0.04918	 0.01239	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52393	 93403	 0.003141	 0.038162	 0.01028	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52393	 93507	 0.003547	 0.036491	 0.01035	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52394	 93540	 0.050336	 0.1294	 0.002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52395	 52396	 0.012604	 0.04247	 0.01056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52395	 52473	 0.006676	 0.042288	 0.01148	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52395	 52800	 0.00332	 0.040464	 0.01338	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52396	 93403	 0.007414	 0.024182	 0.00642	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52397	 93403	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52397	 93403	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52397	 93538	 0.002459	 0.034488	 0.06616	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52398	 52400	 9.8e-05	 0.001605	 0.01576	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52398	 52402	 4.5e-05	 0.000741	 0.00783	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52398	 93404	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52398	 93404	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93404	 52399	 0.019078	 0.034942	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52400	 52401	 0.000211	 0.003373	 0.03409	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52401	 52405	 0.000246	 0.003863	 0.04026	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52401	 52640	 0.000253	 0.002973	 0.05192	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52402	 52762	 0.000672	 0.009107	 0.13879	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92527	 52403	 0.007391	 0.044702	 0.01141	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52404	 52405	 0.000673	 0.008475	 0.12919	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52405	 93405	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52405	 93405	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52406	 52407	 0.001906	 0.011842	 0.00334	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52407	 54318	 0.017467	 0.071093	 0.01733	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52407	 93406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52407	 93406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52408	 57092	 0.024431	 0.072042	 0.01676	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92532	 52409	 0.009999	 0.040013	 0.00084	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93378	 52410	 0.081544	 0.23392	 0.0036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52411	 93408	 0.051	 0.16831	 0.00273	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52412	 93407	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93408	 52413	 0.051711	 0.13293	 0.00206	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92554	 52416	 0.085351	 0.21709	 0.00343	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52417	 52420	 0.012343	 0.056631	 0.01451	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52418	 52419	 0.000379	 0.00453	 0.00895	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52418	 93409	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52418	 93409	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52419	 53854	 0.010196	 0.06964	 0.12566	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52419	 93410	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52419	 93410	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52420	 52421	 0.00545	 0.02784	 0.007	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52420	 57423	 0.017072	 0.074325	 0.02118	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52420	 93875	 0.057426	 0.1565	 0.03452	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52421	 52422	 0.011	 0.044764	 0.01091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93410	 52421	 0.00257	 0.041791	 0.01185	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52422	 93876	 0.017209	 0.068914	 0.01737	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52423	 93411	 0.023276	 0.045617	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52424	 52428	 0.003032	 0.030085	 0.00818	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52424	 52458	 0.004571	 0.046579	 0.01201	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52424	 93411	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52424	 93411	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52425	 93412	 0.093404	 0.23758	 0.00376	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52426	 52771	 0.050319	 0.22174	 0.00385	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52426	 93412	 0.021641	 0.10442	 0.00184	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52427	 52428	 0.003729	 0.029962	 0.00842	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52427	 52769	 0.005291	 0.036713	 0.01048	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52427	 52770	 0.009772	 0.065568	 0.01583	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52427	 93412	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52427	 93412	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52428	 93413	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52428	 93413	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52429	 52431	 0.021096	 0.055761	 0.01305	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52430	 93414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52430	 93414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52431	 93415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52431	 93415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52432	 52434	 0.010423	 0.041731	 0.01051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52432	 93416	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52432	 93416	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52433	 52435	 0.010162	 0.041357	 0.01008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93314	 52433	 0.016988	 0.083953	 0.02453	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52433	 93417	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52433	 93417	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52434	 52435	 0.010609	 0.031277	 0.00728	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52434	 55486	 0.009566	 0.036362	 0.01018	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93291	 52435	 0.009769	 0.050645	 0.01237	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52436	 52437	 0.001534	 0.006243	 0.00152	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92533	 52436	 0.005401	 0.025188	 0.00624	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52437	 52438	 0.004567	 0.018285	 0.00461	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52437	 52835	 0.008386	 0.044416	 0.01126	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52438	 93418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52438	 93418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52439	 52451	 0.001363	 0.014149	 0.22013	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52439	 52830	 0.000336	 0.00426	 0.07438	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52439	 93419	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52439	 93419	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52440	 93420	 0.057632	 0.10399	 0.0015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52441	 93420	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52441	 93420	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52442	 52443	 0.007323	 0.034156	 0.00846	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93418	 52444	 0.060892	 0.15487	 0.00245	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52445	 52447	 0.041305	 0.09142	 0.0015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93307	 52446	 0.009838	 0.034426	 0.01141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93374	 52446	 0.012631	 0.050573	 0.01274	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93375	 52447	 0.054555	 0.16738	 0.00453	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52448	 52450	 0.001262	 0.006454	 0.00176	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52448	 52459	 0.001662	 0.018702	 0.00491	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52448	 93423	 0.001573	 0.012393	 0.00362	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52449	 93421	 0.03336	 0.024544	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52450	 52453	 0.001197	 0.007129	 0.00188	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52450	 93421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52450	 93421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52451	 93422	 9.6e-05	 0.007692	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52451	 93422	 9.6e-05	 0.007692	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93423	 52451	 0.000119	 0.009548	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52452	 52456	 0.000131	 0.00171	 0.01548	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52452	 53074	 0.000552	 0.007483	 0.11403	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52452	 93424	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93425	 52452	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52453	 52455	 0.001828	 0.006371	 0.00148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93423	 52453	 0.000914	 0.004508	 0.00122	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52453	 93426	 0.001987	 0.006816	 0.00163	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52454	 52456	 9.3e-05	 0.001219	 0.01103	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52454	 93426	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52454	 93426	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92522	 52455	 0.001689	 0.009891	 0.00269	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52456	 93427	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52456	 93427	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93421	 52457	 0.054536	 0.039424	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93425	 52458	 0.003523	 0.029262	 0.01145	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52459	 52463	 0.004335	 0.039365	 0.01283	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92522	 52461	 0.004091	 0.025418	 0.00717	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52461	 93428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52461	 93428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52462	 93429	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52462	 93429	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52463	 52723	 0.003102	 0.026092	 0.00773	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92523	 52464	 0.003287	 0.011901	 0.00255	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52464	 93430	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52464	 93430	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52465	 52466	 0.018697	 0.048062	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52465	 52467	 0.023026	 0.058559	 0.00093	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93430	 52465	 0.04539	 0.22964	 0.004	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52468	 52469	 0.005848	 0.029382	 0.00765	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52469	 52471	 0.010032	 0.046025	 0.01179	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52470	 53087	 0.091669	 0.1138	 0.00248	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52470	 93555	 0.14578	 0.24562	 0.0035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52471	 52839	 0.010762	 0.054977	 0.01383	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52471	 93431	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52471	 93431	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52472	 52474	 0.004229	 0.01693	 0.00427	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52473	 93432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52473	 93432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52474	 52840	 0.009474	 0.051993	 0.01374	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52474	 93433	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52474	 93433	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52475	 52726	 0.004459	 0.026115	 0.00711	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52475	 93434	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52475	 93434	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52476	 52478	 0.000959	 0.002828	 0.00066	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52476	 52482	 0.001472	 0.00443	 0.00139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52476	 52546	 0.00242	 0.007349	 0.00161	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52476	 52549	 0.002476	 0.006427	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52476	 93435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52476	 93435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52477	 52485	 0.001041	 0.004091	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52477	 93436	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52477	 93436	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52478	 52482	 0.00091	 0.002405	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52479	 52503	 0.00923	 0.023726	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52479	 52527	 0.006645	 0.015424	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52480	 52490	 0.007778	 0.015399	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52481	 52487	 0.011753	 0.008496	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52482	 52508	 0.004223	 0.011159	 0.00261	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52482	 93437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52482	 93437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52483	 93438	 0.008285	 0.009024	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52484	 52496	 0.008617	 0.009477	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52485	 52494	 0.000807	 0.002249	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52485	 93438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52485	 93438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52485	 93446	 0.002033	 0.009623	 0.00231	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52486	 52493	 0.002053	 0.007988	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93437	 52486	 0.001612	 0.006175	 0.00017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52487	 52491	 0.006991	 0.013842	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93437	 52487	 0.004048	 0.011611	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52488	 52503	 0.006051	 0.009072	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52489	 52502	 0.016297	 0.012897	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52490	 52491	 0.007207	 0.0093	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52490	 52502	 0.006262	 0.012398	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52490	 93439	 0.009467	 0.031582	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52491	 52492	 0.007258	 0.007331	 0.0001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52492	 52493	 0.005509	 0.005625	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52493	 52500	 0.007251	 0.012093	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52494	 52499	 0.000804	 0.002126	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52495	 52498	 0.00488	 0.007999	 0.00014	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52496	 52497	 0.005819	 0.008914	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52496	 52498	 0.007231	 0.014797	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52498	 93440	 0.005758	 0.019207	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52499	 52507	 0.000756	 0.001999	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52500	 52510	 0.01152	 0.015141	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52501	 52505	 0.012282	 0.009627	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52502	 52505	 0.004077	 0.008072	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52502	 93439	 0.004052	 0.019551	 0.00035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52503	 93439	 0.002677	 0.010939	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52504	 52514	 0.002828	 0.009701	 0.00232	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52504	 93439	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52504	 93439	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52504	 93483	 0.001232	 0.009231	 0.00225	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52505	 52513	 0.007977	 0.013303	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52506	 52510	 0.00406	 0.008039	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52507	 52508	 0.000804	 0.002407	 0.00054	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52508	 52578	 0.004464	 0.017544	 0.00459	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52508	 93440	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52508	 93440	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52508	 93442	 0.000526	 0.004127	 0.00189	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93440	 52509	 0.009523	 0.010372	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52510	 52512	 0.002874	 0.008156	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52510	 52714	 0.00452	 0.005832	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52510	 93441	 0.011467	 0.029476	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52511	 52512	 0.002675	 0.007673	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52511	 93443	 0.0045	 0.013546	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52513	 52714	 0.015328	 0.015481	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52513	 93441	 0.007637	 0.019631	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52514	 93441	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52514	 93441	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52514	 93442	 0.002822	 0.008175	 0.00197	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52514	 93448	 0.000692	 0.003841	 0.00117	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52515	 52522	 0.007023	 0.013905	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52516	 52529	 0.000179	 0.001967	 0.0191	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52516	 52577	 0.000409	 0.004717	 0.04135	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52516	 52640	 0.000712	 0.009194	 0.15435	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52516	 93442	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52517	 52531	 0.005228	 0.012381	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52517	 93444	 0.004021	 0.011533	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93442	 52518	 0.001165	 0.004662	 0.00117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52518	 93444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52518	 93444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52519	 52520	 0.005626	 0.009478	 0.00014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52519	 52597	 0.004966	 0.011265	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93443	 52519	 0.004543	 0.017476	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52520	 52521	 0.004334	 0.010063	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52520	 52525	 0.005116	 0.009512	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52521	 52522	 0.005558	 0.009363	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93441	 52522	 0.003224	 0.011519	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52523	 52530	 0.006465	 0.015826	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52523	 93445	 0.005452	 0.011458	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52523	 93449	 0.00425	 0.02074	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52524	 52606	 0.003397	 0.009742	 0.0024	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52524	 93445	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52524	 93445	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52524	 93448	 0.001282	 0.00751	 0.00205	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93445	 52525	 0.004007	 0.009301	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52526	 52672	 0.001294	 0.009381	 0.01889	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52526	 93446	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93447	 52526	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52526	 93482	 0.001245	 0.008306	 0.01565	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52527	 52528	 0.011623	 0.009198	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52529	 52625	 0.000106	 0.00173	 0.027	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52529	 93448	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52530	 52603	 0.007173	 0.016653	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52531	 52595	 0.012937	 0.01321	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52532	 52581	 0.014308	 0.022325	 0.00037	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52532	 93450	 0.007368	 0.016714	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52533	 52552	 0.007037	 0.01769	 0.00458	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93442	 52533	 0.001181	 0.004726	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52533	 93450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52533	 93450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93440	 52534	 0.006651	 0.013035	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52535	 52537	 0.005408	 0.009719	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52535	 52553	 0.006621	 0.013109	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93436	 52535	 0.013636	 0.035052	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52535	 93461	 0.01148	 0.016729	 0.00038	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93436	 52536	 0.007303	 0.017876	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52536	 93457	 0.007961	 0.015046	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52537	 52538	 0.00439	 0.008693	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52537	 52572	 0.008303	 0.013987	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52538	 52539	 0.011941	 0.013007	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52539	 52582	 0.012849	 0.025441	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52540	 52630	 0.022601	 0.044294	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93447	 52541	 0.013936	 0.035825	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52542	 52660	 0.001443	 0.008451	 0.0023	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93446	 52542	 0.001556	 0.005499	 0.00124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52542	 93451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52542	 93451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52543	 52545	 0.00129	 0.003408	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52543	 52546	 0.002174	 0.005644	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52543	 93452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52543	 93452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52544	 52665	 0.000583	 0.003198	 0.00085	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52544	 93453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52544	 93453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52544	 93497	 0.001106	 0.010062	 0.00254	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52545	 52546	 0.001452	 0.004845	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52545	 52665	 0.000631	 0.003879	 0.00112	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52546	 52549	 0.001937	 0.0058	 0.00131	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52547	 52548	 0.001263	 0.004403	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52547	 52558	 0.000633	 0.003179	 0.00083	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52547	 93454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52547	 93454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52548	 52675	 0.000914	 0.004437	 0.00101	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52548	 93455	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52548	 93455	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52549	 93456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52549	 93456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93436	 52550	 0.008555	 0.015669	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93435	 52551	 0.0128	 0.010535	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52552	 52554	 0.001076	 0.00293	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52552	 93457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52552	 93457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93457	 52553	 0.00408	 0.015873	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52554	 52559	 0.000799	 0.002111	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52555	 52556	 0.002987	 0.008566	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52555	 93459	 0.002979	 0.015068	 0.00026	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52556	 52562	 0.025447	 0.018026	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52556	 52563	 0.013501	 0.012181	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52557	 52558	 0.000691	 0.002513	 0.00077	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52557	 52559	 0.00114	 0.003912	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52557	 93458	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52557	 93458	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52559	 93459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52559	 93459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52560	 93460	 0.008758	 0.016041	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52560	 93461	 0.03319	 0.026266	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52561	 52565	 0.007017	 0.020634	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52561	 93462	 0.00325	 0.017316	 0.0003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52562	 93460	 0.010939	 0.016591	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52563	 93461	 0.01372	 0.018031	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52564	 52569	 0.002754	 0.009446	 0.00226	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52564	 52683	 0.001095	 0.004386	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52564	 93460	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52564	 93460	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52565	 52687	 0.014341	 0.024159	 0.00034	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93460	 52565	 0.020277	 0.022498	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52565	 93466	 0.11379	 0.090056	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52566	 52567	 0.005116	 0.008617	 0.00012	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52566	 52568	 0.014334	 0.014477	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52567	 93461	 0.006886	 0.01211	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52568	 52570	 0.014824	 0.010716	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52569	 52573	 0.00106	 0.004244	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52569	 93461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52569	 93461	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52570	 93466	 0.010291	 0.029516	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52571	 52575	 0.000646	 0.003605	 0.00092	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52571	 93462	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52571	 93462	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52571	 93465	 0.001799	 0.00749	 0.00234	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52572	 93463	 0.003223	 0.007888	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52573	 52579	 0.001277	 0.005112	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52573	 93463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52573	 93463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52574	 93464	 0.01174	 0.009291	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52575	 52576	 0.00039	 0.002743	 0.00156	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52575	 52579	 0.000687	 0.004025	 0.0011	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52575	 93464	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52575	 93464	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92558	 52576	 0.000503	 0.003942	 0.0018	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52577	 93465	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52577	 93465	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52578	 52696	 0.002102	 0.009367	 0.00255	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93465	 52578	 0.000735	 0.007677	 0.00211	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52578	 93466	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52578	 93466	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52579	 93467	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52579	 93467	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52580	 52582	 0.03196	 0.042005	 0.00058	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93467	 52580	 0.006427	 0.016522	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93443	 52581	 0.019664	 0.050549	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52581	 93468	 0.008089	 0.018583	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93450	 52582	 0.004295	 0.021855	 0.0005	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52583	 52585	 0.003232	 0.008542	 0.002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52584	 93468	 0.002363	 0.005485	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52584	 93471	 0.002607	 0.006051	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52585	 52592	 0.001378	 0.004062	 0.00094	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52585	 93468	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52585	 93468	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52586	 93469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52586	 93469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52587	 52588	 0.01337	 0.026472	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93332	 52587	 0.0079	 0.01834	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52588	 52601	 0.013339	 0.014671	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52588	 52603	 0.020874	 0.016519	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93445	 52588	 0.00868	 0.022945	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52589	 52590	 0.005637	 0.007685	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93469	 52590	 0.007613	 0.012212	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52590	 93470	 0.004959	 0.010587	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52591	 52592	 0.001222	 0.004427	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52591	 93470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52591	 93470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52592	 52594	 0.001009	 0.00404	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52593	 52599	 0.01605	 0.01321	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93442	 52594	 0.001908	 0.011178	 0.00304	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52594	 93471	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52594	 93471	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52595	 52596	 0.01169	 0.009251	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93471	 52595	 0.004354	 0.006949	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52596	 52598	 0.011678	 0.009241	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52597	 52598	 0.0069	 0.012401	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52598	 52599	 0.003224	 0.011517	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52598	 52602	 0.008988	 0.009078	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93445	 52598	 0.006155	 0.021536	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52599	 52600	 0.00371	 0.006899	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93469	 52600	 0.005555	 0.010329	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52604	 52607	 0.002817	 0.007313	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52604	 93472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52604	 93472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52604	 93474	 0.002719	 0.010685	 0.0028	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52605	 52629	 0.006454	 0.014638	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93449	 52605	 0.007393	 0.017164	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52606	 52607	 0.001853	 0.007284	 0.00191	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93448	 52606	 0.002523	 0.008228	 0.00218	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52607	 93474	 0.000367	 0.003812	 0.00118	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52608	 93473	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52608	 93473	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52608	 93474	 0.006534	 0.017269	 0.00404	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52608	 93477	 0.00245	 0.008539	 0.00198	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52609	 52626	 0.000649	 0.002748	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52609	 93474	 0.001485	 0.005775	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93407	 52610	 0.004074	 0.034912	 0.06646	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52610	 93474	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93475	 52610	 0.000321	 0.02569	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52610	 93476	 0.000308	 0.002823	 0.01114	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52611	 52625	 0.000174	 0.002741	 0.02857	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52611	 93476	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93477	 52611	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52612	 52613	 0.017707	 0.013879	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52612	 52618	 0.016544	 0.012172	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52613	 93478	 0.004275	 0.006823	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52614	 52620	 0.002039	 0.005242	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52614	 52621	 0.001382	 0.003653	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93477	 52614	 0.00166	 0.006647	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52614	 93478	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52614	 93478	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93478	 52615	 0.017728	 0.013896	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52616	 52703	 0.02684	 0.027109	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93478	 52616	 0.016799	 0.024478	 0.00055	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52617	 52706	 0.003912	 0.01342	 0.00321	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52617	 93479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52617	 93479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52618	 93480	 0.004348	 0.008217	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52619	 52621	 0.001635	 0.00394	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52619	 93480	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52619	 93480	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52619	 93483	 0.002281	 0.006029	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52620	 52634	 0.001248	 0.003241	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52622	 52628	 0.006144	 0.011043	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52623	 52627	 0.000751	 0.00318	 0.00072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52623	 93481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52623	 93481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52623	 93483	 0.001682	 0.007718	 0.00198	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52624	 52629	 0.00177	 0.008204	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52624	 93484	 0.003585	 0.020378	 0.00037	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52625	 93482	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52626	 52627	 0.00051	 0.00204	 0.00051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52628	 52629	 0.003178	 0.008169	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93481	 52629	 0.002723	 0.015301	 0.00028	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93484	 52630	 0.007806	 0.018484	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52631	 52638	 0.001971	 0.00553	 0.00142	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93483	 52631	 0.00243	 0.008504	 0.00282	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52632	 52639	 0.046745	 0.058737	 0.00088	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52632	 52708	 0.017929	 0.045415	 0.0009	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93484	 52632	 0.042062	 0.080553	 0.00127	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52633	 52634	 0.001601	 0.004157	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93483	 52633	 0.001514	 0.004557	 0.00143	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52634	 93485	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52634	 93485	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52635	 52636	 0.023317	 0.015095	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93485	 52635	 0.018026	 0.018206	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93479	 52636	 0.009784	 0.019371	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52637	 52638	 0.001603	 0.004121	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52637	 52706	 0.002511	 0.008375	 0.00212	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52639	 52643	 0.015043	 0.050182	 0.0008	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52640	 93486	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52640	 93486	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52641	 52645	 0.000382	 0.004104	 0.00107	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93486	 52641	 0.00068	 0.007368	 0.0023	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52642	 52644	 0.000314	 0.002096	 0.00395	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92563	 52642	 0.00292	 0.025298	 0.04707	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52642	 93487	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52642	 93487	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52643	 93492	 0.006295	 0.032033	 0.00073	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52644	 52671	 0.000434	 0.004717	 0.01025	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52644	 93488	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52644	 93488	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93488	 52645	 0.000454	 0.003818	 0.00113	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52646	 52650	 0.00087	 0.002984	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52646	 93489	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52646	 93489	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52646	 93495	 0.002971	 0.007852	 0.00184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52647	 52650	 0.001296	 0.004226	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52647	 52658	 0.001097	 0.00439	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52648	 52655	 0.013625	 0.014985	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52649	 52658	 0.000702	 0.008029	 0.00245	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93486	 52649	 0.000475	 0.005	 0.00281	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52649	 93490	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52649	 93490	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93489	 52651	 0.010554	 0.020895	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52652	 52659	 0.01231	 0.031904	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93490	 52652	 0.007028	 0.039548	 0.00085	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52653	 52657	 0.001616	 0.006472	 0.00163	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52653	 52658	 0.002367	 0.008248	 0.00191	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52653	 93495	 0.002723	 0.008029	 0.00187	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52654	 52655	 0.01376	 0.017511	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52655	 93496	 0.007076	 0.018189	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52656	 52657	 0.000452	 0.003878	 0.0011	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52656	 52670	 0.000506	 0.0042	 0.0011	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52656	 93491	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52656	 93491	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52657	 52681	 0.001797	 0.016912	 0.00512	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52659	 93496	 0.030965	 0.057576	 0.00135	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52660	 52661	 0.001015	 0.007647	 0.00212	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52661	 52662	 0.000566	 0.005816	 0.00184	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93487	 52662	 0.000966	 0.008425	 0.00231	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93488	 52662	 0.001773	 0.009765	 0.00353	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52662	 93492	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52662	 93492	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93492	 52663	 0.009286	 0.018385	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52664	 52667	 0.000643	 0.003568	 0.00108	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52664	 52675	 0.00137	 0.004615	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52664	 93493	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52664	 93493	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52665	 93494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52665	 93494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52666	 52668	 0.003652	 0.016275	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93494	 52666	 0.005418	 0.013928	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52667	 52669	 0.000403	 0.004604	 0.0014	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52667	 52686	 0.000745	 0.00332	 0.0009	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52668	 93498	 0.005295	 0.026784	 0.00047	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52669	 52670	 0.000531	 0.004068	 0.00109	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52669	 93497	 0.001838	 0.007224	 0.00189	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52671	 52672	 0.000207	 0.002069	 0.00428	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52671	 93495	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93496	 52671	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52672	 93497	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93498	 52672	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52673	 52674	 0.011629	 0.009115	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52673	 52677	 0.013658	 0.012239	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52673	 93499	 0.028723	 0.022514	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52675	 93499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52675	 93499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52676	 52685	 0.001106	 0.004499	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52676	 52692	 0.001192	 0.004771	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93493	 52677	 0.006232	 0.016019	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93454	 52678	 0.026617	 0.020166	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93455	 52678	 0.011261	 0.014655	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93458	 52679	 0.016268	 0.029057	 0.00043	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52679	 93501	 0.030202	 0.021394	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52680	 52692	 0.000527	 0.005415	 0.00205	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52682	 52683	 0.000944	 0.003994	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52682	 52694	 0.000773	 0.003817	 0.00111	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52682	 93500	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52682	 93500	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52683	 93501	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52683	 93501	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52684	 52687	 0.005035	 0.015463	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93500	 52684	 0.008547	 0.016922	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93501	 52684	 0.030066	 0.022779	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52684	 93502	 0.008617	 0.019796	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52684	 93503	 0.006837	 0.03338	 0.0007	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52685	 52686	 0.001121	 0.004487	 0.00113	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52688	 93502	 0.01579	 0.020752	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52688	 93504	 0.005971	 0.016945	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52689	 93504	 0.008505	 0.021629	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52690	 52691	 0.000655	 0.002575	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52691	 52695	 0.002005	 0.008028	 0.00202	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52691	 93502	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52691	 93502	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52692	 52694	 0.000768	 0.003794	 0.00111	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52692	 52695	 0.001438	 0.005653	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52692	 93503	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52692	 93503	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93503	 52693	 0.023338	 0.018469	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52695	 93504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52695	 93504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52696	 52697	 0.001776	 0.007517	 0.00169	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52696	 52698	 0.003085	 0.012555	 0.00306	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93442	 52697	 0.005137	 0.017903	 0.00415	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93473	 52699	 0.034887	 0.02522	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52700	 52701	 0.019259	 0.045604	 0.00083	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52700	 93506	 0.016047	 0.04125	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52702	 52703	 0.006364	 0.01507	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52702	 93505	 0.007252	 0.03195	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52704	 52705	 0.003645	 0.012505	 0.003	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52704	 52712	 0.002855	 0.008593	 0.00269	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52706	 52707	 0.001185	 0.011374	 0.00331	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52706	 93505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52706	 93505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92564	 52707	 0.001404	 0.019859	 0.00658	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52707	 93506	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52707	 93506	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52708	 52709	 0.012984	 0.043314	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93506	 52709	 0.008789	 0.047378	 0.00095	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52710	 93508	 0.075347	 0.12284	 0.00187	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52711	 52713	 0.000174	 0.002763	 0.04536	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52711	 52716	 0.000203	 0.0028	 0.0474	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52711	 93507	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52711	 93507	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92564	 52712	 0.002102	 0.008259	 0.00216	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52713	 52801	 0.000709	 0.007777	 0.07555	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52713	 93508	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52713	 93508	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92527	 52715	 0.003506	 0.031892	 0.00805	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93486	 52715	 0.007133	 0.020659	 0.00498	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93488	 52715	 0.00294	 0.018074	 0.00521	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52717	 52718	 0.0011	 0.009254	 0.00274	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52717	 52723	 0.00393	 0.031903	 0.01016	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52718	 52719	 0.002208	 0.010432	 0.00334	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52718	 52721	 0.002914	 0.012031	 0.00285	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52719	 52722	 0.009029	 0.051332	 0.01486	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52719	 52725	 0.002614	 0.025103	 0.01169	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93425	 52719	 0.010516	 0.1324	 0.04107	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52719	 93509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52719	 93509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52720	 52724	 0.066954	 0.12823	 0.00202	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93509	 52720	 0.015717	 0.03565	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52721	 93510	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52721	 93510	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52722	 53025	 0.003786	 0.033037	 0.00907	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52725	 52726	 0.002515	 0.020921	 0.00634	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52725	 52840	 0.01882	 0.11029	 0.03007	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52727	 52734	 0.010701	 0.054458	 0.01975	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52727	 52747	 0.00813	 0.038409	 0.01229	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52728	 52730	 0.005103	 0.054089	 0.01606	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52728	 52750	 0.012216	 0.10829	 0.02885	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52728	 93511	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52728	 93511	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92560	 52729	 0.086515	 0.22005	 0.00348	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52730	 52734	 0.022209	 0.088948	 0.02242	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52730	 53077	 0.012856	 0.054419	 0.01225	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92961	 52730	 0.008027	 0.10941	 0.03915	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52731	 93631	 0.032313	 0.058079	 0.00104	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52732	 52886	 0.000884	 0.004519	 0.00123	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52732	 52901	 0.001525	 0.006105	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52732	 93512	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52732	 93512	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52733	 93642	 0.020351	 0.11435	 0.00212	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52734	 93658	 0.009471	 0.051974	 0.01374	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52735	 93513	 0.063347	 0.10672	 0.00152	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52736	 52931	 0.00405	 0.014735	 0.00451	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52736	 53046	 0.007379	 0.030466	 0.00721	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52736	 93513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52736	 93513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93511	 52737	 0.16694	 0.33064	 0.00485	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52738	 52741	 0.006373	 0.028693	 0.00764	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92453	 52738	 0.002314	 0.037638	 0.01068	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52738	 93514	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52738	 93514	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52739	 52740	 0.029392	 0.045026	 0.00063	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93514	 52739	 0.023939	 0.073438	 0.00199	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93352	 52740	 0.11156	 0.22931	 0.00437	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52740	 93515	 0.014933	 0.032	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52741	 52742	 0.000875	 0.002949	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52741	 93515	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52741	 93515	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52742	 52744	 0.003609	 0.012379	 0.00297	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52742	 93516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52742	 93516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93514	 52743	 0.013018	 0.070176	 0.00141	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93516	 52743	 0.061827	 0.048929	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52743	 93517	 0.047289	 0.075484	 0.00174	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52744	 52745	 0.009616	 0.033512	 0.00777	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52744	 93517	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52744	 93517	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52745	 93518	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52745	 93518	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93514	 52746	 0.067335	 0.22224	 0.0036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52747	 52749	 0.004552	 0.025091	 0.00586	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52749	 52750	 0.015579	 0.045933	 0.01069	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52749	 93519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52749	 93519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52750	 52751	 0.003863	 0.035139	 0.00887	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52751	 52765	 0.014077	 0.063391	 0.01687	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92523	 52751	 0.026473	 0.06998	 0.01638	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52752	 52756	 0.000115	 0.001863	 0.02908	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52752	 93520	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52753	 52757	 0.00044	 0.003184	 0.00171	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93520	 52753	 0.000557	 0.008401	 0.00251	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52753	 93522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52753	 93522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52755	 93524	 0.009208	 0.014106	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52756	 52761	 9.1e-05	 0.001267	 0.02119	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52756	 93523	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93523	 52757	 0.00025	 0.003613	 0.00115	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52757	 93525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52757	 93525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93525	 52758	 0.011035	 0.024758	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52759	 52760	 0.01711	 0.022487	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93524	 52760	 0.007422	 0.019079	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52761	 52762	 0.000185	 0.002447	 0.03919	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93521	 52763	 0.041476	 0.10662	 0.00165	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52764	 52768	 0.0074	 0.029083	 0.00761	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93523	 52764	 0.007866	 0.039523	 0.01029	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52765	 52766	 0.003188	 0.027338	 0.00778	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52766	 52767	 0.00173	 0.016904	 0.00474	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52766	 93526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52766	 93526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93402	 52767	 0.008658	 0.040383	 0.01	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52769	 52770	 0.003869	 0.025954	 0.00627	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52770	 52773	 0.007564	 0.051927	 0.01515	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52770	 93527	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52770	 93527	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52771	 93529	 0.044717	 0.17397	 0.0029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52772	 93528	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52772	 93528	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52772	 93531	 0.005665	 0.048256	 0.01204	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52773	 52774	 0.001546	 0.010613	 0.0031	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52774	 52777	 0.001825	 0.014572	 0.00359	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52774	 93529	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52774	 93529	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52775	 52776	 0.005385	 0.030611	 0.00055	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93529	 52775	 0.005195	 0.02302	 0.00069	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52776	 93530	 0.006393	 0.035973	 0.00078	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52777	 93530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52777	 93530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52777	 93531	 0.003971	 0.028085	 0.00771	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93530	 52778	 0.010748	 0.02763	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52779	 52948	 0.003104	 0.039483	 0.69415	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52779	 93531	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52779	 93531	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92529	 52780	 0.074779	 0.2672	 0.00531	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93399	 52780	 0.061775	 0.31258	 0.00544	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92529	 52781	 0.028853	 0.057127	 0.00084	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52782	 52784	 0.006547	 0.027708	 0.00623	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52782	 52847	 0.016407	 0.051291	 0.01486	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92528	 52782	 0.019773	 0.13998	 0.03846	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52783	 52791	 0.19815	 0.21798	 0.00291	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52784	 93532	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52784	 93532	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52785	 52788	 0.004939	 0.016476	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52785	 52789	 0.010017	 0.023719	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93532	 52785	 0.005066	 0.030789	 0.00057	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52786	 52789	 0.010726	 0.019944	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92566	 52787	 0.016136	 0.057041	 0.01285	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52787	 93533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52787	 93533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52787	 93534	 0.013659	 0.037189	 0.00819	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93533	 52788	 0.002897	 0.011144	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92565	 52790	 0.002554	 0.018651	 0.03699	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93313	 52790	 0.009734	 0.065006	 0.12276	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93373	 52790	 0.004676	 0.032797	 0.05586	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52790	 93534	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52790	 93534	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52792	 52805	 0.006633	 0.037561	 0.00931	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52792	 93535	 0.001331	 0.01049	 0.00307	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52793	 52794	 0.00461	 0.016468	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52793	 52794	 0.00461	 0.016468	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52793	 93536	 0.005435	 0.020388	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52793	 93536	 0.005435	 0.020388	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52794	 93541	 0.013367	 0.049422	 0.00092	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52794	 93541	 0.013367	 0.049422	 0.00092	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52795	 93536	 0.008781	 0.017385	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52796	 52801	 0.000282	 0.004517	 0.04521	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52796	 52804	 0.00025	 0.002937	 0.0513	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52796	 93535	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52796	 93535	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52797	 52799	 0.002296	 0.00677	 0.00158	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93535	 52797	 0.00128	 0.005123	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52797	 93536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52797	 93536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93536	 52798	 0.009832	 0.019268	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52799	 52800	 0.007572	 0.026391	 0.00612	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92566	 52800	 0.023476	 0.12008	 0.03276	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93535	 52800	 0.012976	 0.03722	 0.00916	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52800	 93537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52800	 93537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52801	 93538	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52802	 52803	 0.047107	 0.09327	 0.00137	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93540	 52803	 0.043627	 0.11215	 0.00174	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52804	 52806	 0.00053	 0.0064	 0.10614	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52804	 93541	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52804	 93541	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92566	 52805	 0.013239	 0.082289	 0.02323	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52805	 93542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52805	 93542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92566	 52807	 0.01923	 0.069645	 0.01495	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93534	 52807	 0.026943	 0.072348	 0.0164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52807	 93543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52807	 93543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52808	 52810	 0.010055	 0.065756	 0.01672	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93277	 52809	 0.018205	 0.086186	 0.02073	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52809	 93544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52809	 93544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92544	 52811	 0.060955	 0.28672	 0.00534	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52812	 52814	 0.001756	 0.005859	 0.00149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92524	 52812	 0.012842	 0.044055	 0.01056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52812	 93552	 0.002208	 0.008589	 0.00229	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52813	 52814	 0.001165	 0.003926	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52813	 52817	 0.001758	 0.00603	 0.00144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92524	 52813	 0.010199	 0.034989	 0.00838	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52813	 93545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52813	 93545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93545	 52815	 0.017822	 0.034927	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52816	 52818	 0.003832	 0.010287	 0.00233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52816	 52835	 0.003571	 0.016902	 0.00406	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52816	 93546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52816	 93546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52817	 52818	 0.000987	 0.003441	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52818	 52835	 0.006134	 0.021042	 0.00504	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52819	 52837	 0.010699	 0.044176	 0.01045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92524	 52819	 0.006798	 0.027665	 0.00674	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52819	 93547	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52819	 93547	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52820	 52821	 0.030928	 0.065003	 0.00118	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93547	 52820	 0.032498	 0.093211	 0.00143	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93546	 52821	 0.024193	 0.06219	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93545	 52822	 0.023739	 0.039991	 0.00057	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52823	 52832	 0.000455	 0.004993	 0.0485	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52823	 52838	 0.000177	 0.002817	 0.02876	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52823	 93548	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52823	 93548	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52824	 52936	 0.000894	 0.009471	 0.00281	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52824	 52937	 0.001477	 0.010624	 0.00282	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93548	 52824	 0.000992	 0.010436	 0.00586	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93548	 52825	 0.004311	 0.016942	 0.00443	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52825	 93553	 0.004517	 0.018382	 0.00448	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52826	 93550	 0.011795	 0.059664	 0.00104	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52826	 93595	 0.011159	 0.037226	 0.00059	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52827	 52828	 8.1e-05	 0.001473	 0.02282	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52827	 52939	 0.000111	 0.00201	 0.02009	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52827	 93549	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52827	 93549	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52828	 52833	 0.000102	 0.001288	 0.02249	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52828	 93550	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52828	 93550	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52829	 53059	 0.023467	 0.072068	 0.00135	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52829	 93554	 0.011861	 0.05788	 0.001	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52830	 52834	 0.00033	 0.00408	 0.06467	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52830	 93551	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52830	 93551	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93551	 52831	 0.043669	 0.078794	 0.00114	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52832	 52833	 0.000159	 0.002009	 0.03509	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52832	 52834	 0.00012	 0.001438	 0.02415	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52832	 93552	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52832	 93552	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52833	 93553	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52836	 52837	 0.00122	 0.005038	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92524	 52839	 0.004516	 0.026449	 0.0072	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52839	 93555	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52839	 93555	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52840	 52841	 0.00744	 0.034135	 0.00874	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52840	 52845	 0.006334	 0.047464	 0.01158	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52841	 52843	 0.004311	 0.026787	 0.00756	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52841	 93556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52841	 93556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52842	 93557	 0.017355	 0.034014	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52843	 52844	 0.001986	 0.011631	 0.00317	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52844	 52846	 0.007463	 0.02988	 0.00753	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52844	 93557	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52844	 93557	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52845	 93558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52845	 93558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52846	 52847	 0.007776	 0.042869	 0.01002	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52846	 93559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52846	 93559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92566	 52847	 0.000752	 0.006405	 0.0016	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92566	 52848	 0.004285	 0.04186	 0.01175	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52849	 93563	 0.057921	 0.11468	 0.00168	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52850	 52851	 0.01183	 0.039862	 0.00991	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52850	 52857	 0.00691	 0.024425	 0.0055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52850	 93560	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52850	 93560	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52852	 52853	 0.010499	 0.026989	 0.00668	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52852	 93561	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52852	 93561	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52853	 52854	 0.014705	 0.037803	 0.00936	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52853	 52855	 0.018499	 0.048893	 0.01145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52853	 93562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52853	 93562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52854	 52855	 0.003873	 0.010398	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52855	 93563	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52855	 93563	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92562	 52856	 0.043737	 0.080109	 0.00138	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52858	 52863	 0.003142	 0.015522	 0.00453	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52858	 52864	 0.002469	 0.018237	 0.00526	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52858	 93564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52858	 93564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52859	 93565	 0.017364	 0.04416	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52860	 52862	 0.015459	 0.030607	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52861	 93565	 0.018564	 0.029632	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52862	 93565	 0.021076	 0.054178	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52863	 52867	 0.018878	 0.061584	 0.01635	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52863	 93565	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52863	 93565	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93564	 52865	 0.054968	 0.13017	 0.00238	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93565	 52866	 0.06065	 0.23598	 0.00394	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93565	 52868	 0.080188	 0.15717	 0.00236	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52870	 52871	 0.024471	 0.070188	 0.00108	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52870	 93566	 0.027292	 0.078278	 0.0012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52871	 57507	 0.12806	 0.5712	 0.00971	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52871	 93566	 0.002375	 0.011025	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52872	 93566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52872	 93566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52873	 93567	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52873	 93567	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52874	 52877	 0.005076	 0.027852	 0.00736	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52875	 52876	 0.011588	 0.038659	 0.00981	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52876	 52877	 0.004445	 0.015491	 0.00359	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52877	 52878	 0.020221	 0.067469	 0.01712	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92595	 52877	 0.013274	 0.084098	 0.02283	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52878	 58423	 0.028918	 0.076445	 0.0179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52879	 52893	 0.001603	 0.006416	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52879	 93568	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52879	 93568	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52879	 93644	 0.000515	 0.005157	 0.00172	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52880	 52882	 0.000545	 0.003852	 0.00106	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52880	 52933	 0.002253	 0.009022	 0.00227	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52880	 53029	 0.001337	 0.005352	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52880	 93644	 0.002381	 0.010922	 0.0028	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93568	 52881	 0.005475	 0.016099	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52881	 93569	 0.023216	 0.017081	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52882	 52883	 0.000566	 0.00426	 0.00118	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52882	 93569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52882	 93569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52883	 52884	 0.00037	 0.002567	 0.00073	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52884	 52885	 0.000386	 0.00195	 0.00054	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52884	 93570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52884	 93570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52885	 52886	 0.000354	 0.001809	 0.00049	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52887	 52889	 0.001791	 0.005364	 0.00121	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52887	 52901	 0.002132	 0.006285	 0.00146	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52887	 93571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52887	 93571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93571	 52888	 0.011389	 0.009013	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52889	 52899	 0.001104	 0.004672	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52889	 52900	 0.000563	 0.005734	 0.00148	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52889	 52941	 0.000991	 0.008338	 0.00247	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52889	 93572	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52889	 93572	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52889	 93644	 0.002625	 0.020954	 0.00516	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93572	 52890	 0.013854	 0.013993	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52890	 93573	 0.003832	 0.012785	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52891	 52908	 0.001754	 0.007424	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52891	 93573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52891	 93573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52891	 93644	 0.003021	 0.015734	 0.00413	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52892	 52896	 0.005123	 0.01709	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93568	 52892	 0.006545	 0.029163	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52893	 93574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52893	 93574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52893	 93607	 0.008127	 0.022664	 0.00476	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52894	 52895	 0.00481	 0.011774	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52894	 52962	 0.010465	 0.016328	 0.00027	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93574	 52894	 0.002522	 0.012104	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52894	 93581	 0.008309	 0.014933	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52895	 52896	 0.003197	 0.008218	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52896	 52897	 0.00276	 0.012298	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52897	 93575	 0.001836	 0.006425	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52898	 52908	 0.000788	 0.002116	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52898	 52909	 0.001595	 0.004447	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52898	 93575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52898	 93575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52899	 52907	 0.000692	 0.00277	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52900	 52904	 0.000898	 0.003594	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52900	 93576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52900	 93576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52900	 93599	 0.003853	 0.014989	 0.004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52901	 93577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52901	 93577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52901	 93599	 0.002541	 0.011442	 0.00304	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52902	 53038	 0.012083	 0.015377	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52903	 53038	 0.018141	 0.022518	 0.00049	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93577	 52903	 0.004643	 0.01858	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52904	 52920	 0.000642	 0.00265	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93576	 52905	 0.014522	 0.015507	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52905	 93578	 0.00201	 0.010792	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52906	 52907	 0.000807	 0.002074	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52906	 52908	 0.00113	 0.004598	 0.00112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52906	 52916	 0.000771	 0.003086	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52906	 93578	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52906	 93578	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52907	 52916	 0.001285	 0.005304	 0.00126	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52907	 93579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52907	 93579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52908	 52909	 0.000806	 0.002093	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52908	 52915	 0.002013	 0.005405	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52908	 93580	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52908	 93580	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52909	 52915	 0.001207	 0.003366	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93580	 52910	 0.003619	 0.014133	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52910	 93581	 0.00409	 0.015737	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52911	 52928	 0.001024	 0.004101	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52911	 93581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52911	 93581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52912	 93582	 0.004096	 0.015758	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52912	 93584	 0.006404	 0.016463	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52913	 52914	 0.00102	 0.004211	 0.001	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52913	 93582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52913	 93582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52913	 93607	 0.00163	 0.008685	 0.00244	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52914	 93583	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52914	 93583	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52915	 52917	 0.001438	 0.005652	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52915	 93584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52915	 93584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52916	 52917	 0.001027	 0.004111	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52916	 52919	 0.000899	 0.003599	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52916	 93585	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52916	 93585	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52917	 52918	 0.000698	 0.002792	 0.00094	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52917	 52925	 0.000882	 0.004046	 0.00104	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52917	 52926	 0.000867	 0.005494	 0.00149	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52917	 93586	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52917	 93586	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92545	 52918	 0.000657	 0.002558	 0.00068	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92545	 52919	 0.000857	 0.003333	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92545	 52920	 0.000698	 0.004978	 0.00154	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52920	 93641	 0.001826	 0.018186	 0.00675	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52921	 52922	 0.001449	 0.003889	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52921	 93599	 0.001484	 0.005941	 0.0015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52921	 93601	 0.00234	 0.007105	 0.00156	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52922	 93601	 0.001722	 0.004471	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52923	 52945	 0.000463	 0.003156	 0.00568	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52923	 93587	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93588	 52923	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52924	 52925	 0.000818	 0.003276	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93587	 52924	 0.002016	 0.005069	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52924	 93601	 0.002716	 0.009149	 0.00227	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52925	 52951	 0.001045	 0.004254	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52925	 93589	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52925	 93589	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52926	 52927	 0.000483	 0.003803	 0.00111	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52926	 53037	 0.000998	 0.003884	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52927	 53036	 0.000397	 0.00374	 0.00113	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52927	 93590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52927	 93590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52928	 52959	 0.001026	 0.004106	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52928	 93591	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52928	 93591	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52929	 93592	 0.058307	 0.058893	 0.00078	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52930	 52931	 0.007164	 0.028684	 0.00723	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92524	 52930	 0.007248	 0.033252	 0.00852	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52930	 93592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52930	 93592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93513	 52932	 0.11522	 0.091189	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52932	 93596	 0.072277	 0.073003	 0.00097	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52933	 53029	 0.001014	 0.004058	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52933	 53047	 0.000778	 0.007993	 0.00253	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52933	 93593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52933	 93593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52934	 93594	 0.006725	 0.01646	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52935	 52936	 0.00056	 0.003958	 0.00109	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52935	 52938	 0.002927	 0.013427	 0.00344	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52935	 93594	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52935	 93594	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93549	 52936	 0.003095	 0.021894	 0.00601	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52936	 93595	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52936	 93595	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52937	 52938	 0.0025	 0.015514	 0.00376	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52938	 53046	 0.002139	 0.020532	 0.00597	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52938	 53047	 0.001245	 0.014005	 0.00368	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92524	 52938	 0.003807	 0.054966	 0.01746	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52938	 93596	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52938	 93596	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52939	 53053	 0.000156	 0.002202	 0.021	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52940	 53031	 0.023357	 0.018484	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93574	 52940	 0.00641	 0.016478	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52941	 53030	 0.000386	 0.003703	 0.00108	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52942	 93597	 0.040164	 0.029034	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52943	 93597	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52943	 93597	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52943	 93599	 0.001858	 0.012751	 0.00372	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52944	 93598	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52945	 52947	 0.000479	 0.003264	 0.00588	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52945	 93601	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52945	 93601	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52945	 93603	 0.001201	 0.008424	 0.01434	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52946	 53010	 0.000664	 0.005796	 0.00159	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92549	 52946	 0.001018	 0.006988	 0.00204	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92548	 52947	 0.001041	 0.006594	 0.01381	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52947	 93602	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52947	 93602	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52947	 93616	 0.001175	 0.015995	 0.03255	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52948	 93603	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52948	 93603	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92530	 52949	 0.000463	 0.003332	 0.00088	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92549	 52949	 0.001479	 0.005923	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52950	 52952	 0.009335	 0.009946	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52951	 52998	 0.001077	 0.004313	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52951	 52999	 0.0018	 0.005307	 0.00123	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52951	 93606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52951	 93606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93606	 52952	 0.003223	 0.007633	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52953	 53001	 0.00729	 0.016924	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93590	 52953	 0.003089	 0.015627	 0.00027	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52954	 93608	 0.003799	 0.01885	 0.00045	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52954	 93624	 0.002504	 0.013791	 0.00031	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52955	 53004	 0.004101	 0.015954	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52955	 93608	 0.004105	 0.014021	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52956	 53040	 0.000278	 0.003228	 0.0279	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52956	 53053	 0.000467	 0.005096	 0.05003	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52956	 93607	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52957	 52958	 0.013713	 0.015215	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93608	 52957	 0.006425	 0.016517	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52958	 52975	 0.010289	 0.023886	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52959	 53033	 0.002051	 0.005941	 0.00143	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52959	 53036	 0.001026	 0.003992	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93607	 52959	 0.000788	 0.00567	 0.0015	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52960	 52962	 0.00686	 0.015925	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52960	 93635	 0.008466	 0.032934	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52961	 52963	 0.011439	 0.017349	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52961	 93634	 0.023975	 0.018793	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52962	 53032	 0.004916	 0.0164	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52963	 93609	 0.006406	 0.02034	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52964	 52965	 0.006557	 0.016856	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52965	 52968	 0.00354	 0.015772	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52965	 53042	 0.007292	 0.013559	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52966	 93639	 0.01286	 0.032705	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52967	 52969	 0.000622	 0.004658	 0.00114	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52967	 53034	 0.002861	 0.011455	 0.00289	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52967	 93609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52967	 93609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52968	 93610	 0.003175	 0.014801	 0.00034	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52969	 52970	 0.001476	 0.006094	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93549	 52969	 0.001005	 0.014514	 0.00461	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52969	 93610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52969	 93610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52970	 52976	 0.005515	 0.021677	 0.00567	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52970	 53043	 0.002904	 0.007539	 0.00183	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52971	 93611	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52971	 93611	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52971	 93612	 0.000112	 0.001102	 0.00378	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52971	 93616	 0.000158	 0.001533	 0.00542	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93611	 52972	 0.025978	 0.020559	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52972	 93613	 0.006334	 0.018166	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52973	 52979	 8.6e-05	 0.001171	 0.01785	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52973	 53063	 7.3e-05	 0.001152	 0.01201	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52973	 93612	 9.3e-05	 0.007407	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52974	 53065	 0.004581	 0.021362	 0.00529	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52974	 93614	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52974	 93614	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52974	 93637	 0.00146	 0.006029	 0.00143	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52975	 53005	 0.006343	 0.016304	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93614	 52975	 0.005246	 0.023114	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52976	 52991	 0.001026	 0.005959	 0.0014	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52976	 52996	 0.000988	 0.004678	 0.00112	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52976	 53006	 0.001008	 0.003962	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52976	 93615	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52976	 93615	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93614	 52977	 0.003601	 0.016114	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93615	 52977	 0.002652	 0.01379	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	52978	 93618	 0.008749	 0.015387	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52979	 53040	 6.6e-05	 0.000736	 0.007	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	52979	 93616	 6.6e-05	 0.005263	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52980	 52985	 0.00161	 0.004321	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52980	 93618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52980	 93618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52981	 52982	 0.00034	 0.003822	 0.001	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52981	 52985	 0.000357	 0.004014	 0.00105	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52982	 93647	 0.000663	 0.007108	 0.00227	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52983	 52987	 0.010508	 0.016396	 0.00027	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52983	 93619	 0.01804	 0.016276	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52984	 93619	 0.007851	 0.034592	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52984	 93621	 0.013157	 0.027652	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	52985	 52992	 0.000769	 0.004006	 0.00105	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52985	 93619	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52985	 93619	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52986	 53070	 0.008684	 0.039423	 0.00086	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52986	 93620	 0.004839	 0.021201	 0.00046	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	52987	 93620	 0.012315	 0.034113	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52988	 52989	 0.002493	 0.012313	 0.0036	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52988	 52993	 0.001107	 0.006104	 0.00143	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92535	 52989	 0.003295	 0.019629	 0.00516	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52989	 93620	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52989	 93620	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52990	 53009	 0.029403	 0.053053	 0.00077	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52990	 53026	 0.020126	 0.021922	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52990	 53072	 0.024867	 0.10957	 0.0019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	52991	 52992	 0.000622	 0.003825	 0.0011	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52993	 53017	 0.000763	 0.004206	 0.00098	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	52993	 93621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52993	 93621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52994	 52995	 0.023448	 0.01575	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93620	 52995	 0.010149	 0.026088	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52996	 53012	 0.000986	 0.004438	 0.00118	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	52997	 93622	 0.016615	 0.013149	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	52998	 53010	 0.002155	 0.008768	 0.00214	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52998	 93622	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52998	 93622	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	52999	 53000	 0.001047	 0.00398	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52999	 53003	 0.002035	 0.008149	 0.00205	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	52999	 53037	 0.001053	 0.004349	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53000	 53010	 0.001016	 0.004066	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53000	 93623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53000	 93623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53001	 53002	 0.006451	 0.016584	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53002	 53013	 0.005785	 0.015293	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53003	 53008	 0.001025	 0.00403	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53003	 93624	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53003	 93624	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53004	 53005	 0.004904	 0.014762	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93624	 53004	 0.003523	 0.015697	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53005	 93625	 0.005811	 0.013288	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53006	 93625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53006	 93625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53007	 53021	 0.007296	 0.01694	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93625	 53007	 0.003524	 0.014102	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53007	 93626	 0.006428	 0.016523	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53008	 53014	 0.001023	 0.003982	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53008	 93626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53008	 93626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53009	 93630	 0.015969	 0.032817	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53010	 93627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53010	 93627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53011	 53021	 0.009737	 0.015961	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53011	 93628	 0.003518	 0.01408	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53012	 53017	 0.001538	 0.006509	 0.00146	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92530	 53012	 0.003775	 0.018321	 0.00419	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53012	 93628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53012	 93628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53013	 53016	 0.007642	 0.017743	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53013	 93629	 0.012424	 0.020636	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53014	 53015	 0.001027	 0.003594	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92530	 53015	 0.002729	 0.011876	 0.00338	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53015	 93629	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53015	 93629	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53016	 53020	 0.015006	 0.033667	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53017	 53018	 0.000803	 0.003961	 0.00107	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92530	 53018	 0.002063	 0.010174	 0.00275	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53018	 93630	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53018	 93630	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92531	 53019	 0.010437	 0.029936	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93630	 53019	 0.004897	 0.014741	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92531	 53020	 0.004751	 0.015847	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53022	 53023	 0.012594	 0.009967	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93623	 53022	 0.004938	 0.012693	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93605	 53024	 0.009404	 0.036585	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92530	 53025	 0.001338	 0.021926	 0.0069	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92531	 53027	 0.021109	 0.097823	 0.00188	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53028	 53030	 0.000358	 0.003918	 0.00109	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53028	 53046	 0.000913	 0.007966	 0.00219	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53028	 93631	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53028	 93631	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53030	 93632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53030	 93632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53031	 53032	 0.008796	 0.017415	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53032	 53039	 0.003051	 0.012103	 0.00035	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53033	 53034	 0.000992	 0.003472	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53033	 93633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53033	 93633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53034	 53035	 0.001358	 0.00453	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53034	 53041	 0.001464	 0.005957	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53034	 93634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53034	 93634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93607	 53035	 0.001375	 0.004792	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53035	 93635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53035	 93635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93607	 53036	 0.000357	 0.003781	 0.00112	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53037	 93636	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53037	 93636	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93600	 53038	 0.012953	 0.02938	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93609	 53039	 0.002473	 0.013914	 0.0003	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53040	 93637	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53041	 53044	 0.001147	 0.004508	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53042	 93640	 0.002991	 0.016121	 0.00032	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53043	 93639	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53043	 93639	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93637	 53044	 0.001406	 0.009432	 0.00228	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53044	 93640	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53044	 93640	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93638	 53045	 0.004499	 0.020129	 0.00041	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93639	 53045	 0.008786	 0.017394	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93598	 53048	 0.000406	 0.004905	 0.01032	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53048	 93641	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93642	 53048	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93642	 53049	 0.013277	 0.034129	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53050	 53051	 0.002184	 0.008584	 0.00225	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93641	 53050	 0.004219	 0.013761	 0.00365	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53050	 93643	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53050	 93643	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93643	 53052	 0.022225	 0.058905	 0.00149	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53053	 93644	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53054	 53055	 0.002689	 0.007927	 0.00184	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53054	 53056	 0.001958	 0.022392	 0.00627	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53054	 53058	 0.003264	 0.020065	 0.00579	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53055	 53057	 0.006475	 0.022889	 0.00516	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53055	 53058	 0.006312	 0.025273	 0.00637	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93423	 53055	 0.0148	 0.049376	 0.01252	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93419	 53056	 0.003126	 0.034619	 0.01126	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92522	 53057	 0.004287	 0.034222	 0.00843	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53057	 93646	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53057	 93646	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53058	 53075	 0.004777	 0.032045	 0.00774	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53059	 53064	 0.024864	 0.057726	 0.00086	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53060	 53061	 0.004979	 0.030612	 0.00055	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93550	 53060	 0.010981	 0.065795	 0.00158	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53061	 53062	 0.003148	 0.012488	 0.00036	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53062	 93648	 0.005521	 0.021479	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53063	 53073	 0.0003	 0.004067	 0.06196	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53063	 93647	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53063	 93647	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53064	 53068	 0.013905	 0.025855	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93647	 53065	 0.00274	 0.009586	 0.00318	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53065	 93648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53065	 93648	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93648	 53066	 0.006035	 0.015514	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53067	 53068	 0.03504	 0.02773	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92536	 53068	 0.013923	 0.039508	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92536	 53069	 0.020709	 0.016389	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92536	 53070	 0.005189	 0.026985	 0.00058	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53071	 53075	 0.002726	 0.015124	 0.0046	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92535	 53071	 0.001457	 0.007579	 0.00223	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53072	 93651	 0.014141	 0.075344	 0.00132	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53073	 53074	 0.000635	 0.007104	 0.06638	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53073	 93649	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53074	 93652	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53074	 93652	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93650	 53075	 0.008753	 0.024408	 0.00512	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53076	 93653	 0.035149	 0.027817	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53077	 53078	 0.000741	 0.00497	 0.0012	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53077	 53082	 0.0033	 0.013213	 0.00333	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53077	 93653	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53077	 93653	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53078	 53079	 0.00073	 0.007502	 0.00237	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53078	 53082	 0.001452	 0.008926	 0.00257	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53079	 53081	 0.001068	 0.011317	 0.00336	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53079	 53086	 0.001876	 0.016373	 0.0045	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92961	 53079	 0.008007	 0.095136	 0.03316	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53079	 93654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53079	 93654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93654	 53080	 0.00821	 0.019058	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53081	 53082	 0.001895	 0.007587	 0.00191	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53081	 93655	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53081	 93655	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53081	 93658	 0.004916	 0.046273	 0.01402	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53082	 93656	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53082	 93656	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53082	 93658	 0.004987	 0.048729	 0.01368	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53083	 53084	 0.023519	 0.01666	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93656	 53083	 0.009045	 0.020994	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93653	 53084	 0.043959	 0.034789	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53085	 53086	 0.003117	 0.030453	 0.00855	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53085	 93657	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53085	 93657	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93655	 53087	 0.0205	 0.031404	 0.00044	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53088	 93658	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53088	 93658	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53089	 53090	 0.011527	 0.05137	 0.01396	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53089	 93659	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53089	 93659	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53090	 93660	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53090	 93660	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53091	 53092	 0.13572	 0.20794	 0.00292	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93361	 53091	 0.1044	 0.23687	 0.00473	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93660	 53091	 0.061335	 0.20955	 0.00456	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93292	 53092	 0.1304	 0.23442	 0.00421	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53093	 93661	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93274	 53094	 0.046911	 0.18251	 0.00305	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93662	 53094	 0.050902	 0.25754	 0.00448	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53095	 93663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53095	 93663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53097	 53098	 0.00481	 0.019575	 0.00477	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53098	 53099	 0.002658	 0.0193	 0.00667	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53098	 93664	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53098	 93664	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92546	 53099	 0.005287	 0.043913	 0.01718	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53099	 93665	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53099	 93665	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92541	 53100	 0.012684	 0.08086	 0.00197	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93665	 53100	 0.006939	 0.042638	 0.00097	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53101	 53161	 0.025428	 0.098967	 0.02645	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53102	 93702	 0.1024	 0.27077	 0.00492	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53103	 53106	 0.012881	 0.052423	 0.01277	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53103	 53175	 0.024402	 0.09934	 0.02422	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53105	 93666	 0.00667	 0.04408	 0.00087	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53106	 53107	 0.003235	 0.017834	 0.00417	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53106	 93666	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53106	 93666	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53107	 53191	 0.030011	 0.10613	 0.02393	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53107	 53297	 0.015454	 0.080431	 0.0237	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53107	 93667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53107	 93667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53108	 53109	 0.020195	 0.050126	 0.00083	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53108	 53300	 0.25263	 0.50058	 0.00735	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93208	 53108	 0.17012	 0.56191	 0.00911	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53109	 53186	 0.078274	 0.39614	 0.0069	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93074	 53109	 0.21996	 0.40933	 0.00959	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53110	 53182	 0.040411	 0.10685	 0.02503	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53110	 53319	 0.014444	 0.070112	 0.01603	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92576	 53110	 0.031207	 0.16275	 0.04276	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53110	 93668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53110	 93668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53111	 53133	 0.063248	 0.21102	 0.00335	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93668	 53111	 0.10937	 0.21656	 0.00318	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53112	 53116	 0.010618	 0.037531	 0.00846	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53113	 93669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53113	 93669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53114	 53116	 0.002729	 0.009361	 0.00224	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53114	 53117	 0.004563	 0.019313	 0.00435	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53114	 93670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53114	 93670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93670	 53115	 0.029375	 0.067486	 0.00103	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53115	 93671	 0.02804	 0.072079	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53115	 93672	 0.007121	 0.027701	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53116	 93671	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53116	 93671	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53117	 53266	 0.012895	 0.070774	 0.01871	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53117	 93672	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53117	 93672	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53118	 53122	 0.10856	 0.076901	 0.00122	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92572	 53118	 0.20245	 0.39695	 0.00595	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53118	 93673	 0.025438	 0.058441	 0.00089	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53118	 93675	 0.081094	 0.26767	 0.00434	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53118	 93688	 0.084969	 0.30364	 0.00603	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53119	 53120	 0.004693	 0.012184	 0.00296	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53119	 53123	 0.00354	 0.014165	 0.00478	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53119	 53125	 0.007025	 0.058307	 0.01534	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53120	 93673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53120	 93673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93673	 53121	 0.007113	 0.014083	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53122	 93688	 0.10065	 0.33226	 0.00538	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53123	 53124	 0.011512	 0.039494	 0.00946	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53124	 53301	 0.039856	 0.13439	 0.03343	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53124	 93674	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53124	 93674	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53125	 93675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53125	 93675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53126	 53127	 0.000533	 0.006544	 0.10486	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53126	 53134	 0.001076	 0.012922	 0.21707	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53127	 93676	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53127	 93676	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53128	 53188	 0.010568	 0.10105	 0.03333	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92575	 53128	 0.004545	 0.047216	 0.0146	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53129	 53177	 0.055966	 0.19229	 0.04616	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53129	 53195	 0.017829	 0.12619	 0.03466	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53129	 53291	 0.077011	 0.26921	 0.06267	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53130	 53197	 0.073209	 0.12333	 0.00176	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93231	 53131	 0.21259	 0.48673	 0.0119	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53131	 93748	 0.16932	 0.3282	 0.00707	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53132	 53134	 0.001	 0.012293	 0.19706	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53132	 93677	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53132	 93677	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92577	 53133	 0.0676	 0.25364	 0.00456	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53135	 53191	 0.029722	 0.13873	 0.0344	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53135	 93678	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53135	 93678	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53136	 53138	 0.008733	 0.012397	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93215	 53136	 0.87405	 0.69352	 0.00873	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53136	 93746	 0.2708	 0.21436	 0.0027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53138	 93749	 0.099274	 0.3548	 0.00705	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53139	 53141	 0.010164	 0.026388	 0.0064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53139	 53168	 0.024439	 0.065623	 0.01488	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92573	 53140	 0.028931	 0.021286	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53140	 93679	 0.019548	 0.032601	 0.00047	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53140	 93680	 0.028987	 0.02294	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53141	 93679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53141	 93679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53142	 93680	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53142	 93680	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53143	 53144	 0.003154	 0.014467	 0.00371	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53143	 53173	 0.016123	 0.063378	 0.01658	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53143	 93681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53143	 93681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53144	 93682	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53144	 93682	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93678	 53145	 0.12708	 0.33607	 0.00611	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93682	 53145	 0.077728	 0.14238	 0.00246	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53146	 93683	 0.045463	 0.16086	 0.0363	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53147	 53316	 0.000672	 0.008884	 0.14232	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53147	 93683	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53147	 93683	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53148	 53149	 0.013107	 0.044965	 0.01077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53148	 93684	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53148	 93684	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53148	 93737	 0.044359	 0.18076	 0.04412	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53149	 53290	 0.015174	 0.063184	 0.01971	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53150	 93685	 0.042753	 0.10873	 0.00172	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53151	 53152	 0.004594	 0.01576	 0.00378	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53151	 53297	 0.018824	 0.075385	 0.019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53152	 53153	 0.003184	 0.009388	 0.00218	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53153	 53183	 0.01195	 0.067944	 0.01967	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53153	 93685	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53153	 93685	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53155	 53156	 0.04446	 0.10085	 0.00201	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92572	 53155	 0.1777	 0.45708	 0.00708	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53156	 53293	 0.13348	 0.354	 0.00898	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53156	 53295	 0.1243	 0.28861	 0.0055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92572	 53156	 0.16974	 0.56678	 0.00899	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93679	 53156	 0.186	 0.42574	 0.0104	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53157	 93686	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53157	 93686	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93686	 53158	 0.17167	 0.12411	 0.00188	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53159	 93687	 0.44197	 0.32541	 0.00476	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53160	 53322	 0.063978	 0.17441	 0.03848	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93683	 53160	 0.066807	 0.17681	 0.04145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53160	 93687	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53160	 93687	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93677	 53161	 0.018463	 0.07816	 0.01759	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53162	 53166	 0.04125	 0.10714	 0.02602	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53162	 93688	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53162	 93688	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93688	 53163	 0.097503	 0.34846	 0.00692	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53163	 93747	 0.09513	 0.41936	 0.00729	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53164	 53165	 0.35066	 0.22714	 0.00432	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93684	 53165	 0.10302	 0.21086	 0.00519	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53166	 53185	 0.063697	 0.16855	 0.03951	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53167	 53168	 0.016157	 0.045059	 0.00946	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53167	 93689	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53167	 93689	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53169	 53170	 0.009175	 0.077184	 0.02287	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93676	 53169	 0.014181	 0.10993	 0.03855	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53171	 53304	 0.064421	 0.17987	 0.03781	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53171	 93690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53171	 93690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53171	 93710	 0.057857	 0.24546	 0.05541	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93680	 53172	 0.078717	 0.21779	 0.00506	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93681	 53172	 0.095365	 0.19519	 0.0048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93686	 53172	 0.14805	 0.38074	 0.0059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53172	 93701	 0.23712	 0.4265	 0.00766	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53173	 53190	 0.0262	 0.0949	 0.02037	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53174	 93691	 0.0802	 0.057977	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53175	 53302	 0.051567	 0.14051	 0.03099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53175	 93691	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53175	 93691	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93685	 53176	 0.071804	 0.20378	 0.0032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53176	 93699	 0.16046	 0.40827	 0.00646	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53178	 53179	 0.000236	 0.002589	 0.02515	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53179	 53181	 0.000638	 0.007842	 0.12567	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53179	 93692	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53179	 93692	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53180	 93693	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53181	 93696	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53181	 93696	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53182	 53184	 0.014812	 0.070114	 0.01686	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53182	 93699	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53182	 93699	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53183	 53184	 0.009406	 0.04726	 0.0123	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53186	 93700	 0.053143	 0.32682	 0.00589	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92570	 53187	 0.11506	 0.30536	 0.07183	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53187	 93700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53187	 93700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53189	 53222	 0.070994	 0.36142	 0.0082	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93695	 53189	 0.082574	 0.44383	 0.01055	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53190	 53192	 0.017892	 0.098667	 0.02307	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53190	 93701	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53190	 93701	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53191	 53223	 0.01881	 0.095193	 0.02652	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53191	 93702	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53191	 93702	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53192	 53193	 0.003258	 0.017358	 0.00487	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53193	 53194	 0.004548	 0.029741	 0.00756	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53193	 53213	 0.034679	 0.091684	 0.02147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53194	 53255	 0.008304	 0.04864	 0.01325	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53195	 53199	 0.01213	 0.06657	 0.0176	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53195	 93703	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53195	 93703	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53195	 93708	 0.023221	 0.079677	 0.01909	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53196	 53198	 0.12867	 0.10086	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93703	 53196	 0.068652	 0.13593	 0.002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93703	 53197	 0.085087	 0.19303	 0.00385	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53199	 53218	 0.026833	 0.070931	 0.01661	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53199	 53290	 0.012363	 0.06151	 0.01986	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53200	 53204	 0.017333	 0.03547	 0.00087	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53200	 93717	 0.052605	 0.087733	 0.00128	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53201	 93705	 0.050149	 0.075186	 0.00137	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53201	 93717	 0.018458	 0.033807	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53202	 53240	 0.016404	 0.015383	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53203	 53206	 0.005441	 0.01438	 0.00337	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53203	 53252	 0.0025	 0.008577	 0.00205	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53203	 93704	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53203	 93704	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53204	 93743	 0.085553	 0.24542	 0.00378	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53205	 53257	 0.065727	 0.052016	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53206	 53208	 0.0157	 0.042153	 0.00955	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53206	 93705	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53206	 93705	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93705	 53207	 0.074512	 0.054821	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53208	 53210	 0.016671	 0.046491	 0.00976	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53209	 53239	 0.020494	 0.049393	 0.01395	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53209	 53311	 0.021205	 0.070753	 0.01795	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53210	 53312	 0.023169	 0.05825	 0.01509	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53210	 93706	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53210	 93706	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53211	 53212	 0.36527	 0.2892	 0.00364	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93698	 53212	 0.87126	 0.56599	 0.01077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53213	 53214	 0.00671	 0.048274	 0.01279	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53213	 53223	 0.013655	 0.091638	 0.02213	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53214	 53310	 0.009698	 0.061435	 0.01668	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92490	 53215	 0.43938	 0.34795	 0.00438	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92572	 53216	 0.31471	 0.50301	 0.0116	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53217	 93707	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53217	 93707	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53217	 93731	 0.01023	 0.027036	 0.00633	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53217	 93734	 0.053644	 0.13939	 0.03387	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53218	 53286	 0.019053	 0.05036	 0.01179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53219	 53221	 0.001857	 0.026384	 0.24993	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53219	 93708	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53220	 53285	 0.18407	 0.42758	 0.00636	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93703	 53220	 0.2299	 0.18024	 0.00231	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93709	 53220	 0.056367	 0.12892	 0.00315	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53221	 93710	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53221	 93710	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53222	 93741	 0.07093	 0.40339	 0.0073	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53223	 93711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53223	 93711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53224	 53225	 0.002085	 0.00861	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53224	 53226	 0.002161	 0.011258	 0.00295	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53224	 53227	 0.002827	 0.007339	 0.00178	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53224	 53260	 0.003916	 0.016573	 0.00373	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53225	 53236	 0.001001	 0.004073	 0.00099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53226	 93712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53226	 93712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53227	 53310	 0.030597	 0.10314	 0.02565	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53227	 93713	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53227	 93713	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93713	 53228	 0.003736	 0.016649	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53228	 93715	 0.002332	 0.008934	 0.00025	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53229	 53230	 0.00177	 0.004678	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53229	 53232	 0.00137	 0.004614	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53229	 93714	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53229	 93714	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53230	 53233	 0.002054	 0.005727	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53230	 93715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53230	 93715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93714	 53231	 0.021867	 0.016088	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53232	 53233	 0.003209	 0.011183	 0.00259	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53232	 53258	 0.01232	 0.033076	 0.0075	 137.0	 137.0	 137.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53232	 53259	 0.00084	 0.008729	 0.0027	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53233	 53246	 0.001486	 0.004644	 0.00135	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53233	 93716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53233	 93716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53234	 53235	 0.005886	 0.01078	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93716	 53234	 0.018156	 0.013125	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53235	 53244	 0.016245	 0.032164	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93713	 53235	 0.005077	 0.019453	 0.00055	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53236	 53265	 0.00162	 0.005557	 0.00133	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53237	 53241	 0.022562	 0.027504	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53237	 53256	 0.12289	 0.18828	 0.00264	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53237	 53262	 0.061399	 0.048128	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93712	 53237	 0.009131	 0.030461	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53238	 53242	 0.024737	 0.019577	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93712	 53238	 0.014766	 0.025968	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53239	 53265	 0.002645	 0.007377	 0.00155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53239	 93717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53239	 93717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53240	 53241	 0.026166	 0.024101	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53240	 53243	 0.007631	 0.019407	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53242	 53243	 0.023519	 0.018612	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93717	 53243	 0.004714	 0.014461	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53244	 93726	 0.018291	 0.013457	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53245	 53246	 0.001536	 0.00406	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53245	 53265	 0.000951	 0.00239	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53245	 93718	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53245	 93718	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53246	 53251	 0.001023	 0.002652	 0.0008	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53246	 93719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53246	 93719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93715	 53247	 0.012204	 0.021463	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93719	 53247	 0.010163	 0.013357	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53248	 53249	 0.028459	 0.022307	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53248	 53250	 0.019762	 0.013275	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93714	 53248	 0.01511	 0.038843	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53248	 93720	 0.032873	 0.026015	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53249	 53257	 0.046567	 0.035281	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93715	 53249	 0.019715	 0.039033	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53251	 53252	 0.001108	 0.002877	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53252	 93720	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53252	 93720	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53253	 53254	 0.008894	 0.029965	 0.00745	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53253	 93721	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53253	 93721	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53254	 53266	 0.015019	 0.059037	 0.01545	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53254	 93722	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53254	 93722	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53255	 53260	 0.013911	 0.055701	 0.01403	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53255	 93723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53255	 93723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93723	 53256	 0.033289	 0.18925	 0.00342	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53257	 53264	 0.11052	 0.08374	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53258	 93724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53258	 93724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53260	 93725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53260	 93725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93712	 53261	 0.030325	 0.039464	 0.00055	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53263	 53264	 0.040309	 0.029657	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93724	 53263	 0.016433	 0.038152	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53265	 93726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53265	 93726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53266	 93727	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53266	 93727	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93672	 53267	 0.1144	 0.29415	 0.00455	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93727	 53267	 0.12991	 0.15839	 0.00254	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53268	 53271	 0.000216	 0.001855	 0.00407	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92578	 53268	 0.000585	 0.004503	 0.00803	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53268	 93728	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93729	 53268	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92579	 53269	 0.002067	 0.008746	 0.00197	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93728	 53269	 0.000927	 0.003525	 0.00099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53270	 93730	 0.017148	 0.022537	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53271	 53278	 0.000374	 0.003121	 0.00542	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53271	 93730	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53271	 93730	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53272	 53276	 0.002348	 0.013193	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53272	 53279	 0.010168	 0.039117	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93730	 53272	 0.007446	 0.019141	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53273	 53274	 0.023216	 0.017808	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53274	 53276	 0.00443	 0.021262	 0.00064	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53274	 53280	 0.002353	 0.014299	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93729	 53274	 0.010722	 0.024633	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53275	 53288	 0.095438	 0.074811	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53275	 93732	 0.021209	 0.035228	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53277	 53279	 0.022129	 0.045284	 0.00111	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53277	 53283	 0.061185	 0.12522	 0.00308	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53278	 53289	 0.007933	 0.053575	 0.09877	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53278	 93731	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93732	 53278	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93732	 53279	 0.018125	 0.046593	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92580	 53280	 0.002679	 0.018391	 0.00034	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92580	 53281	 0.047991	 0.052784	 0.0007	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53282	 53283	 0.045932	 0.11808	 0.00183	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92580	 53282	 0.037281	 0.086541	 0.00165	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93684	 53283	 0.083798	 0.24647	 0.00505	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53284	 53285	 0.017451	 0.012362	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92580	 53285	 0.010797	 0.012925	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92578	 53287	 0.000397	 0.003402	 0.00747	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53287	 93733	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53287	 93733	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93707	 53288	 0.042244	 0.033431	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53289	 93734	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53289	 93734	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53292	 53305	 0.001049	 0.013225	 0.20167	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53292	 53315	 0.000979	 0.012645	 0.21236	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53293	 53295	 0.090974	 0.18014	 0.00264	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53293	 93735	 0.079982	 0.18942	 0.00346	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53294	 93735	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53294	 93735	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53295	 53296	 0.33374	 0.26422	 0.00333	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93689	 53296	 0.24571	 0.15912	 0.00303	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53297	 93736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53297	 93736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53298	 93737	 0.01479	 0.095302	 0.025	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53299	 93737	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93738	 53300	 0.053356	 0.32814	 0.00592	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53301	 53302	 0.004351	 0.010485	 0.00296	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53301	 93739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53301	 93739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93678	 53303	 0.11497	 0.37957	 0.00615	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93739	 53303	 0.11186	 0.26494	 0.00485	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93694	 53304	 0.035849	 0.094779	 0.0222	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53304	 93740	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53304	 93740	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93074	 53306	 0.066568	 0.30857	 0.00592	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53306	 93741	 0.1295	 0.2651	 0.00653	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53307	 53309	 0.046619	 0.1601	 0.03841	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53307	 93741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53307	 93741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53308	 93742	 0.24815	 0.17943	 0.00272	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92575	 53309	 0.024298	 0.19556	 0.05511	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53309	 93742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53309	 93742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53310	 53318	 0.058283	 0.15663	 0.03554	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53310	 93743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53310	 93743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53311	 53321	 0.029718	 0.07856	 0.01839	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53311	 93744	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53311	 93744	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53312	 53313	 0.024532	 0.063699	 0.01546	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53312	 93745	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53312	 93745	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53313	 53314	 0.019625	 0.053435	 0.01177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53313	 93746	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53313	 93746	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53315	 53316	 0.000827	 0.010476	 0.18302	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53315	 93747	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53315	 93747	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53316	 93748	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53316	 93748	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53317	 93749	 0.027459	 0.042845	 0.00072	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53317	 93751	 0.008761	 0.020127	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53318	 53320	 0.002824	 0.008101	 0.00199	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53318	 53321	 0.013096	 0.03156	 0.00891	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92576	 53318	 0.027104	 0.22057	 0.07049	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53318	 93749	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53318	 93749	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53319	 93750	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53319	 93750	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53320	 93751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53320	 93751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93710	 53322	 0.084703	 0.22436	 0.05266	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53323	 54108	 0.031261	 0.14192	 0.00308	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53323	 93754	 0.1001	 0.28412	 0.00447	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53324	 53330	 0.11888	 0.08747	 0.00128	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53324	 93752	 0.060999	 0.097371	 0.00224	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92607	 53325	 0.01026	 0.034569	 0.00859	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53325	 93752	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53325	 93752	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53326	 53327	 0.026591	 0.052647	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53327	 53328	 0.011824	 0.031256	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53327	 53330	 0.028873	 0.059088	 0.00145	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53327	 93753	 0.021374	 0.054943	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53327	 93754	 0.13689	 0.21856	 0.00504	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53328	 93753	 0.008249	 0.022536	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53329	 53331	 0.006846	 0.026906	 0.00704	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53329	 53333	 0.029579	 0.078192	 0.01831	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53329	 93753	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53329	 93753	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93752	 53330	 0.27649	 0.21678	 0.00278	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53331	 53333	 0.034106	 0.09017	 0.02111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53331	 54113	 0.018562	 0.085183	 0.02183	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53332	 56591	 0.028112	 0.12458	 0.00374	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92608	 53332	 0.30303	 0.59454	 0.00892	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93753	 53332	 0.024925	 0.15148	 0.00279	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53333	 54110	 0.018113	 0.13238	 0.03406	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53333	 56434	 0.024939	 0.073542	 0.01711	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92607	 53333	 0.0229	 0.061489	 0.01394	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53333	 93754	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53333	 93754	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53334	 93755	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93756	 53334	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53335	 55392	 0.021438	 0.10576	 0.02862	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93756	 53335	 0.009972	 0.038795	 0.01036	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53335	 93757	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53335	 93757	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53335	 94192	 0.041529	 0.12036	 0.02905	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53336	 53337	 0.22265	 0.16098	 0.00244	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53336	 55053	 0.7661	 0.60749	 0.00765	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93757	 53336	 0.006496	 0.016698	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53337	 94867	 0.49695	 0.39361	 0.00496	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53338	 53341	 0.001679	 0.02374	 0.00786	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53338	 54117	 0.009276	 0.038621	 0.01204	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53338	 57167	 0.004925	 0.03998	 0.01273	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53338	 93758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53338	 93758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93758	 53339	 0.12998	 0.14159	 0.00193	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53340	 53345	 0.001904	 0.007238	 0.00203	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53340	 53352	 0.005829	 0.023337	 0.00588	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53341	 53343	 0.000947	 0.006854	 0.00369	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53341	 93760	 0.010516	 0.048247	 0.01236	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53342	 53349	 0.031768	 0.05732	 0.00083	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53342	 93761	 0.036605	 0.086683	 0.00158	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53343	 53345	 0.002982	 0.01368	 0.0035	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53343	 93759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53343	 93759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53343	 93760	 0.007474	 0.040245	 0.01106	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93759	 53344	 0.010853	 0.035814	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53346	 53347	 0.013463	 0.028743	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93759	 53346	 0.008035	 0.026805	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93759	 53348	 0.016732	 0.033128	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53350	 57351	 0.000842	 0.009372	 0.08839	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53350	 93760	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93761	 53351	 0.042462	 0.10799	 0.00171	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53352	 53354	 0.008	 0.043003	 0.01058	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53352	 57168	 0.007529	 0.056422	 0.01376	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53353	 53354	 0.007341	 0.038242	 0.01003	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53353	 58231	 0.01072	 0.051099	 0.0148	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53355	 53357	 0.012795	 0.051231	 0.01291	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53355	 57432	 0.009	 0.036036	 0.00908	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53356	 93762	 0.038767	 0.028025	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53357	 53359	 0.006032	 0.024546	 0.00598	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53357	 93762	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53357	 93762	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93762	 53358	 0.043916	 0.031746	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92721	 53359	 0.010227	 0.03979	 0.01063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53360	 58411	 0.057568	 0.075663	 0.00104	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53361	 53362	 0.071247	 0.21883	 0.00411	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53361	 93771	 0.073035	 0.35672	 0.00748	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53362	 58564	 0.26273	 0.25714	 0.00364	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53363	 55036	 0.12941	 0.43192	 0.00685	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53363	 57412	 0.085979	 0.30094	 0.00624	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92628	 53364	 0.049365	 0.18917	 0.00535	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53364	 95316	 0.39805	 0.31218	 0.00401	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53365	 53641	 0.071747	 0.14062	 0.00211	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53365	 57049	 0.052285	 0.085707	 0.00151	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53365	 93763	 0.058977	 0.13693	 0.00204	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53366	 53367	 0.007537	 0.021018	 0.00441	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53366	 53369	 0.016568	 0.041652	 0.01079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53366	 53610	 0.016726	 0.044206	 0.01035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53366	 93763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53366	 93763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53367	 53369	 0.009076	 0.021068	 0.00642	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53368	 93764	 0.2038	 0.16131	 0.00203	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53368	 93825	 0.17246	 0.1352	 0.00174	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53369	 56877	 0.060094	 0.16151	 0.03665	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92627	 53369	 0.014892	 0.078887	 0.02	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53369	 93764	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53369	 93764	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53370	 53371	 0.16838	 0.22134	 0.00303	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53370	 55388	 0.26733	 0.2701	 0.00358	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92628	 53371	 0.038751	 0.10587	 0.0018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53372	 55377	 0.004851	 0.040287	 0.01576	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53372	 93765	 0.004707	 0.046637	 0.01429	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53373	 53374	 0.000354	 0.004167	 0.07279	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53373	 58304	 0.000345	 0.004243	 0.06797	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53374	 93765	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53375	 55296	 0.016803	 0.057649	 0.01381	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53375	 58315	 0.013722	 0.047828	 0.01109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92619	 53375	 0.022077	 0.073665	 0.01869	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93765	 53375	 0.010553	 0.066855	 0.01815	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53376	 53377	 0.004514	 0.034	 0.00943	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53376	 58307	 0.021456	 0.056711	 0.01328	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53376	 58314	 0.00454	 0.035319	 0.00918	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53377	 93767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53377	 93767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53377	 95256	 0.006848	 0.0506	 0.01461	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92615	 53378	 0.04552	 0.25881	 0.00468	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53378	 93963	 0.10293	 0.49701	 0.00879	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53379	 53380	 0.060121	 0.11514	 0.00181	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53379	 53381	 0.090728	 0.30274	 0.0048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53379	 53382	 0.078326	 0.16098	 0.00307	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53380	 56793	 0.26963	 0.35453	 0.00486	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53381	 94792	 0.064021	 0.2491	 0.00416	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53382	 53383	 0.053342	 0.093121	 0.00144	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53382	 57046	 0.094021	 0.17485	 0.00409	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53383	 94861	 0.097945	 0.19198	 0.00288	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53384	 53385	 0.007825	 0.024333	 0.00508	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92679	 53384	 0.012397	 0.040436	 0.01074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53385	 58142	 0.006915	 0.0233	 0.00579	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53385	 93768	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53385	 93768	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53386	 58221	 0.031448	 0.083136	 0.01947	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92679	 53386	 0.011707	 0.041384	 0.00933	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92752	 53386	 0.011666	 0.042246	 0.00906	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53386	 93769	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53386	 93769	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53387	 53390	 0.017023	 0.045704	 0.01036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92679	 53387	 0.005963	 0.01576	 0.00369	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92752	 53387	 0.005808	 0.0146	 0.00378	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53387	 93770	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53387	 93770	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92680	 53388	 0.031251	 0.080335	 0.00124	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53389	 56846	 0.019597	 0.082965	 0.01867	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92752	 53389	 0.00601	 0.025437	 0.00572	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53390	 53391	 0.007429	 0.019097	 0.00473	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92686	 53390	 0.052884	 0.22427	 0.0506	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92804	 53390	 0.024064	 0.062483	 0.01517	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92804	 53391	 0.017777	 0.042844	 0.0121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93769	 53392	 0.056136	 0.11115	 0.00163	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53392	 95228	 0.31868	 0.25228	 0.00318	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53393	 53984	 0.077826	 0.1807	 0.00269	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93769	 53393	 0.049592	 0.12853	 0.00243	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53394	 56816	 0.029313	 0.1006	 0.02411	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53394	 58426	 0.034219	 0.1346	 0.03525	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92738	 53394	 0.072723	 0.24569	 0.06128	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53394	 93771	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53394	 93771	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53395	 53398	 0.17751	 0.24746	 0.00423	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53395	 94821	 0.11146	 0.28659	 0.00444	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53396	 56769	 0.048061	 0.16212	 0.04035	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53396	 57486	 0.041716	 0.11031	 0.02584	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53396	 57489	 0.033663	 0.088996	 0.02084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53396	 93772	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53396	 93772	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93772	 53397	 0.11032	 0.12134	 0.00162	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53397	 94999	 0.13819	 0.35537	 0.0055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53398	 53400	 0.035662	 0.038843	 0.00053	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53399	 53400	 0.031518	 0.024943	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93772	 53400	 0.06035	 0.18535	 0.00348	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53401	 57488	 0.3454	 0.27085	 0.00348	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53402	 55278	 0.051671	 0.17238	 0.00273	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53402	 93775	 0.047913	 0.1075	 0.00171	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53403	 53426	 0.016213	 0.0465	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53403	 93773	 0.021654	 0.05507	 0.00087	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53404	 53405	 0.005372	 0.029477	 0.00779	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53404	 57004	 0.005958	 0.041338	 0.0118	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53405	 53416	 0.0018	 0.006841	 0.00192	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53405	 93773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53405	 93773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53406	 53411	 0.005376	 0.014992	 0.00315	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53406	 93774	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53406	 93774	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53407	 93775	 0.050146	 0.046661	 0.00088	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53408	 93775	 0.015024	 0.014089	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53409	 53411	 0.001861	 0.004919	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53409	 53417	 0.003836	 0.0103	 0.00233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53409	 93775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53409	 93775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53410	 93776	 0.015873	 0.012561	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53411	 53417	 0.001969	 0.006754	 0.00162	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53411	 93776	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53411	 93776	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53412	 53413	 0.020929	 0.034955	 0.00059	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53412	 53414	 0.03152	 0.062408	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53413	 53421	 0.027159	 0.041605	 0.00058	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53413	 53422	 0.023829	 0.05346	 0.00085	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93776	 53414	 0.009008	 0.023156	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53415	 53420	 0.011813	 0.027425	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53415	 93777	 0.006419	 0.017779	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53416	 53417	 0.001239	 0.00504	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53417	 53423	 0.006287	 0.030514	 0.00698	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53417	 93777	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53417	 93777	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53418	 53420	 0.009482	 0.021785	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53418	 53421	 0.02552	 0.050527	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53418	 93778	 0.012242	 0.068884	 0.00149	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53419	 53420	 0.005207	 0.012331	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53419	 53421	 0.007873	 0.014205	 0.00021	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53422	 53460	 0.053182	 0.098889	 0.00231	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53423	 53427	 0.003767	 0.030267	 0.00851	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53423	 53461	 0.004195	 0.019245	 0.00493	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92598	 53423	 0.03993	 0.15552	 0.0416	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53423	 93778	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53423	 93778	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53424	 53426	 0.026202	 0.040139	 0.00056	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93778	 53424	 0.019872	 0.047399	 0.00106	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53425	 53426	 0.029328	 0.02222	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93778	 53426	 0.025418	 0.074745	 0.00153	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53427	 53429	 0.002004	 0.018862	 0.00571	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53427	 93779	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53427	 93779	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53428	 93780	 0.013736	 0.023139	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53429	 53441	 0.000557	 0.006367	 0.00194	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53429	 93780	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53429	 93780	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93780	 53430	 0.014073	 0.027864	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93779	 53431	 0.034082	 0.054402	 0.00125	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53432	 53433	 0.004504	 0.011024	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53432	 53445	 0.006728	 0.017831	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53433	 53436	 0.015765	 0.024151	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53433	 53458	 0.013424	 0.014765	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53434	 53435	 0.014483	 0.011352	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53434	 53436	 0.007577	 0.015001	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53436	 53437	 0.013377	 0.01825	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53436	 93788	 0.014204	 0.080743	 0.00146	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53437	 93781	 0.009724	 0.016241	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53438	 53442	 0.000346	 0.002711	 0.00124	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53438	 53443	 0.000456	 0.003447	 0.00169	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53438	 93781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53438	 93781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93780	 53439	 0.035302	 0.027938	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53440	 53441	 0.000309	 0.002235	 0.0012	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53440	 53442	 0.000349	 0.002637	 0.00129	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53441	 53444	 0.000883	 0.008036	 0.00203	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53443	 53447	 0.000409	 0.002876	 0.00163	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53444	 93785	 0.001789	 0.016243	 0.00529	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53445	 53463	 0.002903	 0.011291	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53446	 53463	 0.013076	 0.010348	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53447	 53457	 0.000289	 0.004042	 0.00137	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53447	 93782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53447	 93782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53448	 53453	 0.00804	 0.012833	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53448	 93786	 0.014984	 0.038518	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53449	 53450	 0.002678	 0.010303	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53449	 53450	 0.002678	 0.010303	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53449	 93786	 0.004935	 0.019198	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53449	 93786	 0.004935	 0.019198	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53450	 93789	 0.00274	 0.010658	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53450	 93789	 0.00274	 0.010658	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53451	 53459	 0.000578	 0.008649	 0.02023	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53451	 93783	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53451	 93783	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53451	 93784	 0.000191	 0.002853	 0.00667	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53452	 54341	 0.044728	 0.084537	 0.00137	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53452	 93788	 0.01394	 0.035835	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53452	 94801	 0.11971	 0.1834	 0.00258	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53454	 53456	 7.5e-05	 0.001175	 0.01238	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53454	 58441	 0.001129	 0.014928	 0.2393	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53454	 93784	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53455	 93789	 0.015354	 0.012151	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53456	 53968	 0.003071	 0.039836	 0.67306	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53456	 93787	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53457	 54332	 0.002579	 0.010033	 0.00268	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93787	 53457	 0.000365	 0.005367	 0.00164	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53457	 93789	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53457	 93789	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53458	 53466	 0.063205	 0.05002	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53459	 58449	 0.000965	 0.015047	 0.03233	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53460	 57087	 0.096069	 0.37389	 0.00624	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53461	 53462	 0.005255	 0.021029	 0.0071	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53462	 58524	 0.00664	 0.030462	 0.0078	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93782	 53463	 0.006735	 0.012335	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93788	 53463	 0.007664	 0.040833	 0.00072	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53464	 53465	 0.042016	 0.033251	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93783	 53465	 0.049441	 0.038754	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53467	 53470	 0.005099	 0.017011	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53467	 93792	 0.004454	 0.023729	 0.00042	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53468	 93816	 0.013134	 0.009304	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53469	 53590	 0.000884	 0.003681	 0.00115	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53469	 53772	 0.002175	 0.00855	 0.00224	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53469	 93790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53469	 93790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53470	 53646	 0.010479	 0.026937	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53471	 53472	 0.002851	 0.008745	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53471	 93858	 0.003099	 0.009114	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53472	 93791	 0.002309	 0.01029	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53473	 53474	 0.000745	 0.003151	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53473	 93791	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53473	 93791	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53474	 93792	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53474	 93792	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53474	 93793	 0.003046	 0.010449	 0.0025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53474	 93808	 0.001531	 0.009412	 0.00271	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53475	 53478	 0.00047	 0.003048	 0.00607	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53475	 93793	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93794	 53475	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53475	 93807	 0.000239	 0.002537	 0.00581	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53476	 53482	 0.00496	 0.017719	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53476	 53782	 0.010881	 0.021544	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93794	 53476	 0.00598	 0.036343	 0.00067	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93794	 53477	 0.013833	 0.02119	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53478	 53830	 0.000929	 0.007618	 0.01372	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53478	 93795	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53478	 93795	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53478	 93799	 0.000128	 0.001726	 0.0036	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53479	 53485	 0.009299	 0.014095	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53480	 53483	 0.006725	 0.015253	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93794	 53480	 0.008465	 0.03293	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53481	 53482	 0.008741	 0.015772	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53481	 93869	 0.012134	 0.022562	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53482	 53784	 0.005485	 0.0141	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53483	 53484	 0.00795	 0.020435	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53484	 53486	 0.004788	 0.012177	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53485	 53500	 0.006196	 0.019028	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93795	 53485	 0.00647	 0.028829	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53486	 53500	 0.010781	 0.020046	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53486	 93796	 0.056496	 0.04471	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53487	 53492	 0.010982	 0.021522	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53487	 53495	 0.007723	 0.019642	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53487	 53807	 0.006442	 0.022007	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53487	 93869	 0.008357	 0.03251	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53488	 53498	 0.01572	 0.014086	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53488	 53524	 0.005751	 0.010694	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53489	 53523	 0.012462	 0.020993	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53489	 93796	 0.032406	 0.024552	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53490	 53535	 0.007681	 0.020301	 0.00475	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53490	 93796	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53490	 93796	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53490	 93814	 0.004405	 0.033751	 0.00904	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53490	 93868	 0.004126	 0.0139	 0.00345	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53491	 53495	 0.011627	 0.017634	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53492	 53493	 0.019576	 0.014832	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53493	 53494	 0.009821	 0.016543	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53494	 53497	 0.006517	 0.016753	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53494	 53531	 0.032331	 0.025586	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53495	 53496	 0.003658	 0.01423	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93796	 53496	 0.003789	 0.01757	 0.00036	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53497	 53498	 0.006079	 0.01546	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93796	 53498	 0.004664	 0.022504	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93796	 53499	 0.013889	 0.035703	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53499	 93797	 0.003593	 0.013767	 0.00039	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53500	 53501	 0.018414	 0.022043	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53501	 53502	 0.010391	 0.017259	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93796	 53501	 0.013834	 0.019639	 0.00032	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53502	 53519	 0.036484	 0.04795	 0.00066	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53502	 53520	 0.009585	 0.024638	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53503	 53505	 0.000557	 0.004556	 0.00124	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53503	 53508	 0.002166	 0.005814	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53503	 93797	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53503	 93797	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53504	 53512	 0.011354	 0.020486	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53504	 53553	 0.014026	 0.021885	 0.00037	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53504	 93798	 0.007797	 0.020042	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53505	 93798	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53505	 93798	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53505	 93800	 0.000554	 0.006121	 0.00184	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53506	 53544	 0.00019	 0.002082	 0.02022	 1000.0	 1050.0	 1100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53506	 53566	 0.000463	 0.005341	 0.04682	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53506	 93799	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93800	 53506	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53507	 53508	 0.001681	 0.004442	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53507	 53513	 0.00165	 0.010254	 0.00289	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53507	 93801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53507	 93801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53508	 93802	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53508	 93802	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53509	 53510	 0.017283	 0.018824	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53509	 53514	 0.006986	 0.017958	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53510	 53559	 0.021767	 0.014621	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53511	 53512	 0.015599	 0.012345	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93802	 53511	 0.023084	 0.017707	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53512	 53559	 0.032588	 0.03056	 0.00047	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53513	 53517	 0.000428	 0.003333	 0.001	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53513	 93803	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53513	 93803	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53514	 53515	 0.004811	 0.018716	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53514	 53558	 0.012631	 0.020704	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93803	 53514	 0.003477	 0.015781	 0.00034	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53514	 93815	 0.007888	 0.035151	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53515	 53516	 0.004261	 0.012826	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53516	 53518	 0.014851	 0.026796	 0.00039	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53516	 53519	 0.005995	 0.021417	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53517	 55554	 0.001701	 0.004277	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53517	 93814	 0.001064	 0.007523	 0.00206	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53518	 53534	 0.032811	 0.032819	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53518	 94349	 0.012848	 0.042859	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53519	 53523	 0.011507	 0.02958	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53519	 53526	 0.011079	 0.025452	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53519	 93815	 0.021822	 0.077958	 0.00155	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53520	 53521	 0.00487	 0.01607	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93801	 53520	 0.003802	 0.023376	 0.00042	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53521	 53523	 0.00549	 0.011234	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53522	 53523	 0.002009	 0.008987	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53522	 53525	 0.004628	 0.011993	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53524	 53525	 0.003019	 0.011745	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53525	 93804	 0.015644	 0.030974	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53526	 53527	 0.017094	 0.013528	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53528	 53529	 0.017762	 0.018968	 0.0004	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53529	 53530	 0.009759	 0.022657	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53529	 53531	 0.03742	 0.029613	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53529	 53812	 0.020148	 0.027465	 0.00061	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53529	 93804	 0.008486	 0.040735	 0.00122	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53530	 53532	 0.007006	 0.024529	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53530	 53809	 0.036097	 0.092793	 0.00144	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53532	 53533	 0.026063	 0.060509	 0.0009	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53532	 54306	 0.015797	 0.066857	 0.00126	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53532	 93804	 0.017661	 0.044915	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53533	 54302	 0.061073	 0.1102	 0.00159	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53535	 93804	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53535	 93804	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53535	 94007	 0.008933	 0.040985	 0.0105	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53536	 93805	 0.013744	 0.010877	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53537	 53538	 0.000307	 0.003132	 0.00081	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53537	 53569	 0.000279	 0.00268	 0.00078	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53537	 93805	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53537	 93805	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53538	 53539	 0.000216	 0.003117	 0.00099	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53538	 53540	 0.00063	 0.003347	 0.00078	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53538	 53573	 0.000824	 0.003401	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53539	 53546	 0.00021	 0.00323	 0.0009	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53540	 53541	 0.000785	 0.002984	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53540	 93808	 0.001717	 0.007268	 0.00164	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53541	 53542	 0.00078	 0.002629	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53542	 93806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53542	 93806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53543	 53544	 5.1e-05	 0.000683	 0.01203	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53543	 93807	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53544	 53545	 4.9e-05	 0.000908	 0.00872	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53544	 93810	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53544	 93810	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53545	 53547	 5.3e-05	 0.000984	 0.00945	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53546	 93811	 0.000246	 0.003617	 0.00111	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53547	 53548	 4e-05	 0.000518	 0.0088	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53547	 93811	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53547	 93811	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53548	 53549	 6.1e-05	 0.000835	 0.01413	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53548	 93812	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53548	 93812	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53549	 93813	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53549	 93813	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93813	 53550	 0.044541	 0.035249	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53551	 53552	 0.024051	 0.017695	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53552	 53555	 0.006423	 0.022946	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93810	 53552	 0.002537	 0.018066	 0.00041	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53553	 53555	 0.003097	 0.008209	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53553	 53565	 0.003771	 0.014669	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53554	 53565	 0.011738	 0.039156	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93810	 53554	 0.005269	 0.032394	 0.00058	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53556	 93815	 0.056478	 0.04427	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53557	 53560	 0.015699	 0.019138	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53559	 53560	 0.005523	 0.014198	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53559	 53561	 0.025764	 0.020389	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53559	 93815	 0.014386	 0.046131	 0.00114	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53560	 53563	 0.018287	 0.016499	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53562	 53563	 0.022181	 0.022404	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53562	 53568	 0.081838	 0.062776	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53563	 53564	 0.008904	 0.014212	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53564	 53565	 0.005464	 0.011485	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53566	 93814	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53567	 53568	 0.052121	 0.099818	 0.00157	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53567	 55565	 0.1059	 0.13919	 0.00191	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53567	 58528	 0.047116	 0.09234	 0.00138	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93815	 53568	 0.04689	 0.11104	 0.00203	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53569	 53824	 0.000413	 0.003469	 0.00103	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53569	 93816	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53569	 93816	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53570	 93861	 0.009979	 0.018278	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53571	 53572	 0.027562	 0.021605	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53572	 93817	 0.006554	 0.012845	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53573	 53575	 0.000628	 0.003046	 0.0007	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53573	 93817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53573	 93817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93817	 53574	 0.017135	 0.01356	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53575	 53581	 0.00101	 0.005865	 0.00138	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53576	 53577	 0.000605	 0.003544	 0.00097	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53576	 53597	 0.000661	 0.003629	 0.00096	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53577	 53578	 0.000504	 0.002681	 0.00062	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53577	 53581	 0.000944	 0.00378	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53578	 53580	 0.00062	 0.003844	 0.00093	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53579	 93818	 0.002963	 0.009884	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53579	 93862	 0.021546	 0.023468	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53580	 53585	 0.000548	 0.004611	 0.00137	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53580	 93818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53580	 93818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53581	 53582	 0.000959	 0.00528	 0.00191	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53582	 53585	 0.001104	 0.003324	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93812	 53582	 0.000868	 0.006336	 0.00163	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53583	 53584	 0.001216	 0.004424	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53583	 53587	 0.001712	 0.007855	 0.00201	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53583	 93819	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53583	 93819	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53584	 53585	 0.000699	 0.002399	 0.00057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53585	 53587	 0.002376	 0.012591	 0.0042	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93819	 53586	 0.041551	 0.0269	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92624	 53587	 0.001116	 0.017142	 0.0048	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92803	 53588	 0.001638	 0.005343	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53589	 58534	 0.004403	 0.021486	 0.00593	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92616	 53589	 0.001246	 0.008816	 0.00242	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53590	 53613	 0.000586	 0.004329	 0.00125	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53590	 53615	 0.002628	 0.006946	 0.00163	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53590	 53824	 0.000365	 0.002578	 0.00071	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93808	 53590	 0.002355	 0.018923	 0.00532	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53590	 93820	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53590	 93820	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93820	 53591	 0.017564	 0.01913	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53592	 93828	 0.01378	 0.009961	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53593	 53594	 0.000518	 0.002034	 0.00053	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53593	 53615	 0.001033	 0.003543	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53594	 53622	 0.001304	 0.005306	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53595	 53597	 0.00215	 0.00861	 0.00217	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53595	 53599	 0.000903	 0.003673	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53595	 53600	 0.000949	 0.006115	 0.0016	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93808	 53595	 0.007761	 0.026623	 0.00638	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53595	 93821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53595	 93821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93821	 53596	 0.00987	 0.012736	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53598	 53605	 0.015934	 0.01261	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93821	 53598	 0.031996	 0.025321	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53598	 93824	 0.009503	 0.036971	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53599	 53604	 0.000914	 0.00366	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53600	 53622	 0.000774	 0.004267	 0.001	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53601	 53603	 0.001289	 0.00469	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53601	 93822	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53601	 93822	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93822	 53602	 0.028111	 0.022246	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53602	 93823	 0.008364	 0.01656	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53603	 53607	 0.001456	 0.005925	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53604	 53606	 0.000765	 0.004482	 0.00122	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53604	 93823	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53604	 93823	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53606	 53607	 0.001461	 0.003792	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53606	 53825	 0.001942	 0.008452	 0.00241	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53607	 53608	 0.00171	 0.012501	 0.00369	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53607	 93824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53607	 93824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53608	 53610	 0.010922	 0.028866	 0.00676	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92710	 53608	 0.002526	 0.022973	 0.0058	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53609	 53640	 0.056893	 0.13071	 0.00199	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92711	 53609	 0.032532	 0.11391	 0.00315	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53610	 53611	 0.006983	 0.020589	 0.00479	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53611	 53612	 0.004605	 0.015796	 0.00378	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53611	 93825	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53611	 93825	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92803	 53612	 0.003498	 0.020491	 0.00558	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53612	 93826	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53612	 93826	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53613	 53645	 0.000626	 0.004718	 0.00131	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53613	 93827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53613	 93827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93820	 53614	 0.022066	 0.016235	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53615	 93828	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53615	 93828	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53616	 53621	 0.006618	 0.017013	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53616	 53828	 0.007337	 0.01624	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93821	 53616	 0.005304	 0.028487	 0.00068	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93827	 53617	 0.025121	 0.019033	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93828	 53618	 0.026078	 0.020441	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53619	 53621	 0.019135	 0.019327	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53620	 53653	 0.001494	 0.006323	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53620	 53661	 0.001524	 0.006103	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53620	 93829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53620	 93829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53620	 93870	 0.000518	 0.006518	 0.00202	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53622	 53623	 0.000726	 0.002853	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53622	 93830	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53622	 93830	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53622	 93870	 0.001583	 0.008835	 0.00226	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92808	 53624	 0.005442	 0.008686	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53625	 93831	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53625	 93831	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53626	 53639	 0.031199	 0.056294	 0.00081	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93831	 53626	 0.016483	 0.041918	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53627	 53628	 0.000977	 0.003186	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53628	 53633	 0.001292	 0.00431	 0.00109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92808	 53629	 0.023267	 0.018238	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53630	 53634	 0.001452	 0.005281	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53630	 93832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53630	 93832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53630	 93870	 0.001936	 0.009445	 0.00261	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53631	 53633	 0.001284	 0.003602	 0.00093	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53631	 93870	 0.003314	 0.007694	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53632	 93833	 0.013736	 0.008893	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53633	 93833	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53633	 93833	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53634	 53635	 0.000452	 0.001717	 0.00048	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53635	 53829	 0.001489	 0.00585	 0.00153	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53635	 93834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53635	 93834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53636	 53829	 0.001738	 0.007175	 0.0017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53636	 93835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53636	 93835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93835	 53637	 0.072133	 0.057086	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53638	 53641	 0.12248	 0.096008	 0.00123	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53638	 57045	 0.14912	 0.15063	 0.002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93835	 53638	 0.043805	 0.10064	 0.00153	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53639	 53640	 0.024361	 0.056558	 0.00084	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93763	 53640	 0.083406	 0.1505	 0.00218	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53642	 53643	 0.001433	 0.008065	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53642	 53648	 0.002275	 0.012452	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93790	 53643	 0.002935	 0.018045	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93827	 53644	 0.012456	 0.014911	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53645	 53652	 0.000875	 0.003503	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53645	 93836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53645	 93836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53646	 53647	 0.008532	 0.009385	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53646	 53648	 0.002683	 0.00823	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53646	 53650	 0.007464	 0.016931	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53648	 53689	 0.008344	 0.014904	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53649	 53650	 0.009936	 0.010929	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93836	 53651	 0.027815	 0.022012	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53652	 53653	 0.000701	 0.002807	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53653	 53655	 0.001007	 0.004033	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53653	 93837	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53653	 93837	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93837	 53654	 0.012733	 0.008243	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53655	 53656	 0.000646	 0.002588	 0.00065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53656	 53657	 0.000619	 0.002479	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53656	 53694	 0.001754	 0.005172	 0.0012	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53656	 93838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53656	 93838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53657	 53693	 0.001466	 0.00531	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53657	 53694	 0.000994	 0.002554	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53658	 93839	 0.012791	 0.014069	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53659	 53661	 0.001096	 0.00464	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53659	 93839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53659	 93839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53659	 93840	 0.002834	 0.011137	 0.00291	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93829	 53660	 0.018344	 0.013261	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53662	 53665	 0.019277	 0.021202	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53663	 93841	 0.015464	 0.027795	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53664	 53827	 0.001085	 0.012085	 0.11399	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53664	 53832	 0.000287	 0.003253	 0.02962	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53664	 93840	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53665	 53666	 0.003643	 0.009041	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93832	 53666	 0.010764	 0.027375	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53667	 53669	 0.003749	 0.013118	 0.00435	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53667	 57048	 0.03833	 0.11646	 0.02552	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93840	 53667	 0.000626	 0.005828	 0.00181	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53667	 93842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53667	 93842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53668	 53677	 0.004382	 0.017046	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93834	 53668	 0.005611	 0.025002	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53669	 93843	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53669	 93843	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53670	 53671	 0.013178	 0.014495	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53671	 53672	 0.018001	 0.012092	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93842	 53671	 0.009944	 0.025562	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53673	 53677	 0.018653	 0.033527	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53674	 53675	 0.007053	 0.014433	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53674	 53684	 0.015316	 0.025801	 0.00037	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53675	 53688	 0.013425	 0.034141	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93842	 53675	 0.00952	 0.040698	 0.00092	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53676	 53678	 0.004711	 0.013511	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53676	 93867	 0.00972	 0.032425	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53677	 53678	 0.011625	 0.022523	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53677	 53679	 0.024468	 0.017688	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93842	 53677	 0.008207	 0.035954	 0.00077	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93841	 53680	 0.012597	 0.02924	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53681	 53682	 0.029522	 0.023141	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53682	 53729	 0.008735	 0.025054	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93841	 53682	 0.010021	 0.048352	 0.00085	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53683	 57046	 0.06456	 0.14989	 0.00223	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93835	 53683	 0.018458	 0.099503	 0.00201	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53685	 53686	 0.047666	 0.030859	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53686	 53741	 0.015372	 0.025896	 0.00037	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53687	 53688	 0.028057	 0.049342	 0.00093	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53689	 53690	 0.001805	 0.00702	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53689	 93859	 0.009556	 0.022628	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53690	 53692	 0.002753	 0.010709	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53691	 53692	 0.005302	 0.010498	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53691	 93847	 0.026584	 0.02659	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53693	 53698	 0.00094	 0.003403	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53694	 93844	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53694	 93844	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53695	 53696	 0.004556	 0.011713	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53695	 53700	 0.024768	 0.025017	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53695	 93851	 0.003467	 0.013487	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53696	 53697	 0.002268	 0.008822	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93839	 53697	 0.00318	 0.012996	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53698	 53703	 0.001526	 0.004155	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53698	 93845	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53698	 93845	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53699	 53702	 0.00151	 0.009281	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93844	 53699	 0.005317	 0.026899	 0.00047	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93845	 53700	 0.004407	 0.014702	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53701	 53709	 0.017668	 0.013982	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53702	 93848	 0.008416	 0.01993	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53703	 53704	 0.001213	 0.003206	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53704	 53705	 0.000747	 0.002248	 0.0007	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53704	 93846	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53704	 93846	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53705	 53777	 0.001831	 0.011796	 0.00309	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53705	 53826	 0.00772	 0.019407	 0.00503	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53705	 93847	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53705	 93847	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93847	 53706	 0.007927	 0.020377	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53707	 53708	 0.004499	 0.010443	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53707	 53710	 0.003846	 0.013458	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53707	 53716	 0.012787	 0.016641	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53707	 93848	 0.005636	 0.018598	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53708	 53709	 0.004609	 0.013078	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93846	 53709	 0.003755	 0.014609	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53710	 53711	 0.006937	 0.015563	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53711	 53798	 0.008639	 0.019382	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53712	 53713	 0.00327	 0.009279	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53712	 53805	 0.004047	 0.009396	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53713	 53714	 0.002972	 0.011435	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53714	 93848	 0.004044	 0.022723	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53715	 53720	 0.00275	 0.007486	 0.00165	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53715	 53817	 0.016684	 0.044096	 0.01032	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93793	 53715	 0.006254	 0.038812	 0.0094	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53715	 93848	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53715	 93848	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53716	 93849	 0.004804	 0.009512	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53717	 53720	 0.003573	 0.009592	 0.00217	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53717	 53745	 0.00138	 0.003758	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53717	 53751	 0.003536	 0.009345	 0.00219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53717	 93849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53717	 93849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53718	 53752	 0.021576	 0.017075	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53718	 53753	 0.010531	 0.020851	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53718	 53757	 0.01021	 0.026245	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93848	 53718	 0.004761	 0.020978	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53718	 93850	 0.0024	 0.013483	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93848	 53719	 0.012605	 0.016404	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53719	 93850	 0.014229	 0.012161	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53720	 53721	 0.000869	 0.002424	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53720	 93850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53720	 93850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53721	 53726	 0.001203	 0.003924	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53722	 53725	 0.002616	 0.010474	 0.00264	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53722	 53726	 0.00117	 0.004013	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93840	 53722	 0.001246	 0.011597	 0.00359	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53722	 93851	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53722	 93851	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53723	 53738	 0.004427	 0.015489	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93841	 53723	 0.004339	 0.020826	 0.00062	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53724	 53733	 0.006353	 0.014529	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53724	 53747	 0.010936	 0.013742	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53724	 93852	 0.006292	 0.029336	 0.00068	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53725	 93852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53725	 93852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53727	 53744	 0.008259	 0.02123	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93852	 53727	 0.008322	 0.021392	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53728	 53729	 0.002904	 0.011869	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53728	 53743	 0.002271	 0.00928	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53729	 53740	 0.007157	 0.018398	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93843	 53730	 0.013108	 0.023652	 0.00034	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53731	 53741	 0.008126	 0.018866	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53731	 53744	 0.007298	 0.020933	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53732	 53733	 0.008275	 0.016383	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53732	 53736	 0.014309	 0.010528	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53733	 53734	 0.013706	 0.008873	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53733	 53760	 0.014749	 0.018771	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53735	 53736	 0.015027	 0.011892	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53735	 53744	 0.00655	 0.012544	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53737	 53739	 0.011794	 0.024238	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53737	 53764	 0.03492	 0.031506	 0.00053	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53737	 53771	 0.015501	 0.03069	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53737	 93857	 0.023508	 0.0757	 0.00129	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53738	 53740	 0.005096	 0.014462	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53739	 53741	 0.01538	 0.026499	 0.00042	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53741	 53742	 0.015367	 0.024528	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93843	 53741	 0.006245	 0.037954	 0.0007	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53742	 53770	 0.117	 0.075753	 0.00144	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53743	 53744	 0.003986	 0.010537	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53745	 93853	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53745	 93853	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53746	 53756	 0.015374	 0.012167	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53746	 53761	 0.00579	 0.011849	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53746	 93855	 0.005681	 0.021856	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53747	 53757	 0.00876	 0.016776	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53748	 53750	 0.00831	 0.016454	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53748	 53803	 0.031168	 0.024431	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53749	 53803	 0.008624	 0.017075	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53749	 93857	 0.00903	 0.023871	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93853	 53750	 0.011113	 0.017023	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53750	 93854	 0.00557	 0.014317	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53751	 53754	 0.000913	 0.003133	 0.00075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53751	 93854	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53751	 93854	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53753	 53756	 0.026865	 0.02126	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53754	 93855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53754	 93855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53754	 93856	 0.00073	 0.003805	 0.001	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53755	 53830	 0.002092	 0.01427	 0.02569	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53755	 93856	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93857	 53755	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53755	 93864	 0.00144	 0.012031	 0.02408	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53758	 53759	 0.019509	 0.015439	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53759	 53761	 0.005638	 0.011538	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93857	 53759	 0.007499	 0.026789	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53760	 53761	 0.003134	 0.015119	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53760	 53764	 0.007188	 0.017022	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53762	 53763	 0.031187	 0.061749	 0.00091	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53762	 53766	 0.021211	 0.027878	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53762	 53811	 0.018745	 0.034332	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93857	 53762	 0.007802	 0.026026	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93857	 53765	 0.023485	 0.06037	 0.00093	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53767	 53768	 0.01453	 0.033732	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53767	 56791	 0.027817	 0.051723	 0.00121	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53768	 53769	 0.11341	 0.089752	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53768	 93866	 0.030273	 0.10099	 0.0016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53771	 53831	 0.076202	 0.053979	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53772	 53777	 0.000874	 0.003399	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53772	 93858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53772	 93858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53773	 53774	 0.004219	 0.010685	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53773	 53776	 0.006197	 0.014674	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53773	 53823	 0.004257	 0.020775	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53774	 53781	 0.007729	 0.01734	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53775	 93859	 0.008755	 0.008843	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53776	 93859	 0.003204	 0.008235	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53777	 93859	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53777	 93859	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53778	 53780	 0.012098	 0.009574	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53779	 53781	 0.013	 0.01019	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53780	 53788	 0.003443	 0.013393	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93859	 53780	 0.002579	 0.015854	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53781	 53782	 0.007742	 0.009853	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53781	 53787	 0.017438	 0.0138	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53783	 53794	 0.010615	 0.022662	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53784	 53786	 0.011202	 0.02218	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93847	 53785	 0.005704	 0.011292	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53786	 53790	 0.03047	 0.022418	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93847	 53788	 0.013763	 0.019537	 0.00032	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53789	 53792	 0.022679	 0.017948	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53791	 53792	 0.016676	 0.013071	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53792	 53794	 0.006941	 0.017841	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53793	 93869	 0.023691	 0.021822	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53794	 93869	 0.005913	 0.020689	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53795	 53801	 0.026579	 0.020834	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53795	 53802	 0.007441	 0.014733	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53795	 53804	 0.033039	 0.026147	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53795	 53806	 0.007938	 0.018429	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53795	 93863	 0.007318	 0.041601	 0.00075	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53796	 53808	 0.013667	 0.024565	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53797	 53799	 0.009121	 0.010032	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53798	 53799	 0.005533	 0.016654	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53799	 93863	 0.002671	 0.013509	 0.00024	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53800	 93863	 0.018738	 0.018743	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53803	 93863	 0.034367	 0.072231	 0.00132	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53805	 53806	 0.005553	 0.012892	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53807	 53808	 0.007135	 0.018341	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53808	 53810	 0.017962	 0.046174	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53808	 53820	 0.023017	 0.025316	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53808	 93863	 0.016147	 0.041064	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53809	 53813	 0.035322	 0.03885	 0.00052	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53809	 53818	 0.016732	 0.03019	 0.00044	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53812	 53814	 0.014963	 0.020853	 0.00036	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53812	 53816	 0.023911	 0.023917	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53815	 53817	 0.000993	 0.003476	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53815	 93865	 0.00432	 0.017295	 0.00436	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53816	 93860	 0.008648	 0.013803	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53817	 93860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53817	 93860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53819	 53820	 0.005444	 0.014391	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93860	 53819	 0.004948	 0.019036	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93796	 53821	 0.030573	 0.093891	 0.00176	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93860	 53821	 0.011327	 0.028807	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93792	 53822	 0.005435	 0.013971	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93806	 53823	 0.004416	 0.021196	 0.00063	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53824	 93861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53824	 93861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92624	 53825	 0.004016	 0.034206	 0.00854	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53825	 93862	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53825	 93862	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53826	 93863	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53826	 93863	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53826	 93868	 0.00117	 0.0094	 0.00264	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53827	 93864	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93830	 53828	 0.004416	 0.010253	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53829	 93867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53829	 93867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53830	 93868	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93869	 53830	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53832	 93870	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53832	 93870	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92625	 53833	 0.024501	 0.063619	 0.01544	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53833	 93871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53833	 93871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53834	 54296	 0.10322	 0.16559	 0.00306	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93871	 53834	 0.10706	 0.27527	 0.00426	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53835	 56598	 0.020723	 0.10061	 0.02301	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92701	 53835	 0.01023	 0.058784	 0.01665	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53836	 53837	 0.062325	 0.1447	 0.00215	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53836	 95024	 0.041751	 0.18955	 0.00411	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53837	 53838	 0.094465	 0.095416	 0.00126	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53837	 53840	 0.10446	 0.1885	 0.00273	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53838	 53841	 0.13363	 0.13403	 0.00217	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53839	 55578	 0.015227	 0.077797	 0.01958	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92742	 53839	 0.034724	 0.091804	 0.0215	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53839	 93872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53839	 93872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53840	 53842	 0.018383	 0.11172	 0.00206	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93872	 53840	 0.021668	 0.12317	 0.00223	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92840	 53841	 0.062128	 0.081656	 0.00112	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53842	 94014	 0.040802	 0.2293	 0.00425	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53843	 53847	 0.009221	 0.018256	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53844	 53850	 0.00567	 0.020531	 0.0044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53844	 53852	 0.001383	 0.008909	 0.00234	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53845	 53848	 0.01626	 0.032194	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53846	 53848	 0.027693	 0.017929	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53847	 53848	 0.010745	 0.027622	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53848	 93873	 0.009428	 0.03301	 0.00091	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53849	 93873	 0.01868	 0.044235	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53850	 53852	 0.00612	 0.024904	 0.00607	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53850	 93873	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53850	 93873	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53850	 93874	 0.005372	 0.040258	 0.00982	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93873	 53851	 0.015134	 0.03513	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93873	 53853	 0.033186	 0.058362	 0.0011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53854	 53859	 0.004538	 0.03063	 0.05642	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53854	 93874	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53854	 93874	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53855	 53856	 0.084258	 0.066682	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53855	 93952	 0.10802	 0.22203	 0.00423	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53856	 54092	 0.31573	 0.20449	 0.00389	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53857	 53860	 0.008917	 0.042203	 0.01015	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53857	 93875	 0.005455	 0.025439	 0.0063	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53858	 53859	 0.00274	 0.017786	 0.03543	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53858	 93875	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53858	 93875	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53859	 93876	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53859	 93876	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53860	 57161	 0.01094	 0.048755	 0.01325	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53860	 93877	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53860	 93877	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53861	 55942	 0.03796	 0.030041	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53862	 53863	 0.004212	 0.010588	 0.00274	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53862	 53872	 0.004936	 0.013044	 0.00305	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53862	 93878	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53862	 93878	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53863	 53864	 0.003661	 0.01021	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53863	 53872	 0.004951	 0.012445	 0.00322	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53863	 55894	 0.007101	 0.020936	 0.00487	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53863	 93879	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53863	 93879	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53864	 53865	 0.004504	 0.011323	 0.00293	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53864	 55894	 0.003221	 0.011049	 0.00265	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53864	 93880	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53864	 93880	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53865	 55864	 0.001655	 0.011704	 0.00321	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53865	 93881	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53865	 93881	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53866	 94472	 0.013536	 0.034795	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53867	 53868	 0.00154	 0.013209	 0.00376	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53867	 93882	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53867	 93882	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53867	 94260	 0.001149	 0.014447	 0.00448	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53868	 55864	 0.002593	 0.014227	 0.00376	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93882	 53869	 0.021303	 0.054761	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53870	 53871	 0.022577	 0.017867	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93881	 53870	 0.008739	 0.029153	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93879	 53871	 0.030896	 0.047329	 0.00066	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53872	 53873	 0.002046	 0.009776	 0.00342	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53872	 93883	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53872	 93883	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53873	 53874	 0.005539	 0.019001	 0.00455	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53873	 53878	 0.003048	 0.010271	 0.00255	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53874	 93886	 0.004398	 0.014819	 0.00368	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53875	 53877	 0.001729	 0.005826	 0.00145	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53875	 93886	 0.002	 0.008706	 0.00248	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53876	 93884	 0.011656	 0.023078	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53876	 93885	 0.029536	 0.068572	 0.00102	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53877	 93884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53877	 93884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53878	 53879	 0.001859	 0.013371	 0.00354	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53878	 93885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53878	 93885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53879	 53883	 0.002288	 0.017143	 0.00418	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53880	 53881	 0.000217	 0.002411	 0.02274	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53880	 55890	 0.001038	 0.01198	 0.10505	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53880	 93886	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53880	 93886	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53882	 93887	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53883	 53884	 0.003872	 0.027623	 0.00856	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53884	 53887	 0.010966	 0.03762	 0.00901	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92665	 53884	 0.008263	 0.045345	 0.01199	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53885	 53892	 0.00033	 0.004365	 0.06992	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53885	 55375	 0.000401	 0.005178	 0.08692	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53885	 93889	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53885	 93889	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53886	 53888	 0.004723	 0.022921	 0.00524	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53886	 53890	 0.007005	 0.02403	 0.00576	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53886	 93890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53886	 93890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53887	 53888	 0.003767	 0.021641	 0.00613	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53887	 53889	 0.008132	 0.021833	 0.00495	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53888	 93894	 0.010622	 0.036438	 0.00873	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53889	 53896	 0.007967	 0.046275	 0.0109	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93887	 53889	 0.004405	 0.032201	 0.0095	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53890	 53894	 0.002644	 0.023425	 0.00624	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53890	 53896	 0.003662	 0.020185	 0.00472	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53891	 93892	 0.093413	 0.070774	 0.00097	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53892	 57027	 0.000329	 0.00414	 0.0631	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53892	 93891	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53892	 93891	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53893	 53894	 0.002104	 0.021614	 0.00684	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53893	 57028	 0.002341	 0.016853	 0.01407	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92751	 53893	 0.004826	 0.018776	 0.00501	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53894	 93892	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53894	 93892	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53895	 53904	 0.001167	 0.011487	 0.02448	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53895	 93893	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53895	 93893	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93893	 53896	 0.00814	 0.028771	 0.00648	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53896	 93894	 0.002751	 0.010811	 0.00283	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53897	 93894	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93895	 53897	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53897	 93896	 0.000256	 0.001765	 0.00312	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53898	 53899	 4.1e-05	 0.000674	 0.00656	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53898	 53900	 6.6e-05	 0.000802	 0.00709	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53898	 93896	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53898	 93896	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53899	 53910	 0.000325	 0.005159	 0.05417	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53900	 93897	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53900	 93897	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53901	 53902	 0.003186	 0.014195	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93895	 53901	 0.004677	 0.022568	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53902	 53905	 0.010699	 0.024469	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92787	 53903	 0.003119	 0.008945	 0.0022	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93886	 53903	 0.022215	 0.11167	 0.02908	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93894	 53903	 0.003436	 0.011578	 0.00288	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93897	 53903	 0.001292	 0.004352	 0.00108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53903	 93898	 0.001173	 0.004771	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92786	 53904	 0.000142	 0.001187	 0.0037	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93896	 53904	 0.000634	 0.004278	 0.00788	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53904	 93898	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53904	 93898	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92788	 53905	 0.031721	 0.070208	 0.00115	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53906	 93900	 0.017219	 0.075866	 0.00132	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53907	 93899	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93899	 53908	 0.000777	 0.005302	 0.00955	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53908	 93901	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53908	 93901	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92787	 53909	 0.008218	 0.023803	 0.00574	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93901	 53909	 0.003542	 0.014413	 0.00351	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53909	 93902	 0.002043	 0.035011	 0.01006	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53910	 93902	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53910	 93902	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53911	 53912	 0.001757	 0.012266	 0.02106	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53911	 53916	 0.000603	 0.006247	 0.01199	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92584	 53911	 0.00495	 0.044783	 0.08836	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53911	 93903	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53911	 93903	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53912	 55536	 0.001086	 0.01198	 0.02276	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53912	 56851	 0.004377	 0.044271	 0.10055	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53912	 93904	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53912	 93904	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53913	 57436	 0.022898	 0.077171	 0.01918	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93903	 53913	 0.011057	 0.036066	 0.00958	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53914	 93906	 0.0127	 0.029178	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53915	 53920	 0.005173	 0.020331	 0.00532	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53915	 53971	 0.009899	 0.040285	 0.00982	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53916	 93905	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53916	 93905	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53917	 53921	 0.000959	 0.003993	 0.00125	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93905	 53917	 0.001629	 0.009359	 0.00265	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53918	 53919	 0.000562	 0.004042	 0.00107	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93905	 53918	 0.000897	 0.006759	 0.00188	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53919	 53920	 0.000714	 0.004319	 0.0011	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53920	 53923	 0.001773	 0.004943	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53920	 93906	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53920	 93906	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53921	 53922	 0.00086	 0.003442	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53922	 53923	 0.001327	 0.004689	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53922	 53939	 0.001003	 0.0054	 0.00148	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93905	 53922	 0.002088	 0.012831	 0.00469	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53923	 53924	 0.001146	 0.005422	 0.0013	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53924	 53929	 0.000784	 0.003051	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53924	 53948	 0.0034	 0.009537	 0.00245	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53924	 93907	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53924	 93907	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93907	 53925	 0.009777	 0.015605	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53926	 53928	 0.001164	 0.003994	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53926	 53939	 0.001246	 0.006048	 0.00138	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53926	 53940	 0.005565	 0.014707	 0.00344	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53927	 93908	 0.017161	 0.013581	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53928	 53934	 0.00149	 0.004635	 0.00097	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53928	 53951	 0.00162	 0.003761	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53928	 93908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53928	 93908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53929	 53951	 0.000904	 0.0031	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53930	 53932	 0.001007	 0.003133	 0.00065	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53930	 53951	 0.000971	 0.003166	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53931	 53932	 0.001006	 0.002804	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53931	 53936	 0.00179	 0.004806	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53931	 93909	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53931	 93909	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93909	 53933	 0.016307	 0.012905	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53934	 53936	 0.003242	 0.008568	 0.00201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53935	 93910	 0.026647	 0.020439	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53936	 53940	 0.00238	 0.007018	 0.00163	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53936	 53942	 0.001702	 0.005678	 0.00144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53936	 93910	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53936	 93910	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53936	 93913	 0.005994	 0.015841	 0.00371	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93910	 53937	 0.008544	 0.016917	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53937	 93911	 0.023679	 0.018739	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53938	 93911	 0.018057	 0.013285	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53940	 53941	 0.002789	 0.009398	 0.00234	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53940	 93913	 0.005634	 0.014626	 0.00355	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93904	 53941	 0.004415	 0.031761	 0.00842	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53941	 93913	 0.003813	 0.013081	 0.00313	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53942	 53943	 0.001282	 0.003389	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53942	 93911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53942	 93911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53943	 93912	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53943	 93912	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93912	 53944	 0.012524	 0.019186	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53945	 53946	 0.000194	 0.003589	 0.03448	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53945	 93913	 0.000123	 0.009866	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53946	 53947	 0.000202	 0.003415	 0.03497	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53947	 55533	 0.000528	 0.008926	 0.09143	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93913	 53948	 0.010693	 0.02776	 0.00674	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53948	 93915	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53948	 93915	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53949	 53950	 0.076205	 0.060309	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53949	 53974	 0.14866	 0.16352	 0.00218	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93911	 53949	 0.015008	 0.038579	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53951	 93916	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53951	 93916	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93915	 53952	 0.033926	 0.024961	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53953	 57342	 0.067721	 0.23285	 0.05596	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53953	 93917	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53953	 93917	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93917	 53954	 0.029541	 0.023378	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53955	 57342	 0.10519	 0.27898	 0.06557	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53955	 57388	 0.086968	 0.23039	 0.05408	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53956	 94255	 0.57836	 0.375	 0.00714	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53957	 53958	 0.022573	 0.058612	 0.01423	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53957	 56546	 0.046464	 0.12482	 0.02831	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53958	 56731	 0.015517	 0.042249	 0.00931	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53959	 54312	 0.01051	 0.077671	 0.02243	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53959	 93918	 0.007517	 0.044028	 0.01199	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53959	 94190	 0.011806	 0.054168	 0.01388	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53960	 53969	 0.000475	 0.007874	 0.07381	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53960	 54126	 0.000878	 0.008292	 0.15615	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53960	 54126	 0.000878	 0.008292	 0.15615	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53960	 54311	 0.000996	 0.018152	 0.28148	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53960	 93918	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53961	 57088	 0.008828	 0.071672	 0.02283	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53961	 93926	 0.003136	 0.026898	 0.00765	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93919	 53962	 0.26649	 0.20446	 0.00274	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53963	 93923	 0.03085	 0.031159	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53964	 53968	 0.000146	 0.002105	 0.01931	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53964	 53969	 0.000167	 0.001771	 0.01847	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53964	 93920	 7.6e-05	 0.00606	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93921	 53964	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93920	 53965	 0.0003	 0.002024	 0.00373	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53965	 93922	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93923	 53965	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93922	 53966	 0.00087	 0.003992	 0.00102	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53966	 93924	 0.001465	 0.005963	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93921	 53967	 0.000847	 0.005125	 0.00131	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53967	 93924	 0.001384	 0.008373	 0.00214	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53968	 93924	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53969	 93926	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53969	 93926	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93925	 53970	 0.064261	 0.12724	 0.00187	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53971	 53973	 0.007878	 0.031543	 0.00795	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53972	 53973	 0.005178	 0.017447	 0.00434	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53972	 56847	 0.022589	 0.058554	 0.01772	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92598	 53973	 0.026491	 0.089285	 0.0222	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53973	 93927	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53973	 93927	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93927	 53974	 0.21083	 0.25709	 0.00412	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92597	 53975	 0.006864	 0.045806	 0.08641	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92621	 53975	 0.007963	 0.053776	 0.09914	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53975	 93928	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93929	 53975	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53976	 53978	 0.015267	 0.060014	 0.0157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53976	 56837	 0.009804	 0.064118	 0.01631	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53976	 58450	 0.013423	 0.043784	 0.01163	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53977	 56838	 0.011044	 0.04422	 0.01114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53978	 53979	 0.004239	 0.016112	 0.00451	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53978	 53982	 0.010188	 0.051193	 0.01332	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53980	 93930	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93931	 53980	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93931	 53981	 0.048644	 0.069055	 0.00114	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92625	 53982	 0.004252	 0.027388	 0.00718	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53983	 58087	 0.010986	 0.05332	 0.01219	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53984	 53988	 0.048525	 0.07071	 0.0016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53985	 53986	 0.1141	 0.076647	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53986	 53987	 0.021209	 0.040617	 0.00064	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53986	 53989	 0.023696	 0.12483	 0.00224	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53987	 53988	 0.025971	 0.034134	 0.00047	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53989	 94345	 0.043939	 0.11295	 0.00175	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53989	 94659	 0.066008	 0.16969	 0.00263	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53990	 53991	 0.1544	 0.1492	 0.00217	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53991	 55471	 0.17497	 0.29483	 0.0042	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53991	 94344	 0.058859	 0.26343	 0.00543	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53992	 53993	 0.000438	 0.002957	 0.00544	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92801	 53992	 0.000976	 0.006425	 0.01243	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92732	 53993	 0.002502	 0.017063	 0.03073	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53993	 93932	 0.000895	 0.005811	 0.01157	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53995	 93932	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93933	 53995	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92733	 53996	 0.004706	 0.040083	 0.01	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53997	 53999	 0.00045	 0.006978	 0.12013	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	53997	 93934	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53997	 93934	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53998	 57966	 0.004919	 0.0419	 0.01046	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93934	 53998	 0.004258	 0.032077	 0.0089	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53999	 55044	 0.000543	 0.009087	 0.16723	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53999	 93935	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53999	 93935	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54000	 54031	 0.056653	 0.14564	 0.00225	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54001	 93949	 0.10343	 0.081857	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54002	 54007	 0.002644	 0.009069	 0.00217	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54002	 54084	 0.001804	 0.008623	 0.00302	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54003	 54005	 0.009454	 0.025741	 0.00567	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54003	 56552	 0.008015	 0.027494	 0.00659	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54003	 93936	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54003	 93936	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54004	 93937	 0.056755	 0.11237	 0.00165	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54004	 93943	 0.073129	 0.047345	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54005	 54007	 0.003822	 0.0101	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54006	 93937	 0.015939	 0.02847	 0.00042	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54007	 54012	 0.0022	 0.005712	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54007	 54024	 0.00904	 0.030458	 0.00757	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92708	 54007	 0.020237	 0.12063	 0.03176	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54007	 93937	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54007	 93937	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93937	 54008	 0.007023	 0.014372	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54009	 54010	 0.018026	 0.01413	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54010	 93940	 0.006398	 0.012667	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54011	 56531	 0.001609	 0.022037	 0.22483	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54011	 93938	 0.000128	 0.010206	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54012	 54014	 0.000666	 0.002283	 0.00055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54012	 93940	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54012	 93940	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93940	 54013	 0.022156	 0.017534	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54014	 54015	 0.000888	 0.003047	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54015	 54016	 0.000928	 0.003279	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54016	 54017	 0.001047	 0.00365	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54016	 93941	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54016	 93941	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54017	 54021	 0.001688	 0.00799	 0.00192	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93938	 54017	 0.000617	 0.008249	 0.00226	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93939	 54018	 0.033214	 0.06576	 0.00097	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54019	 54020	 0.007593	 0.015034	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54019	 93942	 0.013807	 0.035492	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54021	 54038	 0.005905	 0.029115	 0.00787	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93938	 54021	 0.003159	 0.014953	 0.0036	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54021	 93942	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54021	 93942	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54022	 54023	 0.0055	 0.016555	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93939	 54022	 0.016734	 0.055825	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93941	 54022	 0.017173	 0.017345	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54023	 54028	 0.042191	 0.077278	 0.00133	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54024	 54025	 0.002158	 0.0052	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54024	 56511	 0.006729	 0.016914	 0.00438	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54024	 93943	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54024	 93943	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54025	 93944	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54025	 93944	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93944	 54026	 0.090678	 0.071763	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93937	 54027	 0.01918	 0.041101	 0.00072	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93944	 54028	 0.10115	 0.08005	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54029	 54030	 0.054404	 0.065127	 0.00108	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93942	 54029	 0.018767	 0.048243	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54031	 54032	 0.15778	 0.15938	 0.00211	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54031	 54035	 0.035315	 0.10129	 0.00156	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93939	 54031	 0.022553	 0.15482	 0.00282	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54033	 54034	 0.007634	 0.015115	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54033	 93947	 0.050269	 0.12785	 0.00202	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54035	 54036	 0.055091	 0.060594	 0.00081	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54035	 54082	 0.020875	 0.080313	 0.00137	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54035	 93945	 0.009432	 0.045973	 0.00086	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54037	 54040	 0.008164	 0.026181	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92815	 54037	 0.044752	 0.053572	 0.00089	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54038	 54039	 0.003077	 0.014114	 0.00362	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54039	 54071	 0.011511	 0.039489	 0.00946	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54039	 93945	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54039	 93945	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54040	 54041	 0.021476	 0.04252	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93945	 54040	 0.026895	 0.055039	 0.00135	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93945	 54041	 0.024041	 0.055806	 0.00106	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54042	 54047	 0.015166	 0.038988	 0.00965	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93938	 54042	 0.007053	 0.069449	 0.02871	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54042	 93946	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54042	 93946	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54043	 54053	 0.012992	 0.016127	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54044	 54082	 0.008321	 0.021391	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54045	 54082	 0.010902	 0.028025	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54046	 54083	 0.016284	 0.021402	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93938	 54047	 0.027889	 0.10855	 0.02902	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54047	 93947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54047	 93947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92815	 54048	 0.002878	 0.004717	 8e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54049	 54050	 0.004424	 0.019492	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54049	 54070	 0.003588	 0.020159	 0.00037	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54050	 54051	 0.004066	 0.008321	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54050	 54054	 0.005404	 0.013893	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54050	 54083	 0.008976	 0.023072	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54051	 54052	 0.004604	 0.011426	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54052	 54069	 0.003586	 0.009932	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54053	 54054	 0.014962	 0.024526	 0.00043	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54053	 54055	 0.008921	 0.020494	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54053	 54061	 0.00655	 0.015047	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93946	 54053	 0.009971	 0.025842	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54055	 54067	 0.005397	 0.013872	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54056	 54058	 0.005166	 0.01199	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93946	 54056	 0.006385	 0.016413	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54057	 54059	 0.011059	 0.008752	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54058	 54061	 0.016613	 0.013147	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54058	 54081	 0.006388	 0.013072	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54059	 54060	 0.004612	 0.010921	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54059	 54085	 0.011215	 0.021979	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93946	 54060	 0.010591	 0.026287	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54061	 54074	 0.019295	 0.019702	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54062	 54063	 0.0152	 0.011659	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54062	 54065	 0.007469	 0.014638	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54062	 54081	 0.006072	 0.015608	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54062	 54085	 0.031167	 0.02253	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54064	 54077	 0.02125	 0.016817	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54065	 54066	 0.010599	 0.008308	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54067	 54068	 0.002921	 0.007507	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92815	 54067	 0.007841	 0.03783	 0.00067	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54069	 93948	 0.003749	 0.011903	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92815	 54070	 0.001439	 0.007728	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54071	 93948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54071	 93948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54072	 54073	 0.002826	 0.01045	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93948	 54072	 0.003688	 0.012913	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54073	 54075	 0.004387	 0.011276	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54073	 54077	 0.006612	 0.011138	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54074	 54076	 0.01582	 0.01252	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54075	 54076	 0.004885	 0.012557	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54076	 54081	 0.006591	 0.01495	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93948	 54078	 0.009994	 0.006713	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54079	 54081	 0.023943	 0.061549	 0.00095	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93946	 54080	 0.04501	 0.11571	 0.00179	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93946	 54081	 0.009795	 0.043647	 0.00074	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93946	 54082	 0.027518	 0.07074	 0.00109	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93946	 54083	 0.027987	 0.040781	 0.00092	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93938	 54084	 0.001514	 0.008572	 0.00212	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54084	 93949	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54084	 93949	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54086	 54087	 0.00949	 0.033075	 0.00767	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54086	 58237	 0.005987	 0.032238	 0.00886	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54086	 93950	 0.00237	 0.013151	 0.004	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92609	 54087	 0.005654	 0.025937	 0.00664	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54087	 93950	 0.002934	 0.02075	 0.00569	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54087	 94289	 0.00263	 0.02649	 0.01625	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54088	 93950	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54088	 93950	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54089	 54090	 0.018548	 0.065571	 0.01478	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54089	 55480	 0.018869	 0.064739	 0.01551	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54089	 93951	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54089	 93951	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92633	 54090	 0.014103	 0.069556	 0.01881	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54091	 54094	 0.005102	 0.017782	 0.00412	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92697	 54091	 0.033202	 0.13719	 0.03249	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54091	 93952	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54091	 93952	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54092	 94904	 0.21243	 0.27928	 0.00383	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93952	 54093	 0.029305	 0.022478	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54094	 54096	 0.011885	 0.049483	 0.01543	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93875	 54094	 0.032458	 0.12347	 0.0346	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93876	 54094	 0.041107	 0.16011	 0.04283	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54094	 93953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54094	 93953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54095	 57018	 0.077774	 0.21546	 0.00356	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93953	 54095	 0.050519	 0.1449	 0.00223	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92697	 54096	 0.0134	 0.058333	 0.01662	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54097	 57162	 0.000509	 0.00567	 0.05347	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91274	 54097	 0.00463	 0.063388	 0.98092	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 0	 -30.0	 30.0;
	54098	 93954	 0.18387	 0.11905	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54099	 54887	 0.024276	 0.083301	 0.01996	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54099	 56830	 0.026538	 0.089445	 0.02224	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54099	 93954	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54099	 93954	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93954	 54100	 0.2011	 0.15427	 0.00207	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54100	 94357	 0.35343	 0.70081	 0.0103	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54100	 94798	 0.062792	 0.24432	 0.00408	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54100	 94995	 0.12193	 0.46766	 0.01324	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54101	 56862	 0.00117	 0.014123	 0.02973	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92660	 54101	 0.001462	 0.009492	 0.01891	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54101	 93955	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93956	 54101	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54102	 93957	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54102	 93957	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54103	 94815	 0.062264	 0.13294	 0.003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54104	 93958	 0.006265	 0.047196	 0.0131	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93957	 54105	 0.002098	 0.023983	 0.05646	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54105	 93958	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54105	 93958	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54105	 94771	 0.00276	 0.035656	 0.08084	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54106	 57464	 0.001498	 0.014974	 0.03097	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92705	 54106	 0.001022	 0.0109	 0.01975	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54106	 93959	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54106	 93959	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54107	 54110	 0.007116	 0.028491	 0.00718	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54107	 57547	 0.006289	 0.02885	 0.00739	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54107	 93960	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54107	 93960	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54108	 93961	 0.013181	 0.080106	 0.00148	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54109	 54112	 0.011451	 0.044546	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54109	 93961	 0.014705	 0.03414	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92706	 54110	 0.013928	 0.073781	 0.01871	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54110	 93961	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54110	 93961	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54111	 54112	 0.008081	 0.039434	 0.00068	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93959	 54111	 0.026344	 0.12646	 0.00378	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54112	 54114	 0.15149	 0.1199	 0.00151	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54113	 54115	 0.002098	 0.014554	 0.00415	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54113	 54116	 0.005583	 0.037411	 0.01146	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92706	 54115	 0.006614	 0.046781	 0.01284	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54116	 54117	 0.008403	 0.040781	 0.00932	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54116	 56596	 0.010657	 0.07668	 0.02033	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92706	 54116	 0.00697	 0.079699	 0.02432	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54118	 54119	 0.080543	 0.12921	 0.00239	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54118	 94358	 0.095095	 0.38076	 0.00804	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54119	 54343	 0.09569	 0.37241	 0.00622	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54119	 94360	 0.64634	 0.46798	 0.0071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54120	 54121	 0.009778	 0.034216	 0.01134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54120	 54122	 0.013411	 0.056768	 0.01278	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54121	 58401	 0.008882	 0.055197	 0.01558	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54121	 93962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54121	 93962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54122	 57095	 0.019332	 0.077419	 0.01951	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92760	 54122	 0.049298	 0.17446	 0.03938	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54123	 58563	 0.064879	 0.17169	 0.04025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54123	 93963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54123	 93963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54124	 57450	 0.10693	 0.28351	 0.00719	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54124	 93964	 0.069469	 0.24822	 0.00493	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54125	 58001	 0.00851	 0.077301	 0.0252	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92800	 54125	 0.003304	 0.038456	 0.01131	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54125	 93964	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54125	 93964	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54126	 93965	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54126	 93965	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93965	 54127	 0.19277	 0.13937	 0.00211	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93965	 54128	 0.31598	 0.25015	 0.00315	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54129	 54130	 0.008543	 0.032473	 0.00909	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54129	 55288	 0.007725	 0.038165	 0.01115	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54129	 93966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54129	 93966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54130	 54131	 0.013052	 0.033885	 0.00822	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54130	 93967	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54130	 93967	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54130	 93984	 0.0085	 0.041251	 0.00943	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54131	 54137	 0.005954	 0.028896	 0.00661	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54131	 55505	 0.005996	 0.033055	 0.00773	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54132	 54180	 0.008377	 0.045967	 0.01215	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54132	 55504	 0.006244	 0.038388	 0.01107	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54133	 54166	 0.048086	 0.038055	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54134	 54164	 0.008306	 0.030713	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54134	 93968	 0.005961	 0.026562	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54135	 54137	 0.006097	 0.022182	 0.00679	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54135	 54138	 0.004892	 0.023154	 0.00557	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54135	 93968	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54135	 93968	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93968	 54136	 0.009872	 0.032578	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54136	 93970	 0.057723	 0.097242	 0.00139	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54137	 93969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54137	 93969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54138	 54143	 0.001087	 0.004133	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54138	 54231	 0.00864	 0.024094	 0.00506	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54138	 54958	 0.002883	 0.01044	 0.00224	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54138	 93970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54138	 93970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54139	 54150	 0.012272	 0.022142	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54139	 93971	 0.009623	 0.026621	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54140	 54141	 0.006175	 0.014334	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54140	 54149	 0.003813	 0.010821	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54140	 54249	 0.025087	 0.031141	 0.00068	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54141	 54142	 0.007775	 0.019773	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54142	 55027	 0.009248	 0.018311	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54143	 54972	 0.012685	 0.043518	 0.01043	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54143	 93971	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54143	 93971	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54144	 54145	 0.006884	 0.017507	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54144	 55026	 0.008739	 0.017301	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54145	 54249	 0.010436	 0.029933	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54146	 54249	 0.021736	 0.017201	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54147	 54249	 0.018173	 0.014382	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54148	 54149	 0.004047	 0.01218	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54148	 54150	 0.002651	 0.011814	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54148	 54230	 0.004626	 0.022547	 0.00042	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54148	 54249	 0.007708	 0.025437	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54150	 54151	 0.004499	 0.015741	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54151	 54152	 0.005598	 0.014838	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54151	 54157	 0.019158	 0.044478	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54151	 54158	 0.041807	 0.033085	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54152	 93993	 0.004436	 0.019051	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54153	 54157	 0.010225	 0.026285	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54153	 54197	 0.007665	 0.023538	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54154	 54155	 0.006814	 0.017516	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54154	 54172	 0.007483	 0.024695	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54155	 54156	 0.018765	 0.018131	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54156	 54157	 0.013763	 0.018089	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54157	 54169	 0.028875	 0.022634	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54159	 54160	 0.033467	 0.022481	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54160	 54161	 0.023951	 0.018774	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93970	 54160	 0.015149	 0.024181	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54161	 54162	 0.025907	 0.016772	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54162	 54163	 0.011703	 0.017927	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54163	 54164	 0.011713	 0.0251	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54163	 54166	 0.014733	 0.037872	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54163	 54169	 0.019371	 0.018716	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54165	 54166	 0.009191	 0.021338	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54165	 54171	 0.015334	 0.020153	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54166	 54167	 0.010549	 0.02582	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54166	 93972	 0.013783	 0.049237	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54167	 93972	 0.011086	 0.028498	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54168	 54170	 0.008595	 0.017017	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54168	 54172	 0.008374	 0.021296	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54170	 54171	 0.021283	 0.016843	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54172	 54178	 0.003035	 0.015446	 0.00035	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54172	 93972	 0.010295	 0.034344	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54173	 54180	 0.002049	 0.012975	 0.00352	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54173	 93972	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54173	 93972	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54174	 54176	 0.032501	 0.023494	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93972	 54175	 0.012411	 0.024323	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93967	 54176	 0.013923	 0.076674	 0.00173	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54176	 93973	 0.015756	 0.05256	 0.00083	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54177	 93973	 0.013867	 0.025784	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54178	 54179	 0.003095	 0.016624	 0.00039	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54179	 93973	 0.00283	 0.01991	 0.0004	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54180	 93973	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54180	 93973	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54180	 93984	 0.001645	 0.012449	 0.00611	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54180	 94135	 0.033159	 0.083381	 0.02161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54181	 54199	 0.000117	 0.001481	 0.02587	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54181	 93974	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54181	 93974	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54182	 54183	 0.042746	 0.065483	 0.00092	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93967	 54182	 0.025895	 0.061318	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93974	 54183	 0.028985	 0.067294	 0.001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92785	 54184	 0.11219	 0.1234	 0.00165	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93966	 54184	 0.0528	 0.17615	 0.00279	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54185	 56622	 0.000295	 0.003996	 0.06088	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54185	 93975	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54185	 93975	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93975	 54186	 0.023045	 0.052944	 0.0008	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54186	 95003	 0.017958	 0.046163	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54187	 54193	 0.068489	 0.054202	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54187	 93980	 0.014174	 0.0329	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54188	 54189	 0.000104	 0.001796	 0.01773	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54188	 54809	 0.000594	 0.00686	 0.06014	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54188	 93976	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54189	 93979	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54190	 54787	 0.007708	 0.0285	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93980	 54190	 0.00546	 0.033564	 0.0006	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54191	 54203	 0.003407	 0.010044	 0.00234	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54191	 54277	 0.002316	 0.006013	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54192	 54203	 0.002027	 0.007969	 0.00208	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54192	 93982	 0.003836	 0.015078	 0.00394	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93978	 54194	 0.013094	 0.031007	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54195	 54278	 0.000143	 0.001853	 0.0042	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54195	 55503	 0.004002	 0.055111	 0.10997	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54195	 93981	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54195	 93981	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54196	 54278	 0.000393	 0.004551	 0.00872	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93976	 54196	 0.000332	 0.002539	 0.00944	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54196	 93982	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93983	 54196	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54196	 94061	 0.003278	 0.028835	 0.06017	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54197	 54207	 0.00724	 0.019138	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54197	 93989	 0.014077	 0.046454	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54198	 54208	 0.016154	 0.030037	 0.0007	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93973	 54198	 0.023999	 0.059567	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54199	 54200	 0.000123	 0.002123	 0.02096	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54199	 93984	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54199	 93984	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54200	 54202	 7.6e-05	 0.001023	 0.01559	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54200	 54204	 0.000118	 0.001358	 0.0119	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54200	 93985	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54200	 93985	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54201	 54280	 0.001734	 0.00716	 0.00169	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54201	 93986	 0.00097	 0.007377	 0.00232	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54201	 93988	 0.001416	 0.006377	 0.0017	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54202	 54204	 6.8e-05	 0.000784	 0.00687	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54202	 54206	 9.1e-05	 0.001053	 0.00923	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54202	 93986	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54202	 93986	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93985	 54203	 0.001397	 0.009368	 0.00226	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54203	 93988	 0.001749	 0.009317	 0.00261	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54204	 93987	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54204	 93987	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54205	 54231	 0.002008	 0.009898	 0.00268	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54205	 93988	 0.001486	 0.008153	 0.00216	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54206	 54847	 0.000661	 0.007721	 0.07344	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54206	 93988	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93989	 54207	 0.006698	 0.026057	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93987	 54208	 0.007981	 0.022648	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54209	 54219	 0.006526	 0.015973	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54209	 54226	 0.023049	 0.01768	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54209	 54273	 0.033263	 0.027378	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54209	 94002	 0.004516	 0.01757	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54210	 54227	 0.005125	 0.016913	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54210	 54241	 0.007901	 0.020311	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54211	 54213	 0.014501	 0.02656	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54211	 54234	 0.024479	 0.019372	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54212	 54241	 0.049473	 0.037949	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54212	 54256	 0.00717	 0.016647	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54212	 54271	 0.011977	 0.028362	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54213	 54214	 0.00729	 0.013021	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54213	 54220	 0.018768	 0.014853	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54213	 54227	 0.012808	 0.049826	 0.00083	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54213	 93997	 0.013919	 0.035257	 0.0007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54213	 94002	 0.005999	 0.03222	 0.00076	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54214	 54218	 0.017232	 0.026397	 0.00037	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54214	 93996	 0.006346	 0.015532	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54215	 54216	 0.013733	 0.012878	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54215	 54271	 0.006331	 0.016273	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54217	 54271	 0.020892	 0.016534	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54219	 54225	 0.003831	 0.009072	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54221	 54222	 0.000498	 0.002859	 0.00081	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54221	 54232	 0.000972	 0.004795	 0.0013	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54221	 93990	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54221	 93990	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54222	 54223	 0.000535	 0.003581	 0.0011	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54222	 54232	 0.00121	 0.006949	 0.00197	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93988	 54223	 0.000955	 0.00693	 0.00239	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54223	 93991	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54223	 93991	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54224	 54225	 0.003108	 0.00736	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54224	 54234	 0.009079	 0.014492	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93991	 54226	 0.013643	 0.014569	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54227	 54228	 0.007346	 0.017054	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54228	 93992	 0.006493	 0.016116	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54229	 54232	 0.000838	 0.004505	 0.00111	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54229	 54250	 0.001106	 0.004347	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54229	 93992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54229	 93992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54230	 93993	 0.002652	 0.016306	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54231	 54232	 0.001275	 0.005105	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54231	 93993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54231	 93993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54233	 54234	 0.023599	 0.018498	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93990	 54234	 0.021167	 0.022553	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54235	 54236	 0.008744	 0.019833	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54235	 54975	 0.008826	 0.015925	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54236	 54238	 0.020918	 0.017217	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54236	 54246	 0.005383	 0.014268	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54237	 54975	 0.006442	 0.013183	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54237	 93994	 0.009611	 0.019669	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54238	 93994	 0.009369	 0.016477	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54239	 93994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54239	 93994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54239	 94142	 0.005902	 0.030743	 0.00806	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54240	 54241	 0.007271	 0.013519	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54240	 54252	 0.005158	 0.013259	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54241	 54242	 0.007255	 0.010572	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54242	 54243	 0.012091	 0.008896	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54243	 54256	 0.032987	 0.030385	 0.00049	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54244	 54246	 0.009106	 0.021562	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54244	 54974	 0.021144	 0.014203	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54245	 54246	 0.025042	 0.019818	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54246	 54248	 0.007072	 0.021695	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54246	 54249	 0.015704	 0.042901	 0.00073	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93994	 54246	 0.077102	 0.060437	 0.00078	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54247	 54248	 0.01535	 0.009938	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54248	 93995	 0.003497	 0.012245	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54249	 93995	 0.001926	 0.010949	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54250	 93995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54250	 93995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54251	 54252	 0.003301	 0.006755	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93995	 54251	 0.004101	 0.010841	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54253	 54254	 0.003598	 0.011037	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54253	 54610	 0.008179	 0.020799	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54254	 54255	 0.003591	 0.016004	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54255	 54256	 0.008594	 0.024649	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54255	 54589	 0.007587	 0.015021	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54256	 54263	 0.008466	 0.015506	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54256	 54265	 0.019167	 0.012409	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54256	 54268	 0.006413	 0.031294	 0.00054	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54257	 54259	 0.003445	 0.011491	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54257	 54983	 0.00381	 0.010928	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54258	 54259	 0.015037	 0.016378	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54259	 54260	 0.007445	 0.008188	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93994	 54259	 0.003332	 0.016752	 0.00046	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54261	 54263	 0.012374	 0.009793	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54262	 54263	 0.008811	 0.006906	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54264	 54589	 0.020491	 0.013266	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54265	 54266	 0.009138	 0.007163	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54266	 54590	 0.011773	 0.009031	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54266	 54855	 0.007635	 0.019627	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54267	 54272	 0.001817	 0.007067	 0.00189	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54267	 54274	 0.001634	 0.011559	 0.00317	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54267	 93996	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54267	 93996	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54268	 54270	 0.003117	 0.012124	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54268	 54859	 0.014519	 0.031113	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54269	 54845	 0.014817	 0.024711	 0.00036	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54269	 54858	 0.009897	 0.025441	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54269	 93997	 0.006474	 0.025184	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93996	 54270	 0.004436	 0.015531	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93996	 54271	 0.004246	 0.026103	 0.00047	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54272	 54274	 0.000601	 0.00505	 0.0015	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54272	 54277	 0.001216	 0.008437	 0.00241	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93988	 54272	 0.008937	 0.024331	 0.00536	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54272	 93997	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54272	 93997	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54272	 94142	 0.007502	 0.027167	 0.00583	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54273	 54279	 0.018203	 0.014406	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93997	 54273	 0.004863	 0.016221	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54274	 54277	 0.000513	 0.005222	 0.00135	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54274	 93998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54274	 93998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54274	 94000	 0.001286	 0.008615	 0.00264	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93998	 54275	 0.031056	 0.024577	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54276	 54838	 0.001092	 0.005395	 0.00158	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54276	 93999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54276	 93999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54276	 94000	 0.000723	 0.004236	 0.00115	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93981	 54277	 0.001178	 0.007238	 0.00265	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54277	 94000	 0.0004	 0.004567	 0.00139	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54278	 54549	 0.003345	 0.023048	 0.04069	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54278	 94000	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94001	 54278	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54280	 94002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54280	 94002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54281	 55037	 0.26946	 0.49399	 0.00854	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54281	 58391	 0.20211	 0.3377	 0.00574	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54282	 54283	 0.35905	 0.23258	 0.00443	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93766	 54282	 0.086474	 0.21466	 0.00357	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54283	 56840	 0.30986	 0.3131	 0.00415	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54284	 54286	 0.072348	 0.16233	 0.00259	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54284	 94254	 0.081669	 0.17439	 0.00394	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92620	 54285	 0.13691	 0.27113	 0.00398	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54287	 54292	 0.021999	 0.02047	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54287	 94003	 0.012865	 0.025471	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54288	 54293	 0.02638	 0.019409	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54288	 54295	 0.037328	 0.026984	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54288	 94005	 0.028238	 0.047094	 0.00068	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54289	 54290	 0.000363	 0.002764	 0.00503	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92649	 54289	 0.002337	 0.015939	 0.0287	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54289	 94003	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54289	 94003	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54289	 94009	 0.001263	 0.008422	 0.01587	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54290	 54307	 0.001143	 0.007871	 0.01389	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54290	 94004	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94005	 54290	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54291	 55551	 0.002895	 0.007772	 0.00176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94004	 54291	 0.001575	 0.004088	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54292	 94347	 0.014028	 0.027774	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94003	 54293	 0.057105	 0.042014	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54293	 94006	 0.015302	 0.023441	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54294	 55546	 0.004954	 0.014208	 0.0035	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94004	 54294	 0.006901	 0.019245	 0.00404	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54294	 94006	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54294	 94006	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94006	 54295	 0.026783	 0.034855	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54295	 94010	 0.031758	 0.055439	 0.00086	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54296	 54298	 0.060445	 0.092597	 0.0013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54297	 54301	 0.074482	 0.058945	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54298	 54308	 0.11674	 0.17013	 0.00384	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54299	 54300	 0.11211	 0.088722	 0.00112	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54300	 54301	 0.059578	 0.10913	 0.00188	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54300	 54310	 0.053625	 0.13786	 0.00213	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54302	 54304	 0.043192	 0.11103	 0.00172	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54302	 54308	 0.034232	 0.087998	 0.00136	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54303	 54304	 0.054619	 0.081887	 0.00149	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54305	 56792	 0.084633	 0.15213	 0.00273	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93866	 54305	 0.040293	 0.082459	 0.00203	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54306	 94008	 0.013972	 0.075037	 0.00178	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92718	 54307	 0.00098	 0.009067	 0.01706	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93799	 54307	 0.003639	 0.024273	 0.04576	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54307	 94007	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94008	 54307	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54308	 94010	 0.025637	 0.11232	 0.00241	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54309	 94009	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92651	 54310	 0.015899	 0.096626	 0.00178	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54311	 55045	 0.000603	 0.006086	 0.10017	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54311	 55270	 0.000704	 0.006968	 0.11929	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54311	 55270	 0.000704	 0.006968	 0.11929	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54311	 94011	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54311	 94011	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54312	 54313	 0.0028	 0.017733	 0.00481	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54313	 55579	 0.014243	 0.12436	 0.03419	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54313	 94012	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54313	 94012	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94012	 54314	 0.31848	 0.24138	 0.00332	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54315	 57053	 0.030955	 0.12402	 0.03127	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54315	 58000	 0.024658	 0.098762	 0.02489	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54316	 54320	 0.027789	 0.12383	 0.0021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54316	 55487	 0.066248	 0.16782	 0.00332	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93406	 54316	 0.040752	 0.13069	 0.00323	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54317	 54318	 0.011593	 0.040566	 0.01345	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54317	 57092	 0.012905	 0.050725	 0.01327	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54318	 94013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54318	 94013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54318	 94163	 0.028448	 0.11583	 0.02824	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54319	 54320	 0.006125	 0.020434	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54319	 54323	 0.019616	 0.056262	 0.00087	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94013	 54319	 0.011226	 0.031855	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54321	 54323	 0.050308	 0.11412	 0.00228	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54321	 54891	 0.09855	 0.22644	 0.00344	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54322	 54906	 0.067664	 0.15546	 0.00236	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94013	 54322	 0.066003	 0.18932	 0.00291	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54324	 54327	 0.005459	 0.015224	 0.0032	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54324	 94014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54324	 94014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54325	 54328	 0.009849	 0.039418	 0.01332	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54325	 55579	 0.012592	 0.078161	 0.01894	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54325	 94015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54325	 94015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54326	 94016	 0.027102	 0.05366	 0.00079	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54327	 54328	 0.004873	 0.022354	 0.00573	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54327	 54329	 0.004452	 0.019839	 0.00539	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54327	 57005	 0.020705	 0.074988	 0.01609	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54327	 94016	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54327	 94016	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54329	 54342	 0.009333	 0.045295	 0.01036	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54330	 54331	 0.023843	 0.018689	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54330	 54333	 0.053668	 0.03605	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93788	 54330	 0.020188	 0.046861	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54332	 54338	 0.013276	 0.030819	 0.00939	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54332	 54342	 0.00705	 0.034213	 0.00782	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93787	 54332	 0.000791	 0.004496	 0.0013	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54334	 54341	 0.019283	 0.014187	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54335	 54336	 0.010459	 0.058851	 0.00127	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54335	 54337	 0.004865	 0.017379	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54335	 54341	 0.013687	 0.039256	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94015	 54336	 0.039241	 0.18839	 0.00563	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54337	 94017	 0.005135	 0.019754	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54338	 56835	 0.003514	 0.014067	 0.00354	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54338	 94017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54338	 94017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54339	 54341	 0.021199	 0.03825	 0.00055	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94017	 54339	 0.012544	 0.029123	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54340	 54341	 0.028686	 0.022702	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54343	 94907	 0.092015	 0.44928	 0.00776	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92638	 54344	 0.03563	 0.095693	 0.0217	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54344	 95260	 0.040286	 0.11239	 0.02361	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54345	 58258	 0.050199	 0.2442	 0.05601	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54345	 94973	 0.033057	 0.19727	 0.05203	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54346	 54347	 0.00916	 0.046024	 0.01198	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92746	 54346	 0.010987	 0.052372	 0.01517	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54347	 54348	 0.008397	 0.03554	 0.008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54347	 55300	 0.024377	 0.095847	 0.02509	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54347	 55460	 0.02985	 0.11959	 0.03015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54347	 56954	 0.019256	 0.074933	 0.02002	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54348	 56954	 0.011606	 0.045155	 0.01206	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54349	 56608	 0.5074	 0.877	 0.0133	 59.0	 59.0	 59.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54349	 57426	 0.877	 1.27	 0.019	 42.0	 42.0	 42.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54350	 94654	 0.030971	 0.1178	 0.03301	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54351	 57507	 0.35814	 0.62605	 0.00971	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54351	 94655	 0.12219	 0.28374	 0.00422	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54352	 54372	 0.001218	 0.004877	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54352	 54374	 0.001654	 0.003986	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54352	 94018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54352	 94018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54353	 54354	 0.011719	 0.009274	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54353	 54472	 0.016269	 0.021172	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54354	 94019	 0.011083	 0.011194	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54355	 54366	 0.00143	 0.003778	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54355	 54369	 0.000763	 0.002617	 0.00063	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54355	 94019	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54355	 94019	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54356	 54365	 0.00317	 0.008379	 0.00196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54356	 54367	 0.004124	 0.011072	 0.00251	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54356	 94020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54356	 94020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54356	 94062	 0.001931	 0.008174	 0.00184	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54356	 94152	 0.004228	 0.011173	 0.00262	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94020	 54357	 0.007811	 0.010165	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54358	 54362	 0.008258	 0.012088	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94020	 54358	 0.004706	 0.009318	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54359	 54513	 0.000106	 0.001228	 0.01076	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54359	 54817	 0.00057	 0.00662	 0.06358	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54359	 94021	 0.000119	 0.009523	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94022	 54359	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54360	 54363	 0.010128	 0.008015	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54360	 54386	 0.008756	 0.010482	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54360	 54387	 0.006431	 0.013729	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94020	 54360	 0.005227	 0.017436	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54361	 54869	 0.017692	 0.014001	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94020	 54361	 0.009827	 0.019456	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54361	 94024	 0.046463	 0.03677	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54362	 54869	 0.016965	 0.013298	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54363	 54364	 0.008612	 0.009175	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54364	 94024	 0.007517	 0.014732	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54365	 54367	 0.000756	 0.002671	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54365	 94023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54365	 94023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54366	 94024	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54366	 94024	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54367	 54370	 0.001263	 0.003339	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54367	 54380	 0.000735	 0.00256	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54367	 94025	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54367	 94025	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94025	 54368	 0.011143	 0.007893	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54368	 94026	 0.003426	 0.004993	 0.00011	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54369	 54370	 0.000483	 0.001628	 0.0004	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54370	 54371	 0.000563	 0.002324	 0.00055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54370	 94026	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54370	 94026	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54371	 54372	 0.000644	 0.002332	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54371	 54378	 0.000877	 0.002586	 0.0006	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54372	 94027	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54372	 94027	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54373	 54374	 0.00054	 0.002286	 0.00051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54373	 54550	 0.000514	 0.002614	 0.00095	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54373	 94028	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54373	 94028	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54374	 54375	 0.000377	 0.001482	 0.00039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54375	 54376	 0.000583	 0.002218	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54375	 94029	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54375	 94029	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54376	 54378	 0.000543	 0.0023	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54377	 54378	 0.000822	 0.002065	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54377	 54381	 0.000423	 0.002432	 0.00069	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54377	 54391	 0.000342	 0.002238	 0.00057	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54378	 94030	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54378	 94030	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54379	 54390	 0.003707	 0.011158	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94030	 54379	 0.003762	 0.016576	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54380	 54381	 0.000189	 0.001016	 0.00028	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54380	 94031	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54380	 94031	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54382	 54384	 0.004109	 0.008135	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94031	 54382	 0.002513	 0.012126	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54383	 54385	 0.010201	 0.007996	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54384	 54386	 0.001933	 0.006379	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94023	 54384	 0.004985	 0.010201	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54385	 54386	 0.010785	 0.006982	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54387	 54389	 0.005499	 0.010778	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54388	 54403	 0.004835	 0.010322	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54388	 94150	 0.006128	 0.027308	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54389	 54395	 0.006114	 0.006659	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54390	 94150	 0.011798	 0.023359	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54391	 54392	 0.000573	 0.003442	 0.00104	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54391	 94032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54391	 94032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54392	 94033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54392	 94033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54392	 94074	 0.001835	 0.014056	 0.00377	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54393	 54399	 0.000767	 0.003881	 0.00108	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54393	 54475	 0.000997	 0.005494	 0.00128	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54393	 94034	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54393	 94034	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94034	 54394	 0.017064	 0.012928	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54395	 94150	 0.013341	 0.013475	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54396	 54397	 0.000416	 0.00432	 0.00134	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54396	 54875	 0.000552	 0.004079	 0.00118	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54397	 54398	 0.000223	 0.001946	 0.00053	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54397	 94035	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54397	 94035	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54398	 54399	 0.000571	 0.002622	 0.00067	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54398	 54400	 0.001028	 0.002477	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54400	 54401	 0.000741	 0.003016	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54400	 54538	 0.000555	 0.005333	 0.00155	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54401	 54477	 0.001386	 0.005865	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54402	 54410	 0.006565	 0.013434	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54402	 54485	 0.006109	 0.015704	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54402	 94150	 0.005414	 0.024123	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54403	 54406	 0.01237	 0.014808	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54403	 54409	 0.011646	 0.014633	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54404	 54406	 0.00517	 0.009327	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54404	 54408	 0.011982	 0.009078	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54404	 54433	 0.017168	 0.017172	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54405	 54406	 0.007935	 0.014263	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54405	 54515	 0.003193	 0.01242	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54405	 54876	 0.012036	 0.025296	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54407	 54415	 0.008004	 0.013349	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54407	 54433	 0.004331	 0.011133	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54407	 94065	 0.012566	 0.03859	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54409	 54410	 0.010372	 0.013631	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54409	 54412	 0.004771	 0.009446	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54410	 54411	 0.020433	 0.013228	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54410	 54416	 0.011846	 0.016147	 0.00036	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54412	 54413	 0.005188	 0.010662	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54413	 54414	 0.004035	 0.007502	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54414	 54415	 0.005164	 0.011863	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54415	 54428	 0.004383	 0.010175	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54415	 54429	 0.004395	 0.01466	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54416	 54417	 0.006751	 0.016525	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54416	 54418	 0.018914	 0.019104	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54417	 54483	 0.002414	 0.007405	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54418	 94037	 0.011892	 0.019861	 0.00034	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54419	 54484	 0.009253	 0.018321	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54419	 94036	 0.010568	 0.010791	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54420	 54421	 0.000796	 0.00268	 0.00067	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54420	 54423	 0.001625	 0.005575	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54420	 54481	 0.001598	 0.006398	 0.00161	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54420	 54738	 0.003952	 0.013773	 0.00319	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54420	 94036	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54420	 94036	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54421	 54423	 0.000849	 0.002861	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54422	 54426	 0.019734	 0.015468	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54423	 54528	 0.002886	 0.011916	 0.00282	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54423	 94037	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54423	 94037	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54424	 54426	 0.007312	 0.013596	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54424	 54529	 0.008477	 0.018165	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54425	 54427	 0.0086	 0.014487	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54426	 94067	 0.002054	 0.011558	 0.00025	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94037	 54427	 0.039639	 0.032626	 0.00066	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54427	 94039	 0.010436	 0.030687	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54428	 94067	 0.00636	 0.014765	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54429	 94038	 0.003119	 0.013899	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54430	 54431	 0.000842	 0.002415	 0.00059	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54430	 54432	 0.001427	 0.004002	 0.00103	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54430	 54521	 0.001223	 0.004895	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54430	 94038	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54430	 94038	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54431	 54525	 0.001291	 0.003244	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54431	 94039	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54431	 94039	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54431	 94064	 0.006037	 0.015956	 0.00373	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54432	 54519	 0.001926	 0.00495	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54432	 94040	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54432	 94040	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54433	 54434	 0.013728	 0.010864	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54435	 54439	 0.005308	 0.017708	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54435	 94041	 0.003149	 0.010392	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94022	 54436	 0.000989	 0.005242	 0.00175	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54436	 94041	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54436	 94041	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54436	 94152	 0.001255	 0.005109	 0.00124	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54437	 54438	 0.004733	 0.009372	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54437	 94153	 0.004602	 0.023932	 0.00052	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54438	 94058	 0.005083	 0.011249	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54439	 54443	 0.012285	 0.029091	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54439	 54865	 0.014732	 0.016204	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54440	 54877	 0.007289	 0.020907	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54440	 94153	 0.005993	 0.016579	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54441	 54443	 0.01799	 0.017602	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54441	 54579	 0.008936	 0.017513	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54441	 54877	 0.007271	 0.01869	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54442	 54444	 0.023738	 0.018786	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54442	 54577	 0.024333	 0.016345	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54443	 54578	 0.011831	 0.017943	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54444	 54445	 0.008594	 0.016843	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54444	 54865	 0.009104	 0.016363	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54445	 54457	 0.003835	 0.011544	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54446	 54447	 0.008304	 0.014926	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54446	 94143	 0.009969	 0.023142	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54447	 54449	 0.007221	 0.018563	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54447	 54575	 0.005528	 0.016639	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54448	 54450	 0.003526	 0.012095	 0.0029	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54448	 54470	 0.001804	 0.006313	 0.00209	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54448	 94042	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54448	 94042	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54448	 94137	 0.003639	 0.015024	 0.00355	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54449	 94043	 0.004372	 0.017006	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54450	 94043	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54450	 94043	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54450	 94137	 0.000818	 0.00653	 0.00161	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54450	 94142	 0.00218	 0.010578	 0.00242	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54451	 54452	 0.00363	 0.01412	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54451	 54459	 0.015559	 0.016947	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54451	 54460	 0.00264	 0.011632	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54452	 54455	 0.022262	 0.017618	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54452	 54457	 0.002384	 0.00917	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54453	 54454	 0.004713	 0.003051	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54453	 54455	 0.001321	 0.004625	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54453	 54457	 0.008127	 0.015928	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54453	 54468	 0.003777	 0.007402	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54453	 54469	 0.00653	 0.012341	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94042	 54453	 0.004403	 0.016939	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54455	 54456	 0.003351	 0.006634	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94042	 54455	 0.004972	 0.01278	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54456	 54459	 0.003483	 0.010241	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54457	 54574	 0.006833	 0.0097	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54458	 54575	 0.012431	 0.009838	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54459	 54461	 0.011908	 0.009423	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54459	 54568	 0.004967	 0.016571	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94043	 54460	 0.00221	 0.009227	 0.00027	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54462	 54568	 0.011712	 0.008467	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54463	 54464	 0.00695	 0.010127	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94042	 54463	 0.00421	 0.012929	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54464	 94044	 0.014842	 0.009609	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54465	 54469	 0.002818	 0.007996	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54465	 54862	 0.003946	 0.007812	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54466	 54469	 0.004934	 0.009768	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54466	 94044	 0.002299	 0.00591	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54467	 54468	 0.007826	 0.006193	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54467	 54469	 0.010627	 0.007682	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54470	 54471	 0.000648	 0.001858	 0.00046	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54470	 94044	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54470	 94044	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54471	 54863	 0.001061	 0.002959	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94042	 54472	 0.008732	 0.029131	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54473	 54474	 0.007179	 0.023947	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94018	 54473	 0.003733	 0.02005	 0.00048	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54473	 94076	 0.006717	 0.029932	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54474	 94080	 0.005112	 0.019886	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54475	 94045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54475	 94045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54475	 94074	 0.001764	 0.008092	 0.00207	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54476	 54548	 0.005367	 0.01879	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54476	 94048	 0.003346	 0.013968	 0.0004	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54477	 94046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54477	 94046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54477	 94062	 0.012857	 0.033052	 0.00818	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94046	 54478	 0.014765	 0.010674	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94046	 54479	 0.011448	 0.029427	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54479	 94047	 0.019615	 0.019619	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54480	 54484	 0.006683	 0.008295	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54480	 94047	 0.004814	 0.009532	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54481	 54482	 0.000344	 0.002509	 0.00064	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54481	 94047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54481	 94047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54482	 54537	 0.000488	 0.003453	 0.00095	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54483	 54484	 0.002349	 0.009939	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94046	 54484	 0.009143	 0.024169	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54486	 54487	 0.000463	 0.00445	 0.00129	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54486	 54492	 0.003769	 0.00996	 0.00233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54486	 94048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54486	 94048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54486	 94072	 0.000297	 0.003972	 0.00109	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54486	 94074	 0.002593	 0.007645	 0.00178	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54487	 54489	 0.001245	 0.003472	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54487	 54538	 0.000801	 0.007654	 0.00281	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54488	 94050	 0.024726	 0.018192	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54489	 54490	 0.000798	 0.001851	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54490	 54493	 0.00069	 0.00285	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54490	 54495	 0.001579	 0.006144	 0.00164	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54491	 54544	 0.013156	 0.023646	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54491	 94049	 0.009605	 0.015408	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54492	 54493	 0.000873	 0.004123	 0.00132	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54492	 54543	 0.000833	 0.006242	 0.00152	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54492	 94049	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54492	 94049	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54493	 94050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54493	 94050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54494	 94051	 0.021865	 0.020505	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54495	 54539	 0.001884	 0.004979	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54495	 54873	 0.002837	 0.010785	 0.00302	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54495	 94051	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54495	 94051	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54496	 54509	 0.000263	 0.00186	 0.00051	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54496	 94052	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54496	 94052	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54496	 94152	 0.000594	 0.006787	 0.00207	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94052	 54497	 0.012058	 0.009452	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94052	 54498	 0.009892	 0.019586	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54498	 94055	 0.008896	 0.017614	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54499	 54579	 0.014205	 0.018669	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54499	 94053	 0.017945	 0.018125	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54500	 54576	 0.001493	 0.005977	 0.00151	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54500	 54617	 0.001077	 0.006617	 0.00242	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54500	 94053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54500	 94053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54501	 54502	 0.016235	 0.011736	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54502	 54506	 0.005255	 0.01179	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54502	 94055	 0.005651	 0.016035	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54503	 54504	 0.001511	 0.003993	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54503	 94054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54503	 94054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54504	 54509	 0.003607	 0.009068	 0.00235	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54504	 94055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54504	 94055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54505	 54617	 0.005854	 0.01547	 0.00362	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54505	 94056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54505	 94056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54505	 94059	 0.001711	 0.006849	 0.00231	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94056	 54506	 0.003863	 0.008968	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54507	 54508	 0.019738	 0.015621	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54507	 94057	 0.005365	 0.013792	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54509	 54511	 0.000512	 0.002229	 0.00064	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54510	 54511	 0.000547	 0.001877	 0.00045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54510	 94057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54510	 94057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54510	 94059	 0.002585	 0.007488	 0.00181	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54511	 94058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54511	 94058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54512	 54621	 0.000222	 0.002855	 0.02685	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54512	 54847	 0.000486	 0.007001	 0.06424	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54512	 57783	 0.000637	 0.007212	 0.06566	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54512	 94059	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54513	 57689	 0.001407	 0.015367	 0.15095	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54513	 94061	 8.6e-05	 0.006896	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54514	 54515	 0.003116	 0.012471	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94063	 54514	 0.005557	 0.022047	 0.00063	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54516	 54688	 0.000796	 0.005486	 0.00968	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94061	 54516	 0.00025	 0.003737	 0.00874	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54516	 94064	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94065	 54516	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54517	 54672	 0.012262	 0.028467	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94065	 54517	 0.003615	 0.016109	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54518	 54519	 0.002166	 0.005725	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54518	 94093	 0.002731	 0.008492	 0.00177	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94064	 54519	 0.001953	 0.00637	 0.00169	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92755	 54520	 0.008853	 0.006707	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92754	 54521	 0.001498	 0.006743	 0.00179	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54522	 54525	 0.001249	 0.005001	 0.00126	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92754	 54522	 0.001731	 0.009201	 0.00213	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54522	 94066	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54522	 94066	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94066	 54523	 0.015027	 0.029753	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54524	 54525	 0.001204	 0.003927	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54524	 94067	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54524	 94067	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54526	 54531	 0.006564	 0.014529	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54526	 94069	 0.006286	 0.020971	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54527	 54528	 0.000879	 0.003518	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54527	 54720	 0.004461	 0.016152	 0.00347	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54527	 94068	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54527	 94068	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54527	 94098	 0.000921	 0.00697	 0.00342	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54528	 94069	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54528	 94069	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54529	 54530	 0.00932	 0.016816	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94069	 54529	 0.010401	 0.024147	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94037	 54530	 0.006555	 0.016852	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54531	 54532	 0.028555	 0.022382	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54531	 54534	 0.011476	 0.020627	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54531	 54535	 0.011573	 0.033194	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54533	 54534	 0.011501	 0.009015	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54535	 54536	 0.003607	 0.015803	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54536	 94104	 0.003846	 0.020001	 0.00043	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54537	 54738	 0.001612	 0.006335	 0.00166	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54537	 54873	 0.001013	 0.00843	 0.00255	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54539	 94070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54539	 94070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54540	 54542	 0.027822	 0.027828	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54540	 94109	 0.016677	 0.041394	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54541	 54542	 0.011575	 0.022684	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54542	 94110	 0.007582	 0.033785	 0.00057	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54543	 54752	 0.000655	 0.005261	 0.00148	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54544	 94115	 0.007312	 0.032584	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54545	 54763	 0.000794	 0.003017	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54545	 94072	 0.000959	 0.00384	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54546	 54761	 4.8e-05	 0.00079	 0.00741	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54546	 54811	 0.000423	 0.004787	 0.04358	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54546	 94071	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54547	 54550	 0.000678	 0.003896	 0.0011	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54547	 54553	 0.000578	 0.003183	 0.00115	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94045	 54548	 0.006528	 0.01399	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94021	 54549	 0.001329	 0.014452	 0.03141	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94071	 54549	 0.0002	 0.001936	 0.00685	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54549	 94074	 0.000105	 0.008384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94075	 54549	 0.000321	 0.02569	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54551	 54552	 0.016961	 0.01098	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54552	 94076	 0.004037	 0.010267	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94074	 54553	 0.00052	 0.004541	 0.00125	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54553	 94076	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54553	 94076	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54554	 54555	 0.010972	 0.011951	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54554	 54556	 0.006082	 0.012445	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94075	 54555	 0.016767	 0.028245	 0.0004	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54556	 94077	 0.006758	 0.016003	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54557	 54561	 0.001219	 0.006352	 0.00167	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54557	 54777	 0.001769	 0.004549	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54557	 54778	 0.00073	 0.005253	 0.00139	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54557	 94077	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54557	 94077	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54558	 54813	 0.002873	 0.011054	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54558	 94079	 0.005354	 0.0123	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54559	 94078	 0.016684	 0.013203	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54560	 54778	 0.001067	 0.003662	 0.00088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54560	 54791	 0.000949	 0.002661	 0.00068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54560	 94078	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54560	 94078	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54561	 54563	 0.001152	 0.003951	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54561	 94079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54561	 94079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94079	 54562	 0.020624	 0.016321	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54563	 94080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54563	 94080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54563	 94135	 0.004094	 0.01082	 0.00253	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94080	 54564	 0.023918	 0.022429	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54565	 54566	 0.003587	 0.015179	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94042	 54565	 0.006311	 0.020827	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54566	 54571	 0.00244	 0.00935	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54567	 54571	 0.013695	 0.010838	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54568	 54569	 0.002512	 0.009663	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54569	 94138	 0.003685	 0.01798	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54570	 54571	 0.005507	 0.014559	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54570	 94136	 0.007405	 0.024704	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54571	 94136	 0.005969	 0.020885	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54572	 54575	 0.006719	 0.013303	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54572	 54577	 0.022765	 0.018016	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54573	 54574	 0.010059	 0.009075	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54573	 54575	 0.014452	 0.011437	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54576	 54585	 0.001814	 0.00506	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54576	 94142	 0.002554	 0.010219	 0.00345	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94053	 54578	 0.020274	 0.019013	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94055	 54579	 0.019609	 0.019805	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54580	 54589	 0.008771	 0.022305	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54580	 54855	 0.005169	 0.014826	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54581	 54591	 0.006289	 0.016166	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54581	 54593	 0.003889	 0.010757	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54581	 94145	 0.005137	 0.029202	 0.00053	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54582	 54584	 0.01791	 0.011595	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54583	 54595	 0.002696	 0.012493	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54583	 94081	 0.003276	 0.016386	 0.00029	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54584	 94081	 0.007838	 0.013785	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54585	 54857	 0.000734	 0.002856	 0.00076	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54585	 94081	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54585	 94081	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54586	 54592	 0.027571	 0.020285	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54587	 54595	 0.00639	 0.011154	 0.00017	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54587	 54598	 0.006418	 0.009831	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94053	 54587	 0.005832	 0.016728	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54588	 54592	 0.005818	 0.011401	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54588	 94085	 0.013501	 0.022426	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54589	 54591	 0.01113	 0.013569	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54592	 54593	 0.001919	 0.007465	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54593	 54594	 0.008514	 0.014343	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54594	 54595	 0.00341	 0.006978	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54595	 54596	 0.007345	 0.010013	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54596	 54597	 0.006602	 0.004435	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54599	 54600	 0.003719	 0.008545	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54599	 54602	 0.004284	 0.009945	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54600	 54603	 0.003351	 0.008613	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54600	 54614	 0.003528	 0.013723	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54600	 54619	 0.005756	 0.012334	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54601	 54622	 0.006264	 0.025079	 0.00632	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54601	 94082	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54601	 94082	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54601	 94086	 0.001275	 0.005103	 0.00129	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54602	 54606	 0.015296	 0.01259	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54602	 54618	 0.013331	 0.018579	 0.00032	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94082	 54602	 0.001305	 0.006954	 0.00012	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54603	 94151	 0.006569	 0.014077	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54604	 54605	 0.006479	 0.012828	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54604	 94083	 0.024159	 0.019119	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94082	 54605	 0.007085	 0.014892	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54607	 54878	 0.00451	 0.012279	 0.00271	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54607	 55007	 0.007045	 0.018618	 0.00436	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54607	 94083	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54607	 94083	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54607	 94086	 0.004293	 0.012312	 0.00303	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54608	 54963	 0.017976	 0.02998	 0.00044	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54608	 94151	 0.010006	 0.025722	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54609	 54986	 0.00786	 0.018613	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54609	 94151	 0.004995	 0.016664	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54610	 54984	 0.00508	 0.011617	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54610	 94084	 0.008082	 0.020775	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54610	 94151	 0.018972	 0.02355	 0.00051	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54611	 54617	 0.001974	 0.008031	 0.00196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54611	 54878	 0.002115	 0.006578	 0.00137	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54611	 94084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54611	 94084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54612	 54616	 0.014527	 0.009405	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94084	 54613	 0.003541	 0.008788	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54614	 54616	 0.004833	 0.00989	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54614	 94085	 0.0103	 0.02439	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94054	 54615	 0.021583	 0.015879	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54616	 94085	 0.005484	 0.012729	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54617	 94085	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54617	 94085	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54617	 94142	 0.00256	 0.021956	 0.00625	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54618	 94087	 0.010489	 0.024346	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54619	 54620	 0.005014	 0.01329	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94056	 54620	 0.00355	 0.015643	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54621	 57848	 0.00059	 0.00668	 0.06082	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54621	 94086	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54622	 94088	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54622	 94088	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54622	 95098	 0.004572	 0.03339	 0.00858	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54623	 54639	 0.01603	 0.012686	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54623	 54653	 0.004592	 0.011805	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54624	 54653	 0.00934	 0.007391	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54625	 54626	 0.013993	 0.01539	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54625	 54653	 0.006063	 0.012407	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54625	 94089	 0.00455	 0.017701	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54627	 54633	 0.010303	 0.024398	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54627	 54641	 0.005493	 0.015754	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54628	 54629	 0.016439	 0.021605	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54629	 54638	 0.017338	 0.013721	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94087	 54629	 0.011375	 0.026937	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54630	 54641	 0.010775	 0.027404	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54630	 55010	 0.018607	 0.024455	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94087	 54630	 0.020882	 0.042734	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54631	 54633	 0.036514	 0.023639	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54631	 54635	 0.010269	 0.020125	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94088	 54631	 0.012247	 0.031483	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54632	 54871	 0.011731	 0.029116	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94088	 54632	 0.022521	 0.067785	 0.00133	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54634	 54635	 0.007194	 0.017036	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54634	 54637	 0.002969	 0.00755	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54636	 54637	 0.005173	 0.013155	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94087	 54636	 0.008858	 0.023478	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54640	 54641	 0.004326	 0.010042	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54640	 55009	 0.004283	 0.012891	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94088	 54642	 0.008082	 0.014583	 0.00021	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54643	 54644	 0.018699	 0.014798	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54643	 54655	 0.01363	 0.026986	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54645	 54647	 0.019906	 0.015754	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54645	 54652	 0.005829	 0.009721	 0.00014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54646	 54648	 0.006761	 0.020741	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54646	 54667	 0.006427	 0.01492	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54646	 94148	 0.006555	 0.028882	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94060	 54648	 0.006749	 0.029737	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54649	 54650	 0.003717	 0.013278	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54649	 54652	 0.004731	 0.01357	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54650	 94089	 0.004163	 0.015951	 0.00045	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54651	 54652	 0.003516	 0.011731	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54651	 54656	 0.007302	 0.018771	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54652	 54665	 0.006174	 0.02402	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54653	 54654	 0.007771	 0.008548	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94088	 54655	 0.007569	 0.019456	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94088	 54656	 0.014985	 0.034789	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54657	 54661	 0.004939	 0.012801	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54657	 54678	 0.005774	 0.022215	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54658	 94089	 0.020755	 0.015004	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54659	 54674	 0.008576	 0.013382	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54659	 94089	 0.004611	 0.015752	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54660	 54872	 0.008708	 0.023377	 0.0053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54660	 94089	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54660	 94089	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54660	 95098	 0.00431	 0.017254	 0.00435	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94089	 54661	 0.004275	 0.007948	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54662	 54674	 0.012925	 0.014216	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54663	 54664	 0.014858	 0.013685	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54663	 54674	 0.005147	 0.012598	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54664	 54665	 0.020496	 0.013269	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54665	 54666	 0.00535	 0.008348	 0.00014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54665	 94148	 0.006464	 0.02776	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54666	 54670	 0.005087	 0.011635	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54667	 54668	 0.003844	 0.009103	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54668	 54669	 0.003507	 0.008056	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54668	 94148	 0.004359	 0.01677	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54669	 54671	 0.004408	 0.008196	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54670	 54676	 0.003722	 0.011204	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54671	 94090	 0.005604	 0.021559	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54672	 94090	 0.006782	 0.021534	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54673	 54675	 0.001732	 0.004451	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54673	 94090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54673	 94090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54673	 94093	 0.003251	 0.011152	 0.00267	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54674	 54676	 0.00378	 0.008952	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54675	 54679	 0.0022	 0.007545	 0.00181	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54675	 94091	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54675	 94091	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54676	 54677	 0.00285	 0.008174	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54676	 54680	 0.006592	 0.01561	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94091	 54677	 0.004391	 0.011638	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54678	 95099	 0.007464	 0.032885	 0.00057	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54679	 94092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54679	 94092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54679	 95098	 0.001048	 0.010891	 0.00337	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54680	 54681	 0.008402	 0.021597	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94092	 54681	 0.004974	 0.014265	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54682	 54685	 0.005053	 0.022611	 0.00047	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54682	 95099	 0.004703	 0.026422	 0.00049	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54683	 54684	 0.013899	 0.011	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54684	 54690	 0.008229	 0.021154	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54684	 95102	 0.004924	 0.019155	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54685	 54686	 0.011177	 0.020471	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94092	 54685	 0.051997	 0.037588	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54686	 54687	 0.017441	 0.019182	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54687	 54689	 0.009204	 0.023659	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54687	 94094	 0.00497	 0.021034	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92753	 54688	 0.00035	 0.003668	 0.0069	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54688	 94093	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94094	 54688	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54688	 95097	 0.001426	 0.009675	 0.01761	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54689	 94095	 0.0168	 0.048184	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54690	 54691	 0.012626	 0.009992	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54690	 54693	 0.006415	 0.014894	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92753	 54692	 0.001169	 0.007405	 0.01551	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54692	 94095	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54692	 94095	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54692	 95100	 0.000323	 0.002649	 0.00477	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54693	 54694	 0.007304	 0.009956	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54694	 54695	 0.011499	 0.022021	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54694	 54698	 0.014161	 0.015575	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54694	 54699	 0.005852	 0.015043	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94095	 54694	 0.004938	 0.017288	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54695	 54696	 0.011474	 0.00908	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54697	 54705	 0.017278	 0.039192	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54697	 54708	 0.034053	 0.079059	 0.00118	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94095	 54697	 0.005805	 0.03569	 0.00064	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54699	 54700	 0.004187	 0.010648	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54700	 54701	 0.022703	 0.016412	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54700	 54717	 0.012639	 0.041708	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94095	 54700	 0.017833	 0.045841	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54702	 54705	 0.012664	 0.017262	 0.00038	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54703	 54718	 0.027352	 0.037285	 0.00083	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54703	 57768	 0.02179	 0.040516	 0.00095	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54703	 57778	 0.008665	 0.038613	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54704	 54705	 0.010829	 0.015779	 0.00036	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54706	 54713	 0.01338	 0.027382	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94068	 54706	 0.008743	 0.020702	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54707	 94097	 0.01292	 0.01698	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54708	 94096	 0.006707	 0.026093	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54709	 54710	 0.001771	 0.004453	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54709	 54711	 0.000914	 0.003135	 0.00075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54709	 94096	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54709	 94096	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54710	 94097	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54710	 94097	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54711	 54737	 0.002698	 0.009771	 0.0021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54712	 54713	 0.006469	 0.016629	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54712	 54714	 0.007361	 0.01709	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54712	 54722	 0.010884	 0.011624	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94068	 54712	 0.010943	 0.02813	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54713	 54721	 0.006382	 0.018304	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54714	 54715	 0.00726	 0.016287	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54715	 54717	 0.015781	 0.033817	 0.00059	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94097	 54715	 0.00986	 0.022892	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54716	 94098	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54718	 54719	 0.041283	 0.041404	 0.00067	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54719	 94210	 0.024408	 0.074956	 0.00141	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54720	 54744	 0.006161	 0.015488	 0.00401	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54720	 94100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54720	 94100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54721	 54728	 0.027387	 0.021467	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54723	 54730	 0.023067	 0.018255	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54723	 94102	 0.014796	 0.019446	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54723	 94107	 0.013349	 0.027317	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54724	 54731	 0.001614	 0.004266	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54724	 54732	 0.001383	 0.003719	 0.00104	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54725	 54734	 0.01639	 0.031388	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94100	 54725	 0.02406	 0.061188	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54726	 94103	 0.018459	 0.014609	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54727	 54737	 0.001774	 0.007509	 0.00169	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54727	 55092	 0.003397	 0.015842	 0.00392	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54727	 94101	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54727	 94101	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54728	 54729	 0.026473	 0.026479	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54729	 94102	 0.013474	 0.024218	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94100	 54730	 0.035232	 0.027882	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54731	 94102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54731	 94102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54732	 54733	 0.001178	 0.004105	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54733	 55077	 0.003607	 0.00982	 0.00216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54733	 55078	 0.003744	 0.010071	 0.00282	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54734	 94204	 0.011935	 0.046429	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94101	 54735	 0.046618	 0.03532	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94097	 54736	 0.015785	 0.040576	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54737	 94103	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54737	 94103	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54738	 94104	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54738	 94104	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94104	 54739	 0.004474	 0.024117	 0.00049	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54739	 94107	 0.018125	 0.046094	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54739	 94108	 0.030415	 0.063925	 0.00116	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54740	 94105	 0.019389	 0.013734	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54741	 54743	 0.00198	 0.006791	 0.00163	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54741	 54744	 0.001363	 0.004261	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54741	 94105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54741	 94105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54742	 94106	 0.036795	 0.040077	 0.00055	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54742	 94205	 0.033696	 0.056197	 0.00082	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54743	 54746	 0.006181	 0.023496	 0.00658	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54743	 94106	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54743	 94106	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54744	 94107	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54744	 94107	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54745	 54746	 0.004929	 0.019374	 0.00507	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54745	 94108	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54745	 94108	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54746	 55075	 0.00434	 0.018367	 0.00413	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92729	 54746	 0.003463	 0.055727	 0.01821	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54747	 54751	 0.002182	 0.020948	 0.00609	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54747	 54757	 0.011727	 0.035119	 0.00791	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54747	 56782	 0.00357	 0.032472	 0.0082	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92729	 54747	 0.006688	 0.040144	 0.01216	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54747	 94914	 0.035813	 0.19065	 0.04433	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54748	 94787	 0.031401	 0.072891	 0.00139	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54749	 54750	 0.016645	 0.02804	 0.0004	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54749	 94112	 0.018483	 0.043767	 0.0008	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54751	 54873	 0.002607	 0.020942	 0.00589	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92729	 54751	 0.006922	 0.043848	 0.0119	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54751	 94109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54751	 94109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54752	 54753	 0.000381	 0.003322	 0.00091	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54753	 54754	 0.001182	 0.004732	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92729	 54753	 0.002905	 0.027886	 0.00811	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54753	 94110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54753	 94110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54754	 54758	 0.001525	 0.006205	 0.00151	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54755	 54756	 0.001613	 0.004263	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54755	 54757	 0.003668	 0.012582	 0.00301	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54755	 54759	 0.000209	 0.003125	 0.00105	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92729	 54755	 0.001598	 0.018266	 0.00557	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54755	 94111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54755	 94111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54756	 54757	 0.002506	 0.008442	 0.0021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54757	 54758	 0.002324	 0.009303	 0.00234	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54757	 56774	 0.005394	 0.019531	 0.00419	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92729	 54757	 0.001152	 0.012209	 0.00362	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54758	 54760	 0.004893	 0.012932	 0.00303	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54758	 94112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54758	 94112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54759	 54760	 0.000259	 0.003775	 0.00121	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54759	 54765	 0.002457	 0.006494	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54760	 54764	 0.000461	 0.003611	 0.00165	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54760	 94113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54760	 94113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54761	 94114	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94113	 54762	 0.030841	 0.024174	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54763	 54764	 0.00092	 0.003617	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94114	 54764	 0.001197	 0.004703	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54765	 54780	 0.002901	 0.009774	 0.00243	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54765	 94116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54765	 94116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54766	 54767	 0.003382	 0.01301	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94113	 54766	 0.016977	 0.032086	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54766	 94120	 0.003471	 0.017558	 0.00031	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94116	 54767	 0.003207	 0.017085	 0.0003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54768	 54769	 0.001452	 0.004843	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54768	 54775	 0.001099	 0.004402	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54768	 94117	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54768	 94117	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54769	 54770	 0.001929	 0.005178	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94074	 54769	 0.001132	 0.008145	 0.00216	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94114	 54769	 0.000645	 0.004707	 0.00121	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54770	 54777	 0.00185	 0.00516	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54771	 54779	 0.021486	 0.015808	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94117	 54771	 0.02034	 0.014704	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54772	 54773	 0.000737	 0.002952	 0.00074	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92630	 54772	 0.002738	 0.014717	 0.00362	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54772	 94118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54772	 94118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54773	 54776	 0.001212	 0.00493	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54773	 94119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54773	 94119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94119	 54774	 0.015969	 0.015624	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54775	 54776	 0.000928	 0.003928	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54775	 94120	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54775	 94120	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54778	 54794	 0.001136	 0.003974	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54778	 94121	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54778	 94121	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94121	 54779	 0.00643	 0.012314	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92630	 54780	 0.002851	 0.011603	 0.00283	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54781	 54806	 0.000412	 0.005021	 0.00166	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54781	 54820	 0.000398	 0.003821	 0.00111	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54781	 94122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54781	 94122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54782	 94123	 0.015249	 0.016284	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54783	 54784	 6.8e-05	 0.000806	 0.0137	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54783	 54809	 5.2e-05	 0.000657	 0.01001	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54783	 94123	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54783	 94123	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54784	 94124	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54784	 94124	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54785	 54788	 0.008335	 0.019737	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54785	 54802	 0.004847	 0.012847	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54785	 94128	 0.013612	 0.040971	 0.0008	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54786	 54796	 0.000932	 0.006562	 0.00373	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54786	 54806	 0.00034	 0.004547	 0.00124	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54787	 94128	 0.034963	 0.065011	 0.00152	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54788	 54850	 0.010807	 0.027779	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54789	 54796	 0.004034	 0.013838	 0.00332	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54789	 54803	 0.003192	 0.008437	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54789	 57439	 0.001702	 0.015478	 0.00391	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93982	 54789	 0.002734	 0.018972	 0.00541	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54790	 54791	 0.001158	 0.003059	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54790	 94125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54790	 94125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54792	 54793	 0.000814	 0.003446	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54792	 54795	 0.002005	 0.008279	 0.00196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54793	 54794	 0.000983	 0.004001	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54794	 94126	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54794	 94126	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92630	 54795	 0.001926	 0.007492	 0.002	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54795	 94127	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54795	 94127	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54796	 54803	 0.00085	 0.005385	 0.00146	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92630	 54796	 0.005711	 0.018626	 0.00494	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54796	 94128	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54796	 94128	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54797	 54803	 0.000835	 0.009391	 0.00247	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54797	 57442	 0.000323	 0.003043	 0.00092	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54797	 94129	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54797	 94129	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94129	 54798	 0.026553	 0.021014	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94128	 54799	 0.019336	 0.015915	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54799	 94130	 0.010294	 0.029525	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54800	 54804	 0.000453	 0.002871	 0.00078	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94124	 54800	 0.001783	 0.007137	 0.0018	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54800	 94130	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54800	 94130	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94127	 54801	 0.016047	 0.013715	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54802	 94131	 0.003761	 0.01441	 0.00041	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54803	 94131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54803	 94131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54804	 57442	 0.00289	 0.016363	 0.00406	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92630	 54804	 0.002198	 0.006836	 0.00143	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92631	 54805	 0.018294	 0.011844	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54806	 94132	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54806	 94132	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94132	 54808	 0.005929	 0.017005	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54808	 94133	 0.002539	 0.01016	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54809	 54810	 3.4e-05	 0.000462	 0.00813	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54809	 94133	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54809	 94133	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54810	 54811	 4.6e-05	 0.000637	 0.01092	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54811	 54814	 4.8e-05	 0.000785	 0.01225	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54811	 94134	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54811	 94134	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94134	 54812	 0.021758	 0.017219	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94134	 54813	 0.002451	 0.011824	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54814	 54817	 7.7e-05	 0.000812	 0.01215	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54814	 54817	 7.7e-05	 0.000812	 0.01215	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54814	 94135	 0.000128	 0.010206	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54815	 54842	 0.002316	 0.006139	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94043	 54815	 0.00209	 0.00641	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54816	 54828	 0.009992	 0.010092	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54817	 54847	 0.000101	 0.001696	 0.03076	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54817	 94137	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54818	 54819	 0.001613	 0.004264	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94135	 54818	 0.001896	 0.004569	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54819	 54821	 0.001245	 0.003291	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54820	 54821	 0.001227	 0.00344	 0.00089	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94135	 54820	 0.005059	 0.013371	 0.00313	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54820	 94139	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54820	 94139	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54822	 54830	 0.007814	 0.020087	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94136	 54822	 0.008059	 0.032936	 0.00067	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54823	 54828	 0.007443	 0.018928	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54823	 54832	 0.014572	 0.016027	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54824	 54825	 0.004881	 0.012546	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54824	 54840	 0.008865	 0.017553	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94136	 54824	 0.005796	 0.023687	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54825	 54829	 0.016031	 0.017632	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54826	 94143	 0.021213	 0.016627	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54827	 54828	 0.010562	 0.011719	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54828	 54841	 0.007786	 0.016685	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94138	 54828	 0.004605	 0.018271	 0.00052	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54830	 54837	 0.006591	 0.012256	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54831	 54836	 0.005646	 0.016193	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54831	 94141	 0.00424	 0.016314	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54833	 54834	 0.014457	 0.01446	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94139	 54834	 0.005883	 0.015123	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54835	 54849	 0.013143	 0.02214	 0.00032	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94139	 54835	 0.008189	 0.036491	 0.00062	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54835	 94140	 0.01124	 0.032239	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54836	 54837	 0.005401	 0.01254	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54838	 54844	 0.001051	 0.004091	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54838	 94140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54838	 94140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54839	 54840	 0.012037	 0.009435	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54841	 54842	 0.003112	 0.008226	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54841	 54848	 0.013702	 0.010844	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54843	 54845	 0.00326	 0.017367	 0.0003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94140	 54843	 0.00271	 0.013448	 0.00032	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54844	 54846	 0.001704	 0.006698	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54845	 94141	 0.028382	 0.031217	 0.00042	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54846	 54851	 0.001341	 0.0046	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54846	 94141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54846	 94141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54847	 94142	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93999	 54849	 0.007841	 0.019463	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94142	 54851	 0.001965	 0.006112	 0.00128	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54851	 94144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54851	 94144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54852	 54853	 0.003912	 0.012911	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94143	 54852	 0.004448	 0.015889	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54853	 54856	 0.008066	 0.020512	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54854	 54857	 0.001364	 0.005774	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94142	 54854	 0.001687	 0.006749	 0.00228	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54854	 94145	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54854	 94145	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54855	 54856	 0.004613	 0.010708	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94145	 54855	 0.00554	 0.024685	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54857	 94146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54857	 94146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54858	 54859	 0.007272	 0.011607	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94144	 54859	 0.009509	 0.023602	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54860	 54861	 0.001626	 0.005425	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94146	 54860	 0.002028	 0.004637	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94143	 54861	 0.003942	 0.015334	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54862	 54864	 0.013588	 0.014946	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54863	 94147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54863	 94147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54864	 54866	 0.014754	 0.014797	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94041	 54865	 0.011462	 0.027339	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54866	 54868	 0.017734	 0.014596	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94041	 54866	 0.009401	 0.021825	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54867	 54868	 0.00474	 0.009289	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94024	 54867	 0.009998	 0.010996	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94147	 54867	 0.005813	 0.014723	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54868	 54869	 0.010954	 0.013113	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94040	 54870	 0.005968	 0.007844	 0.00011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94062	 54872	 0.000904	 0.010006	 0.00325	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54872	 94148	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54872	 94148	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54873	 94149	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54873	 94149	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94033	 54874	 0.008358	 0.023973	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94035	 54874	 0.007193	 0.014097	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94062	 54875	 0.006089	 0.02205	 0.00473	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54875	 94150	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54875	 94150	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94065	 54876	 0.00324	 0.019917	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94086	 54878	 0.003379	 0.013145	 0.00351	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54878	 94151	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54878	 94151	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94088	 54879	 0.011983	 0.030804	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94021	 54880	 8.6e-05	 0.001058	 0.00197	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94061	 54880	 0.000555	 0.003742	 0.00689	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54880	 94152	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94153	 54880	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54881	 54883	 0.011533	 0.040353	 0.00084	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54881	 54884	 0.1471	 0.14755	 0.00239	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92702	 54881	 0.097857	 0.33442	 0.00728	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54882	 54883	 0.040414	 0.040819	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54882	 55391	 0.46436	 0.51129	 0.00683	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54883	 57022	 0.15993	 0.45897	 0.00706	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54884	 56958	 0.36603	 0.40285	 0.00538	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54885	 54887	 0.002702	 0.006792	 0.00176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54885	 54888	 0.023438	 0.061953	 0.0145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54886	 94154	 0.006297	 0.014466	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54886	 94972	 0.13266	 0.38065	 0.00586	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54886	 94992	 0.142	 0.55292	 0.00924	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54887	 54888	 0.025318	 0.066924	 0.01567	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54887	 94154	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54887	 94154	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92739	 54888	 0.024848	 0.10821	 0.03085	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54888	 94971	 0.023632	 0.096204	 0.02345	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54889	 54890	 0.015895	 0.041195	 0.00078	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54889	 94797	 0.077745	 0.17863	 0.00271	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54890	 56582	 0.053783	 0.17079	 0.00299	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54891	 94164	 0.045046	 0.10667	 0.00195	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54892	 54893	 0.12101	 0.089035	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93969	 54892	 0.18023	 0.14265	 0.0018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54893	 94155	 0.036477	 0.076667	 0.0014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54894	 54896	 0.003621	 0.026442	 0.0068	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54894	 94155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54894	 94155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54894	 94163	 0.004207	 0.017118	 0.00417	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54895	 54903	 0.011286	 0.046126	 0.00093	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94155	 54895	 0.009462	 0.045653	 0.00081	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54896	 54898	 0.002072	 0.007536	 0.00231	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54896	 54901	 0.002214	 0.007459	 0.00185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54896	 54902	 0.003277	 0.011422	 0.00265	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54896	 94163	 0.005379	 0.041216	 0.01104	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54897	 94156	 0.035214	 0.027868	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54898	 54899	 0.000898	 0.003654	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54898	 94156	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54898	 94156	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54899	 54958	 0.000987	 0.005441	 0.00127	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54899	 54959	 0.001096	 0.00376	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94156	 54900	 0.024578	 0.018852	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54901	 54902	 0.001268	 0.003672	 0.00089	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54902	 94157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54902	 94157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54903	 94171	 0.023655	 0.053657	 0.00107	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54904	 54906	 0.051855	 0.10899	 0.00199	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54904	 58541	 0.037102	 0.18115	 0.0038	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54904	 94161	 0.092417	 0.18114	 0.00272	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54905	 54915	 0.050189	 0.099372	 0.00146	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54907	 94164	 0.095503	 0.075582	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54908	 54911	 0.008299	 0.021545	 0.00523	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54908	 54990	 0.005171	 0.013883	 0.00315	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54909	 54911	 0.003049	 0.014796	 0.00338	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54909	 55022	 0.00519	 0.018792	 0.00403	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54909	 94158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54909	 94158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54910	 54911	 0.001057	 0.011196	 0.00332	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54910	 54912	 0.00212	 0.015703	 0.00805	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54910	 57882	 0.002586	 0.010353	 0.00261	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54910	 94159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54910	 94159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54912	 54913	 0.008969	 0.029253	 0.00777	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54912	 57890	 0.007267	 0.027625	 0.00773	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54912	 58550	 0.007666	 0.034163	 0.00928	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92647	 54912	 0.00862	 0.090744	 0.05103	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	54912	 94160	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54912	 94160	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54913	 54914	 0.008471	 0.022387	 0.00524	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54913	 94161	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54913	 94161	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54914	 54925	 0.00575	 0.015436	 0.0035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54915	 54916	 0.023361	 0.041726	 0.00062	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54915	 94164	 0.037102	 0.09808	 0.00178	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54916	 94162	 0.009204	 0.02065	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54917	 54924	 0.000867	 0.002291	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54917	 94162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54917	 94162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54918	 54920	 0.012084	 0.017155	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54919	 94164	 0.070109	 0.045389	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54920	 94165	 0.0091	 0.021549	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54921	 94163	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94162	 54922	 0.009127	 0.030447	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54922	 94165	 0.004329	 0.019071	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54923	 54930	 0.00112	 0.006437	 0.00182	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94163	 54923	 0.001402	 0.011266	 0.00317	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54923	 94165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54923	 94165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54924	 54926	 0.001387	 0.003666	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54924	 54927	 0.001312	 0.003659	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54925	 54926	 0.002177	 0.005753	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54925	 94166	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54925	 94166	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54926	 54927	 0.000921	 0.002568	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54926	 94167	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54926	 94167	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54927	 54930	 0.002046	 0.006894	 0.00171	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94167	 54928	 0.017923	 0.021455	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54929	 54932	 0.001055	 0.007242	 0.00211	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94163	 54929	 0.002121	 0.017038	 0.00479	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54929	 94168	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54929	 94168	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54930	 94169	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54930	 94169	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94169	 54931	 0.017087	 0.011062	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54932	 54939	 0.001752	 0.006885	 0.0018	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54932	 54941	 0.001685	 0.008734	 0.00213	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54933	 54938	 0.010308	 0.029564	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94168	 54933	 0.0066	 0.031682	 0.00095	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92802	 54934	 0.026327	 0.017044	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54935	 54936	 0.001304	 0.010163	 0.00304	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54935	 54945	 0.001549	 0.007917	 0.00216	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54935	 94170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54935	 94170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54936	 54937	 0.002811	 0.015496	 0.00362	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54936	 54941	 0.002106	 0.007443	 0.00168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54936	 94171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54936	 94171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94163	 54937	 0.002281	 0.015301	 0.00369	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54938	 94172	 0.014063	 0.023487	 0.0004	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54939	 54944	 0.002107	 0.008281	 0.00217	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54939	 94172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54939	 94172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54940	 94173	 0.010105	 0.018162	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54941	 54946	 0.002703	 0.018752	 0.00535	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54941	 94173	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54941	 94173	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54942	 94174	 0.006843	 0.026218	 0.00074	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54942	 94178	 0.030704	 0.055188	 0.00099	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54943	 54945	 0.001169	 0.005674	 0.0013	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54943	 54987	 0.000897	 0.003652	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54943	 55005	 0.002776	 0.01997	 0.00529	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54943	 94174	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54943	 94174	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54944	 54990	 0.0017	 0.005948	 0.00197	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54945	 94175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54945	 94175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54946	 54991	 0.001859	 0.007231	 0.00193	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54946	 54992	 0.000909	 0.004649	 0.00127	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54946	 94176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54946	 94176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54947	 54951	 0.008693	 0.052833	 0.00097	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54947	 54957	 0.011695	 0.027151	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94157	 54947	 0.006739	 0.036195	 0.00086	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54948	 54950	 0.013692	 0.026834	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54949	 94178	 0.043553	 0.034139	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54950	 54951	 0.007838	 0.025866	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54950	 54973	 0.027431	 0.029878	 0.00041	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54951	 54952	 0.019863	 0.015236	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54951	 54953	 0.020198	 0.026547	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54951	 54955	 0.024491	 0.024736	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54951	 94178	 0.092804	 0.093738	 0.00124	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54953	 54954	 0.025779	 0.020401	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54955	 54956	 0.015929	 0.012486	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54955	 55026	 0.01756	 0.017564	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54955	 55027	 0.032745	 0.035666	 0.00049	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93971	 54957	 0.020012	 0.046461	 0.00069	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54958	 54959	 0.002133	 0.006177	 0.00149	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54958	 94177	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54958	 94177	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54960	 54961	 0.005476	 0.014076	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94083	 54960	 0.007264	 0.018473	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54961	 54962	 0.006748	 0.012053	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54962	 54963	 0.009688	 0.011598	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54962	 54979	 0.010148	 0.014406	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54963	 54981	 0.016307	 0.016311	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54964	 54986	 0.00769	 0.010107	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54965	 54980	 0.015424	 0.016434	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54965	 54982	 0.004017	 0.009513	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54965	 54986	 0.007751	 0.015347	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54966	 54988	 0.004379	 0.017522	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54966	 94182	 0.024203	 0.038633	 0.00089	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54967	 55011	 0.012775	 0.019569	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54967	 94178	 0.011615	 0.026961	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54968	 55010	 0.020551	 0.01512	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54969	 54970	 0.008662	 0.014592	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54969	 54977	 0.050029	 0.052636	 0.00077	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94083	 54969	 0.005185	 0.015924	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54971	 54978	 0.007231	 0.020738	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54971	 94178	 0.005894	 0.02293	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94086	 54972	 0.010193	 0.030053	 0.00699	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54972	 94178	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54972	 94178	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54973	 54977	 0.015603	 0.026022	 0.00038	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54975	 54976	 0.0107	 0.021897	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54976	 54977	 0.011387	 0.022544	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54977	 54979	 0.020466	 0.020671	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54978	 54979	 0.006842	 0.013546	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54982	 54983	 0.002067	 0.006348	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54983	 54984	 0.005026	 0.011668	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54985	 54986	 0.007209	 0.00863	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54987	 54992	 0.000756	 0.004005	 0.00134	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54987	 94179	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54987	 94179	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94179	 54988	 0.002995	 0.015574	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54989	 55014	 0.003077	 0.017488	 0.00032	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94179	 54989	 0.00482	 0.011022	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54989	 94180	 0.004274	 0.016628	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54990	 54991	 0.001956	 0.008278	 0.00186	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54992	 54993	 0.000751	 0.003179	 0.00072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54993	 54999	 0.004602	 0.016666	 0.00358	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	54993	 94180	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54993	 94180	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54994	 54996	 0.007063	 0.016395	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94180	 54994	 0.004103	 0.013688	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54995	 55001	 0.008353	 0.010369	 0.00023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54995	 55014	 0.011934	 0.012054	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	54996	 54998	 0.012307	 0.013143	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	54997	 54998	 0.018878	 0.01494	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	54998	 55025	 0.02963	 0.029717	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54998	 94181	 0.013166	 0.018349	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	54998	 94184	 0.031982	 0.05214	 0.0008	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	54999	 57847	 0.002674	 0.010882	 0.00265	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	54999	 94181	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	54999	 94181	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55000	 94182	 0.025872	 0.018327	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94181	 55001	 0.008146	 0.018275	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55002	 55003	 0.018297	 0.013462	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55003	 55013	 0.018719	 0.014673	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55003	 94182	 0.006425	 0.014915	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55004	 55012	 0.004047	 0.010046	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55004	 94182	 0.002796	 0.007189	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55005	 55006	 0.000596	 0.002425	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55005	 94182	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55005	 94182	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55005	 95118	 0.007676	 0.030734	 0.00774	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55006	 55007	 0.000516	 0.002067	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55007	 94183	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55007	 94183	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55008	 55009	 0.002279	 0.008865	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94183	 55008	 0.002354	 0.00841	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94183	 55010	 0.008278	 0.019215	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55011	 55012	 0.011342	 0.013827	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55011	 55017	 0.0121	 0.023714	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94182	 55011	 0.006827	 0.016167	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55014	 55015	 0.00855	 0.009313	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55014	 55019	 0.030959	 0.046955	 0.00067	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94182	 55014	 0.013413	 0.044263	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55016	 55017	 0.015192	 0.012023	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55018	 55019	 0.007984	 0.015807	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55018	 55021	 0.00525	 0.016904	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55019	 55020	 0.026548	 0.019191	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55021	 94184	 0.005837	 0.023855	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55022	 94184	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55022	 94184	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55023	 55024	 0.015297	 0.015301	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94184	 55023	 0.003851	 0.00894	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55028	 56845	 0.0439	 0.080409	 0.00139	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55029	 55030	 0.23759	 0.23836	 0.00385	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55029	 55474	 0.11088	 0.21956	 0.00322	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55029	 94186	 0.068625	 0.2265	 0.00367	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55030	 56845	 0.045543	 0.19956	 0.00429	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93799	 55031	 0.015918	 0.10519	 0.20462	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55031	 94185	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94186	 55031	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94186	 55032	 0.32198	 0.23285	 0.00353	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55033	 56795	 0.17402	 0.49417	 0.00777	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92747	 55033	 0.1257	 0.22597	 0.00406	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55034	 57044	 0.032404	 0.15127	 0.03752	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55034	 58351	 0.028029	 0.19275	 0.05637	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55034	 94187	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55034	 94187	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55034	 95238	 0.03073	 0.29632	 0.08675	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94187	 55035	 0.0657	 0.29407	 0.00606	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55035	 95265	 0.14641	 0.50061	 0.0109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55036	 55037	 0.029103	 0.066558	 0.00162	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55038	 55039	 0.18508	 0.27756	 0.00504	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55038	 56725	 0.16518	 0.32715	 0.0048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55039	 57013	 0.19957	 0.40874	 0.01007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92750	 55039	 0.18052	 0.45937	 0.00727	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55040	 56723	 0.019912	 0.066438	 0.01685	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55040	 56726	 0.033363	 0.11247	 0.02797	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55041	 55042	 0.000467	 0.006166	 0.09876	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55041	 57304	 0.000706	 0.009179	 0.1522	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55042	 55045	 0.00047	 0.007388	 0.07701	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55042	 94188	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92666	 55043	 0.008125	 0.11598	 0.03878	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94188	 55043	 0.004717	 0.03321	 0.01888	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55044	 55045	 0.000482	 0.008127	 0.14739	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55044	 94190	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55044	 94190	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55046	 55052	 0.000177	 0.00197	 0.01858	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55046	 55068	 0.000275	 0.003556	 0.05968	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55046	 94191	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55047	 55049	 0.00162	 0.004519	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55047	 55066	 0.001855	 0.004902	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55047	 55067	 0.00411	 0.011034	 0.0025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94192	 55047	 0.004079	 0.01095	 0.00248	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55048	 55057	 0.001908	 0.004953	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55048	 55066	 0.002399	 0.006341	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55049	 55050	 0.001553	 0.004829	 0.00101	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94192	 55049	 0.005488	 0.013796	 0.00357	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55050	 55057	 0.002349	 0.006305	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55050	 94194	 0.001584	 0.004312	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55051	 55052	 8.2e-05	 0.0009	 0.00875	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55051	 55055	 6.4e-05	 0.00073	 0.00664	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55051	 94194	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55051	 94194	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94193	 55053	 0.029847	 0.078901	 0.00143	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55053	 94196	 0.005835	 0.016559	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55054	 94198	 0.001429	 0.00498	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55054	 94199	 0.011277	 0.050781	 0.01351	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55054	 94200	 0.011964	 0.032573	 0.00718	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55054	 94202	 0.001692	 0.005804	 0.00139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55055	 94195	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94196	 55056	 0.024725	 0.016007	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55056	 94197	 0.007642	 0.013997	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55056	 94203	 0.02592	 0.020317	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55057	 55058	 0.001393	 0.004191	 0.00131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55057	 55059	 0.001923	 0.006271	 0.00166	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55057	 94197	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55057	 94197	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55058	 55063	 0.000467	 0.003576	 0.00096	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55058	 55064	 0.001241	 0.005049	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55059	 55060	 0.001124	 0.003857	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92709	 55059	 0.000416	 0.004598	 0.00138	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55060	 94198	 0.001988	 0.006927	 0.00161	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55061	 55070	 0.000868	 0.005918	 0.01066	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55061	 55073	 0.000319	 0.00215	 0.00396	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55061	 94198	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55061	 94198	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55062	 55068	 0.000261	 0.003132	 0.05258	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55062	 58311	 0.001492	 0.016374	 0.15914	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55062	 94199	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55062	 94199	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92709	 55063	 0.001458	 0.005835	 0.00147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92797	 55063	 0.001783	 0.006116	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55064	 55067	 0.00232	 0.00613	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55064	 55071	 0.00149	 0.005965	 0.0015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94193	 55065	 0.046553	 0.033653	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55069	 55070	 0.000989	 0.006671	 0.01228	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55069	 94200	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55069	 94200	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55069	 95259	 0.00606	 0.04113	 0.07494	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55071	 94201	 0.001429	 0.005721	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55072	 57076	 0.003752	 0.025849	 0.04564	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92668	 55072	 0.015558	 0.10947	 0.18732	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92796	 55072	 0.000317	 0.003248	 0.00638	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55072	 94201	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55072	 94201	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92796	 55073	 0.000609	 0.005225	 0.01147	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94195	 55073	 0.000225	 0.001498	 0.00282	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55073	 94202	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94203	 55073	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55074	 57421	 0.15075	 0.50326	 0.00798	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55074	 95028	 0.1563	 0.54751	 0.01136	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55075	 55076	 0.002935	 0.016864	 0.00478	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55076	 55102	 0.004605	 0.039226	 0.00979	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55077	 55078	 0.004465	 0.0118	 0.00276	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55077	 94204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55077	 94204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55078	 55079	 0.001628	 0.00747	 0.00191	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55079	 55085	 0.002003	 0.012902	 0.00338	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55079	 94205	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55079	 94205	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55080	 55082	 0.055235	 0.035759	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55080	 94207	 0.034268	 0.045038	 0.00062	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55081	 55086	 0.084834	 0.067138	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55081	 94206	 0.087263	 0.069061	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55083	 55094	 0.024374	 0.062657	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55083	 94209	 0.03481	 0.047451	 0.00105	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55084	 55085	 0.004768	 0.014278	 0.00322	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55084	 55090	 0.001651	 0.009485	 0.00269	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55084	 94206	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55084	 94206	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55086	 94210	 0.010945	 0.036512	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55087	 55088	 0.001664	 0.008276	 0.00267	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55087	 55090	 0.001245	 0.006483	 0.0017	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55087	 94207	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55087	 94207	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55088	 55099	 0.001945	 0.016676	 0.00475	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55088	 94208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55088	 94208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94208	 55089	 0.006967	 0.033296	 0.00073	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55089	 94209	 0.012148	 0.028203	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55090	 55092	 0.01444	 0.036301	 0.00941	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55090	 94209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55090	 94209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55091	 55096	 0.066996	 0.052515	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55092	 55095	 0.003031	 0.025993	 0.0074	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55092	 57731	 0.018461	 0.047932	 0.01163	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55092	 94210	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55092	 94210	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94210	 55093	 0.01961	 0.05041	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55094	 94211	 0.026307	 0.067625	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55095	 56749	 0.003636	 0.017963	 0.00525	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55095	 94211	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55095	 94211	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55095	 94781	 0.005984	 0.060295	 0.037	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55096	 57740	 0.039068	 0.087652	 0.0014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94211	 55096	 0.010771	 0.049914	 0.00096	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94211	 55097	 0.046516	 0.11015	 0.00201	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55098	 55099	 0.012796	 0.043899	 0.01052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55098	 56563	 0.009964	 0.049136	 0.01329	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55100	 57180	 0.00426	 0.040717	 0.01342	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92635	 55101	 0.028412	 0.020126	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92635	 55103	 0.009987	 0.039003	 0.00086	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55104	 55105	 0.002819	 0.019354	 0.00564	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55105	 57178	 0.005618	 0.045136	 0.01269	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55106	 55113	 0.002145	 0.019972	 0.00039	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55106	 94213	 0.004192	 0.025477	 0.00047	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55106	 94217	 0.006925	 0.025606	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55106	 94217	 0.006925	 0.025606	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55107	 55207	 0.002018	 0.010729	 0.00249	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55107	 94212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55107	 94212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55108	 55109	 0.018398	 0.014421	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55108	 55110	 0.003045	 0.010879	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55108	 55110	 0.003045	 0.010879	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94212	 55108	 0.005338	 0.01531	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55108	 94236	 0.010839	 0.034756	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55108	 94236	 0.010839	 0.034756	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55110	 55111	 0.002085	 0.007708	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55110	 55111	 0.002085	 0.007708	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55111	 55117	 0.004609	 0.016463	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55111	 55118	 0.019813	 0.032477	 0.00057	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94212	 55111	 0.00337	 0.02313	 0.00042	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55111	 94214	 0.004947	 0.015176	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55111	 94214	 0.004947	 0.015176	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55112	 55113	 0.011597	 0.009178	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94212	 55113	 0.001617	 0.015052	 0.00029	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55114	 55115	 0.000291	 0.002737	 0.00083	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55114	 94213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55114	 94213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55115	 55116	 0.000342	 0.003287	 0.00096	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55115	 94214	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55115	 94214	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55116	 55120	 0.000346	 0.003525	 0.00091	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94213	 55117	 0.004902	 0.016353	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55119	 55120	 0.000308	 0.002961	 0.00086	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55119	 55122	 0.001164	 0.003922	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55119	 94215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55119	 94215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55119	 94222	 0.002016	 0.020543	 0.00529	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55121	 55122	 0.00205	 0.007144	 0.00166	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55121	 94216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55121	 94216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55122	 55123	 0.000571	 0.002325	 0.00057	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55123	 94217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55123	 94217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55124	 55125	 0.004451	 0.017317	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55124	 55125	 0.004451	 0.017317	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55124	 55265	 0.002195	 0.008443	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55124	 55265	 0.002195	 0.008443	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55125	 55204	 0.007974	 0.030676	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55125	 55204	 0.007974	 0.030676	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55125	 94218	 0.002686	 0.020933	 0.00039	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55126	 55132	 0.002868	 0.011481	 0.00289	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55126	 94218	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55126	 94218	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55126	 94222	 0.001427	 0.015397	 0.00527	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55127	 55128	 0.015698	 0.011348	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55128	 55156	 0.007379	 0.01461	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55129	 55135	 0.00595	 0.012228	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55129	 55136	 0.007697	 0.019786	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55129	 55140	 0.007206	 0.014122	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55129	 55142	 0.012844	 0.033018	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94218	 55129	 0.009898	 0.052963	 0.00161	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55130	 55131	 0.001254	 0.005176	 0.00122	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55130	 94219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55130	 94219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55131	 55132	 0.001083	 0.004337	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55132	 94220	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55132	 94220	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94220	 55133	 0.017313	 0.015513	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55134	 55135	 0.014282	 0.013393	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94219	 55135	 0.009365	 0.021743	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94220	 55136	 0.009337	 0.024	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55137	 55143	 0.008713	 0.020229	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55137	 55144	 0.011993	 0.027844	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55138	 55139	 0.003802	 0.010904	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55138	 55141	 0.003857	 0.014467	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55138	 55142	 0.012388	 0.026036	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94219	 55139	 0.005861	 0.020506	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55141	 55216	 0.005093	 0.022438	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94218	 55143	 0.018943	 0.049095	 0.00093	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55144	 55145	 0.008138	 0.016654	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55145	 55146	 0.003509	 0.013163	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55145	 94221	 0.008267	 0.046994	 0.00085	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55146	 55147	 0.003284	 0.010954	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55147	 55148	 0.01218	 0.007885	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55147	 55149	 0.003589	 0.010184	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55149	 55151	 0.006196	 0.014672	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55150	 55151	 0.007744	 0.009441	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55151	 55152	 0.00924	 0.018295	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55151	 55153	 0.00567	 0.011112	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55151	 94221	 0.004064	 0.020432	 0.00056	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55154	 55155	 0.013718	 0.015088	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55155	 55157	 0.00431	 0.010962	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55156	 55162	 0.010352	 0.024514	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55157	 94221	 0.004767	 0.012254	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55158	 94221	 0.004789	 0.012311	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55159	 94221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55159	 94221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55159	 94222	 0.002216	 0.010168	 0.0026	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55160	 55161	 0.001729	 0.007663	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94221	 55160	 0.002323	 0.011207	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55161	 55169	 0.001338	 0.008229	 0.00015	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55162	 55169	 0.006279	 0.011675	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55162	 94223	 0.003913	 0.01724	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94221	 55163	 0.004084	 0.023213	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55163	 94223	 0.005428	 0.018108	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55163	 94224	 0.010026	 0.03857	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55164	 55167	 8.5e-05	 0.001341	 0.01397	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55164	 94222	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94222	 55165	 0.000307	 0.004422	 0.00181	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55165	 94224	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55165	 94224	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55165	 94225	 0.000368	 0.00387	 0.00217	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94224	 55166	 0.002567	 0.015783	 0.00028	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55166	 94231	 0.00669	 0.024735	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55167	 55243	 0.000275	 0.003373	 0.05404	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55167	 94225	 0.000109	 0.008705	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95332	 55167	 0.002424	 0.046862	 0.92671	 1000.0	 1000.0	 1000.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95332	 55167	 0.002424	 0.046862	 0.92671	 1000.0	 1000.0	 1000.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55168	 55187	 0.009559	 0.016103	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94226	 55169	 0.007872	 0.030284	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94226	 55169	 0.007872	 0.030284	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55170	 94227	 0.020517	 0.013283	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55171	 55173	 0.003452	 0.008962	 0.00218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94225	 55171	 0.001321	 0.004451	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55171	 94227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55171	 94227	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92789	 55172	 0.019873	 0.020292	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94227	 55172	 0.008694	 0.014519	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55173	 55174	 0.001558	 0.004119	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55174	 55175	 0.000948	 0.002506	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55175	 55183	 0.001507	 0.004045	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55176	 55178	 0.001281	 0.011193	 0.00028	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55176	 94230	 0.003102	 0.011081	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55176	 94230	 0.003102	 0.011081	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55177	 55181	 0.006535	 0.015997	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55177	 94228	 0.013043	 0.020819	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55178	 55181	 0.003195	 0.025572	 0.00052	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55179	 55258	 0.003088	 0.012364	 0.00311	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94225	 55179	 0.0035	 0.031016	 0.00826	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55179	 94228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55179	 94228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55180	 55251	 0.005275	 0.044802	 0.00105	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55180	 94229	 0.008792	 0.023302	 0.00059	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55180	 94241	 0.00574	 0.022084	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55180	 94241	 0.00574	 0.022084	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94228	 55181	 0.006724	 0.021652	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55182	 94229	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55182	 94229	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55183	 94230	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55183	 94230	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55183	 94240	 0.001803	 0.011084	 0.0032	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55184	 55185	 0.004697	 0.009299	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55184	 55187	 0.009693	 0.01274	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55185	 55186	 0.014068	 0.011027	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55185	 55191	 0.012558	 0.026912	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55185	 94232	 0.018759	 0.021989	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55187	 55188	 0.005758	 0.014644	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92789	 55188	 0.002532	 0.009851	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55189	 55193	 0.003287	 0.010848	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55189	 55198	 0.00358	 0.012525	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55189	 55221	 0.010834	 0.021233	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55190	 55225	 0.006328	 0.016728	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55190	 94233	 0.00365	 0.012469	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55191	 55197	 0.003	 0.010504	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94229	 55191	 0.009825	 0.02281	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55192	 55222	 0.003048	 0.007835	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55192	 94231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55192	 94231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55193	 55220	 0.024732	 0.019573	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94231	 55193	 0.006458	 0.008488	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55194	 55195	 0.000637	 0.00255	 0.00064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55194	 94232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55194	 94232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55195	 55196	 0.002612	 0.007284	 0.00153	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55195	 94233	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55195	 94233	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55196	 55200	 0.001336	 0.003434	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55197	 94241	 0.003921	 0.024104	 0.00043	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55198	 55199	 0.013677	 0.013382	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92789	 55198	 0.003594	 0.015919	 0.00036	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94232	 55199	 0.0062	 0.013287	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55200	 55201	 0.000241	 0.001786	 0.00092	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55200	 55229	 0.001548	 0.00751	 0.00172	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55200	 94234	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55200	 94234	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55201	 55241	 0.000308	 0.002646	 0.00075	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55202	 94235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55202	 94235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55203	 55204	 0.006867	 0.017652	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94223	 55203	 0.014004	 0.035999	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94223	 55204	 0.003048	 0.020681	 0.00039	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55205	 94237	 0.020401	 0.052443	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55207	 94236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55207	 94236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55208	 55217	 0.014451	 0.064393	 0.00109	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94236	 55208	 0.009033	 0.038795	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92780	 55209	 0.00228	 0.01756	 0.00034	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94236	 55209	 0.002359	 0.018384	 0.00034	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55210	 55211	 0.006444	 0.027673	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55210	 55212	 0.012216	 0.035038	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94216	 55211	 0.007777	 0.044207	 0.0008	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94219	 55211	 0.012934	 0.029018	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55212	 55213	 0.007453	 0.019159	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55212	 55214	 0.004985	 0.022214	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55212	 94237	 0.006566	 0.05788	 0.00125	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55213	 55215	 0.043458	 0.034392	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55213	 55216	 0.014519	 0.026997	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94219	 55214	 0.003944	 0.013809	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55216	 94237	 0.011109	 0.063197	 0.00194	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55217	 94237	 0.011129	 0.043463	 0.00096	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55218	 94237	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55218	 94237	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94237	 55219	 0.027694	 0.021917	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55221	 55224	 0.013696	 0.013833	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55222	 55227	 0.001763	 0.004658	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55223	 55224	 0.012359	 0.011075	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55224	 55225	 0.004772	 0.009351	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55225	 55232	 0.01882	 0.014752	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55226	 94242	 0.20539	 0.16256	 0.00205	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55227	 55230	 0.001636	 0.004392	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55227	 94238	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55227	 94238	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55228	 55232	 0.00448	 0.00878	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94238	 55228	 0.016666	 0.013189	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55228	 94239	 0.025373	 0.02008	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55229	 55230	 0.001474	 0.003825	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55229	 55235	 0.00169	 0.005693	 0.00141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55229	 94239	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55229	 94239	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55231	 55232	 0.003251	 0.008357	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94234	 55231	 0.00641	 0.015179	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94234	 55233	 0.019741	 0.015623	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94239	 55234	 0.028404	 0.022478	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55234	 94243	 0.076418	 0.060477	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55235	 55236	 0.001588	 0.004755	 0.00107	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55236	 55244	 0.004756	 0.018693	 0.00489	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55236	 55246	 0.004258	 0.014606	 0.0035	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55237	 55239	 0.019925	 0.05122	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55237	 94244	 0.01233	 0.047966	 0.0008	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55238	 55240	 0.13513	 0.09769	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55238	 55248	 0.023455	 0.04644	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55241	 55242	 0.00023	 0.003126	 0.00112	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55242	 94240	 0.000287	 0.004334	 0.00129	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55243	 55247	 0.000115	 0.002126	 0.03812	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55243	 94240	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55244	 94242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55244	 94242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94242	 55245	 0.048631	 0.03578	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94240	 55246	 0.005959	 0.023859	 0.00601	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55246	 94243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55246	 94243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55247	 94244	 0.001096	 0.056989	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55247	 94244	 0.001096	 0.056989	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94244	 55248	 0.009745	 0.02262	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94243	 55249	 0.17687	 0.13015	 0.0019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55250	 55251	 0.01613	 0.028991	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55251	 55259	 0.003029	 0.020791	 0.00038	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55252	 55254	 0.014893	 0.028146	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55253	 55259	 0.013031	 0.0258	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55254	 55257	 0.009615	 0.027578	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55254	 55260	 0.032691	 0.077413	 0.00142	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55254	 94245	 0.009872	 0.047414	 0.00092	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55255	 55256	 0.008136	 0.033251	 0.00067	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55255	 94245	 0.006976	 0.034001	 0.00064	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55256	 55257	 0.004484	 0.017444	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55258	 94245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55258	 94245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94228	 55259	 0.005181	 0.023088	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94245	 55259	 0.00347	 0.023822	 0.00043	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55260	 55263	 0.035529	 0.082473	 0.00157	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55261	 55264	 0.09521	 0.070051	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55262	 55264	 0.11011	 0.071291	 0.00136	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55263	 55264	 0.023455	 0.054453	 0.00081	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94215	 55265	 0.00625	 0.021868	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94215	 55265	 0.00625	 0.021868	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94226	 55266	 0.015409	 0.059947	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94231	 55266	 0.012998	 0.030176	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55267	 94952	 0.036364	 0.093516	 0.02317	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55268	 55272	 0.000241	 0.002546	 0.03807	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55268	 55272	 0.000241	 0.002546	 0.03807	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55268	 56580	 0.000748	 0.007595	 0.1235	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55268	 56580	 0.000748	 0.007595	 0.1235	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55269	 94247	 0.051502	 0.090575	 0.0017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55270	 55271	 0.00052	 0.005365	 0.0843	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55270	 55271	 0.00052	 0.005365	 0.0843	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55271	 55272	 0.000125	 0.001584	 0.02766	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55271	 55273	 0.000136	 0.001924	 0.01819	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55271	 94246	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55272	 55273	 0.000119	 0.001263	 0.01318	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55273	 94248	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55273	 94248	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55274	 55578	 0.006675	 0.05726	 0.0163	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94248	 55274	 0.00537	 0.045163	 0.01338	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55275	 55278	 0.049983	 0.12849	 0.00199	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55275	 57003	 0.037893	 0.14012	 0.00259	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55276	 55277	 0.036536	 0.035748	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55277	 55278	 0.080247	 0.19005	 0.00348	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55277	 55280	 0.032639	 0.083904	 0.0013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55278	 55279	 0.051963	 0.13358	 0.00207	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55279	 57081	 0.083988	 0.15618	 0.00366	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55280	 94818	 0.1201	 0.2725	 0.00544	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55281	 55285	 0.025052	 0.12431	 0.00296	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55281	 55289	 0.18008	 0.21957	 0.00352	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55281	 94797	 0.039869	 0.24515	 0.00442	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55282	 55283	 0.008234	 0.027743	 0.0069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55282	 55284	 0.009298	 0.03367	 0.00722	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55282	 55286	 0.014119	 0.037906	 0.00859	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92671	 55282	 0.001554	 0.013238	 0.0033	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55283	 55284	 0.003058	 0.010491	 0.00251	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55283	 94249	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55283	 94249	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55284	 56824	 0.02027	 0.14595	 0.03873	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55284	 94250	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55284	 94250	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55285	 94251	 0.031485	 0.16777	 0.00294	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55286	 55288	 0.007521	 0.038448	 0.01048	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55286	 56819	 0.017712	 0.13282	 0.03243	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55286	 94251	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55286	 94251	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55287	 56610	 0.027693	 0.13514	 0.00233	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94251	 55287	 0.025056	 0.10241	 0.00207	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93285	 55289	 0.22263	 0.24492	 0.00327	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55290	 94804	 0.307	 0.22595	 0.0033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55291	 55292	 0.007483	 0.019776	 0.00463	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92619	 55291	 0.01568	 0.040711	 0.00988	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92804	 55291	 0.00826	 0.029908	 0.00642	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55292	 55294	 0.028011	 0.076279	 0.01681	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92619	 55292	 0.013006	 0.03627	 0.00761	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92804	 55292	 0.012805	 0.044629	 0.01035	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55292	 94252	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55292	 94252	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94252	 55293	 0.10573	 0.1068	 0.00141	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55294	 55295	 0.024234	 0.062926	 0.01528	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55294	 55566	 0.071935	 0.19042	 0.04466	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55294	 94253	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55294	 94253	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92619	 55295	 0.017272	 0.05926	 0.0142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55295	 94254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55295	 94254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92619	 55296	 0.005299	 0.018179	 0.00435	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55297	 56763	 0.009333	 0.077534	 0.03035	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55298	 56765	 0.033572	 0.1422	 0.03203	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55298	 57570	 0.018039	 0.093998	 0.02467	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55299	 55568	 0.016066	 0.089664	 0.02291	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55299	 55577	 0.043952	 0.17299	 0.04534	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55299	 94255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55299	 94255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55300	 94356	 0.033934	 0.13212	 0.03533	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55301	 55583	 0.022345	 0.084966	 0.02379	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55301	 56815	 0.023819	 0.090572	 0.02537	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55301	 56816	 0.0363	 0.14547	 0.03669	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55301	 58430	 0.034153	 0.11723	 0.02811	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55302	 55310	 3.8e-05	 0.000946	 0.01549	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55302	 55863	 1.8e-05	 0.000446	 0.00769	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55302	 94256	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55302	 94256	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94256	 55303	 0.017582	 0.012454	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55304	 55305	 0.000858	 0.002943	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55304	 94257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55304	 94257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55304	 94260	 0.003468	 0.009003	 0.00219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55305	 55309	 0.000557	 0.002997	 0.00082	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55305	 94258	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55305	 94258	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94258	 55306	 0.0163	 0.021213	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55307	 94259	 0.013398	 0.026258	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55308	 55309	 0.000718	 0.004169	 0.00098	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55308	 55312	 0.001291	 0.011072	 0.00315	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55308	 94259	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55308	 94259	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55310	 94260	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55311	 55313	 0.001313	 0.00668	 0.00242	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55311	 55361	 0.001721	 0.014761	 0.0042	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55312	 94262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55312	 94262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55312	 94275	 0.001446	 0.012617	 0.00347	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94260	 55313	 0.001261	 0.006333	 0.00165	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55314	 55315	 0.004121	 0.018363	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55314	 94276	 0.005109	 0.025844	 0.00045	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94262	 55315	 0.014329	 0.026246	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55316	 55317	 0.001148	 0.004741	 0.00112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55316	 55320	 0.000837	 0.006018	 0.00159	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55316	 55325	 0.001382	 0.009413	 0.00321	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55317	 55318	 0.00081	 0.004216	 0.00124	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55317	 55990	 0.00393	 0.027794	 0.00763	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55317	 94263	 0.002309	 0.016863	 0.00433	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55318	 55320	 0.001045	 0.006731	 0.00176	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55319	 55324	 0.0005	 0.004797	 0.0014	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55319	 55325	 0.00064	 0.005486	 0.00156	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55320	 55323	 0.000714	 0.003796	 0.00088	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55320	 94275	 0.000767	 0.008133	 0.00241	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55321	 94276	 0.023954	 0.018957	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55322	 55355	 7.5e-05	 0.000842	 0.00786	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55322	 94263	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55322	 94263	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55323	 55356	 0.001021	 0.004763	 0.00118	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94263	 55323	 0.001363	 0.004935	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94263	 55324	 0.000422	 0.00475	 0.00125	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55325	 94264	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55325	 94264	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55325	 94530	 0.00068	 0.010182	 0.00342	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55326	 55328	 0.004798	 0.012203	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55326	 94555	 0.007517	 0.018399	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55327	 55330	 0.000937	 0.007601	 0.00242	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55327	 56118	 0.00726	 0.019187	 0.00449	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55327	 94265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55327	 94265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55327	 94530	 0.004302	 0.017224	 0.00434	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55329	 55330	 0.000505	 0.00553	 0.00153	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94263	 55329	 0.000522	 0.005455	 0.00184	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55331	 55332	 0.0054	 0.012348	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55331	 55333	 0.017263	 0.018987	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94265	 55332	 0.004837	 0.019357	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55333	 55334	 0.010679	 0.024224	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55333	 56136	 0.008504	 0.015345	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55334	 56137	 0.003625	 0.01091	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55335	 55336	 0.007735	 0.012918	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55335	 94558	 0.014806	 0.03806	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55337	 94266	 0.004305	 0.024191	 0.00045	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55337	 94558	 0.025368	 0.06521	 0.00101	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55338	 55339	 0.001469	 0.005882	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55338	 55340	 0.004991	 0.014715	 0.00342	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55338	 94266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55338	 94266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55339	 55353	 0.002146	 0.009082	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55340	 55349	 0.00168	 0.009219	 0.00244	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55340	 94267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55340	 94267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55340	 94557	 0.004475	 0.020147	 0.00536	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55341	 56149	 0.017785	 0.013941	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55341	 94268	 0.019957	 0.052756	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55341	 94560	 0.015488	 0.024845	 0.00046	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55342	 55343	 0.011933	 0.033862	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94267	 55342	 0.023666	 0.054944	 0.00082	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55343	 94269	 0.005556	 0.024756	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55344	 55345	 0.003025	 0.01009	 0.00256	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55344	 55346	 0.004279	 0.027565	 0.00723	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55344	 94268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55344	 94268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55344	 94610	 0.019043	 0.066378	 0.01539	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55345	 94269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55345	 94269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55346	 94270	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55346	 94270	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55346	 95256	 0.005297	 0.038103	 0.0101	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94270	 55347	 0.092306	 0.09032	 0.00128	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94269	 55348	 0.024995	 0.073502	 0.00151	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55348	 94282	 0.010628	 0.053752	 0.00105	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55349	 55350	 0.001431	 0.008134	 0.00235	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55350	 55352	 0.001073	 0.006864	 0.00231	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55350	 94271	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55350	 94271	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94271	 55351	 0.036723	 0.026013	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55352	 94279	 0.000892	 0.005118	 0.0017	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55353	 94272	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55353	 94272	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55353	 94273	 0.0048	 0.012686	 0.00297	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55353	 94279	 0.003634	 0.014549	 0.00367	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94272	 55354	 0.030325	 0.023999	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55354	 94274	 0.015511	 0.02788	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55355	 94273	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55356	 55357	 0.001249	 0.00606	 0.00139	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94273	 55357	 0.001498	 0.00403	 0.00113	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55357	 94277	 0.001283	 0.011672	 0.00295	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55358	 55363	 0.0004	 0.005167	 0.01171	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55358	 56140	 0.001251	 0.017028	 0.03465	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92602	 55358	 0.000683	 0.009187	 0.01914	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55358	 94275	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94276	 55358	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92603	 55359	 0.003074	 0.018004	 0.0049	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94273	 55359	 0.003074	 0.012508	 0.00305	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94262	 55360	 0.015661	 0.031006	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92665	 55361	 0.002636	 0.027079	 0.00857	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55362	 55364	 0.011588	 0.015796	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55363	 55371	 0.002278	 0.015973	 0.0272	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92602	 55363	 0.00046	 0.003482	 0.01319	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55363	 94277	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94278	 55363	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55364	 55365	 0.027219	 0.022403	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94278	 55364	 0.034393	 0.068095	 0.001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55365	 94280	 0.006995	 0.022524	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55366	 94279	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55367	 55368	 0.002374	 0.008144	 0.00195	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55367	 94281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55367	 94281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55367	 94286	 0.004258	 0.014841	 0.00344	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55368	 94282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55368	 94282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94281	 55369	 0.013699	 0.023077	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55369	 94285	 0.00929	 0.026645	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94279	 55370	 0.002896	 0.014053	 0.00321	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55370	 94283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55370	 94283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55370	 94284	 0.000723	 0.005806	 0.00163	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55371	 55372	 0.000387	 0.00253	 0.00496	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55371	 94284	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94285	 55371	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55372	 94286	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55372	 94286	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55373	 55377	 0.00236	 0.02266	 0.00659	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94286	 55373	 0.004191	 0.014607	 0.00339	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55373	 94287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55373	 94287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92604	 55374	 0.00871	 0.030496	 0.00084	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94286	 55376	 0.009287	 0.05001	 0.01374	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55377	 58383	 0.018139	 0.047944	 0.01122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55378	 56589	 0.000493	 0.006672	 0.11755	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55378	 94288	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55378	 94288	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94288	 55379	 0.075662	 0.059308	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92823	 55380	 0.003139	 0.043827	 0.08485	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55380	 94289	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55380	 94289	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55380	 95321	 0.000615	 0.007355	 0.01453	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55381	 94290	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55382	 55383	 0.001186	 0.004508	 0.00126	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94290	 55382	 0.006448	 0.025344	 0.00663	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55383	 55385	 0.009821	 0.038602	 0.0101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55384	 56871	 0.031345	 0.1782	 0.00322	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94291	 55384	 0.0326	 0.20045	 0.00361	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92588	 55385	 0.012354	 0.050276	 0.01225	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55385	 94292	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55385	 94292	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94292	 55386	 0.080559	 0.063147	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55387	 56850	 0.063004	 0.19351	 0.00363	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93752	 55387	 0.034004	 0.16594	 0.00286	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92663	 55388	 0.060283	 0.12337	 0.00304	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55389	 58571	 0.022679	 0.090832	 0.02289	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55389	 94293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55389	 94293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94293	 55390	 0.13699	 0.25097	 0.00433	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55391	 55393	 0.26666	 0.26942	 0.00357	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55391	 57972	 0.17564	 0.40371	 0.00614	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92714	 55391	 0.074361	 0.28935	 0.00483	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93757	 55391	 0.26962	 0.62668	 0.00933	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92713	 55392	 0.019926	 0.079799	 0.02011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55392	 94294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55392	 94294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94294	 55393	 0.024521	 0.063034	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55394	 55942	 0.037529	 0.040078	 0.00085	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55394	 55949	 0.01099	 0.025248	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55395	 55396	 0.027409	 0.020165	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55395	 94506	 0.014197	 0.015615	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55396	 55397	 0.04203	 0.02721	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55397	 55398	 0.037314	 0.02953	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93878	 55397	 0.00561	 0.025	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55398	 94296	 0.063874	 0.050068	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55399	 55401	 0.002393	 0.006152	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55399	 55951	 0.002178	 0.005055	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55399	 94295	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55399	 94295	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94295	 55400	 0.041504	 0.02788	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55400	 94298	 0.010138	 0.025783	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55401	 55402	 0.002495	 0.008325	 0.00211	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55401	 94296	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55401	 94296	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55402	 55430	 0.002883	 0.011733	 0.00286	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55402	 94297	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55402	 94297	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55403	 55404	 0.003261	 0.008619	 0.00202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55403	 55918	 0.006903	 0.018244	 0.00427	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55403	 94298	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55403	 94298	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55404	 55405	 0.001483	 0.005169	 0.0012	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55405	 55416	 0.005471	 0.018768	 0.0045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55406	 55407	 0.002737	 0.007036	 0.00174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55406	 55416	 0.001993	 0.009829	 0.00266	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55406	 94299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55406	 94299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55407	 55409	 0.002501	 0.006609	 0.00155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55407	 55413	 0.005344	 0.014124	 0.00331	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55408	 55409	 0.002566	 0.00666	 0.00162	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55408	 55411	 0.001889	 0.005298	 0.00136	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55408	 55922	 0.009276	 0.024904	 0.00564	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55408	 94300	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55408	 94300	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94300	 55410	 0.049267	 0.036247	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55410	 94489	 0.037992	 0.030067	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55411	 55412	 0.001001	 0.003623	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55412	 55921	 0.002711	 0.006534	 0.00184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55412	 94492	 0.002854	 0.013091	 0.00335	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55413	 94301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55413	 94301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55414	 55415	 0.013772	 0.035402	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94299	 55414	 0.010317	 0.045458	 0.00079	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55415	 94302	 0.017611	 0.061659	 0.00171	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55416	 55423	 0.00096	 0.010615	 0.00318	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92764	 55416	 0.00114	 0.017504	 0.0049	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55416	 94302	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55416	 94302	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55417	 55419	 0.015299	 0.03029	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92793	 55418	 0.03045	 0.030457	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55419	 55420	 0.010075	 0.016972	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55419	 94303	 0.008018	 0.018985	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55421	 94303	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55421	 94303	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55422	 55423	 0.000668	 0.005919	 0.00158	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92764	 55422	 0.000513	 0.005327	 0.00165	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55423	 55428	 0.003792	 0.009844	 0.00239	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55423	 94304	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55423	 94304	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55424	 55425	 0.002535	 0.011771	 0.00032	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92809	 55424	 0.003265	 0.020071	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55425	 55426	 0.003406	 0.012167	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55425	 55434	 0.032381	 0.025382	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94304	 55426	 0.008119	 0.013486	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94304	 55427	 0.034406	 0.022275	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55428	 55431	 0.004792	 0.012864	 0.00292	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94302	 55429	 0.043178	 0.079086	 0.00137	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55429	 94305	 0.1009	 0.072944	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93886	 55430	 0.002062	 0.018267	 0.00486	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55430	 94305	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55430	 94305	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92820	 55431	 0.017461	 0.045336	 0.01101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92809	 55432	 0.053627	 0.1647	 0.00309	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94305	 55432	 0.054768	 0.065563	 0.00109	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93887	 55433	 0.018268	 0.049742	 0.01096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55433	 94306	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55433	 94306	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55435	 55455	 0.000323	 0.003731	 0.03271	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55435	 94307	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55435	 94307	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55436	 55438	 0.00571	 0.060522	 0.01797	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93958	 55436	 0.004207	 0.044586	 0.01324	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55437	 94308	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55438	 55439	 0.000171	 0.001842	 0.00053	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55439	 55440	 0.000329	 0.003328	 0.00098	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94308	 55440	 0.002263	 0.009059	 0.00228	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55440	 94310	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55440	 94310	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55441	 55445	 0.004042	 0.01147	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94310	 55441	 0.002288	 0.010194	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55442	 55444	 0.016554	 0.013101	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55443	 55444	 0.003939	 0.007325	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55443	 55448	 0.011321	 0.008577	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94309	 55443	 0.013781	 0.018785	 0.00042	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55444	 55445	 0.002942	 0.00602	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55446	 55448	 0.013104	 0.008802	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55447	 94311	 0.017964	 0.012986	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55449	 55450	 0.007167	 0.005273	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55449	 94311	 0.006893	 0.011495	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55451	 55453	 0.001869	 0.005019	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94308	 55451	 0.003745	 0.009897	 0.00232	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55451	 94311	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55451	 94311	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94311	 55452	 0.010459	 0.007924	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55453	 55454	 0.001114	 0.003108	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55454	 94312	 0.001893	 0.005003	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55455	 55456	 9.2e-05	 0.001062	 0.00931	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55456	 94312	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94313	 55457	 0.069122	 0.054703	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93888	 55458	 0.30342	 0.23791	 0.00305	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94306	 55458	 0.19554	 0.15329	 0.00197	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55459	 94314	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55459	 94314	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93871	 55461	 0.11004	 0.25174	 0.00615	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55461	 94315	 0.030265	 0.11774	 0.00197	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55462	 94791	 0.16163	 0.32011	 0.0047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55463	 55464	 0.006989	 0.041949	 0.0127	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55463	 57025	 0.020291	 0.10931	 0.03005	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55464	 56796	 0.030068	 0.080745	 0.0183	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55464	 94315	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55464	 94315	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94315	 55465	 0.081814	 0.14763	 0.00213	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55465	 94791	 0.26129	 0.18893	 0.00287	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55466	 57420	 0.026759	 0.13951	 0.03663	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92601	 55467	 0.16661	 0.12259	 0.00179	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55468	 56768	 0.15704	 0.40388	 0.00625	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92601	 55468	 0.050534	 0.26931	 0.00472	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55469	 55470	 0.17872	 0.19834	 0.00387	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55469	 56842	 0.07398	 0.15141	 0.00373	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94253	 55469	 0.038931	 0.17349	 0.00295	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55470	 55471	 0.038104	 0.038486	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55471	 55472	 0.008742	 0.017308	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55472	 55474	 0.069303	 0.18371	 0.00466	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55473	 55474	 0.082229	 0.20412	 0.00339	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55473	 94352	 0.039341	 0.15745	 0.00332	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55475	 58390	 0.023311	 0.128	 0.03387	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55476	 55477	 0.001884	 0.006145	 0.00163	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55476	 55478	 0.001501	 0.005007	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55477	 56629	 0.020283	 0.082562	 0.02012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55478	 55479	 0.001185	 0.004189	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55479	 55480	 0.001734	 0.007954	 0.00204	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55480	 94316	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55480	 94316	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93951	 55481	 0.13402	 0.26272	 0.00394	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94316	 55481	 0.010891	 0.014314	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55482	 55491	 0.000283	 0.00327	 0.02866	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55482	 94317	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55482	 94317	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55483	 55501	 0.010066	 0.0303	 0.00948	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55483	 55504	 0.004813	 0.031001	 0.00813	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92671	 55483	 0.002268	 0.015187	 0.00955	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93291	 55484	 0.010805	 0.028052	 0.00681	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55484	 94318	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55484	 94318	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55484	 94321	 0.007014	 0.018537	 0.00434	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55485	 55486	 0.004202	 0.016823	 0.00424	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55485	 55494	 0.005847	 0.0176	 0.00551	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55485	 55495	 0.011589	 0.031553	 0.00695	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92716	 55485	 0.024098	 0.18284	 0.09016	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93291	 55485	 0.018347	 0.048494	 0.01135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55485	 94319	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55485	 94319	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94319	 55487	 0.048772	 0.17067	 0.00354	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55488	 94320	 0.011516	 0.030522	 0.00077	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55488	 94322	 0.084133	 0.054469	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55489	 55490	 0.002063	 0.005186	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93291	 55489	 0.008481	 0.029977	 0.00676	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55489	 94320	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55489	 94320	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55490	 55492	 0.001806	 0.004917	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55490	 94321	 0.005129	 0.013964	 0.00308	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55491	 94321	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55491	 94321	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55492	 55493	 0.003486	 0.009722	 0.00204	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94321	 55492	 0.003898	 0.010871	 0.00228	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55493	 55494	 0.003406	 0.009002	 0.00211	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55494	 55495	 0.004282	 0.012824	 0.00289	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55494	 94322	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55494	 94322	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55495	 55500	 0.003367	 0.011552	 0.00277	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55495	 94323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55495	 94323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55496	 55499	 0.083053	 0.087383	 0.00128	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94319	 55496	 0.046051	 0.13209	 0.00203	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94319	 55497	 0.093451	 0.24027	 0.00372	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55498	 55499	 0.010561	 0.01779	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55499	 94325	 0.016804	 0.044422	 0.00081	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92671	 55500	 0.012236	 0.050523	 0.01196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94321	 55500	 0.005502	 0.018875	 0.00452	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55500	 94324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55500	 94324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94321	 55501	 0.004201	 0.029715	 0.00815	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55501	 94325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55501	 94325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55501	 94326	 0.00292	 0.020045	 0.00585	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55502	 55507	 0.036336	 0.034075	 0.00053	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92670	 55503	 0.001892	 0.019614	 0.03766	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93290	 55503	 0.003065	 0.034439	 0.06305	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55503	 94326	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94327	 55503	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55504	 94328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55504	 94328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94326	 55505	 0.005396	 0.027583	 0.00752	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94327	 55506	 0.079218	 0.20149	 0.00319	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94323	 55507	 0.011513	 0.049446	 0.0009	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94325	 55507	 0.009608	 0.024901	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55508	 55510	 0.002509	 0.009085	 0.00195	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55508	 55519	 0.005421	 0.016858	 0.00352	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55508	 94329	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55508	 94329	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55509	 55511	 0.000687	 0.003697	 0.00102	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55509	 55519	 0.001423	 0.007894	 0.0024	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55510	 55514	 0.002154	 0.00739	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55510	 55524	 0.005525	 0.014602	 0.00342	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55511	 55512	 0.001103	 0.004592	 0.00143	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55512	 55513	 0.000855	 0.004451	 0.00117	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55512	 55514	 0.002636	 0.007076	 0.0016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55512	 58242	 0.014107	 0.036265	 0.00898	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55513	 55517	 0.001454	 0.006055	 0.00189	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55514	 55524	 0.006626	 0.017788	 0.00403	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55514	 94330	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55514	 94330	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55515	 55516	 0.009857	 0.017716	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55515	 55526	 0.023164	 0.028754	 0.00063	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94330	 55515	 0.009682	 0.02489	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55517	 55525	 0.009361	 0.032626	 0.00757	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55517	 55527	 0.003125	 0.01251	 0.00315	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55517	 94331	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55517	 94331	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55517	 94333	 0.001254	 0.014334	 0.00437	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55518	 94332	 0.022487	 0.016545	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55519	 55520	 0.000364	 0.004417	 0.00119	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55519	 94332	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55519	 94332	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92724	 55520	 0.002133	 0.010406	 0.00287	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55520	 94334	 0.000753	 0.004484	 0.00118	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55521	 94335	 0.014376	 0.023878	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55522	 55531	 0.000347	 0.004398	 0.07679	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55522	 94333	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55522	 94333	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92723	 55523	 0.000393	 0.002492	 0.00522	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92727	 55523	 0.002738	 0.025056	 0.04824	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92829	 55523	 0.001645	 0.010678	 0.02127	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55523	 94334	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94335	 55523	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55523	 94338	 0.001152	 0.014873	 0.0337	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55523	 95233	 0.005095	 0.034759	 0.06262	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55524	 58242	 0.008387	 0.022165	 0.00519	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55524	 94336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55524	 94336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55525	 55527	 0.005626	 0.0193	 0.00462	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55525	 58241	 0.004958	 0.017009	 0.00407	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55527	 58241	 0.007227	 0.028405	 0.00743	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94333	 55527	 0.003651	 0.025331	 0.00723	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55528	 94340	 0.012929	 0.039664	 0.00107	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92830	 55529	 0.00532	 0.021301	 0.00537	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94333	 55529	 0.004403	 0.015343	 0.00356	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94334	 55529	 0.007017	 0.018218	 0.00442	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55529	 94337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55529	 94337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94333	 55530	 0.004691	 0.026172	 0.00668	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55530	 94339	 0.002879	 0.011528	 0.0029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55531	 94338	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55531	 94338	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55532	 57455	 0.10915	 0.086384	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94337	 55532	 0.00976	 0.025088	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55533	 94341	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55533	 94341	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55534	 58308	 0.029728	 0.13247	 0.00225	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55534	 94342	 0.021916	 0.11397	 0.00247	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55535	 57155	 0.006103	 0.04354	 0.0135	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92692	 55535	 0.004546	 0.048181	 0.0143	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55535	 94342	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55535	 94342	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92621	 55536	 0.000426	 0.004199	 0.00895	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55537	 57017	 0.000915	 0.009452	 0.14856	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55538	 58317	 0.006115	 0.031116	 0.01128	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94341	 55538	 0.002051	 0.012729	 0.00308	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55539	 55542	 0.008915	 0.022918	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92687	 55539	 0.003275	 0.018619	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55540	 55566	 0.016891	 0.044643	 0.01045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92686	 55540	 0.000439	 0.00217	 0.00063	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55540	 94343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55540	 94343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55541	 55563	 0.042874	 0.051325	 0.00085	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55541	 55564	 0.082394	 0.16315	 0.00239	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94343	 55541	 0.005682	 0.022104	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55542	 55567	 0.072227	 0.052213	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55543	 55545	 0.012044	 0.03607	 0.00813	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92686	 55543	 0.00108	 0.011944	 0.00358	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55543	 94344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55543	 94344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55544	 55545	 0.010474	 0.030043	 0.00739	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55544	 56403	 0.005119	 0.015919	 0.00332	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55544	 94345	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55544	 94345	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92686	 55546	 0.005943	 0.027263	 0.00698	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55546	 94346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55546	 94346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94346	 55547	 0.091826	 0.072672	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92720	 55548	 0.075336	 0.057788	 0.00078	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55549	 55561	 0.014927	 0.066514	 0.00113	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92720	 55549	 0.005804	 0.032612	 0.0006	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55550	 55552	 0.003875	 0.01087	 0.0028	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92686	 55550	 0.005817	 0.022861	 0.00598	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55551	 55552	 0.002773	 0.008176	 0.0019	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92719	 55551	 0.004817	 0.01273	 0.00298	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55551	 94347	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55551	 94347	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55553	 55556	 0.02246	 0.02393	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55553	 94348	 0.023703	 0.015346	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55554	 55557	 0.003585	 0.009996	 0.0021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55554	 55562	 0.003857	 0.012868	 0.00326	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55554	 94348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55554	 94348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55555	 94349	 0.020772	 0.017097	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55556	 55560	 0.019723	 0.015608	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55556	 94351	 0.005836	 0.022705	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55557	 55559	 0.001533	 0.00398	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55557	 94349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55557	 94349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94348	 55558	 0.016601	 0.021605	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55558	 94350	 0.036666	 0.026976	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55559	 94350	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55559	 94350	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55560	 55561	 0.034339	 0.023066	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94350	 55561	 0.00832	 0.02361	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92719	 55562	 0.002801	 0.024022	 0.00684	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55562	 94351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55562	 94351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55564	 58527	 0.12098	 0.14182	 0.00247	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94343	 55565	 0.030949	 0.13849	 0.00285	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92686	 55566	 0.013027	 0.04469	 0.01071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55566	 94352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55566	 94352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55568	 94353	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55568	 94353	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55568	 94356	 0.005814	 0.023277	 0.00586	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55569	 55570	 0.003378	 0.00907	 0.00206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55569	 57574	 0.012692	 0.053721	 0.01209	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55569	 94354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55569	 94354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55569	 94356	 0.005257	 0.018032	 0.00432	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55570	 94355	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55570	 94355	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55570	 94356	 0.002205	 0.010116	 0.00259	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94354	 55571	 0.013911	 0.032295	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94355	 55571	 0.016486	 0.021454	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55572	 55575	 0.28723	 0.29342	 0.00457	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94255	 55572	 0.1345	 0.36759	 0.00625	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94355	 55572	 0.011226	 0.029755	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55573	 94356	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55573	 94356	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55574	 55576	 0.011567	 0.047073	 0.01147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55574	 56829	 0.014339	 0.065794	 0.01686	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94356	 55574	 0.014637	 0.049322	 0.01226	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92805	 55575	 0.29799	 0.59062	 0.00868	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55575	 94357	 0.34756	 0.27517	 0.00346	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55576	 56889	 0.007002	 0.078815	 0.02071	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92817	 55576	 0.017429	 0.13139	 0.0365	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94356	 55576	 0.02586	 0.088739	 0.02127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55576	 94357	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55576	 94357	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55577	 55583	 0.068279	 0.2306	 0.05749	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55577	 94358	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55577	 94358	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55578	 55580	 0.019424	 0.046813	 0.01322	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55579	 55580	 0.007749	 0.019478	 0.00505	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55581	 94359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55581	 94359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94359	 55582	 0.058927	 0.22928	 0.00383	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55583	 94360	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55583	 94360	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55584	 55586	 0.005051	 0.043755	 0.01571	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55584	 56858	 0.005148	 0.043299	 0.01283	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55585	 94361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55585	 94361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55585	 94770	 0.010804	 0.042465	 0.01111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55586	 94362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55586	 94362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94362	 55587	 0.05519	 0.043677	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92779	 55588	 0.057535	 0.045533	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55589	 55590	 0.004556	 0.015628	 0.00374	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55589	 56652	 0.001097	 0.015518	 0.00514	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55590	 55591	 0.003054	 0.027782	 0.00701	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55590	 57295	 0.004499	 0.020638	 0.00529	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55592	 55593	 0.002877	 0.013199	 0.00338	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55593	 55594	 0.003766	 0.01639	 0.00467	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55594	 58232	 0.026268	 0.10522	 0.02653	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55594	 94363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55594	 94363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55594	 94737	 0.004845	 0.030103	 0.0085	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55595	 94364	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94365	 55595	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55595	 94373	 0.001129	 0.007778	 0.01373	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55595	 94447	 0.000421	 0.005361	 0.01014	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94365	 55596	 0.006158	 0.015829	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55597	 55612	 0.014871	 0.014915	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55597	 56156	 0.023642	 0.01871	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55597	 94366	 0.003973	 0.010212	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55598	 55601	 0.001128	 0.003868	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55598	 56157	 0.003355	 0.009356	 0.00196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55598	 94366	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55598	 94366	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55599	 56171	 0.003703	 0.012352	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94366	 55599	 0.00761	 0.01264	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55600	 55616	 0.002829	 0.013191	 0.0003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55600	 94367	 0.003186	 0.014256	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55601	 55602	 0.001314	 0.004509	 0.00108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94364	 55601	 0.003409	 0.011693	 0.0028	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55601	 94367	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55601	 94367	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55602	 55604	 0.001892	 0.004757	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55602	 55605	 0.000791	 0.003167	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55602	 94368	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55602	 94368	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94368	 55603	 0.008117	 0.008928	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55603	 94369	 0.016117	 0.012755	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55604	 55606	 0.001164	 0.003022	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55604	 94369	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55604	 94369	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55605	 55610	 0.000977	 0.00391	 0.00099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55606	 55609	 0.001572	 0.004279	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55606	 94370	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55606	 94370	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94370	 55607	 0.010945	 0.014385	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55607	 94442	 0.016424	 0.021586	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55608	 94371	 0.009684	 0.018007	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55608	 94375	 0.004328	 0.016581	 0.00047	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55609	 94371	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55609	 94371	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55610	 55611	 0.000857	 0.004703	 0.00124	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55610	 94374	 0.005652	 0.014939	 0.0035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55610	 94388	 0.000335	 0.004873	 0.00156	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55611	 55613	 0.00095	 0.003326	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55611	 94372	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55611	 94372	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94365	 55612	 0.005452	 0.021211	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92799	 55613	 0.002067	 0.018802	 0.00475	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55613	 94374	 0.002377	 0.009518	 0.0024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55614	 55853	 0.000365	 0.004216	 0.03696	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55614	 55900	 0.000639	 0.00701	 0.06809	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55614	 56244	 0.000672	 0.008684	 0.14578	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55614	 94373	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55615	 55650	 0.019027	 0.012318	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55616	 56171	 0.007589	 0.01553	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55616	 94376	 0.001323	 0.007445	 0.00016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55617	 55619	 0.001286	 0.005232	 0.00127	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55617	 94376	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55617	 94376	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55617	 94389	 0.003759	 0.015909	 0.00358	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55618	 55620	 0.004427	 0.009304	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55618	 55621	 0.008688	 0.017201	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94376	 55618	 0.004444	 0.00997	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55619	 55628	 0.001366	 0.005469	 0.00138	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55619	 94377	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55619	 94377	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94377	 55620	 0.005538	 0.015885	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55621	 55622	 0.005135	 0.01192	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55621	 55623	 0.006138	 0.020478	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55622	 55653	 0.005832	 0.013539	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55623	 55624	 0.002763	 0.012104	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55623	 55654	 0.002633	 0.008783	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55624	 55625	 0.005046	 0.011715	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55624	 55635	 0.00733	 0.024452	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55625	 94378	 0.007167	 0.016256	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55626	 55629	 0.002026	 0.005516	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55626	 55631	 0.001522	 0.004581	 0.00143	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55626	 94378	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55626	 94378	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94377	 55627	 0.006058	 0.020208	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94378	 55627	 0.002985	 0.013302	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55628	 55629	 0.000845	 0.003288	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55629	 55630	 0.001243	 0.004976	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55629	 94379	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55629	 94379	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55630	 55631	 0.001159	 0.004824	 0.0015	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55630	 55638	 0.002178	 0.005655	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55630	 56235	 0.001137	 0.00512	 0.00136	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55630	 94380	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55630	 94380	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55630	 94594	 0.004056	 0.025205	 0.00711	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55631	 94381	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55631	 94381	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55632	 55633	 0.004171	 0.010566	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94381	 55632	 0.025351	 0.020063	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55633	 55635	 0.005569	 0.014315	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55633	 55637	 0.004065	 0.015815	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55634	 55635	 0.018402	 0.014563	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55635	 55636	 0.007744	 0.018338	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55636	 55670	 0.012612	 0.020674	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55636	 94387	 0.006671	 0.028648	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55636	 94395	 0.002609	 0.014843	 0.00046	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55637	 94386	 0.006459	 0.023657	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55638	 94382	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55638	 94382	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55639	 55641	 0.005014	 0.015092	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94382	 55639	 0.003436	 0.011464	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55640	 55642	 0.003487	 0.007136	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55640	 94383	 0.004545	 0.011684	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55641	 55642	 0.009733	 0.016256	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55641	 94383	 0.003247	 0.015846	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55641	 94386	 0.005548	 0.021581	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55642	 94591	 0.037101	 0.037473	 0.0005	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55643	 55697	 0.000722	 0.00281	 0.00075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55643	 94383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55643	 94383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55643	 94385	 0.00361	 0.009371	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55644	 55649	 0.007379	 0.017131	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55644	 94386	 0.00764	 0.026748	 0.00074	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55645	 55698	 0.000252	 0.003292	 0.02979	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55645	 55853	 0.000896	 0.011306	 0.11023	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55645	 94384	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94385	 55646	 0.001336	 0.00525	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55646	 94387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55646	 94387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55647	 55648	 0.004121	 0.008798	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55647	 55649	 0.004557	 0.014674	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55647	 55670	 0.005837	 0.014844	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94387	 55648	 0.007403	 0.01903	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55650	 55653	 0.005794	 0.01912	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94368	 55650	 0.003976	 0.010304	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55651	 55655	 0.000353	 0.00256	 0.00515	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92798	 55651	 0.001163	 0.007548	 0.01503	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55651	 94388	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55651	 94388	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55652	 55653	 0.003281	 0.011722	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55652	 94390	 0.002577	 0.011481	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55654	 94391	 0.004705	 0.018102	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55655	 55656	 8.1e-05	 0.000846	 0.00159	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55655	 94389	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94390	 55655	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55656	 55666	 0.00022	 0.002543	 0.00487	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55656	 94391	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55656	 94391	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55657	 55659	 0.001022	 0.003884	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94389	 55657	 0.001018	 0.004203	 0.00099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94388	 55658	 0.001519	 0.00608	 0.00153	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55658	 94392	 0.001912	 0.008092	 0.00182	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55659	 55662	 0.002009	 0.005602	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55659	 94392	 0.001702	 0.007203	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55660	 94392	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55661	 55662	 0.002591	 0.006727	 0.00163	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55661	 55672	 0.00315	 0.008456	 0.00192	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55662	 94394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55662	 94394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94394	 55663	 0.022917	 0.017579	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55664	 55665	 0.004295	 0.009169	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94394	 55664	 0.010918	 0.020301	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94391	 55665	 0.002543	 0.009894	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55666	 55744	 0.002365	 0.015959	 0.02939	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94384	 55666	 0.00047	 0.005513	 0.0123	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55666	 94395	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55666	 94395	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55667	 55668	 0.005958	 0.026253	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94395	 55667	 0.002483	 0.012418	 0.00022	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55668	 55669	 0.009244	 0.026231	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94393	 55668	 0.012912	 0.049472	 0.0014	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55669	 55671	 0.006655	 0.023284	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55671	 55717	 0.009595	 0.024665	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55671	 94416	 0.017747	 0.042025	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55672	 55673	 0.003155	 0.008338	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92799	 55673	 0.003423	 0.011742	 0.00281	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92798	 55674	 0.000333	 0.002159	 0.0043	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55674	 94396	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94397	 55674	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55674	 94426	 0.000953	 0.006184	 0.01232	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55675	 55684	 0.002076	 0.005572	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94396	 55675	 0.000772	 0.003542	 0.00091	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55675	 94398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55675	 94398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94397	 55676	 0.021644	 0.017129	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92799	 55677	 0.000881	 0.006549	 0.0025	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55677	 94399	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55677	 94399	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55678	 55679	 0.001658	 0.006002	 0.00129	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55678	 94400	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55678	 94400	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55679	 55680	 0.000914	 0.003309	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55680	 55689	 0.002419	 0.006493	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92799	 55680	 0.002448	 0.0098	 0.00247	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55680	 94401	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55680	 94401	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94401	 55681	 0.009526	 0.012519	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55682	 55683	 0.020011	 0.014723	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94398	 55682	 0.004743	 0.015823	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55683	 94402	 0.012485	 0.011708	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55684	 55685	 0.000893	 0.00236	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55685	 55686	 0.000588	 0.002648	 0.0007	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55685	 55686	 0.000588	 0.002648	 0.0007	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55685	 55745	 0.001085	 0.004345	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55686	 55689	 0.000963	 0.003748	 0.001	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55686	 55689	 0.000963	 0.003748	 0.001	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55686	 94402	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55686	 94402	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55687	 55688	 0.006958	 0.012236	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55687	 94427	 0.004038	 0.018067	 0.00037	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94402	 55688	 0.013025	 0.014187	 0.00019	 33.0	 33.0	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55689	 94403	 0.00215	 0.007376	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55689	 94403	 0.00215	 0.007376	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55690	 55696	 0.000359	 0.002364	 0.00457	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92698	 55690	 0.000544	 0.005417	 0.01808	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55690	 94403	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55690	 94403	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55691	 55692	 0.004893	 0.011359	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94400	 55691	 0.002712	 0.01322	 0.00025	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55692	 94404	 0.026774	 0.034843	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55692	 94406	 0.004481	 0.017432	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94375	 55693	 0.004984	 0.019391	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55693	 94404	 0.00916	 0.021266	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92656	 55694	 0.001326	 0.006275	 0.00151	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55694	 94404	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55694	 94404	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55694	 94405	 0.00101	 0.004043	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55695	 55696	 0.000226	 0.001558	 0.00275	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94373	 55695	 0.00057	 0.00387	 0.00705	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55695	 94405	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94406	 55695	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55697	 55701	 0.001	 0.003929	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55697	 94407	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55697	 94407	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55698	 56244	 0.000532	 0.006142	 0.05385	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55698	 57105	 0.000694	 0.009222	 0.14618	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55698	 57135	 0.000847	 0.011199	 0.17945	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55698	 94408	 7.8e-05	 0.006249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55699	 56292	 0.002461	 0.009674	 0.00253	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94409	 55699	 0.002085	 0.008193	 0.00214	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55699	 94411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55699	 94411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94411	 55700	 0.00988	 0.011581	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55701	 56293	 0.001957	 0.005172	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55701	 94412	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55701	 94412	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55702	 55704	 0.004452	 0.02148	 0.00038	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55702	 94413	 0.018382	 0.033039	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55703	 56294	 0.001838	 0.005324	 0.00128	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94409	 55703	 0.001251	 0.006393	 0.00174	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55703	 94413	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55703	 94413	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55704	 94631	 0.004247	 0.02611	 0.00047	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94410	 55705	 0.039246	 0.041911	 0.00089	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55706	 94648	 0.021964	 0.043487	 0.00064	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55707	 94418	 0.055619	 0.056177	 0.00074	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55707	 94648	 0.015831	 0.055393	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55708	 55710	 0.034356	 0.027189	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55708	 57123	 0.022768	 0.037321	 0.00066	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55709	 55713	 0.002424	 0.008087	 0.00205	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55709	 94414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55709	 94414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55710	 55711	 0.005906	 0.014659	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55710	 55712	 0.035585	 0.035594	 0.00048	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94410	 55710	 0.033637	 0.072084	 0.00126	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94414	 55711	 0.004132	 0.018207	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94414	 55712	 0.005706	 0.017524	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55713	 56337	 0.002308	 0.009767	 0.0022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55713	 56339	 0.004163	 0.011003	 0.00258	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55713	 57122	 0.003365	 0.022005	 0.0056	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55713	 94415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55713	 94415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94415	 55714	 0.014827	 0.029355	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55715	 55716	 0.002007	 0.011755	 0.0032	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55715	 94647	 0.00115	 0.009177	 0.00226	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55716	 55718	 0.003435	 0.009579	 0.00201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55716	 94416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55716	 94416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94416	 55717	 0.008164	 0.020987	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55718	 55719	 0.003136	 0.008141	 0.00198	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55719	 55721	 0.002005	 0.006877	 0.00165	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55720	 55721	 0.001362	 0.005298	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55720	 55722	 0.001217	 0.004784	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55721	 55742	 0.003678	 0.014456	 0.00378	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55722	 55723	 0.004205	 0.012059	 0.00297	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55722	 55727	 0.002532	 0.016963	 0.0052	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55722	 94417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55722	 94417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55723	 94418	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55723	 94418	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55724	 55729	 0.01071	 0.029667	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94417	 55724	 0.029179	 0.03493	 0.00058	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55725	 55726	 0.004531	 0.019962	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94417	 55725	 0.009233	 0.019406	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55726	 94419	 0.007407	 0.033623	 0.00073	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55727	 55735	 0.001127	 0.006213	 0.00145	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55727	 55738	 0.004996	 0.020331	 0.00495	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55727	 94419	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55727	 94419	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55728	 55729	 0.009408	 0.036195	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55728	 55731	 0.004033	 0.014122	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94419	 55728	 0.019565	 0.045422	 0.00068	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55729	 94648	 0.095499	 0.12552	 0.00172	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55730	 94892	 0.012262	 0.024278	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55731	 94892	 0.006522	 0.034747	 0.00061	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55732	 55733	 0.005842	 0.012279	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55732	 94421	 0.004546	 0.010555	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55733	 94892	 0.018764	 0.028744	 0.0004	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55734	 55736	 0.001287	 0.008931	 0.00255	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55734	 57128	 0.001398	 0.009698	 0.00277	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55735	 55736	 0.000864	 0.004413	 0.00111	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55735	 94420	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55735	 94420	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55736	 57127	 0.00414	 0.010407	 0.0027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55736	 94421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55736	 94421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55737	 94893	 0.042652	 0.084449	 0.00124	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55738	 94422	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55738	 94422	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55738	 94423	 0.005229	 0.020936	 0.00527	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55739	 56862	 0.000671	 0.006705	 0.01387	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55739	 94423	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94424	 55739	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55740	 55741	 0.002646	 0.011915	 0.00317	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94423	 55740	 0.003666	 0.015955	 0.00455	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55741	 55743	 0.002499	 0.011464	 0.00294	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55742	 55743	 0.003276	 0.013864	 0.00312	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92682	 55743	 0.001806	 0.0136	 0.00377	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92681	 55744	 0.000381	 0.002625	 0.00463	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92783	 55744	 0.000661	 0.004352	 0.00842	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55744	 94425	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55744	 94425	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55745	 55746	 0.000715	 0.004064	 0.00118	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92784	 55746	 0.001461	 0.008016	 0.00212	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55746	 94429	 0.003111	 0.010482	 0.00261	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55747	 55748	 9.9e-05	 0.001145	 0.01003	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55747	 94426	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55748	 55940	 0.000283	 0.003204	 0.02916	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55748	 94428	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55748	 94428	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92681	 55749	 0.000147	 0.001679	 0.00328	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55749	 94429	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55749	 94429	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55750	 55751	 0.018204	 0.060726	 0.00096	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94424	 55750	 0.010484	 0.049302	 0.00092	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55751	 55753	 0.019967	 0.051328	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55751	 94431	 0.06636	 0.083386	 0.00126	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55752	 55758	 0.004038	 0.015869	 0.00415	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92682	 55752	 0.006889	 0.018207	 0.00426	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94429	 55752	 0.00511	 0.014249	 0.00299	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55752	 94430	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55752	 94430	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92825	 55753	 0.036916	 0.073091	 0.00107	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94430	 55753	 0.020774	 0.038049	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55754	 55755	 0.002333	 0.009631	 0.00228	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93955	 55754	 0.005984	 0.026047	 0.00742	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55754	 94431	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55754	 94431	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55755	 55758	 0.001786	 0.01064	 0.0028	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92661	 55755	 0.001422	 0.015068	 0.00447	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55756	 55758	 0.000996	 0.008082	 0.00257	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92691	 55756	 0.001035	 0.011654	 0.00337	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55757	 94432	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55757	 94432	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92824	 55758	 0.000817	 0.004682	 0.00156	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55759	 55760	 0.007038	 0.020186	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92836	 55759	 0.007706	 0.011805	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55760	 94434	 0.003427	 0.020825	 0.00038	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92660	 55761	 0.00033	 0.003987	 0.00839	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92783	 55761	 0.002035	 0.015944	 0.02742	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55761	 94433	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94434	 55761	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55762	 55764	 5.3e-05	 0.000863	 0.00841	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55762	 94435	 7.8e-05	 0.006249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94437	 55763	 0.021698	 0.017859	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55763	 94439	 0.026076	 0.019185	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55764	 55766	 2.8e-05	 0.000528	 0.00934	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55764	 94438	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55765	 55767	 0.004506	 0.01146	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94439	 55765	 0.004677	 0.019114	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55766	 55768	 2.8e-05	 0.000555	 0.0089	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55767	 94441	 0.018481	 0.02013	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55768	 55769	 3e-05	 0.000524	 0.0087	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55768	 94440	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92592	 55770	 0.01875	 0.053779	 0.00083	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55771	 55774	 0.000884	 0.003361	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94364	 55771	 0.000584	 0.004688	 0.00132	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55771	 94442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55771	 94442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55772	 55773	 0.007503	 0.017418	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55772	 55792	 0.006932	 0.013724	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94442	 55772	 0.007853	 0.012534	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55773	 55776	 0.004638	 0.011922	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55773	 94445	 0.007194	 0.018295	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55774	 55775	 0.001325	 0.003501	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94374	 55775	 0.00165	 0.009055	 0.00239	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55776	 55778	 0.015481	 0.015636	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55777	 55778	 0.003479	 0.009624	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55777	 55788	 0.025477	 0.01997	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55777	 94444	 0.003663	 0.010506	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55778	 55779	 0.015968	 0.012517	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55778	 55780	 0.009316	 0.01958	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55779	 55781	 0.007124	 0.014973	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94375	 55780	 0.004504	 0.020069	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55781	 55782	 0.029659	 0.02275	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94375	 55781	 0.007317	 0.022023	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55782	 55783	 0.006261	 0.012396	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55782	 94444	 0.010233	 0.023753	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55783	 55785	 0.007956	 0.013402	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94374	 55784	 0.002143	 0.010399	 0.00238	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55784	 94443	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55784	 94443	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55784	 94469	 0.00183	 0.007329	 0.00185	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55785	 55786	 0.00493	 0.00976	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94443	 55785	 0.002145	 0.013035	 0.00024	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55786	 55787	 0.017386	 0.02285	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55786	 55814	 0.003886	 0.008168	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55786	 55885	 0.014094	 0.0116	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55787	 55788	 0.002975	 0.014354	 0.00025	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55787	 55884	 0.00371	 0.009434	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55788	 94444	 0.005145	 0.013084	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55788	 94450	 0.003825	 0.018675	 0.00039	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55789	 55790	 0.000731	 0.003094	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55789	 94444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55789	 94444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55790	 55791	 0.000506	 0.001922	 0.00054	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55790	 94445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55790	 94445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55791	 55799	 0.001076	 0.004307	 0.00145	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55792	 55797	 0.006687	 0.01918	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55793	 55794	 0.012685	 0.00917	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55794	 55797	 0.008523	 0.008609	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55795	 55796	 0.006499	 0.014863	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55795	 55958	 0.004657	 0.009221	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55796	 55797	 0.003793	 0.012519	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55796	 55800	 0.014602	 0.010743	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55796	 94449	 0.00284	 0.016563	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55798	 94446	 0.013915	 0.010674	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55799	 94446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55799	 94446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55799	 94448	 0.001265	 0.006702	 0.0017	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55801	 55900	 0.000197	 0.002855	 0.02582	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55801	 56026	 0.000584	 0.006736	 0.05905	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55801	 56186	 0.000749	 0.008642	 0.07577	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55801	 94447	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94446	 55802	 0.00919	 0.010108	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55803	 94450	 0.013043	 0.013046	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94448	 55804	 0.003381	 0.013155	 0.00351	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55804	 94450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55804	 94450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55805	 55806	 0.004484	 0.010409	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55805	 55877	 0.014337	 0.011346	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94450	 55805	 0.006707	 0.011979	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55806	 55807	 0.005875	 0.011631	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55806	 55876	 0.034519	 0.027057	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55806	 94451	 0.010153	 0.026099	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55807	 55808	 0.004843	 0.012449	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55808	 55866	 0.008119	 0.014871	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55808	 94451	 0.00422	 0.011689	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55809	 55975	 0.003349	 0.00899	 0.00204	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94448	 55809	 0.00139	 0.005563	 0.0014	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55809	 94451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55809	 94451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94451	 55810	 0.005143	 0.011939	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55811	 55813	 0.010864	 0.010866	 0.00015	 33.0	 33.0	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55812	 55813	 0.006677	 0.013086	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55812	 55988	 0.003339	 0.009237	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55814	 94452	 0.005296	 0.012294	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55815	 55816	 0.001782	 0.006454	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55815	 94452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55815	 94452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92656	 55816	 0.00064	 0.006148	 0.00179	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55816	 94453	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55816	 94453	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55816	 94469	 0.000737	 0.004747	 0.00124	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55817	 55818	 0.003464	 0.008042	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94452	 55817	 0.006505	 0.014946	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55818	 55819	 0.0126	 0.012726	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55819	 55889	 0.01285	 0.019054	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55819	 94454	 0.00603	 0.015335	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55820	 94454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55820	 94454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55820	 94475	 0.001716	 0.007262	 0.00163	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55821	 55822	 0.008322	 0.016478	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55821	 94476	 0.006001	 0.019322	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55822	 55825	 0.017079	 0.01725	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55823	 94455	 0.007313	 0.018798	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55824	 55846	 0.001518	 0.004233	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55824	 94455	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55824	 94455	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55825	 55827	 0.014125	 0.013648	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94455	 55825	 0.013999	 0.01495	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55825	 94476	 0.009907	 0.034666	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55826	 55827	 0.010161	 0.013354	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55826	 55829	 0.009561	 0.016106	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94454	 55826	 0.008286	 0.016405	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55827	 55828	 0.017545	 0.011358	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55828	 55845	 0.014408	 0.009328	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55829	 55830	 0.022437	 0.017756	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55829	 94457	 0.002392	 0.009164	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55830	 55831	 0.016597	 0.012574	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94453	 55831	 0.015309	 0.014102	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94453	 55832	 0.005096	 0.019824	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55832	 94456	 0.001374	 0.007566	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55833	 55835	 0.000475	 0.001679	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55833	 55839	 0.001268	 0.00571	 0.00152	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92656	 55833	 0.001513	 0.005948	 0.00156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55833	 94456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55833	 94456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55834	 55843	 0.000867	 0.002973	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92656	 55834	 0.003109	 0.010663	 0.00255	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55834	 94457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55834	 94457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55835	 55839	 0.000896	 0.003927	 0.00135	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92656	 55835	 0.001554	 0.006223	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55835	 94458	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55835	 94458	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55836	 55930	 0.000651	 0.002754	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55836	 94459	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55836	 94459	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55836	 94460	 0.000579	 0.002319	 0.00058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55837	 55890	 0.000411	 0.004508	 0.04379	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55837	 55931	 9.5e-05	 0.001297	 0.01322	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55837	 94460	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55837	 94460	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55838	 55839	 0.000834	 0.003246	 0.00087	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94460	 55838	 0.000617	 0.003677	 0.00097	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55838	 94461	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55838	 94461	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94460	 55839	 0.001706	 0.006832	 0.00172	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94460	 55839	 0.001706	 0.006832	 0.00172	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55839	 94462	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55839	 94462	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55839	 94468	 0.001688	 0.006568	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55839	 94468	 0.001688	 0.006568	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55840	 55843	 0.000783	 0.002741	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55840	 94463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55840	 94463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55841	 55842	 0.003356	 0.01291	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94459	 55841	 0.003132	 0.014522	 0.0003	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94463	 55842	 0.006808	 0.010866	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55843	 55847	 0.002992	 0.009757	 0.00259	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55844	 55845	 0.008079	 0.014797	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55844	 55849	 0.006713	 0.011309	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94457	 55844	 0.003661	 0.014296	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55846	 55847	 0.00129	 0.004425	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55846	 94464	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55846	 94464	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55847	 55851	 0.001433	 0.005446	 0.00152	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55847	 55852	 0.002243	 0.005929	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55847	 94465	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55847	 94465	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94464	 55848	 0.011803	 0.01536	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94465	 55848	 0.00762	 0.013696	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55848	 94467	 0.017382	 0.013756	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55849	 55850	 0.004451	 0.009538	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55850	 94466	 0.002625	 0.010957	 0.00032	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55851	 94466	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55851	 94466	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55851	 94495	 0.001179	 0.009292	 0.00272	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55852	 94467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55852	 94467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55852	 94484	 0.003234	 0.009536	 0.00222	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55853	 94468	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55853	 94468	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55854	 94469	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55854	 94469	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55854	 94474	 0.001213	 0.007682	 0.01609	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55855	 55862	 3.4e-05	 0.000828	 0.01412	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55855	 55900	 3.6e-05	 0.000653	 0.01245	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55855	 94470	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55855	 94470	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55856	 55857	 0.007802	 0.017504	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94470	 55856	 0.010141	 0.026878	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55857	 94517	 0.006958	 0.012938	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94257	 55858	 0.013339	 0.021292	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55859	 56014	 0.00745	 0.011892	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55860	 94471	 0.015957	 0.024444	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94470	 55861	 0.022634	 0.016362	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55862	 55863	 2.4e-05	 0.000549	 0.01036	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55862	 94471	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55862	 94471	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55864	 94472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55864	 94472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55864	 94482	 0.003768	 0.019628	 0.00515	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55865	 55870	 0.014343	 0.033293	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55865	 94483	 0.010225	 0.035801	 0.00099	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55866	 55867	 0.005105	 0.013123	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55867	 94473	 0.007569	 0.021709	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55868	 94473	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55868	 94473	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55868	 94482	 0.001554	 0.008529	 0.00225	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55869	 55874	 0.003592	 0.016005	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94473	 55869	 0.003539	 0.015836	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55870	 55871	 0.009194	 0.017094	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55871	 55872	 0.010981	 0.025494	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55872	 55873	 0.011002	 0.019852	 0.00029	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55872	 94478	 0.007499	 0.026789	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55873	 55874	 0.005785	 0.016592	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55873	 55880	 0.018847	 0.019036	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55874	 55875	 0.006096	 0.012069	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55874	 55880	 0.003294	 0.015275	 0.00032	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94473	 55874	 0.008494	 0.033045	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55875	 55876	 0.012157	 0.012279	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55878	 55883	 0.006529	 0.016783	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94450	 55878	 0.002861	 0.014555	 0.00033	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55879	 55880	 0.002344	 0.009922	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55879	 55882	 0.004709	 0.01832	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55881	 55882	 0.005032	 0.011682	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55881	 55892	 0.003818	 0.009815	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55882	 55883	 0.005921	 0.013745	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55883	 55884	 0.008141	 0.010595	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55883	 94478	 0.010598	 0.050649	 0.00111	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55884	 55885	 0.010709	 0.017859	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55885	 55886	 0.016355	 0.01282	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94452	 55885	 0.009647	 0.01869	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55886	 55887	 0.00493	 0.00886	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55887	 55891	 0.004501	 0.012774	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55888	 55889	 0.01306	 0.011162	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55889	 94646	 0.004995	 0.019433	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55890	 55893	 0.000145	 0.001537	 0.01603	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55890	 94474	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55891	 55892	 0.025885	 0.017387	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55891	 94646	 0.008674	 0.022296	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55892	 94478	 0.008187	 0.027312	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55893	 55900	 0.000304	 0.003833	 0.05842	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55893	 94477	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94477	 55894	 0.000956	 0.006761	 0.00186	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55894	 94479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55894	 94479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94479	 55895	 0.013604	 0.023925	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55895	 94480	 0.026016	 0.020392	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55896	 55897	 0.00087	 0.003485	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94475	 55896	 0.001648	 0.006976	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55896	 94480	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55896	 94480	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55897	 55948	 0.008877	 0.02546	 0.00626	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55897	 94481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55897	 94481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94481	 55898	 0.014475	 0.014518	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55899	 55943	 0.004676	 0.010855	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94481	 55899	 0.004281	 0.012278	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55900	 94482	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55901	 94485	 0.014543	 0.028501	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94474	 55902	 0.001333	 0.009185	 0.01621	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55902	 94484	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94485	 55902	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55903	 55925	 0.00216	 0.007409	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94484	 55903	 0.002334	 0.007862	 0.00195	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55904	 55906	 0.000445	 0.004188	 0.00127	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92623	 55904	 0.000932	 0.008945	 0.0026	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55905	 55909	 0.00718	 0.016666	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55905	 94486	 0.003579	 0.012523	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55906	 55907	 0.000757	 0.004347	 0.00123	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94484	 55906	 0.004814	 0.012499	 0.00303	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94484	 55906	 0.004814	 0.012499	 0.00303	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55906	 94486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55906	 94486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55907	 55908	 0.000672	 0.003861	 0.00109	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55907	 55917	 0.002476	 0.006905	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55908	 55910	 0.001098	 0.003975	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55908	 55918	 0.002004	 0.005037	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55909	 94487	 0.005954	 0.014099	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55910	 55914	 0.001892	 0.00649	 0.00155	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55910	 94487	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55910	 94487	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94485	 55911	 0.008871	 0.031038	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94487	 55911	 0.014741	 0.022099	 0.0004	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55912	 55947	 0.01157	 0.022907	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94487	 55912	 0.008161	 0.020978	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94487	 55913	 0.005807	 0.013479	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55913	 94488	 0.02749	 0.021755	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55914	 55951	 0.003518	 0.009044	 0.00224	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55914	 94488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55914	 94488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94488	 55915	 0.01175	 0.023027	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55916	 55917	 0.002813	 0.007304	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55916	 94489	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55916	 94489	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55917	 94490	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55917	 94490	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55918	 94491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55918	 94491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55918	 94492	 0.0023	 0.014566	 0.00395	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92622	 55919	 0.000254	 0.003286	 0.00744	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94314	 55919	 0.004124	 0.028417	 0.05018	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55919	 94492	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94493	 55919	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55920	 55921	 0.001762	 0.004429	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55920	 55922	 0.002917	 0.006771	 0.00206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92794	 55922	 0.000818	 0.010078	 0.00326	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55922	 94494	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55922	 94494	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55922	 94503	 0.002315	 0.016654	 0.00441	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92795	 55923	 0.04773	 0.037773	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92795	 55924	 0.031721	 0.023338	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55925	 55935	 0.001777	 0.006982	 0.00183	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94467	 55926	 0.01785	 0.013992	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55927	 55928	 0.009166	 0.015225	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55928	 55929	 0.00591	 0.01503	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55929	 94496	 0.007854	 0.024119	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55929	 94499	 0.017608	 0.028245	 0.00052	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55930	 94495	 0.00092	 0.003682	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55931	 55932	 4.3e-05	 0.000583	 0.00594	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55931	 94495	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55932	 55933	 4.9e-05	 0.000668	 0.00681	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55933	 55938	 0.000136	 0.001513	 0.01427	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55933	 55940	 0.000103	 0.001491	 0.01368	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55933	 94497	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55933	 94497	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55934	 55935	 0.000657	 0.003777	 0.00107	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94497	 55934	 0.000949	 0.00601	 0.00163	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55934	 94498	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55934	 94498	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55935	 94499	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55935	 94499	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94498	 55936	 0.042302	 0.028415	 0.0005	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55936	 94504	 0.032613	 0.03294	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55937	 55939	 0.000237	 0.001537	 0.00306	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92622	 55937	 0.000533	 0.003671	 0.00648	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55937	 94502	 0.000326	 0.002114	 0.00421	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55938	 94500	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55938	 94500	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94500	 55939	 0.000233	 0.001554	 0.00293	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55940	 94501	 0.000119	 0.009523	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55940	 94501	 0.000119	 0.009523	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55941	 94502	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55942	 55944	 0.008807	 0.014837	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93880	 55942	 0.006207	 0.033072	 0.00058	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	55943	 55944	 0.006159	 0.013148	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55945	 55946	 0.014725	 0.021834	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94481	 55945	 0.014717	 0.029138	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55946	 55947	 0.032287	 0.042434	 0.00058	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94485	 55946	 0.018226	 0.046851	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55947	 94505	 0.019827	 0.017766	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55948	 55950	 0.001482	 0.003918	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55948	 94505	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55948	 94505	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94505	 55949	 0.004615	 0.010713	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55950	 55951	 0.002656	 0.006675	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55950	 94506	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55950	 94506	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55952	 55953	 0.000726	 0.002907	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94364	 55952	 0.001048	 0.004119	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55953	 56160	 0.00094	 0.003881	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55953	 94507	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55953	 94507	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55954	 55955	 0.010871	 0.010115	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55954	 94563	 0.005514	 0.010917	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55955	 55956	 0.008294	 0.007778	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55955	 55963	 0.00838	 0.016591	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55955	 55964	 0.011734	 0.009286	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55956	 55959	 0.011933	 0.012053	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55957	 55959	 0.011928	 0.00935	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94507	 55957	 0.010062	 0.01096	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55958	 55959	 0.005742	 0.013191	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55959	 55960	 0.00152	 0.004661	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55960	 55962	 0.003593	 0.009816	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55961	 55962	 0.012069	 0.00946	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55962	 55973	 0.008566	 0.006779	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55962	 94509	 0.003895	 0.013638	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55963	 55969	 0.015986	 0.012531	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55963	 94509	 0.004199	 0.025521	 0.00047	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55965	 55967	 0.006887	 0.009777	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	55965	 56161	 0.013965	 0.018354	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55966	 56057	 0.016707	 0.021262	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55967	 55969	 0.00462	 0.011877	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55967	 94508	 0.00225	 0.011699	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	55968	 55970	 0.00111	 0.002934	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55968	 55972	 0.001519	 0.004014	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55968	 56058	 0.002265	 0.005694	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55968	 94508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55968	 94508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55970	 56059	 0.001018	 0.002734	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55971	 94520	 0.00787	 0.018081	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55972	 55975	 0.002824	 0.007464	 0.00175	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55972	 55978	 0.001333	 0.003628	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55974	 55975	 0.000906	 0.002352	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55974	 55977	 0.001448	 0.004037	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55975	 55985	 0.003527	 0.00932	 0.00218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94448	 55975	 0.000355	 0.003464	 0.00097	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55975	 94509	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55975	 94509	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55976	 55987	 0.001072	 0.002832	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55976	 94510	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55976	 94510	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55977	 55978	 0.00107	 0.002873	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55978	 55980	 0.000903	 0.002425	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55978	 94511	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55978	 94511	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94511	 55979	 0.011855	 0.008722	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55979	 94513	 0.006697	 0.012037	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55980	 55981	 0.000895	 0.002496	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55981	 55998	 0.001136	 0.003094	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55982	 55984	 0.000797	 0.002735	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55982	 55997	 0.001635	 0.004389	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55982	 94512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55982	 94512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94512	 55983	 0.005444	 0.01439	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55983	 94516	 0.004685	 0.015628	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	55984	 55985	 0.000883	 0.002559	 0.00062	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55985	 55987	 0.001228	 0.003086	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55985	 94513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55985	 94513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55986	 94514	 0.006765	 0.005354	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55987	 94514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55987	 94514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94483	 55988	 0.006689	 0.038024	 0.00069	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94513	 55988	 0.008286	 0.012929	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55989	 94515	 0.013816	 0.010468	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	55990	 55991	 0.000847	 0.002763	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55990	 55992	 0.001663	 0.004464	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55990	 55995	 0.002549	 0.006736	 0.00158	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94448	 55990	 0.004474	 0.017911	 0.00451	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94482	 55990	 0.00209	 0.008366	 0.00211	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55990	 94515	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55990	 94515	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55991	 55995	 0.001474	 0.003827	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55991	 94516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55991	 94516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55992	 55994	 0.001416	 0.003741	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55993	 55994	 0.001258	 0.003324	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55993	 56013	 0.001389	 0.003671	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55993	 94517	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55993	 94517	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55994	 94518	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55994	 94518	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55995	 56011	 0.001484	 0.004137	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55995	 56019	 0.002973	 0.008291	 0.00174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55996	 56010	 0.0047	 0.012082	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	55996	 94519	 0.00649	 0.015067	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	55997	 56008	 0.001468	 0.00381	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	55997	 94519	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55997	 94519	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55998	 56007	 0.000924	 0.003013	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55998	 94520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55998	 94520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55999	 56007	 0.00107	 0.003606	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	55999	 56059	 0.001469	 0.004097	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56000	 56069	 0.003196	 0.009166	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56000	 94522	 0.001684	 0.008082	 0.00024	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56001	 56002	 0.005127	 0.006739	 9e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56001	 56068	 0.009241	 0.008512	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56002	 56004	 0.001272	 0.003905	 7e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56002	 94522	 0.02209	 0.017315	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56003	 56008	 0.001395	 0.004784	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56003	 56022	 0.000384	 0.003293	 0.00094	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56003	 56050	 0.003582	 0.01056	 0.00246	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56003	 94521	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56003	 94521	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94521	 56004	 0.002064	 0.009563	 0.00018	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56005	 56006	 0.009292	 0.006015	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56006	 94522	 0.006014	 0.010576	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56007	 56052	 0.003575	 0.009596	 0.00217	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56007	 94522	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56007	 94522	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56007	 94530	 0.001906	 0.013787	 0.00742	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56008	 94523	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56008	 94523	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56009	 56010	 0.001754	 0.00717	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56009	 56020	 0.001819	 0.011184	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56011	 56019	 0.001491	 0.003872	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56012	 56018	 0.017563	 0.013899	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94518	 56012	 0.020452	 0.016031	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56013	 56015	 0.001693	 0.004395	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56014	 94524	 0.004997	 0.010667	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56015	 94524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56015	 94524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56015	 94532	 0.002387	 0.007962	 0.00202	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94524	 56016	 0.010475	 0.008211	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56017	 56018	 0.008949	 0.009039	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56018	 94533	 0.006333	 0.021125	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56019	 56024	 0.003103	 0.008202	 0.00192	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56019	 94525	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56019	 94525	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56019	 94532	 0.002025	 0.008569	 0.00193	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56020	 56021	 0.012277	 0.013111	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94525	 56020	 0.002146	 0.010301	 0.00031	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56022	 56023	 0.00036	 0.00309	 0.00088	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56022	 94526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56022	 94526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56023	 56024	 0.000472	 0.003559	 0.00099	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56023	 94527	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56023	 94527	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56024	 56082	 0.001645	 0.004849	 0.00113	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56024	 94528	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56024	 94528	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56024	 94530	 0.000442	 0.004684	 0.00139	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56025	 56029	 0.013345	 0.008639	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94528	 56025	 0.018581	 0.014704	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56026	 94529	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56027	 56033	 0.002918	 0.011351	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94531	 56027	 0.001679	 0.008842	 0.00016	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94447	 56028	 0.00205	 0.014318	 0.02458	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94529	 56028	 8.4e-05	 0.001119	 0.00239	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56028	 94532	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56028	 94532	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56029	 94533	 0.00547	 0.010476	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94532	 56030	 0.001072	 0.003881	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56030	 94533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56030	 94533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56031	 56032	 0.012501	 0.01375	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56031	 56034	 0.008101	 0.014838	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94524	 56031	 0.017717	 0.01255	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94533	 56031	 0.004267	 0.012109	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56032	 56033	 0.003499	 0.011674	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56035	 56173	 0.007682	 0.014884	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56035	 94541	 0.014692	 0.034109	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56036	 56055	 0.004571	 0.010902	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56036	 94534	 0.004411	 0.014716	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56037	 56048	 0.002001	 0.007863	 0.00206	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56037	 56198	 0.001302	 0.005064	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56037	 94534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56037	 94534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56038	 56039	 0.010731	 0.022553	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56038	 94537	 0.008161	 0.023157	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56038	 94538	 0.0076	 0.017998	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56039	 56194	 0.006169	 0.014321	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56040	 56041	 0.005441	 0.012444	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56040	 56043	 0.007006	 0.01373	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56041	 56042	 0.004162	 0.013736	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56042	 56086	 0.003464	 0.010626	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56042	 56197	 0.015525	 0.02773	 0.00041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56043	 94536	 0.009411	 0.01655	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56044	 56046	 0.00089	 0.004938	 0.0015	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56044	 56094	 0.001069	 0.004281	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94530	 56044	 0.006648	 0.022805	 0.00546	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56044	 94535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56044	 94535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56045	 56046	 0.000767	 0.00206	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56045	 94536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56045	 94536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56046	 56063	 0.000737	 0.002458	 0.00062	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56046	 94537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56046	 94537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94537	 56047	 0.004339	 0.011469	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56047	 94542	 0.003469	 0.008917	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56048	 56049	 0.000537	 0.001842	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56048	 56062	 0.001267	 0.00335	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56048	 94538	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56048	 94538	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56049	 56050	 0.000579	 0.00195	 0.00048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56049	 56062	 0.001303	 0.004717	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56049	 94539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56049	 94539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56050	 56051	 0.000561	 0.001653	 0.00038	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56050	 56052	 0.000917	 0.002705	 0.00063	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56051	 56052	 0.000406	 0.001073	 0.00025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56052	 56058	 0.001403	 0.004812	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56052	 94540	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56052	 94540	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56053	 56055	 0.005502	 0.008782	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56053	 56056	 0.007331	 0.012893	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94539	 56053	 0.0084	 0.019892	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94534	 56054	 0.011388	 0.018177	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94539	 56054	 0.007826	 0.013184	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56057	 56069	 0.009928	 0.019656	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94540	 56057	 0.001221	 0.006347	 0.00014	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56057	 94541	 0.016251	 0.012861	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56058	 94541	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56058	 94541	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56060	 56069	 0.004683	 0.006526	 0.00011	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56061	 56068	 0.008116	 0.008927	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56062	 56066	 0.001124	 0.005156	 0.00132	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56062	 94542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56062	 94542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56063	 56066	 0.000932	 0.0026	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56064	 56065	 0.011289	 0.011046	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94535	 56064	 0.005069	 0.016324	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56065	 56074	 0.007386	 0.009004	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56066	 56082	 0.00215	 0.013001	 0.00332	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56066	 94543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56066	 94543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94542	 56067	 0.004706	 0.008895	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94542	 56068	 0.006251	 0.015835	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56070	 56071	 0.006983	 0.012551	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94526	 56071	 0.004715	 0.010944	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94543	 56071	 0.025643	 0.02362	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56072	 56075	 0.010208	 0.017195	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56073	 56080	 0.018426	 0.013052	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56074	 56076	 0.012476	 0.009874	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56074	 56114	 0.025275	 0.019811	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56074	 94545	 0.008367	 0.037284	 0.00063	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56075	 56076	 0.005471	 0.009772	 0.00014	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56075	 56080	 0.006799	 0.016876	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56076	 56078	 0.011758	 0.012933	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56076	 56115	 0.013169	 0.014484	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56077	 56078	 0.003398	 0.006659	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56077	 56124	 0.013424	 0.009876	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56078	 56079	 0.002172	 0.00667	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94528	 56079	 0.004895	 0.019045	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56080	 94544	 0.005417	 0.018071	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56081	 56082	 0.000916	 0.002378	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94532	 56081	 0.001957	 0.006593	 0.00164	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56081	 94544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56081	 94544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56082	 56084	 0.000835	 0.003343	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94530	 56082	 0.000199	 0.003198	 0.00104	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56082	 94545	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56082	 94545	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94545	 56083	 0.002616	 0.006725	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56083	 94554	 0.004746	 0.009397	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56084	 56126	 0.000812	 0.003436	 0.00077	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94530	 56084	 0.000203	 0.002176	 0.0007	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56084	 94546	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56084	 94546	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94264	 56085	 0.007437	 0.019117	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56086	 94548	 0.003157	 0.009684	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56087	 94547	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94548	 56087	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56087	 94612	 0.000356	 0.00369	 0.00795	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56088	 56089	 0.006588	 0.015295	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94548	 56088	 0.008189	 0.019011	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56089	 56091	 0.015758	 0.012352	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56089	 56104	 0.015296	 0.019737	 0.0004	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56090	 56105	 0.008607	 0.01547	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56090	 94614	 0.023351	 0.04277	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56091	 56104	 0.005676	 0.011237	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56092	 56098	 0.004749	 0.010772	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94548	 56092	 0.004287	 0.014302	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56093	 56094	 0.000183	 0.002027	 0.00061	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94547	 56093	 0.000497	 0.005325	 0.0017	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56094	 94549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56094	 94549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56095	 56113	 0.003351	 0.008881	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94549	 56095	 0.002176	 0.011464	 0.00021	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56096	 56097	 0.008038	 0.008754	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94549	 56096	 0.006572	 0.014908	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56097	 56112	 0.018461	 0.018465	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56098	 56099	 0.006577	 0.013823	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56099	 56100	 0.005737	 0.010666	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56100	 94551	 0.007202	 0.016547	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56101	 56103	 0.006187	 0.011051	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56101	 56104	 0.01724	 0.013643	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56102	 56103	 0.003113	 0.010384	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56102	 94551	 0.004334	 0.011023	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56103	 94550	 0.00274	 0.010963	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56104	 94558	 0.00903	 0.041925	 0.00114	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56105	 94550	 0.009271	 0.021525	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56106	 94550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56106	 94550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56106	 94557	 0.001997	 0.008244	 0.00195	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56106	 94613	 0.004745	 0.018996	 0.00479	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94550	 56107	 0.010784	 0.013387	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56108	 94553	 0.01423	 0.012751	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56109	 56110	 0.000781	 0.003128	 0.00079	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56109	 56111	 0.001157	 0.003411	 0.00079	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56109	 56118	 0.001433	 0.005631	 0.00147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56110	 56111	 0.001383	 0.003475	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56110	 56117	 0.000959	 0.003355	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56111	 94551	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56111	 94551	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56112	 56113	 0.009888	 0.015783	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94546	 56112	 0.069723	 0.075944	 0.00103	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94551	 56112	 0.007612	 0.025394	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56113	 56114	 0.002724	 0.00953	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56114	 56115	 0.014652	 0.014655	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56115	 56116	 0.005857	 0.015056	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94545	 56116	 0.023683	 0.037802	 0.00087	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56116	 94552	 0.006333	 0.021127	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56117	 94552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56117	 94552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56118	 94553	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56118	 94553	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56118	 94557	 0.001135	 0.006645	 0.00181	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56119	 56136	 0.008022	 0.015722	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94553	 56119	 0.003938	 0.012994	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56120	 56121	 0.007622	 0.009919	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56121	 56122	 0.004399	 0.008709	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94552	 56121	 0.005668	 0.014413	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56122	 56123	 0.01251	 0.013759	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56123	 94556	 0.007267	 0.016872	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56125	 56133	 0.001378	 0.003464	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56125	 94554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56125	 94554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56126	 56128	 0.000825	 0.00278	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56127	 94555	 0.01825	 0.014443	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56128	 56133	 0.001783	 0.004855	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56128	 94555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56128	 94555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94555	 56129	 0.014168	 0.011212	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56130	 56131	 0.005062	 0.009807	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94555	 56130	 0.006095	 0.013062	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56131	 56135	 0.003691	 0.010473	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56132	 94556	 0.017999	 0.014244	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56133	 94556	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56133	 94556	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56134	 56135	 0.004145	 0.010985	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56134	 56136	 0.003245	 0.019953	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94556	 56134	 0.021708	 0.02825	 0.0004	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56136	 94558	 0.012479	 0.048546	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56137	 56138	 0.0043	 0.010182	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56137	 94558	 0.011432	 0.023394	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56138	 94558	 0.007306	 0.01878	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56139	 56141	 0.015791	 0.012497	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94529	 56140	 0.001666	 0.011303	 0.02058	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56140	 94557	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94558	 56140	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56140	 94609	 0.003342	 0.030222	 0.0596	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94558	 56141	 0.007745	 0.019909	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56142	 56144	 0.009388	 0.041835	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94558	 56142	 0.016517	 0.036557	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56143	 56273	 0.014925	 0.029251	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94558	 56143	 0.031751	 0.068042	 0.00119	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56143	 94608	 0.008348	 0.037896	 0.00082	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56144	 56148	 0.004759	 0.022379	 0.00042	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56145	 56147	 0.00079	 0.003997	 0.00111	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56145	 56281	 0.000785	 0.003418	 0.00097	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56146	 94559	 0.009109	 0.018035	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56147	 56150	 0.000544	 0.003849	 0.00106	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56147	 94559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56147	 94559	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94268	 56148	 0.023884	 0.079675	 0.00126	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94559	 56148	 0.004892	 0.018086	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56150	 56151	 0.000466	 0.00289	 0.0007	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56150	 94560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56150	 94560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56151	 56153	 0.000822	 0.004525	 0.00163	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56152	 56282	 0.021803	 0.015761	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94560	 56152	 0.004684	 0.015625	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56152	 94561	 0.003855	 0.023426	 0.00043	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56153	 56283	 0.001465	 0.005179	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56153	 56284	 0.001042	 0.006671	 0.00224	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56153	 56285	 0.003516	 0.013363	 0.00374	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56153	 94561	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56153	 94561	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94365	 56154	 0.016595	 0.017681	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94365	 56155	 0.007993	 0.024548	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94507	 56155	 0.005967	 0.014605	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56155	 94562	 0.017085	 0.018792	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56156	 94562	 0.007242	 0.013016	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56157	 56167	 0.001944	 0.005047	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56157	 94562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56157	 94562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56158	 56159	 0.008721	 0.011888	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94562	 56158	 0.007571	 0.011597	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56159	 94563	 0.01308	 0.013211	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56159	 94564	 0.006632	 0.022124	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56160	 56162	 0.002096	 0.008392	 0.00211	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56160	 94563	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56160	 94563	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56161	 94564	 0.010648	 0.021082	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56162	 94564	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56162	 94564	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56162	 94573	 0.002796	 0.018726	 0.01177	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56163	 56172	 0.001916	 0.005064	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56163	 56200	 0.002531	 0.006794	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56163	 94565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56163	 94565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56164	 56166	 0.019184	 0.015182	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94564	 56164	 0.01366	 0.013663	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56165	 56200	 0.000651	 0.002234	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56165	 94566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56165	 94566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94566	 56166	 0.007136	 0.014128	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56167	 94567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56167	 94567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56168	 56169	 0.014815	 0.011724	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94567	 56168	 0.016726	 0.013236	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56169	 56171	 0.006476	 0.008828	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56170	 56171	 0.007149	 0.01635	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56170	 56201	 0.004999	 0.012712	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94564	 56170	 0.062063	 0.049117	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56170	 94580	 0.008132	 0.024974	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56172	 56174	 0.001315	 0.004432	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56173	 94568	 0.004242	 0.02047	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56174	 56175	 0.000685	 0.002829	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56175	 56176	 0.000484	 0.003774	 0.00113	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56175	 94568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56175	 94568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56176	 56177	 0.000836	 0.003178	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56176	 56199	 0.002209	 0.007698	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56176	 94569	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56176	 94569	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56176	 94573	 0.000793	 0.011864	 0.00399	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56177	 56184	 0.000799	 0.003728	 0.00092	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56177	 94570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56177	 94570	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56178	 56179	 0.007795	 0.009794	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94570	 56178	 0.00601	 0.011778	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56179	 94577	 0.007475	 0.012466	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56180	 56194	 0.002503	 0.008943	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56180	 94576	 0.002993	 0.013337	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56181	 94571	 0.005193	 0.009512	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56181	 94576	 0.003492	 0.007483	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56182	 56192	 0.000999	 0.00423	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56182	 56198	 0.00137	 0.005487	 0.00138	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56182	 94571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56182	 94571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94571	 56183	 0.01149	 0.011493	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56183	 94572	 0.005123	 0.012131	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56184	 56185	 0.000895	 0.003585	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56184	 56221	 0.003916	 0.010066	 0.00249	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56185	 56190	 0.000831	 0.004579	 0.00107	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56185	 94572	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56185	 94572	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56186	 56250	 0.000107	 0.00167	 0.02839	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56186	 94573	 0.000119	 0.009548	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56187	 56249	 0.009319	 0.023955	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94574	 56187	 0.00524	 0.015029	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56188	 56251	 0.013681	 0.027997	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56188	 94597	 0.005973	 0.028819	 0.00051	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56189	 56251	 0.006704	 0.015401	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56189	 94575	 0.007074	 0.020289	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56190	 56191	 0.000658	 0.003021	 0.00077	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94573	 56190	 0.000725	 0.003841	 0.00128	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56190	 94613	 0.002501	 0.018739	 0.00457	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56191	 56192	 0.001053	 0.004218	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94573	 56191	 0.001595	 0.007742	 0.00177	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56191	 94575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56191	 94575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56192	 94576	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56192	 94576	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56193	 56196	 0.012601	 0.012604	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94576	 56193	 0.008878	 0.010823	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56194	 56195	 0.011105	 0.012214	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94570	 56194	 0.064371	 0.041674	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56195	 56196	 0.005936	 0.01526	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56196	 56197	 0.001964	 0.008754	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56197	 94614	 0.008764	 0.041884	 0.00092	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56198	 94577	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56198	 94577	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56199	 94578	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56199	 94578	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56200	 56206	 0.003208	 0.011614	 0.00249	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56200	 94579	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56200	 94579	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56201	 56202	 0.003829	 0.009843	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56202	 56203	 0.015941	 0.016101	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94377	 56202	 0.003272	 0.012728	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56203	 94580	 0.008383	 0.0119	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56204	 56207	 0.001169	 0.004011	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56204	 94580	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56204	 94580	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94379	 56205	 0.005244	 0.011994	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56205	 94581	 0.003118	 0.010917	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56206	 56216	 0.001187	 0.004136	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56206	 94581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56206	 94581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56207	 56216	 0.001904	 0.006416	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56207	 94582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56207	 94582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56208	 56209	 0.011152	 0.017082	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94579	 56208	 0.016288	 0.01234	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56209	 56210	 0.008365	 0.015094	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56209	 56215	 0.017838	 0.012895	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56210	 56211	 0.00557	 0.012932	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56211	 56212	 0.003189	 0.010639	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56211	 56214	 0.021095	 0.021306	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56211	 56215	 0.019939	 0.02718	 0.0006	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94569	 56211	 0.002712	 0.01524	 0.00028	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56212	 56213	 0.00278	 0.009273	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56213	 56220	 0.00247	 0.00961	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94569	 56213	 0.018498	 0.017347	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94582	 56215	 0.015465	 0.01551	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56216	 56217	 0.001036	 0.004149	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56217	 56218	 0.000917	 0.003993	 0.00114	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56218	 56221	 0.000739	 0.002876	 0.00077	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56218	 56228	 0.000707	 0.004477	 0.00122	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56218	 94583	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56218	 94583	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56219	 56220	 0.020016	 0.015165	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56220	 94584	 0.00217	 0.012333	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56221	 56222	 0.000686	 0.00485	 0.00133	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56221	 94584	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56221	 94584	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56222	 56223	 0.001045	 0.004423	 0.001	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94573	 56222	 0.002419	 0.00815	 0.00203	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56223	 56224	 0.001139	 0.004958	 0.00141	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56224	 56225	 0.001064	 0.00355	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56224	 56246	 0.001133	 0.008277	 0.00213	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56224	 94585	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56224	 94585	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56225	 56226	 0.000951	 0.003809	 0.00096	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56226	 56227	 0.000699	 0.00443	 0.0012	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56226	 56243	 0.000469	 0.004268	 0.00108	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56226	 94586	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56226	 94586	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56227	 56228	 0.000407	 0.002387	 0.00065	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56228	 56234	 0.00216	 0.008918	 0.00211	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56229	 56230	 0.002955	 0.01137	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94586	 56229	 0.003221	 0.011003	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56230	 56231	 0.005658	 0.014958	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56231	 56232	 0.017324	 0.01371	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94583	 56231	 0.00571	 0.025158	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56231	 94587	 0.00689	 0.017858	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94379	 56233	 0.004719	 0.024537	 0.00053	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56233	 94587	 0.003447	 0.018982	 0.00043	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56234	 56239	 0.001814	 0.007381	 0.0018	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56234	 94587	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56234	 94587	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56235	 56236	 0.001186	 0.00466	 0.00122	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56235	 94588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56235	 94588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56236	 56237	 0.001462	 0.005689	 0.00152	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56236	 94589	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56236	 94589	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56237	 56292	 0.000765	 0.004393	 0.00124	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56237	 94590	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56237	 94590	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56238	 56239	 0.002009	 0.005308	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56238	 94591	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56238	 94591	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56239	 56240	 0.00092	 0.005824	 0.00158	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56239	 94594	 0.001896	 0.011107	 0.00303	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56240	 56241	 0.00068	 0.004807	 0.00132	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56240	 56293	 0.00501	 0.011629	 0.00354	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56241	 56242	 0.000679	 0.003312	 0.00091	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56241	 94592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56241	 94592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56242	 56245	 0.000353	 0.00266	 0.00074	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56242	 94593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56242	 94593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56242	 94594	 0.00096	 0.004542	 0.00109	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56243	 94594	 0.00043	 0.004839	 0.00127	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56244	 94594	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56244	 94594	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92812	 56245	 0.00065	 0.005225	 0.00147	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92812	 56246	 0.000548	 0.007329	 0.002	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56246	 94595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56246	 94595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56247	 56314	 0.012625	 0.016593	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94595	 56247	 0.00771	 0.017632	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56248	 56249	 0.010166	 0.019924	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94585	 56248	 0.031028	 0.0238	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56248	 94628	 0.005765	 0.025688	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94595	 56249	 0.009653	 0.047104	 0.00081	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56250	 56291	 0.000216	 0.002366	 0.02298	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56250	 94596	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56252	 56268	 0.001567	 0.004369	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56252	 94598	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56252	 94598	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94598	 56253	 0.011458	 0.011699	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56254	 94599	 0.023408	 0.016581	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56255	 94599	 0.013898	 0.022184	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56256	 56268	 0.00398	 0.010518	 0.00246	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94596	 56256	 0.002233	 0.008086	 0.00173	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56256	 94599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56256	 94599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56257	 56259	 0.001138	 0.00603	 0.00201	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94596	 56257	 0.002745	 0.011331	 0.00268	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56257	 94600	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56257	 94600	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56258	 94601	 0.012828	 0.010152	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56259	 56260	 0.000815	 0.006247	 0.00167	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56259	 94601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56259	 94601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56260	 56261	 0.000458	 0.005333	 0.00157	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56260	 94602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56260	 94602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56261	 56265	 0.002277	 0.011053	 0.00253	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56261	 56288	 0.001871	 0.011145	 0.00293	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56261	 56353	 0.001733	 0.012463	 0.0033	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56261	 94603	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56261	 94603	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56261	 94610	 0.00458	 0.035915	 0.01642	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94603	 56262	 0.00628	 0.016144	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94601	 56263	 0.029391	 0.023038	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56263	 94604	 0.009159	 0.018133	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56264	 56289	 0.010024	 0.023268	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56264	 94604	 0.004845	 0.014581	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56265	 94604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56265	 94604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94601	 56266	 0.012502	 0.017423	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94604	 56266	 0.006254	 0.009982	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94604	 56267	 0.004578	 0.017808	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56267	 94605	 0.013082	 0.018231	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56268	 56269	 0.000863	 0.005221	 0.00133	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56268	 94605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56268	 94605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56269	 56270	 0.000734	 0.005282	 0.0014	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56270	 56276	 0.000662	 0.004984	 0.00138	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94605	 56271	 0.00778	 0.017648	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56272	 56274	 0.002257	 0.008172	 0.00175	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56272	 94613	 0.005633	 0.014625	 0.00355	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56274	 56275	 0.000879	 0.003956	 0.00105	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56275	 56279	 0.000856	 0.005313	 0.00129	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56275	 94606	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56275	 94606	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56276	 56278	 0.000948	 0.009098	 0.00265	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56276	 94607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56276	 94607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56277	 56289	 0.00674	 0.016497	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56278	 56280	 0.002085	 0.011982	 0.00339	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56278	 56286	 0.001132	 0.011138	 0.0046	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56278	 94610	 0.004465	 0.038293	 0.0109	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56279	 56280	 0.00044	 0.003594	 0.00098	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56280	 56281	 0.001554	 0.005627	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56281	 94608	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56281	 94608	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56283	 56284	 0.001577	 0.006313	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56284	 95253	 0.001466	 0.013797	 0.00418	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56285	 56286	 0.000693	 0.007765	 0.00247	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56285	 95253	 0.000877	 0.01142	 0.0033	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56287	 56288	 0.002404	 0.015224	 0.00413	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56287	 94610	 0.002765	 0.02151	 0.00559	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94603	 56289	 0.01811	 0.060413	 0.00096	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56290	 94609	 0.000104	 0.008333	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56291	 94612	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56292	 56298	 0.00077	 0.004512	 0.00123	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56292	 94615	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56292	 94615	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56293	 56294	 0.001507	 0.006787	 0.00181	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56293	 56298	 0.001721	 0.004468	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56293	 94616	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56293	 94616	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56294	 56295	 0.001639	 0.006562	 0.00165	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56294	 94617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56294	 94617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56295	 56335	 0.00084	 0.006748	 0.0019	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56295	 94618	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56295	 94618	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94618	 56296	 0.01404	 0.024691	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56296	 94625	 0.012359	 0.02447	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94617	 56297	 0.007347	 0.022115	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56297	 94619	 0.028352	 0.022437	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56298	 56299	 0.001043	 0.003515	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56298	 94619	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56298	 94619	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56298	 94623	 0.001924	 0.01036	 0.00285	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56299	 56301	 0.000706	 0.002827	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56299	 94620	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56299	 94620	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94620	 56300	 0.021263	 0.016667	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56301	 94621	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56301	 94621	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56301	 94623	 0.00101	 0.004899	 0.00112	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92812	 56302	 0.002055	 0.008228	 0.00207	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56302	 94622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56302	 94622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56302	 94623	 0.001807	 0.00469	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94621	 56303	 0.014078	 0.011141	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92811	 56304	 0.000505	 0.004056	 0.00762	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94408	 56304	 0.00153	 0.010725	 0.01826	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56304	 94623	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94624	 56304	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94624	 56305	 0.020576	 0.016283	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56306	 56341	 0.004116	 0.013869	 0.00345	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94623	 56306	 0.001922	 0.006697	 0.00155	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56306	 94625	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56306	 94625	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94624	 56307	 0.01225	 0.023151	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94622	 56308	 0.020676	 0.014947	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92812	 56309	 0.002202	 0.006594	 0.00149	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56309	 94626	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56309	 94626	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92812	 56310	 0.000903	 0.004274	 0.00103	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56310	 94627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56310	 94627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56311	 56314	 0.002633	 0.014968	 0.00027	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94627	 56311	 0.003653	 0.019617	 0.00047	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56312	 56314	 0.003348	 0.014917	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56312	 56316	 0.023416	 0.016927	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56312	 56317	 0.025679	 0.020322	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56313	 56314	 0.008805	 0.017433	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56313	 94628	 0.023495	 0.018594	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94596	 56315	 0.003568	 0.010232	 0.00252	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56315	 94628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56315	 94628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94600	 56316	 0.025034	 0.018097	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56317	 56318	 0.004488	 0.014971	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94600	 56317	 0.042526	 0.027531	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56318	 56319	 0.002214	 0.01361	 0.00025	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56319	 56320	 0.006283	 0.01802	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94602	 56319	 0.005145	 0.01838	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56320	 56321	 0.009376	 0.012202	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56320	 56325	 0.004925	 0.016253	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56321	 56322	 0.024219	 0.02429	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56322	 56323	 0.033759	 0.034097	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94603	 56322	 0.005501	 0.023625	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56324	 94629	 0.013331	 0.026395	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56324	 94635	 0.005516	 0.018843	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56325	 94629	 0.006395	 0.024879	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56326	 56327	 0.001023	 0.004161	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92812	 56326	 0.002713	 0.010312	 0.00289	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56326	 94629	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56326	 94629	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56327	 56328	 0.001352	 0.004554	 0.00113	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56328	 56351	 0.001702	 0.005736	 0.00143	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56329	 56347	 0.019698	 0.027962	 0.00046	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94627	 56329	 0.020827	 0.033244	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56330	 56331	 0.02488	 0.025129	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56330	 56349	 0.024075	 0.047667	 0.0007	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94626	 56330	 0.008444	 0.024219	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56331	 56332	 0.0198	 0.017742	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56332	 56333	 0.007888	 0.016141	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56333	 56334	 0.02564	 0.020291	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56333	 94632	 0.006663	 0.021455	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56334	 94630	 0.00676	 0.016779	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56335	 56337	 0.000396	 0.003594	 0.00117	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56335	 94630	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56335	 94630	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94630	 56336	 0.007214	 0.014138	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56337	 56338	 0.000312	 0.003301	 0.00098	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56337	 94631	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56337	 94631	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56338	 56339	 0.000257	 0.002884	 0.00092	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56339	 94641	 0.000274	 0.003735	 0.00134	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56340	 94632	 0.010925	 0.020921	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56341	 56343	 0.001306	 0.005228	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56341	 94632	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56341	 94632	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56342	 56346	 0.006246	 0.016511	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94632	 56342	 0.004274	 0.017104	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56343	 56344	 0.001903	 0.004783	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56343	 56364	 0.001612	 0.006455	 0.00163	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56344	 56364	 0.001373	 0.007568	 0.00177	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92812	 56344	 0.009405	 0.028164	 0.00634	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56344	 94633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56344	 94633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56345	 56348	 0.015431	 0.012212	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94633	 56345	 0.004525	 0.015455	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56346	 56347	 0.00939	 0.018193	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56348	 56349	 0.014942	 0.009674	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56349	 94634	 0.003122	 0.018484	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56350	 56358	 0.004603	 0.012532	 0.00276	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56350	 56359	 0.00259	 0.00651	 0.00169	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56350	 94634	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56350	 94634	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56351	 56352	 0.002299	 0.006076	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56351	 56359	 0.000786	 0.00416	 0.00105	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56352	 56357	 0.002721	 0.006841	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56352	 94635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56352	 94635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56353	 56354	 0.001164	 0.008601	 0.00248	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56353	 56357	 0.003005	 0.007942	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56353	 56358	 0.004868	 0.012236	 0.00317	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56354	 56355	 0.000816	 0.006864	 0.00203	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56354	 94636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56354	 94636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56355	 56377	 0.001218	 0.012085	 0.00329	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94636	 56356	 0.007212	 0.028058	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56356	 94637	 0.016726	 0.035154	 0.00064	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56357	 56359	 0.003667	 0.00952	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56357	 94637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56357	 94637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56358	 56359	 0.001542	 0.005291	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56358	 56374	 0.001153	 0.009889	 0.00281	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56358	 94638	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56358	 94638	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56359	 94639	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56359	 94639	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56359	 94642	 0.008701	 0.04118	 0.0099	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94639	 56360	 0.048545	 0.039957	 0.00081	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56360	 94643	 0.009989	 0.036586	 0.00092	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56361	 56362	 0.008083	 0.031098	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56361	 94640	 0.035795	 0.054835	 0.00077	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56361	 94643	 0.036175	 0.083986	 0.00125	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56362	 56370	 0.012348	 0.047309	 0.00134	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56363	 56364	 0.001146	 0.010153	 0.0027	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56363	 56368	 0.000764	 0.007337	 0.00213	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56364	 94640	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56364	 94640	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56365	 56366	 0.000188	 0.001788	 0.00318	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94384	 56365	 0.001292	 0.018111	 0.03473	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56365	 94641	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56365	 94641	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56366	 56367	 0.00019	 0.001867	 0.00398	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56367	 57119	 0.000513	 0.00682	 0.01457	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56367	 94642	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56367	 94642	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56368	 56369	 0.000444	 0.004526	 0.00117	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56368	 57114	 0.002507	 0.010036	 0.00253	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56369	 57106	 0.003561	 0.013998	 0.00366	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56369	 57113	 0.00119	 0.007538	 0.00205	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56370	 94880	 0.008094	 0.035868	 0.00108	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56371	 56372	 0.003521	 0.01831	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56371	 94876	 0.013623	 0.083753	 0.00151	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56372	 94643	 0.017697	 0.054291	 0.00147	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56373	 56374	 0.00135	 0.012959	 0.00377	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56373	 57100	 0.001674	 0.017735	 0.00526	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94610	 56374	 0.016572	 0.060015	 0.01288	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56374	 94643	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56374	 94643	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56375	 56376	 0.060407	 0.061014	 0.00081	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56376	 94644	 0.007876	 0.018651	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56377	 56378	 0.002397	 0.029124	 0.00785	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56377	 94644	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56377	 94644	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56378	 58305	 0.002376	 0.027647	 0.00813	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56378	 94645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56378	 94645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94475	 56379	 0.002467	 0.006622	 0.0015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94477	 56379	 0.001243	 0.004978	 0.00125	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56379	 94646	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56379	 94646	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94384	 56380	 0.001157	 0.007888	 0.0142	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94408	 56380	 0.000425	 0.003602	 0.00702	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56380	 94647	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94648	 56380	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92728	 56381	 0.023731	 0.096607	 0.02355	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56381	 94649	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56381	 94649	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56382	 94651	 0.1464	 0.1312	 0.00268	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94649	 56383	 0.032619	 0.11653	 0.00231	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56384	 56393	 0.013	 0.034902	 0.00791	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56384	 57019	 0.012107	 0.037846	 0.01096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56385	 56386	 0.036876	 0.08472	 0.00129	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56385	 56389	 0.007972	 0.027893	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56386	 56387	 0.069545	 0.069562	 0.00094	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56386	 57018	 0.16433	 0.29659	 0.00429	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92594	 56386	 0.043134	 0.1763	 0.00357	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56387	 94650	 0.021537	 0.049256	 0.0012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56388	 56390	 0.002983	 0.013683	 0.00351	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92593	 56388	 0.003336	 0.021131	 0.00574	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56388	 94650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56388	 94650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56389	 94651	 0.008572	 0.040966	 0.0009	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92728	 56390	 0.008099	 0.032425	 0.00817	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56390	 94651	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56390	 94651	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56391	 56393	 0.007949	 0.022166	 0.00465	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92593	 56391	 0.002551	 0.025994	 0.0067	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92724	 56391	 0.003902	 0.024712	 0.00671	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56391	 94652	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56391	 94652	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56392	 94653	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56392	 94653	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94329	 56394	 0.008437	 0.037595	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94652	 56394	 0.018487	 0.081922	 0.00246	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56395	 57158	 0.002181	 0.023953	 0.23298	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56395	 94654	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56396	 56397	 0.020383	 0.068691	 0.01708	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56396	 56764	 0.011121	 0.068386	 0.01973	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56396	 56816	 0.025414	 0.10498	 0.02485	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92738	 56396	 0.027801	 0.11773	 0.02651	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56396	 94656	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56396	 94656	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56397	 56815	 0.039899	 0.13024	 0.03461	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56397	 57570	 0.017801	 0.081688	 0.02093	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56398	 56399	 0.000858	 0.002943	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56398	 56400	 0.003183	 0.008263	 0.00201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56398	 56404	 0.0031	 0.013122	 0.00295	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56399	 56402	 0.003643	 0.012498	 0.00299	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56399	 56418	 0.010243	 0.035699	 0.00828	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92650	 56399	 0.003613	 0.030984	 0.00882	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56399	 94657	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56399	 94657	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56400	 56402	 0.00383	 0.011972	 0.00347	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56400	 56404	 0.00494	 0.016947	 0.00406	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94657	 56401	 0.033679	 0.066681	 0.00098	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56401	 94658	 0.029764	 0.021516	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56402	 56407	 0.006882	 0.018737	 0.00413	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56402	 56418	 0.006608	 0.022264	 0.00553	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56402	 94658	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56402	 94658	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56403	 56404	 0.001551	 0.007926	 0.00216	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92650	 56403	 0.001481	 0.012702	 0.00361	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56403	 94659	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56403	 94659	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56404	 56405	 0.003794	 0.019063	 0.00496	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92650	 56404	 0.002494	 0.01764	 0.00484	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56405	 56406	 0.007285	 0.019559	 0.00443	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56405	 94660	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56405	 94660	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56406	 56407	 0.005014	 0.013651	 0.00301	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56407	 56417	 0.003785	 0.012754	 0.00317	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56408	 56409	 0.063841	 0.12641	 0.00186	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56408	 56412	 0.19072	 0.15095	 0.0019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94660	 56409	 0.061215	 0.14211	 0.00271	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56410	 56411	 0.04779	 0.086231	 0.00125	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56410	 56414	 0.028715	 0.082358	 0.00127	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56410	 94661	 0.015971	 0.065275	 0.00132	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56413	 56414	 0.05104	 0.1185	 0.00176	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56413	 58088	 0.05322	 0.12356	 0.00184	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56415	 58154	 0.012517	 0.040828	 0.01084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56415	 94661	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56415	 94661	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56415	 94662	 0.002448	 0.015508	 0.00421	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56416	 58218	 0.003301	 0.021427	 0.04269	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92649	 56416	 0.002965	 0.031048	 0.05843	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92678	 56416	 0.008776	 0.059918	 0.10806	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94009	 56416	 0.00514	 0.033622	 0.066	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56416	 94662	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94663	 56416	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94662	 56417	 0.007966	 0.021387	 0.00485	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56418	 56419	 0.005916	 0.020619	 0.00478	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56418	 58221	 0.01368	 0.035457	 0.01073	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56418	 94664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56418	 94664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56419	 56420	 0.005306	 0.013775	 0.00334	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56420	 58221	 0.005962	 0.015325	 0.00379	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56420	 94665	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56420	 94665	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56421	 56422	 0.020569	 0.018431	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94664	 56422	 0.021544	 0.050009	 0.00095	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56423	 94666	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56423	 94666	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56424	 56425	 0.005637	 0.029856	 0.00757	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56424	 57528	 0.004728	 0.024169	 0.00659	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56424	 57542	 0.00805	 0.049471	 0.01809	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56424	 94667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56424	 94667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56425	 56426	 0.008116	 0.041056	 0.01143	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56426	 56439	 0.00304	 0.017803	 0.00485	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56426	 94668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56426	 94668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56427	 56437	 0.006853	 0.018112	 0.00424	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56427	 56438	 0.003631	 0.013149	 0.00282	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56427	 94669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56427	 94669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56428	 94671	 0.1324	 0.10479	 0.00132	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56429	 56430	 0.000986	 0.005774	 0.00157	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56429	 56433	 0.00223	 0.012677	 0.00367	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56430	 56787	 0.005943	 0.030959	 0.00812	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56431	 56432	 0.006007	 0.035183	 0.00958	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56431	 56787	 0.005868	 0.023492	 0.00592	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56431	 57178	 0.00938	 0.037556	 0.00946	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56432	 94670	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56432	 94670	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56433	 56435	 0.002869	 0.014943	 0.00392	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56433	 94671	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56433	 94671	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92735	 56434	 0.023895	 0.063161	 0.01479	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56435	 56436	 0.004531	 0.023604	 0.00619	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56436	 56437	 0.00621	 0.016412	 0.00384	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56436	 56439	 0.014116	 0.048428	 0.0116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56438	 56439	 0.002	 0.008258	 0.00195	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56439	 94672	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56439	 94672	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56440	 57537	 0.038944	 0.17355	 0.00295	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94668	 56440	 0.058275	 0.15104	 0.00286	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56441	 56446	 0.009037	 0.015224	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56441	 56450	 0.012105	 0.021131	 0.00033	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56441	 94673	 0.010235	 0.034145	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56442	 56449	 0.002465	 0.010432	 0.00235	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56443	 56535	 0.019564	 0.040036	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92715	 56443	 0.006894	 0.031966	 0.00066	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56444	 56447	 0.005449	 0.019731	 0.00423	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56444	 56448	 0.004724	 0.012861	 0.00283	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56444	 94673	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56444	 94673	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94673	 56445	 0.024581	 0.026774	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56445	 94675	 0.036289	 0.026699	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56447	 56457	 0.003707	 0.009625	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56447	 56459	 0.002523	 0.007035	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56447	 56461	 0.002502	 0.006495	 0.00158	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56447	 94674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56447	 94674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56448	 56528	 0.013065	 0.033587	 0.00832	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56448	 94675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56448	 94675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56449	 56454	 0.003808	 0.012831	 0.00319	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56449	 94676	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56449	 94676	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56450	 56451	 0.024879	 0.027363	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94674	 56451	 0.011062	 0.023706	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56452	 56458	 0.01553	 0.023791	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56452	 94678	 0.007881	 0.020259	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56453	 56454	 0.002087	 0.007273	 0.00169	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56453	 94677	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56453	 94677	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56454	 56459	 0.002649	 0.009087	 0.00218	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56454	 56468	 0.005231	 0.013825	 0.00324	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56454	 94678	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56454	 94678	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56455	 56469	 0.012096	 0.009572	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56455	 56553	 0.034248	 0.022172	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56456	 56462	 0.019778	 0.038762	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56456	 56533	 0.03158	 0.041098	 0.00057	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56456	 94680	 0.004009	 0.022078	 0.0005	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56457	 56461	 0.001702	 0.004279	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56457	 56463	 0.003503	 0.008805	 0.00228	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56457	 56464	 0.00259	 0.006846	 0.0016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56458	 56462	 0.022491	 0.024737	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56459	 56461	 0.001539	 0.003957	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56459	 94679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56459	 94679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56460	 56462	 0.020361	 0.016114	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56462	 94683	 0.005879	 0.022871	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56463	 56464	 0.001622	 0.00421	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56463	 56518	 0.000946	 0.005724	 0.00146	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56463	 94680	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56463	 94680	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56464	 94681	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56464	 94681	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56465	 56467	 0.004388	 0.013206	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56465	 94694	 0.005556	 0.03416	 0.00062	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92640	 56466	 0.001118	 0.012563	 0.02299	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56466	 94682	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94683	 56466	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94683	 56467	 0.00751	 0.012086	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94682	 56468	 0.001205	 0.003931	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56468	 94684	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56468	 94684	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94684	 56469	 0.011841	 0.019409	 0.00034	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56470	 56471	 0.047349	 0.034836	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94684	 56470	 0.006409	 0.016474	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94677	 56471	 0.028903	 0.045099	 0.00075	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56472	 56473	 0.016129	 0.041018	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56472	 56490	 0.016174	 0.041132	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94677	 56472	 0.015242	 0.073165	 0.00219	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56474	 56475	 0.028792	 0.051951	 0.00075	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94677	 56475	 0.014253	 0.03664	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56476	 56477	 0.005596	 0.02177	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56476	 56480	 0.00499	 0.012826	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94683	 56476	 0.005926	 0.032632	 0.00074	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56477	 56490	 0.009	 0.029701	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94684	 56478	 0.021519	 0.054726	 0.00087	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56479	 56480	 0.006158	 0.00622	 8e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56481	 56482	 0.004722	 0.016868	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94683	 56481	 0.003595	 0.019309	 0.00046	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56482	 56485	 0.01055	 0.02449	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56483	 56484	 0.011101	 0.009947	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56483	 56485	 0.005932	 0.015248	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56483	 56491	 0.025233	 0.045529	 0.00066	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56485	 56486	 0.00403	 0.01544	 0.00044	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56486	 94692	 0.004575	 0.027804	 0.00051	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56487	 56488	 0.015379	 0.039111	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56487	 56522	 0.017561	 0.04077	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56487	 94692	 0.018658	 0.049453	 0.00125	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56488	 56489	 0.013198	 0.013201	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56488	 56492	 0.016727	 0.030064	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56493	 56494	 0.013548	 0.034826	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56493	 56495	 0.00705	 0.018121	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56494	 94685	 0.010458	 0.027717	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56495	 56496	 0.023297	 0.035684	 0.00062	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56495	 56498	 0.024016	 0.021668	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56497	 56504	 0.003416	 0.015932	 0.00395	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56497	 56552	 0.010923	 0.045103	 0.01067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92708	 56497	 0.003421	 0.051113	 0.01513	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56497	 94685	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56497	 94685	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56499	 56500	 0.038797	 0.037961	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56500	 56501	 0.014125	 0.03631	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56501	 56505	 0.005927	 0.013555	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56501	 56508	 0.036348	 0.093439	 0.00145	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94685	 56501	 0.00675	 0.033491	 0.0008	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94685	 56502	 0.016338	 0.025027	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56503	 56512	 0.041922	 0.030844	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94685	 56503	 0.018539	 0.04696	 0.00093	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56504	 56511	 0.008847	 0.023382	 0.00547	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56504	 94686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56504	 94686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94686	 56505	 0.004823	 0.012783	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56506	 56507	 0.023901	 0.026289	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56506	 56509	 0.039431	 0.043369	 0.00058	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94686	 56506	 0.004536	 0.022146	 0.00046	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56509	 56510	 0.052392	 0.052918	 0.0007	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56510	 94687	 0.029436	 0.05828	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56511	 94687	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56511	 94687	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56512	 56513	 0.016732	 0.0169	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56514	 56546	 0.023821	 0.066439	 0.01395	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92641	 56514	 0.006809	 0.017995	 0.00421	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92708	 56514	 0.006904	 0.019252	 0.00404	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92642	 56515	 0.017298	 0.034248	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56516	 56523	 0.027663	 0.042376	 0.0006	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56516	 94690	 0.015061	 0.038717	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56517	 56532	 0.021727	 0.039795	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56517	 94688	 0.009348	 0.02403	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56518	 56530	 0.002309	 0.00792	 0.0019	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56518	 94688	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56518	 94688	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56518	 94697	 0.003455	 0.015556	 0.00414	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56519	 56521	 0.002575	 0.010016	 0.00268	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56519	 58434	 0.037373	 0.086792	 0.02645	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92641	 56519	 0.004446	 0.024672	 0.0075	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56519	 94689	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56519	 94689	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94689	 56520	 0.073213	 0.04918	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56521	 56524	 0.003573	 0.014304	 0.0036	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56521	 56550	 0.002676	 0.018232	 0.00621	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56521	 94690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56521	 94690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56522	 56523	 0.011614	 0.03331	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56523	 56548	 0.039738	 0.072785	 0.00126	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56523	 94691	 0.014267	 0.056602	 0.00162	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56524	 94691	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56524	 94691	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56524	 94697	 0.00158	 0.009414	 0.00248	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56525	 94693	 0.007706	 0.015257	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56526	 56527	 0.001681	 0.006731	 0.0017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94682	 56526	 0.007499	 0.020416	 0.0045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56526	 94692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56526	 94692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56527	 94693	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56527	 94693	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56527	 94697	 0.003465	 0.013874	 0.0035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56528	 56530	 0.003089	 0.007171	 0.00218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56528	 94694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56528	 94694	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56528	 94697	 0.00437	 0.013659	 0.00396	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56529	 94695	 0.025673	 0.02522	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92641	 56530	 0.001502	 0.011096	 0.0032	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56530	 94695	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56530	 94695	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56531	 94696	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94697	 56531	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56532	 56538	 0.038278	 0.050308	 0.00069	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56532	 56540	 0.024183	 0.044965	 0.00105	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56533	 56536	 0.014903	 0.037901	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56534	 94698	 0.028666	 0.022686	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56535	 56541	 0.022752	 0.038328	 0.00055	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56536	 94698	 0.005893	 0.017737	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56537	 94698	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56537	 94698	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56539	 56724	 0.07922	 0.20405	 0.05064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92641	 56539	 0.015076	 0.039845	 0.00933	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94698	 56540	 0.017653	 0.036125	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94698	 56541	 0.039335	 0.058971	 0.00107	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56542	 94699	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56542	 94699	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56543	 94700	 0.014115	 0.027663	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92715	 56544	 0.022758	 0.029911	 0.00041	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56545	 94700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56545	 94700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56547	 56550	 0.009255	 0.025962	 0.00668	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56547	 58433	 0.013758	 0.047201	 0.01131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56548	 56549	 0.065035	 0.042104	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56549	 94701	 0.023387	 0.034079	 0.00077	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56550	 56551	 0.001426	 0.015116	 0.00449	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56550	 94701	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56550	 94701	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56551	 56552	 0.001566	 0.013165	 0.0039	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94677	 56553	 0.04931	 0.039023	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56554	 56752	 0.008723	 0.036919	 0.00831	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56555	 56556	 0.009007	 0.03812	 0.00858	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56555	 56753	 0.009972	 0.039929	 0.01006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56555	 94702	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56555	 94702	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56556	 56557	 0.010433	 0.030761	 0.00716	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56556	 56558	 0.004753	 0.013331	 0.00343	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56556	 56754	 0.022172	 0.080688	 0.02471	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56557	 56558	 0.005772	 0.017951	 0.00375	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92742	 56557	 0.001983	 0.019369	 0.00544	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56557	 94703	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56557	 94703	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56559	 56562	 0.077969	 0.056365	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56560	 94704	 0.012062	 0.02364	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56561	 56563	 0.004657	 0.028162	 0.00719	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92742	 56561	 0.008778	 0.06613	 0.01835	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56561	 94704	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56561	 94704	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94704	 56562	 0.010542	 0.020872	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56564	 56867	 0.13243	 0.21712	 0.00383	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56564	 57009	 0.2495	 0.19749	 0.00249	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56564	 57181	 0.14008	 0.22366	 0.00515	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56565	 56833	 0.007986	 0.033801	 0.00761	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56565	 56936	 0.011402	 0.048262	 0.01086	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56566	 56568	 0.004318	 0.01944	 0.00517	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56566	 56831	 0.027225	 0.10906	 0.02749	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56567	 94705	 0.019625	 0.035274	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56568	 56569	 0.002105	 0.008567	 0.00209	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56569	 94705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56569	 94705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56570	 56942	 0.049074	 0.16372	 0.0026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56570	 57972	 0.1513	 0.31811	 0.0058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94705	 56570	 0.051889	 0.19965	 0.00341	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56571	 57973	 0.1645	 0.38208	 0.00568	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94705	 56571	 0.046827	 0.15454	 0.0025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56572	 56575	 0.003021	 0.010989	 0.00336	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56572	 56577	 0.004076	 0.01774	 0.00505	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56572	 94706	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56572	 94706	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56573	 94708	 0.062229	 0.062854	 0.00083	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56574	 94707	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56574	 94707	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56575	 56576	 0.00271	 0.011471	 0.00258	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56576	 56578	 0.004704	 0.023241	 0.00679	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92777	 56576	 0.001798	 0.007067	 0.00185	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94707	 56576	 0.001644	 0.018013	 0.005	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56576	 94708	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56576	 94708	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56577	 57332	 0.006162	 0.031475	 0.00792	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56578	 94709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56578	 94709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56578	 94969	 0.00524	 0.039266	 0.00958	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92646	 56579	 0.059026	 0.063035	 0.00133	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56580	 94710	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56580	 94710	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94710	 56581	 0.16956	 0.15197	 0.00311	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56582	 94712	 0.035914	 0.13473	 0.00242	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56583	 56586	 0.000487	 0.005152	 0.07705	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56583	 56586	 0.000487	 0.005152	 0.07705	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56583	 56615	 0.000433	 0.004586	 0.06858	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56583	 56615	 0.000433	 0.004586	 0.06858	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56583	 94711	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56583	 94711	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56584	 56587	 0.000148	 0.002005	 0.03055	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56584	 56589	 0.000321	 0.004524	 0.07307	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56584	 94712	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56584	 94712	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56585	 56590	 0.004968	 0.028543	 0.00809	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56585	 94713	 0.000983	 0.006598	 0.00159	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56586	 56587	 0.0001	 0.001272	 0.02222	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56586	 56588	 0.000167	 0.001855	 0.01749	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56586	 94713	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56586	 94713	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56587	 56588	 0.000103	 0.001191	 0.01044	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56590	 95325	 0.006605	 0.033613	 0.01219	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56591	 56593	 0.08668	 0.19187	 0.00315	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56592	 56597	 0.009317	 0.049346	 0.01251	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56592	 94714	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56592	 94714	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56592	 94806	 0.012552	 0.057589	 0.01476	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56593	 56594	 0.008747	 0.020096	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56594	 94715	 0.034586	 0.07946	 0.00121	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56595	 56596	 0.015369	 0.055922	 0.01712	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92588	 56595	 0.063995	 0.21393	 0.0544	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56595	 94715	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56595	 94715	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56596	 58227	 0.013757	 0.085511	 0.02414	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56597	 58293	 0.0103	 0.053656	 0.01407	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56597	 94716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56597	 94716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92775	 56599	 0.46643	 0.36588	 0.0047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56600	 56602	 0.032655	 0.025843	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56600	 94718	 0.025979	 0.034144	 0.00047	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56601	 56603	 0.005029	 0.014827	 0.00345	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56601	 56605	 0.002033	 0.008395	 0.00199	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56601	 94717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56601	 94717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56602	 56604	 0.021686	 0.017162	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94717	 56602	 0.032158	 0.025449	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92669	 56603	 0.037687	 0.10577	 0.02724	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56603	 94718	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56603	 94718	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94717	 56604	 0.051255	 0.037052	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94718	 56604	 0.008779	 0.022568	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56605	 56606	 0.00158	 0.008368	 0.00212	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56605	 56607	 0.003937	 0.015763	 0.00397	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56606	 57023	 0.008864	 0.066432	 0.01621	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56606	 94719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56606	 94719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94244	 56608	 0.45	 0.91	 0.012	 59.0	 59.0	 59.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95317	 56608	 0.5031	 0.9389	 0.014	 59.0	 59.0	 59.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56609	 56610	 0.019916	 0.10134	 0.0023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56609	 56614	 0.01287	 0.061779	 0.00185	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94328	 56611	 0.051771	 0.29436	 0.00533	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92716	 56613	 0.023166	 0.1272	 0.03366	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94711	 56613	 0.007301	 0.040513	 0.01232	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56613	 94720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56613	 94720	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94720	 56614	 0.002396	 0.017511	 0.00032	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56615	 56619	 0.000368	 0.003713	 0.06111	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56615	 56619	 0.000368	 0.003713	 0.06111	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56617	 56618	 0.006119	 0.034785	 0.00063	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56618	 56620	 0.005236	 0.024277	 0.0005	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56619	 56621	 0.000295	 0.002975	 0.04896	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56619	 56621	 0.000295	 0.002975	 0.04896	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56619	 56625	 0.000334	 0.003932	 0.06868	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56619	 94721	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94722	 56620	 0.013073	 0.069657	 0.00122	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56621	 56622	 0.000278	 0.002734	 0.04747	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56621	 56622	 0.000278	 0.002734	 0.04747	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56623	 56776	 0.025243	 0.1277	 0.00222	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56623	 94723	 0.012571	 0.069228	 0.00156	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56624	 56625	 0.000351	 0.003713	 0.05553	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56624	 56625	 0.000351	 0.003713	 0.05553	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56624	 57444	 0.00032	 0.00323	 0.05316	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56624	 57444	 0.00032	 0.00323	 0.05316	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56624	 94723	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56624	 94723	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56625	 56626	 0.0001	 0.00179	 0.03484	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56626	 57390	 0.000327	 0.005724	 0.11651	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56626	 94724	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56626	 94724	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94724	 56627	 0.10055	 0.079574	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56629	 57278	 0.056695	 0.17751	 0.05152	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56629	 94725	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56629	 94725	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56630	 56631	 0.001979	 0.005836	 0.00136	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56630	 94726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56630	 94726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56630	 94730	 0.001066	 0.004401	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56631	 94727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56631	 94727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56632	 56633	 0.001957	 0.005171	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56632	 94728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56632	 94728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56632	 94730	 0.001451	 0.003731	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56634	 94729	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56635	 57420	 0.023459	 0.12882	 0.03409	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56635	 58002	 0.027145	 0.093151	 0.02233	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56635	 94732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56635	 94732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56636	 94733	 0.15263	 0.098823	 0.00188	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56637	 56638	 0.00674	 0.036983	 0.00978	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92760	 56637	 0.007404	 0.055776	 0.01548	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56637	 94733	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56637	 94733	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92726	 56638	 0.005123	 0.020511	 0.00517	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56639	 56641	 0.009434	 0.046038	 0.01272	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56639	 57035	 0.028894	 0.078687	 0.01734	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56639	 58388	 0.014712	 0.08547	 0.02013	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56639	 94734	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56639	 94734	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56640	 58290	 0.01151	 0.058234	 0.01622	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56640	 58389	 0.014489	 0.07675	 0.01946	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56641	 58280	 0.006992	 0.056764	 0.01808	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56641	 94735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56641	 94735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56642	 56643	 0.004726	 0.027101	 0.00901	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56643	 56645	 0.003106	 0.01645	 0.00417	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56644	 56645	 0.002458	 0.010405	 0.00234	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56645	 94736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56645	 94736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56645	 94737	 0.024276	 0.12866	 0.03264	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56646	 56647	 0.044565	 0.11456	 0.00177	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94736	 56646	 0.028264	 0.15181	 0.0036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56646	 95231	 0.044806	 0.19245	 0.00352	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56647	 57190	 0.029445	 0.11683	 0.00334	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56647	 94916	 0.037811	 0.2128	 0.0046	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56648	 94737	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94738	 56648	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56648	 94917	 0.002867	 0.023148	 0.04303	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56649	 94739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56649	 94739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56649	 94918	 0.011634	 0.040711	 0.01349	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56650	 57387	 0.27888	 0.51924	 0.01217	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56650	 57430	 0.14995	 0.58395	 0.00976	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56650	 57430	 0.14995	 0.58395	 0.00976	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93917	 56650	 0.08252	 0.44201	 0.01342	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56651	 94740	 0.006345	 0.024683	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56651	 94773	 0.088074	 0.12017	 0.00215	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56652	 56654	 0.000997	 0.009071	 0.00229	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56652	 94740	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56652	 94740	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56653	 56664	 0.011876	 0.031394	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94740	 56653	 0.009083	 0.042091	 0.00081	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56654	 56659	 0.000631	 0.005504	 0.00151	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56655	 56659	 0.000777	 0.004922	 0.00134	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56655	 94743	 0.001245	 0.007733	 0.00218	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56656	 56669	 0.001299	 0.00919	 0.00252	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56656	 94741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56656	 94741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56656	 94743	 0.000978	 0.005267	 0.00145	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56657	 56661	 0.000467	 0.004757	 0.00123	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56657	 56668	 0.000933	 0.008961	 0.00261	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56658	 94742	 0.04515	 0.035731	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56659	 56667	 0.00339	 0.012276	 0.00263	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56659	 94742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56659	 94742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92826	 56660	 0.000812	 0.011167	 0.02225	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56660	 94743	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56660	 94743	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56660	 94769	 0.000567	 0.007074	 0.02514	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94743	 56661	 0.000557	 0.004636	 0.0014	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56661	 94744	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56661	 94744	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56662	 56663	 0.013563	 0.014918	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56663	 56664	 0.008778	 0.012233	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56663	 94745	 0.009658	 0.022189	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56665	 57296	 0.002504	 0.013045	 0.00342	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56665	 94772	 0.001601	 0.008101	 0.00226	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56666	 94773	 0.032129	 0.023638	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56667	 94745	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56667	 94745	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56667	 94772	 0.001123	 0.005539	 0.0015	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56668	 56675	 0.001305	 0.004549	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56668	 94772	 0.000618	 0.005303	 0.00151	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56669	 56676	 0.002387	 0.009382	 0.00245	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56669	 94772	 0.000974	 0.010776	 0.00323	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94741	 56670	 0.016582	 0.018238	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56671	 56676	 0.000781	 0.009091	 0.00267	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56672	 56673	 0.000761	 0.003046	 0.00077	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92827	 56672	 0.000567	 0.003208	 0.0008	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56673	 56674	 0.000602	 0.002098	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56674	 56675	 0.001252	 0.004295	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56676	 56677	 0.000569	 0.005561	 0.00156	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56676	 94746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56676	 94746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56677	 56679	 0.000471	 0.003707	 0.00108	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56677	 94747	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56677	 94747	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92828	 56678	 0.00357	 0.017713	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94747	 56678	 0.002337	 0.011216	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56679	 94748	 0.000447	 0.003804	 0.00095	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92826	 56680	 0.00038	 0.002538	 0.00478	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56680	 94748	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56680	 94748	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56680	 94764	 0.000634	 0.0043	 0.00783	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56681	 94750	 0.009039	 0.023236	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56682	 94750	 0.016199	 0.01171	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56683	 56684	 0.000628	 0.003272	 0.00086	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56683	 56687	 0.00079	 0.004117	 0.00108	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56684	 56689	 0.000612	 0.003468	 0.00086	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56685	 56686	 4.7e-05	 0.000526	 0.00492	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56686	 94749	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56686	 94749	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56687	 56691	 0.00115	 0.003593	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56687	 56721	 0.000243	 0.002721	 0.00086	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92763	 56687	 0.000884	 0.004759	 0.00131	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56687	 94750	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56687	 94750	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56687	 94752	 0.001738	 0.01875	 0.00537	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94750	 56688	 0.018044	 0.01367	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56689	 56702	 0.001556	 0.008244	 0.00275	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56689	 94751	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56689	 94751	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92605	 56690	 0.000849	 0.011224	 0.04088	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92652	 56690	 0.00086	 0.007665	 0.01347	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56690	 94752	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94753	 56690	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56690	 94762	 0.000621	 0.008351	 0.0174	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56691	 56692	 0.001442	 0.00381	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56691	 94754	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56691	 94754	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56692	 56695	 0.00266	 0.007029	 0.00165	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56693	 56708	 0.000278	 0.003101	 0.02924	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56693	 56711	 0.00048	 0.005271	 0.0512	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56693	 94755	 9.3e-05	 0.007407	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94756	 56693	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56694	 94757	 0.009527	 0.024228	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56694	 94761	 0.028216	 0.020759	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56695	 56706	 0.001788	 0.007381	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56695	 94757	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56695	 94757	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56696	 56714	 0.004432	 0.021509	 0.00492	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94756	 56696	 0.001656	 0.010276	 0.00249	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94751	 56697	 0.023843	 0.018869	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94751	 56698	 0.016771	 0.013145	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94754	 56699	 0.002767	 0.014744	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56699	 94758	 0.004701	 0.022949	 0.00048	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56700	 56701	 0.001202	 0.004814	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56700	 56703	 0.001117	 0.00447	 0.00113	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56700	 94758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56700	 94758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56701	 56702	 0.001137	 0.004812	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94752	 56702	 0.000375	 0.004202	 0.00134	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56702	 94759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56702	 94759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56704	 94760	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56704	 94760	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56705	 56708	 2.4e-05	 0.000404	 0.00378	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92831	 56706	 0.001152	 0.004689	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94760	 56706	 0.001544	 0.007493	 0.00171	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56707	 56709	 0.000798	 0.004136	 0.00101	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92831	 56707	 0.001776	 0.011246	 0.00305	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56707	 94761	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56707	 94761	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56708	 56711	 0.000169	 0.002227	 0.03567	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56708	 94762	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56708	 94762	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56709	 56713	 0.002776	 0.010552	 0.00295	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56709	 94763	 0.001983	 0.004985	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94762	 56710	 8.4e-05	 0.001146	 0.00233	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56710	 94763	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56710	 94763	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56710	 94764	 0.000417	 0.005155	 0.01034	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56711	 56717	 0.000602	 0.007963	 0.12756	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56711	 94764	 6.8e-05	 0.005405	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56712	 56713	 0.000826	 0.003495	 0.00079	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94748	 56712	 0.004134	 0.014181	 0.0034	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94765	 56712	 0.00216	 0.00543	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94765	 56712	 0.00216	 0.00543	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56714	 56716	 0.002568	 0.013377	 0.00351	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56714	 94767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56714	 94767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56715	 94768	 0.053681	 0.094408	 0.00177	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94765	 56716	 0.001768	 0.02741	 0.00773	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56716	 94768	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56716	 94768	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56716	 94770	 0.008893	 0.047277	 0.01097	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56717	 56866	 0.000783	 0.012492	 0.12631	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56717	 94769	 9.3e-05	 0.007407	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94770	 56717	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92841	 56718	 0.2321	 0.18372	 0.00231	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56719	 94771	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56719	 94771	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56720	 94772	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94749	 56721	 0.000241	 0.002306	 0.00076	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94761	 56722	 0.035944	 0.02327	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56723	 56724	 0.033054	 0.084998	 0.02105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92708	 56724	 0.092553	 0.24914	 0.05664	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56724	 94774	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56724	 94774	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56725	 94942	 0.11023	 0.28039	 0.00444	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56726	 57271	 0.017634	 0.068617	 0.01833	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56726	 94775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56726	 94775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56727	 56728	 0.018823	 0.033963	 0.00049	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56727	 56729	 0.016433	 0.03363	 0.00083	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56729	 56730	 0.031021	 0.022823	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94775	 56729	 0.021315	 0.060484	 0.00095	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56731	 56813	 0.023373	 0.081477	 0.0189	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56732	 56740	 0.00017	 0.002922	 0.05088	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56733	 56734	 0.001002	 0.003897	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56733	 56735	 0.003833	 0.013148	 0.00315	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56734	 57721	 0.001028	 0.003907	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56735	 56738	 0.001645	 0.010529	 0.00354	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56735	 57729	 0.00298	 0.015525	 0.00407	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56735	 94776	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56735	 94776	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94776	 56736	 0.012306	 0.024365	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56736	 94777	 0.013427	 0.05037	 0.00091	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56737	 94777	 0.013122	 0.043304	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56737	 94782	 0.011034	 0.049169	 0.00084	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56738	 56742	 0.00379	 0.019375	 0.00528	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56738	 94777	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56738	 94777	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56739	 57723	 0.001675	 0.01577	 0.00478	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56739	 94778	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56739	 94778	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56739	 94779	 0.001575	 0.016984	 0.00486	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56740	 56741	 0.000176	 0.002413	 0.02459	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56740	 56743	 0.000303	 0.003427	 0.0312	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56740	 94779	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56740	 94779	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56741	 94780	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56741	 94780	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56742	 57720	 0.002407	 0.014555	 0.00371	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94780	 56742	 0.00093	 0.012052	 0.00477	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56743	 57637	 0.001184	 0.015654	 0.25096	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56743	 57666	 0.000785	 0.012756	 0.12436	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56743	 94781	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56743	 94781	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56744	 56745	 0.002116	 0.00921	 0.00262	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56744	 56750	 0.003902	 0.015181	 0.00405	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56744	 56752	 0.012677	 0.038498	 0.00843	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92703	 56745	 0.001666	 0.011559	 0.0033	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56745	 94782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56745	 94782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56746	 56747	 0.008416	 0.042092	 0.00075	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56746	 95082	 0.014668	 0.056431	 0.00096	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94777	 56747	 0.012614	 0.076661	 0.00141	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56748	 56751	 0.003172	 0.026673	 0.0079	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56748	 57735	 0.001735	 0.012815	 0.0037	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56749	 56751	 0.002975	 0.015769	 0.00526	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56750	 56751	 0.00171	 0.016094	 0.00487	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56750	 56752	 0.009323	 0.032955	 0.00743	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56750	 94783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56750	 94783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92703	 56751	 0.007842	 0.049671	 0.01348	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56753	 56754	 0.004703	 0.024496	 0.00642	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56753	 56758	 0.00552	 0.024853	 0.00661	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92583	 56754	 0.00387	 0.056897	 0.0174	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56755	 56756	 0.000958	 0.003486	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56755	 56759	 0.001078	 0.004453	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56756	 56759	 0.00173	 0.007323	 0.00165	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94781	 56756	 0.002964	 0.011867	 0.00299	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56756	 94784	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56756	 94784	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94784	 56757	 0.022336	 0.017676	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56758	 56759	 0.000897	 0.003589	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56760	 56761	 7.9e-05	 0.001978	 0.03239	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56760	 94785	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56760	 94785	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56762	 56763	 0.004749	 0.044705	 0.01354	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56762	 56764	 0.006366	 0.047036	 0.01358	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56762	 56765	 0.006644	 0.018088	 0.00398	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94785	 56765	 0.013041	 0.059836	 0.01533	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56766	 56769	 0.023704	 0.062656	 0.01467	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56766	 58533	 0.025578	 0.066417	 0.01612	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56766	 94786	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56766	 94786	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56767	 56768	 0.069975	 0.14708	 0.00268	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92628	 56767	 0.13315	 0.51265	 0.00876	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56767	 95316	 0.05265	 0.18437	 0.00511	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94185	 56769	 0.025934	 0.091697	 0.02067	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92730	 56770	 0.002918	 0.005778	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56771	 94787	 0.024866	 0.041303	 0.00088	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56772	 56773	 0.030652	 0.038048	 0.00083	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56773	 57449	 0.033377	 0.066085	 0.00097	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92730	 56773	 0.026063	 0.066997	 0.00104	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92729	 56774	 0.004873	 0.014666	 0.00459	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56774	 94787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56774	 94787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56774	 94788	 0.009095	 0.036399	 0.0123	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56775	 56776	 0.008439	 0.032959	 0.00073	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56775	 94789	 0.010935	 0.036479	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56777	 94788	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56778	 58263	 0.002419	 0.033821	 0.01147	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94788	 56778	 0.001625	 0.022984	 0.00761	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56778	 95002	 0.014793	 0.059233	 0.01493	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94789	 56779	 0.048702	 0.087538	 0.00157	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56780	 56781	 0.003481	 0.021599	 0.00523	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56780	 56785	 0.005546	 0.021083	 0.0059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56780	 58267	 0.016247	 0.11694	 0.03101	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94788	 56781	 0.006474	 0.035523	 0.00939	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56782	 56786	 0.002943	 0.030573	 0.00945	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56783	 56784	 0.039929	 0.031299	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94789	 56784	 0.074439	 0.17283	 0.00257	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56784	 94790	 0.021724	 0.11297	 0.00245	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56785	 56787	 0.007329	 0.028807	 0.00754	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56786	 56787	 0.002046	 0.0286	 0.0097	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56786	 94790	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56786	 94790	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56788	 56789	 0.067789	 0.15739	 0.00234	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93866	 56788	 0.17188	 0.39922	 0.00594	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94315	 56788	 0.051635	 0.29359	 0.00531	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56789	 56793	 0.074317	 0.1252	 0.00178	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56790	 56793	 0.025493	 0.095634	 0.00172	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56790	 56805	 0.060802	 0.18674	 0.0035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56791	 56793	 0.026519	 0.065822	 0.00109	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93866	 56793	 0.047824	 0.17086	 0.00339	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56794	 58434	 0.038223	 0.12761	 0.03239	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92637	 56794	 0.012706	 0.034113	 0.00773	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92664	 56794	 0.019535	 0.069062	 0.01556	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92741	 56795	 0.17219	 0.35259	 0.00868	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56796	 56799	 0.029304	 0.11739	 0.0296	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93865	 56796	 0.039548	 0.16757	 0.03776	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56796	 94791	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56796	 94791	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56797	 56802	 0.04012	 0.025974	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56798	 56799	 0.013294	 0.054104	 0.01318	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56798	 94792	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56798	 94792	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56799	 56806	 0.017334	 0.099637	 0.02824	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56800	 56803	 0.079498	 0.062915	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56801	 56803	 0.012282	 0.054728	 0.00093	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94792	 56801	 0.051519	 0.25116	 0.00471	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56802	 56803	 0.014428	 0.033491	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56803	 56804	 0.11397	 0.12144	 0.00173	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94791	 56803	 0.022384	 0.087083	 0.00145	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94791	 56805	 0.056661	 0.15019	 0.00381	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56806	 56807	 0.001486	 0.005649	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56806	 95027	 0.04797	 0.19552	 0.04774	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56807	 57053	 0.028498	 0.11093	 0.02965	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56808	 95026	 0.70584	 0.45799	 0.00871	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56809	 95239	 0.1621	 0.37649	 0.0056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56810	 94793	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94794	 56810	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56811	 56814	 0.003001	 0.010111	 0.00251	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92821	 56811	 0.005245	 0.013186	 0.00342	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94794	 56811	 0.010593	 0.035693	 0.00887	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56811	 94943	 0.007345	 0.019412	 0.00454	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56812	 56813	 0.003412	 0.009016	 0.00211	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92821	 56812	 0.006537	 0.017583	 0.00493	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56813	 56814	 0.003232	 0.008542	 0.002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56815	 94795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56815	 94795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56816	 94796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56816	 94796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92716	 56819	 0.003954	 0.027434	 0.00783	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56819	 94797	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56819	 94797	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56820	 56827	 0.054813	 0.079874	 0.00181	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56821	 56828	 0.022219	 0.022442	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92778	 56822	 0.037472	 0.074193	 0.00109	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92778	 56823	 0.017575	 0.017946	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56824	 56825	 0.003352	 0.013419	 0.00338	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92716	 56825	 0.000773	 0.008071	 0.00222	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56826	 56828	 0.013417	 0.034489	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92717	 56826	 0.005087	 0.026112	 0.00049	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92778	 56827	 0.043505	 0.11184	 0.00173	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92817	 56829	 0.009229	 0.052266	 0.01296	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92614	 56830	 0.003335	 0.038134	 0.01068	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92817	 56830	 0.001814	 0.018339	 0.00539	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56830	 94798	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56830	 94798	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92614	 56831	 0.005188	 0.043636	 0.01293	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56831	 94799	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56831	 94799	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94799	 56832	 0.041437	 0.20564	 0.0049	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56832	 94800	 0.043212	 0.12394	 0.00191	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92817	 56833	 0.022974	 0.092012	 0.02319	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56833	 94800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56833	 94800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56834	 56836	 0.005692	 0.038137	 0.01168	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56834	 57089	 0.010839	 0.080105	 0.02313	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56835	 56837	 0.011394	 0.043313	 0.01213	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56835	 94801	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56835	 94801	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56836	 56837	 0.00228	 0.017088	 0.00417	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56837	 56838	 0.002115	 0.008228	 0.0022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56839	 94802	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56839	 94802	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56840	 56843	 0.13874	 0.35297	 0.00558	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56841	 56842	 0.080861	 0.14591	 0.00211	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56841	 56843	 0.21821	 0.16057	 0.00235	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56843	 56845	 0.078674	 0.15578	 0.00229	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56844	 56845	 0.18174	 0.16743	 0.00268	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92612	 56846	 0.008378	 0.037723	 0.01004	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56847	 56849	 0.013683	 0.042553	 0.00888	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92597	 56848	 0.004684	 0.043118	 0.08211	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92611	 56848	 0.004119	 0.040585	 0.08656	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92678	 56848	 0.003491	 0.024052	 0.04247	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94609	 56848	 0.007875	 0.076495	 0.27193	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56848	 94803	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56848	 94803	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92679	 56849	 0.021084	 0.073797	 0.02447	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92804	 56849	 0.016971	 0.044854	 0.0105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93928	 56849	 0.037545	 0.10226	 0.02254	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94341	 56849	 0.08532	 0.19852	 0.06064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94803	 56849	 0.008622	 0.023147	 0.00525	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56849	 94804	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56849	 94804	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92589	 56850	 0.079388	 0.30551	 0.00522	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94714	 56850	 0.066036	 0.32251	 0.00676	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92587	 56851	 0.002284	 0.017449	 0.06487	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92606	 56851	 0.007128	 0.061218	 0.13469	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56851	 94805	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56851	 94805	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56852	 57017	 0.000849	 0.013856	 0.13397	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56852	 94806	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56852	 94806	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56853	 57134	 0.00412	 0.020313	 0.00549	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56854	 56855	 0.004417	 0.035489	 0.00998	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56855	 56861	 0.012293	 0.042844	 0.00994	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56855	 57132	 0.003477	 0.018429	 0.00615	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56856	 56857	 0.006331	 0.03409	 0.00937	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56856	 56860	 0.008392	 0.039142	 0.0097	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56857	 56858	 0.010573	 0.038285	 0.00821	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56857	 57344	 0.007674	 0.073693	 0.02144	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56858	 94807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56858	 94807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56859	 56860	 0.008709	 0.034871	 0.00879	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56859	 56865	 0.018015	 0.047614	 0.01115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56859	 94808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56859	 94808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56860	 56861	 0.007347	 0.025205	 0.00604	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56860	 94810	 0.009529	 0.046247	 0.01057	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56861	 94809	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56861	 94809	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56862	 94810	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56862	 94810	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56862	 94811	 0.000611	 0.009742	 0.02	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56863	 56864	 0.000218	 0.003421	 0.03565	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56863	 94811	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94812	 56863	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56864	 56866	 0.000391	 0.006411	 0.06294	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56864	 94813	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56864	 94813	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56865	 94814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56865	 94814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56866	 94815	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56866	 94815	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56867	 94816	 0.07202	 0.16473	 0.00402	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56868	 56869	 0.002417	 0.009678	 0.00244	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56868	 56872	 0.011126	 0.045276	 0.01103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56868	 94816	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56868	 94816	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56869	 56870	 0.001448	 0.007671	 0.00194	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56869	 57187	 0.014699	 0.05886	 0.01483	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56870	 56873	 0.00934	 0.047749	 0.01302	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56870	 94817	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56870	 94817	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94816	 56871	 0.025816	 0.066364	 0.00103	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94817	 56871	 0.012198	 0.022341	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56871	 94819	 0.060547	 0.17807	 0.00365	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56872	 56996	 0.014588	 0.057345	 0.015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56872	 94818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56872	 94818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56872	 94820	 0.015042	 0.054471	 0.01169	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92588	 56873	 0.005528	 0.033968	 0.01242	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56873	 94819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56873	 94819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56873	 94820	 0.014277	 0.060434	 0.0136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56874	 57184	 0.010029	 0.066128	 0.12821	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92584	 56874	 0.001776	 0.020339	 0.03979	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56874	 94820	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56874	 94820	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56875	 56876	 0.1025	 0.238	 0.00354	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56875	 94946	 0.1347	 0.38651	 0.00595	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94666	 56876	 0.29339	 0.49462	 0.00705	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56877	 57270	 0.063202	 0.21338	 0.05317	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56877	 58537	 0.056059	 0.14568	 0.0354	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92627	 56877	 0.022716	 0.096176	 0.02165	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56877	 94821	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56877	 94821	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56878	 56879	 0.069053	 0.13673	 0.00201	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94821	 56878	 0.068025	 0.22696	 0.0036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56879	 57492	 0.33614	 0.31299	 0.00592	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56880	 57492	 0.20196	 0.14602	 0.00221	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56881	 56882	 0.005966	 0.025251	 0.00568	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56881	 57494	 0.023972	 0.083912	 0.02782	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56882	 94822	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56882	 94822	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94822	 56883	 0.22344	 0.17686	 0.00223	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92626	 56884	 0.052507	 0.041554	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93930	 56885	 0.004354	 0.028046	 0.00735	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92810	 56886	 0.03476	 0.022504	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56887	 57426	 0.5173	 0.7534	 0.01196	 39.0	 39.0	 39.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56887	 58538	 0.324	 0.4692	 0.00711	 39.0	 39.0	 39.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56888	 56955	 0.052323	 0.041408	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56889	 56892	 0.000981	 0.006214	 0.00169	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56889	 94823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56889	 94823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56890	 56898	 0.00167	 0.008685	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56890	 56901	 0.014824	 0.019483	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56890	 94824	 0.003637	 0.019461	 0.00059	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56891	 56898	 0.00557	 0.014318	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56891	 94825	 0.005526	 0.012828	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56892	 56897	 0.000882	 0.005335	 0.00136	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56892	 94824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56892	 94824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56893	 56894	 0.007318	 0.015381	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56893	 94828	 0.008168	 0.018962	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56894	 94825	 0.012043	 0.023843	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56895	 56896	 0.044111	 0.044554	 0.00059	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56895	 56938	 0.06065	 0.039265	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56895	 94829	 0.032299	 0.029751	 0.00048	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94824	 56896	 0.012466	 0.025511	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56897	 56910	 0.000928	 0.005438	 0.00148	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56897	 94825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56897	 94825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56898	 56899	 0.003231	 0.006924	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56898	 56900	 0.002655	 0.007038	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56898	 56907	 0.007118	 0.020417	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56899	 56901	 0.004512	 0.011474	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56900	 56901	 0.010062	 0.019719	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56900	 56906	 0.002134	 0.011243	 0.0002	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56901	 56905	 0.005737	 0.022319	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56902	 56903	 0.005855	 0.022527	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56902	 56903	 0.005855	 0.022527	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56903	 56904	 0.006665	 0.02593	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56903	 56904	 0.006665	 0.02593	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92813	 56904	 0.018062	 0.051253	 0.00081	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56904	 94833	 0.00809	 0.027635	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56904	 94833	 0.00809	 0.027635	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56905	 56906	 0.013467	 0.014381	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56905	 94831	 0.004005	 0.019325	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56906	 94830	 0.00731	 0.016972	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56906	 94831	 0.005664	 0.024956	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56907	 94826	 0.003666	 0.006816	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56907	 94827	 0.009914	 0.017888	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56908	 56910	 0.000815	 0.004335	 0.00101	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56908	 56930	 0.000805	 0.004623	 0.00131	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56908	 94826	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56908	 94826	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56909	 94827	 0.008724	 0.016488	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56909	 94828	 0.027694	 0.021917	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56910	 56911	 0.003142	 0.00954	 0.00209	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56910	 56930	 0.001451	 0.008499	 0.00231	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56910	 94827	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56910	 94827	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56911	 56913	 0.001814	 0.005349	 0.00124	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56911	 94828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56911	 94828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56912	 56915	 0.005927	 0.016819	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56912	 56939	 0.018498	 0.020148	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56913	 56941	 0.007642	 0.01984	 0.00482	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56913	 94829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56913	 94829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56914	 56943	 0.022035	 0.020664	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56915	 56916	 0.004899	 0.012594	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56916	 56917	 0.005723	 0.013285	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94828	 56916	 0.00482	 0.014802	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56917	 56920	 0.009668	 0.017445	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94827	 56917	 0.012412	 0.024574	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56918	 56921	 0.016308	 0.01602	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56919	 56922	 0.018401	 0.016949	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56920	 56923	 0.004808	 0.010265	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94827	 56920	 0.011491	 0.017038	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56921	 56922	 0.00629	 0.0146	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56921	 56925	 0.008878	 0.014171	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94827	 56921	 0.013937	 0.035826	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56922	 56946	 0.019929	 0.015771	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56923	 56924	 0.001766	 0.006184	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56924	 94830	 0.002193	 0.0084	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56925	 56926	 0.023444	 0.015177	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56925	 56928	 0.004807	 0.012358	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56926	 56947	 0.007301	 0.014455	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56927	 56929	 0.01246	 0.013306	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56928	 56929	 0.004441	 0.011415	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56929	 56948	 0.040454	 0.032015	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56929	 94831	 0.003711	 0.01745	 0.00032	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56930	 56931	 0.000355	 0.003994	 0.00115	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56930	 56952	 0.005809	 0.017638	 0.00386	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56930	 94830	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56930	 94830	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56931	 94831	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56931	 94831	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56931	 94832	 0.000496	 0.00535	 0.00286	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56932	 94832	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56933	 56934	 0.10506	 0.083149	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56933	 56935	 0.2166	 0.16981	 0.00218	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92747	 56933	 0.28593	 0.55476	 0.01195	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56934	 56935	 0.18771	 0.14856	 0.00187	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94823	 56935	 0.042389	 0.1078	 0.0017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56936	 56937	 0.002432	 0.008848	 0.00271	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56937	 56941	 0.006043	 0.023752	 0.00621	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56938	 94834	 0.020768	 0.041119	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56939	 56943	 0.028968	 0.038072	 0.00052	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56939	 56945	 0.011708	 0.017935	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	56940	 56942	 0.022406	 0.041039	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56940	 56943	 0.054742	 0.04291	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56940	 56944	 0.10185	 0.080605	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56941	 94834	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56941	 94834	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94834	 56942	 0.034824	 0.086437	 0.00144	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94834	 56943	 0.041218	 0.098314	 0.0022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94834	 56944	 0.10137	 0.20074	 0.00295	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56945	 56946	 0.007222	 0.013428	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56945	 56950	 0.023309	 0.01685	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56946	 56951	 0.004965	 0.014945	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56947	 94836	 0.005094	 0.015627	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56948	 94836	 0.020308	 0.019044	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56949	 56952	 0.00351	 0.014051	 0.00354	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56949	 56956	 0.019599	 0.051802	 0.01213	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56949	 94835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56949	 94835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56951	 94836	 0.008504	 0.02837	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56952	 94836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56952	 94836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92645	 56953	 0.013056	 0.034507	 0.00808	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56953	 94837	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56953	 94837	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92645	 56954	 0.002103	 0.014807	 0.00842	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56954	 94838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56954	 94838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56956	 56957	 0.013474	 0.037575	 0.00789	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92701	 56957	 0.024574	 0.080175	 0.02129	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	56957	 94839	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56957	 94839	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94839	 56958	 0.063204	 0.12387	 0.00186	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56959	 56960	 0.002675	 0.020146	 0.00559	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56959	 56961	 0.005407	 0.04344	 0.01221	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56959	 57494	 0.02388	 0.12447	 0.03268	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56959	 57985	 0.023027	 0.2504	 0.07863	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56960	 57025	 0.018224	 0.094965	 0.02492	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56961	 57453	 0.022075	 0.17761	 0.05003	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56962	 56965	 0.020392	 0.015003	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56962	 56972	 0.022595	 0.017711	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56963	 56964	 0.022801	 0.014762	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56963	 56965	 0.009958	 0.023114	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56963	 56979	 0.025673	 0.020123	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56963	 94843	 0.00664	 0.033785	 0.00077	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56964	 56975	 0.014931	 0.019431	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56965	 56966	 0.026272	 0.020593	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56966	 56967	 0.009265	 0.018345	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56967	 56968	 0.004548	 0.010768	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56967	 56970	 0.007588	 0.012111	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56967	 94853	 0.011096	 0.037016	 0.00059	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56968	 94847	 0.005269	 0.013079	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56969	 56971	 0.000805	 0.003276	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56969	 56983	 0.001626	 0.006509	 0.00164	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56969	 94840	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56969	 94840	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56970	 56972	 0.007281	 0.012265	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	56971	 56973	 0.001498	 0.003959	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56971	 56989	 0.001519	 0.006082	 0.00153	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56973	 56974	 0.003136	 0.007557	 0.00213	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56974	 56976	 0.002292	 0.007126	 0.00149	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56974	 94841	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56974	 94841	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94841	 56975	 0.013003	 0.033068	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56976	 56977	 0.002112	 0.008939	 0.00201	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56976	 94842	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56976	 94842	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56977	 56978	 0.005866	 0.015228	 0.0037	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	56977	 56995	 0.006305	 0.025241	 0.00636	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92588	 56978	 0.030309	 0.18865	 0.05337	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56978	 94843	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56978	 94843	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56979	 56981	 0.045566	 0.03606	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56980	 57001	 0.001524	 0.009894	 0.01971	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	56980	 94844	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94845	 56980	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56981	 94853	 0.017222	 0.033752	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56982	 56983	 0.000968	 0.003998	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56982	 57011	 0.001447	 0.005628	 0.0015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56982	 94846	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56982	 94846	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56983	 94847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56983	 94847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56984	 94848	 0.015058	 0.01979	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	56985	 56987	 0.002453	 0.009324	 0.00261	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56985	 94848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56985	 94848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56985	 94850	 0.002251	 0.00901	 0.00227	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56986	 56990	 0.093824	 0.073545	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56986	 94851	 0.013705	 0.026859	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56987	 56989	 0.00137	 0.005797	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56987	 94849	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	56987	 94849	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94840	 56988	 0.008435	 0.016531	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94849	 56988	 0.008342	 0.017072	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56989	 56991	 0.000846	 0.0068	 0.00191	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56991	 57008	 0.001705	 0.013698	 0.00385	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56992	 56993	 0.031218	 0.024706	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56992	 56994	 0.010291	 0.040037	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94842	 56992	 0.019822	 0.050955	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56994	 57010	 0.037329	 0.098682	 0.00179	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56994	 94852	 0.044136	 0.11439	 0.00216	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56995	 56996	 0.009917	 0.038979	 0.0102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	56996	 56997	 0.002786	 0.028385	 0.00732	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92792	 56997	 0.000871	 0.008362	 0.00243	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94845	 56998	 0.09342	 0.073229	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	56999	 57000	 0.023589	 0.046704	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57000	 94851	 0.018411	 0.047327	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93784	 57001	 0.009384	 0.065602	 0.11282	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57001	 94850	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94851	 57001	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57002	 57003	 0.017239	 0.067063	 0.00112	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94851	 57002	 0.009374	 0.032019	 0.0007	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94850	 57004	 0.004448	 0.044071	 0.0135	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94850	 57005	 0.016749	 0.045603	 0.01005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57006	 57007	 0.25272	 0.20004	 0.00252	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94014	 57006	 0.10954	 0.2169	 0.00318	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57007	 94852	 0.05754	 0.10342	 0.00186	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92742	 57008	 0.007147	 0.068628	 0.01997	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57008	 94852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57008	 94852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57009	 57010	 0.052615	 0.13526	 0.00209	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92743	 57009	 0.058806	 0.27661	 0.00515	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94844	 57011	 0.00299	 0.014509	 0.00332	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94850	 57011	 0.005554	 0.019053	 0.00456	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57011	 94853	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57011	 94853	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94852	 57012	 0.036087	 0.026087	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92628	 57013	 0.14498	 0.41601	 0.0064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57014	 94855	 0.24649	 0.19325	 0.00248	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57015	 58298	 0.006352	 0.055429	 0.01522	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57015	 94854	 0.001991	 0.019115	 0.00556	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94805	 57016	 0.005944	 0.067959	 0.02073	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57016	 94854	 0.003782	 0.037666	 0.01399	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57017	 94854	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57018	 94856	 0.12554	 0.15029	 0.0025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92697	 57019	 0.006503	 0.022664	 0.00526	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92696	 57020	 0.001375	 0.010356	 0.02217	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92823	 57020	 0.002453	 0.016735	 0.03014	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57020	 95233	 0.001315	 0.011277	 0.02476	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92697	 57021	 0.02117	 0.055957	 0.0131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57021	 94856	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57021	 94856	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92759	 57022	 0.052758	 0.17412	 0.00282	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57022	 94871	 0.19684	 0.35531	 0.00514	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92758	 57023	 0.006144	 0.017797	 0.00429	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57023	 94870	 0.013213	 0.083714	 0.02273	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57024	 94857	 0.050445	 0.039542	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57025	 94857	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57025	 94857	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57026	 57027	 0.000238	 0.003166	 0.05017	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57026	 57029	 0.000252	 0.003163	 0.05602	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57028	 94858	 0.00258	 0.023895	 0.01197	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57029	 94858	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57030	 57032	 0.064321	 0.046498	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94859	 57030	 0.01268	 0.0223	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94859	 57031	 0.14666	 0.094955	 0.00181	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92581	 57033	 0.011776	 0.054031	 0.01384	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92582	 57034	 0.033845	 0.12697	 0.00228	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92581	 57035	 0.009183	 0.044568	 0.01019	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94858	 57035	 0.012988	 0.053631	 0.01269	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94187	 57036	 0.1445	 0.26473	 0.00457	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57037	 57038	 0.017239	 0.026146	 0.00037	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57038	 57041	 0.024728	 0.052794	 0.00119	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57038	 57043	 0.010052	 0.02584	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57038	 94860	 0.045319	 0.25767	 0.00466	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57039	 57041	 0.009426	 0.018051	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57040	 57043	 0.029874	 0.021979	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57042	 57043	 0.018654	 0.014763	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57044	 58255	 0.02518	 0.18896	 0.04619	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57044	 58573	 0.035569	 0.14699	 0.03482	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57044	 94860	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57044	 94860	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57044	 95238	 0.041866	 0.16783	 0.04235	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57045	 57050	 0.039925	 0.085558	 0.0015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57047	 57048	 0.016655	 0.066695	 0.01681	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57047	 57051	 0.017676	 0.057662	 0.01531	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57047	 58245	 0.010609	 0.058223	 0.01539	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57048	 94861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57048	 94861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57049	 94862	 0.054974	 0.11251	 0.00277	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57050	 94862	 0.043724	 0.12541	 0.00193	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57051	 57052	 0.014553	 0.042908	 0.00998	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57052	 94862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57052	 94862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57053	 95027	 0.044363	 0.20012	 0.05338	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57054	 57055	 0.03613	 0.026582	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57054	 57059	 0.029376	 0.048992	 0.00071	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92759	 57054	 0.11311	 0.32452	 0.00499	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57055	 57059	 0.007531	 0.0216	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57055	 94871	 0.009946	 0.038265	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57056	 57057	 0.023507	 0.015219	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57056	 57058	 0.004121	 0.016033	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57056	 57061	 0.006464	 0.013227	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57057	 57059	 0.006572	 0.016893	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57057	 57061	 0.012492	 0.024733	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57057	 57063	 0.009812	 0.025222	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57058	 57071	 0.021824	 0.017271	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57058	 57072	 0.009248	 0.023772	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57058	 94867	 0.02969	 0.024437	 0.0005	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57058	 94868	 0.002732	 0.014729	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57059	 94868	 0.006661	 0.019104	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57060	 57061	 0.017455	 0.017147	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57060	 57072	 0.008952	 0.015742	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57060	 57080	 0.054713	 0.074584	 0.00165	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94197	 57060	 0.27433	 0.25735	 0.00398	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57060	 94864	 0.026853	 0.019756	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57060	 94865	 0.033653	 0.026379	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57061	 57062	 0.031006	 0.024537	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57061	 94864	 0.006136	 0.014097	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57062	 57063	 0.019649	 0.019846	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57062	 94863	 0.007335	 0.014522	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57062	 94871	 0.019874	 0.0663	 0.00105	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57063	 57079	 0.007762	 0.015213	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57064	 57065	 0.002633	 0.006112	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57064	 57066	 0.003626	 0.009582	 0.00224	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57064	 57067	 0.001927	 0.005581	 0.00135	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57064	 94863	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57064	 94863	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57065	 57066	 0.00134	 0.00337	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57065	 94864	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57065	 94864	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57066	 57078	 0.006869	 0.020675	 0.00647	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57066	 94865	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57066	 94865	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57067	 57077	 0.011475	 0.052648	 0.01349	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57067	 94866	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57067	 94866	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94866	 57068	 0.026713	 0.02505	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57069	 57079	 0.009423	 0.015875	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57070	 57073	 0.000951	 0.005572	 0.00152	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57070	 57078	 0.00574	 0.026331	 0.00675	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57070	 94867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57070	 94867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94867	 57071	 0.019911	 0.024272	 0.00039	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57073	 94868	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57073	 94868	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57073	 94870	 0.000813	 0.006009	 0.00173	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57074	 94871	 0.03063	 0.022535	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57075	 57077	 0.019201	 0.060027	 0.01739	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92638	 57075	 0.064493	 0.14991	 0.04574	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92797	 57075	 0.016711	 0.043388	 0.01053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57075	 94869	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57075	 94869	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57076	 94870	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94871	 57076	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94201	 57078	 0.005667	 0.032913	 0.00775	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57078	 94872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57078	 94872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94866	 57079	 0.015851	 0.027876	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94872	 57080	 0.048705	 0.038545	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57081	 57083	 0.052932	 0.12161	 0.00185	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57082	 57086	 0.086618	 0.10369	 0.00173	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57083	 57084	 0.045928	 0.085399	 0.002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57083	 57085	 0.2348	 0.17279	 0.00253	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57084	 57086	 0.049388	 0.15152	 0.0041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92599	 57086	 0.017373	 0.10681	 0.00193	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92613	 57087	 0.013285	 0.075517	 0.00137	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57088	 57089	 0.005044	 0.040525	 0.01139	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57089	 94873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57089	 94873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92643	 57090	 0.019686	 0.06862	 0.01592	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92774	 57090	 0.005246	 0.026356	 0.00686	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92775	 57091	 0.085707	 0.057573	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57092	 57094	 0.009703	 0.039487	 0.00962	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57092	 94874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57092	 94874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57093	 57094	 0.006758	 0.018845	 0.00396	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57094	 57095	 0.019463	 0.066777	 0.016	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57095	 57096	 0.003372	 0.009768	 0.00236	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57096	 58545	 0.021128	 0.066054	 0.01914	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57097	 58544	 0.098551	 0.22883	 0.0034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94874	 57097	 0.095638	 0.17785	 0.00416	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57098	 94875	 0.026363	 0.067768	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57099	 57100	 0.001847	 0.019188	 0.00593	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94341	 57099	 0.005711	 0.074343	 0.02149	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57099	 94875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57099	 94875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57100	 57106	 0.010746	 0.032632	 0.00715	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94875	 57101	 0.027196	 0.051399	 0.00083	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57102	 57103	 0.001038	 0.014984	 0.00476	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57102	 57154	 0.003027	 0.016611	 0.00439	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57102	 57155	 0.005277	 0.036612	 0.01045	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57103	 57106	 0.001236	 0.013685	 0.00445	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57103	 94876	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57103	 94876	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57104	 57139	 0.001566	 0.013876	 0.00369	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57104	 94878	 0.00115	 0.008136	 0.00223	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57105	 94877	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94878	 57106	 0.00351	 0.016369	 0.00405	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57106	 94880	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57106	 94880	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57107	 57124	 0.001698	 0.009422	 0.00286	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94878	 57107	 0.002046	 0.013375	 0.0034	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57108	 57112	 0.001522	 0.007428	 0.00205	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94878	 57108	 0.001454	 0.008067	 0.00245	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57108	 94881	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57108	 94881	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57109	 57110	 0.000452	 0.002807	 0.00079	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94878	 57109	 0.000562	 0.005228	 0.00162	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57109	 94882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57109	 94882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57110	 57111	 0.000472	 0.00241	 0.00066	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57110	 94883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57110	 94883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57111	 57112	 0.001116	 0.006924	 0.00168	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57111	 57113	 0.000773	 0.003446	 0.00094	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57111	 94884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57111	 94884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57112	 57114	 0.001176	 0.005705	 0.0013	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57112	 94888	 0.001007	 0.005722	 0.00166	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57113	 94885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57113	 94885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57114	 57116	 0.001596	 0.006067	 0.0017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57115	 57116	 0.001189	 0.005352	 0.00142	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94642	 57115	 0.000669	 0.004954	 0.00254	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57115	 94888	 0.001512	 0.011782	 0.00352	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57116	 94886	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57116	 94886	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57117	 57118	 0.00103	 0.004049	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57117	 94888	 0.00093	 0.004942	 0.00115	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57118	 57121	 0.002301	 0.007893	 0.00189	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57118	 94887	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57118	 94887	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94877	 57119	 0.00044	 0.006582	 0.0154	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57119	 94888	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94889	 57119	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94889	 57120	 0.010687	 0.02718	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57121	 57122	 0.003241	 0.008332	 0.00206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57122	 57124	 0.004043	 0.017597	 0.00501	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57122	 57126	 0.00523	 0.0277	 0.00702	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57122	 94895	 0.004263	 0.046711	 0.01295	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57123	 94891	 0.019113	 0.047439	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57124	 94890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57124	 94890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57125	 57130	 0.045815	 0.10849	 0.00198	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94890	 57125	 0.023649	 0.067111	 0.00105	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57125	 94896	 0.01536	 0.093352	 0.00172	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57126	 57127	 0.005069	 0.017388	 0.00417	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57126	 94891	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57126	 94891	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57127	 94892	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57127	 94892	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57128	 57133	 0.002115	 0.015213	 0.00403	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57128	 94893	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57128	 94893	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57129	 57130	 0.022345	 0.052912	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57129	 57131	 0.017756	 0.045157	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94893	 57130	 0.037679	 0.086566	 0.00131	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57131	 94896	 0.033608	 0.11212	 0.00178	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57132	 57133	 0.001622	 0.012217	 0.00339	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57132	 57134	 0.005689	 0.024078	 0.00542	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57132	 94894	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57132	 94894	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57134	 94895	 0.007437	 0.028269	 0.00791	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57135	 94895	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57136	 57137	 0.001452	 0.006536	 0.00174	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57136	 57140	 0.00115	 0.005178	 0.00138	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94895	 57137	 0.003643	 0.02577	 0.00707	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57137	 94897	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57137	 94897	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94897	 57138	 0.021985	 0.043086	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57139	 57142	 0.001129	 0.009681	 0.00275	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57139	 94898	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57139	 94898	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57140	 57141	 0.00249	 0.007143	 0.00176	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57140	 57142	 0.002969	 0.009016	 0.00197	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57140	 58296	 0.012361	 0.082848	 0.02539	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94878	 57140	 0.003773	 0.026175	 0.00747	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57141	 57142	 0.002136	 0.005645	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57141	 57145	 0.00276	 0.011052	 0.00278	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57142	 57143	 0.001587	 0.011009	 0.00314	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57143	 57150	 0.001688	 0.012839	 0.00403	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57143	 94899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57143	 94899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57144	 57147	 0.053558	 0.12016	 0.00192	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94899	 57144	 0.011214	 0.04006	 0.0008	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57146	 57474	 0.003698	 0.037051	 0.01233	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94895	 57146	 0.001672	 0.017372	 0.00537	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57147	 57148	 0.027631	 0.054708	 0.0008	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57147	 95250	 0.028274	 0.15571	 0.00351	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57149	 58297	 0.006694	 0.045957	 0.01341	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57151	 57153	 0.002585	 0.018592	 0.00493	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57151	 57156	 0.005762	 0.036497	 0.00991	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92692	 57151	 0.011136	 0.081418	 0.02403	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57152	 94900	 0.010957	 0.028166	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57153	 57154	 0.00225	 0.012927	 0.00366	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57153	 94900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57153	 94900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92692	 57154	 0.01509	 0.10861	 0.0288	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94878	 57154	 0.004455	 0.032537	 0.00836	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92692	 57156	 0.007837	 0.049641	 0.01347	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92816	 57157	 0.060761	 0.1562	 0.00242	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57158	 94901	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57158	 94901	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57159	 94902	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57160	 57375	 0.26125	 0.51768	 0.0076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94903	 57160	 0.009853	 0.025328	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92617	 57161	 0.003947	 0.044215	 0.01406	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57161	 94904	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57161	 94904	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57162	 94905	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94906	 57163	 0.01336	 0.019467	 0.00044	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92746	 57164	 0.039646	 0.10483	 0.02455	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57164	 94907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57164	 94907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57165	 57169	 0.003467	 0.028843	 0.00873	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57165	 57466	 0.003703	 0.034478	 0.01068	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57165	 57502	 0.009623	 0.037824	 0.0099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57166	 57174	 0.043502	 0.1975	 0.00428	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92707	 57166	 0.051549	 0.23907	 0.00497	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57167	 57173	 0.002215	 0.023479	 0.00697	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57168	 57175	 0.002433	 0.020242	 0.00613	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57168	 94908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57168	 94908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57169	 57172	 0.002538	 0.024795	 0.00696	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57170	 94910	 0.031108	 0.03142	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57171	 94909	 0.026988	 0.029683	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57172	 57173	 0.000593	 0.00539	 0.00136	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57172	 94909	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57172	 94909	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57173	 57175	 0.001529	 0.013544	 0.00361	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92694	 57173	 0.00638	 0.099331	 0.03083	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57173	 94910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57173	 94910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57174	 94911	 0.011159	 0.020749	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57175	 94911	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57175	 94911	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94909	 57176	 0.018082	 0.035801	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94908	 57177	 0.1115	 0.152	 0.00337	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57178	 57179	 0.007773	 0.0329	 0.0074	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57179	 94912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57179	 94912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57179	 94914	 0.006915	 0.055561	 0.01562	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57180	 57186	 0.003519	 0.033783	 0.00983	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57180	 94913	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57180	 94913	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94913	 57181	 0.084557	 0.15489	 0.00267	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57182	 57185	 0.008403	 0.012245	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94912	 57182	 0.036665	 0.061765	 0.00088	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92735	 57183	 0.025143	 0.064645	 0.01601	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92606	 57184	 0.002154	 0.029332	 0.05971	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92734	 57184	 0.001661	 0.016548	 0.05523	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92753	 57184	 0.006855	 0.06429	 0.24458	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57184	 94914	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57184	 94914	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57185	 94915	 0.032398	 0.091939	 0.00144	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57186	 57187	 0.009878	 0.035937	 0.011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94914	 57186	 0.00374	 0.02505	 0.01575	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57186	 94915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57186	 94915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92822	 57188	 0.26558	 0.21022	 0.00265	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57189	 94916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57189	 94916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94739	 57190	 0.037868	 0.20179	 0.00354	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57191	 57351	 0.004493	 0.049239	 0.48627	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57191	 94917	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94918	 57191	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57192	 94919	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57192	 94919	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94920	 57192	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57193	 57195	 0.001717	 0.005366	 0.00155	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57194	 57195	 0.001301	 0.006648	 0.00181	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92745	 57195	 0.013711	 0.039715	 0.00958	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92768	 57196	 0.011363	 0.078856	 0.02252	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92800	 57196	 0.030642	 0.11155	 0.03418	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57197	 57203	 0.001071	 0.003206	 0.00072	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92672	 57197	 0.001232	 0.004019	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57198	 94921	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94922	 57198	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94922	 57200	 0.003093	 0.012382	 0.00312	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94922	 57200	 0.003093	 0.012382	 0.00312	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57200	 94923	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57200	 94923	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57201	 57202	 0.001397	 0.003691	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94922	 57201	 0.001889	 0.005874	 0.00123	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57201	 94924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57201	 94924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57202	 57203	 0.001009	 0.002709	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57202	 57205	 0.001161	 0.003162	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57202	 94925	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57202	 94925	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57203	 94926	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57203	 94926	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57204	 94927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57204	 94927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57204	 94928	 0.001399	 0.004562	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57204	 95013	 0.007816	 0.031295	 0.00788	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57205	 94928	 0.001662	 0.004462	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92837	 57206	 0.002007	 0.017559	 0.03201	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94793	 57206	 0.007064	 0.048697	 0.08605	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94921	 57206	 0.000743	 0.004895	 0.00947	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57206	 94928	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57206	 94928	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57207	 57217	 0.000782	 0.003041	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57207	 94929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57207	 94929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94924	 57208	 0.011577	 0.011693	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57209	 57212	 0.003978	 0.017725	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94929	 57209	 0.001569	 0.007849	 0.00014	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57210	 57211	 0.013174	 0.026083	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57210	 57212	 0.009442	 0.018694	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94923	 57210	 0.01044	 0.019121	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57211	 57213	 0.034169	 0.024701	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57212	 57215	 0.014154	 0.018602	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94923	 57212	 0.04065	 0.034742	 0.00065	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57213	 57214	 0.016526	 0.018177	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57214	 57215	 0.00666	 0.015232	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57214	 57224	 0.024847	 0.019664	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57214	 94932	 0.06134	 0.048544	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57215	 57216	 0.002784	 0.008841	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57215	 57222	 0.024138	 0.019103	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57216	 57218	 0.001681	 0.008506	 0.00015	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57216	 94931	 0.018714	 0.01755	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94928	 57217	 0.000889	 0.003494	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94929	 57218	 0.003305	 0.01479	 0.0003	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57219	 57221	 0.000336	 0.002883	 0.00082	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94928	 57219	 0.000459	 0.004555	 0.00124	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57219	 94930	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57219	 94930	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94930	 57220	 0.013355	 0.009654	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57221	 57225	 0.001551	 0.006211	 0.00156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57221	 57226	 0.001478	 0.005151	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57221	 94931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57221	 94931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57222	 57223	 0.003681	 0.011304	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94931	 57222	 0.005008	 0.014365	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57223	 57224	 0.00761	 0.013382	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57223	 57246	 0.023383	 0.018505	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57224	 57247	 0.02338	 0.018502	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57225	 57257	 0.003374	 0.011925	 0.00269	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92685	 57225	 0.011248	 0.037526	 0.00952	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57225	 94932	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57225	 94932	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57226	 94933	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57226	 94933	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57227	 57229	 0.005358	 0.008552	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94933	 57227	 0.004704	 0.013492	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57228	 57229	 0.012744	 0.011498	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57228	 57230	 0.022575	 0.017865	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57228	 57244	 0.022131	 0.016976	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57229	 57232	 0.020084	 0.022089	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94932	 57229	 0.008089	 0.016016	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57230	 57240	 0.008288	 0.01323	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57231	 57233	 0.029344	 0.023222	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57231	 57240	 0.027306	 0.021404	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57231	 94934	 0.053875	 0.059256	 0.00079	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57232	 57233	 0.036454	 0.026353	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57234	 57236	 0.003736	 0.010029	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57234	 57274	 0.010779	 0.028487	 0.00667	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57234	 57480	 0.014676	 0.053145	 0.0114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92685	 57234	 0.006438	 0.025777	 0.00649	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57234	 94934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57234	 94934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94934	 57235	 0.012925	 0.020167	 0.00034	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57236	 57237	 0.003223	 0.009653	 0.00217	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57237	 57241	 0.008183	 0.022818	 0.00479	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57237	 57274	 0.014243	 0.035806	 0.00928	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92685	 57237	 0.000812	 0.007197	 0.00192	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57237	 94935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57237	 94935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57238	 57266	 0.019337	 0.054873	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94935	 57238	 0.007432	 0.024792	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57239	 94936	 0.020579	 0.021651	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57240	 94936	 0.003588	 0.013957	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92685	 57241	 0.007238	 0.024829	 0.00595	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57241	 94936	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57241	 94936	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57242	 57243	 0.008417	 0.015187	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94932	 57242	 0.007253	 0.018645	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57243	 57245	 0.010418	 0.018798	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57243	 57260	 0.007918	 0.012127	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57244	 57245	 0.021138	 0.016729	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57245	 57262	 0.016503	 0.010684	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57245	 57264	 0.009326	 0.023716	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94936	 57245	 0.002645	 0.01486	 0.00028	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94932	 57246	 0.009171	 0.015449	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94932	 57247	 0.015145	 0.029004	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57247	 94940	 0.01755	 0.019302	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92819	 57248	 0.008411	 0.032723	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92835	 57248	 0.010838	 0.042164	 0.0007	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57249	 57250	 0.001459	 0.006022	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57250	 94937	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57250	 94937	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57251	 94938	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57251	 94938	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57252	 57269	 0.00322	 0.012892	 0.00325	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57252	 94939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57252	 94939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57253	 95012	 0.077372	 0.13961	 0.00202	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57254	 57266	 0.030794	 0.02437	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57255	 57258	 0.006868	 0.01815	 0.00425	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57255	 57272	 0.01405	 0.048201	 0.01155	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92664	 57255	 0.059148	 0.15649	 0.03668	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92685	 57255	 0.008209	 0.044127	 0.01086	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57256	 94940	 0.013732	 0.009927	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57257	 57258	 0.001351	 0.004102	 0.0009	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57257	 94940	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57257	 94940	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57259	 57260	 0.011782	 0.009324	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94940	 57260	 0.019357	 0.012532	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57261	 57264	 0.020182	 0.020186	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57263	 57264	 0.014873	 0.016358	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57263	 57266	 0.022013	 0.022234	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57265	 57266	 0.030195	 0.023896	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57267	 94941	 0.011467	 0.029163	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57268	 57272	 0.014293	 0.044451	 0.00928	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57268	 94941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57268	 94941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57269	 57270	 0.007717	 0.030897	 0.00778	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57270	 57271	 0.017351	 0.045048	 0.01094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57270	 94942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57270	 94942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92821	 57271	 0.009708	 0.037768	 0.01009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57271	 94943	 0.008854	 0.034446	 0.0092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57271	 94944	 0.027008	 0.094158	 0.02184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57272	 94943	 0.015144	 0.042233	 0.00886	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92842	 57273	 0.006081	 0.038535	 0.08076	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57273	 94943	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57273	 94943	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57274	 57480	 0.013701	 0.047004	 0.01126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57275	 94944	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92684	 57276	 0.017029	 0.024814	 0.00056	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94926	 57276	 0.020495	 0.01622	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94927	 57276	 0.027705	 0.02099	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94923	 57277	 0.038465	 0.050554	 0.00069	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57278	 94946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57278	 94946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57279	 57280	 0.015557	 0.028071	 0.00041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94946	 57280	 0.047857	 0.10856	 0.00217	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92740	 57281	 0.43514	 0.30846	 0.00488	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57282	 57287	 0.001652	 0.006613	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57282	 57288	 0.002835	 0.011706	 0.00277	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57283	 57302	 0.000117	 0.00211	 0.0333	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57283	 94947	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57283	 94947	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57284	 57287	 0.003176	 0.009877	 0.00206	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94947	 57284	 0.002136	 0.005368	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57285	 94949	 0.038135	 0.075505	 0.00111	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57286	 57287	 0.002086	 0.005415	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57286	 57291	 0.002244	 0.008528	 0.00239	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94947	 57286	 0.005502	 0.014542	 0.0034	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92673	 57288	 0.005573	 0.032369	 0.00762	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92674	 57289	 0.059573	 0.049034	 0.00099	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57290	 57292	 0.001632	 0.017886	 0.00496	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92673	 57290	 0.002049	 0.022951	 0.0073	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57290	 94948	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57290	 94948	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92673	 57291	 0.00442	 0.032659	 0.00943	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57291	 94949	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57291	 94949	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57292	 57297	 0.002354	 0.017735	 0.00492	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57292	 57300	 0.00674	 0.031435	 0.00779	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57292	 94950	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57292	 94950	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94948	 57293	 0.13444	 0.10538	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94950	 57294	 0.060556	 0.1199	 0.00176	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57295	 57296	 0.004367	 0.018484	 0.00416	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57296	 57298	 0.004204	 0.02149	 0.00586	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57296	 57299	 0.004719	 0.012132	 0.003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57297	 57298	 0.001885	 0.01171	 0.0033	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57298	 57300	 0.004963	 0.015072	 0.0033	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92653	 57299	 0.00395	 0.024746	 0.01782	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92827	 57299	 0.001539	 0.012579	 0.00341	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92653	 57300	 0.005255	 0.017141	 0.00455	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94760	 57300	 0.004403	 0.019822	 0.00527	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92653	 57301	 0.000841	 0.002027	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57302	 94951	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57302	 94951	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92761	 57303	 0.23208	 0.17587	 0.00242	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57304	 57568	 0.000443	 0.010219	 0.19575	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57304	 94952	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57304	 94952	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57305	 57306	 0.000309	 0.005022	 0.07839	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57306	 57309	 0.000102	 0.001617	 0.02655	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57306	 94953	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57306	 94953	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57307	 94956	 0.034327	 0.027166	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57308	 57330	 0.000897	 0.008751	 0.03047	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57308	 94954	 0.000186	 0.00185	 0.00617	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57309	 57331	 0.000172	 0.003992	 0.07532	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57309	 94954	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57309	 94954	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94955	 57309	 0.000112	 0.008969	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57310	 57311	 0.000733	 0.004547	 0.0011	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94955	 57310	 0.000956	 0.005599	 0.00153	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57310	 94956	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57310	 94956	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94953	 57311	 0.000836	 0.005197	 0.00147	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57312	 94957	 0.073842	 0.13526	 0.00234	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92591	 57313	 0.056061	 0.10736	 0.00169	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57314	 57501	 0.012561	 0.067528	 0.01662	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57314	 94957	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57314	 94957	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57314	 94958	 0.003348	 0.017743	 0.00592	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57315	 57461	 0.005988	 0.040423	 0.07448	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92727	 57315	 0.003396	 0.025583	 0.05479	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57315	 94958	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94959	 57315	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92695	 57316	 0.16249	 0.11956	 0.00175	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94959	 57317	 0.20237	 0.13596	 0.0024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57318	 57320	 4.3e-05	 0.001082	 0.01771	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57318	 57335	 6.4e-05	 0.001592	 0.02607	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57318	 94960	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57318	 94960	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92648	 57319	 0.052533	 0.32307	 0.00583	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94960	 57319	 0.009223	 0.035879	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94960	 57319	 0.009223	 0.035879	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57319	 94961	 0.008799	 0.03385	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57319	 94961	 0.008799	 0.03385	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57320	 57321	 4.4e-05	 0.001112	 0.01829	 1940.0	 2037.0	 2134.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57320	 94961	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57320	 94961	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57321	 57331	 0.000405	 0.004288	 0.06413	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57321	 57331	 0.000405	 0.004288	 0.06413	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57322	 57323	 0.002216	 0.020626	 0.00639	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57322	 57326	 0.002383	 0.017415	 0.00514	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92647	 57322	 0.003807	 0.054967	 0.01746	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57322	 94962	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57322	 94962	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57322	 94966	 0.001853	 0.019639	 0.00583	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57323	 57892	 0.001233	 0.011478	 0.00356	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57323	 94963	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57323	 94963	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57324	 57584	 0.000399	 0.006064	 0.10868	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57324	 94964	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57324	 94964	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57325	 57326	 0.000885	 0.010514	 0.00366	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57325	 57894	 0.001228	 0.013253	 0.00454	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57325	 94965	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57325	 94965	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57326	 57328	 0.004896	 0.023173	 0.00557	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57327	 57329	 0.000523	 0.008334	 0.01711	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93306	 57327	 0.022426	 0.15244	 0.28369	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57327	 94966	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57327	 94966	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92833	 57328	 0.001905	 0.023963	 0.00742	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94966	 57328	 0.001367	 0.020997	 0.00587	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57329	 57330	 0.000681	 0.011077	 0.02187	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57330	 94967	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57330	 94967	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57331	 94968	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57331	 94968	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94968	 57332	 0.00616	 0.035019	 0.01014	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57333	 57334	 0.000202	 0.003363	 0.03552	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57333	 57335	 0.00012	 0.002035	 0.02084	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57334	 57336	 0.000243	 0.004028	 0.03775	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57334	 94969	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57334	 94969	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57336	 57666	 0.000624	 0.007856	 0.11975	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57336	 94970	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57336	 94970	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57337	 94971	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92615	 57338	 0.16426	 0.34538	 0.0063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94972	 57338	 0.17087	 0.21216	 0.00462	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57339	 94973	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57339	 94973	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57340	 57341	 0.014478	 0.021958	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57341	 94974	 0.09933	 0.25539	 0.00395	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57342	 94974	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57342	 94974	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57343	 57473	 0.049475	 0.11485	 0.00219	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57343	 94975	 0.018721	 0.095262	 0.00216	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57344	 57352	 0.005075	 0.03179	 0.0229	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57344	 58235	 0.01876	 0.063218	 0.01571	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57345	 57346	 0.002589	 0.022202	 0.00632	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57345	 57348	 0.001987	 0.017335	 0.00476	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57346	 94975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57346	 94975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57347	 57348	 0.001479	 0.013457	 0.0034	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57347	 57475	 0.005385	 0.038412	 0.01191	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57347	 94976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57347	 94976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57348	 57349	 0.006106	 0.028013	 0.00718	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57348	 57350	 0.001749	 0.025249	 0.00802	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57349	 58227	 0.01054	 0.053883	 0.01469	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57350	 94977	 0.003729	 0.052132	 0.01768	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57351	 94977	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57351	 94977	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94977	 57352	 0.003838	 0.054275	 0.01798	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57353	 57354	 0.008536	 0.013626	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57353	 94985	 0.004158	 0.006669	 0.00012	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57354	 57361	 0.010906	 0.016707	 0.00023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57354	 57363	 0.005659	 0.016058	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57354	 57392	 0.003731	 0.008661	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57355	 57356	 0.006165	 0.012616	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57355	 57393	 0.003723	 0.008644	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57356	 57361	 0.012452	 0.024654	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57356	 57378	 0.003581	 0.012539	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57357	 57358	 0.004409	 0.017154	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57357	 57395	 0.005939	 0.021957	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57357	 94984	 0.008015	 0.018181	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57358	 57359	 0.020859	 0.016507	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57358	 57396	 0.026441	 0.019114	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57358	 94980	 0.013177	 0.025824	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57358	 94997	 0.026309	 0.051562	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57359	 94980	 0.015533	 0.023546	 0.00049	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57360	 57365	 0.005886	 0.015129	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57360	 57378	 0.009672	 0.01915	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57361	 57363	 0.007097	 0.014051	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57361	 57364	 0.017771	 0.013074	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57362	 57372	 0.007196	 0.028809	 0.00726	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57362	 57391	 0.002488	 0.006679	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57362	 57407	 0.001851	 0.007412	 0.00187	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57362	 94978	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57362	 94978	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57363	 57370	 0.00546	 0.014036	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57365	 94981	 0.01064	 0.016984	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57365	 94983	 0.024778	 0.019609	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57365	 94984	 0.042555	 0.033678	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57366	 94979	 0.007187	 0.015106	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57366	 94981	 0.04036	 0.029694	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57366	 94984	 0.029371	 0.023244	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57367	 57374	 0.000883	 0.006454	 0.0019	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57367	 57381	 0.000581	 0.004375	 0.00121	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57368	 57381	 0.001152	 0.004688	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57368	 57385	 0.002128	 0.007298	 0.00175	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57368	 94979	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57368	 94979	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57369	 57384	 0.001765	 0.005947	 0.00148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57369	 94982	 0.002132	 0.007184	 0.00179	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57370	 94983	 0.006699	 0.019212	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57371	 94983	 0.02552	 0.04299	 0.00061	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92633	 57372	 0.00327	 0.025489	 0.00762	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94901	 57372	 0.058788	 0.15553	 0.03645	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57372	 94982	 0.001765	 0.01034	 0.00282	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57373	 57379	 0.002107	 0.007027	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57373	 57381	 0.001016	 0.004574	 0.00122	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57373	 94982	 0.000452	 0.003628	 0.00102	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92633	 57374	 0.001127	 0.012886	 0.00393	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92762	 57374	 0.000765	 0.009628	 0.00298	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92634	 57375	 0.031803	 0.19555	 0.00353	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92740	 57375	 0.084262	 0.37563	 0.00638	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57376	 57386	 0.002829	 0.011972	 0.00269	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92633	 57376	 0.004086	 0.028902	 0.00793	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57377	 57380	 0.001761	 0.006161	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57377	 57386	 0.004754	 0.018685	 0.00489	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57377	 94980	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57377	 94980	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57377	 94996	 0.001885	 0.011588	 0.00334	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57378	 94984	 0.002847	 0.01517	 0.00027	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57379	 57384	 0.003119	 0.008097	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57379	 57385	 0.00153	 0.006124	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57379	 94981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57379	 94981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57380	 57381	 0.002579	 0.010324	 0.0026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92762	 57380	 0.003172	 0.018579	 0.00506	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57382	 57383	 0.00048	 0.004564	 0.00811	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92632	 57382	 0.000494	 0.005468	 0.01265	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94729	 57382	 0.004707	 0.051955	 0.09883	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57383	 94982	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57383	 94982	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57384	 94983	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57384	 94983	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57385	 94984	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57385	 94984	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57385	 94996	 0.004876	 0.01952	 0.00492	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93917	 57387	 0.29087	 0.66915	 0.01018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57389	 57390	 0.000216	 0.003687	 0.07899	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57389	 58555	 0.000337	 0.005679	 0.12519	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57391	 57405	 0.001183	 0.002974	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57391	 94985	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57391	 94985	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57392	 94989	 0.005373	 0.012343	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57393	 94988	 0.004565	 0.010103	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57394	 94987	 0.014428	 0.011418	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57395	 94986	 0.011982	 0.021945	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57395	 94987	 0.003541	 0.013622	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94980	 57396	 0.009032	 0.017702	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57397	 57400	 0.002386	 0.006307	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57397	 57418	 0.001505	 0.006775	 0.0018	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57397	 94986	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57397	 94986	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57397	 94996	 0.002965	 0.017369	 0.00473	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57398	 57400	 0.001649	 0.004359	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57398	 94987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57398	 94987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57399	 57401	 0.008639	 0.008101	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94986	 57399	 0.006473	 0.016639	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57400	 57402	 0.001453	 0.004208	 0.00101	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57400	 94988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57400	 94988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57401	 57403	 0.006001	 0.013932	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94988	 57401	 0.009225	 0.015385	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57402	 57405	 0.001646	 0.004349	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57402	 94989	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57402	 94989	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57403	 57408	 0.003262	 0.01592	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94989	 57403	 0.007432	 0.015274	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57404	 57409	 0.001842	 0.004783	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57404	 57413	 0.004635	 0.018556	 0.00467	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57404	 57418	 0.001421	 0.005586	 0.00146	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57405	 94990	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57405	 94990	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94978	 57406	 0.025176	 0.019924	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94985	 57406	 0.023659	 0.018724	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57406	 94991	 0.007694	 0.010488	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57407	 57410	 0.001967	 0.008121	 0.00192	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57407	 94991	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57407	 94991	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57408	 94992	 0.003615	 0.018286	 0.00032	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57409	 57411	 0.001781	 0.004707	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57410	 57411	 0.000965	 0.002549	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57410	 57414	 0.005834	 0.02721	 0.00674	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57411	 94992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57411	 94992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57412	 94997	 0.021215	 0.094932	 0.00195	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57413	 57417	 0.011116	 0.052616	 0.01265	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57413	 94993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57413	 94993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92739	 57414	 0.013345	 0.078183	 0.02131	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57414	 94994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57414	 94994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57415	 57416	 0.025147	 0.027658	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94994	 57415	 0.075549	 0.14639	 0.00315	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57415	 94995	 0.038474	 0.11035	 0.0017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94993	 57416	 0.021659	 0.091668	 0.00173	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57416	 94995	 0.032483	 0.10836	 0.00172	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57417	 57572	 0.011744	 0.083091	 0.02281	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57417	 94995	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57417	 94995	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57419	 94996	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92638	 57420	 0.070163	 0.19595	 0.0412	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94792	 57421	 0.15679	 0.40323	 0.00624	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93877	 57422	 0.29214	 0.38038	 0.00532	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57422	 94998	 0.2057	 0.21921	 0.00313	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57423	 57977	 0.029006	 0.12283	 0.02766	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57423	 94998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57423	 94998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57424	 57975	 0.063163	 0.19014	 0.00372	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94998	 57424	 0.072803	 0.20883	 0.00321	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92554	 57425	 0.06362	 0.24754	 0.00413	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94998	 57425	 0.06263	 0.2067	 0.00335	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57426	 57427	 0.3021	 0.21407	 0.00338	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57426	 57430	 0.11777	 0.45844	 0.00766	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57426	 58309	 0.11641	 0.46708	 0.01206	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57427	 57428	 0.00519	 0.010665	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57427	 57429	 0.011669	 0.025827	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57427	 58309	 0.053099	 0.36463	 0.00665	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57428	 57429	 0.007176	 0.016487	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57429	 57430	 0.078581	 0.32819	 0.00948	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57431	 57432	 0.010112	 0.039745	 0.0104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92600	 57431	 0.01611	 0.083943	 0.02203	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57431	 94999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57431	 94999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94725	 57433	 0.17349	 0.35526	 0.00875	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92585	 57434	 0.011019	 0.044118	 0.01112	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92712	 57435	 0.15774	 0.11606	 0.0017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92585	 57436	 0.00626	 0.025065	 0.00631	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57437	 95000	 0.17254	 0.13525	 0.00174	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93903	 57438	 0.029959	 0.083565	 0.01754	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93905	 57438	 0.023047	 0.077673	 0.01931	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57438	 95000	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57438	 95000	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57439	 57440	 0.000762	 0.005741	 0.00159	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57439	 57441	 0.001016	 0.007081	 0.00266	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57439	 95001	 0.00082	 0.008517	 0.00263	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93979	 57440	 0.002071	 0.015521	 0.00379	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57441	 57445	 0.001	 0.012803	 0.00382	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57441	 95001	 0.002723	 0.010703	 0.0028	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57442	 95001	 0.000992	 0.015378	 0.00434	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57443	 57444	 0.000171	 0.002778	 0.05719	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57443	 95001	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57443	 95001	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57444	 95002	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57444	 95002	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95002	 57445	 0.001258	 0.009318	 0.00477	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57445	 95003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57445	 95003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57446	 57447	 0.001654	 0.015047	 0.0038	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95001	 57446	 0.00079	 0.008887	 0.00233	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57446	 95004	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57446	 95004	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92630	 57447	 0.001882	 0.014173	 0.00393	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92730	 57448	 0.1305	 0.19796	 0.00284	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95003	 57448	 0.031151	 0.10392	 0.00165	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95004	 57449	 0.021991	 0.050294	 0.00123	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57450	 57451	 0.008094	 0.027002	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57451	 95005	 0.10094	 0.23438	 0.00349	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57452	 95005	 0.28185	 0.20381	 0.00309	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57453	 95005	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57453	 95005	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92590	 57454	 0.005426	 0.019649	 0.00422	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92830	 57454	 0.005654	 0.019394	 0.00465	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94340	 57456	 0.019519	 0.04964	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57457	 95008	 0.085233	 0.16705	 0.0025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57458	 95006	 0.001911	 0.021138	 0.00634	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57458	 95007	 0.001903	 0.014584	 0.00391	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57459	 95008	 0.073191	 0.068637	 0.00106	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57460	 95006	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57460	 95006	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57461	 57462	 0.000292	 0.003185	 0.00618	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57461	 95007	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95008	 57461	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57462	 57464	 0.00069	 0.010631	 0.02342	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94338	 57462	 0.002141	 0.02363	 0.04984	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	95008	 57463	 0.018741	 0.04351	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57464	 95009	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57464	 95009	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92707	 57465	 0.14261	 0.14405	 0.00191	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92694	 57466	 0.003441	 0.028938	 0.00857	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92706	 57466	 0.022803	 0.086707	 0.02428	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57467	 57469	 0.13685	 0.21849	 0.00503	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57467	 57506	 0.09781	 0.25148	 0.00389	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57468	 57469	 0.075271	 0.17294	 0.00263	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92822	 57468	 0.068737	 0.39092	 0.00708	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57468	 95011	 0.054595	 0.18214	 0.00289	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57470	 57472	 0.008674	 0.059551	 0.01737	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57470	 57504	 0.014598	 0.076058	 0.01995	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57470	 95010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57470	 95010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57471	 57505	 0.037324	 0.19889	 0.00349	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	95010	 57471	 0.01502	 0.03981	 0.00101	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57472	 95011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57472	 95011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92781	 57473	 0.047632	 0.10943	 0.00166	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57474	 57475	 0.004745	 0.031792	 0.00974	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57474	 58296	 0.024908	 0.062623	 0.01623	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94976	 57476	 0.067335	 0.17311	 0.00268	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57476	 95249	 0.083522	 0.13874	 0.00294	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57477	 57478	 0.015552	 0.021199	 0.00047	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92722	 57478	 0.020824	 0.081013	 0.00135	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92722	 57479	 0.023547	 0.037585	 0.00087	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92721	 57480	 0.001171	 0.012636	 0.00362	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57480	 95012	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57480	 95012	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92737	 57481	 0.003789	 0.014739	 0.00394	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57482	 57483	 0.011699	 0.019708	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92839	 57482	 0.043522	 0.086172	 0.00126	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57482	 95014	 0.032739	 0.023667	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92721	 57484	 0.004526	 0.015248	 0.00379	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92838	 57484	 0.003159	 0.01054	 0.00267	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57484	 95013	 0.000991	 0.006091	 0.00223	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92683	 57485	 0.001246	 0.010213	 0.0184	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92736	 57485	 0.000763	 0.006794	 0.01194	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57485	 95013	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95014	 57485	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57486	 57487	 0.002337	 0.007305	 0.00212	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57487	 57489	 0.010382	 0.031091	 0.007	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57488	 57490	 0.039056	 0.090676	 0.00135	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57488	 57492	 0.13299	 0.24363	 0.00421	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57488	 95015	 0.016977	 0.084908	 0.00151	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57489	 95015	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57489	 95015	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94939	 57490	 0.041388	 0.086989	 0.00158	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57491	 57492	 0.10761	 0.084351	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94873	 57493	 0.10862	 0.23282	 0.00408	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57493	 95016	 0.053733	 0.12345	 0.00188	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57494	 95016	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57494	 95016	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92749	 57495	 0.099024	 0.20268	 0.00499	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57498	 57499	 0.006916	 0.03795	 0.01003	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92662	 57499	 0.019005	 0.055054	 0.01328	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57501	 57503	 0.006336	 0.028233	 0.00767	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92694	 57502	 0.015111	 0.068048	 0.01811	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57502	 95017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57502	 95017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57503	 57504	 0.002698	 0.010802	 0.00272	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92694	 57504	 0.013721	 0.11547	 0.03424	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57504	 95018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57504	 95018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95017	 57505	 0.038141	 0.18311	 0.00547	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95018	 57506	 0.068251	 0.22771	 0.00361	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57508	 57509	 0.036425	 0.023582	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57508	 57512	 0.008624	 0.017075	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57508	 57515	 0.01546	 0.039742	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57508	 57529	 0.017475	 0.032008	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57508	 95020	 0.011139	 0.049078	 0.00085	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57510	 57513	 0.02452	 0.01922	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57511	 57527	 0.004264	 0.021067	 0.00615	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57511	 57532	 0.004856	 0.0244	 0.00635	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57511	 95019	 0.001551	 0.006095	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57513	 95020	 0.012447	 0.024644	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92734	 57514	 0.008083	 0.063011	 0.22663	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94338	 57514	 0.002103	 0.031462	 0.07364	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57514	 95019	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95020	 57514	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57516	 57518	 0.014745	 0.022584	 0.00039	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57516	 57540	 0.016283	 0.0422	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95020	 57516	 0.006754	 0.03296	 0.00057	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	95020	 57517	 0.014146	 0.020976	 0.00032	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57519	 57520	 0.005271	 0.012481	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57519	 57521	 0.006088	 0.01452	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57520	 57539	 0.017995	 0.019792	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57520	 57540	 0.004239	 0.01414	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57521	 57522	 0.024064	 0.019044	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95020	 57521	 0.007922	 0.035301	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57523	 57524	 0.008258	 0.033606	 0.00819	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57523	 58267	 0.009968	 0.031159	 0.00903	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57523	 95021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57523	 95021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57524	 57527	 0.004971	 0.017054	 0.00409	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57524	 58267	 0.010537	 0.062781	 0.01652	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95019	 57524	 0.00785	 0.043079	 0.01139	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57524	 95022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57524	 95022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95022	 57525	 0.026849	 0.10445	 0.00174	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57525	 95327	 0.028424	 0.14217	 0.00253	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57526	 57530	 0.005034	 0.02793	 0.00849	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92609	 57526	 0.019892	 0.16	 0.04505	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57528	 57542	 0.008024	 0.036128	 0.00961	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95019	 57528	 0.009642	 0.033076	 0.00792	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57529	 57548	 0.048088	 0.037693	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95019	 57530	 0.006575	 0.023241	 0.00524	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57531	 57532	 0.004317	 0.031057	 0.00823	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57531	 57546	 0.009586	 0.034711	 0.00745	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57531	 58561	 0.037955	 0.13753	 0.02954	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94339	 57531	 0.003474	 0.041256	 0.01437	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95019	 57532	 0.004242	 0.018461	 0.00526	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57533	 57539	 0.008002	 0.020569	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95020	 57533	 0.02393	 0.056666	 0.00104	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57534	 57540	 0.011656	 0.021032	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57535	 57536	 0.007949	 0.042849	 0.00086	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57535	 57538	 0.097693	 0.1284	 0.00176	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57535	 57541	 0.022913	 0.044906	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95020	 57535	 0.018662	 0.10608	 0.00192	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57536	 57537	 0.022809	 0.075271	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94667	 57537	 0.033634	 0.086462	 0.00134	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93960	 57538	 0.023049	 0.10271	 0.00174	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57540	 57541	 0.004409	 0.021515	 0.00037	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57542	 57544	 0.003568	 0.013563	 0.0038	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95009	 57542	 0.011276	 0.078251	 0.02234	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95019	 57542	 0.006635	 0.024138	 0.00739	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57542	 95023	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57542	 95023	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95023	 57543	 0.029859	 0.059119	 0.00087	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57544	 57546	 0.004796	 0.024982	 0.00655	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57544	 57547	 0.005056	 0.0136	 0.00381	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57545	 57546	 0.006675	 0.022492	 0.00559	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57545	 57547	 0.005333	 0.032773	 0.01198	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95009	 57545	 0.005479	 0.03148	 0.00892	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92583	 57549	 0.004788	 0.023236	 0.00531	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57549	 95024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57549	 95024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95024	 57550	 0.028379	 0.028462	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57551	 57561	 0.16558	 0.24135	 0.00546	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94774	 57551	 0.17287	 0.39236	 0.00783	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57552	 57553	 0.089706	 0.070994	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57552	 57559	 0.099483	 0.073195	 0.00107	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57553	 57563	 0.047093	 0.084646	 0.00152	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57554	 57555	 0.038152	 0.029906	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57555	 57560	 0.029183	 0.13005	 0.00221	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57555	 57562	 0.020651	 0.044254	 0.00077	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57556	 57562	 0.1594	 0.11729	 0.00172	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57557	 57559	 0.062333	 0.1769	 0.00278	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57558	 57564	 0.047296	 0.03743	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57559	 57563	 0.14813	 0.16294	 0.00217	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57559	 57564	 0.028211	 0.07252	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94700	 57560	 0.042938	 0.21478	 0.00382	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57561	 57562	 0.033208	 0.17837	 0.00424	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94699	 57561	 0.021535	 0.10337	 0.00309	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57562	 57563	 0.005721	 0.020019	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57564	 57565	 0.027939	 0.018088	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57566	 95025	 0.086269	 0.10517	 0.00169	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57567	 95025	 0.04346	 0.040031	 0.00064	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57568	 58565	 0.001626	 0.017852	 0.17353	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57568	 95025	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57568	 95025	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57570	 95026	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57570	 95026	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57571	 95027	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57572	 57573	 0.003201	 0.022637	 0.00621	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57573	 57574	 0.010152	 0.040648	 0.01024	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94356	 57573	 0.023186	 0.098167	 0.0221	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57575	 57576	 0.00066	 0.002746	 0.00086	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57575	 57635	 0.0009	 0.00401	 0.00109	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57576	 57926	 0.000904	 0.005613	 0.00136	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57577	 95030	 0.008492	 0.011161	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57578	 57587	 4.7e-05	 0.000641	 0.00958	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57578	 57637	 8.8e-05	 0.00152	 0.01501	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57578	 95029	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57579	 57581	 0.000497	 0.003682	 0.00189	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57579	 57636	 0.000443	 0.005386	 0.00145	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57580	 57582	 0.001024	 0.005147	 0.00134	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57580	 95035	 0.001199	 0.005075	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57581	 57697	 0.000297	 0.004283	 0.00136	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57582	 57697	 0.001161	 0.004912	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57582	 95033	 0.000749	 0.006424	 0.00183	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57583	 95070	 0.042643	 0.033747	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57584	 57585	 9.1e-05	 0.001454	 0.02361	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57584	 95031	 0.000116	 0.009249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57585	 57598	 4.3e-05	 0.000516	 0.00877	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57585	 95033	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57586	 57587	 3.3e-05	 0.000398	 0.0066	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57586	 57598	 4.6e-05	 0.00055	 0.00923	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57587	 95035	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57587	 95035	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57588	 57676	 0.00134	 0.003738	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57588	 57694	 0.001222	 0.005172	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92629	 57588	 0.004719	 0.016187	 0.00388	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57588	 95049	 0.002465	 0.018014	 0.00531	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57589	 57596	 0.003974	 0.019174	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57589	 95050	 0.01979	 0.06602	 0.00105	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57590	 57591	 0.000811	 0.003187	 0.00083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57590	 57675	 0.0009	 0.003536	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92629	 57591	 0.00012	 0.000718	 0.00022	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57591	 95036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57591	 95036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57592	 57594	 0.001416	 0.004175	 0.00097	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57592	 57676	 0.00123	 0.003684	 0.00083	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57593	 95037	 0.016463	 0.016172	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92629	 57594	 0.001998	 0.007064	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57594	 95037	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57594	 95037	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57595	 95042	 0.010015	 0.013651	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57596	 95145	 0.004802	 0.022268	 0.00046	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57597	 57608	 0.000843	 0.004935	 0.00134	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57597	 57927	 0.000764	 0.004738	 0.00115	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57597	 57928	 0.001328	 0.006443	 0.00147	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57597	 57930	 0.00158	 0.007859	 0.00254	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	95031	 57597	 0.001102	 0.018356	 0.00558	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57599	 95038	 0.01484	 0.014989	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57600	 57607	 0.000405	 0.00381	 0.00115	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57600	 57924	 0.000478	 0.006222	 0.0018	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57600	 95038	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57600	 95038	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57601	 95071	 0.015666	 0.024444	 0.00041	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57602	 57640	 0.002403	 0.008242	 0.00197	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57602	 57647	 0.001019	 0.005209	 0.00142	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57602	 95039	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57602	 95039	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57602	 95074	 0.00179	 0.011004	 0.00317	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57603	 57605	 0.000712	 0.003207	 0.00085	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57603	 57702	 0.001416	 0.0087	 0.00318	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57603	 95040	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57603	 95040	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95040	 57604	 0.018331	 0.018336	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57605	 57646	 0.001808	 0.006201	 0.00149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57605	 95041	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57605	 95041	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95038	 57606	 0.014086	 0.014227	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95041	 57606	 0.005622	 0.011131	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57607	 57608	 0.000405	 0.002888	 0.0009	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57607	 57644	 0.001529	 0.005245	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57609	 95053	 0.009491	 0.028568	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57609	 95146	 0.019574	 0.015343	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57610	 57613	 0.001027	 0.003193	 0.00067	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92629	 57610	 0.005867	 0.016359	 0.00343	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57610	 95042	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57610	 95042	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57611	 57612	 0.00152	 0.004018	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57611	 57614	 0.001523	 0.003954	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92629	 57612	 0.001143	 0.003112	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57613	 57614	 0.001557	 0.004114	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57613	 57628	 0.000932	 0.003847	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57615	 57628	 0.001271	 0.004493	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57615	 57925	 0.001279	 0.005206	 0.00127	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57616	 95146	 0.019635	 0.014194	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57617	 57619	 0.000509	 0.002651	 0.0007	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57617	 57644	 0.000622	 0.003237	 0.00085	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57618	 57634	 0.019004	 0.014577	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57619	 57620	 0.000866	 0.003291	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57619	 95043	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57619	 95043	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57620	 57621	 0.000871	 0.002935	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57620	 57930	 0.002321	 0.006658	 0.00164	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57621	 57622	 0.001699	 0.004491	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57621	 95044	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57621	 95044	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57622	 95045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57622	 95045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57623	 57629	 0.025696	 0.018905	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95045	 57623	 0.006307	 0.013515	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95044	 57624	 0.007032	 0.013922	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57625	 57670	 0.006858	 0.012249	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57625	 95046	 0.005027	 0.012734	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57626	 57627	 0.001176	 0.003834	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57626	 95046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57626	 95046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57627	 57668	 0.001225	 0.004767	 0.00127	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57627	 57726	 0.001068	 0.004347	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57628	 95047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57628	 95047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57630	 57633	 0.005632	 0.010123	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95045	 57630	 0.013451	 0.010543	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57631	 57662	 0.006047	 0.012958	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57631	 57663	 0.003955	 0.013194	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57632	 57634	 0.002416	 0.013734	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57632	 95056	 0.002295	 0.014107	 0.00025	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57633	 57634	 0.002887	 0.011105	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95043	 57634	 0.034099	 0.022076	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57634	 95058	 0.024152	 0.061177	 0.00121	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57635	 57691	 0.000451	 0.003515	 0.00105	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57635	 95048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57635	 95048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57635	 95049	 0.001666	 0.006548	 0.00171	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57636	 95049	 0.001818	 0.006361	 0.00211	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57637	 57693	 6.6e-05	 0.001227	 0.01178	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57637	 95049	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57638	 57870	 0.000789	 0.004621	 0.00126	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57638	 57873	 0.003822	 0.011267	 0.00262	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95049	 57638	 0.00067	 0.007416	 0.00241	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57638	 95051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57638	 95051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95051	 57639	 0.011875	 0.023511	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57640	 57643	 0.000855	 0.003096	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57640	 57702	 0.002	 0.005577	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57641	 95052	 0.017107	 0.013538	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57642	 57643	 0.000364	 0.0017	 0.00042	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57642	 57703	 0.001196	 0.005837	 0.00161	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57643	 95052	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57643	 95052	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57644	 57646	 0.000926	 0.006761	 0.00174	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57644	 95053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57644	 95053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57645	 95054	 0.019577	 0.02573	 0.00035	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57645	 95056	 0.021063	 0.019003	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57646	 57647	 0.000775	 0.005379	 0.00154	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57646	 95054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57646	 95054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57647	 57709	 0.001325	 0.00344	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57648	 57650	 0.001607	 0.004376	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57648	 57661	 0.002988	 0.006936	 0.00211	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57649	 57653	 0.008114	 0.020858	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57649	 57655	 0.011128	 0.017048	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57650	 57657	 0.001178	 0.003206	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57651	 57652	 0.00177	 0.00455	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57651	 95073	 0.001902	 0.005304	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57652	 57656	 0.001192	 0.003888	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57652	 95055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57652	 95055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57653	 95076	 0.014103	 0.02886	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57654	 95077	 0.010793	 0.020399	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57656	 57657	 0.000889	 0.003051	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57658	 57659	 0.001201	 0.004118	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57658	 95056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57658	 95056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57659	 57660	 0.00064	 0.002328	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57660	 57661	 0.000953	 0.004033	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57661	 57714	 0.002504	 0.007382	 0.00172	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57661	 57717	 0.00113	 0.007838	 0.00224	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57662	 57713	 0.005011	 0.011091	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95045	 57663	 0.004369	 0.014925	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57664	 95080	 0.010773	 0.02133	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57665	 57713	 0.005364	 0.013313	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57666	 57784	 0.000629	 0.008604	 0.12872	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57666	 95057	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57667	 57727	 0.004761	 0.009331	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95058	 57667	 0.01455	 0.029775	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57668	 57669	 0.000385	 0.00267	 0.00157	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57668	 57671	 0.00116	 0.00491	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57668	 57673	 0.000503	 0.004232	 0.00125	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57668	 95059	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57668	 95059	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57669	 57724	 0.002068	 0.007207	 0.00167	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57669	 57725	 0.000626	 0.003037	 0.00069	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57670	 95060	 0.016765	 0.012334	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57671	 57672	 0.000912	 0.003072	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57671	 95060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57671	 95060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92629	 57672	 0.001754	 0.006201	 0.0014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57673	 57902	 0.000558	 0.004948	 0.00132	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57674	 57684	 0.016088	 0.011836	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57675	 57680	 0.001058	 0.00416	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57677	 57679	 0.002387	 0.009287	 0.00248	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57677	 57788	 0.002993	 0.007911	 0.00185	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57677	 95063	 0.006471	 0.016265	 0.00421	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57678	 57679	 0.001312	 0.006593	 0.00172	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57678	 57813	 0.001911	 0.005751	 0.0018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57679	 57680	 0.001449	 0.004882	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92629	 57679	 0.001229	 0.01242	 0.00365	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57680	 57682	 0.001072	 0.004074	 0.00114	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57681	 57914	 0.001408	 0.009605	 0.0173	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57681	 95061	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57681	 95061	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57681	 95062	 0.001723	 0.011689	 0.02128	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57682	 57788	 0.002206	 0.008827	 0.00298	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57682	 57897	 0.001253	 0.004537	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	95061	 57682	 0.001064	 0.005441	 0.00148	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57683	 57684	 0.003396	 0.007883	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57683	 57810	 0.023871	 0.03981	 0.00058	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95036	 57684	 0.007629	 0.037229	 0.00064	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57685	 57689	 0.000585	 0.006628	 0.06034	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57685	 57848	 0.000478	 0.005246	 0.05096	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57685	 95062	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57686	 57821	 0.004358	 0.011516	 0.0027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57686	 95065	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57686	 95065	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57686	 95098	 0.003288	 0.011622	 0.00262	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57687	 95070	 0.01672	 0.013232	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57688	 95131	 0.043381	 0.028085	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57689	 57693	 4.3e-05	 0.000708	 0.00663	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57689	 57848	 0.00074	 0.008543	 0.0749	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57689	 95066	 0.000123	 0.009866	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57690	 57691	 0.00049	 0.003727	 0.00117	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57690	 57694	 0.001149	 0.004862	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95066	 57690	 0.000906	 0.005629	 0.00159	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57690	 95068	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57690	 95068	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57692	 95069	 0.004446	 0.027019	 0.0005	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57692	 95124	 0.006772	 0.019423	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57693	 95069	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57693	 95069	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95048	 57695	 0.011812	 0.023387	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57696	 57697	 0.000753	 0.005302	 0.00301	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95031	 57696	 0.000583	 0.008156	 0.00277	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57696	 95070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57696	 95070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95034	 57698	 0.007739	 0.015323	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57699	 57924	 0.000545	 0.004646	 0.00116	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95031	 57699	 0.000765	 0.005763	 0.0016	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95032	 57700	 0.017744	 0.028323	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57700	 95072	 0.04555	 0.036048	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57701	 95071	 0.019151	 0.021064	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57702	 57705	 0.004984	 0.016792	 0.00417	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57702	 57924	 0.002012	 0.006055	 0.00189	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	95031	 57702	 0.001487	 0.009417	 0.00256	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57702	 95071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57702	 95071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57703	 57704	 0.001331	 0.008184	 0.00236	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57703	 95072	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57703	 95072	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57704	 57705	 0.002622	 0.008994	 0.00215	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94964	 57704	 0.003229	 0.023925	 0.01226	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57706	 57707	 0.000666	 0.005162	 0.00181	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94970	 57706	 0.000975	 0.009528	 0.00267	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57707	 95074	 0.000588	 0.005212	 0.00139	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95039	 57708	 0.010924	 0.016567	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57709	 95073	 0.002739	 0.007041	 0.00174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57710	 57712	 0.000214	 0.002985	 0.00577	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57710	 95073	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57710	 95073	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94970	 57711	 0.003041	 0.019263	 0.00523	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57711	 95074	 0.001053	 0.00578	 0.00153	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57712	 95074	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57712	 95074	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95058	 57713	 0.007644	 0.033679	 0.00058	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57714	 57718	 0.00142	 0.005863	 0.00139	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95057	 57714	 0.002689	 0.010764	 0.00271	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57715	 57717	 0.00091	 0.009025	 0.00245	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57715	 57720	 0.000816	 0.005961	 0.00153	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57715	 57722	 0.002444	 0.011212	 0.00287	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94781	 57715	 0.014031	 0.056182	 0.01416	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57715	 95075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57715	 95075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94778	 57716	 0.12439	 0.080534	 0.00153	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57717	 57718	 0.000842	 0.003984	 0.00096	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57717	 95076	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57717	 95076	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57718	 95077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57718	 95077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95075	 57719	 0.014291	 0.036737	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57720	 57721	 0.000734	 0.00417	 0.00121	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57721	 95078	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57721	 95078	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57722	 57723	 0.001241	 0.010646	 0.00303	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57722	 95079	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57722	 95079	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57724	 57725	 0.001613	 0.004189	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57724	 57726	 0.002103	 0.005646	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57724	 57731	 0.006089	 0.035663	 0.00972	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95057	 57724	 0.001084	 0.009116	 0.0027	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57725	 57726	 0.001549	 0.004158	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95057	 57725	 0.00166	 0.011745	 0.00322	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95057	 57726	 0.000674	 0.008478	 0.00263	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57726	 95080	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57726	 95080	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57728	 95081	 0.017276	 0.029766	 0.00047	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57729	 57730	 0.003562	 0.016339	 0.00419	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57729	 95081	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57729	 95081	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57730	 57732	 0.002148	 0.01192	 0.00362	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57730	 57744	 0.001916	 0.013295	 0.00379	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57730	 95082	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57730	 95082	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57731	 57744	 0.002182	 0.007634	 0.00253	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57731	 57773	 0.003529	 0.012106	 0.0029	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57731	 57779	 0.002146	 0.007229	 0.0018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57731	 95083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57731	 95083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57732	 57735	 0.003446	 0.009106	 0.00213	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57732	 57744	 0.004036	 0.010666	 0.0025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57732	 95084	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57732	 95084	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95084	 57733	 0.012672	 0.022285	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57733	 95085	 0.051681	 0.0409	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57734	 95085	 0.008518	 0.016694	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57735	 57738	 0.00104	 0.005259	 0.00146	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57735	 95085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57735	 95085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57736	 57737	 0.008696	 0.017218	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57736	 95095	 0.012248	 0.031485	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57738	 57779	 0.004274	 0.01466	 0.00351	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57738	 95086	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57738	 95086	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57739	 57740	 0.015276	 0.020077	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57739	 57778	 0.005143	 0.027094	 0.00049	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	95086	 57739	 0.008664	 0.031733	 0.0008	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57741	 57742	 0.003291	 0.008544	 0.00207	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57741	 57743	 0.004334	 0.014867	 0.00356	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57741	 57744	 0.004308	 0.010829	 0.00281	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57741	 57747	 0.000773	 0.003908	 0.00109	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57741	 95087	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57741	 95087	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57742	 57743	 0.000946	 0.007086	 0.00173	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57742	 57745	 0.004811	 0.017422	 0.00374	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57742	 95088	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57742	 95088	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95057	 57743	 0.001778	 0.017367	 0.00487	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57745	 57747	 0.000723	 0.003634	 0.00095	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57745	 57773	 0.000791	 0.003167	 0.00107	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57745	 57779	 0.002346	 0.0062	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95087	 57746	 0.013989	 0.023565	 0.00034	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57748	 95089	 0.021218	 0.016792	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57749	 57790	 0.008703	 0.022595	 0.00548	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57749	 57900	 0.0016	 0.00549	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57749	 57919	 0.000407	 0.004508	 0.00147	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92629	 57749	 0.001378	 0.014036	 0.00362	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95061	 57749	 0.002791	 0.009102	 0.00242	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57749	 95089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57749	 95089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57750	 57751	 0.01305	 0.011694	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57751	 95091	 0.009683	 0.024891	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57752	 57755	 0.004258	 0.012553	 0.00292	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57752	 57772	 0.001127	 0.004431	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57752	 95090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57752	 95090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57753	 57765	 0.013489	 0.022724	 0.00032	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57753	 57910	 0.004832	 0.012289	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57754	 57755	 0.001411	 0.004839	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57754	 57756	 0.002021	 0.00534	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57754	 57923	 0.001243	 0.00374	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57755	 95091	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57755	 95091	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57756	 57758	 0.001461	 0.005743	 0.0015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57756	 95092	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57756	 95092	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57757	 57769	 0.009807	 0.02521	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95092	 57757	 0.006491	 0.016506	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57758	 57781	 0.00087	 0.002933	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57758	 57919	 0.00103	 0.003435	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57758	 57921	 0.002448	 0.006469	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57758	 95093	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57758	 95093	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57759	 57774	 0.000678	 0.004207	 0.00102	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57759	 57901	 0.000572	 0.00303	 0.00101	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57760	 57763	 0.010158	 0.014869	 0.00023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95090	 57760	 0.009798	 0.025185	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57761	 57775	 0.014345	 0.015778	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57762	 57904	 0.012372	 0.019747	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95088	 57762	 0.022942	 0.018156	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57764	 57904	 0.032816	 0.04313	 0.00059	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	95087	 57764	 0.023472	 0.018576	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57765	 57766	 0.006549	 0.013403	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94095	 57765	 0.013487	 0.038271	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95091	 57765	 0.008066	 0.031377	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57766	 57767	 0.007573	 0.012088	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57766	 57768	 0.017988	 0.030042	 0.00051	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57769	 57770	 0.011559	 0.017707	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57771	 95094	 0.009284	 0.016752	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57772	 57773	 0.001033	 0.00376	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57773	 95094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57773	 95094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57774	 57781	 0.00086	 0.004398	 0.0012	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95089	 57775	 0.016266	 0.037758	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57776	 57777	 0.015493	 0.030674	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57776	 95095	 0.013817	 0.039628	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57777	 57778	 0.012763	 0.023731	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57779	 95095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57779	 95095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57779	 95139	 0.013044	 0.033531	 0.0083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95083	 57780	 0.007443	 0.011881	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57781	 95096	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57781	 95096	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95090	 57782	 0.033604	 0.026593	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95096	 57782	 0.003828	 0.012155	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57783	 57784	 0.000176	 0.001929	 0.01874	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57783	 95097	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57784	 95100	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57785	 57788	 0.002227	 0.007262	 0.00193	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	95063	 57785	 0.003352	 0.009348	 0.00196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57786	 57795	 0.027922	 0.022097	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57786	 95103	 0.004797	 0.010882	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57787	 57788	 0.001627	 0.004299	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57787	 57791	 0.001636	 0.004392	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57789	 57795	 0.014269	 0.011293	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57789	 95137	 0.013369	 0.020276	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57790	 57791	 0.000973	 0.002713	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57790	 57907	 0.002001	 0.005372	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95098	 57790	 0.002872	 0.010449	 0.0032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57790	 95103	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57790	 95103	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57791	 95104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57791	 95104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95104	 57792	 0.011331	 0.008967	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95099	 57793	 0.030287	 0.023969	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95099	 57794	 0.018102	 0.028893	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57795	 57796	 0.010191	 0.009557	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95099	 57795	 0.024695	 0.027161	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95067	 57797	 0.010178	 0.020152	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57798	 57859	 0.021435	 0.016963	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57798	 95106	 0.026894	 0.017411	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57799	 57854	 0.003351	 0.011844	 0.00267	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57799	 57860	 0.001854	 0.005047	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95067	 57800	 0.016245	 0.021351	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57801	 57809	 0.001346	 0.00449	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57801	 57811	 0.001963	 0.006842	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57801	 95105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57801	 95105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57802	 57803	 0.000912	 0.003129	 0.00075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57802	 57854	 0.001217	 0.003969	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57802	 95106	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57802	 95106	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57803	 57806	 0.002077	 0.006306	 0.00138	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57804	 57805	 0.000958	 0.002994	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57804	 57856	 0.001331	 0.005229	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57805	 57807	 0.001299	 0.004526	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57805	 95107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57805	 95107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57806	 57829	 0.001485	 0.004301	 0.00104	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57806	 95108	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57806	 95108	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57807	 57815	 0.00387	 0.010046	 0.00244	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57807	 95109	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57807	 95109	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95108	 57808	 0.021976	 0.017226	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95109	 57808	 0.007948	 0.013978	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57809	 57813	 0.001851	 0.006349	 0.00152	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	95066	 57809	 0.000964	 0.009823	 0.00253	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57809	 95110	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57809	 95110	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95110	 57810	 0.009052	 0.015249	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57811	 57812	 0.001728	 0.004486	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57811	 57831	 0.002382	 0.006394	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57812	 57813	 0.00217	 0.007443	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57812	 57815	 0.001779	 0.004703	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57812	 57819	 0.005051	 0.01356	 0.00307	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57812	 57831	 0.001597	 0.004219	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57812	 95111	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57812	 95111	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57813	 57815	 0.001674	 0.005743	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57814	 57833	 0.019563	 0.014142	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57814	 95112	 0.005003	 0.016691	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95063	 57815	 0.007333	 0.018849	 0.00467	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57815	 95112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57815	 95112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57816	 57822	 0.007335	 0.015717	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57816	 57825	 0.012565	 0.029753	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57816	 95114	 0.002504	 0.012741	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57817	 57824	 0.004439	 0.014809	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95065	 57817	 0.008594	 0.033062	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57818	 57819	 0.001014	 0.002722	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57818	 57840	 0.00147	 0.005042	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	95063	 57818	 0.00142	 0.00463	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57819	 57832	 0.002081	 0.005586	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95063	 57819	 0.002813	 0.007552	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57819	 95113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57819	 95113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57820	 95114	 0.012905	 0.014056	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95063	 57821	 0.001359	 0.004662	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57821	 95114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57821	 95114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57822	 57823	 0.005451	 0.011456	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57823	 57824	 0.003537	 0.008209	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57825	 57826	 0.009756	 0.016271	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57825	 57850	 0.013446	 0.020981	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95111	 57827	 0.008246	 0.015103	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57828	 95119	 0.085977	 0.086841	 0.00115	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57828	 95121	 0.0068	 0.030299	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57829	 57830	 0.00145	 0.003832	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57830	 57840	 0.00538	 0.013968	 0.00339	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57831	 57841	 0.001806	 0.005323	 0.00124	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57832	 57841	 0.002095	 0.005536	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57832	 95115	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57832	 95115	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95115	 57833	 0.014359	 0.014503	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57834	 57836	 0.009706	 0.024684	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57834	 57845	 0.024298	 0.024541	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57835	 57836	 0.011761	 0.009219	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57836	 57846	 0.028468	 0.049696	 0.00077	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57836	 95116	 0.003084	 0.0156	 0.00027	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57837	 57838	 0.011821	 0.009355	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57838	 95117	 0.007936	 0.014265	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57839	 95116	 0.004343	 0.008599	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57840	 95116	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57840	 95116	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57841	 95117	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57841	 95117	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95117	 57842	 0.01317	 0.012886	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57843	 57844	 0.00519	 0.014885	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57843	 95119	 0.007162	 0.023891	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57844	 57846	 0.010211	 0.023459	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57847	 95118	 0.003053	 0.011998	 0.00314	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57848	 95118	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57849	 57852	 0.024234	 0.024477	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57851	 57852	 0.017242	 0.013645	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95119	 57852	 0.007769	 0.019971	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57853	 95120	 0.008706	 0.014666	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57854	 57855	 0.000375	 0.002822	 0.00078	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57854	 95120	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57854	 95120	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57855	 57856	 0.000755	 0.002968	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57855	 57871	 0.000905	 0.00479	 0.00121	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57856	 57857	 0.000324	 0.00295	 0.00074	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95066	 57857	 0.000455	 0.004912	 0.00141	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57858	 57859	 0.007141	 0.018508	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57858	 57862	 0.01444	 0.021901	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57858	 57874	 0.006763	 0.026309	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57860	 57865	 0.004425	 0.011695	 0.00274	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57860	 95121	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57860	 95121	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95121	 57861	 0.028353	 0.022224	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57861	 95123	 0.012476	 0.02445	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57862	 95122	 0.009031	 0.018559	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57863	 57864	 0.034262	 0.034605	 0.00046	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57863	 95123	 0.012409	 0.041396	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94158	 57864	 0.014537	 0.046157	 0.00081	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95119	 57864	 0.061853	 0.068031	 0.00091	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57865	 57866	 0.002353	 0.00852	 0.00183	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57865	 57869	 0.002266	 0.007634	 0.0019	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	95118	 57866	 0.00436	 0.010959	 0.00284	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57867	 95122	 0.015369	 0.034862	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57868	 57869	 0.000942	 0.00802	 0.002	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57868	 57875	 0.001252	 0.009864	 0.00289	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57868	 95122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57868	 95122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57869	 95123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57869	 95123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57870	 57872	 0.000608	 0.003108	 0.00085	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57871	 57872	 0.000798	 0.003295	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57871	 95124	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57871	 95124	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57872	 95125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57872	 95125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57873	 95126	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57873	 95126	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95126	 57874	 0.002025	 0.011149	 0.00025	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57875	 57876	 0.000608	 0.006838	 0.0018	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57875	 57882	 0.004533	 0.015799	 0.00366	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57875	 95127	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57875	 95127	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57876	 57880	 0.000612	 0.006997	 0.00213	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57876	 57884	 0.005787	 0.019852	 0.00476	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57877	 57878	 0.018496	 0.014498	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57878	 57879	 0.012724	 0.010069	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95125	 57878	 0.0086	 0.021871	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57880	 57890	 0.000918	 0.01228	 0.00336	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57880	 95128	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57880	 95128	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57881	 57883	 0.012077	 0.030713	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57882	 95129	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57882	 95129	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94159	 57883	 0.026181	 0.059386	 0.00118	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95127	 57883	 0.010587	 0.032511	 0.00061	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57884	 57886	 0.000525	 0.005561	 0.00165	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95049	 57884	 0.003935	 0.015755	 0.00397	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57884	 95130	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57884	 95130	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57885	 95132	 0.009194	 0.014676	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57886	 57888	 0.00036	 0.003813	 0.00113	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57887	 57888	 0.000578	 0.005442	 0.00165	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57887	 57889	 0.00262	 0.013649	 0.00358	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95031	 57887	 0.002863	 0.018134	 0.00492	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57887	 95131	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57887	 95131	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57888	 95132	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57888	 95132	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92757	 57889	 0.000953	 0.010534	 0.00316	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92757	 57890	 0.002352	 0.02524	 0.00657	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57890	 95133	 0.001837	 0.014233	 0.00499	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57891	 95133	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95133	 57892	 0.001982	 0.016084	 0.00512	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57893	 57894	 0.000719	 0.006369	 0.0017	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92757	 57893	 0.001018	 0.010575	 0.00327	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57894	 95135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57894	 95135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57895	 57896	 0.011186	 0.039165	 0.00108	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95135	 57895	 0.007318	 0.037017	 0.00064	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95032	 57896	 0.030747	 0.079039	 0.00122	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57897	 57898	 0.001402	 0.004678	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57897	 57899	 0.002244	 0.007562	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	95061	 57897	 0.001611	 0.008095	 0.00211	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57898	 57899	 0.000902	 0.003038	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57899	 57906	 0.000834	 0.002862	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57899	 57907	 0.002125	 0.005517	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57900	 57901	 0.00214	 0.0055	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95061	 57900	 0.001956	 0.005664	 0.00137	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57901	 57902	 0.001138	 0.007635	 0.00184	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92629	 57902	 0.004881	 0.0129	 0.00302	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57902	 95136	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57902	 95136	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95136	 57903	 0.028022	 0.021495	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95136	 57904	 0.001572	 0.008656	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57905	 57907	 0.002148	 0.005575	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95101	 57905	 0.003279	 0.008666	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57905	 95137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57905	 95137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57906	 57907	 0.001053	 0.002782	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57906	 95138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57906	 95138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57908	 57909	 0.003525	 0.009061	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95102	 57908	 0.006896	 0.026826	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57909	 57910	 0.009967	 0.019734	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57910	 57911	 0.002502	 0.008346	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57911	 57912	 0.002104	 0.007893	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57912	 57913	 0.001595	 0.007784	 0.00013	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57913	 95140	 0.001856	 0.01055	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	95100	 57914	 0.000491	 0.003275	 0.00617	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57914	 95139	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95140	 57914	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57915	 57916	 0.008578	 0.009435	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95138	 57916	 0.008409	 0.021616	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57916	 95141	 0.014954	 0.011002	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57917	 57920	 0.001483	 0.003919	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95139	 57917	 0.003271	 0.008905	 0.00196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57917	 95141	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57917	 95141	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57918	 95142	 0.022153	 0.014342	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57919	 57920	 0.001192	 0.00409	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57919	 95142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57919	 95142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57920	 57921	 0.000976	 0.002625	 0.00074	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57920	 95143	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57920	 95143	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57921	 57922	 0.0006	 0.00202	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57922	 57923	 0.001039	 0.003129	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57923	 95144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57923	 95144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57925	 57930	 0.000934	 0.004975	 0.0014	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	57926	 57927	 0.001915	 0.006451	 0.0016	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	95029	 57926	 0.00086	 0.007231	 0.00214	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57927	 95145	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57927	 95145	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57928	 57930	 0.000817	 0.002888	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57928	 95146	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57928	 95146	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57929	 95147	 0.011978	 0.013174	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57930	 95147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57930	 95147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95119	 57931	 0.020269	 0.047996	 0.00088	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57932	 57933	 4.8e-05	 0.00084	 0.01394	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57932	 57963	 5.8e-05	 0.001002	 0.01722	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57933	 57934	 3.9e-05	 0.000655	 0.01188	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57933	 57941	 0.00011	 0.001278	 0.01105	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57934	 57936	 3e-05	 0.00054	 0.00851	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57934	 95148	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57934	 95148	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95148	 57935	 0.015852	 0.012545	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57936	 57937	 1.8e-05	 0.000296	 0.00545	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57937	 57944	 4.9e-05	 0.00089	 0.01405	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57937	 95149	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57937	 95149	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57938	 57942	 0.000462	 0.002657	 0.00075	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57938	 95151	 0.000959	 0.005284	 0.00124	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57939	 95152	 0.018479	 0.011963	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57940	 57941	 3.5e-05	 0.000853	 0.01454	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57940	 95150	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57940	 95150	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57941	 57946	 4.2e-05	 0.000811	 0.01352	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57941	 95151	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57942	 57945	 0.001033	 0.005225	 0.00145	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95149	 57943	 0.015064	 0.01089	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57944	 57955	 4.6e-05	 0.000654	 0.01056	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57944	 95153	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57944	 95153	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95153	 57945	 0.000555	 0.003355	 0.00086	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57946	 57952	 2.4e-05	 0.000467	 0.00787	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95152	 57947	 0.018859	 0.014288	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95152	 57948	 0.028568	 0.022608	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57949	 57950	 0.000158	 0.001145	 0.00062	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57949	 57969	 0.000579	 0.006848	 0.00195	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95150	 57949	 0.001359	 0.009609	 0.00264	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57950	 57951	 0.000452	 0.003351	 0.00172	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57951	 57953	 0.000417	 0.003269	 0.00149	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57952	 57954	 1.8e-05	 0.000414	 0.0076	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57953	 57956	 0.00161	 0.00655	 0.0016	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57953	 95156	 0.001598	 0.021372	 0.00584	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57954	 57955	 1.9e-05	 0.000337	 0.00559	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57954	 95154	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57954	 95154	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57955	 57964	 2.9e-05	 0.000705	 0.01222	 1940.0	 2037.0	 2134.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57956	 57957	 0.001128	 0.005177	 0.00133	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57957	 57958	 0.000352	 0.004333	 0.0014	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95154	 57957	 0.000736	 0.005516	 0.00135	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57958	 95155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57958	 95155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57958	 95156	 0.000987	 0.012635	 0.00377	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57959	 57960	 6.5e-05	 0.00067	 0.01053	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57959	 57960	 6.5e-05	 0.00067	 0.01053	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57959	 57964	 6.2e-05	 0.000622	 0.01037	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57959	 57964	 6.2e-05	 0.000622	 0.01037	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57960	 57968	 0.000209	 0.005249	 0.08433	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57960	 95156	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57960	 95156	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92768	 57961	 0.007287	 0.048812	 0.0307	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95153	 57961	 0.000326	 0.005457	 0.00309	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95156	 57961	 0.00076	 0.008679	 0.00413	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	57961	 95158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57961	 95158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95158	 57962	 0.015613	 0.039706	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57964	 95159	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57964	 95159	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95157	 57965	 0.029614	 0.070128	 0.00128	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57966	 57969	 0.000995	 0.010226	 0.00323	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57966	 95160	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57966	 95160	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92659	 57967	 0.094333	 0.18679	 0.00274	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92748	 57970	 0.069711	 0.19469	 0.04094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57971	 57972	 0.02517	 0.040177	 0.00093	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57972	 57973	 0.036939	 0.048548	 0.00067	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92714	 57973	 0.23183	 0.53307	 0.0081	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94656	 57974	 0.56417	 0.44696	 0.00563	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57975	 95161	 0.040165	 0.12335	 0.00231	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92610	 57976	 0.1235	 0.097738	 0.00123	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57977	 57979	 0.003731	 0.014663	 0.00384	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92609	 57977	 0.010525	 0.041369	 0.01082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57977	 95161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57977	 95161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57978	 57979	 0.001959	 0.019197	 0.00601	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92617	 57978	 0.001951	 0.02292	 0.00608	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92609	 57979	 0.007663	 0.030119	 0.00788	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57979	 95162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57979	 95162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95162	 57980	 0.012531	 0.032213	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57981	 57982	 0.030954	 0.02004	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95162	 57982	 0.014671	 0.023417	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57983	 57986	 0.001006	 0.007794	 0.00273	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57983	 58001	 0.002767	 0.026562	 0.00773	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57983	 95163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57983	 95163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93964	 57984	 0.13637	 0.45517	 0.00722	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95163	 57984	 0.008682	 0.017767	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57985	 57986	 0.002297	 0.009564	 0.00298	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57985	 57987	 0.001658	 0.010303	 0.00291	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92800	 57985	 0.014839	 0.10746	 0.05789	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57985	 95164	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57985	 95164	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57986	 57991	 0.003837	 0.010446	 0.0023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57986	 58006	 0.001114	 0.003752	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	57987	 58000	 0.010039	 0.041451	 0.00981	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	57987	 95165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57987	 95165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57988	 57999	 0.018083	 0.023533	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	95165	 57989	 0.013604	 0.02084	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57990	 57998	 0.003533	 0.029394	 0.00056	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95165	 57990	 0.003309	 0.025788	 0.00048	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	57991	 57995	 0.001688	 0.00434	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57991	 58006	 0.002406	 0.006047	 0.00157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57992	 57996	 0.02573	 0.019494	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57992	 95169	 0.056261	 0.056426	 0.00091	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57993	 95166	 0.011614	 0.021594	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57993	 95169	 0.005998	 0.015544	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57994	 95169	 0.013828	 0.024853	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57995	 57997	 0.001572	 0.004154	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	57995	 95166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57995	 95166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57996	 58007	 0.11841	 0.085604	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95166	 57996	 0.035819	 0.02319	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	57996	 95168	 0.007444	 0.015298	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	57997	 58003	 0.001543	 0.004143	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95166	 57998	 0.002312	 0.019195	 0.00047	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95165	 57999	 0.01368	 0.035165	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58001	 58002	 0.014912	 0.050248	 0.01249	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58002	 58004	 0.009269	 0.03123	 0.00776	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58002	 95167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58002	 95167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58003	 58004	 0.001288	 0.004662	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58003	 95168	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58003	 95168	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58005	 58007	 0.050403	 0.039509	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95167	 58005	 0.097452	 0.19297	 0.00283	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58006	 95169	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58006	 95169	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95168	 58007	 0.096285	 0.062338	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58008	 58011	 0.001773	 0.005226	 0.00122	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58008	 58043	 0.002768	 0.007536	 0.00166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58008	 95170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58008	 95170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58009	 58060	 0.042774	 0.033851	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95170	 58009	 0.007502	 0.011975	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58010	 58011	 0.000613	 0.002596	 0.00058	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58010	 58016	 0.000652	 0.002759	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58011	 58023	 0.001693	 0.004721	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58012	 58016	 0.001469	 0.003694	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58012	 58044	 0.001135	 0.004313	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58012	 58046	 0.000655	 0.003007	 0.00077	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58012	 95171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58012	 95171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95170	 58013	 0.003033	 0.010117	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95171	 58013	 0.002246	 0.00864	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58014	 58016	 0.001045	 0.003145	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58014	 58021	 0.000929	 0.00282	 0.00062	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58014	 95172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58014	 95172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95172	 58015	 0.004763	 0.011056	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58015	 95211	 0.004985	 0.010201	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58017	 58170	 0.001297	 0.005194	 0.00131	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58017	 58175	 0.002142	 0.008577	 0.00216	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58017	 95173	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58017	 95173	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95173	 58018	 0.017153	 0.013446	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58019	 58020	 0.001021	 0.002625	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58019	 58028	 0.001343	 0.003657	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58020	 58031	 0.002769	 0.007318	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58020	 95174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58020	 95174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58022	 58023	 0.000598	 0.002325	 0.00062	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58022	 95175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58022	 95175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58023	 58034	 0.001212	 0.005774	 0.00167	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58023	 95176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58023	 95176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58024	 58047	 0.008267	 0.026249	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58024	 58050	 0.007481	 0.013499	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95175	 58024	 0.001827	 0.00914	 0.00016	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92744	 58025	 0.006175	 0.012226	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58026	 58031	 0.000683	 0.004003	 0.00109	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58026	 58176	 0.000643	 0.00482	 0.00118	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58026	 95177	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58026	 95177	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58027	 58174	 0.010314	 0.018539	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95177	 58027	 0.014002	 0.011081	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58028	 58029	 0.000759	 0.002117	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58028	 95178	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58028	 95178	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58029	 58030	 0.000531	 0.001425	 0.00032	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58030	 95179	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58030	 95179	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58031	 58037	 0.002129	 0.009768	 0.0025	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58031	 95180	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58031	 95180	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58032	 58187	 0.009154	 0.01203	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	95180	 58032	 0.006314	 0.010487	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92744	 58033	 0.003667	 0.021385	 0.00043	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58033	 95181	 0.016041	 0.019554	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58034	 58035	 0.001475	 0.004273	 0.00103	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58034	 95181	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58034	 95181	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58035	 58037	 0.000867	 0.00302	 0.0007	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58035	 58075	 0.003668	 0.016827	 0.00431	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58036	 58153	 0.013962	 0.013965	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58037	 95182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58037	 95182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58038	 58168	 0.004451	 0.011442	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58038	 58189	 0.00709	 0.018226	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58039	 58189	 0.014719	 0.011648	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58040	 58041	 0.007529	 0.009013	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	95182	 58040	 0.010454	 0.010559	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58041	 58194	 0.007372	 0.014595	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58042	 58194	 0.010517	 0.008323	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58043	 95183	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58043	 95183	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58044	 58111	 0.001322	 0.004456	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58044	 58170	 0.001071	 0.004211	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58045	 58046	 0.00068	 0.003061	 0.00081	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58045	 58116	 0.001893	 0.007363	 0.00197	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58047	 58049	 0.012651	 0.019378	 0.00034	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58047	 58157	 0.022546	 0.051562	 0.00126	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58047	 58163	 0.014156	 0.036001	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58048	 58051	 0.00363	 0.00933	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95176	 58048	 0.004833	 0.012425	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58049	 58051	 0.004927	 0.012665	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58049	 58158	 0.032207	 0.03253	 0.00043	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95181	 58050	 0.007915	 0.01392	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58052	 58054	 0.029989	 0.030289	 0.0004	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58053	 58054	 0.007595	 0.015038	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58053	 58078	 0.00735	 0.018894	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58054	 58113	 0.005941	 0.013792	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58055	 58165	 0.012201	 0.012458	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58055	 95187	 0.030605	 0.023187	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58056	 58202	 0.012155	 0.010891	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58056	 95187	 0.013547	 0.01888	 0.00032	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58057	 58083	 0.008019	 0.024937	 0.0052	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58057	 58467	 0.008279	 0.02188	 0.00512	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58057	 95184	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58057	 95184	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58057	 95200	 0.008276	 0.028392	 0.0068	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58058	 58080	 0.02975	 0.030378	 0.00047	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58059	 58113	 0.021149	 0.035271	 0.00051	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95183	 58059	 0.010315	 0.017772	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58061	 58078	 0.006552	 0.015515	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58061	 58082	 0.005677	 0.010204	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58062	 58063	 0.005817	 0.014954	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58062	 58211	 0.017566	 0.019321	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58062	 95187	 0.01205	 0.030976	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58063	 58096	 0.021341	 0.016889	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58064	 95190	 0.023412	 0.045883	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58065	 58090	 0.002114	 0.007122	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58065	 95185	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58065	 95185	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58066	 58074	 0.02206	 0.022065	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58066	 58097	 0.007295	 0.018753	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95185	 58066	 0.005329	 0.018204	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58066	 95187	 0.021482	 0.0406	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58067	 58073	 0.040562	 0.0321	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58067	 58097	 0.009708	 0.01745	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58068	 58069	 0.02968	 0.051137	 0.00081	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58068	 58100	 0.035663	 0.060077	 0.00086	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58069	 58098	 0.015433	 0.028267	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58069	 95210	 0.026483	 0.088348	 0.0014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58070	 58079	 5.8e-05	 0.000837	 0.00768	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58070	 58105	 6.5e-05	 0.000901	 0.00899	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58070	 95186	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58070	 95186	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58071	 58072	 0.010362	 0.014441	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58071	 58073	 0.025613	 0.02027	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58072	 58208	 0.010543	 0.025807	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58073	 58094	 0.017643	 0.019405	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58074	 58160	 0.007299	 0.014452	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58074	 95187	 0.009256	 0.024468	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58075	 58161	 0.009627	 0.027883	 0.00673	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94662	 58075	 0.012211	 0.046419	 0.013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58075	 95187	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58075	 95187	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58076	 58077	 0.013908	 0.011007	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95183	 58077	 0.007517	 0.014882	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58078	 95201	 0.005641	 0.018616	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58079	 58138	 6.2e-05	 0.000892	 0.00818	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58080	 58082	 0.011429	 0.020622	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58080	 58102	 0.009458	 0.027128	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58080	 58224	 0.015435	 0.024083	 0.0004	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58081	 58224	 0.025337	 0.019196	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58083	 95188	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58083	 95188	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58084	 58157	 0.024043	 0.043381	 0.00063	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95184	 58084	 0.071859	 0.073377	 0.00114	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58085	 58099	 0.048158	 0.05978	 0.0013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95184	 58086	 0.021744	 0.055894	 0.00087	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58087	 58459	 0.011274	 0.030696	 0.00676	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58087	 95189	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58087	 95189	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58088	 58093	 0.024251	 0.057426	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95185	 58089	 0.020339	 0.04027	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58089	 95209	 0.057409	 0.038563	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94662	 58090	 0.008473	 0.033922	 0.00855	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58090	 95190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58090	 95190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58091	 58098	 0.029839	 0.023614	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58092	 58094	 0.035888	 0.023234	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58092	 58201	 0.035643	 0.027939	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95188	 58093	 0.024008	 0.0934	 0.00156	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94661	 58094	 0.013517	 0.07202	 0.00126	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94661	 58095	 0.027716	 0.054877	 0.00081	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95190	 58095	 0.026966	 0.035441	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58096	 58097	 0.017404	 0.012328	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58099	 58100	 0.018297	 0.049987	 0.00085	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95189	 58099	 0.024744	 0.11026	 0.00187	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58101	 58102	 0.004817	 0.009857	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58101	 58476	 0.004345	 0.008929	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95188	 58103	 0.012525	 0.041783	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58103	 95210	 0.009997	 0.033348	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58104	 95210	 0.026996	 0.053449	 0.00078	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58105	 58481	 5.6e-05	 0.000737	 0.00808	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58106	 95191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58106	 95191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58106	 95200	 0.004621	 0.01437	 0.003	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58107	 58108	 0.000943	 0.004104	 0.00117	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58107	 58111	 0.000896	 0.004033	 0.00107	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58107	 58112	 0.001742	 0.005046	 0.00122	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58108	 58114	 0.000756	 0.003122	 0.00074	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58109	 58115	 0.010174	 0.012179	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58109	 95192	 0.007385	 0.014621	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58110	 58111	 0.000504	 0.003195	 0.00087	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58110	 95217	 0.000535	 0.003388	 0.00092	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58112	 58126	 0.002642	 0.006983	 0.00163	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58112	 95192	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58112	 95192	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58113	 95193	 0.00794	 0.02041	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58114	 58116	 0.000936	 0.003808	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58115	 95193	 0.015327	 0.013734	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58116	 95193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58116	 95193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58116	 95200	 0.000575	 0.005977	 0.00185	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95193	 58117	 0.00645	 0.011593	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58118	 58119	 0.007286	 0.011051	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58118	 58132	 0.010642	 0.015955	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58119	 95194	 0.005462	 0.012549	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58120	 58124	 0.01654	 0.013089	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58121	 58134	 0.01884	 0.01491	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58121	 95199	 0.025837	 0.020447	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58122	 58123	 0.002615	 0.011652	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58122	 58135	 0.007456	 0.017655	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95186	 58122	 0.002806	 0.01369	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58123	 58139	 0.002338	 0.011409	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58124	 95194	 0.012628	 0.021272	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58124	 95195	 0.00735	 0.011148	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58125	 58126	 0.001074	 0.005397	 0.0014	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58125	 58127	 0.001854	 0.007846	 0.00177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58125	 95194	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58125	 95194	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58126	 95218	 0.001106	 0.011717	 0.00348	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58127	 58128	 0.001278	 0.005408	 0.00122	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58127	 95195	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58127	 95195	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58128	 58130	 0.003686	 0.00957	 0.00232	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58128	 58137	 0.002151	 0.006231	 0.0015	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58128	 95196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58128	 95196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58129	 58148	 0.01631	 0.029429	 0.00043	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95196	 58129	 0.017953	 0.030244	 0.00043	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58129	 95197	 0.032238	 0.02527	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58130	 58131	 0.002947	 0.00993	 0.00247	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58130	 58150	 0.00182	 0.007155	 0.00187	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58130	 95197	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58130	 95197	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58131	 58144	 0.002919	 0.011879	 0.00289	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58131	 95198	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58131	 95198	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58132	 58133	 0.004549	 0.009006	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58133	 58134	 0.006084	 0.012045	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58133	 95201	 0.007212	 0.017653	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58135	 58152	 0.007371	 0.015083	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58136	 58139	 0.008493	 0.019264	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58136	 95208	 0.020369	 0.014429	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58137	 58151	 0.001046	 0.004187	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58137	 95199	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58137	 95199	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58137	 95200	 0.00301	 0.01205	 0.00304	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58138	 58180	 0.000315	 0.005215	 0.04888	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58138	 95200	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95201	 58139	 0.005706	 0.024148	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58140	 58141	 0.001103	 0.00449	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58140	 58144	 0.012468	 0.036759	 0.00855	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58140	 58495	 0.002464	 0.011305	 0.0029	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58140	 95202	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58140	 95202	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58141	 58151	 0.000842	 0.003369	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58142	 58147	 0.008328	 0.021408	 0.0053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58142	 95203	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58142	 95203	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58143	 58146	 0.036218	 0.039835	 0.00053	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58143	 95207	 0.011672	 0.030005	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92679	 58144	 0.03838	 0.10148	 0.02376	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58144	 95204	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58144	 95204	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58144	 95218	 0.002993	 0.019568	 0.00498	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58145	 58148	 0.01355	 0.020757	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95202	 58145	 0.011239	 0.022253	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95204	 58146	 0.054339	 0.099529	 0.00172	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58146	 95205	 0.016775	 0.05596	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58147	 58150	 0.009905	 0.026967	 0.00594	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58147	 58506	 0.008081	 0.021356	 0.005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58147	 95205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58147	 95205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58148	 95206	 0.005644	 0.014508	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58149	 58150	 0.001062	 0.004253	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58149	 58495	 0.001821	 0.00729	 0.00184	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58149	 95206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58149	 95206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58150	 95207	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58150	 95207	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58151	 95208	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58151	 95208	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95202	 58152	 0.011219	 0.020861	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58153	 58156	 0.007767	 0.010208	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58153	 58167	 0.023002	 0.018203	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58153	 58189	 0.016119	 0.041434	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58154	 58161	 0.003272	 0.008648	 0.00202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58154	 95209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58154	 95209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58155	 58156	 0.019402	 0.019596	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58155	 58164	 0.003473	 0.007878	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58159	 58160	 0.020853	 0.019208	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58159	 58162	 0.03156	 0.024976	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58161	 95210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58161	 95210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58162	 58163	 0.01459	 0.028888	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95181	 58164	 0.013499	 0.034701	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58165	 58166	 0.00644	 0.010756	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58165	 58168	 0.009093	 0.015165	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58166	 58200	 0.005648	 0.014518	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58167	 58168	 0.004724	 0.007889	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58169	 95211	 0.002203	 0.008571	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58169	 95213	 0.002353	 0.010485	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58170	 95211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58170	 95211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58171	 58172	 5.3e-05	 0.000595	 0.00556	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58171	 95212	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58172	 58182	 0.00013	 0.001501	 0.01316	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58172	 95214	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58172	 95214	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95214	 58173	 0.000186	 0.001224	 0.00237	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58173	 95220	 0.000353	 0.002473	 0.00421	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58174	 95215	 0.005997	 0.014885	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58175	 58176	 0.002045	 0.005703	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58175	 95215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58175	 95215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58175	 95221	 0.000797	 0.006792	 0.00169	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58176	 58190	 0.00177	 0.008254	 0.00204	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58176	 58192	 0.004303	 0.015581	 0.00334	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58176	 95216	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58176	 95216	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58176	 95221	 0.002708	 0.010292	 0.00288	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95212	 58177	 0.000152	 0.000989	 0.00197	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	95214	 58177	 0.000148	 0.001817	 0.00369	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58177	 95217	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58177	 95217	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58177	 95295	 0.001675	 0.018966	 0.03798	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58178	 58179	 0.001622	 0.004212	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95217	 58178	 0.001024	 0.002707	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95217	 58179	 0.002621	 0.00731	 0.00153	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58179	 95218	 0.002021	 0.006592	 0.00175	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58180	 95218	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58180	 95218	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92675	 58181	 0.003175	 0.010891	 0.00261	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58181	 95219	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58181	 95219	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58182	 58185	 7.9e-05	 0.001243	 0.01296	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58182	 95220	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95221	 58182	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58183	 58184	 0.026629	 0.066095	 0.0011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93768	 58183	 0.049341	 0.1037	 0.00189	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95219	 58184	 0.019106	 0.058612	 0.00159	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92814	 58186	 0.038355	 0.027727	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58187	 58195	 0.010875	 0.008951	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58188	 58189	 0.002495	 0.012175	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58188	 95223	 0.003277	 0.014603	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95182	 58189	 0.006523	 0.020011	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58189	 95224	 0.009567	 0.027148	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92675	 58190	 0.002652	 0.014044	 0.00356	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58191	 58225	 0.003374	 0.011574	 0.00277	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58191	 95222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58191	 95222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58192	 95223	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58192	 95223	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58192	 95226	 0.001881	 0.007149	 0.002	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58193	 58197	 0.00418	 0.010632	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95223	 58193	 0.012524	 0.0121	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58194	 58195	 0.001531	 0.005891	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95223	 58195	 0.003328	 0.01624	 0.00028	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58196	 58197	 0.002179	 0.011022	 0.00019	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95216	 58196	 0.028674	 0.024506	 0.00046	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95222	 58196	 0.004557	 0.015954	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92676	 58198	 0.04632	 0.034079	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58199	 58200	 0.0068	 0.015784	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58199	 58202	 0.027374	 0.021664	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58199	 58203	 0.013362	 0.013496	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58200	 95224	 0.00233	 0.012831	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58201	 58208	 0.0202	 0.036306	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58202	 58203	 0.010057	 0.007959	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58204	 95224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58204	 95224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58204	 95226	 0.001539	 0.007869	 0.00214	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58205	 58206	 0.002299	 0.013068	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58205	 58207	 0.003712	 0.008616	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95224	 58205	 0.008075	 0.015645	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58206	 95227	 0.003371	 0.020727	 0.00037	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58207	 58214	 0.004805	 0.01222	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58208	 58210	 0.027274	 0.017657	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58208	 58212	 0.004879	 0.019053	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94663	 58208	 0.02943	 0.14362	 0.00248	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58209	 58211	 0.00676	 0.017378	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58209	 58214	 0.008301	 0.016986	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58210	 58211	 0.022336	 0.01446	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58212	 58216	 0.016219	 0.01521	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58212	 95225	 0.005655	 0.029407	 0.00064	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58213	 58217	 0.032441	 0.032767	 0.00043	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58213	 58219	 0.050176	 0.039709	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58213	 95225	 0.015099	 0.035053	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58214	 58216	 0.00984	 0.015707	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58214	 58217	 0.014354	 0.011815	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95224	 58214	 0.012264	 0.027818	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58215	 58221	 0.005249	 0.017685	 0.0044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58215	 95225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58215	 95225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95214	 58218	 0.001641	 0.010648	 0.02121	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58218	 95226	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95227	 58218	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58219	 58223	 0.017796	 0.058726	 0.00095	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92675	 58220	 0.003832	 0.011298	 0.00263	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92688	 58220	 0.004071	 0.013718	 0.00341	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58221	 95228	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58221	 95228	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58222	 58223	 0.017787	 0.059336	 0.00094	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92689	 58222	 0.012639	 0.071015	 0.00132	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92676	 58223	 0.039112	 0.13048	 0.00207	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95201	 58224	 0.016636	 0.042765	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92675	 58225	 0.003444	 0.014015	 0.00341	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93761	 58226	 0.26707	 0.2114	 0.00266	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58227	 95229	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58227	 95229	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58228	 58230	 0.016995	 0.086479	 0.00196	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94715	 58228	 0.079886	 0.28546	 0.00567	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95229	 58228	 0.067582	 0.15527	 0.00236	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58229	 58230	 0.012205	 0.059558	 0.00103	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58229	 95248	 0.037554	 0.14667	 0.00325	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58231	 58233	 0.01066	 0.051738	 0.01183	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58232	 58233	 0.002396	 0.009749	 0.00238	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58232	 95230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58232	 95230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58234	 58235	 0.018856	 0.064696	 0.0155	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94737	 58234	 0.020644	 0.087399	 0.01967	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58234	 95231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58234	 95231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58235	 95232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58235	 95232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58236	 95233	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95234	 58236	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58237	 58238	 0.007624	 0.036087	 0.00868	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58238	 58239	 0.002829	 0.01112	 0.00291	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58238	 58240	 0.007189	 0.032979	 0.00845	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58238	 58242	 0.012755	 0.046187	 0.00991	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58239	 58242	 0.014304	 0.037804	 0.00885	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93950	 58239	 0.013291	 0.075279	 0.01867	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58240	 58241	 0.008807	 0.035839	 0.00873	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58240	 58558	 0.006561	 0.046407	 0.01274	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58240	 58559	 0.010797	 0.043228	 0.01089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95234	 58242	 0.003668	 0.041934	 0.01279	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92639	 58243	 0.13317	 0.34245	 0.0053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92639	 58244	 0.07632	 0.12183	 0.00281	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58245	 58246	 0.012766	 0.079345	 0.0224	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58246	 95235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58246	 95235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58246	 95238	 0.043435	 0.23998	 0.05628	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58247	 58248	 0.029948	 0.019388	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58247	 58249	 0.013901	 0.035734	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58249	 58572	 0.16304	 0.29129	 0.0043	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95235	 58249	 0.03542	 0.12402	 0.00343	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58250	 95237	 0.014996	 0.034015	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58251	 58254	 0.000485	 0.005596	 0.04906	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58251	 95236	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58252	 58256	 0.058611	 0.04237	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95237	 58252	 0.006517	 0.016752	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58253	 58255	 0.00103	 0.003729	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	95236	 58253	 0.003348	 0.009871	 0.0023	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58253	 95238	 0.00933	 0.025048	 0.00568	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58254	 95238	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95236	 58255	 0.003411	 0.011378	 0.00289	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	95238	 58255	 0.008491	 0.022044	 0.00535	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58255	 95240	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58255	 95240	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95240	 58256	 0.022317	 0.017661	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95237	 58257	 0.020768	 0.041119	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92834	 58258	 0.034033	 0.13251	 0.03543	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95237	 58259	 0.01566	 0.011865	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58260	 58262	 0.002199	 0.035755	 0.01014	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58260	 58267	 0.01161	 0.042041	 0.00902	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58260	 58560	 0.008656	 0.058005	 0.01777	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58260	 58561	 0.00458	 0.052362	 0.01597	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58260	 95241	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58260	 95241	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58261	 58556	 0.023612	 0.1398	 0.00272	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95241	 58261	 0.004016	 0.019575	 0.00037	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58262	 58263	 0.005852	 0.041395	 0.01136	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58262	 58264	 0.002903	 0.021	 0.0113	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58263	 58264	 0.00091	 0.010287	 0.00396	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58265	 58266	 0.046931	 0.071894	 0.00101	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95241	 58265	 0.055844	 0.12668	 0.00253	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58265	 95242	 0.13639	 0.14857	 0.00202	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58267	 95242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58267	 95242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95242	 58268	 0.07428	 0.1404	 0.00227	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94669	 58269	 0.14958	 0.29623	 0.00435	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58270	 58271	 0.005506	 0.01525	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92601	 58270	 0.32598	 0.23574	 0.00357	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92677	 58270	 0.003797	 0.008683	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58271	 95244	 0.023531	 0.017313	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58272	 58274	 0.031053	 0.022847	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92677	 58272	 0.024688	 0.041589	 0.00059	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92600	 58273	 0.022029	 0.058228	 0.01363	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58273	 95243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58273	 95243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95243	 58274	 0.011304	 0.02238	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58275	 58285	 0.060494	 0.042851	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92601	 58275	 0.32971	 0.26102	 0.00329	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58275	 95244	 0.023915	 0.015482	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58276	 58277	 0.019753	 0.015632	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58276	 58288	 0.018153	 0.024767	 0.00044	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92677	 58276	 0.017773	 0.046982	 0.00085	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58277	 95244	 0.01059	 0.020754	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58278	 58279	 0.00121	 0.00415	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58278	 95244	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58278	 95244	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58279	 58289	 0.001184	 0.005431	 0.00139	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58280	 58292	 0.004771	 0.020194	 0.00454	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58280	 95245	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58280	 95245	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95245	 58281	 0.17319	 0.12269	 0.00194	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92600	 58282	 0.011789	 0.045866	 0.01225	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92601	 58283	 0.085039	 0.16838	 0.00247	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58285	 58287	 0.028791	 0.020394	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58286	 58287	 0.012086	 0.046496	 0.00079	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58287	 58288	 0.006591	 0.021988	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58288	 95246	 0.00592	 0.0168	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58289	 58290	 0.011643	 0.036394	 0.01054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58289	 58292	 0.003156	 0.011996	 0.00336	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58289	 95246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58289	 95246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58290	 58292	 0.011184	 0.028751	 0.00712	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58290	 95247	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58290	 95247	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58293	 58295	 0.011488	 0.045154	 0.01181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58293	 95248	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58293	 95248	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58294	 58300	 0.019529	 0.10406	 0.00183	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	95248	 58294	 0.018521	 0.10529	 0.0019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58295	 58296	 0.01109	 0.044405	 0.01119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58295	 58299	 0.0152	 0.039075	 0.00968	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58295	 95249	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58295	 95249	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92692	 58296	 0.01968	 0.11314	 0.03208	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58296	 95250	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58296	 95250	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58297	 58299	 0.006847	 0.03567	 0.00936	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92692	 58297	 0.010573	 0.066978	 0.01818	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58298	 58299	 0.007356	 0.042725	 0.01006	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58298	 95251	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58298	 95251	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58299	 95252	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58299	 95252	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58300	 58301	 0.017646	 0.028167	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95252	 58300	 0.006148	 0.023652	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95252	 58302	 0.013882	 0.026586	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94612	 58303	 0.001678	 0.022851	 0.04651	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58303	 95253	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95254	 58303	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58303	 95255	 0.000832	 0.007923	 0.02894	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58304	 95255	 0.000104	 0.008333	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95256	 58304	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58305	 58306	 0.003365	 0.013694	 0.00334	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94341	 58305	 0.009854	 0.078684	 0.0194	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58306	 58307	 0.005501	 0.022026	 0.00555	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58307	 58317	 0.015193	 0.053707	 0.0121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94341	 58307	 0.010323	 0.061507	 0.01619	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58307	 95257	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58307	 95257	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94645	 58308	 0.034843	 0.11499	 0.00186	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92776	 58309	 0.039888	 0.15347	 0.00262	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92776	 58309	 0.039888	 0.15347	 0.00262	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58310	 95258	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58310	 95258	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58310	 95259	 0.000374	 0.002425	 0.00483	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58311	 95259	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95260	 58311	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58312	 95261	 0.16127	 0.12763	 0.00161	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58313	 58315	 0.00305	 0.018951	 0.00535	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93928	 58313	 0.00688	 0.059014	 0.0168	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58313	 95261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58313	 95261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58314	 58315	 0.003439	 0.015482	 0.00412	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58314	 58317	 0.015704	 0.045488	 0.01097	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92619	 58314	 0.033497	 0.11497	 0.02756	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93929	 58316	 0.036177	 0.15468	 0.00349	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	95261	 58316	 0.02584	 0.074113	 0.00114	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58318	 58320	 0.007691	 0.01767	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58318	 58324	 0.00531	 0.01365	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58318	 58333	 0.008312	 0.016456	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58318	 58335	 0.007043	 0.009256	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58318	 58365	 0.022449	 0.06894	 0.00129	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92756	 58318	 0.013822	 0.078573	 0.00142	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58319	 58320	 0.009379	 0.007352	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58320	 58321	 0.003392	 0.006941	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58320	 58369	 0.002902	 0.01129	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58321	 58322	 0.003836	 0.009862	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58321	 58323	 0.016855	 0.013339	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58322	 58364	 0.005137	 0.011802	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58324	 58325	 0.007041	 0.01394	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58324	 58332	 0.007164	 0.018417	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58325	 58329	 0.003828	 0.009839	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58325	 58377	 0.024861	 0.0167	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58326	 58328	 0.010314	 0.008162	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58327	 58342	 0.017968	 0.01422	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58328	 58329	 0.004361	 0.009344	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58328	 58342	 0.004362	 0.011305	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58329	 58341	 0.003059	 0.00778	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58330	 58332	 0.002304	 0.005922	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58330	 58377	 0.036189	 0.036952	 0.00058	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58330	 95262	 0.007197	 0.016706	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58331	 95262	 0.013267	 0.009761	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58333	 58338	 0.003786	 0.009732	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58334	 58335	 0.012811	 0.008294	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58336	 58338	 0.003182	 0.008179	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58336	 58339	 0.014053	 0.015457	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58336	 95262	 0.00525	 0.017515	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58337	 58339	 0.00825	 0.005341	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58340	 58341	 0.003038	 0.007194	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58340	 95262	 0.005267	 0.012891	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58342	 58343	 0.002856	 0.011111	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58343	 58344	 0.014957	 0.009683	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58343	 95269	 0.004008	 0.019556	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58345	 95264	 0.014256	 0.011282	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58346	 58349	 0.000698	 0.002744	 0.00072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58346	 95262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58346	 95262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58347	 58359	 0.001789	 0.006027	 0.0015	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58347	 58360	 0.001407	 0.003777	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58347	 95263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58347	 95263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58348	 58355	 0.013768	 0.024212	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58348	 58363	 0.009652	 0.019834	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95263	 58348	 0.013897	 0.032259	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58349	 95264	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58349	 95264	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58350	 58361	 0.00824	 0.013881	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58350	 95268	 0.007305	 0.03255	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58350	 95270	 0.005482	 0.014092	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58351	 58353	 0.017864	 0.089786	 0.02338	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58351	 95265	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58351	 95265	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58352	 95266	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95267	 58352	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58353	 58360	 0.001964	 0.011506	 0.00313	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95266	 58353	 0.005537	 0.019572	 0.00441	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58353	 95268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58353	 95268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58354	 58363	 0.015435	 0.035835	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95267	 58354	 0.018778	 0.093918	 0.00167	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58355	 58374	 0.056692	 0.057261	 0.00076	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58356	 58357	 0.017058	 0.017229	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95268	 58356	 0.007432	 0.022369	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92756	 58357	 0.004817	 0.021555	 0.00044	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92756	 58358	 0.000505	 0.002688	 5e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58359	 95269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58359	 95269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58360	 58370	 0.004049	 0.021068	 0.0062	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58360	 95270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58360	 95270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92756	 58361	 0.007715	 0.017908	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95268	 58362	 0.02768	 0.021906	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58364	 58366	 0.003497	 0.00927	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58364	 95271	 0.009227	 0.024392	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58365	 58366	 0.009489	 0.025923	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58365	 58367	 0.013548	 0.024445	 0.00035	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58365	 58375	 0.016782	 0.074782	 0.00127	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58368	 95272	 0.021651	 0.028455	 0.00039	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58369	 95271	 0.002843	 0.009952	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58370	 58372	 0.005985	 0.015818	 0.0037	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58370	 95271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58370	 95271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92750	 58371	 0.4646	 0.30107	 0.00573	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58372	 95272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58372	 95272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92750	 58373	 0.15851	 0.11229	 0.00178	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95272	 58374	 0.042715	 0.043617	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58375	 58376	 0.016835	 0.064769	 0.00111	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58376	 58570	 0.13586	 0.45349	 0.00719	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95263	 58378	 0.020378	 0.013192	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92766	 58379	 0.19464	 0.37291	 0.00587	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58379	 95273	 0.036471	 0.18242	 0.00325	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58380	 58382	 0.005881	 0.020175	 0.00483	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58380	 58383	 0.005923	 0.020318	 0.00487	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58381	 58382	 0.005507	 0.01889	 0.00453	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58381	 58386	 0.00408	 0.019497	 0.00683	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58381	 95273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58381	 95273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58382	 58385	 0.013466	 0.037554	 0.00788	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92766	 58384	 0.034668	 0.082095	 0.0015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58385	 58388	 0.010238	 0.02872	 0.00739	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58386	 58389	 0.00851	 0.052815	 0.0128	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58387	 95274	 0.092916	 0.23889	 0.0037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58388	 95274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58388	 95274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58389	 95275	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58389	 95275	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58390	 95276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58390	 95276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95276	 58391	 0.10603	 0.24621	 0.00366	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58392	 58395	 0.025738	 0.018606	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58392	 58403	 0.032938	 0.025265	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58392	 58405	 0.02152	 0.049962	 0.00074	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58392	 95277	 0.00873	 0.031185	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58393	 58399	 0.023326	 0.01846	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58394	 95277	 0.040627	 0.032152	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58396	 58397	 0.012639	 0.009136	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58397	 58399	 0.004178	 0.018617	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58397	 58415	 0.002641	 0.014073	 0.00025	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58398	 58418	 0.051665	 0.034705	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58399	 95277	 0.003198	 0.021952	 0.0004	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58399	 95278	 0.022761	 0.042321	 0.00099	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58400	 95277	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58400	 95277	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58400	 95281	 0.001871	 0.011623	 0.00328	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58401	 95281	 0.001658	 0.011124	 0.00269	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58402	 58404	 0.024508	 0.052324	 0.00118	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95277	 58402	 0.024957	 0.064154	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58405	 58406	 0.003463	 0.010424	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58405	 58407	 0.011986	 0.011989	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58405	 58411	 0.00683	 0.017558	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58406	 58408	 0.003291	 0.012661	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58408	 95278	 0.003925	 0.015707	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58409	 58414	 0.001444	 0.00578	 0.00146	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58409	 95278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58409	 95278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95278	 58410	 0.020885	 0.013521	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92843	 58412	 0.006431	 0.015961	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58413	 58416	 0.002421	 0.009694	 0.00244	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58414	 95279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58414	 95279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95279	 58415	 0.002628	 0.014165	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58416	 95283	 0.004478	 0.020882	 0.00517	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58417	 95280	 0.10278	 0.081343	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58417	 95284	 0.015364	 0.053794	 0.00149	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58418	 95282	 0.051102	 0.056207	 0.00075	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58419	 95280	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58419	 95280	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58419	 95281	 0.004606	 0.018439	 0.00465	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58419	 95283	 0.004663	 0.022223	 0.00644	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58420	 95282	 0.014246	 0.03623	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58421	 95282	 0.022191	 0.017561	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58422	 95281	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58423	 58424	 0.00154	 0.010069	 0.00256	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58423	 95285	 0.00901	 0.055918	 0.01355	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95281	 58424	 0.00681	 0.025888	 0.00725	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58425	 58427	 0.000792	 0.01052	 0.02247	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92725	 58425	 0.015985	 0.10942	 0.19808	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93407	 58425	 0.02262	 0.15544	 0.28294	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58425	 95283	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95284	 58425	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92595	 58426	 0.008413	 0.05838	 0.01667	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58426	 95285	 0.004866	 0.031819	 0.00809	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58427	 95285	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58427	 95285	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95282	 58428	 0.030623	 0.019825	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58429	 58432	 0.10009	 0.079212	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92596	 58429	 0.026821	 0.062269	 0.00093	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58430	 95286	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58430	 95286	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95286	 58431	 0.01918	 0.037974	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58433	 58434	 0.006102	 0.018366	 0.00575	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58434	 58437	 0.008612	 0.022759	 0.00533	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58434	 95287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58434	 95287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58435	 58436	 0.1057	 0.08365	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95287	 58435	 0.062135	 0.095187	 0.00134	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92664	 58437	 0.053367	 0.16087	 0.05042	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93938	 58437	 0.01272	 0.080588	 0.02188	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58438	 58444	 0.035783	 0.065541	 0.00113	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58438	 58451	 0.055472	 0.0439	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58439	 58526	 0.00077	 0.005768	 0.02232	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58439	 95288	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58439	 95288	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58439	 95289	 0.000249	 0.001904	 0.00708	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95288	 58440	 0.041302	 0.041716	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58441	 58446	 6.8e-05	 0.000962	 0.00918	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58441	 95289	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58441	 95289	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58442	 58445	 0.049735	 0.045811	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58443	 58492	 0.039598	 0.035483	 0.00073	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58444	 58447	 0.00522	 0.020306	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58444	 58448	 0.010106	 0.033714	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58445	 58452	 0.055628	 0.15787	 0.00248	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58445	 58492	 0.038075	 0.084273	 0.00138	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58446	 58515	 0.000156	 0.001728	 0.01645	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58446	 58516	 0.00019	 0.003183	 0.03005	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58447	 95304	 0.007893	 0.024213	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95288	 58448	 0.011503	 0.032992	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58449	 58526	 0.000767	 0.00574	 0.02221	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58449	 95290	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58449	 95290	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58450	 95291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58450	 95291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95290	 58452	 0.022427	 0.11217	 0.002	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95291	 58452	 0.054294	 0.10641	 0.0016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95291	 58453	 0.017873	 0.079202	 0.00238	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58453	 95292	 0.019591	 0.0784	 0.00166	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58454	 58466	 0.029539	 0.049761	 0.00071	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58454	 58492	 0.023257	 0.053987	 0.00103	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58455	 58460	 0.025337	 0.025591	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58456	 58461	 0.009803	 0.025199	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58456	 58487	 0.006816	 0.017333	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58457	 58473	 0.013418	 0.050336	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58457	 95292	 0.005203	 0.029575	 0.00054	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58458	 58462	 0.007733	 0.015892	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58458	 58465	 0.016854	 0.03337	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58458	 95293	 0.006134	 0.022465	 0.00057	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58458	 95296	 0.015719	 0.061151	 0.00102	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58459	 95292	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58459	 95292	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58460	 58462	 0.008213	 0.023556	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58460	 95297	 0.013415	 0.052188	 0.00087	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58461	 58463	 0.010278	 0.020349	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58461	 58472	 0.015248	 0.037846	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58463	 58476	 0.016363	 0.037989	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58464	 58465	 0.017242	 0.018413	 0.00039	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	95292	 58465	 0.030653	 0.08491	 0.0014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58466	 58470	 0.009674	 0.015568	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58467	 95293	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58467	 95293	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58468	 58470	 0.01555	 0.012306	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58468	 58473	 0.022027	 0.017432	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58469	 58473	 0.023942	 0.03047	 0.00045	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58470	 58472	 0.015207	 0.022799	 0.00041	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95293	 58471	 0.008185	 0.013064	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95293	 58473	 0.014473	 0.028041	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58474	 58478	 0.025184	 0.01974	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58475	 58478	 0.042453	 0.027484	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58476	 58477	 0.005181	 0.010888	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95191	 58476	 0.016787	 0.040041	 0.0009	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58477	 58478	 0.007617	 0.017685	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95191	 58477	 0.010783	 0.035583	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58478	 58479	 0.017185	 0.022365	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58478	 58487	 0.012891	 0.032784	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95191	 58480	 0.00951	 0.017418	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58481	 58489	 0.000138	 0.001589	 0.01393	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58481	 58522	 0.000368	 0.005131	 0.05024	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58481	 95294	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58481	 95294	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58482	 58483	 0.00842	 0.02415	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58482	 58486	 0.008283	 0.021066	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95202	 58483	 0.008745	 0.022666	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58484	 58490	 0.012256	 0.013088	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58485	 58486	 0.004692	 0.012435	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58485	 58490	 0.011711	 0.028666	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58486	 95296	 0.004858	 0.0189	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58487	 95296	 0.003931	 0.022346	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58488	 95296	 0.009394	 0.01652	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58489	 95295	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58490	 95307	 0.003606	 0.018994	 0.00034	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58491	 95297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58491	 95297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58491	 95310	 0.003993	 0.014457	 0.0031	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	95297	 58492	 0.025952	 0.066712	 0.00103	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95297	 58493	 0.017778	 0.025905	 0.00059	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58494	 58496	 0.001962	 0.008744	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58494	 95307	 0.003421	 0.014692	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58495	 58498	 0.00046	 0.003237	 0.00184	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58495	 95298	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58495	 95298	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58496	 95299	 0.004534	 0.012018	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58497	 58499	 0.010979	 0.018494	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58497	 58501	 0.017511	 0.026821	 0.00047	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58498	 58520	 0.000579	 0.006624	 0.00202	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58498	 95299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58498	 95299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58499	 58523	 0.01169	 0.03005	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95298	 58499	 0.007745	 0.022214	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58500	 58514	 0.01592	 0.03696	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58500	 58525	 0.035011	 0.081284	 0.00121	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58501	 58503	 0.019211	 0.038037	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58501	 58504	 0.034886	 0.035236	 0.00047	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58501	 95311	 0.024911	 0.076502	 0.00144	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58502	 58513	 0.12178	 0.17264	 0.00353	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58502	 95300	 0.04884	 0.096702	 0.00142	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58502	 95311	 0.04383	 0.10024	 0.00245	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58504	 95301	 0.031573	 0.033717	 0.00071	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58505	 58506	 0.005488	 0.018827	 0.00451	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58505	 58508	 0.004709	 0.016155	 0.00387	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58505	 58509	 0.004183	 0.010516	 0.00272	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58505	 95300	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58505	 95300	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58506	 95301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58506	 95301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58507	 58508	 0.003087	 0.021419	 0.00611	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92612	 58507	 0.006957	 0.055894	 0.01571	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58508	 58509	 0.002114	 0.00725	 0.00174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58509	 95302	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58509	 95302	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58510	 58511	 0.017975	 0.011637	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95302	 58511	 0.013719	 0.018701	 0.00041	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95302	 58512	 0.023312	 0.034568	 0.00052	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58514	 95306	 0.009919	 0.033089	 0.00052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58515	 95303	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58516	 58522	 0.000139	 0.00219	 0.02282	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58516	 95305	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58517	 95308	 0.009559	 0.01681	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58518	 95307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58518	 95307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58518	 95310	 0.002382	 0.009693	 0.00236	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58519	 95311	 0.013109	 0.023562	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58520	 95308	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58520	 95308	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58520	 95310	 0.000495	 0.005873	 0.00205	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58521	 95311	 0.04647	 0.036425	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58522	 95309	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95308	 58523	 0.009224	 0.018877	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58524	 95312	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58524	 95312	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58524	 95313	 0.004399	 0.017614	 0.00444	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95312	 58525	 0.05161	 0.10848	 0.00198	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58526	 95313	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58526	 95313	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58527	 58529	 0.046647	 0.091422	 0.00137	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58528	 58529	 0.018076	 0.04791	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58529	 95315	 0.017297	 0.083028	 0.00248	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93826	 58530	 0.098515	 0.077966	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58531	 95314	 0.14027	 0.11101	 0.0014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58532	 58533	 0.010933	 0.030489	 0.0064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58532	 58534	 0.01204	 0.041304	 0.0099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58532	 58535	 0.010199	 0.027769	 0.00612	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58532	 58537	 0.01097	 0.036961	 0.00919	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58532	 95314	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58532	 95314	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58533	 58535	 0.007651	 0.026247	 0.00629	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58533	 58537	 0.016957	 0.043594	 0.0108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58534	 58535	 0.003698	 0.019909	 0.00547	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92616	 58534	 0.003364	 0.02334	 0.00666	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58534	 95315	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58534	 95315	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92687	 58536	 0.081367	 0.39724	 0.00686	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94786	 58536	 0.092712	 0.23015	 0.00383	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58537	 95316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58537	 95316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58538	 58539	 0.0128	 0.018493	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58539	 95317	 0.021182	 0.041512	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58540	 95317	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58540	 95317	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58541	 95318	 0.018604	 0.10576	 0.00191	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58542	 58543	 0.003318	 0.021375	 0.0056	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58542	 58550	 0.005123	 0.029008	 0.00719	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58543	 58548	 0.00474	 0.03502	 0.01011	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58543	 95318	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58543	 95318	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95318	 58544	 0.074869	 0.13922	 0.00326	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92647	 58545	 0.018717	 0.076184	 0.01857	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58546	 58548	 0.004516	 0.040017	 0.01065	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92647	 58546	 0.003332	 0.018941	 0.00548	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92726	 58546	 0.004018	 0.02788	 0.00796	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58547	 95319	 0.10251	 0.096138	 0.00148	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58548	 95319	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58548	 95319	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94962	 58549	 0.048681	 0.096386	 0.00141	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58550	 95320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58550	 95320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95134	 58551	 0.038219	 0.088732	 0.00132	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95320	 58551	 0.04057	 0.094191	 0.0014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58552	 95323	 0.095223	 0.095249	 0.00129	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58553	 58555	 0.000363	 0.006953	 0.1173	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58553	 95321	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58554	 58559	 0.013299	 0.045624	 0.01093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58554	 58560	 0.003579	 0.034366	 0.01	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95322	 58554	 0.004022	 0.046808	 0.01376	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58554	 95324	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58554	 95324	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58554	 95325	 0.008316	 0.04251	 0.01159	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58555	 95325	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95326	 58556	 0.024482	 0.15052	 0.00271	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95324	 58557	 0.098541	 0.077986	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58558	 58559	 0.006326	 0.024611	 0.00657	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58558	 58560	 0.00632	 0.044706	 0.01227	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58558	 95327	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58558	 95327	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58560	 58561	 0.000655	 0.00706	 0.00202	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58561	 95328	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58561	 95328	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93963	 58562	 0.19233	 0.44212	 0.00672	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58562	 95329	 0.10402	 0.24153	 0.00359	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58563	 95329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58563	 95329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92644	 58564	 0.097168	 0.1807	 0.00423	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58566	 95330	 0.009805	 0.017244	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58567	 95330	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58567	 95330	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58568	 58569	 0.034296	 0.026307	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58569	 58570	 0.078326	 0.16098	 0.00307	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58571	 58573	 0.017692	 0.072007	 0.01755	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58572	 95331	 0.16096	 0.29491	 0.00509	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58573	 95331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58573	 95331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94187	 58574	 0.11854	 0.27526	 0.00409	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95331	 58574	 0.039529	 0.11338	 0.00174	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75433	 75434	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75433	 75434	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75433	 75437	 0.008681	 0.076499	 0.16005	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75433	 75442	 0.008684	 0.079614	 0.1537	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 75435	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75434	 75435	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75434	 75436	 0.046922	 0.16114	 0.03866	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 75439	 0.049749	 0.19588	 0.05136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 75441	 0.027649	 0.17178	 0.04168	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 75444	 0.020952	 0.10356	 0.03027	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75435	 75449	 0.023646	 0.12033	 0.00273	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75436	 75698	 0.000109	 0.001782	 0.00106	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75437	 75438	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75437	 75438	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75437	 75578	 0.000123	 0.001527	 0.00551	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75438	 75579	 0.000319	 0.004185	 0.00201	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75438	 75580	 8.4e-05	 0.001263	 0.00074	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75439	 75440	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75439	 75440	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75439	 75451	 0.000406	 0.00397	 0.00111	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75441	 75448	 0.018037	 0.12984	 0.03444	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75442	 75443	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75442	 75443	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75444	 75445	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75444	 75445	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75448	 75449	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75448	 75449	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75451	 75452	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75451	 75452	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75452	 75594	 0.002998	 0.010003	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75458	 75650	 0.009623	 0.024737	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75458	 75658	 0.020289	 0.022315	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75466	 75467	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75466	 75467	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75466	 75869	 0.005476	 0.018786	 0.0045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75468	 75469	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75468	 75469	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75469	 75470	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75469	 75470	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75469	 75981	 0.001168	 0.007256	 0.00205	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75471	 75472	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75471	 75472	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75472	 75473	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75472	 75473	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75473	 75885	 0.14803	 0.14953	 0.00198	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75474	 75991	 0.008559	 0.035727	 0.00103	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75475	 75476	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75475	 75476	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75477	 75478	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75477	 75478	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75479	 75480	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75479	 75480	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75479	 76040	 0.002135	 0.007322	 0.00175	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75479	 76045	 0.000158	 0.002316	 0.00071	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75481	 75482	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75481	 75482	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75481	 75497	 0.000313	 0.002098	 0.00051	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75481	 76126	 0.000406	 0.00287	 0.00079	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75483	 75484	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75483	 75484	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75484	 75485	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75484	 75485	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75485	 76197	 0.011738	 0.02324	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75486	 75487	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75486	 75487	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75486	 75908	 0.006627	 0.02578	 0.00689	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75486	 76372	 0.005677	 0.013681	 0.00386	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75488	 75489	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75488	 75489	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75489	 75964	 0.020536	 0.11309	 0.00255	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75493	 75494	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75493	 75494	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75493	 76272	 0.000707	 0.004141	 0.00113	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75494	 76011	 0.18147	 0.14226	 0.00183	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75496	 75978	 0.000524	 0.005029	 0.00146	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75504	 75879	 0.006464	 0.019454	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75507	 75927	 0.020224	 0.036491	 0.00053	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75508	 76058	 0.001295	 0.005038	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75509	 75880	 0.01312	 0.051041	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75509	 75880	 0.01312	 0.051041	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75511	 75512	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75511	 75512	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75511	 75847	 0.001898	 0.020115	 0.00597	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75515	 75516	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75515	 75516	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75518	 75836	 0.067881	 0.11435	 0.00163	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75520	 75533	 0.000376	 0.001955	 4e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75520	 75805	 0.020496	 0.040581	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75521	 75522	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75521	 75522	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75522	 75783	 0.01513	 0.11059	 0.00204	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75523	 75815	 0.14687	 0.16298	 0.00318	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75523	 75845	 0.01344	 0.038139	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75527	 75792	 0.012252	 0.025178	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75529	 75844	 0.01314	 0.070014	 0.00123	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75531	 75840	 0.18233	 0.30417	 0.00442	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75534	 75851	 0.015667	 0.040274	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75535	 75536	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75535	 75536	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75537	 75538	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75537	 75538	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75538	 76346	 0.016166	 0.032008	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75539	 75540	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75539	 75540	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75543	 75544	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75543	 75544	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75545	 75546	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75545	 75546	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75547	 76406	 0.014284	 0.027675	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75548	 75904	 0.008254	 0.038817	 0.00072	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75548	 75911	 0.008134	 0.058535	 0.00192	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75548	 76382	 0.046734	 0.098226	 0.00179	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75549	 75901	 0.063326	 0.1331	 0.00243	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75550	 75551	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75550	 75551	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75557	 76451	 0.024939	 0.051036	 0.00126	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75569	 75571	 0.027716	 0.10783	 0.0018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75573	 75574	 0.089514	 0.070842	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75575	 75582	 0.000459	 0.007493	 0.0037	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75578	 75579	 9.7e-05	 0.007785	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75580	 75581	 0.000112	 0.008928	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75580	 75582	 0.000504	 0.005573	 0.00167	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75580	 75598	 0.001732	 0.023491	 0.01358	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75580	 76473	 0.004861	 0.060308	 0.02613	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75585	 75586	 0.001443	 0.007689	 0.00013	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75592	 75593	 0.001967	 0.014153	 0.00046	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75596	 75600	 0.025337	 0.058815	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75602	 75606	 0.007227	 0.04392	 0.00081	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75603	 75604	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75604	 75605	 0.015024	 0.046091	 0.00125	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75604	 75605	 0.015024	 0.046091	 0.00125	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75609	 75643	 0.014887	 0.072647	 0.00125	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75611	 75616	 0.058755	 0.046056	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75612	 75613	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75617	 75619	 0.029238	 0.029531	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75621	 75627	 0.032833	 0.060136	 0.00104	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75622	 75623	 0.003796	 0.021577	 0.00039	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75622	 75717	 0.042875	 0.084889	 0.00125	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75626	 75627	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75628	 75671	 0.04456	 0.13104	 0.00269	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75632	 75634	 0.038607	 0.076439	 0.00112	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75634	 75635	 0.027525	 0.048407	 0.00091	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75638	 75639	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75644	 75656	 0.010104	 0.025973	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75660	 75664	 0.007389	 0.028747	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75661	 75662	 0.00985	 0.030249	 0.00057	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75661	 75664	 0.018566	 0.053251	 0.00082	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75673	 75734	 0.009731	 0.037855	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75680	 75681	 0.085024	 0.090801	 0.00192	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75689	 75690	 0.020343	 0.048172	 0.00088	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75692	 75738	 0.009774	 0.020002	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75698	 75699	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75705	 75711	 0.017831	 0.045835	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75707	 75709	 0.017301	 0.049095	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75716	 75717	 0.000136	 0.010869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75717	 75722	 0.032219	 0.082824	 0.00128	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75717	 75723	 0.13371	 0.13375	 0.00181	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75725	 75734	 0.031726	 0.084091	 0.00213	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75729	 75734	 0.007794	 0.034729	 0.00059	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75733	 75734	 0.003866	 0.023404	 0.00073	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75736	 75737	 0.002114	 0.00722	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75740	 75754	 0.017049	 0.095797	 0.00177	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75744	 75745	 0.000245	 0.004003	 0.00239	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75744	 75755	 0.001674	 0.020334	 0.00548	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75745	 75746	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75746	 75749	 0.009211	 0.07663	 0.00145	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75751	 75759	 0.06467	 0.31567	 0.00545	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75755	 75756	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75763	 75765	 0.023162	 0.069715	 0.00136	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75769	 75770	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75771	 75772	 0.005028	 0.011993	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75774	 75775	 0.02562	 0.063589	 0.00106	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75774	 75776	 0.042601	 0.079213	 0.00185	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75776	 75800	 0.038318	 0.14908	 0.00249	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75782	 75835	 0.44362	 0.34797	 0.00447	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75785	 75787	 0.014305	 0.033212	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75785	 75788	 0.00857	 0.030617	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75789	 75790	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75798	 75799	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75803	 75804	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75812	 75814	 0.037296	 0.034975	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75812	 75815	 0.024563	 0.031966	 0.00045	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75813	 75815	 0.057985	 0.063777	 0.00085	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75821	 75822	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75825	 75828	 0.014518	 0.056478	 0.00094	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75825	 75828	 0.014518	 0.056478	 0.00094	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75825	 75837	 0.024035	 0.055218	 0.00084	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75827	 75850	 0.50933	 0.40343	 0.00508	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75833	 75840	 0.064072	 0.16984	 0.00431	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75835	 75836	 0.15796	 0.27787	 0.00522	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75838	 75839	 0.22652	 0.24921	 0.00333	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75842	 75843	 0.052599	 0.1123	 0.00254	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75843	 75850	 0.053703	 0.17916	 0.00284	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75844	 75845	 0.047658	 0.14015	 0.00287	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75844	 75846	 0.17006	 0.12886	 0.00177	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75847	 75848	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75854	 75857	 0.0207	 0.080528	 0.00134	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75856	 75857	 0.096326	 0.22366	 0.00333	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75857	 75858	 0.014403	 0.047531	 0.00077	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75869	 75870	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75872	 75874	 0.27717	 0.21731	 0.00279	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75873	 75874	 0.007465	 0.026137	 0.00072	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75876	 75877	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75887	 75889	 0.034382	 0.028299	 0.00057	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75893	 76178	 0.091871	 0.090253	 0.00152	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75894	 75895	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75915	 75917	 0.04318	 0.034172	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75926	 76034	 0.009547	 0.027383	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75929	 75930	 0.009896	 0.025168	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75932	 75933	 0.004828	 0.014811	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75936	 75937	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75938	 75940	 0.011732	 0.017173	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75938	 75944	 0.0161	 0.019985	 0.00044	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75938	 75949	 0.005412	 0.025128	 0.00069	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75945	 75949	 0.058569	 0.053948	 0.00086	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75945	 75950	 0.007638	 0.021905	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75948	 75949	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75951	 75952	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75959	 75960	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75961	 75962	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75964	 76228	 0.013124	 0.050283	 0.00142	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75965	 75966	 0.00974	 0.02261	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75973	 75974	 0.009906	 0.022758	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75981	 75982	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75985	 75987	 0.015664	 0.03219	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76008	 76027	 0.078724	 0.070545	 0.00144	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76010	 76019	 0.028123	 0.12532	 0.00213	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76014	 76015	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76014	 76065	 0.01459	 0.090687	 0.02561	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76015	 76017	 0.019904	 0.066398	 0.00105	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76015	 76267	 0.036757	 0.066322	 0.00096	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76015	 76268	 0.018284	 0.04846	 0.00123	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76018	 76019	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76019	 76234	 0.067652	 0.15707	 0.00234	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76023	 76024	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76027	 76086	 0.025007	 0.097666	 0.00217	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76028	 76029	 0.004606	 0.020292	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76030	 76031	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76040	 76041	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76043	 76224	 0.006952	 0.016141	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76044	 76045	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76048	 76050	 0.009119	 0.006709	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76051	 76054	 0.038801	 0.02512	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76053	 76054	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76054	 76055	 0.003457	 0.006175	 9e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76055	 76057	 0.003305	 0.006054	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76056	 76057	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76057	 76061	 0.004434	 0.012717	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76062	 76188	 0.004599	 0.012565	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76065	 76066	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76066	 76091	 0.00833	 0.032047	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76067	 76069	 0.028752	 0.029041	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76067	 76073	 0.018191	 0.041792	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76067	 76074	 0.042959	 0.072368	 0.00103	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76073	 76084	 0.010618	 0.027294	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76075	 76076	 0.012426	 0.031602	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76078	 76079	 0.005086	 0.028911	 0.00052	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76078	 76086	 0.11841	 0.1196	 0.00158	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76079	 76081	 0.066793	 0.059852	 0.00122	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76085	 76086	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76086	 76090	 0.023122	 0.059437	 0.00092	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76090	 76092	 0.007576	 0.019474	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76108	 76118	 0.038718	 0.15063	 0.00251	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76111	 76112	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76117	 76118	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76121	 76122	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76122	 76140	 0.011142	 0.025481	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76123	 76125	 0.014661	 0.010787	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76126	 76127	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76126	 76195	 0.012025	 0.03122	 0.00758	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76127	 76128	 0.007033	 0.016328	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76128	 76129	 0.004043	 0.013341	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76129	 76130	 0.014814	 0.016294	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76132	 76133	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76144	 76146	 0.02184	 0.043241	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76146	 76147	 0.067447	 0.049623	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76152	 76153	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76152	 76170	 0.001277	 0.017078	 0.00467	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76155	 76156	 0.015724	 0.018432	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76158	 76161	 0.009606	 0.036958	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76160	 76161	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76170	 76171	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76172	 76173	 0.030244	 0.083666	 0.00194	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76179	 76181	 0.028379	 0.052767	 0.00124	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76179	 76182	 0.043886	 0.073931	 0.00105	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76184	 76187	 0.008751	 0.014594	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76186	 76187	 0.011924	 0.009437	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76195	 76196	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76196	 76197	 0.008678	 0.017181	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76196	 76205	 0.02334	 0.035755	 0.0005	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76208	 76209	 0.026007	 0.027362	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76225	 76226	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76227	 76230	 0.034758	 0.080697	 0.0012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76231	 76232	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76234	 76241	 0.009113	 0.048554	 0.00085	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76235	 76237	 0.027414	 0.091452	 0.00145	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76244	 76245	 0.003032	 0.014631	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76252	 76253	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76253	 76264	 0.02091	 0.059336	 0.00093	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76255	 76261	 0.047776	 0.048255	 0.00064	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76261	 76262	 0.05158	 0.04082	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76261	 76263	 0.077692	 0.072859	 0.00113	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76263	 76283	 0.043114	 0.04742	 0.00063	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76264	 76270	 0.01895	 0.042985	 0.00086	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76265	 76266	 0.007786	 0.024967	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76269	 76282	 0.008308	 0.022019	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76274	 76275	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76284	 76285	 0.021288	 0.081899	 0.0014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76284	 76285	 0.021288	 0.081899	 0.0014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76284	 76333	 0.16643	 0.32963	 0.00484	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76288	 76363	 0.055124	 0.33902	 0.00611	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76290	 76450	 0.048419	 0.21578	 0.00367	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76299	 76300	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76299	 76301	 0.005727	 0.015135	 0.00354	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76301	 76302	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76305	 76310	 0.010649	 0.041427	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76309	 76310	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76317	 76349	 0.052107	 0.13395	 0.00207	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76319	 76320	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76332	 76333	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76335	 76336	 0.005762	 0.053643	 0.00104	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76340	 76341	 0.061332	 0.065499	 0.00138	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76344	 76354	 0.01235	 0.045663	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76358	 76359	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76364	 76365	 0.004568	 0.015237	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76366	 76367	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76370	 76371	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76370	 76372	 0.001084	 0.004474	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76372	 76373	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76376	 76380	 0.015334	 0.04704	 0.00127	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76386	 76387	 0.00513	 0.01645	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76411	 76418	 0.012813	 0.083777	 0.00194	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76412	 76413	 0.022383	 0.16361	 0.00302	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76412	 76417	 0.013955	 0.079329	 0.00144	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76415	 76418	 0.015754	 0.048329	 0.00131	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76415	 76418	 0.015754	 0.048329	 0.00131	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76428	 76429	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76428	 76509	 0.012635	 0.075288	 0.01981	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76429	 76431	 0.033909	 0.12721	 0.00229	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76429	 76431	 0.033909	 0.12721	 0.00229	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76429	 76436	 0.046666	 0.28697	 0.00517	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76439	 76440	 0.02013	 0.089699	 0.00152	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76442	 76443	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76449	 76450	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76453	 76455	 5e-06	 2.4e-05	 1e-05	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76453	 76457	 0.041952	 0.14634	 0.03397	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76453	 76467	 0.025731	 0.09098	 0.02051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76453	 76473	 0.015324	 0.090443	 0.07376	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76453	 76475	 0.038946	 0.20223	 0.0495	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76453	 76476	 0.023104	 0.19204	 0.05064	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76453	 77394	 0.003668	 0.014268	 0.00381	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76454	 76455	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76454	 76455	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76454	 76463	 0.000599	 0.006605	 0.01393	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76454	 77395	 0.000645	 0.005668	 0.01182	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76457	 77224	 0.000206	 0.001623	 0.00047	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76458	 76459	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76458	 76459	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76458	 77200	 0.005702	 0.020743	 0.00635	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76460	 76461	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76460	 76461	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76462	 77161	 0.002608	 0.036698	 0.15241	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76463	 76464	 9.4e-05	 0.007517	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76463	 76464	 9.4e-05	 0.007517	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76463	 77395	 0.000379	 0.002789	 0.00545	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76463	 77541	 0.002322	 0.017394	 0.06732	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76464	 76465	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76464	 76465	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76466	 76467	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76466	 76467	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76466	 76517	 4.5e-05	 0.000512	 0.00191	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76467	 76468	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76467	 76468	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76468	 76712	 0.029235	 0.15203	 0.0033	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76469	 77528	 0.019558	 0.11118	 0.00201	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76469	 77531	 0.08232	 0.29417	 0.00584	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76470	 76471	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76470	 76471	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76470	 76487	 0.003414	 0.027255	 0.00672	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76472	 76473	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76472	 76473	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76473	 76474	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76473	 76474	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76474	 77443	 0.010692	 0.041597	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76474	 77443	 0.010692	 0.041597	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76474	 77448	 0.041472	 0.10749	 0.00203	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76474	 77572	 0.028121	 0.26185	 0.00507	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76476	 76477	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76476	 76477	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76479	 76480	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76479	 76480	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76480	 77432	 0.045589	 0.20317	 0.00345	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76483	 76484	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76483	 76484	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76483	 76491	 6.9e-05	 0.000472	 0.00085	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76485	 76486	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76485	 76486	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76486	 77007	 0.003125	 0.022841	 0.00042	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76487	 77359	 0.00028	 0.002252	 0.00063	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76488	 76489	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76488	 76489	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76491	 76492	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76491	 76492	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76493	 76494	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76493	 76494	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76493	 77197	 0.005081	 0.016573	 0.0044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76495	 77435	 0.54092	 0.4285	 0.0054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76496	 76497	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76496	 76497	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76497	 77224	 0.000689	 0.00268	 0.00072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76500	 76778	 0.006966	 0.016004	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76502	 76747	 0.084944	 0.22519	 0.00571	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76502	 76748	 0.050747	 0.15585	 0.00292	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76506	 77351	 0.003694	 0.01437	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76509	 76510	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76509	 76510	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76513	 77485	 0.073017	 0.15649	 0.00274	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76514	 76515	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76514	 76515	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76515	 76516	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76515	 76516	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76517	 76518	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76517	 76518	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76517	 77395	 0.00541	 0.035132	 0.07002	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76518	 76519	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76518	 76519	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76520	 77413	 0.004429	 0.04123	 0.0008	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76521	 76761	 0.007508	 0.050172	 0.00111	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76522	 76670	 0.51643	 0.40906	 0.00515	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76522	 76671	 0.13112	 0.26842	 0.00661	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76522	 77158	 0.025731	 0.098994	 0.00169	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76526	 76527	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76526	 76527	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76530	 76531	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76530	 76531	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76532	 76981	 0.002079	 0.008118	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76533	 76534	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76533	 76534	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76536	 76538	 0.000852	 0.004842	 9e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76538	 77486	 0.001934	 0.01189	 0.00021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76539	 77453	 0.005877	 0.012352	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76540	 76702	 0.010326	 0.11058	 0.22625	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76540	 76702	 0.010326	 0.11058	 0.22625	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76540	 76702	 0.010326	 0.11058	 0.22625	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76542	 76543	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76542	 76543	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76543	 76544	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76543	 76544	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76544	 77110	 0.006028	 0.02345	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76544	 77110	 0.006028	 0.02345	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76552	 76553	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76552	 76553	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76552	 77179	 0.001006	 0.012445	 0.00671	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76553	 77177	 0.014345	 0.088197	 0.00159	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76554	 77525	 0.011399	 0.054714	 0.00163	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76562	 77106	 0.005425	 0.012463	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76565	 76779	 0.000139	 0.002083	 0.00062	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76566	 77106	 0.008856	 0.060786	 0.00111	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76577	 76579	 0.018387	 0.041707	 0.00083	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76578	 76579	 0.007699	 0.047335	 0.00085	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76582	 76583	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76585	 76586	 0.003534	 0.013746	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76595	 76608	 0.002254	 0.007438	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76599	 76601	 0.006002	 0.009581	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76599	 76607	 0.00414	 0.009469	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76613	 76615	 0.003589	 0.009227	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76615	 77102	 0.005946	 0.00949	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76617	 76621	 0.001764	 0.004534	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76618	 76621	 0.001551	 0.007569	 0.00013	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76622	 76646	 0.004465	 0.015622	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76624	 76627	 0.007588	 0.019506	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76637	 76645	 0.004289	 0.008492	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76644	 76646	 0.000871	 0.004529	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76645	 76647	 0.0064	 0.004626	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76654	 76655	 0.000263	 0.001827	 0.00052	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76657	 76704	 0.24266	 0.62451	 0.00968	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76659	 76660	 0.1384	 0.10953	 0.00138	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76669	 77152	 0.031513	 0.081672	 0.00154	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76671	 77437	 0.074913	 0.22033	 0.00452	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76683	 76685	 0.08138	 0.18895	 0.00281	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76684	 76685	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76685	 76686	 0.032502	 0.10843	 0.00172	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76685	 77202	 0.045687	 0.26	 0.008	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76700	 77509	 0.033903	 0.1131	 0.00179	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76702	 76703	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76702	 77161	 0.010619	 0.079858	 0.3109	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76705	 77204	 0.03833	 0.18706	 0.00323	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76712	 76716	 0.085439	 0.21966	 0.0034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76713	 77514	 0.105	 0.083101	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 76754	 0.018419	 0.0329	 0.00049	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76735	 76736	 0.000104	 0.008333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76738	 76741	 0.01709	 0.031301	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76742	 76752	 0.016532	 0.093979	 0.0017	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76744	 76748	 0.029789	 0.076577	 0.00119	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76762	 76763	 0.003315	 0.014607	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76765	 77608	 0.029579	 0.11507	 0.00192	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76765	 77608	 0.029579	 0.11507	 0.00192	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76769	 76770	 0.024429	 0.12704	 0.00275	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76771	 77132	 0.078673	 0.29097	 0.00539	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76771	 77132	 0.078673	 0.29097	 0.00539	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76779	 76780	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76781	 77017	 0.008521	 0.013968	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76783	 76805	 0.002977	 0.013266	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76783	 76811	 0.002565	 0.009868	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76790	 76792	 0.003642	 0.009263	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76801	 76868	 0.006775	 0.033062	 0.00057	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76801	 76898	 0.005016	 0.019297	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76801	 76898	 0.005016	 0.019297	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76805	 76812	 0.001745	 0.005353	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76805	 76812	 0.001745	 0.005353	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76807	 76831	 0.003087	 0.008	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76809	 76810	 0.001043	 0.004012	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76809	 76810	 0.001043	 0.004012	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76817	 76823	 0.001098	 0.006749	 0.00012	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76824	 76873	 0.001576	 0.007024	 0.00012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76825	 76829	 0.001951	 0.003994	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76829	 76832	 0.002271	 0.004773	 9e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76830	 76848	 0.002608	 0.013559	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76837	 76842	 0.001143	 0.009011	 0.00019	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76859	 76860	 0.00149	 0.008471	 0.00015	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76860	 77302	 0.003202	 0.015623	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76862	 76863	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76863	 77298	 0.002955	 0.010092	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76863	 77298	 0.002955	 0.010092	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76869	 76873	 0.000875	 0.003365	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76886	 76889	 0.006906	 0.006975	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76887	 76891	 0.003285	 0.002599	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76888	 76894	 0.00357	 0.017948	 0.00049	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76892	 77242	 0.002405	 0.011736	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76893	 76894	 0.023688	 0.018746	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76897	 76909	 0.003195	 0.019642	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76904	 76907	 0.003802	 0.010905	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76904	 76909	 0.02586	 0.026119	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76909	 76910	 0.01039	 0.03466	 0.00055	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76923	 76952	 0.15373	 0.22799	 0.00343	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76928	 76930	 0.007413	 0.017211	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76942	 76943	 0.027326	 0.064709	 0.00118	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76946	 77527	 0.013646	 0.093668	 0.00171	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76951	 76952	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76952	 76956	 0.060948	 0.14151	 0.0021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76965	 76969	 0.030919	 0.034007	 0.00045	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76980	 76981	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76982	 76983	 0.005164	 0.018079	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77004	 77570	 0.033795	 0.14977	 0.0045	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77005	 77448	 0.015671	 0.043409	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77022	 77026	 0.002547	 0.012882	 0.00022	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77028	 77030	 0.001044	 0.00406	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77028	 77030	 0.001044	 0.00406	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77029	 77030	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77032	 77033	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77033	 77034	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77033	 77037	 0.000142	 0.001504	 0.00045	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77037	 77038	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77042	 77043	 0.000108	 0.00862	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77043	 77072	 0.015359	 0.03906	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77047	 77049	 0.003198	 0.008221	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77053	 77054	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77054	 77055	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77055	 77070	 0.008288	 0.021304	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77056	 77057	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77057	 77058	 0.002763	 0.007103	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77057	 77062	 0.000644	 0.004868	 0.00016	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77058	 77064	 0.000447	 0.003185	 7e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77072	 77080	 0.0047	 0.022561	 0.00067	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77076	 77078	 0.000996	 0.006052	 0.00011	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77081	 77089	 0.00202	 0.005795	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77083	 77085	 0.004728	 0.003741	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77084	 77087	 0.00116	 0.005566	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77094	 77095	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77095	 77096	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77098	 77099	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77098	 77635	 0.001172	 0.017785	 0.00655	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77104	 77105	 0.003004	 0.017075	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77121	 77122	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77136	 77156	 0.028493	 0.018446	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77142	 77144	 0.010666	 0.016339	 0.00023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77153	 77166	 0.10226	 0.16325	 0.00376	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77155	 77158	 0.040548	 0.061498	 0.00088	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77157	 77158	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77161	 77162	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77162	 77163	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77169	 77529	 0.032824	 0.090922	 0.0015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77170	 77436	 0.058312	 0.12497	 0.00219	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77177	 77518	 0.063835	 0.24838	 0.00415	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77179	 77180	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77181	 77182	 0.006627	 0.02652	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77190	 77192	 0.031649	 0.21727	 0.00396	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77194	 77195	 0.007296	 0.056861	 0.00106	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77195	 77530	 0.08462	 0.4758	 0.00882	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77196	 77197	 0.001606	 0.016227	 0.00477	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77197	 77198	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77198	 77199	 0.014926	 0.029253	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77204	 77208	 0.018564	 0.099702	 0.00237	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77217	 77219	 0.001455	 0.005196	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77224	 77225	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77229	 77232	 0.00165	 0.003908	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77231	 77232	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77233	 77236	 0.000289	 0.001833	 0.0005	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77236	 77237	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77238	 77239	 0.003834	 0.009857	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77241	 77248	 0.001626	 0.00385	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77243	 77244	 0.002012	 0.007187	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77243	 77244	 0.002012	 0.007187	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77243	 77249	 0.000725	 0.004975	 9e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77245	 77246	 0.001344	 0.004591	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77245	 77246	 0.001344	 0.004591	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77248	 77250	 0.004284	 0.008766	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77256	 77257	 0.001147	 0.004412	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77256	 77257	 0.001147	 0.004412	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77257	 77290	 0.001086	 0.00371	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77257	 77291	 0.002752	 0.006831	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77257	 77292	 0.002956	 0.009862	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77258	 77259	 0.000381	 0.00275	 5e-05	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77261	 77262	 0.00057	 0.001947	 4e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77263	 77264	 0.000587	 0.004574	 9e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77265	 77323	 0.010263	 0.023025	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77269	 77272	 0.001761	 0.00431	 7e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77271	 77323	 0.015864	 0.028513	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77288	 77289	 0.000708	 0.005876	 0.00014	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77294	 77295	 0.001533	 0.005963	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77294	 77295	 0.001533	 0.005963	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77298	 77308	 0.004041	 0.020211	 0.00036	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77299	 77300	 0.000328	 0.003057	 6e-05	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77303	 77306	 0.003999	 0.01017	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77308	 77311	 0.005199	 0.022229	 0.0005	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77313	 77315	 0.003228	 0.007493	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77318	 77324	 0.005635	 0.004459	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77321	 77322	 0.002088	 0.003768	 5e-05	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77321	 77327	 0.003086	 0.005652	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77335	 77336	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77346	 77350	 0.003177	 0.016521	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77354	 77355	 0.002678	 0.01433	 0.00043	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77364	 77365	 0.001405	 0.005269	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77364	 77365	 0.001405	 0.005269	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77367	 77368	 0.000772	 0.004982	 0.00016	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77369	 77374	 0.008774	 0.034134	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77369	 77374	 0.008774	 0.034134	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77371	 77373	 0.002748	 0.015441	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77377	 77378	 0.001896	 0.011655	 0.00021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77381	 77383	 0.007004	 0.026946	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77381	 77383	 0.007004	 0.026946	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77386	 78128	 0.008511	 0.056242	 0.00111	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77387	 77393	 0.004284	 0.016069	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77387	 77393	 0.004284	 0.016069	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77390	 77640	 0.00122	 0.009145	 0.00223	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77395	 77396	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77401	 77402	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77403	 77407	 0.012829	 0.064894	 0.00113	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77423	 77427	 0.01331	 0.063889	 0.00191	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77426	 77427	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77442	 77447	 0.008984	 0.023093	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77445	 77446	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77450	 77451	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77452	 77462	 0.011709	 0.057163	 0.0012	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77455	 77458	 0.016658	 0.042821	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77456	 77457	 0.004681	 0.018209	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77465	 77466	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77466	 77468	 0.002636	 0.024542	 0.00048	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77466	 77471	 0.006674	 0.02974	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77467	 77488	 0.036076	 0.083756	 0.00125	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77470	 77471	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77481	 77490	 0.023933	 0.043016	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77482	 77491	 0.026697	 0.061334	 0.00093	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77486	 77487	 0.0032	 0.023028	 0.00075	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77498	 77499	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77503	 77504	 0.16369	 0.16375	 0.00221	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77512	 77519	 0.024709	 0.047321	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77517	 77520	 0.06145	 0.11427	 0.00267	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77523	 77524	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77527	 77531	 0.051474	 0.16576	 0.00282	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77533	 77534	 0.007691	 0.029921	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77535	 77536	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77537	 77538	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77540	 77542	 0.001725	 0.004997	 0.00121	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77541	 77542	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77541	 77548	 9.6e-05	 0.000767	 0.00258	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77545	 77546	 0.004995	 0.012703	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77555	 77556	 0.000109	 0.008719	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77556	 77557	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77557	 77558	 0.021512	 0.017024	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77557	 77560	 0.01566	 0.024435	 0.00041	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77563	 77564	 0.003572	 0.021711	 0.0004	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77568	 77570	 0.002981	 0.011598	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77568	 77570	 0.002981	 0.011598	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77569	 77570	 0.006249	 0.035521	 0.00064	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77574	 77607	 0.01693	 0.082616	 0.00143	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77577	 77579	 0.005838	 0.016567	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77584	 77585	 0.004206	 0.027793	 0.00055	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77586	 77587	 0.00413	 0.022743	 0.00051	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77589	 77591	 0.004223	 0.025665	 0.00047	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77590	 77591	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77611	 77612	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77611	 77612	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77612	 77613	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77612	 77613	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77613	 77614	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77613	 77614	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77613	 77616	 4.9e-05	 0.000764	 0.0005	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77614	 77623	 0.15435	 0.25785	 0.00438	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77614	 77625	 0.08315	 0.33997	 0.00688	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77614	 77634	 0.090296	 0.40255	 0.00684	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77614	 78317	 0.025169	 0.13861	 0.00313	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77615	 77616	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77615	 77616	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77615	 79974	 0.004972	 0.070125	 0.29232	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77617	 77618	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77617	 77618	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77617	 78283	 0.000356	 0.003842	 0.00205	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77619	 77620	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77619	 77620	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77620	 77621	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77620	 77621	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77620	 78012	 0.00013	 0.002058	 0.0013	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77622	 78645	 0.001096	 0.007605	 0.00217	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77624	 77625	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77624	 77625	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77626	 77627	 9.3e-05	 0.007407	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77626	 77627	 9.3e-05	 0.007407	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77627	 77628	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77627	 77628	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77629	 77630	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77629	 77630	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77629	 77653	 0.000491	 0.007541	 0.00211	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77631	 77632	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77631	 77632	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77631	 78104	 0.000876	 0.014238	 0.02811	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77632	 78200	 0.035536	 0.24397	 0.00445	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77634	 77916	 0.01624	 0.063425	 0.00141	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77634	 77920	 0.028123	 0.069803	 0.00116	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77635	 77636	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77635	 77636	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77637	 77638	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77637	 77638	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77638	 78132	 0.000325	 0.005151	 0.00326	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77640	 77641	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77640	 77641	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77642	 77643	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77642	 77643	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77642	 78850	 8.9e-05	 0.002119	 0.03788	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77644	 78249	 0.017116	 0.10133	 0.00197	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77646	 77647	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77646	 77647	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77647	 78022	 0.005224	 0.020097	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77647	 78022	 0.005224	 0.020097	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77649	 77650	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77649	 77650	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77649	 79193	 0.002249	 0.027415	 0.10232	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77650	 77651	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77650	 77651	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77655	 78373	 0.002593	 0.010088	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77655	 78373	 0.002593	 0.010088	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77656	 77912	 0.0245	 0.048507	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77657	 77937	 0.000775	 0.011191	 0.00355	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77657	 78012	 0.000371	 0.006204	 0.00352	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77658	 77659	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77658	 77659	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77658	 78283	 0.00096	 0.005762	 0.00174	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77659	 78268	 0.043046	 0.21778	 0.00379	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77661	 78364	 0.00313	 0.012175	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77661	 78364	 0.00313	 0.012175	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77662	 78169	 0.010199	 0.029253	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77665	 77666	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77665	 77666	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77668	 79454	 0.015039	 0.039748	 0.0093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77669	 77670	 0.000104	 0.008333	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77669	 77670	 0.000104	 0.008333	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77670	 77671	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77670	 77671	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77670	 77680	 0.001064	 0.012342	 0.04387	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77671	 77672	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77671	 77672	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77671	 78937	 0.007962	 0.021042	 0.00493	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77672	 78678	 0.023232	 0.094949	 0.00192	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77673	 77674	 0.000119	 0.009548	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77673	 77674	 0.000119	 0.009548	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77674	 78526	 0.001288	 0.00864	 0.00209	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77675	 77676	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77675	 77676	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77675	 78535	 0.002114	 0.013617	 0.00357	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77677	 77678	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77677	 77678	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77679	 77680	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77679	 77680	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77680	 77681	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77680	 77681	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77681	 77682	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77681	 77682	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77681	 78937	 0.006838	 0.045874	 0.01108	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77683	 77684	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77683	 77684	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77683	 79423	 0.007782	 0.048361	 0.01365	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77685	 77686	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77685	 77686	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77686	 78934	 0.003767	 0.023857	 0.00648	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77686	 78935	 0.008311	 0.047757	 0.01353	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77686	 78937	 0.002977	 0.012115	 0.00295	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77687	 77688	 0.000104	 0.008333	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77687	 77688	 0.000104	 0.008333	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77688	 77689	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77688	 77689	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77689	 77690	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77689	 77690	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77691	 78443	 0.17401	 0.49943	 0.00769	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77691	 79405	 0.043854	 0.26967	 0.00486	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77691	 79413	 0.021596	 0.075614	 0.00209	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77692	 77693	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77692	 77693	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77692	 79021	 0.013101	 0.052457	 0.01322	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77695	 77696	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77695	 77696	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77696	 78563	 0.010547	 0.047194	 0.00097	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77698	 78400	 0.000946	 0.013658	 0.00434	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77699	 77700	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77699	 77700	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77701	 78847	 0.000425	 0.004586	 0.0091	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77701	 78847	 0.000425	 0.004586	 0.0091	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77702	 77703	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77702	 77703	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77702	 78839	 3.8e-05	 0.000547	 0.0108	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77704	 77705	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77704	 77705	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77705	 78506	 0.019524	 0.10971	 0.00203	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77706	 77707	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77706	 77707	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77706	 78915	 0.00065	 0.011321	 0.23337	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77708	 78524	 0.000861	 0.011438	 0.02444	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77708	 78525	 0.000735	 0.005014	 0.00903	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77710	 78657	 0.12675	 0.25947	 0.00639	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77710	 78736	 0.049814	 0.30634	 0.00552	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77713	 77714	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77713	 77714	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77714	 77728	 0.12468	 0.48537	 0.00811	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77714	 77740	 0.095975	 0.37352	 0.00624	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77714	 78972	 0.13689	 0.39279	 0.00604	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77715	 77716	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77715	 77716	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77717	 77718	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77717	 77718	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77717	 78739	 0.001999	 0.023026	 0.08318	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77718	 77719	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77718	 77719	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77718	 78740	 0.008108	 0.077867	 0.02266	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77719	 78882	 0.09342	 0.33386	 0.00663	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77720	 79003	 0.10955	 0.17959	 0.00317	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77721	 79387	 0.057694	 0.31783	 0.00718	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77722	 78517	 0.001532	 0.006132	 0.00154	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77725	 79368	 0.003761	 0.025522	 0.00048	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77726	 77727	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77726	 77727	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77727	 78822	 0.000755	 0.011533	 0.00372	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77729	 77730	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77729	 77730	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77729	 78414	 0.0023	 0.014565	 0.00395	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77730	 78435	 0.008039	 0.049423	 0.00089	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77732	 78784	 0.069972	 0.051482	 0.00075	 28.0	 28.0	 28.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77732	 78794	 0.013672	 0.035146	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77734	 79395	 0.062467	 0.24306	 0.00406	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77734	 79395	 0.062467	 0.24306	 0.00406	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77738	 79234	 0.029662	 0.18228	 0.00417	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77740	 79448	 0.004202	 0.021258	 0.00037	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77740	 79449	 0.005784	 0.010755	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77741	 79373	 0.036834	 0.11812	 0.00292	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77742	 79233	 0.00901	 0.053342	 0.00104	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77743	 79072	 0.031644	 0.11305	 0.00224	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77743	 79072	 0.031644	 0.11305	 0.00224	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77744	 78443	 0.014061	 0.075798	 0.00153	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77746	 78921	 0.024303	 0.1083	 0.00184	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77747	 79379	 0.046931	 0.18259	 0.00305	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77749	 78770	 0.008803	 0.027952	 0.00049	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77750	 78581	 0.03861	 0.21951	 0.00397	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77751	 78970	 0.026989	 0.063911	 0.00117	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77752	 78529	 0.13561	 0.18489	 0.0041	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77753	 79078	 0.000801	 0.011993	 0.04375	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77754	 79152	 0.017102	 0.036513	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77754	 79158	 0.002064	 0.011734	 0.00021	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77755	 79083	 0.001574	 0.004225	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77757	 77758	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77757	 77758	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77757	 79001	 0.002497	 0.020404	 0.00554	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77761	 78554	 0.073608	 0.24295	 0.00394	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77764	 78413	 0.028191	 0.071694	 0.00113	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77766	 79115	 0.055116	 0.31339	 0.00567	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77767	 77768	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77767	 77768	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77768	 77769	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77768	 77769	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77771	 78077	 0.006036	 0.033918	 0.00063	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77771	 78642	 0.00368	 0.028682	 0.00054	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77772	 78701	 0.006299	 0.035394	 0.00066	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77774	 78411	 0.2169	 0.17168	 0.00216	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77775	 77776	 0.013205	 0.013337	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77782	 77787	 0.009251	 0.052585	 0.00095	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77783	 77784	 0.012509	 0.033068	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77796	 77822	 0.006174	 0.017709	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77796	 78048	 0.00975	 0.037929	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77796	 78048	 0.00975	 0.037929	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77800	 78288	 0.007366	 0.045283	 0.00082	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77805	 77806	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77811	 77812	 0.00155	 0.008537	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77816	 77819	 0.006937	 0.019216	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77817	 77821	 0.004824	 0.02966	 0.00053	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77820	 77821	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77826	 77839	 0.014237	 0.045843	 0.00078	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77828	 77831	 0.016843	 0.074636	 0.00224	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77843	 77853	 0.0049	 0.03526	 0.00116	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77846	 77847	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77849	 77850	 0.004184	 0.022387	 0.00068	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77851	 77859	 0.012238	 0.071372	 0.00143	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77856	 77860	 0.014652	 0.078692	 0.00187	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77862	 78264	 0.013334	 0.07135	 0.00216	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77863	 77897	 0.010775	 0.017663	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77866	 77895	 0.009807	 0.020069	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77867	 77868	 0.002461	 0.007548	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77869	 77898	 0.003432	 0.021101	 0.00038	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77874	 77876	 0.004173	 0.030501	 0.00056	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77882	 77884	 0.009018	 0.023838	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77883	 77903	 0.009867	 0.027999	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77886	 77997	 0.015111	 0.07644	 0.00133	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77888	 77889	 0.010137	 0.026059	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77896	 77897	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77896	 79297	 0.001257	 0.010428	 0.00274	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77899	 77902	 0.003415	 0.019413	 0.00035	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77900	 77901	 0.018789	 0.043166	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77900	 79355	 0.012847	 0.029825	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77908	 77913	 0.037975	 0.089927	 0.00164	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77908	 78316	 0.063359	 0.11605	 0.002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77909	 77911	 0.00877	 0.042797	 0.00074	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77910	 77912	 0.016359	 0.021289	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77910	 77913	 0.001268	 0.005621	 0.00017	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77917	 77918	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77918	 78003	 0.024551	 0.15095	 0.00272	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77918	 78006	 0.019905	 0.05042	 0.001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77924	 77936	 0.004452	 0.015587	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77924	 77985	 0.001073	 0.006921	 0.00022	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77932	 77938	 0.007215	 0.027644	 0.00078	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77934	 77938	 0.011321	 0.022415	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77935	 77936	 0.005092	 0.013089	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77935	 78355	 0.015493	 0.046632	 0.00091	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77937	 77938	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77938	 77939	 0.002629	 0.009391	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77938	 77939	 0.002629	 0.009391	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77946	 77985	 0.00656	 0.033179	 0.00065	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77947	 77969	 0.008707	 0.017064	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77948	 77950	 0.002051	 0.012466	 0.00023	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77949	 77951	 0.000965	 0.004277	 0.00013	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77957	 77959	 0.00738	 0.02462	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77960	 77961	 0.002318	 0.01033	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77960	 77962	 0.007398	 0.028781	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77963	 78313	 0.010666	 0.041035	 0.0007	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77963	 78313	 0.010666	 0.041035	 0.0007	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77966	 77967	 0.002284	 0.007998	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77971	 78360	 0.01075	 0.032977	 0.00089	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77978	 77979	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77978	 77979	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77979	 77980	 9.8e-05	 0.007812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77979	 77983	 0.000515	 0.007435	 0.00236	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77983	 77984	 0.000101	 0.008064	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77987	 77988	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77989	 77991	 0.009976	 0.068477	 0.00125	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77990	 77991	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77996	 77997	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78003	 78004	 0.018894	 0.084193	 0.00143	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78007	 78314	 0.061878	 0.12127	 0.00182	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78007	 78852	 0.059591	 0.11799	 0.00173	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78011	 78014	 0.002262	 0.008799	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78011	 78014	 0.002262	 0.008799	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78012	 78013	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78012	 78016	 7e-05	 0.001144	 0.00068	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78013	 78015	 0.012111	 0.012366	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78014	 78017	 0.002538	 0.007785	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78014	 78017	 0.002538	 0.007785	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78016	 78017	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78018	 78019	 0.000903	 0.003514	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78018	 78019	 0.000903	 0.003514	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78018	 78020	 0.000871	 0.008017	 0.00016	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78019	 78031	 0.00252	 0.009003	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78019	 78031	 0.00252	 0.009003	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78024	 78026	 0.002777	 0.010803	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78025	 78027	 0.001293	 0.005699	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78027	 78033	 0.004746	 0.018464	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78036	 78037	 8.7e-05	 0.006944	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78045	 78047	 0.00057	 0.005308	 0.0001	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78047	 78048	 0.002204	 0.012529	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78050	 78068	 0.001393	 0.006722	 0.00012	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78053	 78067	 0.003554	 0.024112	 0.00045	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78054	 78065	 0.005844	 0.027099	 0.00056	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78055	 78056	 0.004851	 0.003839	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78059	 78060	 0.001642	 0.003506	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78061	 78064	 0.001331	 0.007147	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78070	 78071	 0.006971	 0.027117	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78070	 78071	 0.006971	 0.027117	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78072	 78073	 0.037918	 0.14752	 0.00246	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78079	 78092	 0.011488	 0.035278	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78080	 78084	 0.00406	 0.015857	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78088	 78091	 0.008417	 0.041073	 0.00071	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78093	 78100	 0.017898	 0.051333	 0.00079	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78094	 78097	 0.006919	 0.042052	 0.00078	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78095	 78097	 0.003161	 0.024351	 0.00047	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78096	 78097	 0.009049	 0.032324	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78096	 78097	 0.009049	 0.032324	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78102	 78166	 0.008581	 0.059464	 0.00122	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78103	 78336	 0.054817	 0.12594	 0.00191	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78104	 78105	 7.2e-05	 0.005736	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78105	 78106	 0.000108	 0.00862	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78106	 78137	 0.033436	 0.055764	 0.00081	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78106	 78139	 0.01328	 0.075488	 0.00137	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78106	 78167	 0.011923	 0.031517	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78109	 78112	 0.004633	 0.023436	 0.00041	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78109	 78141	 0.007524	 0.021351	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78111	 78115	 0.007645	 0.0389	 0.00088	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78115	 78116	 0.00398	 0.027319	 0.0005	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78115	 78120	 0.003708	 0.013247	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78115	 78120	 0.003708	 0.013247	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78118	 78120	 0.003229	 0.011306	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78122	 78125	 0.006531	 0.017311	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78124	 78125	 0.006749	 0.038365	 0.00069	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78124	 78372	 0.005852	 0.03598	 0.00065	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78128	 78371	 0.010123	 0.03377	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78131	 78134	 0.001936	 0.006917	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78131	 78134	 0.001936	 0.006917	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78132	 78133	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78135	 78136	 0.005098	 0.013104	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78139	 78142	 0.004476	 0.017414	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78139	 78142	 0.004476	 0.017414	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78144	 78160	 0.006941	 0.026705	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78144	 78160	 0.006941	 0.026705	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78152	 78153	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78153	 78178	 0.15707	 0.15712	 0.00212	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78155	 78157	 0.015637	 0.060831	 0.00102	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78157	 78161	 0.012741	 0.062174	 0.00107	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78161	 78162	 0.017824	 0.068573	 0.00117	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78161	 78162	 0.017824	 0.068573	 0.00117	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78165	 78166	 9.5e-05	 0.007575	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78166	 78203	 0.023159	 0.14239	 0.00257	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78168	 78169	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78170	 78373	 0.005211	 0.020047	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78170	 78373	 0.005211	 0.020047	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78176	 78199	 0.004365	 0.032967	 0.00098	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78179	 78213	 0.004937	 0.02778	 0.0006	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78180	 78212	 0.028917	 0.082938	 0.00128	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78183	 78185	 0.003831	 0.023553	 0.00042	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78183	 78187	 0.010448	 0.064237	 0.00116	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78183	 78212	 0.025061	 0.041796	 0.00061	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78184	 78212	 0.013733	 0.02281	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78187	 78192	 0.01336	 0.045637	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78188	 78189	 0.045501	 0.036009	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78189	 78200	 0.030172	 0.077561	 0.0012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78192	 78196	 0.008486	 0.052174	 0.00094	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78193	 78197	 0.033824	 0.026513	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78194	 78195	 0.014205	 0.050747	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78196	 78249	 0.010997	 0.049004	 0.00083	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78206	 78207	 0.009454	 0.052059	 0.00117	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78209	 78210	 0.014962	 0.038461	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78209	 78258	 0.016071	 0.031819	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78211	 78212	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78221	 78222	 0.003555	 0.013828	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78222	 78227	 0.003633	 0.030222	 0.00057	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78222	 78231	 0.022379	 0.071059	 0.00125	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78223	 78224	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78227	 78228	 0.007602	 0.025969	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78227	 78228	 0.007602	 0.025969	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78230	 78336	 0.009961	 0.038751	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78230	 78336	 0.009961	 0.038751	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78234	 78241	 0.002681	 0.008225	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78234	 78248	 0.005492	 0.030054	 0.00059	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78235	 78236	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78244	 78245	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78244	 78396	 0.002832	 0.013962	 0.00378	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78245	 78349	 0.016182	 0.064202	 0.00183	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78247	 78397	 0.021839	 0.084961	 0.00142	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78251	 78255	 0.007306	 0.039097	 0.00119	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78254	 78255	 0.00587	 0.022583	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78262	 78264	 0.019915	 0.12506	 0.00273	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78271	 78273	 0.062999	 0.051854	 0.00105	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78283	 78284	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78286	 78287	 0.005779	 0.022481	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78286	 78287	 0.005779	 0.022481	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78287	 78289	 0.003189	 0.012405	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78287	 78289	 0.003189	 0.012405	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78291	 78293	 0.002321	 0.014269	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78300	 78301	 0.003953	 0.010012	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78303	 78307	 0.014234	 0.069459	 0.0012	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78304	 78305	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78305	 78306	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78306	 78308	 0.00666	 0.029514	 0.00089	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78312	 78313	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78314	 78315	 0.01416	 0.075444	 0.00132	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78316	 78318	 0.060088	 0.074589	 0.00163	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78317	 78318	 0.041503	 0.074886	 0.00108	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78320	 78323	 0.009842	 0.03156	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78320	 78323	 0.009842	 0.03156	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78322	 78323	 0.007393	 0.068824	 0.00133	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78323	 78329	 0.012307	 0.037043	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78323	 78334	 0.009018	 0.050741	 0.0011	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78334	 78335	 0.017146	 0.028884	 0.00041	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78338	 78340	 0.010993	 0.067588	 0.00122	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78339	 78343	 0.014775	 0.08302	 0.00154	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78341	 79363	 0.022528	 0.12056	 0.00366	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78352	 78391	 0.008105	 0.03153	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78352	 78391	 0.008105	 0.03153	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78365	 78368	 0.007394	 0.036079	 0.00062	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78369	 78371	 0.001727	 0.012622	 0.00023	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78370	 78371	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78375	 78384	 0.003215	 0.025058	 0.00047	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78379	 78380	 0.004194	 0.026336	 0.00058	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78380	 78383	 0.004741	 0.021124	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78382	 78383	 0.010498	 0.036731	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78382	 78383	 0.010498	 0.036731	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78389	 78390	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78392	 79229	 0.017721	 0.078081	 0.00136	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78396	 78397	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78399	 78403	 0.00084	 0.013317	 0.00842	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78408	 78409	 0.010375	 0.046423	 0.00096	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78410	 78412	 0.095386	 0.087864	 0.00141	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78414	 78415	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78416	 78417	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78419	 78420	 0.002429	 0.003877	 9e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78419	 78430	 0.003599	 0.024416	 0.00046	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78419	 78518	 0.003949	 0.011327	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78424	 78435	 0.010076	 0.02339	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78439	 78460	 0.023477	 0.021037	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78442	 78523	 0.014357	 0.087254	 0.00161	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78446	 78663	 0.013407	 0.053191	 0.00152	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78447	 78662	 0.022408	 0.057602	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78451	 78452	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78451	 78524	 0.001757	 0.017935	 0.05696	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78453	 78454	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78455	 78456	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78457	 78463	 0.020716	 0.053253	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78466	 78467	 0.004865	 0.023364	 0.00045	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78472	 78473	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78472	 78478	 0.001202	 0.017668	 0.0054	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78474	 83649	 0.1585	 0.45488	 0.007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78477	 78478	 0.000116	 0.009249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78478	 78479	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78480	 78513	 0.028457	 0.028464	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78481	 78513	 0.007587	 0.04263	 0.00079	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78484	 78487	 0.004968	 0.020303	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78485	 78489	 0.030555	 0.025149	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78487	 78489	 0.033725	 0.060852	 0.00088	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78493	 78494	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78496	 78500	 0.049491	 0.14196	 0.00218	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78498	 78501	 0.009689	 0.059569	 0.00107	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78499	 78517	 0.003505	 0.014031	 0.00353	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78499	 79412	 0.003646	 0.014596	 0.00368	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78516	 78517	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78520	 78521	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78522	 78528	 0.013198	 0.087221	 0.00172	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78525	 78526	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78526	 78527	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78533	 78538	 0.004277	 0.019061	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78533	 78548	 0.009163	 0.026281	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78536	 78550	 0.0009	 0.006813	 0.00335	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78537	 78538	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78538	 78551	 0.008036	 0.024677	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78542	 78546	 0.013318	 0.033733	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78543	 78545	 0.03521	 0.027865	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78544	 78545	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78544	 78550	 0.00268	 0.016975	 0.00461	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78544	 78552	 0.001184	 0.006162	 0.00181	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78547	 78657	 0.057747	 0.30777	 0.0054	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78549	 78550	 8.5e-05	 0.006812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78553	 78554	 0.047938	 0.24254	 0.00422	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78553	 78929	 0.021359	 0.12001	 0.00222	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78556	 78577	 0.012013	 0.060769	 0.00106	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78558	 78559	 0.001603	 0.014921	 0.00029	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78560	 78562	 0.006277	 0.050786	 0.00131	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78561	 78564	 0.020638	 0.14698	 0.0033	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78565	 78566	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78566	 78571	 0.085044	 0.18227	 0.00319	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78567	 78568	 0.003426	 0.019491	 0.0006	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78571	 78731	 0.058251	 0.13214	 0.00264	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78572	 78573	 0.009957	 0.032858	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78574	 78576	 0.024122	 0.05712	 0.00104	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78576	 78579	 0.014831	 0.074177	 0.00132	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78577	 79202	 0.043715	 0.17008	 0.00284	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78593	 78597	 0.009761	 0.043005	 0.00075	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78595	 78596	 0.002624	 0.01335	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78601	 78606	 0.025566	 0.21235	 0.00519	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78603	 78604	 8.6e-05	 0.006896	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78604	 78605	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78605	 78606	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78609	 78612	 0.002592	 0.021562	 0.00041	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78610	 78617	 0.014807	 0.042018	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78611	 78612	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78612	 78615	 0.005261	 0.034396	 0.0008	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78613	 78614	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78616	 78642	 0.005106	 0.016372	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78616	 78642	 0.005106	 0.016372	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78621	 78622	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78621	 79157	 0.008547	 0.055058	 0.01444	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78622	 78624	 0.025901	 0.039672	 0.00069	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78622	 78636	 0.012788	 0.12532	 0.00245	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78622	 79128	 0.064121	 0.050745	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78623	 78625	 0.006452	 0.032832	 0.00074	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78628	 78644	 0.003098	 0.02577	 0.00049	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78640	 78641	 0.017809	 0.03526	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78643	 79130	 0.038405	 0.089163	 0.00133	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78645	 78646	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78647	 78650	 0.01057	 0.032427	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78649	 78655	 0.010479	 0.058964	 0.00127	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78651	 78654	 0.019985	 0.10695	 0.00324	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78652	 79105	 0.095793	 0.12467	 0.00174	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78660	 78661	 0.010893	 0.026662	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78667	 78676	 0.020764	 0.083094	 0.00175	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78667	 78679	 0.021983	 0.051035	 0.00076	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78671	 78672	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78672	 78673	 0.016036	 0.048267	 0.00094	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78682	 78684	 0.016743	 0.051362	 0.00139	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78682	 78684	 0.016743	 0.051362	 0.00139	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78682	 79124	 0.01032	 0.087646	 0.00205	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78683	 78684	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78686	 78687	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78687	 78688	 0.007454	 0.069392	 0.00134	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78687	 78692	 0.029251	 0.089736	 0.00243	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78690	 78691	 0.005436	 0.026228	 0.00046	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78693	 78694	 0.005227	 0.007836	 0.00014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78695	 78874	 0.022036	 0.054696	 0.00091	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78699	 78703	 0.013946	 0.078475	 0.00169	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78700	 79178	 0.023486	 0.018586	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78702	 78703	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78703	 78704	 0.006584	 0.050717	 0.00097	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78703	 79174	 0.011835	 0.10052	 0.00235	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78704	 78708	 0.070126	 0.077132	 0.00103	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78706	 78712	 0.008768	 0.026926	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78707	 78710	 0.006038	 0.030357	 0.00083	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78709	 78710	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78713	 78714	 0.01069	 0.041586	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78713	 78714	 0.01069	 0.041586	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78722	 78723	 0.015562	 0.036851	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78726	 78727	 0.00978	 0.040823	 0.00118	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78733	 79005	 0.040844	 0.23221	 0.0042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78738	 78740	 0.001506	 0.007566	 0.00197	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78750	 79232	 0.0265	 0.171	 0.00544	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78753	 78757	 0.095103	 0.21052	 0.00345	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78757	 79103	 0.066825	 0.33433	 0.00595	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78760	 78781	 0.00536	 0.023617	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78764	 78765	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78766	 78767	 6.9e-05	 0.005555	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78766	 78767	 6.9e-05	 0.005555	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78767	 78768	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78767	 78768	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78768	 78769	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78768	 78769	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78771	 78772	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78771	 78775	 0.002535	 0.028395	 0.00903	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78775	 78776	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78777	 78778	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78777	 78779	 0.001591	 0.017911	 0.00518	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78780	 78929	 0.17808	 0.59465	 0.00944	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78782	 78783	 0.004746	 0.012071	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78784	 78803	 0.13638	 0.31672	 0.00471	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78785	 78786	 0.006223	 0.014447	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78786	 79450	 0.017198	 0.044209	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78789	 78791	 0.014774	 0.023582	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78793	 78796	 0.055841	 0.055855	 0.00075	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78794	 78795	 0.014143	 0.055019	 0.00092	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78795	 78797	 0.077835	 0.061012	 0.00078	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78797	 78971	 0.083372	 0.21435	 0.00332	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78798	 78800	 0.015839	 0.047672	 0.00093	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78803	 78944	 0.10746	 0.31612	 0.00648	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78806	 79275	 0.003434	 0.019523	 0.00035	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78807	 79268	 0.006167	 0.024677	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78816	 78817	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78821	 78822	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78821	 78822	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78821	 78831	 0.000126	 0.001147	 0.02342	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78821	 78831	 0.000126	 0.001147	 0.02342	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78827	 78832	 0.000659	 0.00325	 0.00088	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78829	 78830	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78829	 78832	 0.00045	 0.004508	 0.0015	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78829	 78838	 0.000685	 0.004598	 0.00111	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78831	 78832	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78831	 78832	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78832	 78833	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78832	 78833	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78832	 78835	 0.000264	 0.003647	 0.00163	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78833	 78877	 0.003873	 0.022013	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78834	 78835	 0.000116	 0.009249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78834	 78839	 2.9e-05	 0.000485	 0.01053	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78836	 78846	 0.002572	 0.015002	 0.0003	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78837	 78878	 0.017453	 0.013812	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78839	 78840	 0.000123	 0.009866	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78839	 78840	 0.000123	 0.009866	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78840	 78843	 0.00033	 0.004473	 0.00259	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78841	 78845	 0.00038	 0.003052	 0.00086	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78842	 78843	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78842	 78843	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78845	 78846	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78847	 78848	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78848	 78849	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78850	 78851	 0.000116	 0.009249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78851	 78852	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78852	 78854	 0.007469	 0.032907	 0.00057	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78856	 78857	 0.045067	 0.035666	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78858	 78860	 0.013049	 0.025574	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78864	 78865	 0.010543	 0.019927	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78864	 78868	 0.005998	 0.021426	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78865	 78877	 0.005999	 0.036878	 0.00066	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78866	 78871	 0.01181	 0.045434	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78866	 78874	 0.009522	 0.024478	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78869	 78872	 0.006654	 0.019084	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78869	 79163	 0.003579	 0.020108	 0.00037	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78880	 78882	 0.12364	 0.23373	 0.00378	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78886	 78887	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78888	 78892	 0.015583	 0.04422	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78888	 78898	 0.082804	 0.36696	 0.00837	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78902	 78911	 0.039736	 0.21886	 0.00494	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78904	 78907	 0.027718	 0.05488	 0.00081	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78905	 78906	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78915	 78916	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78915	 78916	 0.000114	 0.00909	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78916	 78917	 8.3e-05	 0.006605	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78917	 78918	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78918	 78920	 0.13683	 0.13821	 0.00183	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78919	 78920	 0.063983	 0.050153	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78920	 78923	 0.052556	 0.14915	 0.00234	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78924	 79648	 0.002903	 0.019996	 0.0353	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78926	 78927	 0.054722	 0.11502	 0.0021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78930	 78931	 0.038278	 0.091301	 0.00205	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78934	 78935	 0.006927	 0.029317	 0.0066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78934	 78937	 0.001844	 0.010872	 0.00885	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78935	 78936	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78935	 79423	 0.012732	 0.079135	 0.02234	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78938	 78939	 0.060851	 0.1279	 0.00233	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78940	 78943	 0.10167	 0.23361	 0.00355	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78946	 78962	 0.005722	 0.047603	 0.0009	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78954	 78959	 0.012962	 0.078476	 0.00246	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78955	 78956	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78956	 78957	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78958	 78959	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78961	 79057	 0.009936	 0.081687	 0.00158	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78962	 78964	 0.019349	 0.040666	 0.00074	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78965	 78982	 0.014143	 0.032835	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78969	 78971	 0.027175	 0.13747	 0.00239	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78971	 78977	 0.036393	 0.0777	 0.00175	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78972	 78973	 0.022219	 0.079373	 0.00158	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78972	 79455	 0.025281	 0.14226	 0.00307	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78975	 78984	 0.013368	 0.068022	 0.00154	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78976	 78977	 0.020185	 0.047798	 0.00087	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78976	 78999	 0.00604	 0.02521	 0.00073	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78976	 79002	 0.010521	 0.024061	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78977	 78982	 0.025357	 0.067032	 0.00122	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78981	 78982	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78985	 78987	 0.003734	 0.028371	 0.00065	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78985	 78989	 0.01306	 0.048993	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78985	 78989	 0.01306	 0.048993	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78990	 78991	 0.003463	 0.014153	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79004	 79005	 0.026101	 0.078562	 0.00154	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79012	 79013	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79012	 84244	 0.000889	 0.014499	 0.00865	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79016	 79018	 0.039953	 0.028882	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79016	 79026	 0.030654	 0.078801	 0.00122	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79018	 79027	 0.010632	 0.01911	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79019	 79020	 0.024231	 0.11	 0.00239	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79021	 79022	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79025	 79027	 0.035963	 0.083481	 0.00159	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79032	 79034	 0.020811	 0.041205	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79042	 79047	 0.007721	 0.040151	 0.00087	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79044	 79045	 8.6e-05	 0.006896	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79044	 79045	 8.6e-05	 0.006896	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79044	 79082	 0.000669	 0.016848	 0.27751	 1940.0	 2037.0	 2134.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79045	 79046	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79045	 79046	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79046	 79047	 9.5e-05	 0.007575	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79048	 79049	 0.01091	 0.023379	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79053	 79072	 0.005302	 0.026821	 0.00047	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79055	 79066	 0.002789	 0.023199	 0.00044	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79057	 79063	 0.013147	 0.089206	 0.00166	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79059	 79067	 0.05145	 0.11945	 0.00178	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79059	 79382	 0.09659	 0.37592	 0.00628	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79059	 79382	 0.09659	 0.37592	 0.00628	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79061	 79062	 0.006425	 0.043597	 0.00081	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79064	 79065	 0.007832	 0.016096	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79072	 79074	 0.008365	 0.01942	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79077	 79078	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79077	 79078	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79077	 79079	 0.000286	 0.002885	 0.04749	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79077	 79079	 0.000286	 0.002885	 0.04749	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95336	 79077	 0.002579	 0.037793	 0.57295	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79079	 79080	 0.000186	 0.014868	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79079	 79088	 0.000182	 0.001805	 0.03089	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79079	 79088	 0.000182	 0.001805	 0.03089	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79082	 79083	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79082	 79088	 9.8e-05	 0.001331	 0.02344	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79083	 79089	 0.001704	 0.010794	 0.00293	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79085	 79086	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79088	 79089	 0.000103	 0.008222	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79092	 79093	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79097	 79231	 0.038212	 0.18649	 0.00322	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79104	 79105	 0.018683	 0.086629	 0.0018	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79109	 79239	 0.039632	 0.36912	 0.00715	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79110	 79111	 0.014293	 0.087875	 0.00158	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79112	 79120	 0.009471	 0.092812	 0.00182	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79130	 79138	 0.020982	 0.053359	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79131	 79132	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79131	 79132	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79133	 79134	 0.008422	 0.032889	 0.00073	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79136	 79137	 0.000841	 0.007141	 0.00017	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79138	 79158	 0.027737	 0.12221	 0.00212	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79142	 79143	 0.007439	 0.015882	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79142	 79145	 0.015786	 0.043726	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79144	 79336	 0.020208	 0.051186	 0.00101	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79145	 79316	 0.014633	 0.038682	 0.0007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79151	 79152	 0.00422	 0.017616	 0.00051	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79152	 79308	 0.012456	 0.034503	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79153	 79160	 0.003577	 0.01594	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79154	 79169	 0.009716	 0.035925	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79154	 79169	 0.009716	 0.035925	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79157	 79158	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79158	 79159	 0.007927	 0.025419	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79158	 79172	 0.010435	 0.034812	 0.00055	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79159	 79160	 0.001787	 0.007962	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79163	 79164	 0.012356	 0.035439	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79167	 79168	 0.000123	 0.009866	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79168	 79169	 0.000136	 0.010869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79169	 79173	 0.006644	 0.037766	 0.00068	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79169	 79204	 0.022784	 0.081394	 0.00162	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79174	 79176	 0.004172	 0.026195	 0.00057	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79175	 79176	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79176	 79200	 0.040657	 0.13563	 0.00215	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79176	 79204	 0.010114	 0.033378	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79177	 79199	 0.002591	 0.008887	 0.00213	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79179	 79180	 0.020273	 0.0207	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79180	 79184	 0.012172	 0.064118	 0.00115	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79183	 79184	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79185	 79186	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79186	 79187	 0.003649	 0.01857	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79191	 79192	 0.011516	 0.040293	 0.00083	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79191	 79192	 0.011516	 0.040293	 0.00083	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79193	 79194	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79193	 79195	 0.000269	 0.004297	 0.00882	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79195	 79196	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79196	 79199	 0.001765	 0.01137	 0.00298	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79197	 79198	 9.3e-05	 0.007407	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79197	 79198	 9.3e-05	 0.007407	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79200	 79201	 0.005846	 0.022491	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79200	 79201	 0.005846	 0.022491	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79200	 79202	 0.012745	 0.067909	 0.00119	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79213	 79214	 0.012507	 0.048656	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79213	 79214	 0.012507	 0.048656	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79216	 79217	 0.006447	 0.048977	 0.00112	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79217	 79219	 0.012048	 0.049239	 0.001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79220	 79221	 0.022091	 0.078918	 0.00157	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79220	 79221	 0.022091	 0.078918	 0.00157	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79244	 79342	 0.012209	 0.023654	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79251	 79256	 0.001734	 0.005319	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79259	 79260	 0.000178	 0.014249	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79259	 79260	 0.000178	 0.014249	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79259	 79356	 8.7e-05	 0.000924	 0.01382	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79259	 79356	 8.7e-05	 0.000924	 0.01382	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79261	 79262	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79263	 79265	 0.001285	 0.011961	 0.00023	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79268	 79271	 0.00253	 0.015548	 0.00036	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79272	 79342	 0.00124	 0.011542	 0.00022	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79274	 79276	 0.003623	 0.008411	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79277	 79280	 0.004145	 0.006349	 0.00011	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79278	 79342	 0.004396	 0.027029	 0.00049	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79283	 79285	 0.001172	 0.006246	 0.00011	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79285	 79287	 0.004396	 0.010205	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79289	 79295	 0.012319	 0.015017	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79292	 79293	 0.001839	 0.007074	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79293	 79304	 0.002113	 0.016652	 0.00035	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79295	 79346	 0.009627	 0.0179	 0.00042	 69.0	 69.0	 69.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79297	 79298	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79301	 79350	 0.003856	 0.010221	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79306	 79307	 0.001322	 0.010873	 0.00021	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79306	 79308	 0.004817	 0.019685	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79307	 79308	 0.007214	 0.018544	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79321	 79325	 0.001344	 0.009926	 0.00021	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79324	 79325	 0.001094	 0.00853	 0.00016	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79324	 79326	 0.002715	 0.007196	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79324	 79328	 0.005383	 0.033093	 0.0006	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79334	 79347	 0.003118	 0.011997	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79334	 79347	 0.003118	 0.011997	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79339	 79354	 0.003551	 0.024735	 0.00058	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79341	 79342	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79344	 79345	 9.7e-05	 0.007785	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79344	 79345	 9.7e-05	 0.007785	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79345	 79346	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79345	 79346	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79349	 79350	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79353	 79354	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79356	 79357	 0.000128	 0.010206	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79356	 79357	 0.000128	 0.010206	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79359	 79418	 0.019885	 0.077359	 0.00129	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79359	 79418	 0.019885	 0.077359	 0.00129	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79362	 79417	 0.045387	 0.28943	 0.00706	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79365	 79385	 0.06018	 0.36589	 0.00675	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79366	 79372	 0.039544	 0.10454	 0.0019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79378	 79379	 0.006423	 0.035369	 0.0008	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79389	 79390	 0.025427	 0.057676	 0.00115	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79392	 79393	 0.026948	 0.089898	 0.00143	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79396	 79397	 0.011814	 0.067156	 0.00122	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79400	 79401	 0.006161	 0.018899	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79404	 79410	 0.02482	 0.096557	 0.00161	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79412	 79413	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79413	 79415	 0.13476	 0.09742	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79416	 79417	 0.005571	 0.046346	 0.00088	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79417	 79418	 0.01946	 0.098442	 0.00171	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79423	 79424	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79428	 79429	 0.004129	 0.025383	 0.00046	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79433	 79434	 0.013588	 0.079247	 0.00159	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79435	 79436	 0.084731	 0.085583	 0.00113	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79438	 79439	 0.061062	 0.10521	 0.00167	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79441	 79442	 0.018275	 0.09627	 0.00173	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79454	 79455	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79455	 79456	 0.024522	 0.087601	 0.00174	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79455	 79462	 0.050978	 0.15656	 0.00294	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79464	 79465	 0.024461	 0.048431	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79466	 79493	 0.14576	 0.24314	 0.00354	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79467	 79470	 0.18464	 0.47494	 0.00736	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79467	 79475	 0.020559	 0.1264	 0.00228	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79467	 79680	 0.009811	 0.032728	 0.00052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79468	 79469	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79468	 79469	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79470	 79709	 0.017175	 0.056677	 0.00092	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79470	 79715	 0.005627	 0.040491	 0.00133	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79471	 79719	 0.045964	 0.27839	 0.00872	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79472	 79690	 0.000281	 0.00424	 0.00126	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79473	 79474	 0.001548	 0.004914	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79473	 79681	 0.006295	 0.016685	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79475	 79677	 0.010305	 0.021659	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79476	 79477	 0.000109	 0.008719	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79476	 79477	 0.000109	 0.008719	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79476	 79974	 0.002269	 0.020802	 0.08214	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79479	 79480	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79479	 79480	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79480	 79481	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79480	 79481	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79481	 79930	 0.049201	 0.1481	 0.0029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79482	 79483	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79482	 79483	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79483	 79484	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79483	 79484	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79485	 79486	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79485	 79486	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79485	 81805	 0.00283	 0.027822	 0.09546	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79486	 79804	 0.001482	 0.014476	 0.00406	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79487	 79488	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79487	 79488	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79487	 79998	 0.003306	 0.022778	 0.04022	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79488	 79489	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79488	 79489	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79488	 81287	 0.006065	 0.030169	 0.00974	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79489	 79994	 0.19653	 0.25836	 0.00354	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79489	 81292	 0.055276	 0.21507	 0.00359	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79491	 79876	 0.010237	 0.079788	 0.00149	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79491	 80203	 0.24403	 0.41131	 0.00586	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79492	 79493	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79492	 79493	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79494	 79972	 0.030755	 0.15994	 0.00347	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79495	 79882	 0.002605	 0.014658	 0.00032	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79496	 79497	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79496	 79497	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79496	 79886	 0.003415	 0.024152	 0.00663	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79497	 79924	 0.01324	 0.066974	 0.00117	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79498	 79827	 0.015205	 0.076914	 0.00134	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79498	 79885	 0.005925	 0.026242	 0.0006	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79498	 79913	 0.009031	 0.055525	 0.001	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79499	 80234	 0.008387	 0.032627	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79500	 79844	 0.014274	 0.042962	 0.00084	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79501	 81364	 0.002414	 0.022133	 0.0874	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79502	 79931	 0.004355	 0.024506	 0.00053	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79502	 79975	 0.099847	 0.26473	 0.00672	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79503	 80004	 0.002943	 0.031744	 0.00909	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79504	 79992	 0.008614	 0.029024	 0.00721	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79506	 79507	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79506	 79507	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79507	 80214	 0.028817	 0.14578	 0.00254	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79507	 81754	 0.088105	 0.17446	 0.00256	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79508	 80207	 0.004593	 0.031524	 0.00057	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79510	 80197	 0.016291	 0.012892	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79511	 79512	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79511	 79512	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79511	 80264	 0.002671	 0.016917	 0.00459	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79512	 80283	 0.010399	 0.03469	 0.00055	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79513	 80002	 0.000449	 0.006112	 0.02098	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79513	 80003	 0.001202	 0.008157	 0.01485	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79514	 79515	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79514	 79515	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79516	 79517	 0.000109	 0.008719	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79516	 79517	 0.000109	 0.008719	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79518	 79519	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79518	 79519	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79520	 79521	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79520	 79521	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79520	 80476	 0.001388	 0.020284	 0.07775	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79521	 79522	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79521	 79522	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79521	 80379	 0.001152	 0.012486	 0.0039	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79521	 80420	 0.02062	 0.13493	 0.03435	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79522	 79538	 0.020824	 0.092793	 0.00158	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79523	 80807	 0.001992	 0.013115	 0.02538	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79524	 79525	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79524	 79525	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79524	 80807	 0.000309	 0.003291	 0.00669	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79524	 80807	 0.000309	 0.003291	 0.00669	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79526	 80875	 0.044647	 0.17716	 0.00506	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79527	 79528	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79527	 79528	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79528	 79560	 0.30709	 0.51258	 0.00746	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79528	 79563	 0.028244	 0.1939	 0.00354	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79528	 79569	 0.11067	 0.36932	 0.00586	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79528	 80859	 0.051085	 0.17043	 0.0027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79529	 79530	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79529	 79530	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79529	 80850	 0.005503	 0.045709	 0.01788	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79530	 80577	 0.050503	 0.14852	 0.00304	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79532	 79533	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79532	 79533	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79534	 79535	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79534	 79535	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79535	 79536	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79535	 79536	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79537	 79538	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79537	 79538	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79538	 80380	 0.050658	 0.169	 0.00268	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79540	 79541	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79540	 79541	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79542	 79543	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79542	 79543	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79543	 80873	 0.21133	 0.34658	 0.00612	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79545	 80321	 0.039148	 0.22	 0.00407	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79545	 80323	 0.08344	 0.4076	 0.00855	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79546	 79547	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79546	 79547	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79547	 81220	 0.01769	 0.042635	 0.01204	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79548	 81524	 0.059335	 0.26001	 0.00559	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79550	 79551	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79550	 79551	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79551	 79552	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79551	 79552	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79552	 80831	 0.041584	 0.096545	 0.00144	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79555	 80834	 0.044318	 0.21184	 0.00464	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79555	 80842	 0.030283	 0.15748	 0.00341	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79556	 81320	 0.080548	 0.39323	 0.00679	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79557	 80643	 0.11107	 0.34122	 0.00641	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79558	 80315	 0.33567	 0.50956	 0.00731	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79561	 79562	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79561	 79562	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79562	 79563	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79562	 79563	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79564	 79565	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79564	 79565	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79564	 88614	 0.011235	 0.10777	 0.39793	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79565	 79566	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79565	 79566	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79567	 80589	 0.006902	 0.017742	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79570	 80395	 0.028298	 0.099017	 0.00205	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79570	 80395	 0.028298	 0.099017	 0.00205	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79575	 80625	 0.026027	 0.15819	 0.00292	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79577	 79578	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79577	 79578	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79579	 79580	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79579	 79580	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79582	 79583	 0.000105	 0.008384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79582	 79583	 0.000105	 0.008384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79582	 81040	 0.003299	 0.035622	 0.07074	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79582	 81040	 0.003299	 0.035622	 0.07074	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79582	 81739	 0.005312	 0.083672	 0.27936	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79584	 79585	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79584	 79585	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79584	 79633	 0.046664	 0.12004	 0.02975	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79586	 81442	 0.07643	 0.12876	 0.00183	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79587	 79588	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79587	 79588	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79588	 79589	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79588	 79589	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79588	 81608	 0.037783	 0.10148	 0.02301	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79591	 79592	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79591	 79592	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79591	 81059	 0.015615	 0.11708	 0.02858	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79591	 81316	 0.008448	 0.076858	 0.01941	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79591	 81338	 0.010873	 0.098934	 0.02499	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79593	 79594	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79593	 79594	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79594	 79595	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79594	 79595	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79594	 81440	 0.010612	 0.078421	 0.02264	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79594	 81532	 0.010025	 0.055217	 0.01994	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79596	 79597	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79596	 79597	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79597	 79598	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79597	 79598	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79597	 81092	 0.007406	 0.041096	 0.01249	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79599	 79600	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79599	 79600	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79601	 79602	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79601	 79602	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79601	 81605	 0.000665	 0.007527	 0.02809	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79602	 79603	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79602	 79603	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79603	 81501	 0.004899	 0.025806	 0.00046	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79605	 79606	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79605	 79606	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79608	 79609	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79608	 79609	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79608	 81067	 0.003684	 0.032406	 0.06763	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79610	 79611	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79610	 79611	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79611	 79612	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79611	 79612	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79612	 81639	 0.00316	 0.014004	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79613	 81210	 0.11572	 0.27609	 0.00619	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79613	 81281	 0.028969	 0.15855	 0.0031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79614	 79615	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79614	 79615	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79616	 81417	 0.11052	 0.087465	 0.0011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79617	 81337	 0.000673	 0.006971	 0.01338	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79617	 81495	 0.001513	 0.017942	 0.0611	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79619	 79620	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79619	 79620	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79619	 81067	 0.002228	 0.020424	 0.08065	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79621	 81316	 0.003048	 0.021557	 0.00592	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79621	 81336	 0.004944	 0.042404	 0.01207	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79622	 81064	 0.072093	 0.38429	 0.00674	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79622	 81387	 0.010589	 0.053566	 0.00093	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79622	 81618	 0.014973	 0.066721	 0.00113	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79625	 80607	 0.11733	 0.39157	 0.00621	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79628	 80205	 0.029781	 0.2478	 0.00469	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79630	 79631	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79630	 79631	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79633	 79634	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79633	 79634	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79633	 81319	 0.005192	 0.049856	 0.0145	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79635	 81057	 0.033582	 0.1292	 0.00221	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79638	 79639	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79638	 79639	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79638	 81053	 0.011822	 0.076171	 0.01997	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79639	 81052	 0.49554	 0.38876	 0.00499	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79640	 79641	 0.000318	 0.023855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79640	 79641	 0.000318	 0.023855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79642	 79643	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79642	 79643	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79644	 79645	 0.000127	 0.01012	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79644	 79645	 0.000127	 0.01012	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79644	 81750	 0.000329	 0.003547	 0.00704	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79644	 81750	 0.000329	 0.003547	 0.00704	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79644	 81790	 0.000558	 0.008751	 0.02905	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79646	 79647	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79646	 79647	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79648	 79649	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79648	 79649	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79650	 79651	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79650	 79651	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79650	 81739	 0.003026	 0.028828	 0.10539	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79652	 79653	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79652	 79653	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79653	 81794	 0.003479	 0.013929	 0.00351	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79654	 79655	 0.00019	 0.015181	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79654	 79655	 0.00019	 0.015181	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79656	 79657	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79656	 79657	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79656	 81857	 0.004312	 0.055907	 0.02213	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79658	 79659	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79658	 79659	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79661	 79662	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79661	 79662	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79661	 81790	 0.00103	 0.011565	 0.02116	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79661	 81790	 0.00103	 0.011565	 0.02116	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79662	 79663	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79662	 79663	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79664	 79665	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79664	 79665	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79666	 80005	 0.005281	 0.021145	 0.00533	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79667	 81825	 0.001399	 0.014825	 0.0044	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79667	 81827	 0.003589	 0.030188	 0.00894	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79669	 81821	 0.69316	 0.54945	 0.00692	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79670	 81845	 0.00069	 0.010937	 0.00692	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79671	 81837	 0.14324	 0.47814	 0.00759	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79672	 81794	 0.018748	 0.049553	 0.0116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79674	 81848	 0.006006	 0.02123	 0.00478	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79676	 79677	 0.015792	 0.038653	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79686	 79687	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79686	 79687	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79687	 79688	 9.5e-05	 0.007575	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79690	 79691	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79691	 79693	 0.00484	 0.033223	 0.00061	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79697	 79703	 0.011023	 0.032414	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79698	 79699	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79698	 79699	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79698	 79952	 0.007268	 0.064405	 0.01715	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79699	 79710	 0.01979	 0.056158	 0.00088	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79705	 79706	 0.003248	 0.023373	 0.00077	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79706	 79708	 0.014187	 0.05068	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79708	 79947	 0.022465	 0.12372	 0.00279	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79710	 79715	 0.015046	 0.050192	 0.0008	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79714	 79716	 0.018519	 0.06178	 0.00098	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79717	 79718	 0.034552	 0.063285	 0.00109	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79717	 79947	 0.01234	 0.054682	 0.00164	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79717	 80044	 0.048719	 0.2996	 0.0054	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79730	 80222	 0.047836	 0.1519	 0.00266	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79732	 79733	 0.006636	 0.017058	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79740	 79784	 0.005268	 0.013963	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79742	 79743	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79743	 79778	 0.001709	 0.009716	 0.00018	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79750	 79751	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79750	 79791	 0.000351	 0.002541	 0.00137	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79754	 79755	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79756	 79757	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79757	 79799	 0.005184	 0.01374	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79762	 79768	 0.014952	 0.029603	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79762	 80166	 0.012314	 0.054254	 0.00094	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79763	 79795	 0.008382	 0.015353	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79769	 79771	 0.003975	 0.020108	 0.00035	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79781	 79782	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79783	 79787	 0.002136	 0.009558	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79784	 79786	 0.008247	 0.016329	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79791	 79792	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79793	 79795	 0.005894	 0.03154	 0.00096	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79797	 79798	 9.7e-05	 0.007785	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79800	 79801	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79801	 79802	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79805	 81817	 0.054661	 0.31081	 0.00563	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79806	 79807	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79812	 79813	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79813	 79821	 0.02155	 0.071889	 0.00114	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79816	 80138	 0.027309	 0.090121	 0.00146	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79817	 79820	 0.005389	 0.033129	 0.0006	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79819	 79820	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79820	 79822	 0.009358	 0.038244	 0.00077	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79821	 79822	 0.006233	 0.020791	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79821	 79832	 0.010138	 0.057629	 0.00104	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79824	 79825	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79826	 79827	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79827	 79831	 0.05274	 0.099679	 0.00161	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79828	 79836	 0.007598	 0.025347	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79830	 79839	 0.005811	 0.01749	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79837	 79838	 0.009033	 0.027187	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79837	 79846	 0.02278	 0.069958	 0.00131	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79839	 79840	 0.005714	 0.023721	 0.00062	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79840	 79841	 0.012611	 0.033425	 0.00085	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79842	 79851	 0.01103	 0.038618	 0.00107	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79842	 80041	 0.071171	 0.055788	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79844	 79849	 0.010375	 0.027499	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79846	 79849	 0.022098	 0.035272	 0.00081	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79850	 79896	 0.014501	 0.04159	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79850	 80041	 0.015438	 0.094913	 0.00171	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79851	 80128	 0.00448	 0.025485	 0.00078	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79851	 80201	 0.012887	 0.079187	 0.00181	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79853	 80032	 0.020195	 0.060785	 0.00119	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79853	 80260	 0.066603	 0.052207	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79854	 79857	 0.007315	 0.021511	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79857	 79858	 0.011635	 0.017824	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79860	 79861	 0.008379	 0.015346	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79860	 79866	 0.048296	 0.045291	 0.0007	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79865	 79866	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79869	 79870	 0.03102	 0.047047	 0.00067	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79869	 79871	 0.005744	 0.032652	 0.00059	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79870	 79942	 0.22976	 0.18186	 0.00229	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79872	 79874	 0.11856	 0.23478	 0.00345	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79872	 80023	 0.031219	 0.15235	 0.00263	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79877	 79880	 0.005618	 0.022959	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79877	 79882	 0.035621	 0.02819	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79877	 79883	 0.006223	 0.015997	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79877	 79909	 0.020088	 0.064687	 0.0011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79879	 79880	 0.010346	 0.026596	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79881	 79883	 0.00694	 0.026698	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79881	 79906	 0.076536	 0.062997	 0.00128	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79884	 79888	 0.004084	 0.018196	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79884	 79912	 0.010241	 0.025067	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79887	 79889	 0.007516	 0.025074	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79891	 79892	 0.000105	 0.008384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79894	 80261	 0.002226	 0.012524	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79898	 79899	 0.006126	 0.023568	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79899	 79900	 0.031179	 0.022939	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79902	 79913	 0.005458	 0.039897	 0.00074	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79904	 79905	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79904	 79907	 0.000359	 0.005655	 0.00193	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79907	 79908	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79910	 79911	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79912	 80271	 0.004023	 0.027612	 0.0005	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79916	 80282	 0.013429	 0.034521	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79917	 79918	 0.002452	 0.010927	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79918	 79919	 0.013112	 0.01537	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79919	 79920	 0.00177	 0.009947	 0.00018	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79921	 80279	 0.007647	 0.036896	 0.00065	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79925	 79926	 0.031311	 0.080489	 0.00125	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79927	 79963	 0.007911	 0.04634	 0.01262	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79928	 79931	 0.11508	 0.22788	 0.00335	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79929	 79930	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79933	 80034	 0.009836	 0.047242	 0.00091	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79934	 79942	 0.022834	 0.10588	 0.0022	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79936	 79938	 0.018155	 0.046671	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79937	 79938	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79944	 79989	 0.008964	 0.045038	 0.01172	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79948	 79949	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79950	 79951	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79952	 79953	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79955	 80026	 0.01328	 0.10089	 0.0023	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79957	 79958	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79958	 79959	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79960	 79962	 0.008016	 0.060901	 0.00139	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79962	 81278	 0.12949	 0.25643	 0.00376	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79963	 79967	 0.007902	 0.031638	 0.00797	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79963	 81455	 0.017193	 0.11081	 0.02907	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79967	 79968	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79967	 81431	 0.01556	 0.10443	 0.02523	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79969	 81456	 0.037108	 0.119	 0.00294	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79969	 81456	 0.037108	 0.119	 0.00294	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79972	 80208	 0.18559	 0.16633	 0.0034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79974	 79975	 0.00019	 0.015181	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79975	 79976	 0.072749	 0.16715	 0.00254	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79976	 79977	 0.023187	 0.11131	 0.00333	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79982	 79983	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79983	 79984	 0.036095	 0.091797	 0.00145	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79985	 79988	 0.08515	 0.067388	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79986	 79987	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79987	 79990	 0.007739	 0.027646	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79987	 79990	 0.007739	 0.027646	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79988	 80047	 0.13293	 0.10071	 0.00139	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79989	 79990	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79992	 79993	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79994	 79995	 0.037922	 0.074322	 0.00111	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79995	 79996	 0.03279	 0.10821	 0.00175	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79998	 79999	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79998	 79999	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79999	 80000	 9.8e-05	 0.007812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80003	 80004	 0.000105	 0.008384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80007	 80012	 0.011635	 0.030837	 0.00078	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80012	 80017	 0.11815	 0.093503	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80012	 80027	 0.025842	 0.086207	 0.00137	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80015	 80020	 0.026862	 0.077045	 0.00118	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80016	 80024	 0.011821	 0.067198	 0.00122	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80017	 80022	 0.019674	 0.038557	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80027	 80045	 0.14346	 0.25891	 0.00374	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80031	 80033	 0.004264	 0.018787	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80035	 80088	 0.032867	 0.10584	 0.0018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80036	 80037	 0.0066	 0.037519	 0.00068	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80037	 80087	 0.032518	 0.10848	 0.00172	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80038	 80039	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80040	 80041	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80041	 80042	 0.019424	 0.058462	 0.00114	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80043	 80129	 0.00682	 0.030391	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80044	 80045	 0.023305	 0.089659	 0.00153	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80044	 80045	 0.023305	 0.089659	 0.00153	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80046	 80082	 0.11176	 0.088452	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80049	 80050	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80052	 80053	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80054	 80070	 0.10235	 0.098892	 0.00144	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80056	 80069	 0.011818	 0.030378	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80058	 80059	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80062	 80066	 0.000101	 0.00137	 0.00471	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80062	 80080	 0.000391	 0.004165	 0.00755	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80064	 80065	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80065	 80068	 0.002017	 0.012391	 0.00028	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80066	 80067	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80074	 80108	 0.016443	 0.04358	 0.00111	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80075	 80076	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80076	 80078	 0.044275	 0.034705	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80077	 80116	 0.012419	 0.031924	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80078	 80079	 0.009653	 0.02445	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80080	 80081	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80080	 80121	 0.001869	 0.012134	 0.02417	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80081	 80082	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80081	 80084	 0.005613	 0.01891	 0.0047	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80083	 80084	 0.001733	 0.00578	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80084	 80122	 0.004618	 0.016323	 0.00368	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80087	 80104	 0.033065	 0.094837	 0.00146	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80088	 80091	 0.007417	 0.024741	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80089	 80090	 0.00341	 0.013267	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80090	 80130	 0.008967	 0.034885	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80092	 80100	 0.009791	 0.046997	 0.0014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80097	 80098	 0.005714	 0.01906	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80099	 80100	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80100	 80101	 0.008289	 0.02108	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80100	 80191	 0.005726	 0.03153	 0.00071	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80102	 80105	 0.006917	 0.01778	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80103	 80104	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80104	 80110	 0.010477	 0.020299	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80104	 80112	 0.007661	 0.025557	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80111	 80115	 0.017654	 0.034954	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80116	 80120	 0.032721	 0.021183	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80118	 80119	 0.003579	 0.005712	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80118	 80123	 0.010188	 0.018943	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80121	 80122	 8.3e-05	 0.006605	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80122	 80123	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80126	 81151	 0.011943	 0.036676	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80129	 80133	 0.00195	 0.010433	 0.00032	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80130	 80201	 0.014132	 0.068962	 0.00119	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80131	 80132	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80132	 80133	 0.005015	 0.024072	 0.00072	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80135	 80183	 0.034026	 0.097594	 0.0015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80137	 80138	 0.001548	 0.011137	 0.00037	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80139	 80140	 0.01313	 0.037657	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80143	 80147	 0.024433	 0.048376	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80144	 80145	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80145	 80148	 0.050456	 0.03955	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80146	 80149	 0.033067	 0.04346	 0.0006	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80150	 80158	 0.015042	 0.034922	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80151	 81099	 0.010717	 0.047954	 0.00099	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80154	 80156	 0.052158	 0.033767	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80154	 80157	 0.02566	 0.025917	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80154	 81487	 0.020488	 0.058762	 0.0009	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80159	 80160	 0.023512	 0.018607	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80161	 80163	 0.007244	 0.014342	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80162	 80163	 0.015577	 0.012327	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80165	 80167	 0.00767	 0.025311	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80166	 80173	 0.004903	 0.011693	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80167	 80172	 0.00991	 0.028122	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80167	 80173	 0.00624	 0.020093	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80168	 80169	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80170	 80172	 0.01011	 0.023227	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80171	 80172	 0.003784	 0.025671	 0.00048	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80177	 80189	 0.007631	 0.029801	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80180	 80181	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80187	 80188	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80188	 80189	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80195	 80196	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80198	 80201	 0.020441	 0.068189	 0.00108	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80199	 80200	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80199	 80200	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80200	 80201	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80200	 80201	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80206	 80225	 0.034623	 0.18597	 0.00442	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80210	 80211	 0.005819	 0.027132	 0.00062	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80215	 80216	 0.007862	 0.023873	 0.00523	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80216	 80217	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80220	 81759	 0.005981	 0.030053	 0.00782	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80221	 80222	 0.008168	 0.046431	 0.00084	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80223	 80225	 0.056298	 0.12934	 0.00196	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80233	 80234	 0.002721	 0.007804	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80235	 80281	 0.002893	 0.017785	 0.00032	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80236	 80237	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80239	 80240	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80244	 80254	 0.007294	 0.028375	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80246	 80247	 0.003934	 0.010006	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80248	 80252	 0.003015	 0.007991	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80252	 80254	 0.004226	 0.010747	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80253	 80254	 0.022778	 0.018026	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80256	 80257	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80256	 80257	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80257	 80258	 8.9e-05	 0.007142	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80257	 80268	 0.003101	 0.020803	 0.00502	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80265	 80269	 0.002896	 0.01988	 0.00036	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80268	 80269	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80269	 80270	 0.005244	 0.017494	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80272	 80273	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80285	 80286	 0.004792	 0.021112	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80288	 80295	 0.022734	 0.081216	 0.00161	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80289	 80296	 0.01145	 0.060313	 0.00108	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80292	 80293	 0.021451	 0.071561	 0.00113	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80293	 80364	 0.16956	 0.12476	 0.00182	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80295	 80826	 0.080438	 0.23074	 0.00355	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80296	 80794	 0.069856	 0.12796	 0.00221	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80300	 80301	 0.044164	 0.14575	 0.00236	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80300	 80882	 0.050631	 0.22311	 0.00388	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80305	 80306	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80305	 80976	 0.002157	 0.030154	 0.01022	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80307	 80308	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80308	 80745	 0.32109	 0.23632	 0.00346	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80308	 80979	 0.035	 0.24028	 0.00438	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80313	 80608	 0.067226	 0.20627	 0.00559	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80316	 80390	 0.15239	 0.30179	 0.00443	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80329	 80330	 0.01173	 0.045129	 0.00077	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80331	 80653	 0.098371	 0.255	 0.00482	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80332	 80653	 0.034269	 0.13597	 0.00388	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80332	 80654	 0.084056	 0.25795	 0.00699	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80340	 80704	 0.016158	 0.091849	 0.00166	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80341	 80349	 0.007429	 0.045672	 0.00082	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80341	 80711	 0.005269	 0.04847	 0.00096	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80350	 80354	 0.02941	 0.10507	 0.00209	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80354	 80355	 0.043325	 0.10059	 0.0015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80358	 80359	 0.030742	 0.071371	 0.00106	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80359	 80783	 0.1878	 0.31646	 0.00451	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80361	 80362	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80362	 80363	 0.034457	 0.13257	 0.00226	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80363	 80364	 0.069545	 0.23203	 0.00368	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80365	 80373	 0.010907	 0.057454	 0.00103	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80367	 80370	 0.008275	 0.036875	 0.00063	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80368	 80370	 0.007697	 0.022076	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80369	 80370	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80371	 80372	 9.4e-05	 0.007517	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80372	 80373	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80374	 80375	 0.008441	 0.053004	 0.00116	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80375	 80376	 0.009023	 0.046921	 0.00102	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80379	 80638	 0.00891	 0.03502	 0.00916	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80382	 80383	 0.029566	 0.12641	 0.00286	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80383	 80607	 0.098319	 0.25279	 0.00391	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80389	 80872	 0.04203	 0.11643	 0.00192	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80389	 84867	 0.071652	 0.16636	 0.00247	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80394	 80395	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80395	 80642	 0.35706	 0.30538	 0.00572	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80399	 80400	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80400	 80401	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80404	 80407	 0.003714	 0.021111	 0.00038	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80404	 80426	 0.017226	 0.039992	 0.00059	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80405	 80406	 0.005096	 0.024876	 0.00052	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80406	 80411	 0.039524	 0.073491	 0.00172	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80407	 80408	 0.014576	 0.029954	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80408	 80416	 0.005455	 0.015645	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80409	 80411	 0.03941	 0.031188	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80410	 80411	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80412	 80873	 0.088865	 0.29652	 0.0047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80415	 80418	 0.044305	 0.05823	 0.0008	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80415	 80421	 0.079258	 0.18211	 0.00277	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80415	 80835	 0.017197	 0.11669	 0.00218	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80416	 80424	 0.015067	 0.032288	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80419	 80420	 7.8e-05	 0.006228	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80420	 80421	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80421	 80609	 0.057443	 0.18958	 0.00307	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80431	 80511	 0.021971	 0.087168	 0.00249	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80433	 80434	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80433	 80571	 0.001056	 0.014931	 0.00495	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80436	 80437	 0.005229	 0.020342	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80437	 80439	 0.018532	 0.034459	 0.00081	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80438	 80439	 0.005356	 0.024833	 0.00052	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80439	 80443	 0.011408	 0.047362	 0.00123	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80440	 80443	 0.015971	 0.057054	 0.00113	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80441	 80443	 0.026215	 0.086512	 0.0014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80442	 80443	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80442	 80445	 0.005281	 0.031694	 0.0096	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80445	 80446	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80446	 80447	 0.046575	 0.12345	 0.00313	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80450	 80874	 0.12464	 0.15473	 0.00337	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80455	 80460	 0.018939	 0.017761	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80455	 80464	 0.038869	 0.029815	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80456	 80457	 0.014343	 0.015775	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80458	 80459	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80458	 80475	 0.006203	 0.023578	 0.0066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80464	 80466	 0.060979	 0.044865	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80466	 80467	 0.040933	 0.032393	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80466	 80546	 0.23442	 0.18555	 0.00234	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80470	 80795	 0.11915	 0.094297	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80472	 80473	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80474	 80475	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80476	 80477	 8.5e-05	 0.006812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80477	 80478	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80485	 80493	 0.018225	 0.036083	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80490	 80491	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80490	 80499	 0.000226	 0.002677	 0.00911	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80491	 80492	 0.007022	 0.027016	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80491	 80497	 0.010068	 0.048576	 0.00086	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80494	 80512	 0.014199	 0.036499	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80495	 80513	 0.023361	 0.039353	 0.00056	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80496	 80497	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80497	 80997	 0.070155	 0.34246	 0.00591	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80499	 80500	 0.000109	 0.008719	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80501	 80508	 0.018656	 0.056151	 0.0011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80502	 80503	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80505	 80506	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80507	 80508	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80508	 80583	 0.035669	 0.11771	 0.00191	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80517	 80519	 0.069558	 0.19741	 0.0031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80517	 80975	 0.090111	 0.17843	 0.00262	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80518	 80520	 0.038434	 0.12822	 0.00203	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80519	 80520	 0.014978	 0.075308	 0.00205	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80523	 80524	 0.042125	 0.06389	 0.00092	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80530	 80531	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80534	 80535	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80534	 80723	 0.001993	 0.011676	 0.00318	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80542	 80546	 0.066159	 0.17491	 0.00318	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80544	 80545	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80545	 80953	 0.01727	 0.058196	 0.01447	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80549	 80560	 0.045751	 0.029619	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80551	 80554	 0.005384	 0.016206	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80552	 80559	 0.007699	 0.017874	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80552	 80563	 0.00856	 0.028249	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80553	 80554	 0.003812	 0.013616	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80553	 80554	 0.003812	 0.013616	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80554	 80555	 0.005	 0.016501	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80555	 80557	 0.03327	 0.036593	 0.00049	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80556	 80557	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80558	 80559	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80558	 80562	 0.001595	 0.006489	 0.00158	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80562	 80563	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80563	 80565	 0.00495	 0.021257	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80568	 80584	 0.016989	 0.048728	 0.00075	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80569	 80830	 0.011275	 0.033155	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80571	 80572	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80578	 80579	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80578	 80579	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80582	 80583	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80587	 80826	 0.046592	 0.15544	 0.00246	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80589	 80591	 0.015728	 0.055032	 0.00114	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80589	 80591	 0.015728	 0.055032	 0.00114	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80589	 81417	 0.19701	 0.65801	 0.01045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80593	 80633	 0.045999	 0.15346	 0.00243	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80594	 80632	 0.043211	 0.12707	 0.00261	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80594	 80930	 0.099741	 0.15922	 0.00367	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80597	 80930	 0.051753	 0.08261	 0.0019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80598	 80641	 0.22856	 0.18091	 0.00228	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80607	 80608	 0.037066	 0.14261	 0.00243	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80614	 80615	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80618	 80619	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80624	 80893	 0.046914	 0.22525	 0.00673	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80625	 80658	 0.015767	 0.12146	 0.00232	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80625	 80895	 0.042081	 0.21886	 0.00475	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80626	 80627	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80628	 80631	 0.032619	 0.11143	 0.00242	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80634	 80649	 0.28913	 0.22888	 0.00288	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80637	 80752	 0.064544	 0.16593	 0.00257	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80638	 80639	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80640	 80641	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80645	 80647	 0.0238	 0.092592	 0.00155	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80653	 80655	 0.024356	 0.091369	 0.00164	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80653	 80655	 0.024356	 0.091369	 0.00164	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80657	 80659	 0.040262	 0.13432	 0.00213	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80657	 80660	 0.072608	 0.16858	 0.00251	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80667	 80669	 0.006523	 0.016767	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80667	 80674	 0.0078	 0.037438	 0.00112	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80670	 80676	 0.018704	 0.053646	 0.00082	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80677	 80718	 0.008532	 0.052455	 0.00095	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80678	 80683	 0.01911	 0.037837	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80678	 80685	 0.004788	 0.026939	 0.00058	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80680	 80719	 0.012254	 0.027122	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80682	 80683	 0.007544	 0.021638	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80682	 80686	 0.009938	 0.023533	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80685	 80718	 0.019669	 0.050563	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80687	 80688	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80689	 80690	 0.000174	 0.013916	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80690	 80696	 0.002638	 0.012873	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80691	 80692	 9.4e-05	 0.007517	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80692	 80693	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80693	 80732	 0.009181	 0.044297	 0.00078	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80694	 80695	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80700	 80701	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80702	 80705	 0.008013	 0.030829	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80703	 80704	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80704	 80738	 0.017374	 0.046049	 0.00117	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80708	 80709	 0.003485	 0.02508	 0.00082	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80713	 80714	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80717	 80718	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80717	 80727	 0.002593	 0.014277	 0.00515	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80718	 80719	 0.004372	 0.026876	 0.00048	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80719	 80720	 0.005136	 0.015773	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80723	 80724	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80725	 80726	 0.019752	 0.032378	 0.00057	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80726	 80744	 0.011542	 0.030591	 0.00078	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80727	 80728	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80732	 80734	 0.002914	 0.027458	 0.00058	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80733	 80734	 0.007968	 0.024468	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80735	 80736	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80739	 80741	 0.005389	 0.039027	 0.00098	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80740	 80741	 0.025067	 0.059358	 0.00109	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80743	 80744	 0.000182	 0.014521	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80743	 84825	 0.000802	 0.012783	 0.02624	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80743	 87065	 0.002489	 0.016391	 0.03172	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80757	 80759	 0.025798	 0.14666	 0.00265	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80759	 80760	 0.023407	 0.1043	 0.00177	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80762	 80778	 0.007927	 0.045059	 0.00082	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80764	 80765	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80765	 80769	 0.027951	 0.02212	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80765	 80770	 0.01077	 0.019358	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80765	 80776	 0.024803	 0.096493	 0.00161	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80766	 80767	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80766	 80767	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80767	 80768	 8.9e-05	 0.007142	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80771	 80772	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80771	 80773	 0.00233	 0.007849	 0.00195	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80774	 80775	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80776	 80777	 0.01022	 0.023727	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80785	 80788	 0.019905	 0.11315	 0.00205	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80786	 80787	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80791	 80792	 0.091163	 0.072147	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80798	 80805	 0.053202	 0.17558	 0.00284	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80799	 80800	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80806	 80808	 0.034445	 0.098794	 0.00152	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80812	 80818	 0.024181	 0.12988	 0.00308	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80821	 80823	 0.012039	 0.066299	 0.0015	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80822	 80823	 0.008482	 0.046417	 0.00091	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80827	 80828	 0.013894	 0.095372	 0.00174	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80829	 80830	 0.011731	 0.036027	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80837	 80839	 0.049355	 0.16861	 0.00367	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80841	 80842	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80843	 80878	 0.019646	 0.052748	 0.01196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80844	 80849	 0.036226	 0.12085	 0.00192	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80846	 80847	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80849	 80851	 0.10874	 0.1196	 0.0016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80850	 80851	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80852	 80853	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80858	 80859	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80858	 80860	 0.002311	 0.01244	 0.00342	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80860	 80861	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80863	 80864	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80865	 80866	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80868	 80869	 8.2e-05	 0.006578	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80870	 80872	 0.066813	 0.071352	 0.00151	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80871	 80872	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80877	 80878	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80878	 80879	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80883	 80884	 0.009984	 0.044673	 0.00092	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80888	 80889	 0.052749	 0.048587	 0.00078	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80889	 81341	 0.08081	 0.26963	 0.00427	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80890	 80987	 0.021193	 0.082449	 0.00138	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80892	 80893	 0.000136	 0.010869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80894	 80895	 0.014273	 0.094326	 0.00186	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80898	 80899	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80899	 80903	 0.016722	 0.065053	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80904	 80905	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80905	 80906	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80908	 80910	 0.018101	 0.070419	 0.00118	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80920	 80921	 0.025292	 0.071771	 0.00113	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80922	 80973	 0.018368	 0.042642	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80923	 80967	 0.028832	 0.074116	 0.00115	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80924	 80925	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80927	 80928	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80928	 80929	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80936	 80937	 0.003189	 0.021891	 0.0004	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80938	 80939	 0.033006	 0.043379	 0.00059	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	80940	 80941	 0.000136	 0.010869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80944	 80946	 0.01856	 0.042446	 0.00104	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80946	 80947	 0.089783	 0.06887	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	80948	 80949	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80950	 80955	 0.010771	 0.029796	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80951	 80952	 0.007909	 0.018359	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80952	 80957	 0.009847	 0.019496	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80952	 80959	 0.014256	 0.063527	 0.00108	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	80953	 80954	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80963	 80964	 0.011668	 0.029995	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80966	 80967	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80967	 80969	 0.010948	 0.05833	 0.00102	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	80971	 80972	 0.010107	 0.069378	 0.00126	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80978	 80979	 0.016812	 0.042756	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	80982	 80983	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80987	 80988	 0.024373	 0.096699	 0.00276	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80989	 80990	 0.009202	 0.056576	 0.00102	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80993	 80994	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80994	 80995	 0.01577	 0.060421	 0.00171	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80999	 81000	 0.041101	 0.19833	 0.0035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81001	 81217	 0.28292	 0.22183	 0.00285	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81002	 81339	 0.074041	 0.22741	 0.00427	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81002	 81494	 0.003014	 0.027724	 0.00055	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81004	 81005	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81007	 81008	 0.031045	 0.17097	 0.00386	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81007	 81350	 0.046298	 0.1712	 0.00317	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81007	 81350	 0.046298	 0.1712	 0.00317	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81007	 81352	 0.10271	 0.27232	 0.00691	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81008	 81080	 0.058946	 0.33519	 0.00607	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81009	 81332	 0.029024	 0.21771	 0.0044	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81011	 81012	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81016	 81023	 0.004871	 0.018012	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81017	 81020	 0.00313	 0.010079	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81019	 81020	 0.003462	 0.009929	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81020	 81022	 0.001454	 0.006481	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81021	 81022	 0.002358	 0.005772	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81023	 81026	 0.005442	 0.009089	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81029	 81033	 0.002425	 0.009329	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81031	 81032	 0.001129	 0.005677	 0.00015	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81031	 81484	 0.011992	 0.023743	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81032	 81473	 0.006554	 0.021863	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81033	 81138	 0.00252	 0.010518	 0.0003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81036	 81037	 0.010722	 0.010829	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81036	 81038	 0.00152	 0.006735	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81036	 81485	 0.003313	 0.020366	 0.00037	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81039	 81485	 0.004559	 0.01172	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81041	 81042	 0.10241	 0.1841	 0.00331	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81044	 81045	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81044	 81664	 0.002047	 0.013289	 0.02647	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81047	 81562	 0.020709	 0.080564	 0.00134	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81058	 81194	 0.003916	 0.048266	 0.01559	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81061	 81562	 0.006663	 0.0355	 0.00062	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81062	 81225	 0.061002	 0.20352	 0.00323	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81063	 81064	 0.051255	 0.12138	 0.00222	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81070	 81077	 0.009966	 0.025619	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81079	 81080	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81082	 81085	 0.006488	 0.039885	 0.00072	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81083	 81646	 0.013743	 0.045846	 0.00073	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81084	 81347	 0.24696	 0.15992	 0.00304	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81087	 81334	 0.056054	 0.25087	 0.00517	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81090	 81091	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81090	 81095	 0.002214	 0.024919	 0.00721	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81094	 81095	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81094	 81337	 0.001491	 0.017308	 0.06153	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81098	 81453	 0.08096	 0.26723	 0.00433	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81099	 81109	 0.0291	 0.023029	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81102	 81119	 0.007052	 0.020227	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81103	 81477	 0.007533	 0.019364	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81104	 81483	 0.003451	 0.009146	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81109	 81110	 0.004999	 0.014186	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81114	 81187	 0.020324	 0.040239	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81117	 81127	 0.011701	 0.019542	 0.00033	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81118	 81124	 0.02779	 0.052522	 0.00085	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81118	 81133	 0.005946	 0.029015	 0.0005	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81119	 81140	 0.014075	 0.021962	 0.00037	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81120	 81122	 0.010365	 0.020313	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81120	 81187	 0.015762	 0.05005	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81121	 81122	 0.00769	 0.015226	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81123	 81124	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81125	 81129	 0.003441	 0.018415	 0.00056	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81128	 81129	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81130	 81131	 9.7e-05	 0.007785	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81130	 81131	 9.7e-05	 0.007785	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81131	 81132	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81131	 81132	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81134	 81136	 0.008077	 0.021351	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81135	 81149	 0.038181	 0.038564	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81136	 81141	 0.063753	 0.050454	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81137	 81138	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81138	 81142	 0.001955	 0.011714	 0.00028	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81141	 81480	 0.021006	 0.03752	 0.00055	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81142	 81472	 0.005175	 0.011454	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81145	 81146	 0.005226	 0.025085	 0.00075	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81146	 81170	 0.057692	 0.11307	 0.00169	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81151	 81155	 0.008001	 0.040474	 0.0007	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81154	 81529	 0.005975	 0.019932	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81157	 81158	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81158	 81162	 0.013834	 0.022676	 0.0004	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81158	 81164	 0.005405	 0.025046	 0.00048	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81161	 81162	 0.01057	 0.019654	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81161	 81169	 0.006651	 0.030838	 0.00064	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81162	 81165	 0.004134	 0.020675	 0.00037	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81167	 81168	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81168	 81169	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81170	 81171	 0.023955	 0.031484	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81172	 81173	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81172	 81303	 0.009364	 0.032121	 0.0077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81173	 81177	 0.016042	 0.053514	 0.00085	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81173	 81310	 0.009458	 0.031553	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81173	 81312	 0.041942	 0.075678	 0.00109	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81178	 81179	 0.0175	 0.012651	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81178	 81180	 0.003574	 0.010965	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81180	 81181	 0.00176	 0.008446	 0.00025	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81182	 81184	 0.079956	 0.063277	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81183	 81184	 0.014181	 0.018048	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81192	 81193	 0.17335	 0.1597	 0.00256	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81198	 81199	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81198	 81199	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81200	 81201	 8.3e-05	 0.006605	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81201	 81204	 0.00426	 0.045153	 0.0134	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81201	 81734	 0.014271	 0.10098	 0.02773	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81202	 81703	 0.003012	 0.024042	 0.00593	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81203	 81205	 0.018497	 0.046854	 0.00093	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81203	 81447	 0.16226	 0.1272	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81204	 81205	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81204	 81708	 0.015251	 0.085114	 0.02175	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81205	 81207	 0.024794	 0.082711	 0.00131	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81206	 81207	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81207	 81704	 0.020895	 0.055382	 0.0014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81211	 81465	 0.12097	 0.13177	 0.00179	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81211	 81467	 0.040854	 0.094849	 0.00141	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81212	 81318	 0.025711	 0.21392	 0.00405	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81213	 81227	 0.26515	 0.26789	 0.00355	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81216	 81217	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81217	 81340	 0.12089	 0.25912	 0.00454	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81226	 81227	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81228	 81250	 0.051154	 0.051668	 0.00068	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81229	 81230	 0.017641	 0.046634	 0.00085	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81229	 81249	 0.020778	 0.068569	 0.00111	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81231	 81254	 0.019745	 0.056631	 0.00087	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81232	 81239	 0.017655	 0.045385	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81234	 81245	 0.040863	 0.080086	 0.0012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81235	 81237	 0.010365	 0.036269	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81239	 81244	 0.008564	 0.04812	 0.00089	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81240	 81241	 0.005075	 0.022491	 0.00068	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81241	 81242	 0.002176	 0.011593	 0.0002	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81246	 81247	 0.004257	 0.014202	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81246	 81252	 0.013744	 0.045849	 0.00073	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81247	 81248	 0.008436	 0.028142	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81247	 81249	 0.009036	 0.030144	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81248	 81251	 0.052018	 0.038272	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81253	 81255	 0.008681	 0.023009	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81253	 81256	 0.012403	 0.03809	 0.00071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81254	 81255	 0.002495	 0.013399	 0.00032	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81257	 81260	 0.012074	 0.02245	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81259	 81260	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81262	 81263	 0.011467	 0.050524	 0.00088	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81264	 81268	 0.011281	 0.054428	 0.00096	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81266	 81267	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81268	 81269	 0.023885	 0.0614	 0.00095	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81273	 81699	 0.064413	 0.050976	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81274	 81275	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81275	 81276	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81276	 81470	 0.16815	 0.13842	 0.0028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81277	 81280	 0.024321	 0.16696	 0.00304	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81277	 81281	 0.046516	 0.18097	 0.00302	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81277	 81281	 0.046516	 0.18097	 0.00302	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81287	 81288	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81291	 81292	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81293	 81296	 0.071714	 0.046428	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81295	 81296	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81295	 81301	 0.001205	 0.007478	 0.00181	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81297	 81298	 0.016635	 0.030015	 0.00043	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81298	 81302	 0.022037	 0.042697	 0.00092	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81299	 81300	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81302	 81304	 0.01691	 0.039259	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81303	 81304	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81304	 81307	 0.010583	 0.04663	 0.00081	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81304	 81312	 0.016429	 0.043545	 0.0011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81314	 81315	 0.001696	 0.018357	 0.00773	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81317	 81339	 0.16806	 0.33285	 0.00489	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81319	 81320	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81322	 81324	 0.010126	 0.031097	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81323	 81326	 0.014283	 0.0697	 0.0012	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81323	 81328	 0.011772	 0.061215	 0.00133	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81325	 81326	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81328	 81619	 0.025588	 0.089592	 0.00248	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81330	 81332	 0.043181	 0.1512	 0.00419	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81331	 81696	 0.028481	 0.14408	 0.00251	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81332	 81696	 0.045569	 0.251	 0.00567	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81335	 81351	 0.05968	 0.15468	 0.00292	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81337	 81338	 8.8e-05	 0.007032	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81338	 81339	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81340	 81392	 0.039374	 0.12503	 0.00219	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81344	 81346	 0.021319	 0.10408	 0.00218	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81346	 81519	 0.014344	 0.04619	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81356	 81362	 0.004614	 0.015393	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81357	 81358	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81360	 81361	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81361	 81362	 0.004066	 0.015644	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81364	 81365	 0.000109	 0.008719	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81367	 81432	 0.001276	 0.018758	 0.00574	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81371	 81372	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81375	 81385	 0.002841	 0.014281	 0.00039	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81376	 81380	 0.008587	 0.033036	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81376	 81380	 0.008587	 0.033036	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81377	 81378	 9.1e-05	 0.007266	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81377	 81378	 9.1e-05	 0.007266	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81378	 81379	 0.000136	 0.010869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81378	 81379	 0.000136	 0.010869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81380	 81383	 0.017493	 0.053663	 0.00145	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81384	 81385	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81386	 81462	 0.041588	 0.18222	 0.00392	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81386	 81619	 0.019284	 0.12443	 0.00396	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81389	 81656	 0.014581	 0.038647	 0.00098	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81390	 81649	 0.022336	 0.037626	 0.00054	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81392	 81549	 0.071017	 0.22872	 0.0039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81394	 81410	 0.07237	 0.17139	 0.00313	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81395	 81396	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81399	 81400	 0.04851	 0.19828	 0.00401	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81402	 81411	 0.047067	 0.22598	 0.00676	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81407	 81408	 8.3e-05	 0.006605	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81408	 81409	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81409	 81704	 0.1331	 0.43949	 0.00712	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81411	 81413	 0.13003	 0.33081	 0.00523	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81412	 81414	 0.013058	 0.10864	 0.00206	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81412	 81464	 0.13489	 0.27729	 0.00529	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81415	 81417	 0.045027	 0.17518	 0.00292	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81418	 81419	 0.088521	 0.062705	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81420	 81424	 0.000305	 0.003364	 0.00639	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81420	 81424	 0.000305	 0.003364	 0.00639	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81422	 81531	 0.056388	 0.094993	 0.00135	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81423	 81534	 0.014476	 0.044456	 0.00083	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81424	 81425	 0.000105	 0.008384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81426	 81427	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81431	 81532	 0.004879	 0.029995	 0.00865	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81432	 81437	 0.002345	 0.013447	 0.00447	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81435	 81436	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81437	 81438	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81440	 81441	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81441	 81531	 0.050678	 0.095783	 0.00155	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81443	 81444	 0.02684	 0.12884	 0.00385	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81445	 81786	 0.12778	 0.16631	 0.00233	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81445	 81800	 0.085189	 0.076338	 0.00156	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81447	 81448	 0.029367	 0.075492	 0.00117	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81449	 81450	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81450	 81451	 0.014595	 0.10018	 0.00183	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81455	 81456	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81457	 81458	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81457	 87731	 0.011499	 0.10838	 0.41534	 731.0	 767.5	 804.1	 0.0	 0.0	 0	 -30.0	 30.0;
	81457	 95343	 0.002572	 0.02563	 0.08557	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81458	 81459	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81461	 81609	 0.012028	 0.064087	 0.00112	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81465	 81584	 0.019324	 0.037872	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81466	 81467	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81469	 81699	 0.013928	 0.062064	 0.00105	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81471	 81476	 0.002927	 0.010457	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81472	 81473	 0.002268	 0.007566	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81473	 81474	 0.004353	 0.01128	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81475	 81476	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81478	 81479	 9.7e-05	 0.007785	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81479	 81480	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81482	 81483	 0.007731	 0.029744	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81488	 81489	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81489	 81490	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81491	 81492	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81495	 81496	 7e-05	 0.005589	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81495	 81664	 0.0026	 0.032558	 0.1327	 871.0	 914.6	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81496	 81497	 0.000104	 0.008333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81498	 81599	 0.051205	 0.034396	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81499	 81505	 0.01277	 0.024134	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81499	 81600	 0.0138	 0.029005	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81501	 81502	 0.007388	 0.022688	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81502	 81504	 0.009865	 0.029692	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81503	 81504	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81504	 81506	 0.005196	 0.035667	 0.00065	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81504	 81508	 0.033981	 0.049516	 0.00112	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81513	 81616	 0.028114	 0.022249	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81514	 81515	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81516	 81610	 0.041117	 0.029125	 0.00046	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81518	 81519	 0.004889	 0.024449	 0.00044	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81521	 81522	 0.006101	 0.020354	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81527	 81528	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81531	 81534	 0.008912	 0.02973	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81533	 81534	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81535	 81536	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81540	 81541	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81541	 81542	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81542	 81543	 0.011449	 0.044046	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81543	 81547	 0.00708	 0.020306	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81550	 81551	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81554	 81564	 0.015283	 0.031276	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81555	 81556	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81559	 81560	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81560	 81561	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81563	 81564	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81565	 81569	 0.008035	 0.030913	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81573	 81582	 0.003961	 0.01292	 0.00343	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81574	 81576	 0.01192	 0.023601	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81575	 81581	 0.057368	 0.037141	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81576	 81583	 0.032216	 0.025252	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81577	 81578	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81579	 81581	 0.044908	 0.03554	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81579	 81584	 0.030672	 0.023527	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81582	 81583	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81586	 81587	 0.060569	 0.059264	 0.00084	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81591	 81592	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81598	 81599	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81605	 81606	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81606	 81607	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81608	 81609	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81616	 81617	 0.009103	 0.021134	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81625	 81630	 0.006393	 0.014842	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81625	 81645	 0.005536	 0.024667	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81626	 81627	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81628	 81629	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81630	 81634	 0.001303	 0.012126	 0.00023	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81633	 81634	 0.00358	 0.018109	 0.00032	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81635	 81641	 0.004095	 0.018043	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81639	 81645	 0.002182	 0.013416	 0.00024	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81640	 81645	 0.0342	 0.027065	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81643	 81644	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81648	 81649	 0.00737	 0.028672	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81648	 81656	 0.005485	 0.021339	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81651	 81652	 0.007612	 0.020175	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81651	 81655	 0.010189	 0.025808	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81651	 81661	 0.00659	 0.035262	 0.00107	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81652	 81653	 0.00723	 0.016785	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81652	 81656	 0.005065	 0.019703	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81652	 81657	 0.002464	 0.016912	 0.00031	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81659	 81660	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81660	 81661	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81663	 81665	 0.002901	 0.011614	 0.00293	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81664	 81665	 9.1e-05	 0.007266	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81664	 81665	 9.1e-05	 0.007266	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81665	 81666	 0.000136	 0.010869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81665	 81666	 0.000136	 0.010869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81666	 81698	 0.036247	 0.12382	 0.00269	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81666	 81698	 0.036247	 0.12382	 0.00269	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81667	 81669	 0.15727	 0.12447	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81668	 81669	 0.025279	 0.077632	 0.00146	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81670	 81672	 0.038811	 0.12948	 0.00205	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81673	 81674	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81677	 81689	 0.039097	 0.030941	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81681	 81686	 0.009752	 0.025846	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81685	 81686	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81696	 81698	 0.00655	 0.02457	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81696	 81698	 0.00655	 0.02457	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81702	 81703	 0.00074	 0.006225	 0.00184	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81703	 81704	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81708	 81709	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81709	 81754	 0.04967	 0.13166	 0.00334	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81710	 81758	 0.008696	 0.030307	 0.00703	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81713	 81714	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81717	 81718	 0.001896	 0.016149	 0.00403	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81718	 81719	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81718	 82005	 0.001314	 0.017237	 0.00827	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81720	 81722	 0.005655	 0.032148	 0.00058	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81721	 81723	 0.003474	 0.023844	 0.00043	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81723	 81724	 0.00282	 0.016898	 0.00041	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81726	 81841	 0.24253	 0.31887	 0.00437	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81727	 81728	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81727	 81818	 0.019267	 0.069778	 0.01498	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81731	 81732	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81732	 81858	 0.9359	 0.74288	 0.00935	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81733	 81813	 0.026589	 0.1616	 0.00298	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81733	 81840	 0.10501	 0.40873	 0.00683	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81734	 81803	 0.004803	 0.046121	 0.01342	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81737	 82020	 0.007431	 0.044521	 0.00107	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81738	 84107	 0.008324	 0.060137	 0.00114	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81739	 81740	 7.2e-05	 0.005736	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81740	 81741	 0.000108	 0.00862	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81742	 81743	 0.006101	 0.02084	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81742	 81746	 0.021988	 0.07855	 0.00156	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81745	 81746	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81747	 81748	 0.000101	 0.008064	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81751	 81752	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81754	 81755	 0.028417	 0.065286	 0.00099	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81756	 81757	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81762	 81774	 0.003297	 0.022632	 0.00041	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81763	 81764	 9.4e-05	 0.007517	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81763	 81773	 0.001038	 0.006739	 0.01342	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81764	 81765	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81765	 81779	 0.01355	 0.083303	 0.0015	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81771	 81772	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81773	 81774	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81775	 81776	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81777	 81778	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81783	 81784	 0.3149	 0.22773	 0.00345	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81785	 81786	 0.028366	 0.15114	 0.00265	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81793	 82036	 0.003283	 0.012773	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81793	 82036	 0.003283	 0.012773	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81794	 81795	 9.5e-05	 0.007575	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81794	 81848	 0.016911	 0.044696	 0.01046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81794	 82035	 0.001134	 0.017848	 0.00951	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81798	 82013	 0.002988	 0.049992	 0.02835	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81799	 81834	 0.13074	 0.25891	 0.0038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81807	 81810	 0.026057	 0.051591	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81812	 81827	 0.00389	 0.040658	 0.01369	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81815	 81816	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81819	 83553	 0.006648	 0.025861	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81819	 83553	 0.006648	 0.025861	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81824	 81826	 0.034007	 0.089906	 0.02105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81828	 81829	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81831	 81837	 0.02851	 0.095109	 0.00151	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81832	 81840	 0.095615	 0.16108	 0.00229	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81833	 81834	 0.025936	 0.12663	 0.00265	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81836	 81837	 0.01469	 0.058786	 0.00124	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81836	 81858	 0.24738	 0.49014	 0.0072	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81843	 81844	 0.012404	 0.047723	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81843	 81844	 0.012404	 0.047723	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81848	 81849	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81852	 81853	 0.006863	 0.024516	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81860	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81859	 81860	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81859	 81862	 0.080337	 0.20899	 0.05085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81872	 0.028973	 0.16993	 0.04637	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81873	 0.059269	 0.13774	 0.04201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81894	 0.015508	 0.15228	 0.13299	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81898	 0.065297	 0.23695	 0.05099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81900	 0.026736	 0.15352	 0.05113	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81906	 0.019467	 0.06679	 0.01601	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81913	 0.026166	 0.18481	 0.10557	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81921	 0.049845	 0.1295	 0.03146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81861	 81862	 0.000109	 0.008705	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81861	 81862	 0.000109	 0.008705	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81862	 81863	 0.00012	 0.009615	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81862	 81863	 0.00012	 0.009615	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81864	 81865	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81864	 81865	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81866	 81867	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81866	 81867	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81867	 81868	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81867	 81868	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81868	 81899	 0.1917	 0.44532	 0.00849	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81868	 81901	 0.46447	 0.6485	 0.0111	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81868	 81918	 0.62417	 0.45188	 0.00685	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81868	 82153	 0.69939	 0.53082	 0.00731	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81868	 82155	 0.28679	 0.56837	 0.00835	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81869	 81870	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81869	 81870	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81869	 81911	 0.00188	 0.004881	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81869	 82232	 0.006202	 0.034157	 0.01233	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81870	 81912	 0.027381	 0.021462	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81870	 82566	 0.030641	 0.18624	 0.00344	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81870	 82685	 0.038116	 0.090915	 0.00204	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81871	 81872	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81871	 81872	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81873	 81874	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81873	 81874	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81875	 81876	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81875	 81876	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81876	 82633	 0.081479	 0.31707	 0.00529	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81878	 81879	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81878	 81879	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81879	 82125	 0.13075	 0.30364	 0.00452	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81879	 82661	 0.096411	 0.15391	 0.00355	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81881	 81882	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81881	 81882	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81883	 81884	 0.000128	 0.010206	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81883	 81884	 0.000128	 0.010206	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81884	 81885	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81884	 81885	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81884	 82156	 0.00016	 0.002542	 0.00161	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81885	 82157	 0.004081	 0.014578	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81885	 82157	 0.004081	 0.014578	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81885	 82599	 0.55237	 0.43759	 0.00551	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81886	 81887	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81886	 81887	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81887	 82499	 0.033005	 0.065347	 0.00096	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81888	 81906	 0.000191	 0.001563	 0.00042	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81889	 82347	 0.006456	 0.039235	 0.00072	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81889	 82354	 0.006452	 0.044286	 0.00081	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81890	 81891	 0.000116	 0.009249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81890	 81891	 0.000116	 0.009249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81891	 81892	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81891	 81892	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81892	 82157	 0.008545	 0.026242	 0.00049	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81895	 82116	 0.002734	 0.027633	 0.00813	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81895	 82552	 0.004722	 0.02903	 0.00837	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81896	 82309	 0.11297	 0.12426	 0.00166	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81896	 82310	 0.061181	 0.15728	 0.00243	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81897	 82347	 0.00931	 0.03622	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81897	 82347	 0.00931	 0.03622	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81898	 81899	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81898	 81899	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81899	 82153	 0.1134	 0.32536	 0.00501	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81900	 81901	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81900	 81901	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81900	 82154	 0.004942	 0.029663	 0.00898	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81902	 81903	 0.000116	 0.009249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81902	 81903	 0.000116	 0.009249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81904	 82314	 0.009732	 0.038965	 0.00982	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81905	 82702	 0.00116	 0.003979	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81908	 81909	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81908	 81909	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81908	 82116	 0.001451	 0.020952	 0.00665	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81910	 82364	 0.012009	 0.027464	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81910	 82364	 0.012009	 0.027464	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81911	 81912	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81911	 81912	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81911	 82231	 0.016803	 0.081568	 0.01865	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81913	 81914	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81913	 81914	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81914	 82398	 0.05585	 0.12774	 0.00312	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81917	 81918	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81917	 81918	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81917	 82246	 0.002097	 0.02157	 0.00612	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81917	 82247	 0.007263	 0.02175	 0.0049	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81918	 82333	 0.13832	 0.3519	 0.00557	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81919	 81920	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81919	 81920	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81919	 82715	 0.004684	 0.035624	 0.0112	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81920	 82321	 0.28309	 0.3686	 0.00516	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81923	 82550	 0.077478	 0.063773	 0.00129	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81924	 82213	 0.019692	 0.032841	 0.00048	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81924	 82214	 0.007883	 0.030203	 0.00085	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81925	 82708	 0.002162	 0.00915	 0.00206	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81925	 82713	 0.003112	 0.010484	 0.00261	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81926	 82404	 0.014145	 0.080407	 0.00145	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81928	 82159	 0.060036	 0.26757	 0.00455	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81929	 81930	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81929	 81930	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81930	 81931	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81930	 81931	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81932	 81933	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81932	 81933	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81933	 82770	 0.001723	 0.010706	 0.00302	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81935	 81936	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81935	 81936	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81936	 81962	 7.3e-05	 0.000793	 0.00025	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81937	 81938	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81937	 81938	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81937	 83087	 0.003888	 0.015565	 0.00392	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81938	 83086	 0.027826	 0.078963	 0.00124	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81939	 81940	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81939	 81940	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81943	 83248	 0.008502	 0.021856	 0.00541	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81944	 81945	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81944	 81945	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81944	 83449	 0.001075	 0.003114	 0.00075	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81945	 83374	 0.025589	 0.019628	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81945	 83495	 0.011412	 0.010296	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81945	 83495	 0.011412	 0.010296	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81946	 81947	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81946	 81947	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81947	 82804	 0.057375	 0.15168	 0.00275	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81948	 83158	 0.02991	 0.045819	 0.00064	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81949	 81951	 0.000143	 0.001611	 0.00047	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81951	 83096	 0.00461	 0.066562	 0.02114	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81952	 81953	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81952	 81953	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81953	 83358	 0.000788	 0.004096	 9e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81955	 81956	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81955	 81956	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81955	 83487	 0.000615	 0.002391	 0.00064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81957	 81958	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81957	 81958	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81958	 83110	 0.075419	 0.055489	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81959	 81960	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81959	 81960	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81960	 81961	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81960	 81961	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81962	 81963	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81962	 81963	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81962	 83018	 0.01175	 0.05703	 0.01304	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81963	 83295	 0.026056	 0.048448	 0.00113	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81964	 81965	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81964	 81965	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81967	 83087	 0.000396	 0.003181	 0.00089	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81968	 81986	 0.00353	 0.020063	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81968	 81991	 0.014555	 0.031191	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81968	 83234	 0.042929	 0.17546	 0.00355	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81969	 81970	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81969	 81970	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81970	 83238	 0.001522	 0.014165	 0.00027	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81972	 81973	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81972	 81973	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81972	 82926	 0.003264	 0.013067	 0.00329	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81976	 83101	 0.011656	 0.045343	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81978	 83329	 0.082601	 0.064747	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81981	 83231	 0.078407	 0.18205	 0.00271	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81983	 81984	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81983	 81984	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81984	 82887	 0.016373	 0.078996	 0.00139	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81984	 82896	 0.037821	 0.16665	 0.00289	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81985	 83498	 0.009986	 0.013612	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81989	 81990	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81989	 81990	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81990	 82812	 0.047438	 0.16948	 0.00337	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81990	 82812	 0.047438	 0.16948	 0.00337	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81991	 83233	 0.016088	 0.03735	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81993	 82735	 0.044917	 0.10273	 0.00251	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81993	 82736	 0.019158	 0.036207	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81993	 82738	 0.027379	 0.072376	 0.00131	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81993	 82922	 0.070006	 0.16012	 0.00391	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81996	 81997	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81996	 81997	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81997	 81998	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81997	 81998	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81999	 84140	 0.001956	 0.018776	 0.00546	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81999	 84142	 0.000543	 0.009081	 0.00515	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82000	 82001	 9.2e-05	 0.007399	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82000	 82001	 9.2e-05	 0.007399	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82003	 82004	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82003	 82004	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82003	 82007	 0.004674	 0.033813	 0.01819	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82003	 83500	 0.004968	 0.057621	 0.0308	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82003	 84449	 0.033409	 0.10903	 0.02897	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82005	 82035	 0.005491	 0.06634	 0.03764	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82005	 83547	 0.009101	 0.057649	 0.01565	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82006	 82007	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82006	 82007	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82008	 82009	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82008	 82009	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82008	 83813	 0.002972	 0.014166	 0.0041	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82009	 84087	 0.08436	 0.25888	 0.00701	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82013	 84385	 0.042862	 0.1772	 0.042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82015	 82016	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82015	 82016	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82015	 84374	 0.014659	 0.044517	 0.00975	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82016	 82091	 0.27895	 0.20529	 0.003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82017	 82018	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82017	 82018	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82018	 84269	 0.013402	 0.091999	 0.00168	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82019	 82020	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82019	 82020	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82021	 82022	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82021	 82022	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82021	 84353	 0.005789	 0.036668	 0.00995	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82021	 84377	 0.025253	 0.11959	 0.02878	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82021	 84600	 0.016424	 0.069525	 0.01565	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82022	 84605	 0.03107	 0.17485	 0.00378	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82023	 82024	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82023	 82024	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82023	 84631	 0.008228	 0.022401	 0.00494	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82025	 82026	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82025	 82026	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82026	 82027	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82026	 82027	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82028	 83657	 0.01513	 0.05887	 0.01573	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82028	 84358	 0.008146	 0.056521	 0.01613	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82029	 84208	 0.014215	 0.056885	 0.0012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82030	 84251	 0.013091	 0.052387	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82030	 84564	 0.003558	 0.032726	 0.00065	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82031	 84133	 0.00023	 0.002481	 0.00133	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82032	 82033	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82032	 82033	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82032	 84063	 0.001519	 0.022734	 0.00764	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82033	 83635	 0.021587	 0.050117	 0.00075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82035	 82036	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82035	 82036	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82036	 83553	 0.029533	 0.20274	 0.0037	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82037	 83581	 0.002378	 0.006474	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82038	 84382	 0.003609	 0.023597	 0.006	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82039	 82047	 0.000174	 0.001355	 3e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82039	 84308	 0.021099	 0.082081	 0.00137	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82040	 82041	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82040	 82041	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82040	 83573	 0.002524	 0.012447	 0.00337	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82040	 83583	 0.001578	 0.009469	 0.00287	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82041	 83584	 0.015013	 0.038908	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82042	 82043	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82042	 82043	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82043	 84168	 0.010999	 0.075501	 0.00138	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82043	 84170	 0.006663	 0.037907	 0.00117	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82044	 82045	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82044	 82045	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82044	 84176	 0.000737	 0.011006	 0.00326	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82044	 84191	 0.000234	 0.003381	 0.00138	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82045	 83829	 0.076532	 0.19676	 0.00305	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82045	 84171	 0.017399	 0.045092	 0.00085	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82046	 82047	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82046	 82047	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82046	 84302	 0.000212	 0.002454	 0.00131	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82047	 84309	 0.04083	 0.080841	 0.00119	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82048	 84583	 0.002365	 0.011029	 0.00273	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82048	 84584	 0.005228	 0.013571	 0.00329	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82049	 83682	 0.005766	 0.013248	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82049	 83685	 0.002487	 0.013101	 0.00024	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82049	 83693	 0.002974	 0.012153	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82050	 82596	 0.049638	 0.17382	 0.00481	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82051	 84141	 0.01615	 0.046319	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82053	 84624	 0.10194	 0.28935	 0.00455	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82054	 83676	 0.013387	 0.010594	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82055	 83565	 0.004645	 0.01285	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82057	 84569	 0.028484	 0.06745	 0.00123	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82059	 84427	 0.077374	 0.055934	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82060	 83604	 0.0098	 0.02014	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82062	 82063	 0.07501	 0.059363	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82063	 82318	 0.059543	 0.13619	 0.00332	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82066	 82067	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82066	 82093	 0.001011	 0.007465	 0.00215	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82068	 82069	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82068	 82076	 0.00062	 0.003929	 0.00107	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82074	 82102	 0.011423	 0.020531	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82076	 82077	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82082	 82098	 0.057151	 0.04704	 0.00095	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82082	 82722	 0.065163	 0.25355	 0.00423	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82082	 82723	 0.026727	 0.15194	 0.00275	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82083	 82086	 0.015307	 0.024433	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82084	 82085	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82085	 82102	 0.009537	 0.017733	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82089	 82090	 0.010034	 0.039036	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82091	 84373	 0.099463	 0.25573	 0.00396	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82093	 82094	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82101	 82102	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82103	 82104	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82103	 82105	 0.001306	 0.005228	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82103	 82111	 0.00695	 0.023842	 0.00571	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82104	 82110	 0.010418	 0.024186	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82104	 82113	 0.17489	 0.13842	 0.00174	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82105	 82106	 0.00252	 0.006861	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82107	 82110	 0.07146	 0.054815	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82109	 82110	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82111	 82112	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82114	 82115	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82117	 82242	 0.072754	 0.20648	 0.00324	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82118	 82119	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82119	 82544	 0.11351	 0.25967	 0.00634	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82120	 82413	 0.007794	 0.018092	 0.00551	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82121	 82414	 0.024754	 0.063634	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82122	 82332	 0.013575	 0.076275	 0.00141	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82122	 82398	 0.17602	 0.50522	 0.00778	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82123	 82132	 0.003779	 0.03241	 0.00922	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82126	 82127	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82128	 82716	 0.044115	 0.14717	 0.00233	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82130	 82132	 0.007409	 0.029665	 0.00747	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82131	 82132	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82131	 82132	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82132	 82133	 0.007858	 0.030887	 0.00808	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82134	 82135	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82134	 82136	 0.001589	 0.004325	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82136	 82137	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82138	 82222	 0.01931	 0.064416	 0.00102	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82140	 82141	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82141	 82142	 0.013675	 0.054723	 0.00116	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82143	 82633	 0.071924	 0.16451	 0.00402	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82144	 82145	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82146	 82656	 0.071801	 0.26941	 0.00484	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82147	 82148	 0.035136	 0.027806	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82150	 82275	 0.084753	 0.16782	 0.00246	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82150	 82561	 0.28082	 0.28373	 0.00376	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82151	 82152	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82152	 82277	 0.055151	 0.184	 0.00292	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82156	 82157	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82158	 82598	 0.25819	 0.24954	 0.00362	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82161	 82162	 0.098926	 0.19589	 0.00288	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82163	 82164	 0.02568	 0.12991	 0.00226	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82165	 82166	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82166	 82167	 0.007206	 0.037959	 0.00068	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82166	 82554	 0.065836	 0.18684	 0.00294	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82169	 82170	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82173	 82174	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82174	 82175	 0.007731	 0.015821	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82179	 82180	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82179	 82183	 0.0049	 0.019618	 0.00494	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82180	 82594	 0.064446	 0.2857	 0.00858	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82182	 82183	 0.003716	 0.014123	 0.00395	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82183	 82184	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82185	 82186	 0.015477	 0.07829	 0.00136	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82189	 82192	 0.009542	 0.024529	 0.00607	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82190	 82562	 0.077805	 0.30276	 0.00506	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82191	 82192	 0.00316	 0.011494	 0.00352	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82193	 82336	 0.31091	 0.22883	 0.00335	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82193	 82513	 0.10632	 0.26938	 0.00534	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82196	 82559	 0.012159	 0.032136	 0.00752	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82198	 82199	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82198	 82199	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82199	 82623	 0.003774	 0.012948	 0.0031	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82200	 82210	 0.031229	 0.034348	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82201	 82203	 0.010993	 0.023105	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82201	 82204	 0.016201	 0.037612	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82202	 82203	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82206	 82207	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82211	 82213	 0.004605	 0.026179	 0.00047	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82212	 82213	 0.1008	 0.10979	 0.00149	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82212	 82214	 0.15808	 0.11631	 0.0017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82213	 82215	 0.013753	 0.073596	 0.00223	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82216	 82222	 0.042275	 0.033456	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82218	 82219	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82221	 82222	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82222	 82223	 0.024014	 0.068877	 0.00106	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82222	 82226	 0.006324	 0.042911	 0.0008	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82223	 82226	 0.02009	 0.042224	 0.00077	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82223	 82227	 0.015075	 0.10348	 0.00189	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82224	 82225	 0.004347	 0.019369	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82224	 82226	 0.01483	 0.034429	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82229	 82231	 0.01135	 0.038243	 0.0095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82234	 82523	 0.47249	 0.36272	 0.00487	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82234	 82586	 0.043778	 0.30058	 0.00548	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82235	 82521	 0.013724	 0.03563	 0.00865	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82240	 82241	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82240	 82243	 0.002117	 0.014977	 0.00411	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82241	 82245	 0.01627	 0.045007	 0.00105	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82243	 82244	 0.003257	 0.008456	 0.00205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82244	 82245	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82245	 82406	 0.067133	 0.19052	 0.00299	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82247	 82248	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82248	 82564	 0.15427	 0.44272	 0.00681	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82250	 82251	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82252	 82262	 0.021612	 0.061987	 0.00095	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82253	 82254	 0.002167	 0.010256	 0.00247	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82255	 82256	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82256	 82264	 0.049057	 0.064476	 0.00088	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82257	 82258	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82257	 82438	 0.005325	 0.02922	 0.00772	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82261	 82262	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82262	 82264	 0.002907	 0.02266	 0.00042	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82263	 82264	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82265	 82266	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82268	 82269	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82270	 82414	 0.015779	 0.036086	 0.00088	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82270	 82421	 0.007323	 0.024429	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82271	 82272	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82272	 82634	 0.098041	 0.15651	 0.00361	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82274	 82275	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82276	 82277	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82278	 82279	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82280	 82281	 0.000134	 0.010687	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82280	 82281	 0.000134	 0.010687	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82282	 82288	 0.18304	 0.1849	 0.00245	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82284	 82285	 0.023697	 0.046918	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82287	 82548	 0.069526	 0.070225	 0.00093	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82288	 82590	 0.064425	 0.16698	 0.00316	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82289	 82290	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82293	 82296	 0.062002	 0.049068	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82295	 82296	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82298	 82299	 0.014922	 0.075931	 0.00172	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82298	 82301	 0.017032	 0.06626	 0.00111	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82298	 82301	 0.017032	 0.06626	 0.00111	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82299	 82301	 0.015783	 0.10834	 0.00198	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82300	 82301	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82300	 82302	 0.001166	 0.011783	 0.00346	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82302	 82700	 0.002068	 0.031597	 0.01018	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82306	 82307	 0.025585	 0.12228	 0.00268	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82309	 82588	 0.030918	 0.1901	 0.00343	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82311	 82314	 0.014651	 0.038724	 0.00906	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82312	 82313	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82313	 82717	 0.047812	 0.15951	 0.00253	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82314	 82315	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82315	 82717	 0.029454	 0.19261	 0.00446	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82316	 82317	 0.006713	 0.043246	 0.01134	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82316	 82320	 0.01112	 0.030276	 0.00667	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82317	 82318	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82318	 82319	 0.02993	 0.099848	 0.00158	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82320	 82321	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82329	 82330	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82330	 82331	 0.044722	 0.11497	 0.00178	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82330	 82503	 0.042927	 0.056419	 0.00077	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82331	 82549	 0.07196	 0.19025	 0.00345	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82338	 82339	 0.014511	 0.056451	 0.00094	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82339	 82340	 0.040457	 0.093914	 0.00179	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82341	 82559	 0.017171	 0.095318	 0.02899	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82341	 82699	 0.022632	 0.076271	 0.01896	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82343	 82554	 0.073895	 0.22697	 0.00426	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82344	 82345	 0.10602	 0.083904	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82346	 82347	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82346	 82350	 0.000699	 0.007496	 0.00195	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82348	 82349	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82349	 82357	 0.016885	 0.028445	 0.00041	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82350	 82351	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82353	 82356	 0.004158	 0.015597	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82353	 82356	 0.004158	 0.015597	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82355	 82356	 0.007937	 0.030878	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82355	 82356	 0.007937	 0.030878	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82359	 82367	 0.006532	 0.018736	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82360	 82361	 0.033183	 0.024414	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82361	 82362	 0.012231	 0.022403	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82363	 82364	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82365	 82366	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82366	 82367	 0.00744	 0.036305	 0.00063	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82371	 82372	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82372	 82378	 0.041779	 0.05491	 0.00075	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82372	 82380	 0.002983	 0.022162	 0.00053	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82374	 82375	 0.007795	 0.022356	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82377	 82380	 0.016598	 0.079324	 0.00174	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82379	 82380	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82386	 82387	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82386	 82574	 0.001811	 0.020998	 0.01122	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82388	 82389	 0.00224	 0.009248	 0.00219	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82389	 82772	 0.002567	 0.023353	 0.00589	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82391	 82392	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82394	 82395	 0.005853	 0.034135	 0.00069	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82396	 82579	 0.062141	 0.17635	 0.00277	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82397	 82630	 0.23601	 0.16721	 0.00264	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82398	 82541	 0.10533	 0.13844	 0.0019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82399	 82536	 0.039798	 0.1221	 0.00331	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82400	 82401	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82401	 82541	 0.28962	 0.22927	 0.00289	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82407	 82408	 0.030108	 0.15231	 0.00265	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82412	 82413	 0.000123	 0.009866	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82412	 82413	 0.000123	 0.009866	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82412	 82413	 0.000123	 0.009866	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82414	 82425	 0.01373	 0.039378	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82416	 82417	 0.018727	 0.031231	 0.00045	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82417	 82430	 0.010466	 0.054424	 0.00118	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82423	 82439	 0.016129	 0.045771	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82428	 82435	 0.004476	 0.017411	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82429	 82434	 0.02912	 0.031026	 0.00044	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82430	 82433	 0.016757	 0.016925	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82433	 82434	 0.011223	 0.029667	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82434	 82435	 0.006373	 0.01828	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82434	 82461	 0.007914	 0.020344	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82435	 82490	 0.029107	 0.082599	 0.0013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82436	 82437	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82436	 82438	 0.001244	 0.006482	 0.0017	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82437	 82439	 0.009346	 0.022292	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82438	 82439	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82439	 82508	 0.009094	 0.044379	 0.00077	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82441	 82442	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82441	 82454	 0.00256	 0.008539	 0.00217	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82443	 82444	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82451	 82509	 0.000519	 0.001973	 0.00055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82452	 82456	 0.041625	 0.030091	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82453	 82454	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82453	 82454	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82454	 82455	 0.000969	 0.007076	 0.00182	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82457	 82458	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82457	 82458	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82458	 82487	 0.001063	 0.006847	 0.00179	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82459	 82509	 0.0004	 0.002967	 0.00152	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82462	 82466	 0.004354	 0.012488	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82464	 82465	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82464	 82468	 0.001204	 0.003278	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82468	 82510	 0.001749	 0.005893	 0.00146	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82469	 82480	 0.016148	 0.031971	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82470	 82478	 0.011918	 0.013108	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82473	 82474	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82475	 82476	 0.002645	 0.006991	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82476	 82477	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82478	 82485	 0.017219	 0.033746	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82480	 82511	 0.006199	 0.01778	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82482	 82483	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82482	 82486	 0.004665	 0.016257	 0.00377	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82483	 82500	 0.028326	 0.02084	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82484	 82485	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82484	 82486	 0.000846	 0.004913	 0.00116	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82493	 82494	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82495	 82500	 0.029221	 0.052725	 0.00076	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82497	 82504	 0.027244	 0.051491	 0.00083	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82505	 82506	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82510	 82511	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82512	 82513	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82513	 82519	 0.074058	 0.19039	 0.00295	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82513	 82631	 0.027635	 0.10793	 0.00239	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82514	 82626	 0.30673	 0.22181	 0.00336	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82515	 82516	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82516	 82519	 0.019027	 0.073203	 0.00125	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82516	 82519	 0.019027	 0.073203	 0.00125	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82517	 82518	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82521	 82522	 0.013418	 0.03373	 0.00874	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82521	 82524	 0.012636	 0.043349	 0.01039	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82522	 82523	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82522	 82524	 0.00132	 0.008629	 0.00219	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82523	 82525	 0.007118	 0.034732	 0.0006	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82525	 82526	 0.012266	 0.021571	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82528	 82531	 0.047714	 0.037761	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82530	 82535	 0.079155	 0.051246	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82532	 82535	 0.067214	 0.047612	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82534	 82535	 0.043793	 0.044233	 0.00059	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82537	 82538	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82538	 82563	 0.093395	 0.18493	 0.00271	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82540	 82541	 0.065298	 0.14935	 0.00365	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82542	 82544	 0.14273	 0.14022	 0.00237	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82543	 82566	 0.40055	 0.31716	 0.00399	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82545	 82546	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82552	 82553	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82555	 82556	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82557	 82558	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82557	 82559	 0.001885	 0.008592	 0.00273	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82560	 82561	 0.04847	 0.10387	 0.00182	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82563	 82564	 0.05142	 0.13219	 0.00205	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82567	 82685	 0.034378	 0.1532	 0.0026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82567	 82686	 0.070142	 0.11816	 0.00168	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82568	 82569	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82571	 82572	 0.016142	 0.086376	 0.00262	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82580	 82581	 0.081019	 0.16042	 0.00235	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82585	 82586	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82585	 82587	 0.008682	 0.041094	 0.00988	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82585	 82644	 0.018529	 0.048107	 0.01168	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82586	 82588	 0.057055	 0.14453	 0.00286	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82587	 82588	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82588	 82716	 0.1511	 0.27684	 0.00478	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82590	 82591	 0.21826	 0.17276	 0.00218	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82593	 82594	 0.019373	 0.10668	 0.00241	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82593	 82596	 0.029724	 0.13246	 0.00225	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82595	 82597	 0.039978	 0.10361	 0.00196	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82602	 82604	 0.007584	 0.01389	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82602	 82619	 0.019035	 0.048932	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82604	 82613	 0.03301	 0.050561	 0.00088	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82608	 82609	 0.003275	 0.010046	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82610	 82611	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82613	 82627	 0.025118	 0.041891	 0.00061	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82615	 82623	 0.006131	 0.017098	 0.00359	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82617	 82618	 0.001112	 0.016341	 0.005	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82617	 82629	 0.009027	 0.060569	 0.01462	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82619	 82781	 0.037265	 0.06698	 0.0012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82623	 82624	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82624	 82625	 0.058651	 0.043152	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82624	 82626	 0.025346	 0.057966	 0.00142	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82629	 82630	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82636	 82640	 0.009153	 0.035609	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82636	 82641	 0.007906	 0.049645	 0.00109	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82638	 82640	 0.006148	 0.020509	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82639	 82640	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82655	 82656	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82660	 82661	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82660	 82663	 0.002237	 0.014984	 0.00942	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82663	 82664	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82666	 82667	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82669	 82670	 0.008384	 0.016601	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82671	 82672	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82672	 82675	 0.035713	 0.025816	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82674	 82681	 0.036861	 0.055263	 0.001	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82677	 82678	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82679	 82681	 0.021119	 0.039268	 0.00092	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82680	 82681	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82682	 82683	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82686	 82688	 0.024376	 0.069913	 0.00108	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82687	 82688	 0.084614	 0.056839	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82689	 82695	 0.005661	 0.011584	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82691	 82692	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82692	 82693	 0.013911	 0.030788	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82694	 82696	 0.009074	 0.023327	 0.00578	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82698	 82699	 0.007185	 0.035428	 0.00958	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82698	 82700	 0.007934	 0.043693	 0.01578	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82699	 82701	 0.004401	 0.023697	 0.00651	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82704	 82705	 0.034679	 0.068662	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82707	 82710	 0.012552	 0.028705	 0.0007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82709	 82710	 0.014232	 0.046965	 0.00076	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82712	 82713	 0.00418	 0.014341	 0.00344	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82713	 82714	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82716	 82717	 0.044713	 0.13718	 0.00372	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82724	 82725	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82727	 82729	 0.01174	 0.040273	 0.00965	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82732	 83317	 0.057931	 0.092472	 0.00213	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82734	 82735	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82736	 82737	 0.026172	 0.047937	 0.00083	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82737	 82738	 0.019313	 0.063732	 0.00103	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82737	 82739	 0.026391	 0.068399	 0.00129	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82739	 82745	 0.32616	 0.30059	 0.00482	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82740	 82741	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82741	 83254	 0.016777	 0.04812	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82743	 82748	 0.42621	 0.43083	 0.00571	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82745	 82984	 0.12378	 0.23399	 0.00379	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82746	 83276	 0.079801	 0.19535	 0.00334	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82748	 83276	 0.090589	 0.2329	 0.00361	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82750	 82751	 0.022506	 0.064549	 0.00099	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82751	 82753	 0.017284	 0.040127	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82751	 82754	 0.02116	 0.10157	 0.00304	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82752	 82753	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82758	 83080	 0.093118	 0.31072	 0.00493	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82759	 82760	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82760	 82763	 0.045177	 0.035412	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82761	 82762	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82762	 82763	 0.020004	 0.022002	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82763	 82765	 0.10043	 0.093451	 0.00177	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82764	 82765	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82765	 82773	 0.075141	 0.29239	 0.00488	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82768	 82769	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82770	 82771	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82770	 82774	 0.00408	 0.029519	 0.01588	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82772	 82773	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82772	 82774	 0.003274	 0.021407	 0.00544	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82774	 82775	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82780	 82781	 0.10176	 0.08053	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82783	 82786	 0.021187	 0.14544	 0.00265	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82785	 82786	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82787	 82794	 0.00313	 0.011182	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82801	 82802	 0.010621	 0.022761	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82802	 82886	 0.07567	 0.062284	 0.00126	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82803	 82886	 0.020497	 0.073223	 0.00145	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82805	 82806	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82820	 82821	 0.003918	 0.016583	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82822	 82826	 0.012925	 0.024032	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82822	 82842	 0.004668	 0.016332	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82824	 82825	 0.005376	 0.017935	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82825	 82834	 0.011608	 0.026946	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82825	 82863	 0.018257	 0.023995	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82828	 82831	 0.0141	 0.027916	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82828	 82865	 0.013766	 0.022564	 0.0004	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82829	 82852	 0.009688	 0.027491	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82830	 82864	 0.052456	 0.10386	 0.00152	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82831	 82834	 0.005314	 0.014048	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82832	 82849	 0.011293	 0.031282	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82833	 82848	 0.013387	 0.038395	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82834	 82864	 0.090567	 0.064155	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82837	 83290	 0.022674	 0.1134	 0.00202	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82839	 83290	 0.023767	 0.14604	 0.00334	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82843	 82856	 0.027388	 0.062637	 0.00153	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82844	 82856	 0.01618	 0.044202	 0.00075	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82845	 82846	 0.019198	 0.04457	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82846	 82858	 0.008376	 0.042372	 0.00074	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82846	 82862	 0.17389	 0.1334	 0.00179	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82848	 82857	 0.01453	 0.03735	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82853	 82863	 0.063859	 0.0645	 0.00085	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82854	 83289	 0.022056	 0.067734	 0.00127	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82855	 83280	 0.005448	 0.053983	 0.01654	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82858	 82859	 0.019202	 0.039295	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82858	 82864	 0.031343	 0.089898	 0.00138	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82862	 83003	 0.043421	 0.14486	 0.0023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82868	 82872	 0.061721	 0.063024	 0.00098	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82869	 82870	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82870	 82872	 0.010089	 0.044453	 0.00077	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82871	 82872	 0.014134	 0.032813	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82871	 82873	 0.012215	 0.024184	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82874	 82877	 0.090649	 0.24769	 0.00421	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82874	 82907	 0.021454	 0.13039	 0.00241	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82876	 83285	 0.068906	 0.17715	 0.00274	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82877	 83286	 0.041223	 0.12647	 0.00343	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82878	 82919	 0.030497	 0.15428	 0.00268	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82880	 82881	 0.017303	 0.053137	 0.001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82884	 82885	 0.006905	 0.012144	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82889	 82890	 0.006399	 0.028514	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82891	 82892	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82899	 83111	 0.04265	 0.12838	 0.00251	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82900	 82902	 0.055404	 0.1436	 0.00272	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82908	 82909	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82910	 82916	 0.005848	 0.026058	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82910	 82917	 0.048675	 0.035187	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82911	 82912	 0.020416	 0.015468	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82911	 82921	 0.014874	 0.010943	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82923	 82927	 0.036222	 0.02345	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82925	 82927	 0.087324	 0.085444	 0.00121	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82926	 82927	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82927	 82930	 0.083877	 0.065748	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82929	 82930	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82930	 83300	 0.49126	 0.38909	 0.0049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82930	 83302	 0.29655	 0.49996	 0.00713	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82931	 82939	 0.039282	 0.028397	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82932	 82939	 0.018976	 0.063302	 0.001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82936	 83318	 0.007854	 0.063551	 0.00164	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82937	 82938	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82941	 82947	 0.020208	 0.015992	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82943	 82945	 0.003732	 0.009594	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82944	 82945	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82945	 82947	 0.00605	 0.010048	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82946	 82947	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82951	 82952	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82951	 82964	 0.003703	 0.021278	 0.00603	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82953	 82954	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82957	 82961	 0.15676	 0.12407	 0.00156	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82958	 82959	 0.10168	 0.11184	 0.00149	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82960	 83127	 0.041743	 0.2866	 0.00523	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82962	 82963	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82964	 82965	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82969	 82970	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82969	 82973	 0.003684	 0.014481	 0.00379	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82973	 82974	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82974	 82981	 0.10276	 0.081325	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82974	 82984	 0.077627	 0.11892	 0.00167	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82975	 82980	 0.00792	 0.022474	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82976	 83246	 0.028143	 0.17304	 0.00312	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82985	 82987	 0.03372	 0.096716	 0.00149	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82987	 82991	 0.02274	 0.052007	 0.00127	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82988	 82989	 0.025089	 0.066324	 0.0012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82990	 82991	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82996	 82997	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82997	 82998	 0.030875	 0.032972	 0.0007	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83000	 83955	 0.5031	 0.37049	 0.00542	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83005	 83007	 0.10853	 0.14265	 0.00196	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83009	 83014	 0.029991	 0.17971	 0.00432	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83014	 83015	 0.011819	 0.041379	 0.00115	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83014	 83016	 0.008685	 0.038862	 0.0008	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83018	 83019	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83018	 83023	 0.002493	 0.0146	 0.00398	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83020	 83031	 0.080626	 0.1872	 0.00278	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83022	 83208	 0.025071	 0.044091	 0.00083	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83023	 83024	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83023	 83027	 0.008302	 0.032632	 0.00854	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83025	 83026	 0.005556	 0.014726	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83025	 83298	 0.013643	 0.060795	 0.00103	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83027	 83075	 0.018998	 0.052982	 0.01112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83033	 83052	 0.093022	 0.073618	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83034	 83039	 0.018222	 0.018405	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83034	 83041	 0.019657	 0.025581	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83035	 83037	 0.001819	 0.004953	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83037	 83075	 0.001729	 0.00525	 0.00115	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83038	 83039	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83038	 83075	 0.001438	 0.005012	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83040	 83041	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83041	 83046	 0.011556	 0.033144	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83043	 83044	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83045	 83046	 0.006419	 0.018409	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83046	 83206	 0.013781	 0.039526	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83048	 83052	 0.051094	 0.040436	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83049	 83051	 0.011131	 0.022037	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83049	 83057	 0.01692	 0.030412	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83056	 83057	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83057	 83059	 0.008835	 0.029155	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83062	 83066	 0.008568	 0.024573	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83062	 83079	 0.002767	 0.01328	 0.0004	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83064	 83065	 0.003507	 0.015627	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83064	 83202	 0.044365	 0.086949	 0.0013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83067	 83202	 0.063495	 0.069161	 0.00094	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83068	 83073	 0.041817	 0.030766	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83072	 83073	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83074	 83075	 9.2e-05	 0.007399	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83074	 83075	 9.2e-05	 0.007399	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83075	 83076	 0.000104	 0.008333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83075	 83076	 0.000104	 0.008333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83075	 83078	 0.001944	 0.012313	 0.00334	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83078	 83079	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83086	 83088	 0.081162	 0.11312	 0.00193	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83093	 83097	 0.051833	 0.04102	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83094	 83098	 0.046343	 0.030003	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83094	 83099	 0.028541	 0.054658	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83094	 83284	 0.050496	 0.19429	 0.00332	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83095	 83096	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83095	 83096	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83101	 83104	 0.021443	 0.041546	 0.00089	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83102	 83106	 0.12676	 0.13539	 0.00286	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83104	 83106	 0.07652	 0.077289	 0.00102	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83105	 83106	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83108	 84210	 0.062813	 0.040666	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83109	 83110	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83115	 83232	 0.073892	 0.20189	 0.00343	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83116	 83117	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83117	 83124	 0.012171	 0.059394	 0.00103	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83117	 83130	 0.018893	 0.048567	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83117	 83235	 0.041851	 0.25439	 0.00469	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83121	 83123	 0.086936	 0.058399	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83128	 83129	 0.16152	 0.12784	 0.00161	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83129	 83226	 0.1069	 0.30668	 0.00472	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83134	 83135	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83135	 83136	 0.033957	 0.049706	 0.00077	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83144	 83145	 0.049294	 0.088945	 0.00129	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83146	 83147	 0.039257	 0.043178	 0.00058	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83149	 83178	 0.059053	 0.046734	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83156	 83157	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83166	 83167	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83167	 83173	 0.033614	 0.04024	 0.00067	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83167	 83176	 0.015885	 0.061796	 0.00103	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83167	 83214	 0.019566	 0.038739	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83167	 83215	 0.016435	 0.042247	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83168	 83169	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83172	 83174	 0.050328	 0.039829	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83174	 83175	 0.025587	 0.025844	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83175	 83176	 0.012838	 0.025418	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83185	 83187	 0.034987	 0.024783	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83192	 83193	 0.042195	 0.030503	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83194	 83195	 0.024499	 0.044872	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83199	 83200	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83199	 83201	 0.001632	 0.004313	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83200	 83202	 0.018303	 0.018486	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83201	 83202	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83204	 83221	 0.041841	 0.033112	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83206	 83207	 0.047266	 0.037406	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83209	 83210	 0.049928	 0.039513	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83217	 83218	 0.002985	 0.016966	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83218	 83222	 0.007339	 0.028549	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83220	 83221	 0.00419	 0.023818	 0.00043	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83226	 83227	 0.023453	 0.12596	 0.00299	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83229	 83230	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83232	 83234	 0.14538	 0.20641	 0.0034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83238	 83239	 0.005474	 0.033656	 0.00061	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83240	 83241	 0.002647	 0.01705	 0.00447	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83241	 83242	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83251	 83252	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83252	 83253	 0.020287	 0.030751	 0.00064	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83252	 83254	 0.012252	 0.022781	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83253	 83254	 0.004782	 0.012641	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83256	 83257	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83257	 83258	 0.061314	 0.048061	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83257	 83272	 0.01661	 0.03816	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83258	 83262	 0.004591	 0.014723	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83260	 83274	 0.036658	 0.040319	 0.00054	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83260	 83281	 0.015869	 0.052939	 0.00084	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83262	 83268	 0.009167	 0.040388	 0.0007	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83267	 83268	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83268	 83270	 0.005211	 0.02322	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83271	 83272	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83272	 83284	 0.033208	 0.16214	 0.0034	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83273	 83274	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83274	 83278	 0.032953	 0.12678	 0.00216	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83275	 83276	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83276	 83290	 0.041791	 0.18624	 0.00316	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83277	 83278	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83280	 83281	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83280	 83288	 0.002164	 0.019159	 0.01052	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83282	 83286	 0.3088	 0.2	 0.00381	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83284	 83285	 0.031852	 0.084201	 0.00153	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83286	 83287	 0.051644	 0.14813	 0.00228	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83286	 83309	 0.080561	 0.23109	 0.00355	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83288	 83289	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83293	 83295	 0.046138	 0.074012	 0.00137	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83309	 83311	 0.012886	 0.059829	 0.00163	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83316	 83323	 0.058439	 0.097605	 0.00166	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83319	 83320	 0.022529	 0.075155	 0.00119	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83320	 83323	 0.075553	 0.080686	 0.00171	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83321	 83322	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83329	 83420	 0.16932	 0.13273	 0.0017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83332	 83333	 0.055966	 0.05613	 0.00091	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83333	 83336	 0.050171	 0.036268	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83343	 83349	 0.099651	 0.078865	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83345	 83346	 0.011548	 0.016393	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83352	 83353	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83352	 83377	 0.012228	 0.031746	 0.00771	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83353	 83361	 0.019738	 0.038683	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83355	 83395	 0.019803	 0.015671	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83357	 83358	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83361	 83389	 0.039847	 0.031234	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83362	 83368	 0.014028	 0.010996	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83369	 83370	 0.00134	 0.003543	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83370	 83371	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83370	 83375	 0.001402	 0.004219	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83372	 83376	 0.006822	 0.010889	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83372	 83379	 0.052909	 0.037478	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83373	 83374	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83373	 83377	 0.004741	 0.012187	 0.00302	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83373	 83461	 0.00221	 0.005933	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83375	 83376	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83375	 83493	 0.001745	 0.004752	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83377	 83378	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83377	 84366	 0.05695	 0.22435	 0.05887	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83378	 83494	 0.049458	 0.039141	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83380	 83450	 0.023242	 0.015047	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83381	 83382	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83382	 83388	 0.009159	 0.021264	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83383	 83390	 0.006372	 0.010583	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83388	 83452	 0.038167	 0.029917	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83399	 83403	 0.034757	 0.023347	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83400	 83401	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83402	 83418	 0.004972	 0.015789	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83410	 83411	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83410	 83413	 0.001093	 0.004378	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83411	 83414	 0.007784	 0.018071	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83412	 83413	 9.2e-05	 0.007399	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83412	 83413	 9.2e-05	 0.007399	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83413	 83414	 0.000104	 0.008333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83413	 83414	 0.000104	 0.008333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83415	 83416	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83423	 83424	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83426	 83427	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83426	 83428	 0.002382	 0.006394	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83428	 83429	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83430	 83480	 0.040126	 0.031755	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83434	 83436	 0.005838	 0.015006	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83435	 83436	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83437	 83439	 0.0073	 0.024353	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83439	 83440	 0.009664	 0.01628	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83440	 83441	 0.0116	 0.022966	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83442	 83448	 0.028217	 0.022331	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83447	 83457	 0.010761	 0.011721	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83449	 83450	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83450	 83495	 0.024407	 0.015801	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83451	 83452	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83456	 83457	 0.020606	 0.016152	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83456	 83458	 0.020792	 0.016455	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83458	 83459	 0.004242	 0.012165	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83459	 83467	 0.12088	 0.094754	 0.00122	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83462	 83467	 0.094824	 0.074329	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83463	 83494	 0.007902	 0.020479	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83465	 83467	 0.010119	 0.025733	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83469	 83490	 0.046791	 0.03703	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83470	 83472	 0.008637	 0.028502	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83471	 83472	 0.01503	 0.010865	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83472	 83478	 0.055985	 0.052095	 0.00099	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83473	 83474	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83482	 83489	 0.044646	 0.032847	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83484	 83485	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83493	 83494	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83497	 83498	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83504	 83505	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83505	 83519	 0.09816	 0.077685	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83506	 83519	 0.026477	 0.075942	 0.00117	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83508	 83509	 0.000103	 0.008222	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83508	 83509	 0.000103	 0.008222	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83509	 83510	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83509	 83510	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83510	 83512	 0.018129	 0.04165	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83511	 83512	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83511	 83515	 0.004096	 0.0138	 0.00343	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83512	 83545	 0.11146	 0.20113	 0.00291	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83512	 84165	 0.074492	 0.3578	 0.0107	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83514	 83517	 0.000859	 0.003004	 0.001	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83515	 83516	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83515	 83517	 0.001271	 0.005088	 0.00128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83517	 83518	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83517	 83520	 0.001968	 0.004568	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83519	 83521	 0.019487	 0.014947	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83520	 83521	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83522	 83523	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83524	 84617	 0.094162	 0.27013	 0.00416	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83525	 84419	 0.18031	 0.14271	 0.0018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83525	 84425	 0.25842	 0.16735	 0.00319	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83525	 84609	 0.10165	 0.27777	 0.00472	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83527	 83528	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83528	 83529	 0.014235	 0.048627	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83528	 83529	 0.014235	 0.048627	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83529	 83531	 0.007412	 0.022738	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83529	 83531	 0.007412	 0.022738	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83530	 83531	 0.011979	 0.036748	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83530	 83531	 0.011979	 0.036748	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83540	 83541	 0.039853	 0.11431	 0.00176	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83542	 84163	 0.086758	 0.19845	 0.00485	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83543	 83544	 0.02069	 0.04234	 0.00104	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83547	 83548	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83559	 83560	 0.008476	 0.02431	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83561	 83562	 0.006358	 0.036928	 0.0087	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83563	 83566	 0.019971	 0.021966	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83563	 83567	 0.017618	 0.032269	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83564	 83566	 0.017529	 0.037565	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83565	 83567	 0.017514	 0.025521	 0.00058	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83566	 84035	 0.006244	 0.024292	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83568	 84019	 0.014199	 0.032472	 0.00079	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83571	 83572	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83575	 83581	 0.003508	 0.009782	 0.00205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83576	 83577	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83576	 84597	 0.006645	 0.05339	 0.01501	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83577	 84047	 0.02229	 0.057298	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83581	 83582	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83581	 83583	 0.002822	 0.01165	 0.00276	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83582	 83590	 0.063318	 0.056738	 0.00116	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83582	 84588	 0.031582	 0.15412	 0.00266	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83582	 84592	 0.029381	 0.075527	 0.00117	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83583	 83591	 0.001532	 0.009509	 0.0023	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83585	 83587	 0.068371	 0.054108	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83585	 83594	 0.021295	 0.061077	 0.00094	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83586	 83593	 0.000445	 0.003222	 0.00173	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83587	 83588	 0.012544	 0.015964	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83591	 83592	 0.001521	 0.00598	 0.00156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83592	 84586	 0.001446	 0.015217	 0.00855	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83593	 83594	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83598	 84477	 0.15788	 0.2419	 0.0034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83599	 83644	 0.11659	 0.30915	 0.00785	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83599	 84572	 0.053635	 0.3129	 0.00628	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83600	 84165	 0.34953	 0.27673	 0.00348	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83603	 83606	 0.017482	 0.034261	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83603	 83616	 0.011804	 0.032697	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83604	 83605	 0.005271	 0.023489	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83606	 83609	 0.010272	 0.040117	 0.00089	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83607	 83616	 0.005716	 0.016807	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83608	 83615	 0.024933	 0.070754	 0.00111	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83611	 83612	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83613	 83975	 0.15697	 0.15856	 0.0021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83614	 83615	 0.007054	 0.043364	 0.00078	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83619	 84598	 0.002706	 0.013595	 0.00354	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83620	 83621	 0.00093	 0.006547	 0.00372	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83620	 83623	 0.000825	 0.006585	 0.00162	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83621	 83622	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83621	 83623	 0.002361	 0.008098	 0.00194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83623	 83624	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83624	 83627	 0.050206	 0.052823	 0.00077	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83624	 83628	 0.029151	 0.021447	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83625	 84060	 0.023864	 0.068445	 0.00105	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83626	 83627	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83626	 83631	 0.0021	 0.019454	 0.00974	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83631	 83632	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83636	 83637	 0.002731	 0.012528	 0.00321	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83637	 83638	 0.002311	 0.010404	 0.00277	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83638	 83639	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83639	 83851	 0.11811	 0.38993	 0.00632	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83639	 84090	 0.10198	 0.3403	 0.0054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83641	 83642	 0.002524	 0.009921	 0.0026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83642	 83643	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83643	 83644	 0.035156	 0.099764	 0.00157	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83644	 83647	 0.018796	 0.064208	 0.0014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83644	 84253	 0.036952	 0.14376	 0.0024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83645	 83646	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83648	 83649	 0.015517	 0.097439	 0.00213	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83648	 83650	 0.024638	 0.082192	 0.0013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83649	 84246	 0.25428	 0.27976	 0.00373	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83651	 83652	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83654	 83655	 0.002309	 0.019212	 0.00036	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83657	 84115	 0.019069	 0.051923	 0.01144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83658	 83662	 0.001318	 0.019683	 0.00582	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83659	 83661	 0.001525	 0.01321	 0.00474	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83661	 83662	 0.000707	 0.0072	 0.00186	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83663	 84356	 0.45662	 0.35051	 0.00471	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83663	 84572	 0.12172	 0.34924	 0.00537	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83667	 84420	 0.020204	 0.09003	 0.00153	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83668	 83759	 0.007075	 0.014009	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83670	 83671	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83672	 83720	 0.00555	 0.016704	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83672	 83736	 0.005218	 0.011932	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83675	 83676	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83675	 83683	 0.000697	 0.001843	 0.00043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83677	 83678	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83680	 83681	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83681	 83809	 0.004578	 0.011207	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83682	 83809	 0.002083	 0.009651	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83683	 83684	 0.001339	 0.003227	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83684	 83685	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83687	 83699	 0.014387	 0.041265	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83689	 83779	 0.006073	 0.017232	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83693	 83697	 0.002105	 0.011963	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83696	 83697	 0.003699	 0.011346	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83696	 83697	 0.003699	 0.011346	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83700	 83708	 0.003835	 0.02954	 0.00057	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83703	 83704	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83703	 83705	 0.000635	 0.002471	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83703	 83706	 0.000488	 0.003124	 0.00105	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83705	 83743	 0.001016	 0.003484	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83706	 83707	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83708	 83747	 0.006373	 0.028078	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83711	 83712	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83719	 83720	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83720	 83756	 0.00501	 0.024445	 0.00042	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83722	 83800	 0.013665	 0.065931	 0.00116	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83724	 83725	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83727	 83728	 0.010893	 0.028001	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83729	 83793	 0.017421	 0.034493	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83729	 83799	 0.010381	 0.02385	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83730	 83775	 0.006716	 0.031182	 0.00085	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83732	 83733	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83732	 83734	 0.000979	 0.008553	 0.00339	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83734	 83735	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83735	 83754	 0.007652	 0.040769	 0.00072	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83736	 83777	 0.03298	 0.043345	 0.00059	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83737	 83738	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83738	 83739	 0.010172	 0.016965	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83741	 83744	 0.004219	 0.0121	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83743	 83744	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83745	 83746	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83746	 83752	 0.009409	 0.050132	 0.00088	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83749	 83750	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83753	 83790	 0.008917	 0.025574	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83763	 83805	 0.007051	 0.031421	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83768	 83769	 0.013816	 0.029037	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83773	 83785	 0.021885	 0.039336	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83776	 83777	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83778	 83790	 0.017754	 0.019527	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83779	 83780	 0.001409	 0.007507	 0.00013	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83789	 83804	 0.000643	 0.003764	 0.00103	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83792	 83793	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83793	 83966	 0.022296	 0.068399	 0.00185	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83793	 83966	 0.022296	 0.068399	 0.00185	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83797	 83798	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83800	 83802	 0.009001	 0.039656	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83802	 84168	 0.007114	 0.034146	 0.00102	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83804	 83808	 0.000331	 0.003887	 0.00233	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83807	 83808	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83807	 83808	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83807	 83808	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83816	 83817	 0.021681	 0.050335	 0.00075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83816	 83822	 0.065938	 0.091899	 0.00157	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83818	 83819	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83818	 84575	 0.003513	 0.025417	 0.01367	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83819	 83820	 0.006469	 0.028826	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83819	 83826	 0.071666	 0.12882	 0.00231	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83821	 83822	 0.061615	 0.065801	 0.00139	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83822	 83823	 0.029552	 0.098586	 0.00156	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83822	 83884	 0.086349	 0.2045	 0.00374	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83824	 83828	 0.023022	 0.05344	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83825	 83826	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83826	 83885	 0.027594	 0.054635	 0.0008	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83829	 83830	 0.034583	 0.12355	 0.00245	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83829	 83830	 0.034583	 0.12355	 0.00245	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83831	 84366	 0.001465	 0.016943	 0.0105	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83832	 83835	 0.095446	 0.095473	 0.00129	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83835	 83836	 0.047566	 0.12575	 0.00228	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83835	 84436	 0.028898	 0.17768	 0.0032	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83836	 84103	 0.031886	 0.081968	 0.00127	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83837	 83838	 0.00147	 0.014972	 0.00386	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83837	 84376	 0.021991	 0.05988	 0.01319	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83838	 83839	 0.00685	 0.020196	 0.0047	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83839	 83840	 0.00348	 0.0123	 0.00277	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83842	 83843	 0.002481	 0.015713	 0.00426	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83842	 84093	 0.011343	 0.040095	 0.00904	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83843	 83844	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83843	 84384	 0.013455	 0.08275	 0.02387	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83847	 83848	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83852	 84089	 0.004016	 0.032263	 0.00907	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83860	 83869	 0.00685	 0.02665	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83864	 83869	 0.016197	 0.041192	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83864	 83909	 0.007254	 0.018448	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83865	 83954	 0.007213	 0.032139	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83868	 83869	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83872	 83876	 0.024333	 0.017236	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83876	 83878	 0.022643	 0.017919	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83877	 83878	 0.006278	 0.01002	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83877	 83939	 0.025277	 0.019151	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83878	 83880	 0.004229	 0.010872	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83880	 83881	 0.026805	 0.027074	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83881	 83935	 0.00368	 0.014317	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83882	 83887	 0.006245	 0.01791	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83882	 83888	 0.037942	 0.030027	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83882	 83889	 0.011997	 0.046673	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83883	 83884	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83885	 83889	 0.012499	 0.031787	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83887	 83891	 0.018304	 0.036239	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83894	 83895	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83895	 83919	 0.044156	 0.044599	 0.00059	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83897	 83898	 0.010504	 0.017218	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83898	 83902	 0.01248	 0.031738	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83898	 83910	 0.008046	 0.01825	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83900	 83901	 0.038573	 0.059091	 0.00083	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83903	 83912	 0.033005	 0.067543	 0.00166	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83904	 84157	 0.015025	 0.085412	 0.00155	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83907	 84157	 0.040133	 0.17885	 0.00304	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83908	 83912	 0.027372	 0.021662	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83910	 83912	 0.049561	 0.039222	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83911	 83912	 0.011552	 0.022872	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83911	 83913	 0.004754	 0.016634	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83917	 83918	 0.013275	 0.038073	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83920	 83921	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83921	 83922	 0.03228	 0.025546	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83923	 83924	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83923	 83925	 0.001095	 0.015955	 0.00511	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83925	 83926	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83928	 83929	 0.016007	 0.037905	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83931	 83932	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83931	 83933	 0.001004	 0.006174	 0.00178	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83933	 83934	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83934	 83947	 0.028571	 0.055995	 0.00084	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83936	 83937	 0.001217	 0.004953	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83936	 83951	 0.003951	 0.016721	 0.00376	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83937	 83938	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83940	 83941	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83948	 83949	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83952	 84382	 0.001821	 0.012821	 0.00729	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83957	 83958	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83964	 83965	 0.013942	 0.078339	 0.00145	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83967	 83968	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83971	 84308	 0.011976	 0.030785	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83974	 83975	 0.026582	 0.075432	 0.00119	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83977	 83978	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83977	 83978	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83979	 83980	 0.006564	 0.019352	 0.0045	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83980	 83981	 0.002233	 0.012693	 0.00367	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83981	 83982	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83983	 83985	 0.005758	 0.019754	 0.00473	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83984	 83985	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83986	 83995	 0.012961	 0.043236	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83989	 84057	 0.023243	 0.019131	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83992	 84014	 0.006374	 0.018282	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83994	 83995	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83994	 84067	 0.000488	 0.00527	 0.00181	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83995	 84027	 0.014478	 0.056323	 0.00094	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84000	 84042	 0.004673	 0.017978	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84001	 84002	 0.004066	 0.012912	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84007	 84008	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84009	 84028	 0.01226	 0.015218	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84009	 84033	 0.010035	 0.019666	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84011	 84012	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84015	 84016	 0.000535	 0.007728	 0.00245	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84017	 84018	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84019	 84035	 0.013531	 0.030945	 0.00076	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84019	 84043	 0.05479	 0.10848	 0.00159	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84019	 84071	 0.039358	 0.11289	 0.00174	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84021	 84074	 0.013454	 0.080614	 0.00194	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84022	 84027	 0.081059	 0.06415	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84024	 84037	 0.030705	 0.019878	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84026	 84027	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84027	 84028	 0.009716	 0.03738	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84027	 84028	 0.009716	 0.03738	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84029	 84031	 0.00408	 0.019582	 0.00059	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84031	 84032	 0.023819	 0.033195	 0.00057	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84032	 84033	 0.007439	 0.031052	 0.0009	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84034	 84043	 0.035527	 0.063458	 0.00094	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84037	 84042	 0.023307	 0.023541	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84038	 84039	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84039	 84040	 0.002448	 0.01091	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84041	 84042	 0.001927	 0.011843	 0.00027	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84041	 84043	 0.010793	 0.027744	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84045	 84046	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84046	 84050	 0.016564	 0.03788	 0.00092	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84048	 84049	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84049	 84051	 0.0155	 0.030376	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84049	 84053	 0.015894	 0.042015	 0.00076	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84052	 84055	 0.021383	 0.060678	 0.00095	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84052	 84595	 0.027887	 0.079984	 0.00123	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84059	 84060	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84059	 84063	 0.004421	 0.014897	 0.0037	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84060	 84075	 0.1227	 0.079444	 0.00151	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84063	 84064	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84067	 84068	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84069	 84071	 0.024726	 0.06356	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84070	 84071	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84071	 84072	 0.018998	 0.073908	 0.00123	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84078	 84079	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84080	 84081	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84081	 84082	 0.01465	 0.062634	 0.00141	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84081	 84639	 0.093125	 0.35841	 0.00612	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84084	 84640	 0.027358	 0.16821	 0.00303	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84086	 84087	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84089	 84090	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84095	 84096	 0.047695	 0.097608	 0.0024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84095	 84099	 0.050169	 0.1439	 0.00221	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84096	 84097	 0.061697	 0.17509	 0.00275	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84098	 84099	 0.025502	 0.08929	 0.00247	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84098	 84116	 0.066435	 0.19056	 0.00293	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84100	 84489	 0.087496	 0.2268	 0.00429	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84101	 84102	 0.032419	 0.064188	 0.00094	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84101	 84103	 0.024531	 0.040747	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84108	 84109	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84108	 84110	 0.002699	 0.010804	 0.00272	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84110	 84112	 0.001064	 0.012037	 0.00676	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84112	 84113	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84115	 84116	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84119	 84120	 0.026091	 0.07404	 0.00116	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84121	 84122	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84122	 84123	 0.14029	 0.13158	 0.00203	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84122	 84157	 0.2033	 0.30845	 0.00442	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84123	 84355	 0.13458	 0.1769	 0.00242	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84126	 84127	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84127	 84128	 0.00691	 0.015804	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84129	 84130	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84129	 84147	 0.001737	 0.025529	 0.00781	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84131	 84144	 0.050516	 0.14336	 0.00225	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84138	 84140	 0.001697	 0.009938	 0.00271	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84140	 84141	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84141	 84143	 0.032495	 0.12642	 0.00211	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84141	 84143	 0.032495	 0.12642	 0.00211	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84141	 84144	 0.007872	 0.054032	 0.00098	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84142	 84143	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84145	 84146	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84147	 84148	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84151	 84446	 0.042968	 0.16717	 0.00279	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84151	 84446	 0.042968	 0.16717	 0.00279	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84155	 84156	 0.076473	 0.14988	 0.00225	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84155	 84162	 0.024138	 0.074127	 0.00139	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84168	 84188	 0.07117	 0.11361	 0.00262	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84172	 84173	 0.020212	 0.022231	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84176	 84177	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84179	 84183	 0.074495	 0.097911	 0.00134	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84182	 84183	 0.004007	 0.018579	 0.00039	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84185	 84187	 0.023129	 0.028195	 0.00045	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84186	 84187	 0.009879	 0.044022	 0.00075	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84188	 84189	 0.053022	 0.053035	 0.00072	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84190	 84422	 0.41681	 0.30151	 0.00457	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84192	 84213	 0.055103	 0.040541	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84193	 84195	 0.014764	 0.033488	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84193	 84210	 0.031557	 0.024974	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84194	 84197	 0.017566	 0.013769	 0.00018	 27.0	 27.0	 27.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84195	 84196	 0.025156	 0.019296	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84196	 84204	 0.045822	 0.036263	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84197	 84198	 0.013509	 0.014859	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84197	 84201	 0.015213	 0.014013	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84199	 84202	 0.014355	 0.025902	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84205	 84230	 0.015906	 0.016986	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84206	 84207	 0.000791	 0.003165	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 0	 -30.0	 30.0;
	84210	 84212	 0.052108	 0.041238	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84214	 84215	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84214	 84216	 0.001255	 0.00619	 0.00167	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84215	 84628	 0.055701	 0.10917	 0.00164	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84216	 84217	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84219	 84221	 0.037752	 0.024441	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84228	 84229	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84229	 84630	 0.046642	 0.060699	 0.00085	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84236	 84237	 0.001645	 0.007468	 0.00016	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84237	 84239	 0.015333	 0.037532	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84245	 84246	 0.010015	 0.018344	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84248	 84249	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84250	 84252	 0.013026	 0.050675	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84252	 84402	 0.12205	 0.42735	 0.00886	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84255	 84256	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84259	 84260	 0.012586	 0.044963	 0.00089	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84262	 84616	 0.046739	 0.15425	 0.0025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84262	 84622	 0.049778	 0.14126	 0.00222	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84266	 84533	 0.009839	 0.043842	 0.00074	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84267	 84618	 0.053488	 0.15179	 0.00239	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84267	 84622	 0.024919	 0.057249	 0.00087	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84268	 84270	 0.005037	 0.03023	 0.00915	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84272	 84274	 0.010344	 0.051323	 0.00122	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84273	 84276	 0.092223	 0.09315	 0.00123	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84274	 84578	 0.39992	 0.36866	 0.00591	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84275	 84276	 0.019648	 0.095877	 0.00165	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84276	 84277	 0.06588	 0.085015	 0.00171	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84282	 84283	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84283	 84284	 0.02397	 0.043084	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84283	 84285	 0.09859	 0.078025	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84287	 84288	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84287	 84332	 0.000995	 0.00391	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84291	 84292	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84291	 84351	 0.001464	 0.005756	 0.00151	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84292	 84293	 0.004302	 0.009985	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84292	 84352	 0.009193	 0.022817	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84296	 84297	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84298	 84305	 0.027588	 0.019943	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84298	 84306	 0.007275	 0.020644	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84299	 84305	 0.014586	 0.011433	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84312	 84315	 0.002373	 0.013841	 0.00028	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84313	 84315	 0.006427	 0.013774	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84317	 84318	 0.001109	 0.004994	 0.00133	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84320	 84321	 0.051682	 0.040511	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84322	 84325	 0.000607	 0.004574	 0.00127	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84323	 84324	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84323	 84325	 0.001155	 0.004391	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84324	 84328	 0.017959	 0.0476	 0.00121	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84325	 84327	 0.00034	 0.003013	 0.00165	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84328	 84350	 0.006968	 0.047828	 0.00087	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84328	 84599	 0.037502	 0.074252	 0.00109	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84331	 84352	 0.08149	 0.064491	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84334	 84335	 0.006171	 0.020586	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84335	 84344	 0.011311	 0.028651	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84341	 84342	 0.004733	 0.023095	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84344	 84345	 0.018596	 0.053336	 0.00082	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84349	 84350	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84351	 84352	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84357	 84361	 0.041171	 0.032272	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84358	 84359	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84360	 84361	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84361	 84363	 0.044391	 0.035131	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84362	 84363	 0.024471	 0.019366	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84364	 84365	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84364	 84365	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84366	 84367	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84369	 84370	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84369	 84631	 0.005996	 0.020982	 0.00695	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84370	 84437	 0.025233	 0.098164	 0.00164	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84372	 84435	 0.003381	 0.032459	 0.00944	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84376	 84377	 0.005875	 0.026953	 0.0069	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84378	 84379	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84378	 84380	 0.004083	 0.0106	 0.00257	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84378	 84381	 0.001205	 0.004905	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84380	 84381	 0.005878	 0.01511	 0.00374	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84384	 84426	 0.002909	 0.021119	 0.0073	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84387	 84542	 0.082615	 0.065382	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84389	 84390	 0.010651	 0.077849	 0.00144	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84389	 84393	 0.014288	 0.086838	 0.0016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84391	 84561	 0.044589	 0.10915	 0.00187	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84393	 84398	 0.024038	 0.093517	 0.00156	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84393	 84398	 0.024038	 0.093517	 0.00156	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84395	 84396	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84397	 84398	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84397	 84399	 0.003628	 0.009418	 0.00229	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84399	 84400	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84401	 84402	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84401	 84528	 0.0038	 0.015215	 0.00383	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84402	 84497	 0.056579	 0.090314	 0.00208	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84402	 84541	 0.079221	 0.098343	 0.00214	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84405	 84406	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84405	 84408	 0.002626	 0.025083	 0.00921	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84408	 84409	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84412	 84425	 0.011335	 0.018903	 0.00027	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84415	 84420	 0.086108	 0.094711	 0.00126	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84416	 84421	 0.049364	 0.097739	 0.00143	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84416	 84425	 0.013326	 0.051268	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84417	 84425	 0.11212	 0.087887	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84418	 84419	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84418	 84424	 0.006182	 0.025158	 0.00613	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84428	 84430	 0.036881	 0.12304	 0.00195	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84429	 84430	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84430	 84431	 0.060758	 0.10963	 0.00158	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84435	 84436	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84437	 84438	 0.065545	 0.16989	 0.00321	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84438	 84439	 0.013277	 0.04429	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84441	 84443	 0.01566	 0.10104	 0.00322	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84444	 84445	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84444	 84445	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84445	 84446	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84445	 84446	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84447	 84448	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84447	 84449	 0.00494	 0.016947	 0.00406	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84449	 84450	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84460	 84461	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84460	 84464	 0.000984	 0.003738	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84465	 84466	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84466	 84477	 0.032938	 0.17352	 0.00311	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84469	 84470	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84469	 84483	 0.00197	 0.008338	 0.00188	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84476	 84477	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84479	 84486	 0.009444	 0.05806	 0.00105	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84480	 84481	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84483	 84484	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84485	 84489	 0.031508	 0.11256	 0.00223	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84486	 84489	 0.030415	 0.10147	 0.00161	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84488	 84621	 0.013179	 0.080094	 0.00148	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84491	 84527	 0.033125	 0.026215	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84492	 84503	 0.041936	 0.083031	 0.00122	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84493	 84494	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84493	 84495	 0.003064	 0.007383	 0.00208	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84495	 84496	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84495	 84498	 0.002242	 0.00582	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84500	 84501	 0.041837	 0.033109	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84500	 84514	 0.048224	 0.038164	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84502	 84503	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84502	 84506	 0.003625	 0.00958	 0.00224	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84503	 84513	 0.040406	 0.040811	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84503	 84532	 0.054899	 0.10208	 0.00239	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84504	 84508	 0.025766	 0.020196	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84504	 84543	 0.055083	 0.043592	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84505	 84512	 0.014401	 0.028513	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84506	 84507	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84506	 84511	 0.001538	 0.004187	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84507	 84512	 0.022393	 0.017177	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84510	 84519	 0.01808	 0.035796	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84510	 84540	 0.068754	 0.050585	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84511	 84512	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84514	 84515	 0.031364	 0.023075	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84522	 84525	 0.018929	 0.024879	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84522	 84542	 0.034198	 0.057609	 0.00082	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84523	 84526	 0.03911	 0.028272	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84528	 84529	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84531	 84532	 0.037426	 0.071675	 0.00113	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84532	 84613	 0.056174	 0.15561	 0.00257	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84532	 84620	 0.021239	 0.075872	 0.00151	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84533	 84622	 0.030588	 0.119	 0.00199	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84534	 84535	 0.12811	 0.10139	 0.00128	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84537	 84538	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84545	 84548	 0.008575	 0.028607	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84545	 84560	 0.006879	 0.038654	 0.00072	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84546	 84563	 0.005535	 0.01467	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84547	 84550	 0.014066	 0.046923	 0.00074	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84548	 84563	 0.003227	 0.012915	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84550	 84551	 0.005914	 0.026354	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84552	 84563	 0.023661	 0.029371	 0.00064	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84553	 84563	 0.018802	 0.073148	 0.00122	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84553	 84563	 0.018802	 0.073148	 0.00122	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84555	 84556	 0.012842	 0.072999	 0.00132	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84565	 84567	 0.000664	 0.011349	 0.00615	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84567	 84568	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84574	 84576	 0.02858	 0.10996	 0.00188	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84575	 84576	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84582	 84583	 0.001736	 0.00695	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84584	 84585	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84585	 84599	 0.031701	 0.025087	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84587	 84588	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84587	 84589	 0.002695	 0.016745	 0.00473	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84588	 84590	 0.025001	 0.057178	 0.0014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84589	 84590	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84590	 84595	 0.063285	 0.16731	 0.00304	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84591	 84592	 0.060603	 0.061211	 0.00081	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84597	 84598	 0.010431	 0.024213	 0.00738	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84600	 84601	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84606	 84607	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84607	 84608	 0.006495	 0.031693	 0.00055	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84607	 84609	 0.012695	 0.045352	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84607	 84609	 0.012695	 0.045352	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84607	 84614	 0.031579	 0.090573	 0.00139	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84608	 84609	 0.006231	 0.038289	 0.00087	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84608	 84613	 0.050053	 0.13267	 0.00337	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84611	 84612	 0.01009	 0.038817	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84612	 84613	 0.017111	 0.03931	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84613	 84620	 0.026997	 0.090062	 0.00143	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84616	 84617	 0.032716	 0.084101	 0.0013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84617	 84618	 0.018193	 0.060692	 0.00096	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84617	 84622	 0.05876	 0.16054	 0.00273	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84629	 84630	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84641	 84642	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84641	 84642	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84642	 84643	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84642	 84643	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84642	 84690	 0.028801	 0.12196	 0.02747	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84643	 84657	 0.36772	 0.4837	 0.00663	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84643	 84666	 0.08806	 0.14687	 0.00214	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84643	 84736	 0.4968	 0.36585	 0.00535	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84643	 86014	 0.058689	 0.13624	 0.00259	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84644	 84645	 7.8e-05	 0.006228	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84644	 84645	 7.8e-05	 0.006228	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84647	 84648	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84647	 84648	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84648	 84668	 0.24397	 0.35575	 0.00804	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84649	 84650	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84649	 84650	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84650	 86062	 0.024897	 0.0969	 0.0259	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84651	 84652	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84651	 84652	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84652	 84687	 0.016584	 0.055882	 0.01389	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84652	 85308	 0.0031	 0.024422	 0.00714	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84653	 84654	 0.000199	 0.015904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84653	 84654	 0.000199	 0.015904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84654	 84708	 0.083306	 0.47388	 0.00858	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84654	 84889	 0.079485	 0.62025	 0.01161	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84655	 84917	 0.010164	 0.093496	 0.00185	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84656	 84657	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84656	 84657	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84659	 84660	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84659	 84660	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84661	 84662	 9.1e-05	 0.007266	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84661	 84662	 9.1e-05	 0.007266	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84665	 84666	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84665	 84666	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84667	 84668	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84667	 84668	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84672	 84673	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84672	 84673	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84674	 84675	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84674	 84675	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84676	 85180	 0.046655	 0.2277	 0.00393	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84677	 85313	 0.001609	 0.011081	 0.01956	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84678	 84679	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84678	 84679	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84678	 85964	 0.011127	 0.037122	 0.00942	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84679	 85958	 0.007592	 0.029207	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84679	 85958	 0.007592	 0.029207	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84680	 84681	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84680	 84681	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84682	 84683	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84682	 84683	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84684	 84685	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84684	 84685	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84686	 84687	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84686	 84687	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84686	 86035	 0.003355	 0.029067	 0.05408	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84687	 84688	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84687	 84688	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84687	 85328	 0.011054	 0.037245	 0.00926	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84688	 84721	 0.32068	 0.41759	 0.00584	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84689	 84690	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84689	 84690	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84691	 84692	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84691	 84692	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84691	 85599	 0.001511	 0.019518	 0.04423	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84692	 84693	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84692	 84693	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84694	 84695	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84694	 84695	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84695	 84696	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84695	 84696	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84695	 85008	 0.005995	 0.020894	 0.00484	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84696	 84993	 0.053625	 0.095785	 0.00141	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84696	 85003	 0.007665	 0.041318	 0.00083	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84696	 85012	 0.024757	 0.061447	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84697	 84698	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84697	 84698	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84698	 85134	 0.005928	 0.015713	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84699	 84700	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84699	 84700	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84701	 84702	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84701	 84702	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84701	 84719	 0.001835	 0.012384	 0.0228	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84702	 85181	 0.020782	 0.082453	 0.00235	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84703	 85276	 0.01548	 0.096228	 0.02717	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84704	 84705	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84704	 84705	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84708	 84737	 0.1189	 0.34113	 0.00525	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84710	 84711	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84710	 84711	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84711	 84712	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84711	 84712	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84712	 85368	 0.033518	 0.18835	 0.00349	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84712	 86063	 0.027146	 0.10561	 0.00176	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84712	 86135	 0.01324	 0.040617	 0.0011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84713	 84714	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84713	 84714	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84714	 84715	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84714	 84715	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84715	 84737	 0.92652	 0.73539	 0.00926	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84715	 84739	 0.056257	 0.12012	 0.00271	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84715	 84740	 0.13041	 0.40036	 0.01085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84716	 84717	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84716	 84717	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84716	 85628	 0.03123	 0.1627	 0.048	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84718	 86024	 0.007281	 0.033804	 0.00092	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84719	 84720	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84719	 84720	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84720	 84721	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84720	 84721	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84720	 85322	 0.030786	 0.088328	 0.02174	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84721	 84740	 0.1914	 0.31214	 0.00476	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84722	 84723	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84722	 84723	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84722	 85982	 0.001818	 0.014144	 0.00367	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84722	 85984	 0.002908	 0.02537	 0.00697	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84723	 85979	 0.017243	 0.089668	 0.00194	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84724	 84725	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84724	 84725	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84726	 84727	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84726	 84727	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84727	 84728	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84727	 84728	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84728	 84913	 0.011264	 0.038477	 0.00084	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84730	 84731	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84730	 84731	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84732	 84967	 0.002466	 0.010437	 0.00235	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84735	 85445	 0.11443	 0.24055	 0.00438	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84736	 85339	 0.004724	 0.009354	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84739	 85739	 0.009595	 0.026541	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84739	 85743	 0.007405	 0.04209	 0.00076	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84739	 85752	 0.024663	 0.12476	 0.00217	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84743	 84744	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84743	 84744	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84744	 84885	 0.080219	 0.20624	 0.00319	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84744	 85443	 0.12915	 0.42643	 0.00691	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84745	 85361	 0.052976	 0.10012	 0.00162	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84746	 85946	 0.048872	 0.096765	 0.00142	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84749	 84750	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84749	 84750	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84752	 85967	 0.030595	 0.10097	 0.00164	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84757	 84758	 0.000105	 0.008384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84757	 84758	 0.000105	 0.008384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84759	 84760	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84759	 84760	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84759	 84762	 0.010316	 0.077561	 0.30186	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84759	 84789	 7.6e-05	 0.000812	 0.00165	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84759	 84789	 7.6e-05	 0.000812	 0.00165	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84760	 84761	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84760	 84761	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84761	 86194	 0.008038	 0.074834	 0.00145	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84761	 86292	 0.014436	 0.080938	 0.00223	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84761	 86667	 0.15704	 0.40388	 0.00625	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84762	 84763	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84762	 84763	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84764	 84765	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84764	 84765	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84766	 84767	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84766	 84767	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84767	 84768	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84767	 84768	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84769	 84770	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84769	 84770	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84771	 84772	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84771	 84772	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84772	 84773	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84772	 84773	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84772	 84809	 0.036559	 0.21018	 0.07011	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84772	 84811	 0.019924	 0.098476	 0.02878	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84773	 86572	 0.14496	 0.4839	 0.00768	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84774	 84775	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84774	 84775	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84776	 84777	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84776	 84777	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84779	 84845	 0.005294	 0.042537	 0.01196	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84780	 84781	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84780	 84781	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84782	 84783	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84782	 84783	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84783	 86572	 0.080183	 0.31202	 0.00521	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84784	 84785	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84784	 84785	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84787	 84788	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84787	 84788	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84791	 84792	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84791	 84792	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84794	 84795	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84794	 84795	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84795	 86155	 0.026478	 0.1628	 0.00293	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84796	 86340	 0.018362	 0.10447	 0.00321	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84798	 84799	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84798	 84799	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84801	 84802	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84801	 84802	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84801	 86294	 0.002636	 0.035255	 0.00964	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84805	 84806	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84805	 84806	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84807	 86338	 0.063729	 0.40041	 0.00876	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84808	 86524	 0.009314	 0.040805	 0.00088	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84809	 84810	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84809	 84810	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84812	 84813	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84812	 84813	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84812	 86734	 0.003815	 0.053955	 0.01787	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84814	 86689	 0.051983	 0.11943	 0.00181	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84815	 84816	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84815	 84816	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84816	 86359	 0.037297	 0.11961	 0.00296	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84817	 86461	 0.023972	 0.093259	 0.00156	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84818	 84819	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84818	 84819	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84821	 86341	 0.049161	 0.19127	 0.00319	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84824	 86716	 0.018876	 0.07554	 0.00159	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84825	 84826	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84825	 84826	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84828	 84829	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84828	 84829	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84829	 84830	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84829	 84830	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84831	 84832	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84831	 84832	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84833	 84834	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84833	 84834	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84834	 84835	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84834	 84835	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84835	 86757	 0.033749	 0.15102	 0.00311	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84836	 84837	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84836	 84837	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84838	 84839	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84838	 84839	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84839	 84868	 0.007775	 0.064684	 0.00122	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84840	 84841	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84840	 84841	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84842	 84843	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84842	 84843	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84843	 86817	 0.019971	 0.077694	 0.0013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84843	 86817	 0.019971	 0.077694	 0.0013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84844	 84845	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84844	 84845	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84845	 84846	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84845	 84846	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84848	 84849	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84848	 84849	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84851	 84852	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84851	 84852	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84856	 86899	 0.009076	 0.051594	 0.00093	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84859	 84860	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84859	 84860	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84859	 86883	 0.005707	 0.023225	 0.00566	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84860	 86729	 0.009869	 0.047615	 0.00084	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84862	 84863	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84862	 84863	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84863	 86966	 0.018099	 0.04797	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84864	 86959	 0.19386	 0.25485	 0.00349	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84864	 87006	 0.030501	 0.14868	 0.00279	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84869	 84870	 0.003682	 0.022637	 0.00041	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84870	 84871	 0.010166	 0.044793	 0.00078	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84876	 84877	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84877	 84878	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84883	 84884	 0.071378	 0.066937	 0.00103	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84885	 85462	 0.0557	 0.199	 0.00395	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84885	 85977	 0.036771	 0.12267	 0.00194	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84886	 84887	 0.14348	 0.10557	 0.00154	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84892	 84893	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84893	 84894	 0.21824	 0.4127	 0.00668	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84893	 85354	 0.14926	 0.42831	 0.00659	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84895	 84896	 0.014771	 0.049273	 0.00078	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84895	 84902	 0.029933	 0.084942	 0.00133	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84896	 84900	 0.010405	 0.026748	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84897	 84899	 0.016746	 0.038297	 0.00093	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84898	 84899	 0.008196	 0.016773	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84901	 84902	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84901	 84904	 0.013972	 0.036928	 0.00864	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84904	 84905	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84906	 84907	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84909	 84910	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84910	 84946	 0.010974	 0.05584	 0.00127	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84911	 84912	 0.003782	 0.016662	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84916	 84917	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84916	 84920	 0.005916	 0.019297	 0.00512	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84919	 84921	 0.007398	 0.042053	 0.00076	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84919	 84922	 0.038113	 0.097976	 0.00152	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84920	 84921	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84924	 84925	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84928	 84929	 0.016046	 0.037253	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84931	 84933	 0.035075	 0.081431	 0.00121	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84937	 84938	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84937	 84943	 0.000213	 0.003108	 0.01191	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84939	 84944	 0.004368	 0.037101	 0.00087	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84940	 84941	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84943	 84944	 0.000174	 0.013916	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84945	 84946	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84953	 84959	 0.014846	 0.037755	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84957	 84961	 0.046389	 0.036712	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84958	 84963	 0.00987	 0.019542	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84961	 84963	 0.00738	 0.019128	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84965	 84970	 0.014261	 0.03311	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84966	 84967	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84967	 84968	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84969	 84970	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84969	 84983	 0.007209	 0.024729	 0.00592	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84972	 84984	 0.043827	 0.046111	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84974	 84978	 0.002983	 0.009151	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84975	 84976	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84975	 84977	 0.001197	 0.003164	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84977	 84978	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84977	 85028	 0.004084	 0.010793	 0.00253	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84980	 84981	 7e-05	 0.005589	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84981	 84982	 0.000104	 0.008333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84983	 84984	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84984	 84988	 0.036097	 0.028567	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84985	 84991	 0.013493	 0.034684	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84989	 84991	 0.004599	 0.00941	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84993	 84994	 0.003622	 0.009212	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84993	 84998	 0.07976	 0.063122	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84999	 85028	 0.003703	 0.009942	 0.00225	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85007	 85011	 0.02048	 0.040548	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85012	 85015	 0.002639	 0.014829	 0.00027	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85013	 85022	 0.006951	 0.018375	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85013	 85571	 0.00712	 0.037933	 0.00067	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	85016	 85020	 0.014616	 0.02627	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85018	 85020	 0.008011	 0.025796	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85019	 85020	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85020	 85021	 0.038671	 0.030604	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85024	 85025	 8.2e-05	 0.006578	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85024	 85561	 0.006378	 0.024811	 0.00663	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85027	 85573	 0.006343	 0.033414	 0.0006	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	85028	 85029	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85032	 85033	 0.01226	 0.019569	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85033	 85039	 0.073957	 0.047881	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85035	 85036	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85041	 85042	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85041	 85044	 0.000868	 0.007402	 0.00636	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	85042	 85047	 0.036739	 0.14078	 0.00398	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85044	 85045	 0.000951	 0.013324	 0.01082	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85049	 85052	 0.012286	 0.069031	 0.00128	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85050	 85052	 0.041042	 0.095287	 0.00142	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85053	 85054	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85056	 85058	 0.011308	 0.043504	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85056	 85058	 0.011308	 0.043504	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85057	 85058	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85058	 85060	 0.017681	 0.091946	 0.00199	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85058	 85062	 0.031805	 0.15529	 0.00325	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	85058	 85064	 0.030542	 0.25946	 0.00606	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85063	 85064	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85067	 85068	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85072	 85075	 0.028571	 0.11336	 0.00324	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85074	 85076	 0.040103	 0.12303	 0.00333	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85074	 85076	 0.040103	 0.12303	 0.00333	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85075	 86097	 0.04837	 0.16926	 0.00351	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85076	 85178	 0.032417	 0.22587	 0.00531	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85080	 85081	 0.000116	 0.009277	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85082	 85083	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85084	 85085	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85087	 85113	 0.005856	 0.020501	 0.00057	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85091	 85107	 0.017931	 0.033888	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85093	 85097	 0.028023	 0.079521	 0.00125	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85095	 85096	 0.009637	 0.022371	 0.00682	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85096	 85097	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85097	 85101	 0.089318	 0.13683	 0.00192	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85097	 85621	 0.034072	 0.077924	 0.0019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85098	 85103	 0.048871	 0.087293	 0.00129	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85099	 85105	 0.04547	 0.075943	 0.00129	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85106	 85107	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85108	 85109	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85114	 85115	 8.3e-05	 0.006605	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85115	 85116	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85116	 85992	 0.022913	 0.15729	 0.00287	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85119	 85120	 0.034426	 0.06149	 0.00091	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85120	 85128	 0.072926	 0.1444	 0.00212	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85120	 85617	 0.15474	 0.3473	 0.00554	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85124	 85140	 0.009703	 0.029798	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85124	 85617	 0.16932	 0.37492	 0.00615	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85125	 85126	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85125	 85152	 0.007932	 0.031178	 0.00816	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85126	 85128	 0.014494	 0.082389	 0.00149	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85126	 85617	 0.15027	 0.31593	 0.00576	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85128	 85991	 0.052573	 0.17539	 0.00278	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85130	 85990	 0.022792	 0.091211	 0.00193	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85132	 85133	 0.0242	 0.033727	 0.00058	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85135	 85137	 0.012078	 0.039857	 0.00065	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85139	 85140	 0.005762	 0.014654	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85144	 85145	 0.020672	 0.053138	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85152	 85153	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85155	 85156	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85163	 86020	 0.30166	 0.21814	 0.00331	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85163	 86022	 0.10779	 0.11857	 0.00158	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85165	 85166	 0.01171	 0.025094	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85166	 85168	 0.024914	 0.074988	 0.00147	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85166	 85170	 0.025091	 0.082802	 0.00134	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85168	 85170	 0.016885	 0.0392	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85173	 85175	 0.056787	 0.12988	 0.00317	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85173	 85437	 0.051659	 0.1328	 0.00206	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85176	 85428	 0.094963	 0.22047	 0.0042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85179	 85182	 0.63837	 0.5059	 0.00637	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85179	 85183	 0.060414	 0.19939	 0.00323	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85182	 85834	 0.57414	 0.37225	 0.00708	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85187	 85188	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85188	 85191	 0.016016	 0.085337	 0.0015	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	85188	 85198	 0.024742	 0.13184	 0.00231	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	85190	 85191	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85191	 85192	 0.030852	 0.033933	 0.00045	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85191	 85198	 0.018729	 0.042833	 0.00105	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85195	 85199	 0.013553	 0.026833	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85200	 85203	 0.012333	 0.024419	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85201	 85202	 0.012548	 0.016329	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85203	 85208	 0.018056	 0.04051	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85206	 85207	 0.009348	 0.021205	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85216	 85217	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85216	 85276	 0.005094	 0.032811	 0.0086	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85217	 85220	 0.013097	 0.033667	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85218	 85221	 0.01685	 0.030404	 0.00044	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85222	 85233	 0.009451	 0.049148	 0.00107	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85224	 85228	 0.007234	 0.016791	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85225	 85226	 0.004888	 0.015741	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85227	 85240	 0.014466	 0.029728	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85230	 85262	 0.018824	 0.053991	 0.00083	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85231	 85232	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85231	 85244	 0.000691	 0.009774	 0.00324	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85231	 85290	 0.00129	 0.010845	 0.00321	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85233	 85306	 0.00435	 0.033046	 0.00075	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85234	 85235	 0.000405	 0.001674	 0.0004	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85234	 85236	 0.001185	 0.003187	 0.00089	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85238	 85239	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85238	 85333	 0.00164	 0.006564	 0.00165	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85243	 85244	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85246	 85247	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85253	 85254	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85253	 85255	 0.002737	 0.009389	 0.00225	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85258	 85270	 0.009058	 0.084325	 0.00163	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85259	 85269	 0.079791	 0.15799	 0.00232	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85260	 85261	 0.089491	 0.057938	 0.0011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85262	 85291	 0.053354	 0.069435	 0.00097	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85264	 85287	 0.001782	 0.00725	 0.00177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85269	 85270	 0.007437	 0.026039	 0.00072	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85269	 85869	 0.065013	 0.21691	 0.00344	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85269	 85871	 0.02264	 0.12115	 0.00367	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85275	 85276	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85275	 85276	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85276	 85277	 8.9e-05	 0.007142	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85278	 85281	 0.018435	 0.070923	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85280	 85281	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85281	 85286	 0.006846	 0.0377	 0.00085	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85281	 85858	 0.037983	 0.15201	 0.00321	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85289	 85292	 0.084731	 0.062341	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85290	 85291	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85291	 85293	 0.25482	 0.20171	 0.00254	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85291	 85941	 0.47751	 0.37459	 0.00481	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85293	 85296	 0.13578	 0.10746	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85297	 85973	 0.18147	 0.2753	 0.00395	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85303	 85310	 0.084558	 0.06692	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85304	 85305	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85311	 85312	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85312	 85317	 0.048401	 0.088654	 0.00153	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85314	 85316	 0.018501	 0.030856	 0.00045	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85315	 85324	 0.062081	 0.045675	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85327	 85331	 0.03058	 0.033635	 0.00045	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85329	 85330	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85333	 85334	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85335	 85353	 0.09528	 0.18675	 0.0028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85336	 85337	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85337	 85338	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85337	 85340	 0.002216	 0.014275	 0.00374	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85343	 85344	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85350	 85351	 0.000234	 0.017577	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85364	 85365	 0.008472	 0.052085	 0.00094	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85371	 85372	 0.032603	 0.08381	 0.0013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85374	 85377	 0.041019	 0.13684	 0.00217	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85376	 85377	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85378	 85715	 0.065072	 0.12884	 0.00189	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85380	 85714	 0.072086	 0.15449	 0.00271	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85381	 85382	 0.000209	 0.016699	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85381	 85384	 0.000894	 0.005806	 0.01156	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	85383	 85410	 0.070021	 0.0496	 0.00078	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85384	 85385	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85384	 85388	 0.000136	 0.001754	 0.00397	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85385	 85386	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85385	 85409	 0.00766	 0.030107	 0.00788	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85388	 85389	 0.000247	 0.018554	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85389	 85412	 0.013573	 0.071498	 0.00128	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	85390	 85391	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85391	 85423	 0.043867	 0.0922	 0.00168	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85394	 85418	 0.010965	 0.022439	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85398	 85399	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85398	 85406	 0.00534	 0.018319	 0.00439	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85400	 85403	 0.020344	 0.043433	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85406	 85407	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85409	 85410	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85411	 85418	 0.04049	 0.039775	 0.00067	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85414	 85415	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85424	 85425	 0.02281	 0.025088	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85426	 85429	 0.011716	 0.04558	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85428	 85429	 0.004422	 0.017202	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85432	 85434	 0.019634	 0.053639	 0.00091	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85435	 85436	 0.003412	 0.014438	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85435	 85442	 0.030001	 0.039043	 0.00055	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85440	 85441	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85445	 86177	 0.18325	 0.61195	 0.00971	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85446	 85453	 0.025841	 0.051163	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85449	 85451	 0.019847	 0.046071	 0.00088	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85450	 85451	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85454	 85457	 0.013694	 0.064397	 0.0012	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85454	 85921	 0.049427	 0.15164	 0.00411	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85456	 85457	 0.039511	 0.060528	 0.00085	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85461	 85462	 0.053411	 0.20781	 0.00347	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85461	 85473	 0.050704	 0.11772	 0.00175	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85468	 85469	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85469	 85482	 0.068982	 0.13659	 0.002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85469	 85483	 0.10235	 0.20061	 0.00301	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85469	 86090	 0.069949	 0.18131	 0.00343	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85472	 85476	 0.011147	 0.052419	 0.00098	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85475	 85476	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85478	 85482	 0.020938	 0.048103	 0.00073	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85480	 85481	 0.023542	 0.042478	 0.00061	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85486	 85487	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85488	 85490	 0.038604	 0.034592	 0.00071	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85491	 86010	 0.10156	 0.18326	 0.00265	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85498	 85502	 0.049576	 0.039234	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85502	 85504	 0.003173	 0.015231	 0.00046	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85509	 85511	 0.034329	 0.033169	 0.00048	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85509	 85566	 0.016857	 0.027041	 0.0005	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85511	 85512	 0.009513	 0.024454	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85514	 85560	 0.062174	 0.065414	 0.00096	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85515	 85526	 0.020597	 0.038927	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85526	 85560	 0.006449	 0.021513	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85531	 85533	 0.006457	 0.012005	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85532	 85604	 0.007697	 0.025676	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85534	 85535	 0.003061	 0.011775	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85534	 85536	 0.008295	 0.019258	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85537	 85538	 0.0147	 0.010815	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85542	 85550	 0.012164	 0.024084	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85543	 85546	 0.040241	 0.067789	 0.00097	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85550	 85551	 0.020874	 0.015089	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85553	 85598	 0.032109	 0.073434	 0.00179	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85563	 85564	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85564	 85587	 0.01726	 0.033827	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85575	 85578	 0.004281	 0.02308	 0.00047	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85581	 85582	 0.000182	 0.014521	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85587	 85589	 0.022844	 0.018078	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85597	 85598	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85597	 85600	 0.00119	 0.011631	 0.00326	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85599	 85600	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85600	 85601	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85603	 85604	 0.000101	 0.008064	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85603	 85607	 0.014807	 0.035685	 0.01008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85605	 85606	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85607	 85608	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85611	 85612	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85614	 85615	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85617	 86185	 0.12418	 0.28178	 0.00562	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85618	 85620	 0.058528	 0.22773	 0.0038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85618	 86188	 0.10886	 0.17379	 0.004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85622	 85623	 7.8e-05	 0.006228	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85622	 87088	 0.004429	 0.062169	 0.11942	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85623	 85624	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85624	 85626	 0.070193	 0.14426	 0.00275	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85624	 86143	 0.11416	 0.381	 0.00604	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85625	 85626	 0.015316	 0.059584	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85626	 86020	 0.24297	 0.46565	 0.00733	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85627	 85630	 0.066901	 0.12025	 0.00216	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85628	 85629	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85629	 85632	 0.031313	 0.12182	 0.00203	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85629	 86145	 0.35114	 0.28922	 0.00586	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85632	 85634	 0.011695	 0.023154	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85633	 85635	 0.004108	 0.02078	 0.00036	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85638	 85639	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85644	 85670	 0.01501	 0.058395	 0.00097	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85646	 85732	 0.022	 0.038689	 0.00073	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85648	 85649	 0.005325	 0.012608	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85648	 85650	 0.034965	 0.027671	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85652	 85653	 0.020502	 0.016225	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85652	 85693	 0.014593	 0.037512	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85653	 85654	 0.008444	 0.012304	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85657	 85709	 0.037817	 0.084845	 0.00135	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85660	 85730	 0.025252	 0.04836	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85661	 85662	 0.041586	 0.034229	 0.00069	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85664	 85665	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85668	 85669	 8.5e-05	 0.006812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85669	 85670	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85670	 85721	 0.015015	 0.057764	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85670	 85721	 0.015015	 0.057764	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85673	 85676	 0.019053	 0.048456	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85676	 85679	 0.008267	 0.021252	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85677	 85678	 0.01867	 0.014775	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85679	 85680	 0.045757	 0.034667	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85680	 86087	 0.007497	 0.021502	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85684	 86074	 0.018143	 0.037284	 0.00071	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85686	 85688	 0.070162	 0.15742	 0.00251	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85686	 86087	 0.13661	 0.12812	 0.00198	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85690	 85691	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85693	 85698	 0.033092	 0.060612	 0.00105	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85697	 85698	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85698	 85700	 0.093009	 0.076557	 0.00155	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85699	 85700	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85699	 85703	 0.005843	 0.015443	 0.00361	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85701	 85702	 0.005968	 0.023306	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85701	 85710	 0.005238	 0.029774	 0.00054	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85704	 85705	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85705	 85743	 0.023942	 0.05299	 0.00087	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85706	 85728	 0.073613	 0.056466	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85707	 85708	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85708	 85717	 0.077048	 0.060975	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85709	 85711	 0.005037	 0.015161	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85712	 85713	 0.013464	 0.027553	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85713	 85734	 0.069535	 0.16145	 0.0024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85716	 85718	 0.089633	 0.10927	 0.00175	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85720	 85723	 0.019567	 0.11123	 0.00201	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85722	 85723	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85726	 85727	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85727	 85732	 0.012484	 0.025547	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85729	 85730	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85733	 85949	 0.061569	 0.14295	 0.00213	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85734	 85735	 0.023541	 0.054083	 0.00082	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85734	 85737	 0.030404	 0.08628	 0.00136	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85736	 85954	 0.039451	 0.062972	 0.00145	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85737	 85749	 0.050936	 0.08495	 0.00124	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85739	 85740	 0.007542	 0.014932	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85740	 85741	 0.0147	 0.022519	 0.00032	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85740	 85742	 0.015033	 0.023995	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85741	 85742	 0.008926	 0.025601	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85743	 85745	 0.006119	 0.027264	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85744	 85745	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85747	 85748	 0.010189	 0.030667	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85751	 85752	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85759	 85760	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85760	 85761	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85762	 85763	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85765	 85766	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85766	 85771	 0.011808	 0.045938	 0.00077	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85767	 85771	 0.020882	 0.053106	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85773	 85779	 0.011	 0.026047	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85774	 85837	 0.038345	 0.03873	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85777	 85778	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85778	 85783	 0.006931	 0.034664	 0.00062	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85778	 85785	 0.010479	 0.030056	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85780	 85790	 0.017112	 0.017283	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85781	 85783	 0.026625	 0.021071	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85786	 85790	 0.013309	 0.038173	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85787	 85791	 0.00534	 0.013727	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85791	 85830	 0.013436	 0.034538	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85793	 85803	 0.025102	 0.0497	 0.00073	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85796	 85799	 0.031195	 0.047314	 0.00068	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85798	 85799	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85799	 85800	 0.00444	 0.022458	 0.00039	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85799	 85801	 0.004864	 0.014923	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85800	 85821	 0.011347	 0.057399	 0.001	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85802	 85803	 0.00199	 0.008818	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85803	 85806	 0.00934	 0.036336	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85807	 85811	 0.023032	 0.035283	 0.0005	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85811	 85813	 0.018469	 0.052973	 0.00081	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85811	 85826	 0.013158	 0.058631	 0.001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85811	 85830	 0.040013	 0.12288	 0.00231	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85813	 85826	 0.019249	 0.03811	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85814	 85818	 0.01275	 0.018906	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85815	 85817	 0.005689	 0.018979	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85821	 85822	 0.016887	 0.064969	 0.00111	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85829	 85830	 0.017615	 0.023151	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85833	 85834	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85841	 85844	 0.00371	 0.011382	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85841	 85844	 0.00371	 0.011382	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85841	 85857	 0.010459	 0.041926	 0.00108	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85841	 85920	 0.012219	 0.069461	 0.00126	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85843	 85844	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85854	 85855	 0.006116	 0.011203	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85858	 85859	 0.062219	 0.12319	 0.00181	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85862	 85866	 0.026775	 0.076796	 0.00118	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85864	 85866	 0.028254	 0.07263	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85865	 85866	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85866	 85867	 0.057254	 0.14562	 0.0023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85867	 85869	 0.033004	 0.084842	 0.00131	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85868	 85872	 0.017412	 0.053472	 0.001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85869	 85871	 0.012622	 0.049101	 0.00082	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85874	 85876	 0.010345	 0.024497	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85876	 85877	 0.003453	 0.012091	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85877	 85879	 0.020214	 0.067432	 0.00107	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85882	 85895	 0.010275	 0.035953	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85883	 85895	 0.029324	 0.061633	 0.00112	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	85883	 85921	 0.013824	 0.036543	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85887	 85888	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85889	 85906	 0.007312	 0.028557	 0.00063	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85890	 85892	 0.002522	 0.020982	 0.0004	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85891	 85892	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85893	 85895	 0.002375	 0.016305	 0.0003	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85897	 85898	 0.008839	 0.027145	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85904	 85906	 0.002616	 0.014406	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85905	 85906	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85908	 85910	 0.072767	 0.057587	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85908	 85912	 0.071323	 0.14122	 0.00207	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85909	 85918	 0.017431	 0.044152	 0.00087	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85912	 85920	 0.00973	 0.037852	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85918	 85919	 0.00663	 0.023686	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85925	 85926	 0.004197	 0.016326	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85925	 85936	 0.013664	 0.045582	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85926	 85937	 0.050486	 0.050498	 0.00068	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85928	 85947	 0.020653	 0.039033	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85930	 85931	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85933	 85935	 0.00622	 0.024196	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85940	 85941	 0.013614	 0.044926	 0.00073	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85943	 85944	 0.007122	 0.022933	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85943	 85945	 0.007617	 0.017277	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	85952	 85953	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85959	 85960	 0.010742	 0.027209	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	85966	 85967	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85972	 85973	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85975	 85976	 0.022353	 0.10908	 0.00188	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85977	 85978	 0.040003	 0.17627	 0.00306	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85978	 85979	 0.033602	 0.11766	 0.00326	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	85979	 85981	 0.009038	 0.044102	 0.00076	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	85980	 85981	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85984	 85985	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	85987	 85990	 0.055222	 0.31037	 0.00575	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	85987	 85995	 0.00834	 0.051276	 0.00092	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	85989	 85990	 0.006415	 0.032084	 0.00057	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	85999	 86000	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86001	 86002	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86004	 86018	 0.024809	 0.025058	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86005	 86006	 0.04638	 0.030026	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86009	 86011	 0.016018	 0.056046	 0.00116	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86012	 86013	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86013	 86015	 0.066347	 0.067013	 0.00089	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86019	 86020	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86023	 86024	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86027	 86030	 0.007074	 0.048561	 0.00089	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86031	 86032	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86032	 86033	 0.002394	 0.013453	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86032	 86043	 0.009151	 0.03269	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86035	 86036	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86036	 86037	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86046	 86048	 0.008215	 0.027404	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86048	 86049	 0.027694	 0.10774	 0.0018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86052	 86053	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86053	 86054	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86059	 86069	 0.026774	 0.066454	 0.0011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86059	 86138	 0.032843	 0.084429	 0.00131	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86061	 86062	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86062	 86063	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86063	 86069	 0.019391	 0.082903	 0.00187	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86064	 86068	 0.014592	 0.03751	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86067	 86068	 0.016972	 0.02709	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86067	 86069	 0.020292	 0.052162	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86072	 86073	 0.034205	 0.026238	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86074	 86087	 0.029359	 0.058128	 0.00085	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86075	 86076	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86086	 86087	 0.035327	 0.038478	 0.00052	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86088	 86095	 0.05032	 0.070131	 0.0012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86091	 86092	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86092	 86093	 0.013832	 0.08504	 0.00153	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86094	 86095	 0.048699	 0.11189	 0.0017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86102	 86103	 0.011875	 0.021211	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86106	 86107	 0.010919	 0.024496	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86108	 86141	 0.007588	 0.033434	 0.00058	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86117	 86118	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86120	 86121	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86121	 86122	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86129	 86133	 0.011912	 0.024377	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86131	 86132	 0.002019	 0.008218	 0.002	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86132	 86133	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86140	 86141	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86144	 86145	 0.031756	 0.12354	 0.00206	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86146	 86148	 0.071723	 0.38231	 0.00671	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	86147	 86148	 0.032903	 0.12659	 0.00216	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86149	 86510	 0.26169	 0.50159	 0.0079	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86150	 86491	 0.06664	 0.22233	 0.00352	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86150	 86493	 0.035772	 0.10151	 0.0016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86150	 86530	 0.037011	 0.14399	 0.0024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86151	 86153	 0.009702	 0.041668	 0.00076	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86152	 86154	 0.005306	 0.02351	 0.00071	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86152	 86528	 0.04775	 0.12275	 0.0019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86157	 86158	 0.022685	 0.065063	 0.001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86158	 86606	 0.046342	 0.11913	 0.00184	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86159	 86217	 0.025561	 0.14531	 0.00263	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86159	 86249	 0.12566	 0.29178	 0.00556	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86159	 86454	 0.17966	 0.41731	 0.00621	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86163	 86164	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86163	 86653	 0.015931	 0.098897	 0.02397	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86164	 86661	 0.42887	 0.45164	 0.00661	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86167	 86170	 0.007794	 0.064842	 0.00123	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86171	 86172	 0.000101	 0.008064	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86172	 86520	 0.026398	 0.11763	 0.002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86174	 86175	 0.074799	 0.16556	 0.00271	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86176	 86616	 0.073779	 0.28279	 0.008	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86177	 86282	 0.028968	 0.16278	 0.00301	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86177	 86283	 0.089251	 0.21138	 0.00387	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86181	 86534	 0.15077	 0.39993	 0.01015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86184	 86185	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86186	 86188	 0.050412	 0.090046	 0.00133	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86187	 86188	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86189	 86619	 0.1343	 0.34534	 0.00535	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86193	 86195	 0.009568	 0.074574	 0.00139	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86199	 86200	 9.4e-05	 0.007517	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86200	 86201	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86201	 86203	 0.009879	 0.025602	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86201	 86548	 0.16509	 0.42461	 0.00658	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86205	 86354	 0.029753	 0.091277	 0.00247	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86207	 86208	 0.011793	 0.023349	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86211	 86213	 0.022459	 0.1096	 0.00189	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86211	 86376	 0.025453	 0.11342	 0.00193	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86215	 86255	 0.025695	 0.049208	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86216	 86218	 0.026726	 0.068702	 0.00106	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86216	 86247	 0.082931	 0.083764	 0.00111	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86219	 86225	 0.023184	 0.048727	 0.00089	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86220	 86602	 0.017515	 0.089123	 0.00202	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86226	 86229	 0.007237	 0.023881	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86227	 86228	 0.003817	 0.021698	 0.00039	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86228	 86233	 0.009224	 0.021416	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86229	 86243	 0.015468	 0.036628	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86229	 86434	 0.041536	 0.081405	 0.00122	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86230	 86232	 0.012726	 0.038303	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86232	 86512	 0.015329	 0.087138	 0.00158	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86234	 86235	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86237	 86243	 0.038566	 0.088603	 0.00135	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86238	 86239	 0.012435	 0.026134	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86240	 86241	 0.017517	 0.031288	 0.00046	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86243	 86442	 0.009146	 0.024242	 0.00061	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86248	 86262	 0.01435	 0.074621	 0.00162	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86252	 86262	 0.0181	 0.042015	 0.0008	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86261	 86262	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86264	 86267	 0.011794	 0.027928	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86264	 86268	 0.017498	 0.03596	 0.00069	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86264	 86275	 0.013317	 0.091411	 0.00167	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86272	 86417	 0.039226	 0.039235	 0.00053	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86275	 86276	 0.012641	 0.032496	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86276	 86346	 0.016143	 0.078774	 0.00136	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86278	 86279	 0.012355	 0.070234	 0.00127	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86278	 86533	 0.066681	 0.36739	 0.0083	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86280	 86654	 0.072447	 0.44567	 0.00804	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86283	 86569	 0.12017	 0.30899	 0.00478	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86286	 86289	 0.033534	 0.096183	 0.00148	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86290	 86834	 0.035012	 0.13621	 0.00227	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86294	 86295	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86300	 86701	 0.13189	 0.24931	 0.00403	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86301	 86641	 0.12172	 0.28265	 0.0042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86302	 86303	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86310	 86311	 8.5e-05	 0.006812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86311	 86312	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86317	 86326	 0.02853	 0.065546	 0.001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86319	 86320	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86320	 86330	 0.035419	 0.12394	 0.00257	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86320	 86478	 0.006686	 0.029793	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86322	 86324	 0.080015	 0.051803	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86324	 86328	 0.006969	 0.031052	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86326	 86327	 0.008628	 0.042123	 0.00088	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	86331	 86332	 0.011395	 0.034296	 0.00067	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86340	 86342	 0.04313	 0.066071	 0.00093	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86341	 86343	 0.019095	 0.073163	 0.00207	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86341	 86651	 0.21372	 0.54401	 0.00861	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86342	 86651	 0.19124	 0.39167	 0.00965	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86345	 86346	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86347	 86349	 0.046827	 0.091774	 0.00138	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86348	 86350	 0.009116	 0.045232	 0.00108	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86352	 86568	 0.15891	 0.36522	 0.00555	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86354	 86355	 0.025833	 0.11382	 0.00198	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86356	 86357	 0.001164	 0.012875	 0.00386	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86359	 86703	 0.087651	 0.30703	 0.0085	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86361	 86519	 0.027946	 0.12385	 0.00372	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86368	 86369	 0.021075	 0.070305	 0.00111	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86371	 86374	 0.054522	 0.15473	 0.00243	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86375	 86617	 0.038682	 0.13214	 0.00287	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86377	 86379	 0.040602	 0.065131	 0.0012	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86383	 86510	 0.051003	 0.19844	 0.00331	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86385	 86390	 0.003764	 0.01448	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86385	 86410	 0.010446	 0.024251	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86385	 86412	 0.007452	 0.021374	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86386	 86412	 0.007652	 0.029439	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86395	 86440	 0.004016	 0.01862	 0.00039	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86396	 86398	 0.009035	 0.023883	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86399	 86441	 0.012849	 0.03303	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86405	 86407	 0.005331	 0.038963	 0.00072	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86412	 86416	 0.035819	 0.057174	 0.00132	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86419	 86420	 0.008006	 0.031146	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86420	 86437	 0.026183	 0.060153	 0.00091	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86422	 86423	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86422	 86423	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86422	 86427	 0.001005	 0.016027	 0.03291	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86423	 86424	 9.8e-05	 0.007812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86427	 86428	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86427	 86428	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86428	 86429	 9.8e-05	 0.007812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86433	 86435	 0.008514	 0.027034	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86445	 86548	 0.11388	 0.50785	 0.00863	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86446	 86447	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86446	 86448	 0.004271	 0.021058	 0.00569	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86446	 86450	 0.007055	 0.02986	 0.00672	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86448	 86449	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86448	 86450	 0.002605	 0.009078	 0.0021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86452	 86453	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86454	 86575	 0.096485	 0.17411	 0.00252	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86457	 86458	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86458	 86459	 0.038487	 0.14808	 0.00253	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86458	 86459	 0.038487	 0.14808	 0.00253	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86459	 86460	 0.020776	 0.11674	 0.00216	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86459	 86572	 0.10623	 0.27312	 0.00423	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86462	 86472	 0.075394	 0.21627	 0.00333	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86468	 86469	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86469	 86470	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86471	 86472	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86482	 86485	 0.061533	 0.14286	 0.00212	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86496	 86529	 0.017419	 0.077189	 0.00232	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86499	 86500	 0.041851	 0.074754	 0.0011	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86500	 86528	 0.050128	 0.15395	 0.00289	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86501	 86504	 0.023723	 0.079138	 0.00125	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86502	 86504	 0.011861	 0.039567	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86508	 86509	 0.072503	 0.1981	 0.00337	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86519	 86675	 0.13902	 0.49706	 0.00988	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86526	 86527	 0.011123	 0.062498	 0.00116	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86529	 86530	 0.023169	 0.10324	 0.00175	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86534	 86629	 0.27696	 0.63707	 0.00969	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86534	 86640	 0.043597	 0.26809	 0.00483	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86539	 86540	 0.013578	 0.076291	 0.00141	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86542	 86543	 0.040343	 0.078166	 0.00168	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86543	 86651	 0.086199	 0.43629	 0.0076	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86544	 86548	 0.13645	 0.26748	 0.00401	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86545	 86548	 0.10052	 0.23098	 0.00351	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86546	 86547	 0.045077	 0.08925	 0.00131	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86546	 86548	 0.054449	 0.15063	 0.0035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86549	 86550	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86552	 86554	 0.015904	 0.042153	 0.00107	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86556	 86557	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86559	 86561	 0.049607	 0.12616	 0.002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86560	 86561	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86566	 86664	 0.071179	 0.23748	 0.00377	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86570	 86571	 0.000318	 0.022264	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86574	 86575	 0.0453	 0.093096	 0.00178	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86577	 86587	 0.01736	 0.049791	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86577	 86588	 0.009651	 0.022853	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86582	 86586	 0.011606	 0.021934	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86582	 86590	 0.027521	 0.045964	 0.00078	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86585	 86587	 0.05002	 0.062853	 0.00095	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86586	 86587	 0.051953	 0.055482	 0.00117	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86594	 86596	 0.023339	 0.077859	 0.00123	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86595	 86596	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86596	 86600	 0.021503	 0.06102	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86597	 86598	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86604	 86605	 0.034027	 0.13238	 0.00221	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86606	 86607	 0.031413	 0.074385	 0.00136	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86607	 86608	 0.0354	 0.090029	 0.00142	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86610	 86620	 0.022828	 0.1549	 0.00289	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86616	 86690	 0.5012	 0.50679	 0.00671	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86619	 86620	 0.022475	 0.087437	 0.00146	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86629	 86630	 0.011746	 0.04196	 0.00083	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86629	 86630	 0.011746	 0.04196	 0.00083	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86629	 86633	 0.041216	 0.09569	 0.00142	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86635	 86636	 0.021383	 0.049643	 0.00074	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86645	 86646	 0.018224	 0.060792	 0.00096	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86651	 86656	 0.20387	 0.3736	 0.00645	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86652	 86675	 0.17601	 0.45273	 0.00701	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86653	 86654	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86655	 86657	 0.026354	 0.14982	 0.00271	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86668	 86670	 0.077072	 0.1003	 0.0014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86674	 86676	 0.023294	 0.15991	 0.00292	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86677	 86696	 0.25231	 0.26957	 0.0057	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86694	 86696	 0.007776	 0.040961	 0.00074	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	86697	 86698	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86699	 86700	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86702	 86703	 0.064759	 0.21606	 0.00343	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86704	 86705	 7.8e-05	 0.006228	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86705	 86706	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86707	 86891	 0.011985	 0.11158	 0.00216	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86707	 86922	 0.039806	 0.1328	 0.0021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86708	 86709	 0.017116	 0.11749	 0.00214	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86709	 86893	 0.031371	 0.12447	 0.00355	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86711	 86832	 0.018825	 0.084787	 0.02257	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86712	 86722	 0.005347	 0.038082	 0.00086	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86721	 86746	 0.051878	 0.38573	 0.0092	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86724	 86725	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86730	 86731	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86731	 86732	 0.026039	 0.091111	 0.00189	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86737	 86738	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86739	 86740	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86740	 86741	 0.024025	 0.073779	 0.00138	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86747	 86748	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86748	 86749	 0.01677	 0.065241	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86748	 86749	 0.01677	 0.065241	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86748	 86911	 0.051469	 0.15791	 0.00428	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86748	 86911	 0.051469	 0.15791	 0.00428	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86750	 86751	 0.014495	 0.05639	 0.00094	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86750	 86751	 0.014495	 0.05639	 0.00094	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86751	 86752	 0.048414	 0.14854	 0.00402	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86751	 86752	 0.048414	 0.14854	 0.00402	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86757	 86761	 0.24776	 0.19612	 0.00247	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86758	 86768	 0.03935	 0.12495	 0.00219	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86759	 86760	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86761	 86762	 0.026711	 0.048196	 0.0007	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86763	 86764	 0.034054	 0.067425	 0.00099	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86765	 86766	 0.029722	 0.049368	 0.00105	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86770	 86773	 0.009	 0.036015	 0.00076	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86771	 86787	 0.007731	 0.022175	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86772	 86773	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86773	 86786	 0.011786	 0.066994	 0.00121	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86774	 86984	 0.016615	 0.12566	 0.00418	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86777	 86778	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86779	 86783	 0.009085	 0.081175	 0.00192	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86780	 86781	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86784	 86793	 0.007744	 0.050409	 0.00102	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86786	 86790	 0.034474	 0.087674	 0.00139	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86788	 86831	 0.005549	 0.024727	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86791	 86792	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86792	 86793	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86801	 86804	 0.009123	 0.071102	 0.00133	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86803	 86804	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86803	 86836	 0.019715	 0.11752	 0.03094	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86804	 86835	 0.17551	 0.40342	 0.00613	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86805	 86807	 0.13343	 0.33944	 0.00537	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86807	 86809	 0.039674	 0.1768	 0.003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86817	 86818	 0.041179	 0.07657	 0.00179	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86819	 86820	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86823	 86824	 0.039815	 0.17024	 0.00385	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86823	 86972	 0.015152	 0.1394	 0.00276	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86824	 86825	 0.010946	 0.097799	 0.00231	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86825	 86827	 0.007207	 0.034594	 0.00103	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86825	 86828	 0.03669	 0.078333	 0.00177	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86832	 86833	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86837	 86838	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86839	 86845	 0.018553	 0.041064	 0.00067	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86839	 86846	 0.016349	 0.092935	 0.00168	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	86840	 86847	 0.039267	 0.17302	 0.00301	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86844	 86845	 0.018815	 0.059742	 0.00105	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86846	 86849	 0.014338	 0.092507	 0.00294	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86850	 87058	 0.38588	 0.39001	 0.00517	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86855	 86856	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86856	 86857	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86859	 86862	 0.025896	 0.074273	 0.00114	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86862	 86873	 0.019877	 0.06955	 0.00144	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86863	 86887	 0.009383	 0.036501	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86865	 86888	 0.021467	 0.049094	 0.0012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86868	 87044	 0.009127	 0.051357	 0.00111	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86871	 86873	 0.053739	 0.13815	 0.00214	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86872	 86873	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86873	 86875	 0.047497	 0.084839	 0.00125	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86876	 86877	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86878	 86879	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86879	 86882	 0.093306	 0.084186	 0.00141	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86883	 86884	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86885	 86886	 0.000109	 0.008719	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86885	 86886	 0.000109	 0.008719	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86886	 86887	 8.2e-05	 0.006578	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86892	 86926	 0.040919	 0.13504	 0.00219	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86893	 86894	 0.013306	 0.096125	 0.00181	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86907	 86909	 0.010387	 0.04041	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86907	 86909	 0.010387	 0.04041	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86908	 86909	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86910	 86911	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86914	 87016	 0.01246	 0.059808	 0.00179	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86920	 86921	 0.04609	 0.11848	 0.00183	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86923	 87047	 0.050501	 0.20971	 0.00546	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86927	 86934	 0.00501	 0.02442	 0.00046	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86927	 86935	 0.007866	 0.037953	 0.00067	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86927	 87001	 0.006693	 0.029324	 0.00063	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86928	 86929	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86929	 86932	 0.004455	 0.021496	 0.00038	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86929	 86946	 0.012253	 0.043771	 0.00087	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86929	 86952	 0.036122	 0.083862	 0.00125	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86929	 87008	 0.00595	 0.040372	 0.00075	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86931	 86933	 0.045171	 0.044198	 0.00063	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86931	 87008	 0.002726	 0.018498	 0.00035	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86933	 86934	 0.017992	 0.041771	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86938	 86939	 0.008565	 0.045832	 0.00139	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86939	 86940	 0.03415	 0.14454	 0.00273	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	86944	 86945	 0.012361	 0.084847	 0.00155	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	86956	 86957	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86959	 86960	 0.02538	 0.070303	 0.00116	 64.0	 67.2	 70.4	 0.0	 0.0	 0	 -30.0	 30.0;
	86962	 86963	 0.007806	 0.041122	 0.00074	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	86964	 86965	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86967	 86968	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86969	 86970	 0.009785	 0.071521	 0.00132	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	86972	 86974	 0.069712	 0.1848	 0.00469	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86973	 86974	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86975	 86976	 0.035566	 0.10201	 0.00157	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86978	 86979	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86978	 86982	 0.001752	 0.016821	 0.00489	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	86979	 86980	 0.004191	 0.017493	 0.0005	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	86981	 86982	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86981	 86982	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86982	 86983	 8.9e-05	 0.007142	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86985	 86994	 0.03138	 0.065952	 0.0012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	86988	 86992	 0.010672	 0.049454	 0.00095	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	86989	 86990	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	86997	 87011	 0.032478	 0.083488	 0.00129	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87000	 87019	 0.03952	 0.028569	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87002	 87019	 0.056162	 0.090379	 0.00142	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87003	 87004	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87030	 87031	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87033	 87034	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87034	 87047	 0.058502	 0.23914	 0.00484	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87041	 87042	 0.004781	 0.025679	 0.00061	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87043	 87044	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87048	 87052	 0.033425	 0.085925	 0.00133	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87053	 87054	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87055	 87056	 0.018419	 0.061444	 0.00097	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87057	 87059	 0.027146	 0.10444	 0.00178	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87060	 87062	 0.046547	 0.10807	 0.00161	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87061	 87063	 0.00438	 0.036834	 0.01091	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87063	 87064	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87065	 87066	 9.1e-05	 0.007266	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87066	 87067	 0.000136	 0.010869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87069	 87078	 0.059952	 0.078023	 0.00109	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87071	 87072	 0.012246	 0.062313	 0.00141	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87071	 87073	 0.022272	 0.12515	 0.00232	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87076	 87079	 0.00241	 0.022432	 0.00695	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87079	 87080	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87081	 87082	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 0	 -30.0	 30.0;
	87081	 87082	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 0	 -30.0	 30.0;
	87081	 87085	 0.010222	 0.081102	 0.28309	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87081	 87101	 0.001018	 0.0085	 0.01476	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87081	 87104	 0.009316	 0.064247	 0.11362	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87081	 87112	 0.008734	 0.080408	 0.31939	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87081	 87114	 0.016371	 0.10668	 0.21367	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87081	 87465	 0.001738	 0.011727	 0.02159	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87082	 87100	 0.003671	 0.030465	 0.00801	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87083	 87084	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87083	 87084	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87083	 87327	 0.032127	 0.16673	 0.04077	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87085	 87086	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87085	 87086	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87086	 87087	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87086	 87087	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87087	 87400	 0.085767	 0.24603	 0.00378	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87087	 87416	 0.028574	 0.18886	 0.00372	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87088	 87089	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87088	 87089	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87088	 87280	 0.006105	 0.038686	 0.08108	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87088	 87317	 0.002596	 0.029036	 0.05361	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87089	 87090	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87089	 87090	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87092	 87093	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87092	 87093	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87093	 87094	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87093	 87094	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87093	 87610	 0.026243	 0.090056	 0.02158	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87095	 87096	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87095	 87096	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87097	 87098	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87097	 87098	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87097	 87293	 0.01014	 0.069261	 0.12497	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87098	 87099	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87098	 87099	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87099	 87628	 0.57262	 0.57921	 0.00767	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87101	 87582	 0.000169	 0.002701	 0.00555	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87102	 87103	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87102	 87103	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87104	 87105	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87104	 87105	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87107	 87109	 0.007861	 0.077916	 0.02387	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87108	 87109	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87108	 87109	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87108	 87302	 0.001701	 0.022613	 0.04832	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87110	 87111	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87110	 87111	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87111	 87450	 0.037097	 0.22811	 0.00411	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87112	 87113	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87112	 87113	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87112	 88540	 0.001766	 0.015218	 0.02863	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87114	 87115	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87114	 87115	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87114	 87498	 0.010516	 0.071454	 0.13039	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87116	 87117	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87116	 87117	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87116	 87655	 0.00051	 0.003752	 0.00734	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87118	 87466	 0.034593	 0.13458	 0.00225	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87118	 87466	 0.034593	 0.13458	 0.00225	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87119	 87120	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87119	 87120	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87119	 87541	 0.001797	 0.01796	 0.03715	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87119	 87655	 0.00071	 0.004892	 0.00864	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87122	 87310	 0.075725	 0.25266	 0.00401	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87127	 87128	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87127	 87128	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87128	 87272	 0.32334	 0.42523	 0.00583	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87129	 87630	 0.90301	 0.71662	 0.00902	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87131	 87494	 0.14057	 0.46924	 0.00744	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87132	 87133	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87132	 87133	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87134	 87657	 0.023146	 0.17201	 0.0041	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87136	 87504	 0.026002	 0.15804	 0.00292	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87140	 87304	 0.17922	 0.2356	 0.00323	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87141	 87142	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87141	 87142	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87143	 87144	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87143	 87144	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87145	 87146	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87145	 87146	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87145	 87792	 0.003116	 0.040255	 0.09129	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87146	 87147	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87146	 87147	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87148	 87149	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87148	 87149	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87150	 87151	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87150	 87151	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87150	 88001	 0.003704	 0.025517	 0.04506	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87151	 87152	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87151	 87152	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87151	 88010	 0.008684	 0.083404	 0.02427	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87151	 88013	 0.025089	 0.067367	 0.01527	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87152	 87826	 0.32354	 0.64138	 0.00943	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87153	 87154	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87153	 87154	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87155	 87156	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87155	 87156	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87158	 87938	 0.013248	 0.053915	 0.01314	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87159	 87160	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87159	 87160	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87163	 87164	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87163	 87164	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87164	 87165	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87164	 87165	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87166	 87167	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87166	 87167	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87169	 87170	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87169	 87170	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87171	 88000	 0.018882	 0.058726	 0.01226	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87172	 88067	 0.072967	 0.28079	 0.00479	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87173	 87174	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87173	 87174	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87174	 87947	 0.008719	 0.02991	 0.00717	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87175	 87176	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87175	 87176	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87176	 87953	 0.006115	 0.049639	 0.01581	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87178	 87179	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87178	 87179	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87180	 87181	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87180	 87181	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87182	 87183	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87182	 87183	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87184	 87185	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87184	 87185	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87185	 87186	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87185	 87186	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87187	 88204	 0.065851	 0.33522	 0.0076	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87188	 87189	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87188	 87189	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87190	 87191	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87190	 87191	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87190	 88704	 0.001282	 0.008381	 0.0031	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87191	 88099	 0.012017	 0.034101	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87194	 88134	 0.010414	 0.05268	 0.00092	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87196	 87197	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87196	 87197	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87196	 87498	 0.003386	 0.044096	 0.09843	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87198	 87199	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87198	 87199	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87199	 87200	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87199	 87200	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87200	 88244	 0.14775	 0.31672	 0.00555	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87202	 87203	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87202	 87203	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87203	 88251	 0.01802	 0.10244	 0.00185	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87206	 87207	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87206	 87207	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87206	 91884	 0.007844	 0.07496	 0.27524	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87208	 88109	 0.002332	 0.014335	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87210	 87211	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87210	 87211	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87212	 87213	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87212	 87213	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87214	 87215	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87214	 87215	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87215	 87216	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87215	 87216	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87215	 88452	 0.012445	 0.051387	 0.01216	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87216	 88438	 0.026269	 0.16151	 0.00291	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87217	 87218	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87217	 87218	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87217	 88506	 0.003257	 0.01304	 0.00329	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87219	 87220	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87219	 87220	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87220	 88431	 0.002479	 0.021966	 0.00585	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87222	 87223	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87222	 87223	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87224	 87225	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87224	 87225	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87225	 88759	 0.088756	 0.15954	 0.00287	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87226	 87227	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87226	 87227	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87226	 88585	 0.000879	 0.011483	 0.03718	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87227	 87228	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87227	 87228	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87229	 87230	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87229	 87230	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87230	 87231	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87230	 87231	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87231	 87235	 0.099407	 0.23082	 0.00343	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87231	 88464	 0.07089	 0.16288	 0.00247	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87232	 87233	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87232	 87233	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87233	 88468	 0.02815	 0.099538	 0.02244	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87234	 87235	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87234	 87235	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87236	 87237	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87236	 87237	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87238	 87239	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87238	 87239	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87240	 87241	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87240	 87241	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87242	 88283	 0.14196	 0.25523	 0.00458	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87242	 88616	 0.21286	 0.43601	 0.01074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87245	 88444	 0.052137	 0.03769	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87245	 88451	 0.04822	 0.12396	 0.00192	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87246	 87247	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87246	 87247	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87248	 88532	 0.049897	 0.2112	 0.00398	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87253	 87254	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87256	 87257	 0.001067	 0.009444	 0.00519	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87260	 87534	 0.097808	 0.24879	 0.00393	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87268	 87269	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87268	 87327	 0.075141	 0.2099	 0.04415	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87270	 87271	 0.30014	 0.2376	 0.00299	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87270	 87637	 0.10556	 0.20691	 0.0031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87274	 87605	 0.052441	 0.20404	 0.00341	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87278	 87444	 0.17502	 0.48514	 0.00802	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87278	 87591	 0.17335	 0.49753	 0.00766	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87279	 87658	 0.13806	 0.42425	 0.00797	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87280	 87281	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87280	 87317	 0.005228	 0.034198	 0.06714	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87282	 87283	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87282	 87317	 0.003424	 0.021688	 0.04543	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87284	 87290	 0.044991	 0.054847	 0.00088	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87289	 87310	 0.49154	 0.38931	 0.0049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87293	 87294	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87294	 87295	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87299	 87300	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87299	 87300	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87302	 87303	 0.000109	 0.008719	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87303	 87304	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87305	 87343	 0.17847	 0.36547	 0.009	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87306	 87653	 0.21227	 0.49316	 0.00734	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87306	 88179	 0.20886	 0.48524	 0.00722	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87307	 87657	 0.027586	 0.14346	 0.00311	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87308	 87309	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87313	 87361	 0.15874	 0.25347	 0.00584	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87327	 87328	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87327	 87374	 0.02905	 0.099696	 0.0239	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87328	 87591	 0.6098	 0.39545	 0.00752	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87335	 87589	 0.20102	 0.35921	 0.0053	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87340	 87505	 0.074043	 0.17191	 0.00256	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87342	 87630	 0.43176	 0.46045	 0.00657	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87343	 87563	 0.013838	 0.1066	 0.00204	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87345	 87561	 0.10414	 0.40532	 0.00677	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87346	 87347	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87352	 87356	 0.067017	 0.19223	 0.00296	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87354	 87355	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87356	 87505	 0.10184	 0.19962	 0.00299	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87358	 87500	 0.20067	 0.33817	 0.00482	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87365	 87366	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87367	 87368	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87369	 87370	 0.02102	 0.0488	 0.00073	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87372	 87373	 0.060359	 0.065744	 0.0009	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87374	 87375	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87383	 87391	 0.01292	 0.029992	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87387	 87397	 0.010616	 0.051804	 0.00089	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87388	 87392	 0.020604	 0.016305	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87391	 87396	 0.009624	 0.024475	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87394	 87395	 0.001705	 0.008147	 0.00018	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87400	 87401	 0.005832	 0.035857	 0.00065	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87407	 87421	 0.016547	 0.030308	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87408	 87424	 0.018831	 0.062819	 0.001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87410	 87411	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87411	 87423	 0.13602	 0.10765	 0.00136	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87418	 87421	 0.060694	 0.066757	 0.00089	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87419	 87420	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87425	 87426	 0.017764	 0.035172	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87429	 87430	 9.8e-05	 0.007812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87435	 87436	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87439	 87583	 0.022227	 0.059682	 0.01353	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87440	 87584	 0.19598	 0.15511	 0.00195	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87455	 87456	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87456	 87457	 0.001701	 0.010026	 0.00816	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87458	 87459	 0.001963	 0.006404	 0.0017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87459	 87460	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87461	 87463	 0.003565	 0.009421	 0.00221	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87463	 87464	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87473	 87491	 0.014485	 0.055728	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87473	 87491	 0.014485	 0.055728	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87474	 87482	 0.025052	 0.019826	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87485	 87487	 0.05106	 0.11731	 0.00178	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87489	 87491	 0.024914	 0.046325	 0.00108	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87493	 87501	 0.13289	 0.26317	 0.00386	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87496	 87499	 0.019054	 0.078688	 0.01862	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87497	 88187	 0.064497	 0.17338	 0.03935	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87498	 87499	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87500	 87660	 0.36651	 0.36682	 0.00496	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87517	 87558	 0.026957	 0.03227	 0.00054	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87519	 87523	 0.056975	 0.040359	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87522	 87525	 0.018072	 0.021634	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87524	 87526	 0.036768	 0.029098	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87532	 87533	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87532	 87541	 0.002329	 0.023543	 0.05343	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87532	 87541	 0.002329	 0.023543	 0.05343	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87533	 87534	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87536	 87560	 0.064249	 0.049283	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87539	 87540	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87542	 87543	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87546	 87547	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87554	 87555	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87557	 87558	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87562	 87564	 0.002967	 0.016864	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87563	 87564	 0.013594	 0.052886	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87563	 87564	 0.013594	 0.052886	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87570	 87574	 0.006748	 0.041486	 0.00075	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87578	 87579	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87582	 87583	 7.6e-05	 0.006055	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87583	 87584	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87585	 87588	 0.30395	 0.24062	 0.00303	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87594	 87595	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87594	 87599	 0.002982	 0.009948	 0.00252	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87595	 87596	 0.020152	 0.033947	 0.00048	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87598	 87599	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87598	 87600	 0.000331	 0.003098	 0.01174	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87611	 87612	 0.042529	 0.033657	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87616	 87618	 0.072701	 0.056987	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87620	 87621	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87624	 87625	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87633	 87641	 0.045954	 0.036021	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87636	 87649	 0.018576	 0.044768	 0.01264	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87638	 87639	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87641	 87642	 0.031616	 0.02502	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87642	 87643	 0.047037	 0.037225	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87642	 87644	 0.1023	 0.08096	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87642	 87647	 0.066201	 0.047857	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87648	 87649	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87653	 87654	 0.095131	 0.22089	 0.00329	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87655	 87656	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87661	 87993	 0.072693	 0.23993	 0.00389	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87664	 87665	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87665	 87993	 0.10238	 0.34164	 0.00542	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87667	 87992	 0.10893	 0.18351	 0.00261	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87670	 87679	 0.00467	 0.023358	 0.00042	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87672	 87673	 8.3e-05	 0.006605	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87673	 87674	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87676	 87678	 0.03379	 0.086862	 0.00134	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87677	 87678	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87678	 87922	 0.01062	 0.065289	 0.00118	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87682	 87778	 0.045625	 0.22267	 0.00384	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87683	 88041	 0.077732	 0.19984	 0.00309	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87686	 87687	 0.002975	 0.022295	 0.00544	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87687	 87688	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87691	 87692	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87694	 87695	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87697	 87987	 0.10759	 0.41414	 0.00707	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87697	 87987	 0.10759	 0.41414	 0.00707	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87700	 87885	 0.036808	 0.033904	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87705	 87706	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87706	 87707	 0.014859	 0.065467	 0.00114	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87708	 87710	 0.020533	 0.0169	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87710	 87713	 0.012225	 0.025693	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87711	 87714	 0.021745	 0.050484	 0.00075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87712	 87714	 0.017842	 0.06941	 0.00116	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87714	 87917	 0.016327	 0.029903	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87716	 87865	 0.32304	 0.6404	 0.00941	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87723	 87724	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87723	 87828	 0.027655	 0.097789	 0.02205	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87726	 87727	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87726	 88561	 0.006655	 0.057083	 0.01625	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95343	 87731	 0.009018	 0.086272	 0.31731	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87733	 87934	 0.04876	 0.29986	 0.00541	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87736	 87737	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87736	 87952	 0.013272	 0.067151	 0.0187	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87736	 88069	 0.014293	 0.06766	 0.01627	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87739	 87745	 0.087698	 0.17189	 0.00258	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87741	 87742	 0.024277	 0.024521	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87741	 87746	 0.019136	 0.041008	 0.00072	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87751	 87755	 0.013109	 0.012075	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87758	 87759	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87759	 87762	 0.032937	 0.033268	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87760	 87761	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87760	 87780	 0.000457	 0.00405	 0.00222	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87771	 87772	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87776	 87777	 8.5e-05	 0.006812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87777	 87778	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87780	 87781	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87782	 88035	 0.075231	 0.29274	 0.00489	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87784	 87785	 0.041442	 0.08481	 0.00209	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87785	 88020	 0.11108	 0.35642	 0.00883	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87790	 87791	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87790	 88399	 0.038932	 0.16495	 0.03717	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87792	 87793	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87797	 87798	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87798	 87799	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87800	 87960	 0.07203	 0.31568	 0.00679	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87803	 87991	 0.04632	 0.28484	 0.00514	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87808	 87809	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87812	 87813	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87813	 87931	 0.074782	 0.19226	 0.00298	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87819	 88009	 0.19405	 0.30989	 0.00714	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87826	 87827	 0.16647	 0.1305	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87826	 87948	 0.22769	 0.57964	 0.00918	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87832	 87835	 0.004089	 0.015908	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87833	 87834	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87833	 87906	 0.001317	 0.008548	 0.01703	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	87834	 87835	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87839	 87840	 0.003199	 0.015612	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87839	 87905	 0.016959	 0.035644	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87840	 87853	 0.035972	 0.046814	 0.00065	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87842	 87845	 0.002408	 0.016532	 0.0003	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87844	 87845	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87849	 87868	 0.016749	 0.055874	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87853	 87854	 0.006792	 0.013899	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87855	 87861	 0.002704	 0.018562	 0.00034	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87858	 87859	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87860	 87869	 0.009752	 0.025068	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87863	 88018	 0.043456	 0.086042	 0.00126	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87864	 87865	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87868	 87869	 0.005886	 0.032414	 0.00073	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87868	 87879	 0.039809	 0.094269	 0.00172	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87870	 87875	 0.003377	 0.019004	 0.00041	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87871	 87881	 0.005935	 0.028963	 0.0005	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	87876	 87882	 0.012047	 0.030968	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87879	 87887	 0.002346	 0.013179	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87884	 87888	 0.064484	 0.051033	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87889	 87986	 0.042909	 0.12618	 0.00259	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87890	 87891	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87894	 87895	 0.000779	 0.004936	 0.00134	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87899	 87900	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87902	 87903	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87906	 87907	 9.4e-05	 0.007517	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87908	 87909	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87913	 87914	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87913	 87981	 0.003365	 0.040643	 0.02305	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87917	 87924	 0.009789	 0.02249	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87923	 87924	 0.00626	 0.017763	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87927	 87928	 0.006768	 0.046455	 0.00085	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87933	 87934	 0.00984	 0.070811	 0.00232	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87935	 87936	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87938	 87939	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87941	 87942	 0.029224	 0.15198	 0.00329	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87942	 87943	 0.025112	 0.12055	 0.0036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87943	 88023	 0.029108	 0.11324	 0.00189	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87946	 88033	 0.089167	 0.25579	 0.00393	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	87947	 87948	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87950	 88048	 0.096497	 0.322	 0.00511	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87954	 87955	 0.000109	 0.008719	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87954	 88912	 0.002447	 0.027499	 0.05033	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87954	 88912	 0.002447	 0.027499	 0.05033	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	87959	 87960	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87959	 87961	 0.004222	 0.019692	 0.00488	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	87961	 87962	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87965	 88289	 0.10737	 0.24673	 0.00375	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87965	 88608	 0.03701	 0.21914	 0.00427	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87967	 87969	 0.007805	 0.031232	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	87971	 87972	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87972	 88033	 0.10974	 0.25217	 0.00383	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	87975	 87976	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87976	 88051	 0.19308	 0.25383	 0.00348	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	87977	 87978	 8.3e-05	 0.006605	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87981	 87982	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	87986	 87987	 0.005024	 0.028581	 0.00088	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	87991	 87992	 0.091067	 0.18717	 0.00357	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88001	 88002	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88001	 88015	 0.003063	 0.021483	 0.03658	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88006	 88008	 0.021116	 0.049024	 0.00073	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88010	 88011	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88013	 88014	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88024	 88027	 0.096701	 0.19876	 0.00379	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88029	 88030	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88034	 88036	 0.029067	 0.17872	 0.00322	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88040	 88041	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88044	 88045	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88045	 88046	 0.013298	 0.07116	 0.00216	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88047	 88048	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88048	 88062	 0.24365	 0.19286	 0.00243	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88051	 88053	 0.048338	 0.089883	 0.0021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88056	 88057	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88059	 88060	 0.008055	 0.009819	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88064	 88065	 9.7e-05	 0.007785	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88072	 88073	 0.044849	 0.14962	 0.00237	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88073	 88290	 0.15138	 0.38365	 0.0076	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88078	 88184	 0.27636	 0.59296	 0.0104	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88078	 88531	 0.11374	 0.22522	 0.00331	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88085	 88210	 0.032338	 0.15524	 0.00464	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88086	 88087	 0.015606	 0.059795	 0.00169	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88088	 88089	 0.093303	 0.15562	 0.00226	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88094	 88095	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88096	 88097	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88102	 88106	 0.006338	 0.025377	 0.00639	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88104	 88714	 0.019838	 0.06618	 0.00105	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88109	 88113	 0.010386	 0.052528	 0.00102	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88110	 88174	 0.070784	 0.098653	 0.00169	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88111	 88112	 0.011185	 0.063582	 0.00115	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88111	 88113	 0.034716	 0.099573	 0.00153	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88114	 88242	 0.041788	 0.25401	 0.00469	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88121	 88122	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88123	 88124	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88134	 88149	 0.013275	 0.02386	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88136	 88144	 0.10178	 0.080547	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88140	 88141	 0.014644	 0.033644	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88141	 88142	 0.030232	 0.030535	 0.0004	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88141	 88150	 0.089367	 0.065752	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88142	 88154	 0.043738	 0.073681	 0.00105	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88147	 88252	 0.00642	 0.092719	 0.02946	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88153	 88154	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88157	 88245	 0.29392	 0.2941	 0.00397	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88158	 88256	 0.18894	 0.37424	 0.0055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88159	 88239	 0.29957	 0.22986	 0.00309	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88161	 88162	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88168	 88240	 0.23989	 0.3272	 0.00726	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88180	 88181	 0.00851	 0.062202	 0.00115	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88184	 88186	 0.066232	 0.13114	 0.00192	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88184	 88188	 0.10412	 0.17366	 0.00253	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88187	 88188	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88187	 88247	 0.036684	 0.1516	 0.03591	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88195	 88196	 0.039178	 0.039571	 0.00052	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88197	 88198	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88199	 88200	 0.012429	 0.033841	 0.00746	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88215	 88217	 0.00052	 0.007502	 0.00238	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88216	 88217	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88218	 88219	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88220	 88222	 0.098248	 0.22813	 0.00339	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88220	 88246	 0.12872	 0.23229	 0.00336	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88223	 88224	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88231	 88249	 0.019881	 0.078161	 0.02045	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88236	 88237	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88239	 88245	 0.60961	 0.61674	 0.00817	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88244	 88245	 0.040363	 0.17987	 0.00306	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88260	 88261	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88269	 88290	 0.063864	 0.28464	 0.00484	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88273	 88274	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88273	 88274	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88274	 88275	 8.7e-05	 0.006944	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88275	 88505	 0.020558	 0.095267	 0.00183	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88276	 88278	 0.046339	 0.070987	 0.001	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88279	 88470	 0.011472	 0.039355	 0.00943	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88283	 88496	 0.12875	 0.31524	 0.00539	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88284	 88285	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88294	 88295	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88296	 88298	 0.014253	 0.026502	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88296	 88732	 0.050733	 0.080981	 0.00187	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88299	 88300	 0.016684	 0.10477	 0.00229	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88304	 88305	 0.089685	 0.1374	 0.00193	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88304	 88616	 0.061777	 0.38813	 0.00849	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88307	 88308	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88310	 88404	 0.029869	 0.061125	 0.0015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88311	 88312	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88311	 88540	 0.003543	 0.0497	 0.0954	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88314	 88767	 0.11517	 0.35383	 0.00664	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88316	 88319	 0.028996	 0.05741	 0.00084	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88317	 88318	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88318	 88319	 0.016112	 0.034527	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88319	 88745	 0.017302	 0.04017	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88324	 88341	 0.022735	 0.045014	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88325	 88326	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88328	 88329	 0.000155	 0.012369	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88329	 88333	 0.056337	 0.044585	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88330	 88331	 7.8e-05	 0.006228	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88331	 88332	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88332	 88777	 0.46115	 0.36173	 0.00464	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88335	 88372	 0.056013	 0.061608	 0.00082	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88336	 88337	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88336	 88339	 0.000731	 0.002506	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88340	 88383	 0.000274	 0.002357	 0.00137	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88347	 88348	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88348	 88349	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88350	 88352	 0.008293	 0.040014	 0.00071	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88351	 88352	 0.005787	 0.028239	 0.00049	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88353	 88593	 0.007048	 0.040063	 0.00072	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88355	 88356	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88359	 88360	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88360	 88368	 0.029987	 0.050515	 0.00072	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88363	 88367	 0.021215	 0.016789	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88365	 88366	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88366	 88378	 0.016012	 0.061601	 0.00105	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88366	 88773	 0.25493	 0.20179	 0.00254	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88373	 88380	 0.035104	 0.027781	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88381	 88382	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88381	 88385	 0.004604	 0.012167	 0.00285	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88384	 88385	 7.8e-05	 0.006228	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 0	 -30.0	 30.0;
	88384	 88385	 7.8e-05	 0.006228	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 0	 -30.0	 30.0;
	88386	 88387	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88391	 88392	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88396	 88397	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88396	 88569	 0.041834	 0.12342	 0.02873	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88398	 88399	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88407	 88408	 0.094238	 0.1694	 0.00304	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88409	 88514	 0.15465	 0.21557	 0.00369	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88411	 88421	 0.15226	 0.1205	 0.00152	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88412	 88413	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88413	 88415	 0.014672	 0.05137	 0.00142	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88414	 88760	 0.12004	 0.30865	 0.00478	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88416	 88759	 0.065729	 0.16898	 0.00262	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88417	 88418	 0.030033	 0.14656	 0.00253	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88422	 88423	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88423	 88425	 0.020287	 0.1274	 0.00278	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88425	 88496	 0.12707	 0.42412	 0.00673	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88427	 88428	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88429	 88435	 0.0176	 0.02885	 0.00051	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88429	 88444	 0.1192	 0.094339	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88438	 88549	 0.048574	 0.16205	 0.00257	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88439	 88440	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88448	 88449	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88448	 88450	 0.001772	 0.014905	 0.00441	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88454	 88455	 8.5e-05	 0.006812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88459	 88529	 0.15966	 0.31622	 0.00464	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88462	 88463	 0.015295	 0.094037	 0.00169	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88468	 88469	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88472	 88473	 0.000105	 0.008384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88477	 88478	 0.008514	 0.021132	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88479	 88480	 0.003484	 0.02142	 0.00039	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88481	 88485	 0.013142	 0.05562	 0.00105	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88482	 88483	 9.8e-05	 0.007812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88485	 88498	 0.004334	 0.019392	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88485	 88500	 0.023107	 0.067949	 0.00139	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88486	 88498	 0.007581	 0.041746	 0.00094	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88487	 88488	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88489	 88493	 0.013005	 0.03343	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88495	 88496	 0.005658	 0.038836	 0.00071	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88500	 88505	 0.009909	 0.044339	 0.00091	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88501	 88504	 0.011288	 0.029017	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88502	 88503	 0.00608	 0.027092	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88506	 88507	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88513	 88515	 0.086237	 0.12567	 0.00284	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88513	 88516	 0.019892	 0.10344	 0.00224	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88515	 88516	 0.045177	 0.12958	 0.00199	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88518	 88519	 0.015407	 0.074337	 0.00131	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88521	 88522	 0.010283	 0.052015	 0.00091	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88523	 88580	 0.004687	 0.025813	 0.00932	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88524	 88581	 0.002352	 0.01995	 0.01195	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88525	 88528	 0.022637	 0.11047	 0.00191	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88530	 88531	 0.040465	 0.119	 0.00244	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88540	 88541	 9.4e-05	 0.007517	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88541	 88542	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88543	 88548	 0.28016	 0.2811	 0.00455	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88546	 88547	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88551	 88552	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88553	 88554	 0.000247	 0.018554	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88553	 88557	 0.000546	 0.006136	 0.01123	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88556	 88564	 0.024562	 0.062464	 0.00099	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88557	 88558	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88559	 88560	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88561	 88562	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88563	 88564	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88563	 88566	 0.000785	 0.008465	 0.00452	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88567	 88568	 0.20686	 0.27194	 0.00373	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88571	 88572	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88574	 88576	 0.019124	 0.093321	 0.00161	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88581	 88582	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88585	 88586	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88589	 88590	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88592	 88593	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88595	 88596	 0.058723	 0.088041	 0.0016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88598	 88599	 0.012665	 0.067482	 0.00118	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88600	 88601	 0.009595	 0.034277	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88607	 88609	 0.021537	 0.14785	 0.0027	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88614	 88615	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88614	 88615	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88615	 88616	 8.9e-05	 0.007142	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88617	 88656	 0.007341	 0.034086	 0.00093	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88619	 88625	 0.008141	 0.035868	 0.00062	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88621	 88623	 0.025839	 0.020254	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88622	 88625	 0.002049	 0.01245	 0.00023	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88625	 88626	 0.00379	 0.00904	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88626	 88656	 0.005102	 0.017018	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88628	 88629	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88632	 88633	 0.002809	 0.009828	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88634	 88643	 0.073272	 0.057987	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88635	 88636	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88638	 88661	 0.003197	 0.015427	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88639	 88640	 0.003163	 0.016852	 0.0003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88639	 88642	 0.041876	 0.03081	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88641	 88653	 0.020657	 0.031644	 0.00044	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88643	 88689	 0.009565	 0.024588	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88644	 88647	 0.02616	 0.016936	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88648	 88653	 0.057692	 0.045222	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88650	 88651	 0.030728	 0.024318	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88650	 88661	 0.00411	 0.019728	 0.00059	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88651	 88652	 0.006842	 0.014001	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88653	 88667	 0.094673	 0.069656	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88655	 88656	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88659	 88660	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88667	 88681	 0.081779	 0.059119	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88668	 88680	 0.003463	 0.018451	 0.00032	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88669	 88670	 0.005335	 0.014139	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88672	 88673	 0.029622	 0.058054	 0.00087	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88674	 88681	 0.019495	 0.035706	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88676	 88677	 0.036956	 0.037326	 0.00049	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88679	 88683	 0.15878	 0.12566	 0.00158	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88681	 88683	 0.004237	 0.018881	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88683	 88685	 0.027419	 0.054287	 0.0008	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88685	 88689	 0.10711	 0.084767	 0.00107	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88690	 88691	 0.012388	 0.048191	 0.0008	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88690	 88702	 0.056606	 0.04342	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88694	 88696	 0.011896	 0.03058	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88695	 88696	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88698	 88700	 0.013932	 0.02347	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88701	 88702	 0.028782	 0.051409	 0.00076	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88704	 88705	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88705	 88706	 0.010397	 0.024137	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88708	 88709	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88709	 88711	 0.001167	 0.010344	 0.00275	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88710	 88715	 0.003206	 0.013047	 0.00318	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88711	 88712	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88713	 88714	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88714	 88716	 0.041351	 0.081873	 0.0012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88717	 88718	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88718	 88719	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88721	 88722	 0.031455	 0.12102	 0.00207	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88723	 88724	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88725	 88726	 8.3e-05	 0.006605	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88726	 88727	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88735	 88738	 0.059189	 0.09448	 0.00218	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88748	 88749	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88754	 88756	 0.013282	 0.026296	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88760	 88762	 0.014497	 0.089131	 0.00161	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88761	 88762	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88773	 88782	 0.028197	 0.060425	 0.00106	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88774	 88775	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88776	 88777	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88778	 88779	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88778	 88780	 0.002479	 0.008351	 0.00208	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88785	 88786	 0.025044	 0.041768	 0.00061	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88788	 88789	 0.000136	 0.010869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88788	 88789	 0.000136	 0.010869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88790	 90040	 0.095111	 0.21854	 0.00332	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88790	 90146	 0.022511	 0.1363	 0.00427	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88792	 90081	 0.001332	 0.005421	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88792	 90083	 0.003032	 0.012831	 0.00289	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88793	 88794	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88793	 88794	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88793	 90113	 0.009057	 0.030215	 0.00766	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88795	 90203	 0.001902	 0.00723	 0.00202	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88796	 90068	 0.08344	 0.2512	 0.00491	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88797	 88798	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88797	 88798	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88798	 90073	 0.017623	 0.068558	 0.00114	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88798	 90073	 0.017623	 0.068558	 0.00114	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88799	 88820	 0.38133	 0.6368	 0.00927	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88800	 88817	 0.71524	 0.56702	 0.00714	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88800	 90067	 0.057731	 0.13404	 0.00199	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88800	 90233	 0.40516	 0.31776	 0.00408	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88800	 90267	 0.17241	 0.55572	 0.00948	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88801	 88802	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88801	 88802	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88802	 88809	 0.34939	 0.27662	 0.00348	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88803	 88821	 0.45747	 0.36229	 0.00456	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88803	 88826	 0.42324	 0.33515	 0.00422	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88803	 90130	 0.1837	 0.4353	 0.00796	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88803	 90169	 0.052816	 0.23411	 0.00703	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88804	 90121	 0.1549	 0.35976	 0.00535	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88805	 88812	 0.13411	 0.44762	 0.0071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88805	 89532	 0.037408	 0.19933	 0.0035	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88805	 89533	 0.083106	 0.2773	 0.0044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88805	 90145	 0.026907	 0.062469	 0.00093	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88806	 90185	 0.007016	 0.037157	 0.00942	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88807	 90101	 0.06519	 0.25365	 0.00424	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88810	 90154	 0.008687	 0.02233	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88811	 90275	 0.032488	 0.10418	 0.00258	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88812	 90143	 0.056875	 0.25348	 0.00431	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88813	 90097	 0.018027	 0.02955	 0.00052	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88813	 90098	 0.011621	 0.034978	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88814	 90084	 0.052678	 0.063061	 0.00105	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88817	 90233	 0.26077	 0.28691	 0.00383	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88818	 90077	 0.58115	 0.46044	 0.0058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88818	 90094	 0.44747	 0.33926	 0.00467	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88818	 90163	 0.24135	 0.47819	 0.00702	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88819	 88820	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88819	 88820	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88820	 90180	 0.21503	 0.53421	 0.00889	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88820	 93193	 0.031458	 0.073022	 0.00139	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88822	 90274	 0.17142	 0.26004	 0.00373	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88824	 88825	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88824	 88825	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88825	 90036	 0.47223	 0.374	 0.00471	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88825	 90982	 0.052686	 0.32401	 0.00584	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88830	 90181	 0.012788	 0.033798	 0.00791	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88832	 88833	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88832	 88833	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88832	 89531	 0.005751	 0.016037	 0.00337	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88833	 89530	 0.072799	 0.20661	 0.00325	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88834	 88835	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88834	 88835	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88835	 89781	 0.007066	 0.031489	 0.00856	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88835	 89784	 0.006107	 0.058341	 0.02142	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88837	 88838	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88837	 88838	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88837	 89730	 0.00288	 0.032224	 0.0595	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88838	 88893	 0.005073	 0.035712	 0.02031	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88838	 88926	 0.015363	 0.084324	 0.0223	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88839	 88840	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88839	 88840	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88840	 89976	 0.003143	 0.018055	 0.00511	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88842	 88843	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88842	 88843	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88843	 88844	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88843	 88844	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88843	 89810	 0.004393	 0.026169	 0.00688	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88845	 88846	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88845	 88846	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88845	 88860	 5.1e-05	 0.000486	 0.00178	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88846	 89965	 0.000135	 0.001695	 0.00053	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88848	 88849	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88848	 88849	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88850	 88851	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88850	 88851	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88852	 88853	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88852	 88853	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88853	 89050	 0.16453	 0.42316	 0.00655	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88855	 88856	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88855	 88856	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 0	 -30.0	 30.0;
	88856	 88857	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88856	 88857	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88858	 88859	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88858	 88859	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88858	 89409	 0.000699	 0.002355	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88860	 89964	 5.8e-05	 0.000887	 0.00201	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88861	 88862	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88861	 88862	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88863	 89719	 0.035277	 0.1939	 0.05138	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88863	 89965	 0.026641	 0.1613	 0.04123	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88864	 88865	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88864	 88865	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88864	 89295	 0.000601	 0.00401	 0.00756	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88864	 89399	 0.001045	 0.006352	 0.01447	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88865	 88866	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88865	 88866	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88865	 89370	 0.000125	 0.000454	 0.00014	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88866	 89130	 0.007077	 0.013869	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88866	 89151	 0.005609	 0.014418	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88867	 88868	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88867	 88868	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88867	 89814	 0.020997	 0.12707	 0.03246	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88870	 90081	 0.005329	 0.031216	 0.0085	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88871	 88872	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88871	 88872	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88871	 89680	 0.001398	 0.009535	 0.01717	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88873	 88874	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88873	 88874	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88873	 90775	 0.005281	 0.022352	 0.00503	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88874	 89621	 0.013631	 0.036128	 0.00092	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88875	 88876	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88875	 88876	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88878	 88879	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88878	 88879	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88878	 89314	 0.006334	 0.040802	 0.0107	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88878	 89994	 0.00282	 0.015646	 0.00476	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88879	 89930	 0.009789	 0.042884	 0.00092	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88882	 88883	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88882	 88883	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88884	 89767	 0.019871	 0.10052	 0.00175	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88886	 88887	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88886	 88887	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88889	 89514	 0.21903	 0.28512	 0.00399	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88890	 89199	 0.000271	 0.003408	 0.00106	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88892	 88893	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88892	 88893	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88894	 88895	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88894	 88895	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88896	 89530	 0.031544	 0.14057	 0.00239	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88897	 88898	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88897	 88898	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88897	 89781	 0.016762	 0.054677	 0.01452	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88901	 88902	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88901	 88902	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88902	 89863	 0.049252	 0.096527	 0.00145	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88902	 89869	 0.028378	 0.056187	 0.00082	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88902	 89873	 0.026783	 0.053028	 0.00078	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88905	 89909	 0.13683	 0.10829	 0.00136	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88906	 88907	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88906	 88907	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88908	 89726	 0.003423	 0.009818	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88911	 89362	 0.021804	 0.11618	 0.00204	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88911	 89979	 0.040501	 0.071227	 0.00134	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88912	 88913	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88912	 88913	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88913	 88914	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88913	 88914	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88917	 89793	 0.001039	 0.00705	 0.00013	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88917	 89796	 0.012933	 0.033518	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88921	 89971	 0.013882	 0.070635	 0.0016	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88921	 89975	 0.044486	 0.044933	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88921	 89977	 0.035303	 0.10018	 0.00157	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88923	 89821	 0.27581	 0.21625	 0.00278	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88924	 88925	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88924	 88925	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88924	 90000	 0.00045	 0.006358	 0.03255	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88924	 90002	 0.000528	 0.006536	 0.02359	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88926	 88927	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88926	 88927	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88929	 89759	 0.029625	 0.080934	 0.00137	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88930	 89398	 0.006643	 0.008645	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88933	 88934	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88933	 88934	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88934	 88935	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88934	 88935	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88937	 88938	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88937	 88938	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88937	 90357	 0.014096	 0.051047	 0.01095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88938	 90377	 0.26845	 0.26275	 0.00372	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88939	 88940	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88939	 88940	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88940	 88941	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88940	 88941	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88940	 90295	 0.002203	 0.013322	 0.0034	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88942	 88943	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88942	 88943	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88944	 90357	 0.015415	 0.053729	 0.01246	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88945	 90568	 0.22554	 0.37487	 0.00795	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88946	 88947	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88946	 88947	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88947	 90537	 0.014494	 0.037258	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88949	 88950	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88949	 88950	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88949	 90356	 0.00161	 0.010864	 0.02	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88949	 90633	 0.000278	 0.002233	 0.00752	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88950	 88951	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88950	 88951	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88950	 90350	 0.012468	 0.032051	 0.00794	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88950	 90632	 0.006267	 0.021498	 0.00515	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	88951	 90630	 0.022708	 0.044959	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88953	 88954	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88953	 88954	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88955	 90480	 0.12948	 0.39784	 0.00747	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88955	 93671	 0.081507	 0.31718	 0.0053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88957	 90479	 0.077188	 0.43903	 0.00795	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	88957	 90519	 0.31394	 0.24616	 0.00316	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88958	 88959	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88958	 88959	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88959	 90359	 0.18881	 0.31817	 0.00453	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88959	 90361	 0.12463	 0.19094	 0.00268	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88959	 90491	 0.14291	 0.12895	 0.00216	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88965	 88966	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88965	 88966	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88967	 90307	 0.086662	 0.146	 0.00208	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	88972	 88973	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88972	 88973	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88972	 90584	 0.00586	 0.015487	 0.00362	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88974	 90410	 0.028421	 0.043538	 0.00061	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88977	 88978	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88977	 88978	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88979	 90639	 0.018599	 0.061379	 0.00099	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88980	 90462	 0.10486	 0.30082	 0.00463	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88980	 90581	 0.014032	 0.025221	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88983	 90310	 0.1978	 0.12808	 0.00244	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	88984	 90306	 0.1856	 0.47744	 0.00739	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88985	 90583	 0.014002	 0.027441	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88987	 90380	 0.051345	 0.20375	 0.00582	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	88988	 88989	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88988	 88989	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88988	 88997	 3.9e-05	 0.000469	 0.00094	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88988	 90917	 0.008384	 0.055259	 0.10707	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	88989	 90936	 0.012178	 0.037874	 0.0079	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88990	 90790	 0.021163	 0.065824	 0.01374	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	88990	 90790	 0.021163	 0.065824	 0.01374	 128.0	 134.4	 140.8	 0.0	 0.0	 0	 -30.0	 30.0;
	88991	 88992	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88991	 88992	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88992	 88993	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88992	 88993	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88993	 90776	 0.007337	 0.024475	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88994	 88995	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88994	 88995	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88994	 89003	 0.000345	 0.001459	 0.00033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	88995	 90669	 0.05487	 0.18306	 0.0029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88998	 88999	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	88998	 88999	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89003	 89004	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89003	 89004	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89004	 90617	 0.44337	 0.34777	 0.00446	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89004	 90671	 0.03668	 0.095066	 0.0018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89005	 90762	 0.32264	 0.20897	 0.00398	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89005	 90765	 0.1713	 0.13429	 0.00172	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89005	 90985	 0.062878	 0.040708	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89006	 89007	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89006	 89007	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89006	 90971	 0.003337	 0.021137	 0.00574	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89007	 90968	 0.1462	 0.10758	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89007	 90975	 0.056913	 0.095877	 0.00137	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89008	 89009	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89008	 89009	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89008	 90919	 0.00522	 0.014015	 0.00318	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89008	 90921	 0.003866	 0.019426	 0.00506	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89011	 90836	 0.097534	 0.077189	 0.00097	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89012	 89013	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89012	 89013	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89012	 90662	 0.001707	 0.007048	 0.00167	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89013	 90660	 0.012931	 0.019808	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89014	 90080	 0.50888	 0.40307	 0.00508	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89015	 91028	 0.046977	 0.15672	 0.00248	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89017	 91002	 0.035719	 0.068406	 0.00108	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89018	 89026	 0.000119	 0.000734	 2e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89019	 89020	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89019	 89020	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89021	 90913	 0.005117	 0.019906	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89022	 90792	 0.019127	 0.044406	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89022	 90793	 0.022937	 0.030146	 0.00041	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89022	 90795	 0.094572	 0.095524	 0.00127	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89024	 90800	 0.000808	 0.009091	 0.00239	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89025	 90731	 0.054654	 0.054668	 0.00074	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89026	 90810	 0.037614	 0.12548	 0.00199	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89028	 89029	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89028	 89029	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89029	 90955	 0.014124	 0.047118	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89029	 90959	 0.041853	 0.21768	 0.00472	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89029	 90986	 0.077097	 0.25724	 0.00408	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89031	 90893	 0.006103	 0.011011	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89035	 90691	 0.009893	 0.017398	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89036	 89037	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89038	 89819	 0.027431	 0.15607	 0.0048	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89040	 89041	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89041	 89420	 0.067204	 0.11321	 0.00161	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89041	 89567	 0.069225	 0.26936	 0.0045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89042	 89043	 0.063301	 0.19055	 0.00373	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89042	 89046	 0.081749	 0.18699	 0.00457	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89042	 89920	 0.43428	 0.34391	 0.00433	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89043	 89044	 0.14955	 0.13777	 0.00221	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89044	 89045	 0.017159	 0.096558	 0.00208	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89045	 89675	 0.029575	 0.084827	 0.0013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89050	 89880	 0.3192	 0.24192	 0.00333	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89052	 89061	 0.10785	 0.21356	 0.00314	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89057	 89058	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89058	 89908	 0.15844	 0.41088	 0.00777	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89060	 89063	 0.27639	 0.21878	 0.00275	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89063	 89909	 0.036868	 0.15069	 0.00305	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89067	 89068	 0.11035	 0.21629	 0.00324	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89069	 89418	 0.039529	 0.22473	 0.00407	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89070	 89071	 0.001798	 0.027982	 0.00868	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89072	 89912	 0.053557	 0.27858	 0.00604	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89077	 89433	 0.039449	 0.23359	 0.00455	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89079	 89083	 0.006553	 0.012843	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89080	 89092	 0.0063	 0.011539	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89080	 89104	 0.015206	 0.028274	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89089	 89090	 0.015108	 0.011956	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89095	 89097	 0.003994	 0.009059	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89099	 89371	 0.007273	 0.011857	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89101	 89374	 0.024201	 0.015668	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89101	 89401	 0.01486	 0.042621	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89102	 89103	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89103	 89106	 0.002437	 0.008526	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89106	 89107	 0.005519	 0.008454	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89110	 89112	 0.01472	 0.012116	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89110	 89116	 0.012767	 0.020378	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89114	 89115	 0.006907	 0.008989	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89117	 89245	 0.012538	 0.041377	 0.00067	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89118	 89119	 0.002788	 0.00791	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89118	 89121	 0.00517	 0.011878	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89120	 89401	 0.004024	 0.010345	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89123	 89258	 0.009144	 0.026227	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89124	 89401	 0.005338	 0.012208	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89124	 89408	 0.009963	 0.018829	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89129	 89130	 0.001046	 0.005948	 0.00011	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89133	 89384	 0.027324	 0.0541	 0.00079	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89133	 89414	 0.008864	 0.017551	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89135	 89136	 0.009649	 0.007099	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89136	 89414	 0.005782	 0.010391	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89150	 89159	 0.000519	 0.002197	 0.00049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89150	 89290	 0.002783	 0.015987	 0.00453	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89161	 89415	 0.009072	 0.011924	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89163	 89164	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89164	 89300	 0.008903	 0.020668	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89164	 89304	 0.010414	 0.041318	 0.00118	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89167	 89169	 0.010665	 0.021116	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89176	 89219	 0.012148	 0.026033	 0.00046	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89176	 89435	 0.026366	 0.062887	 0.00141	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89177	 89178	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89177	 89202	 0.001447	 0.009394	 0.01871	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89178	 89218	 0.001977	 0.006782	 0.00162	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89181	 89665	 0.043675	 0.069715	 0.00161	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89182	 89186	 0.045072	 0.045524	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89183	 89184	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89183	 89185	 0.001899	 0.006617	 0.00153	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89185	 89186	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89191	 89217	 0.023181	 0.037001	 0.00085	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89193	 89204	 0.017425	 0.085032	 0.00147	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89196	 89599	 0.056052	 0.036288	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89197	 89200	 0.005254	 0.015068	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89201	 89212	 0.005929	 0.017005	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89202	 89203	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89203	 89204	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89204	 89217	 0.014802	 0.034365	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89206	 89208	 0.002878	 0.017692	 0.00032	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89206	 89209	 0.009293	 0.016703	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89211	 89214	 0.002607	 0.01603	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89214	 89215	 0.00223	 0.015305	 0.00028	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89218	 89219	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89219	 89220	 0.00484	 0.013406	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89224	 89226	 0.009015	 0.025858	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89226	 89227	 0.00943	 0.015749	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89228	 89229	 0.020203	 0.015988	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89230	 89231	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89233	 89376	 0.043531	 0.034121	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89234	 89235	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89236	 89237	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89246	 89250	 0.011993	 0.027427	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89246	 89273	 0.012994	 0.037269	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89248	 89249	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89249	 89250	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89250	 89438	 0.0247	 0.047302	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89257	 89258	 0.007352	 0.009487	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89260	 89263	 0.004499	 0.021156	 0.00039	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89260	 89373	 0.009587	 0.015715	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89262	 89263	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89272	 89274	 0.01722	 0.026379	 0.00037	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89272	 89278	 0.018765	 0.05325	 0.00084	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89277	 89278	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89278	 89279	 0.024953	 0.019748	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89280	 89475	 0.004416	 0.021307	 0.00038	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89282	 89283	 0.006392	 0.018334	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89283	 89284	 0.009525	 0.016045	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89284	 89285	 0.00369	 0.009562	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89285	 89288	 0.016847	 0.012764	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89286	 89291	 0.082022	 0.064912	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89287	 89476	 0.007883	 0.02043	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89289	 89290	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89289	 89290	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89289	 89293	 0.000495	 0.003373	 0.00607	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89289	 89497	 0.001144	 0.015207	 0.03249	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89290	 89291	 9.8e-05	 0.007812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89293	 89294	 0.000262	 0.019645	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89295	 89296	 9.7e-05	 0.007785	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89296	 89297	 0.000556	 0.00331	 0.00087	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89298	 89299	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89298	 89299	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89299	 89309	 0.00538	 0.02468	 0.00632	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89300	 89305	 0.014492	 0.037558	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89302	 89312	 0.004077	 0.019894	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89303	 89344	 0.055276	 0.043328	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89303	 89345	 0.042755	 0.033836	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89305	 89306	 0.009023	 0.023193	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89308	 89313	 0.020269	 0.037689	 0.00088	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89309	 89310	 0.001912	 0.007654	 0.00193	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89310	 89311	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89311	 89348	 0.032154	 0.063662	 0.00093	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89312	 89331	 0.014513	 0.026085	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89314	 89316	 0.002088	 0.015019	 0.00398	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89316	 89317	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89318	 89482	 0.066389	 0.05254	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89319	 89320	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89321	 89330	 0.00829	 0.018803	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89322	 89326	 0.003846	 0.009887	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89324	 89325	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89325	 89326	 0.000463	 0.004721	 0.00122	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89325	 89328	 0.004272	 0.011631	 0.00256	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89327	 89948	 0.006414	 0.032079	 0.00057	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89329	 89339	 0.005392	 0.013713	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89332	 89333	 0.018006	 0.051643	 0.00079	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89333	 89334	 0.002835	 0.015105	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89334	 89982	 0.060879	 0.089116	 0.00138	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89336	 89338	 0.008798	 0.015473	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89341	 89343	 0.024801	 0.016056	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89342	 89356	 0.0651	 0.05152	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89343	 89345	 0.044278	 0.035041	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89345	 89346	 0.013611	 0.010772	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89345	 89347	 0.023995	 0.01899	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89347	 89348	 0.024644	 0.02465	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89349	 89350	 0.022415	 0.017739	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89352	 89360	 0.014972	 0.042942	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89353	 89356	 0.11376	 0.090029	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89361	 89364	 0.025404	 0.058365	 0.00089	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89362	 89364	 0.022798	 0.029668	 0.00041	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89366	 89368	 0.035811	 0.02834	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89368	 89988	 0.046591	 0.036871	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89369	 89989	 0.010482	 0.055851	 0.00098	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89378	 89379	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89379	 89412	 0.013466	 0.031258	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89380	 89391	 0.008314	 0.021143	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89383	 89407	 0.042535	 0.031294	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89384	 89393	 0.026112	 0.019211	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89385	 89401	 0.005769	 0.025706	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89388	 89411	 0.012227	 0.035956	 0.00074	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89390	 89391	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89392	 89406	 0.006754	 0.017107	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89399	 89400	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89400	 89401	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89403	 89404	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89405	 89406	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89409	 89410	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89416	 89548	 0.044093	 0.2244	 0.00509	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89418	 89883	 0.1696	 0.48161	 0.00757	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89419	 89420	 0.043639	 0.13402	 0.00252	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89420	 89426	 0.19633	 0.16163	 0.00328	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89421	 89422	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89422	 89423	 0.004405	 0.011643	 0.00273	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89423	 89568	 0.005484	 0.031507	 0.00893	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89424	 89425	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89425	 89428	 0.003582	 0.017663	 0.00478	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89428	 89429	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89429	 89670	 0.21965	 0.43514	 0.00639	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89430	 89606	 0.011955	 0.071231	 0.01874	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89430	 89609	 0.002184	 0.016614	 0.00522	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89432	 89433	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89435	 89437	 0.014833	 0.029368	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89439	 89509	 0.004551	 0.028576	 0.00062	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89442	 89443	 0.005312	 0.020354	 0.00058	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89442	 89444	 0.007354	 0.01944	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89446	 89450	 0.008608	 0.022127	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89446	 89509	 0.013806	 0.061522	 0.00104	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89447	 89450	 0.002095	 0.013638	 0.00028	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89448	 89450	 0.007989	 0.018919	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89449	 89453	 0.005948	 0.027971	 0.00052	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89452	 89572	 0.017708	 0.037947	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89454	 89456	 0.014683	 0.042114	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89459	 89466	 0.006847	 0.026341	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89460	 89488	 0.004462	 0.023503	 0.00042	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89463	 89468	 0.010594	 0.01653	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89463	 89473	 0.015263	 0.043777	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89464	 89511	 0.008988	 0.022308	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89472	 89473	 0.002323	 0.013207	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89477	 89485	 0.006413	 0.023486	 0.00059	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89478	 89479	 0.002858	 0.01095	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89480	 89494	 0.001323	 0.008876	 0.00214	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89482	 89484	 0.017816	 0.050558	 0.00079	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89490	 89498	 0.025004	 0.035495	 0.00058	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89492	 89493	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89492	 89497	 0.000378	 0.002453	 0.00489	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89492	 89928	 0.001088	 0.007886	 0.01588	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89493	 89494	 0.001742	 0.006973	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89494	 89496	 0.000816	 0.003454	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89496	 89922	 0.001688	 0.006757	 0.0017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89499	 89500	 0.000136	 0.010869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89499	 89501	 0.000375	 0.00542	 0.00172	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89503	 89504	 0.019633	 0.019637	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89506	 89932	 0.029667	 0.027326	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89508	 89509	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89509	 89511	 0.026463	 0.020942	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89510	 89511	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89514	 89776	 0.13569	 0.35884	 0.00652	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89516	 89520	 0.027122	 0.10551	 0.00176	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89516	 89520	 0.027122	 0.10551	 0.00176	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89517	 89518	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89518	 89544	 0.01498	 0.10173	 0.00252	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89519	 89520	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89522	 89812	 0.33892	 0.26832	 0.00338	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89526	 89527	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89527	 89528	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89528	 89671	 0.065989	 0.16154	 0.00276	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89531	 89973	 0.013382	 0.078399	 0.02136	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89533	 89693	 0.069138	 0.18327	 0.00465	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89534	 89911	 0.17936	 0.23346	 0.00327	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89537	 89538	 0.10845	 0.099894	 0.0016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89540	 89541	 0.063852	 0.19592	 0.00531	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89540	 89601	 0.10462	 0.18879	 0.00273	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89544	 89547	 0.084092	 0.19525	 0.0029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89550	 89552	 0.00082	 0.013394	 0.00662	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89552	 89553	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89553	 89764	 0.1157	 0.29995	 0.00567	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89555	 89556	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89557	 89558	 0.093345	 0.23999	 0.00371	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89558	 89559	 0.31884	 0.25001	 0.00321	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89560	 89995	 0.048915	 0.27812	 0.00503	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89561	 89562	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89564	 89595	 0.098913	 0.072775	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89565	 89566	 0.011594	 0.071281	 0.00128	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89571	 89599	 0.025675	 0.025681	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89574	 89579	 0.059055	 0.076855	 0.00107	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89575	 89580	 0.006573	 0.025572	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89575	 89581	 0.0254	 0.050289	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89575	 89599	 0.081527	 0.1249	 0.00175	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89577	 89578	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89577	 89589	 0.002264	 0.01961	 0.03648	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89578	 89594	 0.001935	 0.021396	 0.00642	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89579	 89580	 0.017704	 0.035052	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89579	 89583	 0.011221	 0.029662	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89581	 89598	 0.00847	 0.028257	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89582	 89583	 0.04697	 0.034557	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89584	 89585	 0.008825	 0.01552	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89584	 89586	 0.018711	 0.015401	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89585	 89588	 0.011203	 0.03213	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89585	 89597	 0.039982	 0.031641	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89587	 89592	 0.009411	 0.016809	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89587	 89597	 0.00865	 0.024809	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89589	 89590	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89590	 89591	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89590	 89594	 0.01487	 0.041469	 0.0087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89590	 89609	 0.004905	 0.042067	 0.01197	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89591	 89592	 0.015185	 0.043551	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89592	 89593	 0.016491	 0.021462	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89596	 89597	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89601	 89605	 0.20994	 0.15179	 0.0023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89602	 89605	 0.016232	 0.049848	 0.00094	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89603	 89604	 0.024176	 0.019133	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89603	 89605	 0.020149	 0.045704	 0.00091	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89606	 89607	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89606	 89933	 0.004718	 0.016186	 0.00388	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89610	 89971	 0.032475	 0.16526	 0.00375	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89613	 89615	 0.009785	 0.032642	 0.00052	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89613	 89617	 0.093247	 0.087447	 0.00135	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89614	 89615	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89615	 89911	 0.23371	 0.23611	 0.00313	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89617	 89808	 0.5525	 0.35818	 0.00682	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89618	 89619	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89619	 89620	 0.017528	 0.040688	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89620	 89623	 0.009129	 0.014571	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89632	 89633	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89637	 89640	 0.00178	 0.008303	 0.00206	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89640	 89641	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89641	 89644	 0.006455	 0.033567	 0.00073	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89646	 89647	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89648	 89664	 0.011883	 0.047635	 0.00123	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89650	 89651	 0.008776	 0.016587	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89651	 89652	 0.00442	 0.019586	 0.00059	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89651	 89655	 0.008798	 0.020834	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89652	 89653	 0.017485	 0.029203	 0.0005	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89654	 89655	 0.010718	 0.021006	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89657	 89659	 0.016194	 0.054021	 0.00086	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89659	 89700	 0.027079	 0.06961	 0.00108	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89660	 89661	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89662	 89663	 0.10378	 0.085422	 0.00173	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89671	 89672	 0.10185	 0.13885	 0.00308	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89671	 89676	 0.14935	 0.15952	 0.00337	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89675	 89821	 0.018627	 0.083004	 0.00141	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89675	 89822	 0.041833	 0.16742	 0.00354	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89676	 89682	 0.39886	 0.40315	 0.00534	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89678	 89768	 0.074075	 0.21248	 0.00327	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89678	 89822	 0.057462	 0.22999	 0.00486	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89681	 89682	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89681	 89684	 0.012565	 0.049389	 0.01292	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89681	 90030	 0.00365	 0.042479	 0.01249	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89688	 89690	 0.078874	 0.17697	 0.00282	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89689	 89691	 0.011425	 0.03242	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89689	 89692	 0.096981	 0.12039	 0.00262	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89690	 89691	 0.004979	 0.043488	 0.00108	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89691	 89693	 0.059572	 0.13831	 0.00206	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89697	 89700	 0.009507	 0.043155	 0.00094	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89701	 89702	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89701	 89711	 0.00391	 0.024763	 0.00672	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89705	 89711	 0.002334	 0.024011	 0.00681	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89713	 89718	 0.017491	 0.068046	 0.00114	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89714	 89719	 0.00711	 0.025132	 0.00566	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89721	 89722	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89722	 89723	 0.022015	 0.024213	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89724	 89900	 0.038526	 0.1688	 0.00363	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89725	 89734	 0.012432	 0.013541	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89726	 89732	 0.00385	 0.021632	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89727	 89734	 0.004517	 0.031003	 0.00057	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89729	 89879	 0.065182	 0.24981	 0.00706	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89730	 89731	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89730	 89731	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89731	 89732	 9.8e-05	 0.007812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89733	 89734	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89735	 89877	 0.04379	 0.32017	 0.00591	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89739	 89741	 0.006831	 0.015859	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89739	 89742	 0.008874	 0.025452	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89739	 89846	 0.074732	 0.17351	 0.00258	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89740	 89741	 0.01771	 0.017112	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89741	 89742	 0.013273	 0.024679	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89741	 89743	 0.01209	 0.03303	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89742	 89747	 0.03968	 0.15438	 0.00258	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89743	 89750	 0.017455	 0.067907	 0.00113	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89744	 89745	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89747	 89749	 0.004805	 0.023447	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89748	 89749	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89750	 89755	 0.011563	 0.044486	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89754	 89755	 0.015139	 0.043421	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89754	 89756	 0.018039	 0.04188	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89756	 89760	 0.01247	 0.060852	 0.00105	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89764	 89765	 0.014648	 0.044982	 0.00084	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89768	 90031	 0.080167	 0.14684	 0.00254	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89769	 89770	 0.092044	 0.21149	 0.00321	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89770	 89771	 0.054661	 0.10164	 0.00238	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89775	 89776	 0.032448	 0.11362	 0.00315	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89777	 89779	 0.020891	 0.12844	 0.00232	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89781	 89782	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89785	 89786	 0.000321	 0.02569	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89786	 89789	 0.05635	 0.11157	 0.00164	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89787	 89788	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89790	 89791	 0.011833	 0.012636	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89791	 89794	 0.00501	 0.013877	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89792	 89793	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89793	 89794	 0.016402	 0.019635	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89794	 89811	 0.10118	 0.076659	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89795	 89889	 0.016856	 0.020924	 0.00046	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89796	 89802	 0.010846	 0.04833	 0.00082	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89797	 89798	 0.015607	 0.012351	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89798	 89799	 0.005781	 0.014861	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89802	 89804	 0.021734	 0.062337	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89804	 89807	 0.31853	 0.25216	 0.00317	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89808	 89812	 0.10461	 0.19163	 0.00331	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89809	 89810	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89812	 89892	 0.062045	 0.11195	 0.00162	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89821	 89822	 0.093373	 0.12272	 0.00168	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89829	 89830	 0.04862	 0.038111	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89831	 89832	 0.017798	 0.035238	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89831	 89836	 0.011672	 0.030251	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89835	 89836	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89836	 90246	 0.076957	 0.060324	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89838	 89848	 0.018778	 0.043596	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89838	 89859	 0.004625	 0.030105	 0.00061	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89845	 89846	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89845	 89858	 0.001661	 0.014493	 0.00398	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89850	 89851	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89856	 89857	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89858	 89859	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89860	 89997	 0.060116	 0.23857	 0.00682	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89861	 89863	 0.019484	 0.0311	 0.00072	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89862	 89863	 0.021102	 0.013661	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89868	 89871	 0.00112	 0.004485	 0.00113	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89876	 89877	 0.019414	 0.11323	 0.00227	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89884	 90754	 0.037473	 0.18288	 0.00316	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	89889	 89895	 0.061666	 0.1221	 0.00179	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89889	 89901	 0.017544	 0.068253	 0.00114	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89891	 89892	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89894	 89895	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89895	 89898	 0.043699	 0.11552	 0.0021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89896	 89897	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89897	 90034	 0.099755	 0.25648	 0.00397	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89898	 89900	 0.10015	 0.19832	 0.00291	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89906	 89907	 0.031579	 0.083701	 0.00212	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89906	 89908	 0.063352	 0.16112	 0.00255	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89910	 89913	 0.056715	 0.44231	 0.00827	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89914	 89921	 0.23542	 0.15245	 0.0029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89916	 90082	 0.010336	 0.063546	 0.00115	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89919	 89920	 0.023081	 0.042276	 0.00073	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89922	 89923	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89927	 89931	 0.011008	 0.031573	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89928	 89929	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89930	 89931	 0.092932	 0.073547	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89930	 89946	 0.029133	 0.066628	 0.00163	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89933	 89934	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89936	 89944	 0.003588	 0.010005	 0.0021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89936	 89965	 0.014	 0.040156	 0.00988	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	89937	 89939	 0.001711	 0.007982	 0.00198	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	89938	 89946	 0.005481	 0.021087	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89938	 89969	 0.008942	 0.023637	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89939	 89940	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89940	 89943	 0.020949	 0.060086	 0.00092	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89940	 89946	 0.008829	 0.022695	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89941	 89942	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89942	 89943	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89951	 89952	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89951	 89965	 0.002764	 0.028157	 0.00726	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89953	 89959	 0.003966	 0.016556	 0.00048	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89954	 89955	 0.002335	 0.011588	 0.00028	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89954	 89958	 0.011112	 0.031872	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89964	 89965	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89965	 89994	 0.001866	 0.01858	 0.0069	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89966	 89967	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89969	 89970	 0.00855	 0.021221	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89970	 89971	 0.01715	 0.036752	 0.00064	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	89971	 89974	 0.03955	 0.078306	 0.00115	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89982	 89986	 0.014391	 0.041275	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89985	 89986	 0.004693	 0.02472	 0.00044	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	89987	 89989	 0.013405	 0.035436	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	89987	 89992	 0.12412	 0.15132	 0.00243	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89988	 89990	 0.018513	 0.033907	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	89990	 89991	 0.016472	 0.042343	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	89995	 90001	 0.094617	 0.11327	 0.00189	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	89998	 89999	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	89998	 90000	 0.000207	 0.002421	 0.00977	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90000	 90001	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90007	 90010	 0.010899	 0.053123	 0.001	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90008	 90015	 0.012769	 0.042595	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90009	 90010	 0.005569	 0.023918	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90010	 90016	 0.011745	 0.03113	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90011	 90012	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90012	 90029	 0.015477	 0.040112	 0.00076	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90018	 90023	 0.13613	 0.122	 0.0025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90022	 90023	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90026	 90027	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90028	 90029	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90030	 90031	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90035	 90259	 0.048499	 0.21251	 0.00457	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	90035	 90260	 0.15178	 0.35248	 0.00671	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90042	 90043	 0.027511	 0.049448	 0.00089	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90042	 90045	 0.036498	 0.028884	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90046	 90057	 0.21393	 0.15742	 0.0023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90047	 90048	 0.02662	 0.052706	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90047	 90110	 0.13759	 0.3906	 0.00614	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90051	 90052	 0.057121	 0.091923	 0.00144	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90061	 90062	 0.049006	 0.18122	 0.00336	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90062	 90064	 0.27852	 0.22047	 0.00278	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90062	 90074	 0.35873	 0.28132	 0.00361	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90069	 90070	 0.12084	 0.20359	 0.0029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90072	 90073	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90081	 90082	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90083	 90084	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90083	 90086	 0.004608	 0.017517	 0.0049	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90088	 90089	 0.053486	 0.1573	 0.00322	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90090	 90092	 0.081623	 0.24007	 0.00492	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90090	 90116	 0.039819	 0.1976	 0.00471	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90090	 90117	 0.53134	 0.41689	 0.00535	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90091	 90117	 0.13473	 0.24221	 0.00435	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90092	 90094	 0.10608	 0.21006	 0.00308	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90096	 90097	 0.012471	 0.022501	 0.00033	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90101	 90109	 0.093964	 0.18417	 0.00276	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90102	 90103	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90107	 90749	 0.16149	 0.29146	 0.00421	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90111	 90112	 0.005242	 0.023794	 0.00052	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90113	 90114	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90125	 90162	 0.36291	 0.37083	 0.00578	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90132	 90261	 0.077356	 0.2219	 0.00341	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90134	 90135	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90135	 90136	 0.042237	 0.031075	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90138	 90140	 0.50369	 0.39896	 0.00502	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90147	 90152	 0.009665	 0.032241	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90149	 90150	 0.004779	 0.018593	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90150	 90152	 0.007428	 0.015612	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90153	 90154	 0.018958	 0.031617	 0.00046	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90157	 90160	 0.004028	 0.030463	 0.00101	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90158	 90159	 0.079575	 0.053454	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90164	 90165	 0.27029	 0.17504	 0.00333	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90174	 93071	 0.67587	 0.53571	 0.00674	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90175	 90176	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90178	 90179	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90181	 90182	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90182	 90184	 0.13503	 0.13639	 0.00181	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90183	 90184	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90185	 90186	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90190	 90269	 0.031852	 0.086747	 0.01912	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90192	 90216	 0.011316	 0.026271	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90193	 90194	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90194	 90208	 0.030185	 0.053916	 0.0008	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90199	 90219	 0.093399	 0.10273	 0.00137	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90205	 90208	 0.015478	 0.030646	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90207	 90209	 0.03143	 0.024873	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90210	 90212	 0.025826	 0.033943	 0.00047	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90210	 90216	 0.059098	 0.10664	 0.00154	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90214	 90215	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90216	 90218	 0.01779	 0.059346	 0.00094	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90217	 90220	 0.040234	 0.078853	 0.00118	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90218	 90220	 0.022878	 0.057949	 0.00115	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90219	 90263	 0.25695	 0.20146	 0.00259	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90222	 90224	 0.003327	 0.014825	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90223	 90224	 0.031744	 0.034914	 0.00047	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90227	 90228	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90229	 90230	 0.000234	 0.017577	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90231	 90232	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90235	 90236	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90245	 90246	 0.022923	 0.016571	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90249	 93706	 0.2799	 0.23048	 0.00467	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90251	 90252	 0.008002	 0.033868	 0.00762	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90252	 90253	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90269	 90270	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90269	 90273	 0.006648	 0.032263	 0.00738	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90274	 90275	 0.097608	 0.14954	 0.0021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90277	 90597	 0.015079	 0.10231	 0.00191	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90285	 90424	 0.060825	 0.039379	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90287	 90288	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90288	 90289	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90289	 90422	 0.009956	 0.043868	 0.00076	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90291	 90436	 0.11893	 0.093225	 0.0012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90293	 90294	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90294	 90601	 0.024413	 0.047845	 0.00072	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90294	 90602	 0.099904	 0.10989	 0.00147	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90295	 90296	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90296	 90299	 0.009111	 0.030067	 0.00049	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90297	 90298	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90298	 90299	 0.004517	 0.024066	 0.00042	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90302	 90303	 0.015706	 0.042764	 0.00942	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90306	 90563	 0.068219	 0.20953	 0.00393	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90308	 90309	 0.11542	 0.19252	 0.0028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90310	 90580	 0.056462	 0.13107	 0.0025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90313	 90314	 0.029993	 0.10005	 0.00159	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90317	 90475	 0.051259	 0.13587	 0.00345	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90322	 90323	 0.28125	 0.22263	 0.0028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90322	 90493	 0.063418	 0.27242	 0.00499	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90323	 90324	 0.053685	 0.2097	 0.00465	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90328	 90560	 0.023542	 0.034305	 0.00078	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90329	 90560	 0.007782	 0.020005	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90330	 90560	 0.008372	 0.032209	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90331	 90332	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90340	 90401	 0.034664	 0.068632	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90345	 90595	 0.16859	 0.13343	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90347	 90353	 0.063009	 0.049865	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90350	 90351	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90351	 90352	 0.027489	 0.062354	 0.00124	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90351	 90353	 0.040838	 0.080858	 0.00119	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90352	 90353	 0.040838	 0.032319	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90354	 90355	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90354	 90356	 0.000797	 0.005375	 0.0099	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90354	 90633	 0.001158	 0.008121	 0.01383	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90356	 90357	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90356	 90379	 0.006208	 0.041907	 0.07722	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90357	 90358	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90359	 90361	 0.070948	 0.14048	 0.00206	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90360	 90361	 0.30871	 0.24439	 0.00308	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90362	 90515	 0.34007	 0.37425	 0.005	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90367	 90368	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90369	 90638	 0.078016	 0.2603	 0.00413	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90370	 90611	 0.052148	 0.27476	 0.00493	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90371	 90372	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90372	 90374	 0.088687	 0.14732	 0.00312	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90381	 90388	 0.008826	 0.034337	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90381	 90431	 0.013579	 0.024501	 0.00035	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90384	 90446	 0.005421	 0.010734	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90387	 90399	 0.017716	 0.046833	 0.00085	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90388	 90423	 0.016825	 0.028343	 0.0004	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90391	 90449	 0.010311	 0.01737	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90392	 90407	 0.010524	 0.052636	 0.00094	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90392	 90449	 0.013069	 0.037086	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90393	 90407	 0.008984	 0.045447	 0.00079	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90394	 90395	 0.021021	 0.016635	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90395	 90397	 0.008269	 0.030573	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90396	 90397	 0.002597	 0.012987	 0.00023	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90397	 90399	 0.021532	 0.01704	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90397	 90451	 0.040203	 0.029063	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90405	 90407	 0.037974	 0.027451	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90406	 90407	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90413	 90414	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90414	 90420	 0.10055	 0.10267	 0.0016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90416	 90417	 0.005933	 0.03862	 0.00078	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90416	 90425	 0.1171	 0.086159	 0.00126	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90417	 90418	 0.017184	 0.032909	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90427	 90428	 0.018511	 0.055716	 0.00109	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90435	 90436	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90435	 90551	 0.004365	 0.011719	 0.00266	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90436	 90440	 0.003618	 0.020564	 0.00037	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90437	 90453	 0.029293	 0.023182	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90438	 90453	 0.018113	 0.014334	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90439	 90452	 0.026148	 0.020693	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90450	 90451	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90455	 90456	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90458	 90459	 0.1795	 0.3439	 0.00541	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90460	 90461	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90463	 90464	 0.004136	 0.038933	 0.01179	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90465	 90468	 0.021919	 0.078301	 0.00155	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90465	 90469	 0.098856	 0.1777	 0.00319	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90467	 90469	 0.21316	 0.2345	 0.00313	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90469	 90470	 0.062893	 0.20983	 0.00333	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90471	 93249	 0.026934	 0.26399	 0.00517	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90472	 90473	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90476	 90477	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90477	 90649	 0.18325	 0.42566	 0.00811	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90480	 90493	 0.43382	 0.35745	 0.00724	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90481	 90646	 0.083873	 0.21741	 0.00411	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90487	 90488	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90496	 90506	 0.088234	 0.069829	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90499	 90509	 0.026974	 0.10702	 0.00306	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90502	 90503	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90511	 90512	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90516	 90517	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90521	 90522	 0.038853	 0.19538	 0.00531	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90526	 90527	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90528	 90531	 0.018966	 0.017785	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90530	 90533	 0.006045	 0.010866	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90531	 90533	 0.015643	 0.026352	 0.00038	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90533	 90534	 0.015472	 0.011383	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90534	 90539	 0.008478	 0.016786	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90545	 90546	 0.015552	 0.039551	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90547	 90548	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90547	 90550	 0.000566	 0.003724	 0.00721	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90550	 90551	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90551	 90552	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90555	 90556	 0.013029	 0.034441	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90568	 93724	 0.10017	 0.23725	 0.00434	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90570	 90723	 0.09635	 0.18885	 0.00283	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90571	 90574	 0.040729	 0.044363	 0.0006	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90573	 90574	 0.007061	 0.007541	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90573	 90575	 0.010054	 0.010056	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90577	 90587	 0.03806	 0.03012	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90581	 90583	 0.080056	 0.2802	 0.00581	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90588	 90724	 0.010211	 0.034063	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90592	 90593	 0.10934	 0.070791	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90598	 90640	 0.02312	 0.048592	 0.00089	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90600	 90642	 0.071387	 0.23561	 0.00382	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90602	 90604	 0.067831	 0.053681	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90602	 90606	 0.075463	 0.059721	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90607	 90608	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90616	 90618	 0.12656	 0.24809	 0.00372	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90621	 90623	 0.016574	 0.08508	 0.00161	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90622	 90623	 0.048036	 0.037653	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90623	 90625	 0.01779	 0.088274	 0.0021	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90629	 90634	 0.077254	 0.060556	 0.00078	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90630	 90634	 0.013499	 0.03134	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90633	 90634	 0.000247	 0.018554	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90639	 90643	 0.008704	 0.05351	 0.00096	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90641	 90642	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90653	 90654	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90654	 90656	 0.026546	 0.026077	 0.00044	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90654	 90659	 0.10207	 0.08078	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90655	 90660	 0.063419	 0.05019	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90657	 90658	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90660	 90661	 0.00944	 0.02023	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90663	 90666	 0.072923	 0.057711	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90668	 90737	 0.006046	 0.034371	 0.00995	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	90670	 90671	 0.000318	 0.022264	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90673	 90972	 0.6775	 0.5319	 0.00683	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90674	 90732	 0.038815	 0.09501	 0.00162	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90692	 90693	 0.034836	 0.027569	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90694	 90696	 0.047533	 0.037617	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90695	 90696	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90696	 90705	 0.076851	 0.06082	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90696	 90711	 0.12804	 0.16829	 0.00231	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90699	 90700	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90700	 90707	 0.14083	 0.094604	 0.00167	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90702	 90712	 0.097528	 0.074812	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90706	 90707	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90711	 90964	 0.20764	 0.41131	 0.00604	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90714	 90742	 0.11769	 0.23306	 0.00342	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90717	 90718	 0.049649	 0.036529	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90720	 90721	 0.011181	 0.036899	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90722	 90723	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90726	 90736	 0.072945	 0.13112	 0.00235	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90728	 90729	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90729	 90730	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90730	 90738	 0.081907	 0.10292	 0.00155	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90732	 90735	 0.04805	 0.037664	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90735	 90736	 0.079642	 0.063029	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90736	 90924	 0.093275	 0.26474	 0.00416	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90739	 90742	 0.023713	 0.055053	 0.00082	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90740	 90741	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90741	 90742	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90749	 90750	 0.075231	 0.13523	 0.00243	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90751	 90752	 0.10392	 0.20578	 0.00302	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90758	 90759	 0.34502	 0.27056	 0.00347	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90761	 90762	 0.059422	 0.11766	 0.00173	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90762	 90763	 0.028721	 0.050509	 0.00095	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90763	 90765	 0.17912	 0.14177	 0.00178	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90765	 90959	 0.045491	 0.13971	 0.00262	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90767	 90980	 0.097155	 0.29845	 0.0056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90769	 90778	 0.19129	 0.14996	 0.00193	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90769	 90944	 0.10695	 0.083835	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90770	 90772	 0.035808	 0.028338	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90771	 90772	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90771	 90933	 0.012066	 0.03365	 0.00706	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90775	 90776	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90778	 90780	 0.11033	 0.087317	 0.0011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90783	 90784	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90784	 90785	 0.045973	 0.058509	 0.00086	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90784	 90786	 0.019465	 0.074888	 0.00128	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90791	 90792	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90798	 90799	 0.004216	 0.011173	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90799	 90801	 0.011572	 0.071142	 0.00128	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90800	 90801	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90801	 90804	 0.013321	 0.074848	 0.00139	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90808	 90809	 0.15655	 0.26377	 0.00376	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	90812	 90813	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90813	 90815	 0.018249	 0.033424	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90814	 90815	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90815	 91002	 0.025521	 0.031112	 0.0005	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90817	 90818	 0.02088	 0.013518	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90818	 90819	 0.030072	 0.03016	 0.00049	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90820	 90823	 0.018024	 0.035686	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90832	 90834	 0.013215	 0.010458	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90837	 90838	 0.013431	 0.022431	 0.00038	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90838	 90844	 0.015228	 0.031163	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90843	 90844	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90844	 90872	 0.010446	 0.034846	 0.00055	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90844	 90889	 0.035958	 0.071194	 0.00105	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90847	 90891	 0.007003	 0.012587	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90847	 90892	 0.008671	 0.010571	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90848	 90892	 0.03263	 0.025823	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90861	 90862	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90863	 90864	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90865	 90895	 0.098644	 0.088397	 0.00181	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90869	 91005	 0.040409	 0.02973	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90873	 90875	 0.011889	 0.012696	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90874	 90877	 0.006746	 0.017341	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90876	 91010	 0.019912	 0.04874	 0.00083	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90880	 90882	 0.018521	 0.053121	 0.00082	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90880	 90896	 0.033379	 0.061137	 0.00106	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90881	 90882	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90882	 90883	 0.07102	 0.052253	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90882	 90886	 0.013876	 0.053981	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90882	 90887	 0.006793	 0.033706	 0.0008	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90893	 90897	 0.006144	 0.012042	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90894	 90895	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90903	 90904	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90905	 90910	 0.019247	 0.014161	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90906	 90911	 0.019062	 0.014942	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90914	 90916	 0.012185	 0.035832	 0.00073	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90915	 91030	 0.48957	 0.38406	 0.00493	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90917	 90918	 0.000652	 0.004132	 0.00865	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90918	 90919	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90926	 91044	 0.065869	 0.21976	 0.00348	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90933	 90934	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90933	 90936	 0.002537	 0.007348	 0.00177	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90936	 90937	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90938	 90939	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90939	 90942	 0.092346	 0.076011	 0.00154	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	90943	 90944	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90947	 90949	 0.30068	 0.23576	 0.00303	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90947	 90981	 0.1129	 0.33212	 0.00681	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90948	 90949	 0.11837	 0.08557	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90951	 90952	 0.047215	 0.093484	 0.00137	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90951	 90955	 0.014364	 0.0474	 0.00077	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90958	 90959	 0.042096	 0.097718	 0.00186	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	90966	 90972	 0.076448	 0.060501	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90970	 90971	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90970	 90973	 0.001475	 0.009837	 0.01854	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90971	 90972	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90973	 90974	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90973	 90977	 0.001619	 0.0108	 0.02036	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	90974	 90976	 0.29315	 0.21199	 0.00321	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90977	 90978	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	90980	 90982	 0.13559	 0.35155	 0.00665	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90986	 90987	 0.017256	 0.097098	 0.0021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90988	 90989	 0.012689	 0.049365	 0.00082	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90992	 90995	 0.041369	 0.032739	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90994	 90996	 0.042951	 0.05645	 0.00077	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	90994	 90997	 0.19925	 0.12901	 0.00246	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90998	 91000	 0.029442	 0.0233	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	90999	 91000	 0.12971	 0.10266	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91007	 91008	 0.10947	 0.070874	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91009	 91010	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91013	 91014	 0.056184	 0.044464	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91016	 91018	 0.033218	 0.021505	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91018	 91022	 0.069627	 0.091513	 0.00125	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91019	 91021	 0.070717	 0.1386	 0.00208	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91020	 91028	 0.049528	 0.16346	 0.00265	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91033	 91034	 0.041565	 0.029442	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91039	 91040	 0.027517	 0.021776	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91041	 91042	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91046	 91047	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91046	 91047	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91046	 91412	 0.0021	 0.033074	 0.34567	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91046	 91440	 0.002395	 0.043583	 0.43771	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91047	 91048	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91047	 91048	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91047	 91090	 0.004341	 0.022613	 0.00593	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91047	 91387	 0.022263	 0.080632	 0.01731	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91049	 91050	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91049	 91050	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91049	 91248	 0.003175	 0.03604	 0.32906	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91049	 91458	 0.000926	 0.010685	 0.09369	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91050	 91084	 0.002807	 0.01822	 0.0363	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91051	 91052	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91051	 91052	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91051	 91248	 0.004756	 0.060076	 0.59659	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91051	 91422	 0.002356	 0.02588	 0.25178	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91052	 91053	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91052	 91053	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91053	 91054	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91053	 91054	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91055	 91056	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91055	 91056	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91055	 91064	 0.00092	 0.014332	 0.06022	 1023.0	 1074.1	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91056	 91057	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91056	 91057	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91056	 91303	 0.054281	 0.15739	 0.03802	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91059	 91060	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91059	 91060	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91061	 91062	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91061	 91062	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91061	 91334	 0.000886	 0.012182	 0.02427	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91062	 91063	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91062	 91063	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91062	 91092	 0.003227	 0.016496	 0.0045	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91064	 91065	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91064	 91065	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91064	 91407	 0.000669	 0.008746	 0.02831	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91065	 91349	 0.046664	 0.12341	 0.02891	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91065	 91419	 0.047647	 0.13296	 0.02793	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91066	 91067	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91066	 91067	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91066	 91358	 0.001779	 0.02113	 0.00736	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91068	 91069	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91068	 91069	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91069	 91289	 0.076828	 0.37506	 0.00648	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91069	 91377	 0.029226	 0.097498	 0.00155	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91070	 91071	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91070	 91071	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91071	 91072	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91071	 91072	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91071	 91548	 0.017093	 0.14527	 0.08729	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91075	 91076	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91075	 91076	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91075	 91107	 0.000122	 0.001206	 0.00257	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91075	 91386	 0.001354	 0.014441	 0.02937	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91078	 91079	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91078	 91079	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91079	 91522	 0.051399	 0.19998	 0.00334	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91083	 91277	 0.17009	 0.23193	 0.00515	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91084	 91085	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91084	 91085	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91084	 91459	 0.001149	 0.007662	 0.01444	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91084	 91461	 0.001359	 0.009529	 0.01622	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91085	 91086	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91085	 91086	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91090	 91431	 0.001469	 0.006066	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91091	 91092	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91091	 91092	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91092	 91093	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91092	 91093	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91093	 91094	 0.05194	 0.28433	 0.00556	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91094	 91340	 0.044605	 0.22567	 0.00393	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91094	 91359	 0.074036	 0.15867	 0.00278	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91095	 91096	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91095	 91096	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91096	 91271	 0.2331	 0.53598	 0.00815	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91098	 91292	 0.01092	 0.07298	 0.00162	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91103	 91443	 0.023397	 0.10251	 0.0022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91105	 91106	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91105	 91106	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91105	 91294	 0.004899	 0.016807	 0.00403	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91107	 91108	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91107	 91108	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91109	 91110	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91109	 91110	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91113	 91114	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91113	 91114	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91113	 91602	 0.001413	 0.014284	 0.0042	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91114	 91604	 0.035963	 0.16026	 0.00272	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91115	 91141	 0.003259	 0.014952	 0.00383	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91116	 91117	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91116	 91117	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91116	 91589	 0.001347	 0.010689	 0.02057	 397.0	 416.8	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91118	 91119	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91118	 91119	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91120	 91121	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91120	 91121	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91120	 91123	 0.000225	 0.001552	 0.00274	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91121	 91740	 0.039867	 0.10027	 0.02599	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91122	 91123	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91122	 91123	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91123	 91135	 0.000254	 0.001648	 0.00328	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91123	 91913	 0.006678	 0.046026	 0.08132	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91124	 91125	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91124	 91125	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91128	 91129	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91128	 91129	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91128	 91659	 0.000616	 0.004156	 0.00765	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91130	 91165	 0.000336	 0.003946	 0.00105	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91130	 91587	 0.004038	 0.013853	 0.00332	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91131	 91132	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91131	 91132	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91132	 91535	 0.064548	 0.33145	 0.00627	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91134	 91159	 0.000104	 0.001745	 0.00099	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91135	 91144	 0.000132	 0.001543	 0.00344	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91136	 91137	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91136	 91137	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91138	 91139	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91138	 91139	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91139	 91140	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91139	 91140	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91139	 91155	 0.001703	 0.011728	 0.0207	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91141	 91142	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91141	 91142	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91143	 91735	 0.005683	 0.060234	 0.01788	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91144	 91684	 0.004079	 0.026483	 0.05277	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91146	 91147	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91146	 91147	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91147	 91772	 0.001241	 0.007713	 0.00218	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91148	 91149	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91148	 91149	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91148	 91586	 0.004163	 0.058422	 0.1122	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91149	 91150	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91149	 91150	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91151	 91659	 0.000353	 0.004208	 0.00911	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91151	 91662	 0.001065	 0.007336	 0.01295	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91152	 91153	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91152	 91153	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91153	 91941	 0.011863	 0.045641	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91156	 91157	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91156	 91157	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91157	 91699	 0.00028	 0.004568	 0.00273	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91158	 91159	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91158	 91159	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91159	 91160	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91159	 91160	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91161	 91867	 0.04266	 0.16597	 0.00277	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91161	 91867	 0.04266	 0.16597	 0.00277	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91163	 91164	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91163	 91164	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91165	 91166	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91165	 91166	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91165	 91578	 0.003732	 0.012172	 0.00323	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91166	 91594	 0.010405	 0.034336	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91170	 91550	 0.071313	 0.27749	 0.00463	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91172	 91619	 0.002709	 0.026549	 0.00052	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91173	 91174	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91173	 91174	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91175	 91862	 0.002343	 0.016083	 0.00029	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91176	 91177	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91176	 91177	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91177	 91178	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91177	 91178	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91179	 91180	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91179	 91180	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91180	 92940	 0.028168	 0.086414	 0.00234	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91180	 92940	 0.028168	 0.086414	 0.00234	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91181	 91182	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91181	 91182	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91181	 92241	 0.000642	 0.00907	 0.14653	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91182	 91193	 0.003264	 0.034609	 0.07932	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91183	 91184	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91183	 91184	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91185	 91186	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91185	 91186	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91185	 92034	 0.005291	 0.021185	 0.00534	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91186	 92133	 0.016059	 0.084594	 0.00152	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91187	 91188	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91187	 91188	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91189	 91190	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91189	 91190	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91191	 91192	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91191	 91192	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91192	 92035	 0.007514	 0.021322	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91193	 91194	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91193	 91194	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91193	 92224	 0.000636	 0.008211	 0.0186	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91193	 92373	 3.1e-05	 0.000436	 0.00084	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91194	 91195	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91194	 91195	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91196	 91197	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91196	 91197	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91196	 92241	 0.001751	 0.01992	 0.18005	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91197	 91198	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91197	 91198	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91197	 92380	 0.004106	 0.027707	 0.05103	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91198	 91199	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91198	 91199	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91198	 92243	 0.040622	 0.12237	 0.03833	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91201	 91202	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91201	 91202	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91202	 92053	 0.16321	 0.50131	 0.0136	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91202	 92103	 0.093587	 0.24061	 0.00372	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91202	 92216	 0.21781	 0.44796	 0.00855	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91204	 91205	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91204	 91205	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91205	 91958	 0.090248	 0.34733	 0.00593	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91206	 92861	 0.001152	 0.017933	 0.00556	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91207	 91208	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91207	 91208	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91208	 91209	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91208	 91209	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91210	 91211	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91210	 91211	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91214	 91215	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91214	 91215	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91214	 92179	 0.001418	 0.015644	 0.02972	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91214	 92179	 0.001418	 0.015644	 0.02972	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91215	 91216	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91215	 91216	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91219	 91220	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91219	 91220	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91220	 92223	 0.12617	 0.33365	 0.00606	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91223	 92206	 0.1176	 0.30239	 0.00468	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91224	 92068	 0.026766	 0.13062	 0.00225	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	91229	 91230	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91229	 91230	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91229	 92385	 0.001299	 0.011129	 0.02118	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91230	 91231	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91230	 91231	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91232	 92328	 0.005802	 0.026903	 0.00056	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91233	 91988	 0.1165	 0.24971	 0.00437	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91236	 91965	 0.055169	 0.091639	 0.00194	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91238	 92201	 0.083234	 0.1094	 0.0015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91239	 92940	 0.095637	 0.21975	 0.00334	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91241	 92147	 0.12514	 0.099042	 0.00125	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91242	 91964	 0.004247	 0.008691	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91242	 91972	 0.03446	 0.027271	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91243	 91244	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91243	 91244	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91243	 92019	 0.001071	 0.009801	 0.01887	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91244	 91245	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91244	 91245	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91248	 91249	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91248	 91249	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91248	 91824	 0.005905	 0.082995	 0.83484	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91249	 91250	 7.2e-05	 0.005736	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91250	 91251	 0.000108	 0.00862	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91254	 91318	 0.081992	 0.29299	 0.00582	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91256	 91257	 0.019781	 0.036781	 0.00086	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91266	 91267	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91272	 91317	 0.14034	 0.2885	 0.0055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91273	 91507	 0.21371	 0.34133	 0.00787	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91274	 91275	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91275	 91276	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91281	 91411	 0.099047	 0.33051	 0.00524	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91283	 91284	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91285	 91286	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91288	 91289	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91290	 91937	 0.09018	 0.2715	 0.00531	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91291	 91511	 0.1122	 0.25782	 0.00392	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91294	 91295	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91297	 91298	 0.003913	 0.016155	 0.00382	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91303	 91304	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91305	 91306	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91305	 91308	 0.003718	 0.009826	 0.0023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91308	 91309	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91311	 91312	 0.000525	 0.005867	 0.05482	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91311	 91314	 0.00049	 0.005374	 0.0522	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91312	 91313	 0.000147	 0.011792	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91312	 91422	 0.001233	 0.012203	 0.20899	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91312	 91422	 0.001233	 0.012203	 0.20899	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91313	 91369	 0.35658	 0.63775	 0.00942	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91314	 91315	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91316	 91317	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91318	 91418	 0.10306	 0.54962	 0.00965	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91319	 91384	 0.15755	 0.50772	 0.00866	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91321	 91322	 0.035263	 0.078047	 0.00128	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91328	 91329	 0.027259	 0.089956	 0.00146	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91330	 91331	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91330	 91386	 0.001836	 0.023718	 0.05376	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91332	 91333	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91332	 91334	 0.001236	 0.010301	 0.03213	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91337	 91359	 0.045324	 0.1512	 0.0024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91342	 91343	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91344	 91345	 0.065322	 0.15166	 0.00226	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91346	 91347	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91346	 92229	 0.007382	 0.066839	 0.13204	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91348	 91392	 0.10738	 0.24934	 0.00371	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91349	 91350	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91351	 91352	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91351	 91353	 0.000883	 0.007762	 0.01619	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91354	 91360	 0.11265	 0.27967	 0.00465	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91354	 91361	 0.09339	 0.21682	 0.00413	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91355	 91356	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91355	 91357	 0.002548	 0.0102	 0.00257	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91361	 91501	 0.28758	 0.51934	 0.00751	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91362	 91363	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91365	 91366	 0.00019	 0.014284	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91365	 91476	 0.001965	 0.028552	 0.25869	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91366	 91367	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91366	 91423	 0.008887	 0.062383	 0.10638	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91372	 91373	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91375	 91376	 0.009838	 0.017301	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91381	 91382	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91382	 91484	 0.006577	 0.042718	 0.08516	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91383	 91384	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91387	 91388	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91387	 91389	 0.004931	 0.018742	 0.00525	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91390	 91391	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91394	 91396	 0.057713	 0.10732	 0.00251	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91395	 91396	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91402	 91403	 0.016792	 0.056018	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91405	 91406	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91407	 91408	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91412	 91413	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91414	 91415	 0.00024	 0.017998	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91419	 91420	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91420	 91425	 0.054478	 0.1798	 0.00291	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91422	 91423	 0.000104	 0.008333	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91422	 91423	 0.000104	 0.008333	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91422	 92242	 0.00417	 0.047402	 0.43375	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91423	 91424	 0.000116	 0.009277	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91426	 91427	 0.11125	 0.25833	 0.00384	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91429	 91434	 0.024876	 0.082986	 0.00132	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91430	 91431	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91431	 91432	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91433	 91434	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91436	 91437	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91436	 91442	 0.004354	 0.023057	 0.00584	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91437	 91445	 0.007131	 0.040533	 0.00073	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91439	 91444	 0.028226	 0.055885	 0.00082	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91440	 91441	 9.3e-05	 0.007407	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91441	 91442	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91441	 91461	 0.000926	 0.006174	 0.01164	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91442	 91443	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91442	 91462	 0.010427	 0.027559	 0.00645	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91443	 91474	 0.015077	 0.058656	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91444	 91468	 0.011727	 0.052255	 0.00089	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91458	 91459	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91459	 91460	 0.000247	 0.018554	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91463	 91469	 0.018629	 0.042798	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91464	 91489	 0.027928	 0.077361	 0.00128	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91470	 91471	 0.00545	 0.037968	 0.00089	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91476	 91477	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91477	 91478	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91480	 91481	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91484	 91485	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91485	 91486	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91487	 91488	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91491	 91492	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91496	 91497	 0.007136	 0.040566	 0.00073	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91498	 91499	 0.017622	 0.077644	 0.00135	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91498	 91500	 0.036103	 0.10867	 0.00212	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91505	 91506	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91508	 91938	 0.18604	 0.6213	 0.00986	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91520	 91521	 0.047547	 0.12223	 0.00189	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91523	 91524	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91530	 91702	 0.008776	 0.076037	 0.02731	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91533	 91534	 0.013707	 0.029374	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91539	 91866	 0.007725	 0.048006	 0.01355	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91548	 91549	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91549	 91599	 0.12851	 0.29843	 0.00444	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91554	 91555	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91558	 91573	 0.087834	 0.22582	 0.0035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91559	 91562	 0.013513	 0.022568	 0.00038	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91561	 91562	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91566	 91567	 0.014814	 0.025524	 0.00041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91569	 91570	 0.014686	 0.030053	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91575	 91579	 0.022853	 0.03466	 0.0005	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91578	 91579	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91581	 91582	 0.021575	 0.055461	 0.00086	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91581	 91584	 0.014255	 0.037783	 0.00096	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91585	 91590	 0.003096	 0.04731	 0.01524	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91586	 91587	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91587	 91588	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91589	 91590	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91590	 91591	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91593	 91596	 0.016211	 0.051474	 0.0009	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91598	 91726	 0.13579	 0.31207	 0.00474	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91602	 91603	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91607	 91640	 0.004519	 0.025392	 0.00047	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91608	 91611	 0.003262	 0.016316	 0.00029	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91609	 91612	 0.022427	 0.044404	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91615	 91616	 0.000446	 0.031247	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91618	 91633	 0.012277	 0.040956	 0.00065	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91621	 91634	 0.022732	 0.053829	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91621	 91640	 0.14524	 0.094034	 0.00179	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91624	 91630	 0.068148	 0.13493	 0.00198	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91629	 91630	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91636	 91644	 0.00732	 0.034645	 0.00833	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91642	 91942	 0.077707	 0.18042	 0.00268	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91643	 91944	 0.14654	 0.25254	 0.00402	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91646	 91647	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91651	 91652	 0.013433	 0.092209	 0.00168	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91654	 91655	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91656	 91657	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91656	 91657	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91657	 91658	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91657	 91658	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91659	 91660	 0.000234	 0.017577	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91661	 91662	 7.1e-05	 0.005714	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91665	 91669	 0.004321	 0.029318	 0.00055	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91668	 91669	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91675	 91784	 0.00819	 0.023491	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91680	 91681	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91684	 91685	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91685	 91686	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91687	 91688	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91687	 91861	 0.002227	 0.016262	 0.00418	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91694	 91812	 0.007766	 0.022038	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91696	 91697	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91699	 91700	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91705	 91706	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91709	 91710	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91715	 91716	 0.006355	 0.021199	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91721	 91722	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91723	 91724	 0.21459	 0.39327	 0.00679	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91725	 91915	 0.02633	 0.10244	 0.00171	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91725	 91915	 0.02633	 0.10244	 0.00171	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91729	 91730	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91735	 91736	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91737	 91738	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91739	 91740	 0.004001	 0.019522	 0.00539	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91742	 91942	 0.20682	 0.47546	 0.00723	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91743	 91744	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91746	 91747	 0.056335	 0.14482	 0.00224	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91749	 91750	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91755	 91758	 0.000732	 0.003808	 0.00112	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91756	 91757	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91758	 91759	 0.000589	 0.00505	 0.00144	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91758	 91772	 0.00115	 0.012594	 0.00349	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91759	 91760	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91763	 91764	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91768	 91769	 0.000142	 0.011399	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91768	 91770	 0.000128	 0.001478	 0.01448	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91770	 91771	 0.000104	 0.008333	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91771	 91772	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91772	 91773	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91778	 91779	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91786	 91808	 0.008171	 0.014967	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91800	 91801	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91801	 91802	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91804	 91805	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91807	 91808	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91818	 91823	 0.028185	 0.065436	 0.00097	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91819	 91827	 0.013258	 0.10213	 0.00195	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91824	 91825	 0.000119	 0.009523	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91824	 91825	 0.000119	 0.009523	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91825	 91826	 8.5e-05	 0.006812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91826	 91827	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91830	 91832	 0.016983	 0.063708	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91830	 91832	 0.016983	 0.063708	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91831	 91832	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91835	 91841	 0.09884	 0.21879	 0.00359	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91836	 91837	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91840	 91841	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91844	 91851	 0.017444	 0.092944	 0.00163	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91855	 91856	 0.10911	 0.18198	 0.00265	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91859	 91862	 0.00416	 0.016503	 0.00047	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91860	 91861	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91861	 91862	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91866	 91867	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91875	 91877	 0.055016	 0.1179	 0.00206	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91884	 91885	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91884	 91913	 0.002588	 0.017263	 0.03254	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91885	 91886	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91885	 91931	 0.023982	 0.12501	 0.03282	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91887	 91888	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91890	 91892	 0.062354	 0.1603	 0.00248	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91891	 91892	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91895	 91897	 0.01242	 0.031927	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	91898	 91899	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91899	 91900	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91905	 91931	 0.011677	 0.08753	 0.02136	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91907	 91908	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91907	 91931	 0.01458	 0.12514	 0.03565	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91911	 91912	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91911	 91914	 0.002989	 0.015891	 0.00369	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91913	 91914	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91916	 91917	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91917	 91918	 0.0397	 0.17692	 0.003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91920	 91921	 0.031958	 0.084706	 0.00215	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91926	 91927	 0.069323	 0.23129	 0.00367	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91930	 91932	 0.023308	 0.18168	 0.0034	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91931	 91932	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91931	 91932	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91934	 91935	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91935	 91936	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91937	 91939	 0.016166	 0.11097	 0.00202	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91943	 91944	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91943	 91945	 0.012611	 0.034336	 0.00756	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	91946	 91948	 0.019148	 0.14925	 0.00279	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	91947	 91948	 0.060537	 0.14055	 0.00209	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91954	 92204	 0.058994	 0.16922	 0.0026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91957	 92050	 0.31802	 0.53623	 0.00764	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	91962	 91963	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91962	 92378	 0.013624	 0.094968	 0.03573	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91966	 92222	 0.10268	 0.32613	 0.00572	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91968	 91969	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91970	 91971	 0.045959	 0.033813	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91970	 91972	 0.037922	 0.04171	 0.00056	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91971	 91972	 0.018512	 0.029548	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91971	 92267	 0.38951	 0.45706	 0.00795	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91975	 91977	 0.023962	 0.13465	 0.00249	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	91975	 92856	 0.3277	 0.57709	 0.01086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	91979	 91980	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91979	 91980	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91980	 91981	 9.8e-05	 0.007812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91982	 91983	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91985	 91986	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91987	 92271	 0.47266	 0.3351	 0.0053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	91995	 92245	 0.006415	 0.043548	 0.07935	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	91996	 91997	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	91996	 92000	 0.00085	 0.009629	 0.03593	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92000	 92001	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92001	 92002	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92003	 92004	 0.05677	 0.11618	 0.00286	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92006	 92007	 0.05089	 0.084532	 0.00179	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92006	 92957	 0.010014	 0.092125	 0.00183	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92012	 92013	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92013	 92096	 0.10092	 0.23434	 0.00349	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92014	 92015	 0.074985	 0.082476	 0.0011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92017	 92018	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92017	 92019	 0.000433	 0.004537	 0.00853	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92017	 92385	 0.003365	 0.027727	 0.05717	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92019	 92020	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92024	 92025	 0.039635	 0.031068	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92024	 92026	 0.025906	 0.034049	 0.00047	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92026	 92027	 0.007741	 0.025825	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92032	 92033	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92033	 92034	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92034	 92035	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92034	 92455	 0.011144	 0.031077	 0.00652	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92035	 93042	 0.013854	 0.035613	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92039	 92044	 0.020115	 0.041164	 0.00101	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92041	 92042	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92043	 92221	 0.12761	 0.15277	 0.00254	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92046	 92048	 0.020815	 0.12797	 0.00231	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92046	 92065	 0.091036	 0.20917	 0.00318	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92047	 92049	 0.085612	 0.1895	 0.00311	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92047	 92064	 0.13548	 0.30404	 0.00485	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92048	 92049	 0.018039	 0.072191	 0.00152	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92048	 92251	 0.079151	 0.23828	 0.00466	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92051	 92199	 0.10609	 0.35403	 0.00561	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92054	 92408	 0.39156	 0.36747	 0.00568	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92057	 92062	 0.037304	 0.088337	 0.00162	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92058	 92059	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92059	 92060	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92060	 92062	 0.018097	 0.10168	 0.00188	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92060	 92393	 0.082679	 0.2729	 0.00442	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92061	 92062	 0.13811	 0.2116	 0.00297	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92068	 92235	 0.20954	 0.34959	 0.00509	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92072	 92084	 0.070372	 0.08579	 0.00138	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92076	 92086	 0.007401	 0.039435	 0.00069	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92077	 92089	 0.002578	 0.014504	 0.00031	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92080	 92084	 0.017634	 0.040939	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92082	 92083	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92093	 92094	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92097	 92375	 0.093874	 0.24334	 0.0046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92098	 92099	 0.008135	 0.030922	 0.00866	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92099	 92100	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92100	 92238	 0.048658	 0.16058	 0.0026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92101	 92102	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92103	 92295	 0.05655	 0.21759	 0.00372	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92105	 92158	 0.024849	 0.057682	 0.0011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92106	 92107	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92106	 92150	 0.000479	 0.002808	 0.00076	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92109	 92110	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92113	 92158	 0.020644	 0.019015	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92113	 92160	 0.008017	 0.017179	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92117	 92119	 0.009705	 0.024949	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92120	 92121	 0.013544	 0.017801	 0.00024	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92122	 92124	 0.050233	 0.032521	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92123	 92124	 0.018421	 0.011926	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92127	 92128	 0.019645	 0.038895	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92129	 92132	 0.01418	 0.02779	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92137	 92141	 0.02703	 0.062744	 0.00119	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92140	 92141	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92149	 92155	 0.007264	 0.020613	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92150	 92151	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92152	 92153	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92154	 92155	 0.005875	 0.010924	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92159	 93059	 0.002567	 0.012984	 0.00023	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92164	 92165	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92168	 92233	 0.071033	 0.16492	 0.00245	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92169	 92233	 0.028619	 0.11177	 0.00248	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92170	 92171	 0.004707	 0.020976	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92172	 92356	 0.014093	 0.052866	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92174	 92175	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92177	 92178	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92179	 92180	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92179	 92183	 0.000617	 0.006489	 0.02813	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92179	 92186	 0.001361	 0.017126	 0.04094	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92180	 92181	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92183	 92184	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92183	 92245	 0.010197	 0.069283	 0.12641	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92184	 92185	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92185	 92189	 0.018331	 0.081684	 0.00139	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92185	 92190	 0.093516	 0.15597	 0.00227	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92186	 92187	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92186	 92396	 0.000904	 0.014098	 0.03029	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92187	 92188	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92188	 92189	 0.022189	 0.057039	 0.00088	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92192	 92194	 0.065223	 0.16589	 0.00262	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92192	 92195	 0.12977	 0.25699	 0.00377	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92193	 92194	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92198	 92199	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92201	 92202	 0.21453	 0.15511	 0.00235	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92205	 92382	 0.24448	 0.24971	 0.00389	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92206	 92208	 0.10685	 0.27473	 0.00425	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92207	 92223	 0.18419	 0.47379	 0.00734	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92210	 92212	 0.17636	 0.16413	 0.0031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92215	 92216	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92218	 92219	 0.053848	 0.17771	 0.00288	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92224	 92225	 0.000321	 0.02569	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92224	 92226	 0.00163	 0.015778	 0.05581	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92226	 92227	 0.000321	 0.02569	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92226	 92229	 0.001772	 0.011501	 0.02291	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92228	 92229	 0.000104	 0.008333	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92228	 92229	 0.000104	 0.008333	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92228	 92231	 0.000205	 0.003401	 0.03187	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92229	 92230	 7.6e-05	 0.006055	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92232	 92234	 0.096842	 0.097816	 0.0013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92235	 92236	 0.030948	 0.10324	 0.00164	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92241	 92242	 0.000153	 0.002672	 0.05505	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92242	 92243	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92243	 92244	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92245	 92246	 9.4e-05	 0.007517	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92246	 92247	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92247	 92293	 0.067509	 0.19159	 0.00301	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92251	 92252	 0.002972	 0.029124	 0.00057	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92257	 92258	 0.05125	 0.0993	 0.00214	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92259	 92260	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92266	 92267	 0.014799	 0.034357	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92269	 92270	 0.000582	 0.006481	 0.06112	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92270	 92271	 0.000214	 0.017099	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92274	 92317	 0.027208	 0.063157	 0.0012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92281	 92289	 0.0265	 0.050084	 0.00081	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92284	 92286	 0.015363	 0.047179	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92285	 92286	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92291	 92293	 0.14017	 0.23416	 0.00398	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92294	 92295	 0.027498	 0.12932	 0.00241	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92295	 92297	 0.036968	 0.10491	 0.00165	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92296	 92297	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92298	 92300	 0.011421	 0.026514	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92298	 92438	 0.003568	 0.013881	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92301	 92302	 0.013269	 0.044266	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92301	 92303	 0.010268	 0.02945	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92304	 92308	 0.011687	 0.033164	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92306	 92309	 0.015827	 0.026661	 0.00038	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92311	 92317	 0.033995	 0.078924	 0.00117	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92312	 92313	 0.008472	 0.019667	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92316	 92317	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92321	 92322	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92330	 92331	 8.3e-05	 0.006605	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92331	 92332	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92339	 92341	 0.017138	 0.044054	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92340	 92369	 0.037588	 0.087267	 0.0013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92349	 92414	 0.008592	 0.018412	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92350	 92357	 0.017323	 0.040219	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92353	 92354	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92354	 92355	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92361	 92362	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92363	 92364	 0.014158	 0.043478	 0.00082	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92363	 92365	 0.032453	 0.083425	 0.00129	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92365	 92369	 0.023095	 0.077043	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92366	 92369	 0.003149	 0.024541	 0.00046	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92368	 92369	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92371	 92372	 0.011427	 0.10638	 0.00206	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92380	 92381	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92385	 92386	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92390	 92407	 0.18957	 0.43578	 0.00662	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92396	 92397	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92397	 92398	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92400	 92401	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92401	 92402	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92403	 92404	 0.016346	 0.063591	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92409	 92413	 0.008751	 0.017909	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92411	 92412	 8.5e-05	 0.006812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92412	 92413	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92414	 92425	 0.009266	 0.01561	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92416	 92417	 0.011003	 0.027983	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92418	 92437	 0.0091	 0.021126	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92419	 92443	 0.021397	 0.058456	 0.00099	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92424	 92426	 0.042103	 0.030976	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92429	 92436	 0.012513	 0.038388	 0.00104	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92430	 92442	 0.00758	 0.019278	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92430	 92443	 0.05747	 0.045481	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92431	 92444	 0.005066	 0.013024	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92432	 92444	 0.006516	 0.012901	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92435	 92436	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92440	 92441	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92445	 92446	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92445	 92446	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92445	 92450	 0.069833	 0.24745	 0.05594	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92447	 92448	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92447	 92448	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92448	 92986	 0.12264	 0.32522	 0.00825	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92449	 92450	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92449	 92450	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92451	 92452	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92451	 92452	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92453	 92454	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92453	 92454	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92453	 92861	 0.000915	 0.006687	 0.00197	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92455	 92456	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92455	 92456	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92459	 92995	 0.012609	 0.12856	 0.03316	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92460	 92885	 0.1296	 0.3284	 0.00651	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92462	 92943	 0.055347	 0.43163	 0.00807	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92463	 92464	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92463	 92464	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92463	 92982	 0.013821	 0.087571	 0.02378	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92466	 92924	 0.026897	 0.069143	 0.00107	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92469	 92864	 0.074259	 0.28896	 0.00483	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92469	 92953	 0.27598	 0.44098	 0.01017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92469	 93037	 0.15972	 0.20789	 0.00291	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92474	 92882	 0.018778	 0.072243	 0.00123	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92475	 92476	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92475	 92476	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92479	 93052	 0.012376	 0.023011	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92480	 92851	 0.12872	 0.21687	 0.00309	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92487	 92488	 0.016057	 0.065352	 0.01593	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92487	 92489	 0.01662	 0.065332	 0.01709	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92488	 92489	 0.00066	 0.002643	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92488	 93239	 0.007905	 0.058413	 0.01686	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92489	 92493	 0.015181	 0.057711	 0.01616	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92490	 93675	 0.08288	 0.44548	 0.01059	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92492	 93238	 0.19738	 0.50235	 0.00795	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92493	 93239	 0.015097	 0.079977	 0.02028	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92494	 92495	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92494	 92495	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92494	 93239	 0.013171	 0.09319	 0.02559	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92495	 93222	 0.035583	 0.18108	 0.0041	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92496	 93230	 0.075881	 0.46664	 0.01068	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92496	 93262	 0.1354	 0.47459	 0.01316	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92497	 93236	 0.089941	 0.30011	 0.00476	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92498	 92499	 0.000578	 0.001328	 2e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92499	 93247	 0.13115	 0.46887	 0.00932	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92500	 93243	 0.00474	 0.021122	 0.00574	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92501	 92502	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92501	 92502	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92503	 92504	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92503	 92504	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92504	 92505	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92504	 92505	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92507	 93061	 0.00086	 0.010597	 0.00342	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92508	 92509	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92508	 92509	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92510	 93161	 0.009003	 0.040116	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92511	 93079	 0.03096	 0.19036	 0.00343	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92511	 93188	 0.05293	 0.069567	 0.00095	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92515	 92516	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92515	 92516	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92517	 93200	 0.01893	 0.047948	 0.00095	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92518	 93179	 0.000427	 0.002849	 0.00537	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92522	 93419	 0.010836	 0.076322	 0.04342	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92522	 93426	 0.001637	 0.011577	 0.00318	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92524	 92525	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92524	 92525	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92524	 92961	 0.037122	 0.19693	 0.05003	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92525	 93546	 0.24419	 0.15813	 0.00301	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92527	 93495	 0.004107	 0.044266	 0.02366	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92527	 93507	 0.003702	 0.023845	 0.00625	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92528	 92529	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92528	 92529	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92528	 93277	 0.003898	 0.042708	 0.01184	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92530	 92531	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92530	 92531	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92532	 93325	 0.054154	 0.12573	 0.00187	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92533	 93419	 0.004118	 0.022599	 0.00597	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92534	 92535	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92534	 92535	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92534	 93612	 0.000534	 0.006899	 0.01563	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92534	 93649	 0.000547	 0.006607	 0.01391	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92535	 92536	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92535	 92536	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92535	 93647	 0.002361	 0.012715	 0.00349	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92539	 92540	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92539	 92540	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92539	 92546	 0.005752	 0.022376	 0.00598	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92541	 93664	 0.06106	 0.12549	 0.00239	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92543	 93348	 0.055018	 0.14144	 0.00219	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92547	 92550	 0.018917	 0.086809	 0.02225	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92548	 92549	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92548	 92549	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92549	 93604	 0.001914	 0.01068	 0.00273	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92555	 93369	 0.017674	 0.041031	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92557	 93271	 0.081858	 0.46025	 0.00853	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92559	 93428	 0.045179	 0.16141	 0.0032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92561	 93413	 0.023788	 0.10394	 0.00273	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92563	 92564	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92563	 92564	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92563	 93538	 0.002332	 0.015135	 0.03015	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92565	 92566	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92565	 92566	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92567	 93368	 0.10498	 0.25045	 0.00561	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92568	 93562	 0.27839	 0.18029	 0.00343	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92569	 92570	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92569	 92570	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92569	 93692	 0.001669	 0.011264	 0.02074	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92569	 93696	 0.00365	 0.030071	 0.062	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92570	 92571	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92570	 92571	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92570	 92575	 0.02096	 0.15195	 0.08199	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92571	 93740	 0.41709	 0.33027	 0.00416	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92572	 93674	 0.079518	 0.1523	 0.0024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92574	 92575	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92574	 92575	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92574	 93696	 0.00321	 0.048044	 0.11253	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92576	 92577	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92576	 92577	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92578	 92579	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92578	 92579	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92580	 93709	 0.071728	 0.30814	 0.00564	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92581	 92582	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92581	 92582	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92583	 94707	 0.002987	 0.020011	 0.00613	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92584	 92585	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92584	 92585	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92585	 92586	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92585	 92586	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92586	 92712	 0.088353	 0.22715	 0.00352	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92587	 92588	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92587	 92588	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92587	 92606	 0.006717	 0.042573	 0.08924	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92587	 92621	 0.006305	 0.062943	 0.21072	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92588	 92589	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92588	 92589	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92588	 94806	 0.018062	 0.10081	 0.02576	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92589	 94816	 0.097222	 0.3119	 0.00772	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92589	 94818	 0.08304	 0.37017	 0.00629	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92590	 92591	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92590	 92591	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92590	 95007	 0.003611	 0.050488	 0.01712	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92593	 92594	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92593	 92594	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92594	 94332	 0.034945	 0.19246	 0.00434	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92595	 92596	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92595	 92596	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92596	 95286	 0.043325	 0.16669	 0.00285	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92596	 95286	 0.043325	 0.16669	 0.00285	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92597	 92598	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92597	 92598	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92598	 92599	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92598	 92599	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92598	 92612	 0.000176	 0.000938	 0.00022	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92600	 92601	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92600	 92601	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92602	 92603	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92602	 92603	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92603	 92604	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92603	 92604	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92604	 94287	 0.34788	 0.27542	 0.00347	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92605	 94917	 0.0031	 0.028527	 0.0543	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92606	 92607	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92606	 92607	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92607	 92608	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92607	 92608	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92607	 94290	 0.006487	 0.015634	 0.00441	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92609	 92610	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92609	 92610	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92611	 92612	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92611	 92612	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92611	 95309	 0.00485	 0.050332	 0.10854	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92612	 92613	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92612	 92613	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92614	 92615	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92614	 92615	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92616	 92624	 0.000163	 0.001053	 0.00028	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92618	 92619	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92618	 92619	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92618	 95255	 0.00485	 0.064552	 0.1382	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92619	 92620	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92619	 92620	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92621	 94877	 0.004601	 0.061233	 0.13107	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92622	 92623	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92622	 92623	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92623	 94503	 0.001145	 0.003929	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92625	 92626	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92625	 92626	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92627	 92628	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92627	 92628	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92630	 92631	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92630	 92631	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92630	 92729	 0.007775	 0.026673	 0.00639	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92632	 92633	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92632	 92633	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92633	 92634	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92633	 92634	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92634	 93951	 0.23126	 0.49601	 0.00869	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92634	 94997	 0.075357	 0.17497	 0.0026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92636	 92637	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92636	 92637	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92636	 94696	 0.013178	 0.083676	 0.17587	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92638	 92639	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92638	 92639	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92638	 94973	 0.016233	 0.068716	 0.01547	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92640	 92641	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92640	 92641	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92641	 92642	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92641	 92642	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92641	 92708	 0.001425	 0.003766	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92641	 94697	 0.001404	 0.006257	 0.0017	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92646	 94706	 0.15103	 0.16613	 0.00222	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92646	 94709	 0.036821	 0.15371	 0.00444	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92647	 92648	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92647	 92648	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92647	 94966	 0.006735	 0.050475	 0.01231	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92648	 94967	 0.22745	 0.22978	 0.00304	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92648	 95318	 0.057558	 0.354	 0.00638	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92649	 92650	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92649	 92650	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92650	 92651	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92650	 92651	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92650	 94007	 0.020145	 0.069118	 0.01656	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92652	 92653	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92652	 92653	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92654	 94672	 0.21758	 0.23243	 0.00492	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92655	 92745	 0.006789	 0.036088	 0.00837	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92655	 95156	 0.011593	 0.077696	 0.02381	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92657	 92658	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92657	 92658	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92658	 92659	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92658	 92659	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92658	 95156	 0.010653	 0.076648	 0.02032	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92660	 92661	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92660	 92661	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92660	 94435	 0.000281	 0.002756	 0.00945	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92663	 94862	 0.068022	 0.25156	 0.00466	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92665	 94277	 0.004077	 0.016831	 0.00398	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92666	 94785	 0.002257	 0.033181	 0.01015	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92667	 95160	 0.17995	 0.18178	 0.00241	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92668	 92669	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92668	 92669	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92668	 92773	 0.004293	 0.039298	 0.0757	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92670	 92671	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92670	 92671	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92670	 94317	 0.000763	 0.008567	 0.01568	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92671	 94321	 0.008297	 0.04301	 0.0105	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92673	 92674	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92673	 92674	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92673	 94918	 0.002585	 0.026133	 0.00768	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92675	 92676	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92675	 92676	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92675	 95221	 0.006647	 0.021679	 0.00576	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92677	 92765	 0.021181	 0.13023	 0.00235	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92678	 92679	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92678	 92679	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92679	 92680	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92679	 92680	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92679	 92752	 0.000114	 0.000662	 0.00016	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92681	 92682	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92681	 92682	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92683	 92684	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92683	 92684	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92683	 94921	 0.000361	 0.002409	 0.00454	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92686	 92687	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92686	 92687	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92688	 92689	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92688	 92689	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92690	 92691	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92690	 92691	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92690	 92806	 0.000191	 0.002544	 0.00543	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92692	 92693	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92692	 92693	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92692	 94341	 0.025393	 0.079397	 0.02301	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92693	 95251	 0.12783	 0.29685	 0.00442	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92694	 92695	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92694	 92695	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92694	 95006	 0.001606	 0.023986	 0.0071	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92696	 92697	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92696	 92697	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92698	 92699	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92698	 92699	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92698	 94500	 0.001036	 0.006722	 0.01339	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92699	 94428	 0.002595	 0.013036	 0.00339	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92699	 94460	 0.000746	 0.007902	 0.00235	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92699	 94495	 0.000293	 0.004228	 0.00134	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92700	 92771	 0.000767	 0.003016	 0.00079	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92701	 92702	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92701	 92702	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92703	 92704	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92703	 92704	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92703	 94781	 0.000807	 0.005709	 0.00157	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92704	 94777	 0.018798	 0.10686	 0.00193	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92704	 94783	 0.026722	 0.13518	 0.00235	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92705	 92706	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92705	 92706	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92706	 92707	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92706	 92707	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92706	 95007	 0.011119	 0.078665	 0.02159	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92709	 94198	 0.002792	 0.014543	 0.00381	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92709	 94202	 0.002258	 0.012599	 0.00322	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92710	 92711	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92710	 92711	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92710	 92803	 3.8e-05	 0.000357	 0.00011	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92713	 92714	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92713	 92714	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92714	 95329	 0.017736	 0.066533	 0.0012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92714	 95329	 0.017736	 0.066533	 0.0012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92716	 92717	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92716	 92717	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92716	 94721	 0.014936	 0.13857	 0.06956	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92718	 92719	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92718	 92719	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92719	 92720	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92719	 92720	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92719	 94004	 0.006061	 0.01787	 0.00416	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92721	 92722	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92721	 92722	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92723	 92724	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92723	 92724	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92725	 92726	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92725	 92726	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92727	 92728	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92727	 92728	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92729	 92730	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92729	 92730	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92731	 92772	 0.27809	 0.19705	 0.00311	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92732	 92733	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92732	 92733	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92732	 92736	 0.00844	 0.077367	 0.14934	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92733	 93933	 0.011497	 0.030867	 0.007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92734	 92735	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92734	 92735	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92735	 94290	 0.005175	 0.020338	 0.00532	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92736	 92737	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92736	 92737	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92737	 92838	 0.000434	 0.001736	 0.00044	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92738	 93935	 0.034166	 0.1369	 0.03453	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92739	 92740	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92739	 92740	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92742	 92743	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92742	 92743	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92746	 92747	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92746	 92747	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92748	 94973	 0.012191	 0.060234	 0.0176	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92749	 94732	 0.24547	 0.36823	 0.00669	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92749	 95167	 0.16869	 0.36166	 0.00634	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92751	 93891	 0.002307	 0.020133	 0.00553	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92753	 92754	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92753	 92754	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92754	 92755	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92754	 92755	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92758	 92759	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92758	 92759	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92759	 94717	 0.11615	 0.33324	 0.00513	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92760	 92761	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92760	 92761	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92763	 94749	 0.001285	 0.00433	 0.00108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92764	 93898	 0.04594	 0.13843	 0.04337	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	92764	 94308	 0.014221	 0.038181	 0.00865	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92769	 92770	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92769	 92770	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92769	 93899	 0.000595	 0.003771	 0.0079	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92770	 93901	 0.001594	 0.006748	 0.00152	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92771	 93893	 0.007041	 0.032301	 0.00828	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92771	 93898	 0.000613	 0.004638	 0.00228	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92773	 92774	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92773	 92774	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92773	 94919	 0.008103	 0.054726	 0.1009	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92774	 92775	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92774	 92775	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92779	 94363	 0.073636	 0.18931	 0.00293	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92783	 92784	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92783	 92784	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92783	 94426	 0.000712	 0.004908	 0.00866	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92784	 94429	 0.000841	 0.003305	 0.00086	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92786	 92787	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92786	 92787	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92787	 92788	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92787	 92788	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92789	 94224	 0.009472	 0.031598	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92790	 93951	 0.015081	 0.084863	 0.00183	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92791	 94359	 0.051689	 0.094676	 0.00163	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92794	 92795	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92794	 92795	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92796	 92797	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92796	 92797	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92798	 92799	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92798	 92799	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92805	 94907	 0.13373	 0.30732	 0.00467	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92806	 92807	 0.000699	 0.036327	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92806	 92807	 0.000699	 0.036327	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92806	 94500	 0.000262	 0.00205	 0.00352	 383.0	 402.2	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92807	 94503	 0.004646	 0.01826	 0.00478	 222.0	 222.0	 222.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92807	 94503	 0.004646	 0.01826	 0.00478	 222.0	 222.0	 222.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92807	 94503	 0.004646	 0.01826	 0.00478	 222.0	 222.0	 222.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92811	 92812	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92811	 92812	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92811	 94612	 0.002313	 0.015778	 0.02841	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92813	 94835	 0.014728	 0.078474	 0.00138	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92816	 94903	 0.025108	 0.077026	 0.00209	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92817	 92818	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92817	 92818	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92818	 93954	 0.30476	 0.4672	 0.00656	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92818	 94799	 0.026586	 0.14641	 0.0033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92819	 94945	 0.010531	 0.02913	 0.00068	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92820	 93887	 0.001156	 0.006888	 0.00181	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92823	 94905	 0.00138	 0.009204	 0.01735	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92824	 92825	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92824	 92825	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92826	 92827	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92826	 92827	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92827	 92828	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92827	 92828	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92829	 92830	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92829	 92830	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92829	 94653	 0.001603	 0.014024	 0.02557	 417.0	 437.8	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92833	 94969	 0.007558	 0.037975	 0.00988	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92837	 92838	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92837	 92838	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92838	 92839	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92838	 92839	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92842	 94921	 0.00014	 0.001105	 0.00384	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92843	 95280	 0.060076	 0.11171	 0.00261	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92846	 92847	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92846	 92848	 0.002141	 0.014748	 0.02603	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	92847	 92936	 0.02919	 0.075056	 0.01859	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92849	 92850	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92851	 92929	 0.2064	 0.59258	 0.00912	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	92855	 92856	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92856	 92965	 0.29264	 0.49335	 0.00703	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92858	 92860	 0.1318	 0.25835	 0.00387	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92861	 92862	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92866	 92867	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92870	 92871	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92873	 92874	 0.006938	 0.057043	 0.00111	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92876	 92994	 0.30883	 0.33654	 0.00458	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92881	 92929	 0.061033	 0.34707	 0.00628	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92883	 92884	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92886	 92975	 0.18194	 0.4226	 0.00805	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92887	 92943	 0.20121	 0.46743	 0.00696	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92891	 92946	 0.089649	 0.51001	 0.00924	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92895	 92896	 0.006364	 0.039493	 0.00957	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92900	 92915	 0.050674	 0.11765	 0.00175	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92907	 92928	 0.021101	 0.032924	 0.00055	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92909	 92925	 0.066989	 0.11285	 0.00161	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92915	 92916	 0.02772	 0.037819	 0.00068	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	92924	 92925	 0.014757	 0.037935	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92926	 92927	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92934	 92935	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92945	 92971	 0.056764	 0.25015	 0.00435	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	92948	 92949	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92952	 92953	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92953	 92965	 0.23099	 0.5944	 0.00921	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92953	 93036	 0.069675	 0.39625	 0.00717	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92956	 92957	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92959	 92972	 0.18284	 0.39202	 0.00687	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92961	 92962	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92961	 93040	 0.015648	 0.088638	 0.02198	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	92962	 93657	 0.039214	 0.18826	 0.00563	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92966	 92967	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92966	 93038	 0.019851	 0.077249	 0.02064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92970	 93027	 0.26327	 0.55395	 0.0101	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	92972	 92991	 0.13057	 0.44636	 0.00972	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92982	 92983	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92985	 92987	 0.008336	 0.013306	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	92990	 92991	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92991	 92992	 0.010393	 0.067957	 0.00157	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	92993	 92994	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92995	 92996	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92999	 93005	 0.027046	 0.10406	 0.00178	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93007	 93008	 0.00012	 0.009615	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93024	 93026	 0.073616	 0.096756	 0.00133	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93027	 93034	 0.40028	 0.72343	 0.01047	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93028	 93034	 0.14273	 0.55578	 0.00929	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93031	 93032	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93036	 93130	 0.067948	 0.36512	 0.00867	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93038	 93039	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93044	 93045	 0.008933	 0.021153	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93045	 93046	 0.006583	 0.011878	 0.00017	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93046	 93047	 0.012377	 0.016267	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93048	 93049	 0.011232	 0.028566	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93050	 93052	 0.012337	 0.025247	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93051	 93052	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93052	 93059	 0.026048	 0.062128	 0.00139	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93061	 93062	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93064	 93132	 0.16462	 0.45629	 0.00754	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93065	 93066	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93066	 93067	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93067	 93069	 0.033825	 0.13159	 0.0022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93067	 93069	 0.033825	 0.13159	 0.0022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93068	 93069	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93070	 93071	 0.19204	 0.20921	 0.00285	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93070	 93080	 0.08061	 0.17276	 0.00303	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93070	 93088	 0.077211	 0.17661	 0.00431	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93072	 93187	 0.048902	 0.21885	 0.00451	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93072	 93216	 0.21291	 0.5478	 0.00849	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93073	 93074	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93076	 93077	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93078	 93185	 0.049365	 0.30358	 0.00547	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93079	 93091	 0.17531	 0.35899	 0.00884	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93080	 93213	 0.15136	 0.35153	 0.00523	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93081	 93082	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93084	 93209	 0.059599	 0.50668	 0.01185	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93085	 93087	 0.03224	 0.085452	 0.00217	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93086	 93087	 0.10908	 0.20285	 0.00475	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93089	 93204	 0.07001	 0.24519	 0.00679	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93090	 93091	 0.010096	 0.025675	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93092	 93093	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93095	 93102	 0.009946	 0.028527	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93095	 93110	 0.027352	 0.070312	 0.00109	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93096	 93097	 0.014469	 0.02413	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93106	 93123	 0.019045	 0.063533	 0.00101	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93110	 93111	 0.018794	 0.024701	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93111	 93126	 0.008702	 0.028717	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93116	 93117	 0.027315	 0.078343	 0.0012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93120	 93121	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93123	 93125	 0.00954	 0.021404	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93130	 93131	 0.012442	 0.10351	 0.00196	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93130	 93192	 0.063486	 0.22218	 0.0046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93130	 93192	 0.063486	 0.22218	 0.0046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93137	 93138	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93138	 93189	 0.062369	 0.38361	 0.00692	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93142	 93143	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93149	 93168	 0.097781	 0.12852	 0.00176	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93151	 93153	 0.00581	 0.017824	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93153	 93191	 0.038405	 0.26368	 0.00481	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93154	 93155	 0.026928	 0.020402	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93159	 93163	 0.030031	 0.068995	 0.00105	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93173	 93174	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93174	 93215	 0.31678	 0.44185	 0.00756	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93176	 93177	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93178	 93211	 0.069347	 0.29357	 0.00554	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93179	 93180	 0.000247	 0.018554	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93179	 93181	 0.000371	 0.002604	 0.00443	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93182	 93183	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93185	 93188	 0.090181	 0.07069	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93186	 93187	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93191	 93192	 0.019148	 0.17828	 0.00345	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93191	 93207	 0.054686	 0.26259	 0.00785	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93193	 93199	 0.011363	 0.022498	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93194	 93195	 0.01325	 0.033698	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93221	 93222	 0.04314	 0.12374	 0.0019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93225	 93226	 0.00324	 0.016391	 0.00029	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93228	 93230	 0.02478	 0.18742	 0.00624	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93236	 93246	 0.11309	 0.50432	 0.00857	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93239	 93240	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93241	 93242	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93243	 93244	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93247	 93249	 0.055064	 0.33848	 0.00774	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93251	 93255	 0.064118	 0.38986	 0.0072	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93254	 93255	 0.069091	 0.46961	 0.01164	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93257	 93258	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93265	 93266	 0.02034	 0.040271	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93267	 93268	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93273	 93380	 0.058684	 0.36093	 0.00651	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93273	 93662	 0.20092	 0.53164	 0.00966	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93275	 93663	 0.058373	 0.2803	 0.00838	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93276	 93277	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93280	 93281	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93284	 93364	 0.34825	 0.45356	 0.00635	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93286	 93289	 0.002296	 0.037334	 0.01059	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93287	 93290	 0.002272	 0.015931	 0.02712	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93289	 93291	 0.00772	 0.049732	 0.01304	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93290	 93291	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93290	 94317	 0.003048	 0.021375	 0.0364	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93296	 93297	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93297	 93303	 0.076117	 0.1973	 0.00373	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93306	 93307	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93306	 93373	 0.003125	 0.033335	 0.06044	 473.0	 496.6	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93307	 93308	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93308	 93309	 0.077046	 0.25707	 0.00408	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93311	 93312	 0.051951	 0.15955	 0.00299	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93313	 93314	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93314	 93315	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93323	 93324	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93323	 93374	 0.058782	 0.17353	 0.04043	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93328	 93338	 0.016493	 0.032323	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93331	 93472	 0.007568	 0.036328	 0.00109	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93334	 93337	 0.013011	 0.028796	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93342	 93343	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93345	 93347	 0.052497	 0.040268	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93346	 93349	 0.013915	 0.079102	 0.00143	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93349	 93350	 0.012458	 0.064783	 0.0014	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93356	 93358	 0.071305	 0.28301	 0.00809	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93356	 93526	 0.025967	 0.11788	 0.00256	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93357	 93360	 0.05699	 0.30373	 0.00533	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93359	 93360	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93359	 93402	 0.01054	 0.13271	 0.04117	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93361	 93363	 0.087312	 0.13376	 0.00188	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93362	 93363	 0.12257	 0.24273	 0.00356	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93367	 93518	 0.10097	 0.1701	 0.00242	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93371	 93372	 0.002124	 0.02516	 0.01287	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93373	 93374	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93373	 93407	 0.007779	 0.054589	 0.09305	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93373	 93538	 0.012016	 0.081241	 0.15003	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93374	 93375	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93381	 93393	 0.27976	 0.55441	 0.00815	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93385	 93386	 0.091993	 0.30366	 0.00492	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93386	 93558	 0.20763	 0.3316	 0.00764	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93388	 93389	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93389	 93396	 0.20619	 0.47902	 0.00713	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93389	 93660	 0.15636	 0.5592	 0.01112	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93390	 93962	 0.051588	 0.31725	 0.00572	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93392	 93393	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93398	 93400	 0.12959	 0.53015	 0.01074	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93407	 93408	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93410	 93876	 0.0335	 0.1419	 0.03196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93414	 93415	 0.034375	 0.16784	 0.00352	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93416	 93417	 0.063865	 0.10469	 0.00185	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93422	 93423	 7e-05	 0.005589	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93422	 93424	 0.000813	 0.008876	 0.01721	 491.0	 515.5	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93422	 93649	 0.002204	 0.030009	 0.06109	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93422	 93652	 0.000928	 0.013885	 0.03248	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93424	 93425	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93424	 93538	 0.010581	 0.097615	 0.38894	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93425	 93426	 0.002384	 0.01654	 0.00472	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93431	 93654	 0.12683	 0.29452	 0.00438	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93432	 93510	 0.14162	 0.47273	 0.0075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93433	 93434	 0.035028	 0.16902	 0.00298	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93435	 93447	 0.005479	 0.01808	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93442	 93443	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93444	 93471	 0.010456	 0.02967	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93445	 93469	 0.016268	 0.051654	 0.00091	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93446	 93447	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93447	 93459	 0.019905	 0.054378	 0.00092	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93448	 93449	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93451	 93452	 0.003926	 0.020417	 0.00044	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93452	 93455	 0.015554	 0.030795	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93453	 93499	 0.004932	 0.024947	 0.00043	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93454	 93456	 0.005786	 0.014874	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93466	 93467	 0.018981	 0.018986	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93468	 93471	 0.004856	 0.012483	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93474	 93475	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93476	 93477	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93476	 93482	 0.000965	 0.006765	 0.01152	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93479	 93484	 0.069051	 0.069745	 0.00092	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93482	 93483	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93483	 93484	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93486	 93488	 0.002235	 0.015809	 0.00434	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93487	 93495	 0.003372	 0.013502	 0.0034	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93491	 93496	 0.028876	 0.048645	 0.00069	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93492	 93496	 0.011569	 0.026859	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93495	 93496	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93497	 93498	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93509	 93510	 0.019434	 0.06258	 0.00107	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93512	 93571	 0.012008	 0.015495	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93515	 93518	 0.11673	 0.19666	 0.0028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93520	 93521	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93523	 93524	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93532	 93533	 0.023438	 0.054407	 0.00104	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93535	 93539	 0.001761	 0.023982	 0.00857	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93537	 93556	 0.042051	 0.1636	 0.00273	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93538	 93539	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93539	 93540	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93548	 93658	 0.008779	 0.060921	 0.01739	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93552	 93553	 0.002281	 0.016655	 0.00428	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93553	 93554	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93558	 93559	 0.049103	 0.18422	 0.00331	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93568	 93569	 0.018004	 0.032977	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93568	 93581	 0.022625	 0.058161	 0.0009	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93570	 93572	 0.003845	 0.017133	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93573	 93575	 0.005007	 0.019477	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93579	 93580	 0.008634	 0.017095	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93583	 93585	 0.003789	 0.021287	 0.00039	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93583	 93589	 0.003796	 0.021328	 0.00039	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93586	 93588	 0.011571	 0.02686	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93587	 93588	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93587	 93599	 0.004159	 0.010798	 0.00262	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93591	 93633	 0.002496	 0.013743	 0.00031	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93593	 93631	 0.007591	 0.023313	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93598	 93599	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93599	 93600	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93602	 93604	 0.003354	 0.013426	 0.00338	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93603	 93604	 8.3e-05	 0.006605	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93603	 93616	 0.00125	 0.017523	 0.0336	 579.0	 608.0	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93604	 93605	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93606	 93636	 0.003006	 0.011693	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93607	 93608	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93612	 93613	 0.000247	 0.018554	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93614	 93625	 0.013095	 0.043685	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93616	 93617	 0.000167	 0.013359	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93617	 93618	 0.002504	 0.015396	 0.00028	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93624	 93627	 0.017181	 0.046936	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93626	 93629	 0.014595	 0.033532	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93632	 93645	 0.031738	 0.06495	 0.0016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93637	 93638	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93638	 93639	 0.006003	 0.027873	 0.00076	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93641	 93642	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93644	 93645	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93649	 93650	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93650	 93651	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93661	 93662	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93668	 93751	 0.12679	 0.29441	 0.00561	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93669	 93670	 0.018068	 0.099497	 0.00225	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93669	 93711	 0.35544	 0.56833	 0.01311	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93671	 93672	 0.019004	 0.063396	 0.001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93678	 93682	 0.13405	 0.35552	 0.00902	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93679	 93680	 0.012986	 0.027292	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93679	 93682	 0.007836	 0.053787	 0.00098	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93680	 93681	 0.026416	 0.032791	 0.00071	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93690	 93700	 0.18948	 0.48741	 0.00755	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93692	 93693	 0.000469	 0.003182	 0.00579	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93693	 93694	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93694	 93695	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93694	 93697	 0.016781	 0.067199	 0.01693	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93696	 93697	 8.5e-05	 0.006812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93697	 93698	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93699	 93743	 0.12975	 0.33363	 0.00517	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93699	 93744	 0.070936	 0.29462	 0.00767	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93704	 93718	 0.027498	 0.050365	 0.00087	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93706	 93716	 0.35569	 0.42616	 0.0071	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93708	 93709	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93708	 93710	 0.034748	 0.15959	 0.04095	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93711	 93736	 0.097788	 0.38058	 0.00636	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93712	 93726	 0.017796	 0.041315	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93713	 93725	 0.040277	 0.093509	 0.00139	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93714	 93724	 0.18349	 0.13502	 0.00197	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93716	 93718	 0.048714	 0.038552	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93718	 93719	 0.02237	 0.015846	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93718	 93720	 0.0344	 0.027224	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93719	 93720	 0.022153	 0.024129	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93719	 93726	 0.027832	 0.020477	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93721	 93724	 0.10644	 0.20862	 0.00313	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93722	 93725	 0.11063	 0.21907	 0.00322	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93728	 93729	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93731	 93732	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93731	 93733	 0.002361	 0.013	 0.00469	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93731	 93737	 0.020586	 0.16174	 0.07414	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93737	 93738	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93743	 93744	 0.11646	 0.19348	 0.0041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93750	 93751	 0.00992	 0.041409	 0.00119	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93755	 93756	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93755	 94191	 0.007735	 0.052517	 0.09573	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93760	 93761	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93760	 94977	 0.003632	 0.038208	 0.02147	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93765	 93766	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93767	 95257	 0.078742	 0.20244	 0.00313	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93770	 94253	 0.61605	 0.48817	 0.00615	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93773	 93774	 0.037193	 0.0507	 0.00112	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93774	 93775	 0.032082	 0.042166	 0.00058	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93784	 93785	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93785	 93786	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93787	 93788	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93791	 93858	 0.005112	 0.024943	 0.00043	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93793	 93794	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93794	 93847	 0.015461	 0.095058	 0.00171	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93799	 93800	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93800	 93808	 0.004005	 0.01558	 0.00416	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93803	 93815	 0.00547	 0.031093	 0.00056	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93806	 93809	 0.003475	 0.01975	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93807	 93808	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93808	 93809	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93811	 93812	 0.00058	 0.003981	 0.00116	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93814	 93815	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93836	 93838	 0.010564	 0.041097	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93838	 93839	 0.006543	 0.015191	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93840	 93841	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93848	 93849	 0.01078	 0.021342	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93853	 93854	 0.031932	 0.02503	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93856	 93857	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93864	 93865	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93865	 93866	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93868	 93869	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93874	 93875	 0.003685	 0.032152	 0.00883	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93881	 93883	 0.12377	 0.097955	 0.00123	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93882	 93885	 0.048314	 0.13858	 0.00213	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93883	 94297	 0.21409	 0.13863	 0.00264	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93884	 94261	 0.066973	 0.24768	 0.00459	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93887	 93888	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93889	 93890	 0.029386	 0.16513	 0.00306	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93894	 93895	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93894	 93897	 0.003544	 0.009367	 0.00219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93897	 93898	 0.001706	 0.006831	 0.00172	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93899	 93900	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93899	 93900	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93903	 93904	 0.012547	 0.032576	 0.00791	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	93912	 93914	 0.067533	 0.053445	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93913	 93914	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93913	 94341	 0.0116	 0.074266	 0.025	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93915	 93916	 0.032107	 0.020786	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93918	 93919	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93918	 93922	 0.006575	 0.045137	 0.01317	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93920	 93921	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93920	 94954	 0.012507	 0.09943	 0.34807	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93921	 93926	 0.002842	 0.010801	 0.00302	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93922	 93923	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93922	 93924	 0.002475	 0.010475	 0.00236	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	93924	 93925	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93925	 94012	 0.089428	 0.43663	 0.00754	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93928	 93929	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93930	 93931	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93932	 93933	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93934	 93935	 0.005314	 0.053723	 0.0158	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93938	 93939	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93955	 93956	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93955	 94812	 0.002829	 0.02716	 0.0079	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93956	 94813	 0.046221	 0.1579	 0.00343	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93956	 94813	 0.046221	 0.1579	 0.00343	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	93957	 94435	 0.00115	 0.007672	 0.01446	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	93967	 93974	 0.067997	 0.14572	 0.00255	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93969	 93972	 0.073622	 0.17094	 0.00254	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	93971	 94177	 0.004556	 0.021152	 0.00058	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93976	 93977	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93977	 93978	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93977	 93979	 0.001234	 0.010768	 0.00296	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	93977	 93981	 0.001567	 0.015044	 0.00438	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93978	 94139	 0.0249	 0.099815	 0.00257	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93979	 93980	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93981	 93982	 0.002094	 0.007581	 0.00163	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	93982	 93983	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	93982	 94000	 0.002231	 0.011887	 0.00334	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	93983	 94139	 0.032612	 0.093537	 0.00144	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93984	 93985	 0.001289	 0.012596	 0.00353	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	93985	 93986	 0.001721	 0.007895	 0.00202	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	93988	 93989	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94000	 94001	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94001	 94139	 0.049919	 0.072741	 0.00164	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94004	 94005	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94006	 94010	 0.050681	 0.084524	 0.00123	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94007	 94008	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94008	 94349	 0.029637	 0.091017	 0.00171	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94009	 94010	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94011	 94189	 0.55013	 0.43167	 0.00554	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94018	 94028	 0.006292	 0.017427	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94021	 94022	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94027	 94030	 0.017627	 0.012969	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94029	 94032	 0.014414	 0.011407	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94041	 94147	 0.029219	 0.047635	 0.00073	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94050	 94051	 0.002208	 0.013418	 0.00025	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94051	 94073	 0.020957	 0.069911	 0.00111	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94052	 94055	 0.018654	 0.036933	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94054	 94085	 0.008605	 0.02468	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94059	 94060	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94061	 94062	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94062	 94063	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94064	 94065	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94064	 94152	 0.006389	 0.023136	 0.00496	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94070	 94149	 0.009283	 0.030966	 0.00049	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94071	 94072	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94072	 94073	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94074	 94075	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94074	 94114	 0.001529	 0.010811	 0.00297	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94086	 94087	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94093	 94094	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94097	 94099	 0.021781	 0.07266	 0.00115	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94098	 94099	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94100	 94102	 0.060963	 0.048246	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94111	 94116	 0.009962	 0.028573	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94114	 94115	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94118	 94126	 0.004922	 0.019148	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94123	 94125	 0.002344	 0.013326	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94135	 94136	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94135	 94137	 0.000372	 0.004092	 0.00243	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94137	 94138	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94141	 94143	 0.0343	 0.037726	 0.0005	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94142	 94143	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94143	 94146	 0.006252	 0.022334	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94152	 94153	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94160	 94166	 0.25747	 0.23723	 0.0038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94163	 94164	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94168	 94169	 0.021327	 0.023457	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94170	 94178	 0.026001	 0.11587	 0.00197	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94175	 94176	 0.006397	 0.016911	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94185	 94186	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94188	 94189	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94191	 94192	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94191	 94195	 0.001173	 0.008084	 0.01427	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94192	 94193	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94193	 95317	 0.2759	 0.4534	 0.0128	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94193	 95317	 0.2759	 0.4534	 0.0128	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94195	 94196	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94199	 95258	 0.037511	 0.10465	 0.02198	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94200	 95258	 0.040737	 0.10772	 0.02523	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94202	 94203	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94204	 94210	 0.039514	 0.10049	 0.00159	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94209	 94211	 0.070533	 0.16704	 0.00305	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94214	 94217	 0.008692	 0.03105	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94214	 94217	 0.008692	 0.03105	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94215	 94217	 0.002428	 0.009446	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94215	 94217	 0.002428	 0.009446	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94216	 94217	 0.004627	 0.033822	 0.00062	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94216	 94218	 0.00972	 0.037813	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94216	 94218	 0.00972	 0.037813	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94222	 94223	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94225	 94226	 0.000136	 0.010869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94229	 94230	 0.002806	 0.013701	 0.00029	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94230	 94241	 0.011818	 0.045974	 0.00077	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94235	 94242	 0.010002	 0.08495	 0.00198	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94240	 94241	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94241	 94244	 0.017773	 0.065714	 0.00122	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94241	 94244	 0.017773	 0.065714	 0.00122	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94242	 94244	 0.038806	 0.14349	 0.00266	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94242	 94244	 0.038806	 0.14349	 0.00266	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94246	 94247	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94246	 94248	 0.003533	 0.012793	 0.00274	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94249	 94251	 0.10215	 0.080839	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94250	 94251	 0.077897	 0.11933	 0.00168	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94260	 94261	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94263	 94273	 0.000318	 0.00449	 0.00149	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94273	 94274	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94273	 94275	 0.00481	 0.012711	 0.00298	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94275	 94276	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94277	 94278	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94279	 94280	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94280	 94282	 0.025632	 0.056731	 0.00093	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94281	 94283	 0.016112	 0.017206	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94284	 94285	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94289	 95325	 0.006868	 0.070655	 0.02004	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94290	 94291	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94296	 94298	 0.083875	 0.054302	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94300	 94489	 0.071422	 0.052548	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94301	 94494	 0.083399	 0.084238	 0.00112	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94307	 94314	 0.000274	 0.002134	 0.00765	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94308	 94309	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94308	 94312	 0.00743	 0.020229	 0.00446	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94312	 94313	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94316	 94725	 0.1339	 0.34433	 0.00533	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94324	 94325	 0.016359	 0.054571	 0.00086	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94326	 94327	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94330	 94331	 0.032169	 0.063693	 0.00093	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94332	 94336	 0.1434	 0.14485	 0.00192	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94333	 94334	 0.001055	 0.007586	 0.00201	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94334	 94335	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94338	 94339	 8.3e-05	 0.006605	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94338	 95321	 0.010047	 0.068625	 0.12382	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94339	 94340	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94353	 94354	 0.004638	 0.026062	 0.00048	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94361	 94814	 0.03066	 0.16886	 0.00381	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94364	 94365	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94366	 94376	 0.008296	 0.032272	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94367	 94369	 0.009747	 0.01642	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94371	 94372	 0.005449	 0.012518	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94373	 94374	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94374	 94375	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94377	 94380	 0.009031	 0.04595	 0.00104	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94382	 94386	 0.010271	 0.030915	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94384	 94385	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94385	 94386	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94389	 94390	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94392	 94393	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94396	 94397	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94396	 94425	 0.002927	 0.011716	 0.00295	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94399	 94400	 0.005512	 0.022528	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94403	 94405	 0.003445	 0.010158	 0.00236	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94403	 94468	 0.001633	 0.008793	 0.00242	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94405	 94406	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94407	 94411	 0.004533	 0.016193	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94408	 94409	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94409	 94410	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94412	 94413	 0.003853	 0.020693	 0.00049	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94416	 94418	 0.012214	 0.031654	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94420	 94892	 0.039677	 0.054132	 0.00097	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94422	 94809	 0.0191	 0.11743	 0.00212	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94423	 94424	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94423	 94895	 0.012763	 0.10952	 0.03119	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94425	 94429	 0.004386	 0.012231	 0.00257	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94426	 94427	 0.000318	 0.022264	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94433	 94434	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94433	 94436	 0.001646	 0.005492	 0.00139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94433	 94438	 0.001786	 0.005377	 0.00168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94435	 94436	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94436	 94437	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94438	 94439	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94438	 94440	 0.001206	 0.008369	 0.00239	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94440	 94441	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94447	 94448	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94448	 94449	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94455	 94476	 0.018119	 0.051966	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94458	 94463	 0.016397	 0.025119	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94461	 94463	 0.003263	 0.015921	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94462	 94463	 0.00152	 0.009238	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94466	 94467	 0.019478	 0.038173	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94474	 94475	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94475	 94476	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94477	 94478	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94482	 94483	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94484	 94485	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94485	 94487	 0.031342	 0.062055	 0.00091	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94488	 94491	 0.007356	 0.021097	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94489	 94491	 0.017809	 0.023176	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94490	 94493	 0.005434	 0.030578	 0.00066	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94492	 94493	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94495	 94496	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94495	 94497	 0.001987	 0.007808	 0.00204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94500	 94501	 0.000472	 0.003222	 0.0058	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94502	 94503	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 0.95	 1.0	 1	 -30.0	 30.0;
	94503	 94504	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94509	 94510	 0.00763	 0.013975	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94522	 94523	 0.007026	 0.013911	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94522	 94539	 0.059319	 0.046945	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94527	 94544	 0.004608	 0.022483	 0.00039	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94529	 94530	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94530	 94531	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94535	 94536	 0.002122	 0.012561	 0.00024	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94546	 94554	 0.003163	 0.015818	 0.00028	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94547	 94548	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94557	 94558	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94564	 94565	 0.008993	 0.02066	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94564	 94567	 0.015526	 0.027906	 0.0005	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94566	 94567	 0.004338	 0.022268	 0.00042	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94569	 94583	 0.007791	 0.02985	 0.00084	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94571	 94575	 0.008989	 0.025508	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94573	 94574	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94573	 94596	 0.001515	 0.012991	 0.0037	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94578	 94579	 0.00859	 0.028656	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94581	 94582	 0.013994	 0.019865	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94587	 94588	 0.013286	 0.021778	 0.00038	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94589	 94591	 0.003287	 0.016022	 0.0003	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94590	 94591	 0.013475	 0.014821	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94592	 94622	 0.003783	 0.016756	 0.00038	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94593	 94622	 0.004269	 0.013556	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94596	 94597	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94598	 94599	 0.03881	 0.030713	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94603	 94607	 0.1373	 0.10866	 0.00137	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94606	 94607	 0.021399	 0.042369	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94609	 94610	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94610	 94611	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94610	 95256	 0.002905	 0.040965	 0.01401	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94611	 94636	 0.042465	 0.16338	 0.00279	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94611	 94644	 0.025758	 0.082601	 0.00204	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94611	 95254	 0.076594	 0.17598	 0.00267	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94612	 94613	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94613	 94614	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94615	 94616	 0.005983	 0.014645	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94623	 94624	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94632	 94633	 0.011237	 0.031886	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94637	 94638	 0.00675	 0.019359	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94642	 94888	 0.002693	 0.020182	 0.00492	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94647	 94648	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94654	 94655	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94656	 94795	 0.35429	 0.61124	 0.00974	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94662	 94663	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94663	 94665	 0.16968	 0.12485	 0.00183	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94670	 94671	 0.093555	 0.094496	 0.00125	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94674	 94675	 0.004804	 0.023444	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94676	 94679	 0.090425	 0.071562	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94681	 94683	 0.018225	 0.036085	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94682	 94683	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94696	 94697	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94702	 94703	 0.13498	 0.23743	 0.00446	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94711	 94713	 0.001586	 0.027117	 0.0147	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94715	 94716	 0.041241	 0.25068	 0.00463	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94717	 94719	 0.014674	 0.041642	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94721	 94722	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94721	 95002	 0.007067	 0.071444	 0.02101	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94725	 94727	 0.024504	 0.10919	 0.00185	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94726	 94728	 0.0105	 0.024378	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94727	 94728	 0.01	 0.023217	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94729	 94730	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94730	 94731	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94732	 95163	 0.34651	 0.54129	 0.00905	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94734	 95245	 0.11071	 0.43094	 0.0072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94735	 95275	 0.22014	 0.43611	 0.0064	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94737	 94738	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94738	 94739	 0.047405	 0.09386	 0.00138	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94741	 94744	 0.019803	 0.015523	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94746	 94766	 0.020356	 0.090707	 0.00154	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94752	 94753	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94755	 94756	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94755	 94762	 0.00104	 0.006587	 0.01379	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	94755	 94771	 0.002119	 0.017661	 0.0551	 635.0	 666.8	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94764	 94765	 9.7e-05	 0.007785	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94765	 94766	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94766	 94767	 0.012792	 0.064707	 0.00113	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94769	 94770	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94769	 94811	 0.002995	 0.046747	 0.10055	 647.0	 679.3	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94772	 94773	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94776	 94782	 0.023306	 0.13249	 0.0024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94779	 94780	 0.00383	 0.014559	 0.00408	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94785	 95150	 0.003346	 0.042093	 0.01304	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94788	 94789	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94793	 94794	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94795	 94796	 0.13041	 0.25564	 0.00383	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94802	 95265	 0.49648	 0.64711	 0.00906	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94807	 94808	 0.031087	 0.19114	 0.00345	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94811	 94812	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94814	 94815	 0.032697	 0.14571	 0.00247	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94832	 94833	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94833	 94838	 0.040586	 0.1579	 0.00264	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94833	 94838	 0.040586	 0.1579	 0.00264	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94837	 94838	 0.015322	 0.059606	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94841	 94843	 0.061727	 0.080332	 0.00112	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94842	 94843	 0.04952	 0.059281	 0.00099	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94844	 94845	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94846	 94851	 0.033978	 0.066592	 0.001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94850	 94851	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94854	 94855	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94858	 94859	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94865	 94869	 0.30369	 0.24041	 0.00303	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94870	 94871	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94877	 94878	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94878	 94879	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94879	 94890	 0.018589	 0.081442	 0.00175	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94881	 94883	 0.033914	 0.026584	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94882	 94884	 0.00403	 0.018685	 0.00039	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94883	 94885	 0.004753	 0.019053	 0.00049	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	94886	 94887	 0.028259	 0.022363	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94888	 94889	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94894	 94896	 0.096473	 0.18235	 0.00295	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94895	 94896	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94897	 94898	 0.035465	 0.070217	 0.00103	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94901	 94902	 0.002991	 0.019555	 0.00497	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94902	 94903	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94905	 94906	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94912	 94913	 0.023376	 0.103	 0.00179	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94917	 94918	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94919	 94920	 8.3e-05	 0.006605	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94921	 94922	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94924	 94929	 0.005216	 0.022402	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	94925	 94927	 0.012432	 0.011567	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94932	 94933	 0.013153	 0.02015	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94937	 94938	 0.00429	 0.026373	 0.00048	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94944	 94945	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94952	 94953	 0.010063	 0.079308	 0.02321	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94954	 94955	 7e-05	 0.005589	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94955	 94968	 0.004709	 0.033872	 0.00898	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94958	 94959	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94963	 94965	 0.058298	 0.076621	 0.00105	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	94969	 94970	 0.002384	 0.02244	 0.0068	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	94970	 95031	 0.010677	 0.042748	 0.01077	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94970	 95074	 0.002646	 0.018714	 0.00514	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94971	 94972	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	94979	 94981	 0.0117	 0.018769	 0.00035	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94986	 94987	 0.009717	 0.012062	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	94986	 94995	 0.12201	 0.31374	 0.00486	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	94990	 94991	 0.008897	 0.017615	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94992	 94994	 0.052552	 0.12201	 0.00181	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	94993	 94997	 0.020732	 0.099521	 0.00297	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94996	 94997	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95001	 95002	 0.001473	 0.022921	 0.00711	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95006	 95007	 0.005137	 0.036332	 0.00997	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95007	 95008	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95007	 95009	 0.005373	 0.037277	 0.01064	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95013	 95014	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95019	 95020	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95021	 95328	 0.023815	 0.141	 0.00274	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95027	 95028	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95029	 95030	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95029	 95035	 0.000482	 0.00449	 0.00139	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95031	 95032	 0.000136	 0.010869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95032	 95132	 0.017042	 0.090806	 0.00159	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	95033	 95034	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95044	 95147	 0.017025	 0.027755	 0.00042	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	95045	 95058	 0.013173	 0.044997	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95046	 95047	 0.006266	 0.018858	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95046	 95059	 0.032556	 0.025519	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95049	 95050	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95051	 95127	 0.055995	 0.085781	 0.0012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95055	 95079	 0.008431	 0.047928	 0.00087	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	95057	 95058	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95058	 95082	 0.028871	 0.11107	 0.0019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95062	 95063	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95062	 95097	 0.000819	 0.00519	 0.01087	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	95063	 95064	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95064	 95116	 0.018116	 0.035868	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95066	 95067	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95067	 95120	 0.011789	 0.052532	 0.00089	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95068	 95069	 0.013123	 0.025982	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95075	 95078	 0.059564	 0.040011	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95090	 95140	 0.12076	 0.094665	 0.00122	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95092	 95140	 0.03892	 0.047446	 0.00076	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	95093	 95143	 0.023182	 0.018346	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95094	 95095	 0.021615	 0.021832	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95097	 95098	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95098	 95099	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95100	 95101	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95101	 95102	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95103	 95137	 0.031411	 0.02311	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95105	 95107	 0.019646	 0.015548	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95113	 95116	 0.004841	 0.01231	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95118	 95119	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95122	 95129	 0.008497	 0.038022	 0.00078	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	95128	 95130	 0.10842	 0.084988	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95133	 95134	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95139	 95140	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95140	 95144	 0.007755	 0.020097	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95150	 95151	 0.000957	 0.006987	 0.0018	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95151	 95152	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95155	 95159	 0.004556	 0.015951	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95156	 95157	 9.5e-05	 0.007575	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95163	 95169	 0.007608	 0.039051	 0.00074	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	95164	 95169	 0.079783	 0.051653	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95174	 95178	 0.013711	 0.01085	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95179	 95180	 0.005613	 0.011114	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95180	 95223	 0.064557	 0.046668	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95186	 95191	 0.00175	 0.013635	 0.00025	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95187	 95209	 0.086874	 0.095553	 0.00128	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95191	 95294	 0.004819	 0.026538	 0.0006	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95196	 95198	 0.061027	 0.040994	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95197	 95208	 0.064068	 0.049145	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95200	 95201	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95203	 95300	 0.17656	 0.19423	 0.00259	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95212	 95213	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95218	 95221	 0.000893	 0.010207	 0.00311	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95220	 95221	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95222	 95227	 0.025095	 0.043808	 0.00068	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	95226	 95227	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95230	 95232	 0.034754	 0.14205	 0.00287	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95233	 95234	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95236	 95237	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95236	 95238	 0.012933	 0.034182	 0.008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	95238	 95239	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95253	 95254	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95255	 95256	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95259	 95260	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95262	 95263	 0.002116	 0.013009	 0.00023	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95266	 95267	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95269	 95270	 0.006065	 0.012008	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95281	 95282	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95283	 95284	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95289	 95303	 0.000558	 0.005313	 0.00944	 435.0	 456.8	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95289	 95309	 0.000865	 0.010041	 0.03569	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	95295	 95296	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95295	 95309	 0.000733	 0.007205	 0.02471	 731.0	 767.5	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95303	 95304	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95303	 95305	 0.000288	 0.00367	 0.00694	 541.0	 568.1	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95305	 95306	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95309	 95310	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95310	 95311	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95310	 95313	 0.013014	 0.062038	 0.01798	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	95321	 95322	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95322	 95323	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95323	 95327	 0.069312	 0.30376	 0.00653	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	95325	 95326	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	95327	 95328	 0.031377	 0.19293	 0.00348	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Gen Active Cost Model:       stat
% INFO    : Setting Flat Start
% WARNING : Unrecognized data matrix named mpc.dcline: data was ignored
% INFO    : 
% INFO    : === Generator Classification Notes ===
% INFO    : PEL    1423 -     5.58
% INFO    : NUC    25  -     3.39
% INFO    : COW    1025 -    38.77
% INFO    : NG     4400 -    52.26
% INFO    : 
% INFO    : === Generator Active Cost Stat Model Notes ===
% INFO    : Updated Generator Cost: NUC - 0.0 0.0 0.0 -> 0 8.11250775245 0
% INFO    : Updated Generator Cost: NUC - 0.0 0.0 0.0 -> 0 5.24292404438 0
% INFO    : Updated Generator Cost: NG - 3775.4 71.579 0.015 -> 0 63.1811851398 0
% INFO    : Updated Generator Cost: NG - 598.64 13.119 0.004 -> 0 27.006173727 0
% INFO    : Updated Generator Cost: NG - 1586.4 77.147 0.046 -> 0 24.4360148262 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 22.2020868572 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 28.9129133133 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 23.7556490739 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 35.1931443789 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 28.7473949286 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 19.8956800813 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 35.6745956688 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 27.1509334359 0
% INFO    : Updated Generator Cost: NG - 638.61 21.819 0.009 -> 0 37.2520598927 0
% INFO    : Updated Generator Cost: COW - 339.67 23.532 0.02 -> 0 30.8981009051 0
% INFO    : Updated Generator Cost: NG - 3497.17 71.3 0.017 -> 0 26.6339846903 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 55.3654980906 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 29.5583758916 0
% INFO    : Updated Generator Cost: NG - 3497.17 71.3 0.017 -> 0 31.4400076414 0
% INFO    : Updated Generator Cost: NG - 794.13 83.969 0.108 -> 0 25.8591798016 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 79.47653283 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 41.7294427931 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 25.0565841933 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 25.3511321288 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 44.1308851438 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 33.9745369773 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 34.7449257009 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 100.595917896 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 60.2885660961 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 38.8546617909 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 32.3069111925 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.2034501702 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 37.0398677738 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 112.341859694 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 37.6575802971 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 116.060551544 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 46.8546728114 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.9002972349 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 43.260136207 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 19.6548892505 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 41.361885512 0
% INFO    : Updated Generator Cost: NG - 102.96 15.563 0.048 -> 0 55.8205773618 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 56.008068827 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 17.2849936244 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 103.319093615 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 22.4621496812 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 53.6647283594 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 119.294432493 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 39.0711645081 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 119.106070561 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 39.7415229025 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 115.537987262 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 40.2171780733 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 114.117382208 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 125.030499688 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 33.4974851046 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 119.311110386 0
% INFO    : Updated Generator Cost: COW - 1755.23 50.578 0.008 -> 0 29.6056646531 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 27.0757031014 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 112.561403273 0
% INFO    : Updated Generator Cost: COW - 4845.09 72.389 0.009 -> 0 25.6026558278 0
% INFO    : Updated Generator Cost: COW - 4856.2 72.363 0.009 -> 0 23.7485142991 0
% INFO    : Updated Generator Cost: COW - 426.81 13.382 0.013 -> 0 20.1783369064 0
% INFO    : Updated Generator Cost: PEL - 590.89 26.977 0.015 -> 0 108.38249957 0
% INFO    : Updated Generator Cost: NG - 590.89 26.977 0.015 -> 0 40.5112768481 0
% INFO    : Updated Generator Cost: NG - 590.89 26.977 0.015 -> 0 38.4795304656 0
% INFO    : Updated Generator Cost: PEL - 426.81 13.382 0.013 -> 0 113.845104482 0
% INFO    : Updated Generator Cost: NG - 426.81 13.382 0.013 -> 0 26.9800910121 0
% INFO    : Updated Generator Cost: NG - 426.81 13.382 0.013 -> 0 29.2058686771 0
% INFO    : Updated Generator Cost: NG - 426.81 13.382 0.013 -> 0 38.9700791291 0
% INFO    : Updated Generator Cost: NG - 426.81 13.382 0.013 -> 0 24.1527018694 0
% INFO    : Updated Generator Cost: NG - 590.89 26.977 0.015 -> 0 40.9522169649 0
% INFO    : Updated Generator Cost: NG - 590.89 26.977 0.015 -> 0 44.6171798141 0
% INFO    : Updated Generator Cost: NG - 590.89 26.977 0.015 -> 0 41.726221175 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 26.6297092573 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 49.6396510182 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 17.7557042772 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 34.996530902 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 39.6688196952 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 35.7182246214 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 21.9630429124 0
% INFO    : Updated Generator Cost: NG - 5131.3 71.986 0.009 -> 0 26.3853710149 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 42.765098258 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 41.9926026324 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 40.8288279999 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 18.6847123731 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 32.9269098599 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 38.1181360464 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 40.9449185337 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 22.9487320958 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 28.9991709291 0
% INFO    : Updated Generator Cost: COW - 1755.23 50.578 0.008 -> 0 28.2160720282 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 34.6375111029 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 121.724100544 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 28.4575528934 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 24.2674916218 0
% INFO    : Updated Generator Cost: PEL - 993.75 11.398 0.026 -> 0 101.18215019 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 117.040995106 0
% INFO    : Updated Generator Cost: COW - 3885.7 71.657 0.014 -> 0 21.6542088797 0
% INFO    : Updated Generator Cost: NG - 413.33 13.709 0.006 -> 0 31.824075807 0
% INFO    : Updated Generator Cost: NG - 413.33 13.709 0.006 -> 0 36.630984801 0
% INFO    : Updated Generator Cost: COW - 995.46 13.162 0.002 -> 0 32.3971947884 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 31.7758325947 0
% INFO    : Updated Generator Cost: COW - 303.56 14.879 0.009 -> 0 25.1993138948 0
% INFO    : Updated Generator Cost: COW - 303.56 14.879 0.009 -> 0 33.1878350107 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 40.52498698 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 48.2484545963 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 18.8698345506 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 47.2525378624 0
% INFO    : Updated Generator Cost: COW - 250.53 14.524 0.01 -> 0 28.154468336 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 7.89002320462 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 43.8133657312 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 20.8319190485 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 119.025238176 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 45.1217770756 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 119.777474488 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.0298770106 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 32.5989775548 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.4384037159 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 25.4965795981 0
% INFO    : Updated Generator Cost: NG - 341.87 23.529 0.02 -> 0 46.0014792054 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 108.89821372 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 40.9012429072 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 34.3203600265 0
% INFO    : Updated Generator Cost: COW - 51.34 14.879 0.053 -> 0 14.4471916351 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 51.2666024613 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 51.2311499024 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 99.8108443258 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 110.151972655 0
% INFO    : Updated Generator Cost: COW - 1952.1 59.305 0.01 -> 0 18.012783638 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 116.690016314 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 131.824409219 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 31.0186453103 0
% INFO    : Updated Generator Cost: COW - 51.34 14.879 0.053 -> 0 23.4291360082 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 26.9476030355 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 49.0258176262 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 46.1134935768 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 33.9416666602 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 40.2083618953 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 18.3690381689 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.2840537873 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.7323666605 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 45.9570308835 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 37.7057400435 0
% INFO    : Updated Generator Cost: NG - 136.48 25.306 0.083 -> 0 25.7469675162 0
% INFO    : Updated Generator Cost: NG - 136.48 25.306 0.083 -> 0 21.7333837739 0
% INFO    : Updated Generator Cost: NG - 136.48 25.306 0.083 -> 0 50.7552735127 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 109.925360531 0
% INFO    : Updated Generator Cost: COW - 1755.23 50.578 0.008 -> 0 33.2470644377 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 116.886623091 0
% INFO    : Updated Generator Cost: NG - 76.57 25.495 0.117 -> 0 46.7525739983 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 126.495268172 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 19.1717018914 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 41.8775167679 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 126.703823829 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 39.969024397 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 31.6015552995 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 18.2663268095 0
% INFO    : Updated Generator Cost: NG - 76.57 25.495 0.117 -> 0 30.0189967993 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 98.0201991081 0
% INFO    : Updated Generator Cost: NG - 426.81 13.382 0.013 -> 0 35.6925444857 0
% INFO    : Updated Generator Cost: NG - 45.76 14.879 0.06 -> 0 29.7388329198 0
% INFO    : Updated Generator Cost: NG - 318.09 87.0 0.288 -> 0 32.4849180388 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 33.6375387573 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 99.1528027174 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 104.038461622 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 24.5061724497 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 25.5749982616 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 29.9951861168 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 32.8957527002 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 44.5529403316 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 30.4335218734 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 28.6448551305 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 29.00211608 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 47.9416076541 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 92.4938484631 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 46.8592780413 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 45.3259138163 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 48.1267843662 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 93.8539563835 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 129.681652658 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 39.1663218554 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 43.5217775425 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 114.971151657 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 23.4314656879 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 24.0141030683 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 98.0465069982 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 42.7418640407 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 40.916963967 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 19.0611732531 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 12.598149355 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 16.48431545 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 30.2455406176 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 120.478755141 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 112.024008367 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 35.0555776926 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 45.926221308 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 30.1840190892 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 43.6352908589 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 22.7437893001 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 14.8036748853 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 38.9950332487 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 34.9645417226 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 28.7677727008 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 30.2282799637 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 34.7615827817 0
% INFO    : Updated Generator Cost: COW - 417.14 32.407 0.031 -> 0 39.3713766183 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 111.56661099 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 42.9185084573 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 35.1186483155 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 25.2089320484 0
% INFO    : Updated Generator Cost: COW - 5268.3 71.682 0.009 -> 0 29.4493592034 0
% INFO    : Updated Generator Cost: NG - 1142.8 80.179 0.068 -> 0 19.3873685598 0
% INFO    : Updated Generator Cost: PEL - 567.01 86.715 0.161 -> 0 105.288590328 0
% INFO    : Updated Generator Cost: NG - 567.01 86.715 0.161 -> 0 41.5986866991 0
% INFO    : Updated Generator Cost: NG - 217.63 34.988 0.068 -> 0 38.9532314017 0
% INFO    : Updated Generator Cost: NG - 295.65 34.128 0.048 -> 0 24.6655423628 0
% INFO    : Updated Generator Cost: NG - 202.14 34.988 0.073 -> 0 25.2046444745 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 28.1758964776 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 38.5630559282 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 109.43840221 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 16.2020925977 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 119.63577666 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 46.8091538898 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 22.165300027 0
% INFO    : Updated Generator Cost: COW - 172.97 34.988 0.086 -> 0 24.9902622649 0
% INFO    : Updated Generator Cost: NG - 173.22 34.988 0.086 -> 0 33.8953950355 0
% INFO    : Updated Generator Cost: PEL - 163.99 34.988 0.089 -> 0 102.42702636 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.1777417717 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 46.490378193 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 107.475982087 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 113.566462578 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 117.506567851 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 104.906464333 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 108.679918475 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 109.527564815 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 120.479429744 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 107.622530352 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 20.265097266 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 21.1018763189 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 88.5505508031 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 109.265475313 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 120.050488727 0
% INFO    : Updated Generator Cost: NG - 125.37 34.988 0.117 -> 0 34.7658079379 0
% INFO    : Updated Generator Cost: COW - 125.37 34.988 0.117 -> 0 21.625381487 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.2890519394 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 58.8715647487 0
% INFO    : Updated Generator Cost: NG - 120.34 34.988 0.121 -> 0 44.6138117783 0
% INFO    : Updated Generator Cost: NG - 296.16 87.0 0.31 -> 0 31.7907988491 0
% INFO    : Updated Generator Cost: NG - 296.16 87.0 0.31 -> 0 40.9462779074 0
% INFO    : Updated Generator Cost: NG - 296.16 87.0 0.31 -> 0 44.5938438354 0
% INFO    : Updated Generator Cost: NG - 296.16 87.0 0.31 -> 0 47.1821888506 0
% INFO    : Updated Generator Cost: NG - 296.16 87.0 0.31 -> 0 33.9756363056 0
% INFO    : Updated Generator Cost: PEL - 296.16 87.0 0.31 -> 0 122.030926009 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 112.851027547 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 106.202213764 0
% INFO    : Updated Generator Cost: NG - 112.54 34.988 0.131 -> 0 25.3194906686 0
% INFO    : Updated Generator Cost: NG - 112.54 34.988 0.131 -> 0 37.3042924775 0
% INFO    : Updated Generator Cost: NG - 136.79 34.988 0.114 -> 0 37.5182654454 0
% INFO    : Updated Generator Cost: COW - 69.93 15.88 0.066 -> 0 28.0916946755 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 31.1745775569 0
% INFO    : Updated Generator Cost: NG - 3461.9 71.344 0.017 -> 0 14.6234063969 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 45.5757133341 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 33.2274238156 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 29.2152644418 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 23.6006154502 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 36.3191155592 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 47.2146897438 0
% INFO    : Updated Generator Cost: NG - 104.0 15.993 0.03 -> 0 53.36908333 0
% INFO    : Updated Generator Cost: COW - 104.0 15.993 0.03 -> 0 35.779799329 0
% INFO    : Updated Generator Cost: NG - 104.0 15.993 0.03 -> 0 13.9747182327 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 103.300481205 0
% INFO    : Updated Generator Cost: COW - 1952.1 59.305 0.01 -> 0 28.1758469291 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 96.557621529 0
% INFO    : Updated Generator Cost: NG - 214.3 14.762 0.013 -> 0 32.9190231562 0
% INFO    : Updated Generator Cost: NG - 538.71 13.319 0.004 -> 0 44.4338075782 0
% INFO    : Updated Generator Cost: NG - 111.89 34.988 0.132 -> 0 38.6125868433 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 109.453689665 0
% INFO    : Updated Generator Cost: PEL - 88.75 34.988 0.168 -> 0 103.187534452 0
% INFO    : Updated Generator Cost: PEL - 91.72 34.988 0.159 -> 0 110.919336541 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 21.3060254788 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 36.1700443063 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 24.3784174661 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 38.7640708395 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 23.7045908651 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 42.6007968031 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 46.7011492673 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 105.251554585 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 15.4876964568 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 37.0730279537 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.2887383086 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 36.6479073635 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 30.2730705138 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 52.6734057272 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 32.4403259326 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 35.3105102873 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 33.5802088996 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 39.8348237095 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 92.4389092677 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.8606738865 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 100.765513632 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 31.5192743882 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.2893238139 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 22.9334794148 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 117.143778493 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 120.518768565 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 10.1228783543 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 104.600053102 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 90.5345022826 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 15.0453964777 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 47.5297567123 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 45.3495403025 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.9233519866 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 20.0329505463 0
% INFO    : Updated Generator Cost: PEL - 95.07 34.988 0.152 -> 0 115.554078706 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 46.2921959155 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 40.8627641596 0
% INFO    : Updated Generator Cost: NUC - 7910.3 67.576 0.009 -> 0 7.93601944485 0
% INFO    : Updated Generator Cost: COW - 7910.3 67.576 0.009 -> 0 20.6889756255 0
% INFO    : Updated Generator Cost: COW - 7760.9 67.576 0.009 -> 0 13.7558719629 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 25.5204330519 0
% INFO    : Updated Generator Cost: COW - 1017.57 13.102 0.002 -> 0 24.9302781312 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 12.3180159843 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 33.4569090159 0
% INFO    : Updated Generator Cost: COW - 1515.9 21.147 0.003 -> 0 20.0732002397 0
% INFO    : Updated Generator Cost: COW - 1515.9 21.147 0.003 -> 0 36.8302545818 0
% INFO    : Updated Generator Cost: COW - 1517.34 21.162 0.003 -> 0 19.8158894369 0
% INFO    : Updated Generator Cost: COW - 1517.34 21.162 0.003 -> 0 13.5935408385 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 4.07741791545 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 46.1419546412 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 39.8805608927 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 31.4002613297 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 37.5397492945 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 17.3274664431 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 29.3900227359 0
% INFO    : Updated Generator Cost: NG - 910.45 21.0 0.006 -> 0 29.4385041781 0
% INFO    : Updated Generator Cost: COW - 910.45 20.999 0.006 -> 0 24.60659796 0
% INFO    : Updated Generator Cost: NG - 910.45 20.999 0.006 -> 0 34.9559869757 0
% INFO    : Updated Generator Cost: NG - 910.45 20.999 0.006 -> 0 39.5556506891 0
% INFO    : Updated Generator Cost: NG - 1293.2 21.105 0.003 -> 0 23.5980486164 0
% INFO    : Updated Generator Cost: NG - 854.99 21.188 0.006 -> 0 48.9175173014 0
% INFO    : Updated Generator Cost: NG - 528.37 22.239 0.011 -> 0 28.4184388942 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 16.2957069347 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 38.4839963359 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 20.7352988086 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 24.9730277903 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 30.6989441246 0
% INFO    : Updated Generator Cost: NG - 528.37 22.239 0.011 -> 0 13.7296531387 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 34.2767541235 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 110.824109395 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 118.862102905 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 44.8985569809 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 31.4437334167 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 12.8593258056 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 40.3773154252 0
% INFO    : Updated Generator Cost: PEL - 2249.86 9.547 0.032 -> 0 94.2878050854 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 42.6555649929 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 36.884159735 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 20.3343834787 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 41.4398538401 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 21.4500727628 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 40.0397495057 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 53.5745640927 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 18.5685379609 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 40.1634230668 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 31.4511266054 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.9646788051 0
% INFO    : Updated Generator Cost: NG - 553.15 22.03 0.011 -> 0 33.4438771197 0
% INFO    : Updated Generator Cost: NG - 451.55 22.796 0.014 -> 0 35.1555035023 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 46.7456485193 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 50.2887568641 0
% INFO    : Updated Generator Cost: NG - 521.25 22.317 0.012 -> 0 43.764836381 0
% INFO    : Updated Generator Cost: NG - 910.45 20.999 0.006 -> 0 48.8837588329 0
% INFO    : Updated Generator Cost: NG - 920.03 20.962 0.006 -> 0 35.4612199525 0
% INFO    : Updated Generator Cost: NG - 920.03 20.962 0.006 -> 0 56.9891051559 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 28.3818315166 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 36.1504265676 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 32.7682231628 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 29.9931611516 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 41.5539962639 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 6.74176341698 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 32.9219527359 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 26.1894496693 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 19.1245148808 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 49.9081767519 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 99.7940595706 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 33.3239189255 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.3613842746 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 43.712822459 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 22.8391596968 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.0969611533 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 47.0787178633 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 17.8164191818 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 13.1980636418 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 42.2399026619 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 107.989466831 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 61.5617763905 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 50.2726664009 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 15.9572553066 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 35.5194839929 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 123.096673676 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 15.9489170252 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 26.9337589701 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 31.8323312908 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 34.9238250218 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 20.4840675532 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 44.3041622678 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 19.4574214015 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 27.4296761911 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 24.359709173 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 28.9300194714 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 16.7966865667 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 24.9483731219 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 24.8734731781 0
% INFO    : Updated Generator Cost: NG - 308.53 14.126 0.008 -> 0 29.9433344908 0
% INFO    : Updated Generator Cost: NG - 279.82 14.339 0.009 -> 0 36.940299469 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 115.00869036 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 32.47905873 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 40.6847484212 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 113.038641174 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 38.3749100332 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 99.5385277189 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 31.748621374 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 47.0335823833 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 31.8331645289 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.3425392959 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 31.0074359099 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 42.1278399951 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 24.7379069389 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.3100443102 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 35.9606938089 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 97.6273717734 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 55.08971242 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 26.1870949407 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 109.58755929 0
% INFO    : Updated Generator Cost: COW - 1952.1 59.305 0.01 -> 0 28.0562094263 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 22.1929466773 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 33.2756169554 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 41.6219253047 0
% INFO    : Updated Generator Cost: NG - 242.67 14.588 0.011 -> 0 44.5433283015 0
% INFO    : Updated Generator Cost: COW - 52.21 16.01 0.059 -> 0 20.0813272625 0
% INFO    : Updated Generator Cost: NG - 242.67 14.588 0.011 -> 0 9.79747793708 0
% INFO    : Updated Generator Cost: PEL - 242.67 14.588 0.011 -> 0 95.7258718212 0
% INFO    : Updated Generator Cost: NG - 242.67 14.588 0.011 -> 0 46.6509208577 0
% INFO    : Updated Generator Cost: PEL - 242.67 14.588 0.011 -> 0 106.419957555 0
% INFO    : Updated Generator Cost: PEL - 242.67 14.588 0.011 -> 0 106.610748247 0
% INFO    : Updated Generator Cost: NG - 52.21 16.01 0.059 -> 0 30.8220606145 0
% INFO    : Updated Generator Cost: NG - 52.21 16.01 0.059 -> 0 24.7498666636 0
% INFO    : Updated Generator Cost: PEL - 52.21 16.01 0.059 -> 0 120.585179914 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 29.3220552295 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 33.9796846917 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 34.7593934146 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 26.6319753927 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 23.2274668398 0
% INFO    : Updated Generator Cost: NG - 345.06 23.517 0.02 -> 0 41.1572981999 0
% INFO    : Updated Generator Cost: NG - 345.06 23.517 0.02 -> 0 43.0712342862 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 105.282260243 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 34.5414169328 0
% INFO    : Updated Generator Cost: NG - 205.59 14.815 0.013 -> 0 30.5060738902 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 34.3403197552 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 46.8208826274 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 28.4792785052 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 30.0516956125 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 45.1984293481 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 36.9396015523 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 107.568481816 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 19.8812167281 0
% INFO    : Updated Generator Cost: NG - 394.44 13.78 0.006 -> 0 28.5872395543 0
% INFO    : Updated Generator Cost: NG - 394.44 13.78 0.006 -> 0 21.2748913307 0
% INFO    : Updated Generator Cost: NG - 183.37 14.988 0.015 -> 0 18.3578420614 0
% INFO    : Updated Generator Cost: NG - 183.37 14.988 0.015 -> 0 33.5751573414 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 30.259909911 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 45.3552105091 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 27.7336195959 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 35.7464751988 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 52.074475824 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 37.0083478908 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 28.5757927803 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 59.0446966523 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 27.1942621567 0
% INFO    : Updated Generator Cost: NG - 420.13 22.933 0.016 -> 0 13.0978753914 0
% INFO    : Updated Generator Cost: NG - 648.29 21.782 0.009 -> 0 36.8398548811 0
% INFO    : Updated Generator Cost: COW - 227.82 24.774 0.034 -> 0 29.0542884817 0
% INFO    : Updated Generator Cost: COW - 231.82 24.711 0.033 -> 0 2.79478154413 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 55.8511636735 0
% INFO    : Updated Generator Cost: COW - 51.34 14.879 0.053 -> 0 24.2904687675 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 114.97333008 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 109.310669141 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 48.4414798519 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 32.4293044016 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 16.4114497905 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 40.5415676928 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 49.817822494 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 49.3247257537 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 119.43241099 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 119.823887808 0
% INFO    : Updated Generator Cost: COW - 51.34 14.879 0.053 -> 0 17.6073523497 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 30.0744558187 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 108.982751039 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.7404623011 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 112.134563794 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 37.59006026 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 38.4223400463 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.0343530816 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 118.560025229 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 45.0253729051 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 112.508959545 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.918438419 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 29.810248129 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 110.085067451 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 28.1816561806 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 130.523543353 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 51.8333399407 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 27.4247030754 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 117.567835954 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 39.1727388652 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 22.7987032216 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 27.9623182819 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 28.6508670069 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.8947562488 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 35.77514672 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 17.4878370825 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 40.8627299459 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 126.360136838 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 41.9276312701 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 43.7547785179 0
% INFO    : Updated Generator Cost: NG - 246.79 34.686 0.06 -> 0 39.7156063666 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 33.8196216361 0
% INFO    : Updated Generator Cost: NG - 530.05 22.235 0.011 -> 0 48.0044972395 0
% INFO    : Updated Generator Cost: NG - 530.05 22.235 0.011 -> 0 49.7537165092 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 38.2137139337 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.3049753388 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 26.685563415 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 40.8315486801 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 39.1787140177 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 33.8184293431 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 24.4823241821 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 33.2940895525 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 31.1168230549 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 45.827240091 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.5048749822 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 17.656456383 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 25.3552805549 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 28.1647137832 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 122.099092763 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 109.346513647 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 16.6243235896 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 117.65959855 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 23.3235884625 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 13.7929078781 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 114.827293057 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 35.2943626861 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 47.4474825387 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 115.659399124 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 8.26376742675 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 31.5112833153 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 26.3800127448 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 38.790072996 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 120.101677702 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 7.01155087649 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 38.1185827535 0
% INFO    : Updated Generator Cost: NG - 190.41 34.988 0.08 -> 0 31.3567399878 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.9860778731 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 109.269677745 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 18.8970254382 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 47.7210162667 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 20.5759645785 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 32.5379239909 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 28.9799990444 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 47.6734080763 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 28.4852404353 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 34.4512132792 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 106.738427262 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 103.136932407 0
% INFO    : Updated Generator Cost: COW - 0.38 17.2 0.004 -> 0 31.8053380198 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 122.130230756 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 113.354030016 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 125.818106348 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 48.2156200129 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 35.100649396 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 22.551786923 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 44.9363715345 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 46.6986594367 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 125.322578537 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 44.1728895671 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 103.428510534 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 34.491971074 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 54.75368236 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 96.9019216752 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 18.8398945681 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 29.6344992575 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 43.4069482286 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 47.4225535139 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 18.4075628003 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 32.8941771608 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 41.010411682 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 106.954523742 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.7309865966 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 35.6766195184 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 131.652613047 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 24.4668709597 0
% INFO    : Updated Generator Cost: COW - 78.78 26.977 0.114 -> 0 38.911068256 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 42.9178181277 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 16.5667676991 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 46.5551086 0
% INFO    : Updated Generator Cost: PEL - 125.03 25.342 0.091 -> 0 118.684852746 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 107.61117621 0
% INFO    : Updated Generator Cost: NG - 116.87 25.372 0.099 -> 0 27.1693756942 0
% INFO    : Updated Generator Cost: NG - 116.87 25.372 0.099 -> 0 29.7265514672 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 120.095079428 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 114.702083005 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 48.7957585528 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 104.82575645 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 28.5933390602 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 100.66498698 0
% INFO    : Updated Generator Cost: COW - 51.34 14.879 0.053 -> 0 26.6462524738 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 105.236308722 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 30.4123044071 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 28.0913691198 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 20.6163285732 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 43.8389013944 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 102.595028689 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 46.7464821204 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 116.075044769 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 13.7173279944 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.0668837329 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 110.293053248 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 123.882591215 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 115.427942723 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 75.835455056 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 31.929580385 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 33.9748401973 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 6.15131944592 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 105.063001363 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 22.0469932016 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.9293439804 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.778360685 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 18.7452340916 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 113.48968522 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 50.260667834 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 121.754184602 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 101.022896834 0
% INFO    : Updated Generator Cost: NG - 94.3 34.988 0.153 -> 0 50.6267869927 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.5343871033 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 25.9465309912 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.5328388535 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 120.595110406 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 36.5369730253 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 125.933780652 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 118.014574698 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 20.111872105 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 106.060140563 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 31.9487631202 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 51.5359531702 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 44.2125592061 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 27.2065062635 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 44.7945887784 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 109.608995557 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 36.1924241413 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 21.4172287658 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.8325599698 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 32.1232338021 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.810247702 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 60.1988565436 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 37.406162345 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.9367408343 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 21.877512733 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 111.957361185 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 35.9107751887 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 117.205177066 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.5424328015 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.9941367734 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 25.9409711687 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.235221749 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 115.625237801 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 32.8737685341 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 30.6155720055 0
% INFO    : Updated Generator Cost: NUC - 0.0 0.0 0.0 -> 0 6.68134568948 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 22.9638569905 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 21.141990046 0
% INFO    : Updated Generator Cost: COW - 1074.56 20.945 0.005 -> 0 29.3848070464 0
% INFO    : Updated Generator Cost: COW - 1628.9 20.773 0.003 -> 0 16.9536263681 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 34.2308960735 0
% INFO    : Updated Generator Cost: NG - 524.35 13.379 0.004 -> 0 37.300569377 0
% INFO    : Updated Generator Cost: NG - 524.35 13.379 0.004 -> 0 60.3527214178 0
% INFO    : Updated Generator Cost: NG - 465.56 13.53 0.005 -> 0 40.8406221801 0
% INFO    : Updated Generator Cost: NG - 416.32 13.696 0.006 -> 0 39.7217540422 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 25.26410815 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 28.329852782 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 31.1450789691 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 16.5542928827 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 40.5147592204 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 40.4175694025 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 26.8445318672 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 114.499307885 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.3549582309 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 21.2316553525 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 22.3598745347 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 22.2569692995 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 34.9037745338 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 21.9096995312 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 45.8989031383 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 30.7547524453 0
% INFO    : Updated Generator Cost: NG - 251.25 14.515 0.01 -> 0 12.4200053132 0
% INFO    : Updated Generator Cost: NG - 296.11 14.15 0.008 -> 0 40.0534552901 0
% INFO    : Updated Generator Cost: NG - 1686.5 76.389 0.042 -> 0 35.8208798759 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 30.4845948604 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 41.8005499532 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 40.0575458712 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 19.2310062081 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 33.1672045955 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 35.4962333098 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 23.6756616941 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 29.4331656644 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 41.3665264457 0
% INFO    : Updated Generator Cost: COW - 316.5 23.699 0.022 -> 0 33.1309941603 0
% INFO    : Updated Generator Cost: NG - 316.5 23.699 0.022 -> 0 51.9372836239 0
% INFO    : Updated Generator Cost: NG - 331.79 23.605 0.021 -> 0 36.656724961 0
% INFO    : Updated Generator Cost: NG - 373.7 23.326 0.018 -> 0 27.7920642877 0
% INFO    : Updated Generator Cost: COW - 1755.23 50.578 0.008 -> 0 14.5816855399 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 22.766690964 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 36.5730319084 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 41.1899736744 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 23.8509070695 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 33.6594338382 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.7172031378 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.7134876736 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 42.3102421992 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 37.630490979 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 38.1730432031 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 36.0451962377 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 37.7015267386 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 26.2657606008 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 16.8720735641 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 30.5998785374 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 33.3282749697 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 28.949283185 0
% INFO    : Updated Generator Cost: NG - 254.45 24.461 0.029 -> 0 33.9958563955 0
% INFO    : Updated Generator Cost: NG - 230.84 24.714 0.033 -> 0 26.7235722026 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 24.3105090752 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 36.0498528032 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 47.8383733924 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 44.3058399186 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 48.659442933 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.5578420556 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 24.9236518438 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.2531581409 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 29.5894173637 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 28.1645211511 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 40.2896667524 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 107.690088255 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 21.8769674094 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 22.7841535994 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 123.151830707 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.3337008268 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 26.8291746644 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 53.0275991513 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 24.2547742217 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 39.0364732861 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 114.96553325 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 115.544236061 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.1967727608 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 37.9455974122 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 126.776249024 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 25.2016077227 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 22.0981908061 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 20.4578865594 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 22.9626774213 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 21.2683949859 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 23.9569410896 0
% INFO    : Updated Generator Cost: COW - 1755.23 50.578 0.008 -> 0 17.192771278 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 30.1446352553 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 26.027597737 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 23.2424682513 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 23.5288600244 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.4850575253 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 14.324874624 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 116.372805831 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 123.191743935 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 15.2078644429 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 44.6737486498 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 46.6330004626 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 35.742696179 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 8.8672576931 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 33.4502457461 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 113.460984083 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 57.2506514389 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.5491491666 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 37.4264104654 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 42.8987203355 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.0692127184 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.1009681564 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 56.8504929265 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.7099398724 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 44.9118534537 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 43.1428774188 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 42.6747500119 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 10.0859041212 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 110.185979772 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.8437301246 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 46.8198821035 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.3815979222 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 38.5019839587 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 49.5781632162 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 111.542160853 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 23.466972697 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 49.1569735388 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 38.7447969636 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 25.3688987311 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.8774502879 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 40.228864079 0
% INFO    : Updated Generator Cost: PEL - 156.14 34.988 0.096 -> 0 114.198602304 0
% INFO    : Updated Generator Cost: NG - 156.14 34.988 0.096 -> 0 27.4070384083 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 116.756618932 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 110.372240039 0
% INFO    : Updated Generator Cost: PEL - 274.22 87.0 0.334 -> 0 114.621754923 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 98.8102871459 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 58.4012047099 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 38.8127220484 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 127.512811668 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 20.9773574101 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 32.0208987604 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 31.5410027298 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 37.8633581862 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 40.5414156066 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 11.0022547128 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 25.8867368803 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 25.4137460749 0
% INFO    : Updated Generator Cost: COW - 1519.9 12.513 0.002 -> 0 27.4826442174 0
% INFO    : Updated Generator Cost: COW - 1519.9 12.513 0.002 -> 0 16.9648922636 0
% INFO    : Updated Generator Cost: NUC - 1523.96 12.513 0.002 -> 0 7.78398545474 0
% INFO    : Updated Generator Cost: COW - 1523.96 12.513 0.002 -> 0 12.3348802148 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 19.0112260333 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 20.982345908 0
% INFO    : Updated Generator Cost: COW - 1483.7 12.513 0.002 -> 0 28.6763628772 0
% INFO    : Updated Generator Cost: COW - 1483.7 12.513 0.002 -> 0 27.3488225263 0
% INFO    : Updated Generator Cost: COW - 1483.7 12.513 0.002 -> 0 27.1943517866 0
% INFO    : Updated Generator Cost: COW - 1081.76 12.965 0.002 -> 0 19.8127478516 0
% INFO    : Updated Generator Cost: COW - 1031.54 13.068 0.002 -> 0 18.6552693524 0
% INFO    : Updated Generator Cost: COW - 1031.54 13.068 0.002 -> 0 24.0549380503 0
% INFO    : Updated Generator Cost: COW - 981.37 13.192 0.002 -> 0 12.5935277707 0
% INFO    : Updated Generator Cost: COW - 892.86 13.334 0.002 -> 0 19.632889682 0
% INFO    : Updated Generator Cost: COW - 872.99 13.326 0.002 -> 0 12.4447845728 0
% INFO    : Updated Generator Cost: COW - 872.99 13.326 0.002 -> 0 20.3754981408 0
% INFO    : Updated Generator Cost: COW - 872.99 13.326 0.002 -> 0 15.4037930822 0
% INFO    : Updated Generator Cost: NG - 485.75 13.475 0.005 -> 0 33.9363767737 0
% INFO    : Updated Generator Cost: PEL - 721.64 86.019 0.149 -> 0 93.517672504 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 35.9980564764 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 50.8356098048 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 38.3811017594 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 55.9389406416 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.090700134 0
% INFO    : Updated Generator Cost: NG - 417.68 13.673 0.006 -> 0 31.7140740374 0
% INFO    : Updated Generator Cost: NG - 1655.42 76.828 0.045 -> 0 31.014044192 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 23.1139911923 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 9.16517936133 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 25.2515956483 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 10.7972311966 0
% INFO    : Updated Generator Cost: NG - 2088.53 74.412 0.032 -> 0 23.6314195284 0
% INFO    : Updated Generator Cost: NG - 2088.53 74.412 0.032 -> 0 30.2041476884 0
% INFO    : Updated Generator Cost: PEL - 2088.53 74.412 0.032 -> 0 98.5890467843 0
% INFO    : Updated Generator Cost: NG - 2088.53 74.412 0.032 -> 0 52.9031656287 0
% INFO    : Updated Generator Cost: NG - 1794.0 75.631 0.039 -> 0 22.2102217918 0
% INFO    : Updated Generator Cost: NG - 2088.5 74.412 0.032 -> 0 36.9490783094 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 39.9633299641 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.4296074918 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 22.1550241691 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 36.0521686619 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 32.5262723173 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.7460663248 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 48.5954053587 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 18.2597568788 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 36.8746192255 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 15.5004164856 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 48.2878395175 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.9171199633 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 30.7034076961 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 47.6787686993 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 37.4039955614 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 29.4062717199 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 19.3586848334 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 25.910845315 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 28.0291740492 0
% INFO    : Updated Generator Cost: COW - 2130.63 13.659 0.009 -> 0 21.7489130702 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 32.0282726334 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 28.2305419233 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 19.6003855236 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 52.1760249237 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 20.4771298345 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 52.2821225822 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 44.30070064 0
% INFO    : Updated Generator Cost: NG - 303.12 14.137 0.008 -> 0 35.1953161935 0
% INFO    : Updated Generator Cost: NG - 303.12 14.137 0.008 -> 0 42.6675880331 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 113.847976257 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 14.0128090546 0
% INFO    : Updated Generator Cost: NG - 248.12 14.537 0.01 -> 0 43.4409466643 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 26.7012994832 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 41.0540260168 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 22.890544559 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 23.2153496483 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 23.7970243637 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 42.9564951598 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 41.9522768739 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 48.5487060502 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 30.5638432858 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.7185086425 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 43.5270969073 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 42.4653172362 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 39.79563316 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 48.5049388742 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 36.9536449121 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 22.8636553252 0
% INFO    : Updated Generator Cost: NG - 350.97 13.989 0.007 -> 0 25.5415789315 0
% INFO    : Updated Generator Cost: NG - 350.97 13.989 0.007 -> 0 34.8380667734 0
% INFO    : Updated Generator Cost: NG - 236.4 14.601 0.011 -> 0 35.553107755 0
% INFO    : Updated Generator Cost: NG - 236.4 14.601 0.011 -> 0 40.6128243269 0
% INFO    : Updated Generator Cost: NG - 218.2 14.727 0.012 -> 0 46.5164272041 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 24.3261678463 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 32.1778203215 0
% INFO    : Updated Generator Cost: NG - 236.06 14.612 0.011 -> 0 28.930203926 0
% INFO    : Updated Generator Cost: NG - 341.62 14.011 0.007 -> 0 37.0986047952 0
% INFO    : Updated Generator Cost: NG - 188.73 14.913 0.014 -> 0 53.6135501005 0
% INFO    : Updated Generator Cost: COW - 188.73 14.913 0.014 -> 0 30.1468469681 0
% INFO    : Updated Generator Cost: NG - 185.47 14.96 0.015 -> 0 32.2243908167 0
% INFO    : Updated Generator Cost: NG - 179.25 15.043 0.015 -> 0 38.0193132049 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 34.8678856246 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 14.8153791318 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 23.242359291 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 44.6913872283 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 112.310062998 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 37.0083075495 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 102.257704522 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 28.4946309677 0
% INFO    : Updated Generator Cost: NG - 932.7 20.958 0.006 -> 0 31.7487049873 0
% INFO    : Updated Generator Cost: COW - 932.7 20.958 0.006 -> 0 21.1283857111 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 24.009569003 0
% INFO    : Updated Generator Cost: COW - 1952.1 59.305 0.01 -> 0 21.2028115373 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 39.5830764855 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 41.6194963386 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 23.2409691332 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 96.6176508843 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 122.140704617 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 43.1375254943 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 42.4620615155 0
% INFO    : Updated Generator Cost: NG - 90.9 16.01 0.034 -> 0 26.2612620966 0
% INFO    : Updated Generator Cost: PEL - 139.99 15.548 0.021 -> 0 107.160122713 0
% INFO    : Updated Generator Cost: PEL - 139.99 15.548 0.021 -> 0 105.875510048 0
% INFO    : Updated Generator Cost: PEL - 139.99 15.548 0.021 -> 0 130.923880914 0
% INFO    : Updated Generator Cost: NG - 139.99 15.548 0.021 -> 0 26.1746809129 0
% INFO    : Updated Generator Cost: NG - 139.99 15.548 0.021 -> 0 4.48611963745 0
% INFO    : Updated Generator Cost: COW - 170.34 34.988 0.086 -> 0 33.1783477884 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 109.277326809 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 102.051304664 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 102.634374663 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 127.065105961 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 24.0382919699 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 118.926702193 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 39.7246076111 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 19.9284704162 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 122.1501229 0
% INFO    : Updated Generator Cost: NG - 187.65 22.535 0.033 -> 0 26.9700022127 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 35.7441998121 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 34.9840094384 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 31.9299567063 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 115.853438515 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 109.843845857 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 38.2643551821 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 117.59379059 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 52.5683869437 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 19.8388801643 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 121.661354966 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 51.0457279213 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 51.9128890408 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 38.8969625239 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 44.2477764094 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 46.6664891557 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 103.228543122 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 26.7688334589 0
% INFO    : Updated Generator Cost: PEL - 116.51 15.849 0.026 -> 0 120.238210347 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 18.8263229325 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 93.8880370005 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 20.2976876681 0
% INFO    : Updated Generator Cost: PEL - 240.49 34.811 0.06 -> 0 97.7287335421 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 37.2222861581 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 29.4460898184 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 36.179123025 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 108.381876634 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 41.6823929673 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 55.9186432213 0
% INFO    : Updated Generator Cost: NG - 281.65 14.311 0.009 -> 0 43.8428732418 0
% INFO    : Updated Generator Cost: NG - 169.26 15.165 0.016 -> 0 42.5667953933 0
% INFO    : Updated Generator Cost: NG - 169.26 15.165 0.016 -> 0 27.7250028336 0
% INFO    : Updated Generator Cost: NG - 194.59 14.891 0.014 -> 0 45.8740575872 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 40.0826751396 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 108.369537413 0
% INFO    : Updated Generator Cost: COW - 51.34 14.879 0.053 -> 0 20.4266226685 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 23.7010584107 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 21.8337978746 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 98.4399541374 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.2645648707 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 40.441765908 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 52.1706335431 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 50.505074355 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 115.160003111 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.4342061531 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 118.479915394 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 46.7721641319 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 20.9333259715 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 104.732013202 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 41.241766962 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 91.5684739376 0
% INFO    : Updated Generator Cost: COW - 151.03 15.411 0.019 -> 0 28.5820993075 0
% INFO    : Updated Generator Cost: COW - 151.03 15.411 0.019 -> 0 25.2011856144 0
% INFO    : Updated Generator Cost: COW - 151.03 15.411 0.019 -> 0 10.7817687649 0
% INFO    : Updated Generator Cost: PEL - 72.57 16.01 0.044 -> 0 106.265894416 0
% INFO    : Updated Generator Cost: NG - 216.93 14.75 0.012 -> 0 42.9367673744 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 115.197334697 0
% INFO    : Updated Generator Cost: NG - 149.1 34.988 0.103 -> 0 56.1323657181 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.633875091 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 20.3067508777 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 119.709008526 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 25.4911173968 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 40.9298804456 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.5631983729 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.6937020652 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.7238904857 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 44.7963658366 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 115.579119025 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 102.529556313 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 107.79292873 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 113.754292795 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 37.8066938906 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 101.434759308 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 118.143554046 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 140.62134336 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 48.01242842 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.3347098652 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 101.166273529 0
% INFO    : Updated Generator Cost: NG - 102.78 25.545 0.076 -> 0 38.2532366668 0
% INFO    : Updated Generator Cost: NG - 102.78 25.545 0.076 -> 0 33.7744826986 0
% INFO    : Updated Generator Cost: NG - 102.78 25.545 0.076 -> 0 56.4400467263 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 107.811494797 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.7289647631 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 12.8570954788 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 30.3268292955 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 112.408053801 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 103.444992051 0
% INFO    : Updated Generator Cost: COW - 1755.23 50.578 0.008 -> 0 9.96699177899 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 106.179474995 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 20.3018411917 0
% INFO    : Updated Generator Cost: COW - 0.38 17.2 0.004 -> 0 28.5759593394 0
% INFO    : Updated Generator Cost: NG - 81.79 25.545 0.101 -> 0 37.8288165202 0
% INFO    : Updated Generator Cost: NG - 81.79 25.545 0.101 -> 0 47.7588666504 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 99.4021257769 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 39.5119616106 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 104.824216077 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 23.6836963058 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 110.098306298 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 36.3238940977 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 23.6800730652 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 17.0927242015 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 100.46542017 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 105.017164044 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.8581861008 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 105.374049822 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 23.3920438209 0
% INFO    : Updated Generator Cost: COW - 2189.7 19.79 0.003 -> 0 18.1318233098 0
% INFO    : Updated Generator Cost: COW - 2189.7 19.79 0.003 -> 0 25.6693021758 0
% INFO    : Updated Generator Cost: COW - 68.98 25.545 0.124 -> 0 16.5836311842 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 124.986161278 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 119.082285644 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 40.530798245 0
% INFO    : Updated Generator Cost: NG - 435.41 22.9 0.015 -> 0 48.8910532723 0
% INFO    : Updated Generator Cost: NG - 435.41 22.9 0.015 -> 0 46.7762528351 0
% INFO    : Updated Generator Cost: NG - 435.41 22.9 0.015 -> 0 32.4201141922 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 23.4686593447 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 21.6473229538 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 27.7958803444 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 29.2498417217 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.917542 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 54.009970845 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 50.8988658134 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 24.2085102577 0
% INFO    : Updated Generator Cost: PEL - 88.34 25.545 0.094 -> 0 106.880630807 0
% INFO    : Updated Generator Cost: PEL - 88.34 25.545 0.094 -> 0 120.371256037 0
% INFO    : Updated Generator Cost: NG - 236.16 24.664 0.032 -> 0 37.1285234412 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 24.6118635665 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 31.789578841 0
% INFO    : Updated Generator Cost: NG - 332.48 14.029 0.007 -> 0 27.0306280957 0
% INFO    : Updated Generator Cost: PEL - 155.36 15.37 0.018 -> 0 112.247332947 0
% INFO    : Updated Generator Cost: NG - 155.36 15.37 0.018 -> 0 38.4994428621 0
% INFO    : Updated Generator Cost: COW - 668.33 13.171 0.003 -> 0 16.4030495909 0
% INFO    : Updated Generator Cost: NG - 497.22 22.459 0.012 -> 0 27.849759529 0
% INFO    : Updated Generator Cost: COW - 1027.54 20.883 0.005 -> 0 16.8529929434 0
% INFO    : Updated Generator Cost: NG - 240.23 24.641 0.032 -> 0 18.8855653016 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 115.043367306 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 29.6317424628 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 45.6014786724 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 37.5081065065 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 40.7455758507 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 34.5329019293 0
% INFO    : Updated Generator Cost: NG - 75.34 25.504 0.121 -> 0 32.7248576056 0
% INFO    : Updated Generator Cost: PEL - 75.34 25.504 0.121 -> 0 111.905949158 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 117.472733522 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 21.0838305679 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 18.66883621 0
% INFO    : Updated Generator Cost: COW - 1071.2 12.996 0.002 -> 0 17.1262032189 0
% INFO    : Updated Generator Cost: COW - 1071.2 12.996 0.002 -> 0 28.7121579405 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 122.221065727 0
% INFO    : Updated Generator Cost: NG - 562.38 13.245 0.004 -> 0 35.4603005946 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 31.919051153 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 9.03039712499 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 105.489491249 0
% INFO    : Updated Generator Cost: COW - 1755.23 50.578 0.008 -> 0 29.9093093619 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 49.7329575133 0
% INFO    : Updated Generator Cost: COW - 1596.95 20.859 0.003 -> 0 32.7710237076 0
% INFO    : Updated Generator Cost: COW - 1596.95 20.859 0.003 -> 0 28.5252147946 0
% INFO    : Updated Generator Cost: NG - 562.38 13.245 0.004 -> 0 33.2263512888 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 26.4202124297 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 28.6893787857 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 22.3277065465 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 44.4213647036 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 28.5041764937 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 41.5820410777 0
% INFO    : Updated Generator Cost: COW - 965.61 13.226 0.002 -> 0 16.5924283787 0
% INFO    : Updated Generator Cost: COW - 965.61 13.226 0.002 -> 0 17.4422501503 0
% INFO    : Updated Generator Cost: NG - 360.48 13.926 0.007 -> 0 33.8352916202 0
% INFO    : Updated Generator Cost: NG - 360.48 13.926 0.007 -> 0 20.6564794541 0
% INFO    : Updated Generator Cost: NG - 360.48 13.926 0.007 -> 0 44.0699361929 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 56.3594651041 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 36.311135198 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 32.3639186579 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 36.3790078578 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 26.8274194933 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 41.0974002147 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 25.9237507109 0
% INFO    : Updated Generator Cost: NG - 355.68 13.96 0.007 -> 0 39.4023758336 0
% INFO    : Updated Generator Cost: NG - 380.36 13.826 0.006 -> 0 36.1607232515 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 31.2204923378 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 38.1337088406 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 29.722004808 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 40.797530457 0
% INFO    : Updated Generator Cost: NG - 1553.77 77.195 0.047 -> 0 34.0713011252 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 117.270220846 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 11.1543678125 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 36.8735791308 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 44.479749757 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 39.2120551708 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 22.0564462806 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 34.41160561 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 118.156973954 0
% INFO    : Updated Generator Cost: NG - 249.39 14.526 0.01 -> 0 53.2452234835 0
% INFO    : Updated Generator Cost: COW - 3484.23 71.325 0.017 -> 0 21.2852400631 0
% INFO    : Updated Generator Cost: NG - 554.91 13.269 0.004 -> 0 37.4597196907 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 99.6659893504 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 36.3951820523 0
% INFO    : Updated Generator Cost: PEL - 229.51 24.733 0.034 -> 0 113.571754648 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 22.9283227934 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 29.4562696653 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 105.64544962 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 101.382067636 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 17.5291296351 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 102.973658001 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 109.041505159 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 37.2502379521 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 38.2354277359 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 97.7683487367 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 118.441174493 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 10.7111406334 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 24.1855245206 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 43.1710672436 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 39.7303063759 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 23.742011915 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 113.386764101 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 35.8838714148 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 98.0152191875 0
% INFO    : Updated Generator Cost: COW - 2022.6 12.513 0.001 -> 0 26.323723328 0
% INFO    : Updated Generator Cost: COW - 2022.6 12.513 0.001 -> 0 9.08116079675 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 23.0320513386 0
% INFO    : Updated Generator Cost: NUC - 0.0 0.0 0.0 -> 0 6.4729577085 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 32.5030643906 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 36.6778206133 0
% INFO    : Updated Generator Cost: NUC - 0.0 0.0 0.0 -> 0 7.36234860291 0
% INFO    : Updated Generator Cost: COW - 1223.3 12.67 0.002 -> 0 22.2842187748 0
% INFO    : Updated Generator Cost: COW - 1198.4 12.722 0.002 -> 0 24.5023003976 0
% INFO    : Updated Generator Cost: COW - 1018.7 13.102 0.002 -> 0 22.7885361943 0
% INFO    : Updated Generator Cost: COW - 1198.4 12.722 0.002 -> 0 19.1426106132 0
% INFO    : Updated Generator Cost: COW - 629.93 13.131 0.003 -> 0 23.0311822972 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.7731046523 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 33.6772176909 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.7392751929 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 51.1106703826 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 37.5496813539 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 39.4941026828 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 56.205219427 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 31.1368015882 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 48.9128287618 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 16.5185378075 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 42.4516219166 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.393662558 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.5180398694 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 25.2811358455 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 44.6607980933 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 39.8617760204 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 37.9663611428 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 21.719784387 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 17.7233525017 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 7.22964931789 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 37.0470187943 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 26.3392866172 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 33.2135137219 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 34.3065247235 0
% INFO    : Updated Generator Cost: COW - 296.46 14.144 0.008 -> 0 34.9409734339 0
% INFO    : Updated Generator Cost: NG - 296.46 14.144 0.008 -> 0 34.0674697817 0
% INFO    : Updated Generator Cost: NG - 450.25 13.571 0.005 -> 0 39.5079172916 0
% INFO    : Updated Generator Cost: NG - 450.25 13.571 0.005 -> 0 46.5667970151 0
% INFO    : Updated Generator Cost: NG - 458.84 13.555 0.005 -> 0 38.8495661838 0
% INFO    : Updated Generator Cost: NG - 208.35 14.809 0.013 -> 0 29.7513749134 0
% INFO    : Updated Generator Cost: COW - 208.35 14.809 0.013 -> 0 25.088243598 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 112.591981905 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 62.517832449 0
% INFO    : Updated Generator Cost: COW - 675.54 13.175 0.003 -> 0 39.9617205237 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 36.5514307004 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 108.954823295 0
% INFO    : Updated Generator Cost: COW - 347.69 13.992 0.007 -> 0 22.3792500011 0
% INFO    : Updated Generator Cost: NG - 258.15 14.462 0.01 -> 0 14.117830971 0
% INFO    : Updated Generator Cost: NG - 247.26 14.555 0.01 -> 0 33.9941412326 0
% INFO    : Updated Generator Cost: NG - 247.26 14.555 0.01 -> 0 31.4387430578 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 121.103496801 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.4952737582 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 108.26002857 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 120.310547295 0
% INFO    : Updated Generator Cost: COW - 188.73 14.913 0.014 -> 0 21.3964000645 0
% INFO    : Updated Generator Cost: PEL - 188.73 14.913 0.014 -> 0 112.582594903 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 22.4148254526 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 45.4974907456 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 19.7619020028 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 17.5240165657 0
% INFO    : Updated Generator Cost: COW - 150.77 15.419 0.019 -> 0 20.9944187755 0
% INFO    : Updated Generator Cost: NG - 150.77 15.419 0.019 -> 0 37.5402780824 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 46.2223149201 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 31.5379605655 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 116.355161086 0
% INFO    : Updated Generator Cost: COW - 416.48 13.676 0.006 -> 0 31.9274553336 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 131.019720235 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 33.8941388063 0
% INFO    : Updated Generator Cost: PEL - 171.18 15.246 0.024 -> 0 116.931808574 0
% INFO    : Updated Generator Cost: NG - 171.18 15.246 0.024 -> 0 39.461606589 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 30.9527694035 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 22.2602227368 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.1907371535 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 28.3862620548 0
% INFO    : Updated Generator Cost: NG - 117.2 15.839 0.026 -> 0 36.2715614677 0
% INFO    : Updated Generator Cost: NG - 115.04 15.859 0.027 -> 0 43.8415949327 0
% INFO    : Updated Generator Cost: PEL - 115.04 15.859 0.027 -> 0 103.171606505 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 42.6047408184 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.9662560927 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 19.8302058413 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 19.6351344289 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 41.2751261991 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.9024243176 0
% INFO    : Updated Generator Cost: NG - 157.68 15.321 0.028 -> 0 54.3018061406 0
% INFO    : Updated Generator Cost: NG - 107.73 15.957 0.029 -> 0 35.3358611163 0
% INFO    : Updated Generator Cost: NG - 107.73 15.957 0.029 -> 0 60.144751746 0
% INFO    : Updated Generator Cost: NG - 107.73 15.957 0.029 -> 0 26.6703789171 0
% INFO    : Updated Generator Cost: NG - 107.73 15.957 0.029 -> 0 33.8680169461 0
% INFO    : Updated Generator Cost: NG - 107.73 15.957 0.029 -> 0 29.213205573 0
% INFO    : Updated Generator Cost: NG - 107.73 15.957 0.029 -> 0 15.9951350712 0
% INFO    : Updated Generator Cost: COW - 229.64 34.986 0.066 -> 0 27.5115067772 0
% INFO    : Updated Generator Cost: NG - 92.92 16.01 0.034 -> 0 50.0545598483 0
% INFO    : Updated Generator Cost: NG - 92.92 16.01 0.034 -> 0 37.4684442891 0
% INFO    : Updated Generator Cost: NG - 144.4 15.489 0.02 -> 0 35.5419636074 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 24.1486775215 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 32.6367338032 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 27.5544557338 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 15.4853334463 0
% INFO    : Updated Generator Cost: COW - 197.36 34.988 0.076 -> 0 21.8723027187 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.3337322468 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 47.4121929484 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 115.894628543 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.8648122041 0
% INFO    : Updated Generator Cost: NG - 233.38 14.619 0.011 -> 0 33.5136905146 0
% INFO    : Updated Generator Cost: NG - 233.38 14.619 0.011 -> 0 27.2446215651 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 122.30320178 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 18.9314470565 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 110.597413934 0
% INFO    : Updated Generator Cost: NG - 81.1 16.01 0.038 -> 0 44.1872383832 0
% INFO    : Updated Generator Cost: NG - 153.1 15.378 0.019 -> 0 56.5671422536 0
% INFO    : Updated Generator Cost: NG - 81.27 16.01 0.038 -> 0 30.0760377772 0
% INFO    : Updated Generator Cost: PEL - 81.27 16.01 0.038 -> 0 117.310279332 0
% INFO    : Updated Generator Cost: NG - 128.78 15.703 0.023 -> 0 45.4979084704 0
% INFO    : Updated Generator Cost: PEL - 128.78 15.703 0.023 -> 0 104.243309427 0
% INFO    : Updated Generator Cost: COW - 954.51 13.257 0.002 -> 0 25.6495502775 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 26.2038806258 0
% INFO    : Updated Generator Cost: COW - 51.34 14.879 0.053 -> 0 28.6213399218 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 30.1734384437 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.5824190529 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.1371303757 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 44.1903529705 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 22.7544093538 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.1995026878 0
% INFO    : Updated Generator Cost: NG - 71.66 16.01 0.044 -> 0 12.2374564443 0
% INFO    : Updated Generator Cost: COW - 151.65 34.988 0.098 -> 0 9.12488955765 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 105.905654385 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 133.268178326 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 28.1197182273 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 116.164772679 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 110.281115164 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 38.6544519674 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 31.8454828578 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 42.6648080149 0
% INFO    : Updated Generator Cost: NG - 130.81 34.988 0.115 -> 0 50.0479565617 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 123.812687091 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 37.9877645942 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 38.5068395878 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 126.614121096 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 18.4712355338 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 18.896083322 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 41.5265713638 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 125.931159871 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 107.808334607 0
% INFO    : Updated Generator Cost: NG - 124.1 34.988 0.117 -> 0 38.0234252191 0
% INFO    : Updated Generator Cost: NG - 56.34 16.01 0.054 -> 0 17.3122712571 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 110.96785064 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 101.558979444 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 54.336565987 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 103.781676279 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.6681820478 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 123.045308233 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 26.3658461407 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 25.8470500025 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 17.1089435109 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 50.8941505879 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.7284891471 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.8834771536 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 34.4811652508 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 112.071691273 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 10.1971146363 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 20.6199799406 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 117.163527213 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 106.715983684 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 117.708224692 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 37.5479680775 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 119.378722661 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.6021834099 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 52.4699009188 0
% INFO    : Updated Generator Cost: COW - 1952.1 59.305 0.01 -> 0 25.6933458682 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 35.9356577478 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 47.0439026312 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 113.472576701 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 28.8393351603 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 25.3014417221 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 119.357431002 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 112.363754116 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.5613618824 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 113.380657107 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 95.9691850657 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 14.994011418 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 100.726317492 0
% INFO    : Updated Generator Cost: NUC - 0.0 0.0 0.0 -> 0 7.93416440986 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 31.3622511914 0
% INFO    : Updated Generator Cost: NG - 343.34 23.524 0.02 -> 0 48.0894649612 0
% INFO    : Updated Generator Cost: COW - 7752.1 67.576 0.009 -> 0 26.9421879964 0
% INFO    : Updated Generator Cost: NG - 636.27 21.831 0.009 -> 0 38.4004936487 0
% INFO    : Updated Generator Cost: NG - 8595.9 67.576 0.008 -> 0 26.6840731971 0
% INFO    : Updated Generator Cost: COW - 8595.9 67.576 0.008 -> 0 14.7409775522 0
% INFO    : Updated Generator Cost: COW - 8595.9 67.576 0.008 -> 0 33.4069424712 0
% INFO    : Updated Generator Cost: NG - 8595.9 67.576 0.008 -> 0 20.0469531529 0
% INFO    : Updated Generator Cost: NG - 8595.9 67.576 0.008 -> 0 29.1284416253 0
% INFO    : Updated Generator Cost: NG - 8595.9 67.576 0.008 -> 0 25.8349115152 0
% INFO    : Updated Generator Cost: NG - 8595.9 67.576 0.008 -> 0 41.4299116979 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 24.8095054552 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 27.9079433406 0
% INFO    : Updated Generator Cost: PEL - 573.64 14.879 0.005 -> 0 106.427670249 0
% INFO    : Updated Generator Cost: COW - 573.64 14.879 0.005 -> 0 17.4819234315 0
% INFO    : Updated Generator Cost: NG - 573.64 14.879 0.005 -> 0 58.1540716333 0
% INFO    : Updated Generator Cost: PEL - 573.64 14.879 0.005 -> 0 106.471329975 0
% INFO    : Updated Generator Cost: COW - 573.64 14.879 0.005 -> 0 30.2628295596 0
% INFO    : Updated Generator Cost: COW - 573.64 14.879 0.005 -> 0 26.0186629844 0
% INFO    : Updated Generator Cost: COW - 637.29 13.147 0.003 -> 0 32.8251081764 0
% INFO    : Updated Generator Cost: NG - 637.29 13.147 0.003 -> 0 40.0435707602 0
% INFO    : Updated Generator Cost: NG - 420.37 13.653 0.005 -> 0 18.9589167187 0
% INFO    : Updated Generator Cost: NG - 407.01 13.728 0.006 -> 0 24.5675451918 0
% INFO    : Updated Generator Cost: NG - 407.01 13.728 0.006 -> 0 45.7164516297 0
% INFO    : Updated Generator Cost: NG - 407.01 13.728 0.006 -> 0 20.6314956125 0
% INFO    : Updated Generator Cost: NG - 346.87 13.994 0.007 -> 0 33.861036235 0
% INFO    : Updated Generator Cost: NG - 346.87 13.994 0.007 -> 0 36.5908521889 0
% INFO    : Updated Generator Cost: COW - 7756.44 67.576 0.009 -> 0 21.3565849158 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 49.2922701777 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 36.5008372092 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 31.6549301049 0
% INFO    : Updated Generator Cost: COW - 2130.63 13.659 0.009 -> 0 19.1449318533 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 26.0764274272 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 38.1615963312 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 27.4497184171 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 40.0652084864 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 33.5875685007 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 12.4853637208 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 44.3176438953 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 13.9568858641 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 43.2295585306 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 44.7031765034 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 32.6153893138 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 16.3952142584 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 24.0781687707 0
% INFO    : Updated Generator Cost: NG - 210.67 14.788 0.013 -> 0 44.1864162938 0
% INFO    : Updated Generator Cost: NG - 210.67 14.788 0.013 -> 0 49.8168561869 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 108.840922322 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 117.060238039 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 114.420958951 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 122.207912888 0
% INFO    : Updated Generator Cost: NG - 411.4 13.709 0.006 -> 0 23.7111404178 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 55.025462472 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 106.99749807 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 51.3155482183 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 127.734250326 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 100.0233127 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 27.2377408076 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 32.9794197983 0
% INFO    : Updated Generator Cost: NG - 344.42 14.005 0.007 -> 0 27.8891539255 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 103.64506438 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 106.376061266 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 45.4043063381 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 44.088930081 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 23.4552104606 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 25.7264338919 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 126.487743122 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 22.5674667088 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 22.9399149567 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 24.1284286367 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 24.1737867589 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 18.3778532103 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 27.5946687624 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 32.6915581153 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 22.1442174588 0
% INFO    : Updated Generator Cost: NG - 346.87 13.994 0.007 -> 0 41.0052166063 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 22.1056061826 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 25.9100387648 0
% INFO    : Updated Generator Cost: NG - 209.92 14.79 0.013 -> 0 34.0218365786 0
% INFO    : Updated Generator Cost: COW - 1083.48 12.959 0.002 -> 0 37.3806237747 0
% INFO    : Updated Generator Cost: COW - 555.91 13.263 0.004 -> 0 13.3631038418 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.575879848 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 128.303117684 0
% INFO    : Updated Generator Cost: NG - 110.28 34.988 0.134 -> 0 22.9214440395 0
% INFO    : Updated Generator Cost: PEL - 202.92 34.988 0.073 -> 0 111.692888458 0
% INFO    : Updated Generator Cost: NG - 412.48 32.5 0.031 -> 0 40.3667371589 0
% INFO    : Updated Generator Cost: PEL - 412.48 32.5 0.031 -> 0 114.853906375 0
% INFO    : Updated Generator Cost: PEL - 412.48 32.5 0.031 -> 0 118.666784795 0
% INFO    : Updated Generator Cost: PEL - 412.48 32.5 0.031 -> 0 118.394564393 0
% INFO    : Updated Generator Cost: COW - 412.48 32.5 0.031 -> 0 28.9301925234 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 17.5423917881 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 28.0067162786 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 29.6582242261 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 30.0709833245 0
% INFO    : Updated Generator Cost: NG - 190.57 14.908 0.014 -> 0 22.7466623439 0
% INFO    : Updated Generator Cost: COW - 409.33 13.723 0.006 -> 0 24.2544428652 0
% INFO    : Updated Generator Cost: NG - 122.15 34.988 0.12 -> 0 39.3648657865 0
% INFO    : Updated Generator Cost: PEL - 159.59 34.988 0.091 -> 0 120.999735271 0
% INFO    : Updated Generator Cost: NG - 410.53 32.55 0.031 -> 0 35.9174816519 0
% INFO    : Updated Generator Cost: COW - 410.53 32.55 0.031 -> 0 24.4231798924 0
% INFO    : Updated Generator Cost: NG - 410.53 32.55 0.031 -> 0 30.7755654394 0
% INFO    : Updated Generator Cost: PEL - 410.53 32.55 0.031 -> 0 118.240583649 0
% INFO    : Updated Generator Cost: NG - 410.53 32.55 0.031 -> 0 53.6542586725 0
% INFO    : Updated Generator Cost: COW - 410.53 32.55 0.031 -> 0 21.4010488628 0
% INFO    : Updated Generator Cost: NG - 410.53 32.55 0.031 -> 0 29.9541401445 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 14.7853032575 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 17.0571956888 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 29.7337619883 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 18.1365371717 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 116.862112401 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 32.0698951972 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 22.4989996517 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 105.665725405 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 50.0163841327 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 128.363969132 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 27.7328890025 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 106.445103625 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 111.44558605 0
% INFO    : Updated Generator Cost: NG - 301.22 34.019 0.047 -> 0 38.1317034143 0
% INFO    : Updated Generator Cost: PEL - 301.27 33.978 0.046 -> 0 113.778065677 0
% INFO    : Updated Generator Cost: PEL - 306.05 33.943 0.046 -> 0 109.111950984 0
% INFO    : Updated Generator Cost: NG - 139.4 15.557 0.021 -> 0 48.6598948268 0
% INFO    : Updated Generator Cost: NG - 139.4 15.557 0.021 -> 0 53.9015938118 0
% INFO    : Updated Generator Cost: NG - 521.37 22.294 0.012 -> 0 38.9286858315 0
% INFO    : Updated Generator Cost: NG - 225.95 24.857 0.035 -> 0 35.7867339808 0
% INFO    : Updated Generator Cost: NG - 129.42 15.703 0.023 -> 0 36.3446597296 0
% INFO    : Updated Generator Cost: PEL - 129.42 15.703 0.023 -> 0 117.939076555 0
% INFO    : Updated Generator Cost: NG - 129.42 15.703 0.023 -> 0 37.7698457249 0
% INFO    : Updated Generator Cost: NG - 129.42 15.703 0.023 -> 0 57.4420077342 0
% INFO    : Updated Generator Cost: PEL - 68.68 16.01 0.045 -> 0 105.68278556 0
% INFO    : Updated Generator Cost: PEL - 68.68 16.01 0.045 -> 0 115.124015406 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 15.6836990612 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 52.1539370082 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 120.695529559 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 109.679490517 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 111.450875158 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.3282307486 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 109.235239972 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 26.4208197215 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 41.69459113 0
% INFO    : Updated Generator Cost: NG - 114.16 15.873 0.027 -> 0 32.3243662067 0
% INFO    : Updated Generator Cost: PEL - 114.16 15.873 0.027 -> 0 122.974534055 0
% INFO    : Updated Generator Cost: NG - 114.84 15.861 0.027 -> 0 7.43187742713 0
% INFO    : Updated Generator Cost: NG - 114.84 15.861 0.027 -> 0 29.3641177873 0
% INFO    : Updated Generator Cost: PEL - 115.49 15.85 0.026 -> 0 116.224783084 0
% INFO    : Updated Generator Cost: NG - 115.49 15.85 0.026 -> 0 21.7956037381 0
% INFO    : Updated Generator Cost: NG - 115.49 15.85 0.026 -> 0 17.2294635739 0
% INFO    : Updated Generator Cost: PEL - 115.49 15.85 0.026 -> 0 132.599408917 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 32.1251837086 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.1341390185 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 25.2680169679 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 127.180784703 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 118.270570451 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 26.1075430572 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.3044993513 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 28.5020047966 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 121.086506266 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.7714509588 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 17.9940213767 0
% INFO    : Updated Generator Cost: NG - 198.5 34.988 0.075 -> 0 26.0826998264 0
% INFO    : Updated Generator Cost: PEL - 198.5 34.988 0.075 -> 0 97.8589352142 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 20.4727889977 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 109.869706953 0
% INFO    : Updated Generator Cost: COW - 127.93 34.988 0.116 -> 0 24.4644195916 0
% INFO    : Updated Generator Cost: PEL - 127.93 34.988 0.116 -> 0 130.607662451 0
% INFO    : Updated Generator Cost: NG - 127.39 25.336 0.089 -> 0 32.5992668093 0
% INFO    : Updated Generator Cost: NG - 127.39 25.336 0.089 -> 0 16.6042302594 0
% INFO    : Updated Generator Cost: NG - 127.39 25.336 0.089 -> 0 20.6625918651 0
% INFO    : Updated Generator Cost: NG - 127.39 25.336 0.089 -> 0 30.8057046126 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 31.6095751339 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 44.6455519937 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 109.164765908 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 39.074394666 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 118.429683328 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 40.3234465332 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 117.849625858 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 32.6445913317 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 110.96720512 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 120.427668303 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.056994776 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 27.416529401 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 31.9488065518 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 26.0886653922 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 26.553809362 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 102.525197631 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 101.955615969 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 23.1018493537 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 103.850454384 0
% INFO    : Updated Generator Cost: COW - 2115.32 12.513 0.001 -> 0 4.12620409798 0
% INFO    : Updated Generator Cost: COW - 2113.0 12.513 0.001 -> 0 28.1261574428 0
% INFO    : Updated Generator Cost: NUC - 1322.44 12.513 0.002 -> 0 7.41548858968 0
% INFO    : Updated Generator Cost: COW - 1322.44 12.513 0.002 -> 0 26.566398131 0
% INFO    : Updated Generator Cost: COW - 1323.84 12.513 0.002 -> 0 16.6676010664 0
% INFO    : Updated Generator Cost: COW - 1323.84 12.513 0.002 -> 0 25.431071587 0
% INFO    : Updated Generator Cost: COW - 1066.56 13.006 0.002 -> 0 26.8834561344 0
% INFO    : Updated Generator Cost: COW - 1066.56 13.006 0.002 -> 0 22.7084798624 0
% INFO    : Updated Generator Cost: COW - 1066.56 13.006 0.002 -> 0 35.7831836716 0
% INFO    : Updated Generator Cost: COW - 1068.84 12.999 0.002 -> 0 22.4204066541 0
% INFO    : Updated Generator Cost: COW - 1068.84 12.999 0.002 -> 0 37.1552512753 0
% INFO    : Updated Generator Cost: COW - 874.59 13.327 0.002 -> 0 36.6315521296 0
% INFO    : Updated Generator Cost: COW - 874.59 13.327 0.002 -> 0 33.8029228562 0
% INFO    : Updated Generator Cost: NG - 778.5 13.255 0.002 -> 0 41.043239849 0
% INFO    : Updated Generator Cost: NG - 866.34 13.313 0.002 -> 0 51.1385313161 0
% INFO    : Updated Generator Cost: COW - 866.34 13.313 0.002 -> 0 27.6824011697 0
% INFO    : Updated Generator Cost: NG - 409.64 13.723 0.006 -> 0 26.3396905601 0
% INFO    : Updated Generator Cost: NG - 409.64 13.723 0.006 -> 0 33.677950498 0
% INFO    : Updated Generator Cost: NG - 409.64 13.723 0.006 -> 0 31.2306440409 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 26.9700951166 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 32.3279510002 0
% INFO    : Updated Generator Cost: NG - 276.73 14.342 0.009 -> 0 30.0424851299 0
% INFO    : Updated Generator Cost: NG - 276.73 14.342 0.009 -> 0 35.5689052746 0
% INFO    : Updated Generator Cost: NG - 276.73 14.342 0.009 -> 0 20.4770721548 0
% INFO    : Updated Generator Cost: NG - 276.73 14.342 0.009 -> 0 50.4293689657 0
% INFO    : Updated Generator Cost: NG - 738.65 13.221 0.002 -> 0 36.5252054296 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 41.7634098461 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 37.0016646708 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 41.0910906147 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 35.7764964908 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 121.363109983 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 30.952939725 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 24.6043666481 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.9444801428 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 17.079962895 0
% INFO    : Updated Generator Cost: COW - 255.34 14.511 0.01 -> 0 21.3556188174 0
% INFO    : Updated Generator Cost: PEL - 138.01 15.575 0.022 -> 0 119.21107369 0
% INFO    : Updated Generator Cost: NG - 138.01 15.575 0.022 -> 0 17.8690911929 0
% INFO    : Updated Generator Cost: PEL - 134.13 15.635 0.022 -> 0 106.931833884 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 126.874167269 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 139.723238762 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 35.7564513726 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 102.8987195 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 104.13271967 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 89.1243678202 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.9926361781 0
% INFO    : Updated Generator Cost: COW - 304.2 14.135 0.008 -> 0 37.0030859002 0
% INFO    : Updated Generator Cost: NG - 104.5 15.982 0.03 -> 0 36.4292810385 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.0937979107 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.1313386066 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.0512144408 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 109.753621308 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 48.1203405935 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 119.809312357 0
% INFO    : Updated Generator Cost: COW - 2114.9 12.513 0.001 -> 0 17.4121801048 0
% INFO    : Updated Generator Cost: COW - 2114.9 12.513 0.001 -> 0 22.9228615436 0
% INFO    : Updated Generator Cost: COW - 1047.4 13.037 0.002 -> 0 26.0103962321 0
% INFO    : Updated Generator Cost: COW - 1047.4 13.037 0.002 -> 0 25.8595458805 0
% INFO    : Updated Generator Cost: NG - 1047.4 13.037 0.002 -> 0 18.2335394207 0
% INFO    : Updated Generator Cost: COW - 1047.4 13.037 0.002 -> 0 14.979081752 0
% INFO    : Updated Generator Cost: COW - 1047.4 13.037 0.002 -> 0 15.2498378519 0
% INFO    : Updated Generator Cost: NG - 226.45 24.825 0.034 -> 0 28.508612941 0
% INFO    : Updated Generator Cost: NG - 226.45 24.825 0.034 -> 0 30.2559041247 0
% INFO    : Updated Generator Cost: NG - 813.68 13.277 0.002 -> 0 23.6961916171 0
% INFO    : Updated Generator Cost: COW - 815.22 13.279 0.002 -> 0 38.88064902 0
% INFO    : Updated Generator Cost: COW - 815.22 13.279 0.002 -> 0 20.8437398598 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 31.3154982931 0
% INFO    : Updated Generator Cost: PEL - 803.2 13.269 0.002 -> 0 113.178016144 0
% INFO    : Updated Generator Cost: COW - 803.2 13.269 0.002 -> 0 30.531056064 0
% INFO    : Updated Generator Cost: COW - 1052.2 13.035 0.002 -> 0 22.4435971025 0
% INFO    : Updated Generator Cost: PEL - 1052.2 13.035 0.002 -> 0 97.7772464302 0
% INFO    : Updated Generator Cost: NG - 463.61 13.538 0.005 -> 0 39.5477990485 0
% INFO    : Updated Generator Cost: COW - 781.99 13.256 0.002 -> 0 25.7222176085 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 64.7761131166 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 23.0689028886 0
% INFO    : Updated Generator Cost: NG - 445.01 13.588 0.005 -> 0 29.8038759299 0
% INFO    : Updated Generator Cost: NG - 445.01 13.588 0.005 -> 0 43.5994333315 0
% INFO    : Updated Generator Cost: NG - 385.35 13.811 0.006 -> 0 38.5679143252 0
% INFO    : Updated Generator Cost: COW - 385.35 13.811 0.006 -> 0 15.6097011847 0
% INFO    : Updated Generator Cost: NG - 385.35 13.811 0.006 -> 0 24.3486600407 0
% INFO    : Updated Generator Cost: NG - 385.35 13.811 0.006 -> 0 53.6022167906 0
% INFO    : Updated Generator Cost: NG - 385.35 13.811 0.006 -> 0 29.7485847357 0
% INFO    : Updated Generator Cost: NG - 385.35 13.811 0.006 -> 0 37.8234114967 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 38.9808336631 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 52.5315357659 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 16.0174980162 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 47.5472102561 0
% INFO    : Updated Generator Cost: NG - 355.3 13.961 0.007 -> 0 47.4972184862 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.8485614072 0
% INFO    : Updated Generator Cost: COW - 631.77 13.138 0.003 -> 0 21.0716130953 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 35.3732617148 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 24.0704468147 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 21.1045404129 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 29.1452302451 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 22.6761389133 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 41.5611555727 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 39.9195132896 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 27.0292441017 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 51.5722733921 0
% INFO    : Updated Generator Cost: NG - 188.18 14.92 0.014 -> 0 38.0068406364 0
% INFO    : Updated Generator Cost: NG - 1586.4 77.147 0.046 -> 0 45.6963583281 0
% INFO    : Updated Generator Cost: PEL - 1586.4 77.147 0.046 -> 0 108.436418322 0
% INFO    : Updated Generator Cost: COW - 696.71 13.196 0.003 -> 0 16.3674773455 0
% INFO    : Updated Generator Cost: NG - 188.18 14.92 0.014 -> 0 36.6813311062 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 35.993455401 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 44.180145525 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 15.7001577151 0
% INFO    : Updated Generator Cost: NG - 1586.4 77.147 0.046 -> 0 41.5229702238 0
% INFO    : Updated Generator Cost: NG - 1586.4 77.147 0.046 -> 0 28.578403519 0
% INFO    : Updated Generator Cost: NG - 1586.4 77.147 0.046 -> 0 22.233122583 0
% INFO    : Updated Generator Cost: PEL - 1586.4 77.147 0.046 -> 0 117.849821291 0
% INFO    : Updated Generator Cost: NG - 307.36 14.135 0.008 -> 0 23.6302173433 0
% INFO    : Updated Generator Cost: NG - 307.36 14.135 0.008 -> 0 34.1046734636 0
% INFO    : Updated Generator Cost: NG - 307.36 14.135 0.008 -> 0 28.3797250292 0
% INFO    : Updated Generator Cost: COW - 512.16 13.397 0.004 -> 0 27.3719948514 0
% INFO    : Updated Generator Cost: NG - 468.14 22.68 0.013 -> 0 17.3080427738 0
% INFO    : Updated Generator Cost: NG - 276.67 14.342 0.009 -> 0 19.0885993625 0
% INFO    : Updated Generator Cost: NG - 276.67 14.342 0.009 -> 0 38.2740794924 0
% INFO    : Updated Generator Cost: NG - 382.2 13.813 0.006 -> 0 46.9061335154 0
% INFO    : Updated Generator Cost: COW - 887.35 13.329 0.002 -> 0 17.5237093705 0
% INFO    : Updated Generator Cost: NG - 175.85 25.435 0.047 -> 0 34.6694378976 0
% INFO    : Updated Generator Cost: NG - 442.95 22.845 0.014 -> 0 19.7152827247 0
% INFO    : Updated Generator Cost: NG - 442.95 22.845 0.014 -> 0 18.2848027374 0
% INFO    : Updated Generator Cost: PEL - 442.95 22.845 0.014 -> 0 115.544882739 0
% INFO    : Updated Generator Cost: NG - 442.95 22.845 0.014 -> 0 24.3655623933 0
% INFO    : Updated Generator Cost: NG - 442.95 22.845 0.014 -> 0 21.5951500896 0
% INFO    : Updated Generator Cost: NG - 130.87 25.545 0.063 -> 0 33.0799889062 0
% INFO    : Updated Generator Cost: PEL - 111.24 25.545 0.074 -> 0 123.622337388 0
% INFO    : Updated Generator Cost: NG - 271.89 14.376 0.009 -> 0 47.0985739592 0
% INFO    : Updated Generator Cost: COW - 271.89 14.376 0.009 -> 0 16.5572163959 0
% INFO    : Updated Generator Cost: COW - 271.89 14.376 0.009 -> 0 36.0951748692 0
% INFO    : Updated Generator Cost: NG - 271.89 14.376 0.009 -> 0 20.1341681782 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 7.15589334694 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 29.4897608541 0
% INFO    : Updated Generator Cost: PEL - 404.83 23.121 0.016 -> 0 106.716943094 0
% INFO    : Updated Generator Cost: NG - 239.21 14.595 0.011 -> 0 17.4995494754 0
% INFO    : Updated Generator Cost: NG - 242.12 14.594 0.011 -> 0 36.8794991124 0
% INFO    : Updated Generator Cost: NG - 242.12 14.594 0.011 -> 0 39.2227878145 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 39.634018744 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 28.9224619419 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 45.9592330033 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 28.5120218919 0
% INFO    : Updated Generator Cost: NG - 233.21 14.645 0.011 -> 0 38.6670846156 0
% INFO    : Updated Generator Cost: COW - 229.96 14.658 0.011 -> 0 34.1036159718 0
% INFO    : Updated Generator Cost: NG - 208.07 14.813 0.013 -> 0 36.269639937 0
% INFO    : Updated Generator Cost: PEL - 208.07 14.813 0.013 -> 0 106.35268508 0
% INFO    : Updated Generator Cost: NG - 208.07 14.813 0.013 -> 0 37.0216169105 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 25.2312261679 0
% INFO    : Updated Generator Cost: NG - 584.57 13.172 0.004 -> 0 15.5993985472 0
% INFO    : Updated Generator Cost: NG - 195.25 14.886 0.014 -> 0 18.3483576461 0
% INFO    : Updated Generator Cost: COW - 442.21 13.597 0.005 -> 0 13.5199548921 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 32.1775933929 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 23.4636072955 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 42.4560082554 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 44.8970372125 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 40.3233772514 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 51.8550646641 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 42.5074301858 0
% INFO    : Updated Generator Cost: NG - 176.37 15.07 0.019 -> 0 36.6628462286 0
% INFO    : Updated Generator Cost: NG - 277.16 24.168 0.026 -> 0 20.1139124738 0
% INFO    : Updated Generator Cost: NG - 94.88 25.545 0.087 -> 0 27.3340900271 0
% INFO    : Updated Generator Cost: NG - 271.68 24.223 0.027 -> 0 35.236301014 0
% INFO    : Updated Generator Cost: NG - 271.68 24.223 0.027 -> 0 30.3739940418 0
% INFO    : Updated Generator Cost: COW - 271.68 24.223 0.027 -> 0 15.5115582117 0
% INFO    : Updated Generator Cost: PEL - 271.68 24.223 0.027 -> 0 130.330480058 0
% INFO    : Updated Generator Cost: NG - 271.68 24.223 0.027 -> 0 52.3244847461 0
% INFO    : Updated Generator Cost: NG - 271.68 24.223 0.027 -> 0 38.9054254661 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 25.9439533954 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 24.533200868 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 49.6052828327 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 36.4531144712 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 22.8892217021 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 31.0704864096 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 118.87777477 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 46.5122736064 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 15.9819979812 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 17.293054279 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 20.837088889 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 65.6514841639 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 109.940420802 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 35.9134097957 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 37.0175233876 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 123.291436708 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 116.308968525 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 99.2808229777 0
% INFO    : Updated Generator Cost: COW - 51.34 14.879 0.053 -> 0 30.0646118467 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 34.602728768 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 40.8042803853 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 39.9796706309 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 39.1703401771 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 26.9910292052 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.0622613937 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 40.1678174694 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 26.2638635274 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 37.8274359556 0
% INFO    : Updated Generator Cost: NG - 163.59 25.545 0.051 -> 0 27.272357678 0
% INFO    : Updated Generator Cost: NG - 203.1 25.105 0.039 -> 0 36.7686844784 0
% INFO    : Updated Generator Cost: NG - 199.51 25.16 0.04 -> 0 59.6585258415 0
% INFO    : Updated Generator Cost: NG - 102.29 16.003 0.03 -> 0 34.1001904895 0
% INFO    : Updated Generator Cost: PEL - 211.58 14.778 0.013 -> 0 120.198743854 0
% INFO    : Updated Generator Cost: NG - 135.81 15.601 0.022 -> 0 23.2127170163 0
% INFO    : Updated Generator Cost: NG - 135.81 15.601 0.022 -> 0 42.7389570603 0
% INFO    : Updated Generator Cost: NG - 507.3 87.0 0.18 -> 0 16.5070678816 0
% INFO    : Updated Generator Cost: PEL - 507.3 87.0 0.18 -> 0 124.433715768 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 49.9518084424 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 35.5558746445 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 22.1321701422 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 24.5698507865 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 16.3403037945 0
% INFO    : Updated Generator Cost: PEL - 84.87 16.01 0.036 -> 0 90.8267051749 0
% INFO    : Updated Generator Cost: PEL - 137.47 15.587 0.022 -> 0 102.782034064 0
% INFO    : Updated Generator Cost: PEL - 372.94 87.0 0.246 -> 0 105.547160595 0
% INFO    : Updated Generator Cost: NG - 122.03 15.78 0.025 -> 0 29.2198616254 0
% INFO    : Updated Generator Cost: PEL - 66.83 16.01 0.045 -> 0 97.5786098302 0
% INFO    : Updated Generator Cost: NG - 135.16 25.309 0.085 -> 0 38.1685973519 0
% INFO    : Updated Generator Cost: NG - 51.08 16.01 0.061 -> 0 34.2719992838 0
% INFO    : Updated Generator Cost: PEL - 50.49 16.01 0.062 -> 0 103.545787074 0
% INFO    : Updated Generator Cost: PEL - 50.49 16.01 0.062 -> 0 117.983647028 0
% INFO    : Updated Generator Cost: NG - 83.38 25.478 0.114 -> 0 28.9720928973 0
% INFO    : Updated Generator Cost: NG - 83.38 25.478 0.114 -> 0 20.1354307248 0
% INFO    : Updated Generator Cost: NG - 83.38 25.478 0.114 -> 0 29.6299589245 0
% INFO    : Updated Generator Cost: NG - 83.38 25.478 0.114 -> 0 39.7144577707 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 41.3213970744 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 38.1576116231 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 98.5003189397 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 27.673496369 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 28.750620315 0
% INFO    : Updated Generator Cost: COW - 5647.54 15.698 0.002 -> 0 33.7672242237 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 36.8359402794 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 20.7876047198 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 38.6693672887 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 18.211393854 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 38.7081009883 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 25.508071513 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 26.2599430201 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 18.8104062114 0
% INFO    : Updated Generator Cost: COW - 5647.54 15.698 0.002 -> 0 10.6775146807 0
% INFO    : Updated Generator Cost: COW - 5647.54 15.698 0.002 -> 0 28.8080548156 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 42.1588827597 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 47.6341538708 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.715643228 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 0.101581145099 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 48.7915380061 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 32.247329769 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 16.6153479173 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 23.6907414798 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 27.2706751043 0
% INFO    : Updated Generator Cost: COW - 1094.5 12.935 0.002 -> 0 20.3028355744 0
% INFO    : Updated Generator Cost: COW - 1094.5 12.935 0.002 -> 0 18.5694020007 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 45.1397793049 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 120.987339131 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 23.7807248562 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 30.1547524619 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 28.4272916211 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 42.3467111581 0
% INFO    : Updated Generator Cost: COW - 303.56 14.879 0.009 -> 0 28.3302522087 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 44.7803656506 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 32.4515628596 0
% INFO    : Updated Generator Cost: NG - 473.56 13.503 0.005 -> 0 34.2164470475 0
% INFO    : Updated Generator Cost: NG - 741.26 21.527 0.008 -> 0 25.2034222481 0
% INFO    : Updated Generator Cost: NG - 554.22 13.27 0.004 -> 0 30.9097197993 0
% INFO    : Updated Generator Cost: COW - 1488.7 12.513 0.002 -> 0 9.68282244725 0
% INFO    : Updated Generator Cost: NG - 444.79 13.596 0.005 -> 0 29.7580059533 0
% INFO    : Updated Generator Cost: NG - 576.64 13.196 0.004 -> 0 36.1048761748 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 9.89711517104 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 31.3005020904 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 37.788857896 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 37.7753061483 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 11.7714498697 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 53.556952 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 107.244351866 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 41.1334021505 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 108.177504673 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 21.4077527778 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 121.852591633 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.9624410095 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 48.8355333105 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 104.146098706 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 112.231745701 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 118.76531547 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 38.647033503 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 39.9027042583 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 22.8076431621 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 22.1003324735 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 19.4458123619 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 47.8204464039 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 51.3554162892 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 33.9088152839 0
% INFO    : Updated Generator Cost: NG - 669.8 21.727 0.009 -> 0 32.2965229351 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 40.9566682881 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 52.6397647941 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 32.6935466487 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 26.9824363682 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 32.9051617187 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 34.1630514133 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 32.842687207 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 55.2354966748 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 47.4910933617 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 113.690223162 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 34.4866682024 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 27.9227789524 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 23.9552990914 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 46.9027276355 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 48.0192725683 0
% INFO    : Updated Generator Cost: NG - 283.22 14.307 0.009 -> 0 29.9999181944 0
% INFO    : Updated Generator Cost: NG - 283.22 14.307 0.009 -> 0 52.7380377809 0
% INFO    : Updated Generator Cost: NG - 278.48 14.342 0.009 -> 0 50.5063430794 0
% INFO    : Updated Generator Cost: COW - 251.02 14.522 0.01 -> 0 19.4453549509 0
% INFO    : Updated Generator Cost: COW - 251.02 14.522 0.01 -> 0 10.6456561837 0
% INFO    : Updated Generator Cost: PEL - 251.02 14.522 0.01 -> 0 110.547197583 0
% INFO    : Updated Generator Cost: COW - 251.02 14.522 0.01 -> 0 23.733880613 0
% INFO    : Updated Generator Cost: COW - 1734.8 20.549 0.003 -> 0 24.7809706532 0
% INFO    : Updated Generator Cost: COW - 1898.45 20.18 0.003 -> 0 40.8668146957 0
% INFO    : Updated Generator Cost: NG - 224.01 14.708 0.012 -> 0 49.7407991345 0
% INFO    : Updated Generator Cost: NG - 221.98 14.713 0.012 -> 0 45.5583429881 0
% INFO    : Updated Generator Cost: COW - 221.98 14.713 0.012 -> 0 31.7288893779 0
% INFO    : Updated Generator Cost: NG - 810.8 13.27 0.002 -> 0 40.9888590412 0
% INFO    : Updated Generator Cost: COW - 243.67 14.561 0.011 -> 0 12.589045018 0
% INFO    : Updated Generator Cost: NG - 200.42 14.852 0.013 -> 0 30.4151561586 0
% INFO    : Updated Generator Cost: NG - 200.42 14.852 0.013 -> 0 35.9792079201 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 28.2545549994 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 30.2628348145 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 43.9074811405 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 122.364896128 0
% INFO    : Updated Generator Cost: COW - 2091.8 19.79 0.003 -> 0 23.4853868565 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 48.8580276094 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 28.3542581379 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 18.7564153488 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 24.9281188542 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 35.1211482732 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 22.3467197642 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 112.114916773 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 41.512871176 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 102.837802666 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 32.1414640732 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 28.7237723329 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 46.7310587067 0
% INFO    : Updated Generator Cost: PEL - 149.28 15.433 0.02 -> 0 119.739664289 0
% INFO    : Updated Generator Cost: COW - 149.28 15.433 0.02 -> 0 32.9802960345 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 37.23673151 0
% INFO    : Updated Generator Cost: COW - 1952.1 59.305 0.01 -> 0 20.4111674548 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 92.4881050104 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 43.1267977049 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 118.628059606 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 17.9564017987 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 40.0540521969 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 20.6289058813 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 15.7361822279 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 36.6456321965 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 120.552129975 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 129.232703198 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.5714083859 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 47.7082709371 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 118.076965643 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 45.0859098014 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 122.731717381 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 101.705528466 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 22.0878191679 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 114.512871816 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 41.1161386672 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 44.6434358187 0
% INFO    : Updated Generator Cost: NG - 113.74 15.878 0.027 -> 0 50.1216038916 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 59.495424893 0
% INFO    : Updated Generator Cost: NG - 95.4 16.01 0.032 -> 0 42.87009247 0
% INFO    : Updated Generator Cost: PEL - 95.4 16.01 0.032 -> 0 102.77475772 0
% INFO    : Updated Generator Cost: NG - 95.4 16.01 0.032 -> 0 30.2014583988 0
% INFO    : Updated Generator Cost: NG - 95.4 16.01 0.032 -> 0 28.4948354991 0
% INFO    : Updated Generator Cost: NG - 95.4 16.01 0.032 -> 0 39.7629462877 0
% INFO    : Updated Generator Cost: NG - 153.01 15.391 0.019 -> 0 32.1290656869 0
% INFO    : Updated Generator Cost: NG - 153.01 15.391 0.019 -> 0 58.8847188011 0
% INFO    : Updated Generator Cost: NG - 153.01 15.391 0.019 -> 0 32.5245024163 0
% INFO    : Updated Generator Cost: NG - 88.48 16.01 0.035 -> 0 30.6346560777 0
% INFO    : Updated Generator Cost: NG - 88.48 16.01 0.035 -> 0 32.7064018795 0
% INFO    : Updated Generator Cost: NG - 95.26 16.01 0.033 -> 0 31.7023657582 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 42.805152299 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.303124306 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 28.274224366 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 32.2742203426 0
% INFO    : Updated Generator Cost: NG - 172.09 34.988 0.086 -> 0 46.0750983015 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 30.8231353769 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 33.2715372312 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 35.7913582516 0
% INFO    : Updated Generator Cost: PEL - 165.54 34.988 0.088 -> 0 105.989857923 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 40.0137429753 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 26.3387198656 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 25.4496535011 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.1194865124 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 52.3163844279 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 43.5983119157 0
% INFO    : Updated Generator Cost: NG - 122.66 34.988 0.118 -> 0 34.1460680594 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 41.1526205135 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 40.6126737043 0
% INFO    : Updated Generator Cost: COW - 78.78 26.977 0.114 -> 0 31.458222422 0
% INFO    : Updated Generator Cost: COW - 78.78 26.977 0.114 -> 0 28.8610427937 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 106.537388092 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 57.3456782979 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 51.7743676204 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 17.4541199867 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 43.5956101264 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 32.8922082829 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 108.709616371 0
% INFO    : Updated Generator Cost: COW - 78.78 26.977 0.114 -> 0 20.8278947819 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 16.7617042142 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 19.5831438161 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.1989319438 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 114.541853573 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 101.536341269 0
% INFO    : Updated Generator Cost: NG - 49.51 16.01 0.065 -> 0 36.170205311 0
% INFO    : Updated Generator Cost: NG - 49.51 16.01 0.065 -> 0 41.8973409166 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 101.443074712 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 31.4034132675 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 25.4081642973 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 121.434961134 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 102.199797847 0
% INFO    : Updated Generator Cost: COW - 128.6 26.977 0.07 -> 0 29.8041681734 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 110.728859822 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 118.588673954 0
% INFO    : Updated Generator Cost: PEL - 43.36 16.01 0.072 -> 0 96.5292450193 0
% INFO    : Updated Generator Cost: NG - 58.58 16.01 0.053 -> 0 35.3894682588 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 101.402927776 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 111.269522042 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 45.8013871643 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 23.0379040102 0
% INFO    : Updated Generator Cost: PEL - 69.93 25.535 0.123 -> 0 81.4360429307 0
% INFO    : Updated Generator Cost: NG - 69.93 25.535 0.123 -> 0 32.3322491219 0
% INFO    : Updated Generator Cost: PEL - 69.93 25.535 0.123 -> 0 110.9274913 0
% INFO    : Updated Generator Cost: PEL - 89.96 34.988 0.167 -> 0 106.773860969 0
% INFO    : Updated Generator Cost: COW - 2314.9 12.513 0.001 -> 0 30.7455580181 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 32.196987798 0
% INFO    : Updated Generator Cost: NUC - 2116.4 12.513 0.001 -> 0 6.34697351878 0
% INFO    : Updated Generator Cost: COW - 2116.4 12.513 0.001 -> 0 28.2659148306 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 28.586306843 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 39.2781999933 0
% INFO    : Updated Generator Cost: COW - 1039.68 13.054 0.002 -> 0 34.8169360215 0
% INFO    : Updated Generator Cost: NG - 1005.53 13.133 0.002 -> 0 30.4317973554 0
% INFO    : Updated Generator Cost: NG - 941.59 13.286 0.002 -> 0 38.7034053779 0
% INFO    : Updated Generator Cost: COW - 941.59 13.286 0.002 -> 0 17.8853408165 0
% INFO    : Updated Generator Cost: COW - 933.8 13.317 0.002 -> 0 22.2092042872 0
% INFO    : Updated Generator Cost: COW - 933.8 13.317 0.002 -> 0 20.2206143902 0
% INFO    : Updated Generator Cost: COW - 933.8 13.317 0.002 -> 0 26.6603420545 0
% INFO    : Updated Generator Cost: COW - 933.8 13.317 0.002 -> 0 36.6593662065 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 18.7744112507 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 36.7344699555 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 53.8459054132 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 36.2974636869 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 33.3844450821 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 36.5946382261 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 32.6217455841 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 32.695541601 0
% INFO    : Updated Generator Cost: NG - 419.6 13.669 0.006 -> 0 39.8168402962 0
% INFO    : Updated Generator Cost: NG - 397.44 13.758 0.006 -> 0 28.0625996722 0
% INFO    : Updated Generator Cost: NG - 397.44 13.758 0.006 -> 0 28.4307806875 0
% INFO    : Updated Generator Cost: NG - 404.83 13.738 0.006 -> 0 33.1590773652 0
% INFO    : Updated Generator Cost: NG - 404.83 13.738 0.006 -> 0 35.2495489595 0
% INFO    : Updated Generator Cost: NG - 942.0 13.283 0.002 -> 0 25.8705163119 0
% INFO    : Updated Generator Cost: NG - 390.61 13.799 0.006 -> 0 23.0037213621 0
% INFO    : Updated Generator Cost: COW - 390.61 13.799 0.006 -> 0 33.6486101429 0
% INFO    : Updated Generator Cost: NG - 390.61 13.799 0.006 -> 0 14.7870270144 0
% INFO    : Updated Generator Cost: NG - 390.61 13.799 0.006 -> 0 24.336808114 0
% INFO    : Updated Generator Cost: COW - 390.61 13.799 0.006 -> 0 11.7885703585 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 29.2748681953 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 48.6198047021 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 44.4070637881 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 36.0430317185 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 36.7330026575 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 30.3267555625 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 32.8391880665 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 33.4480268036 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 46.789480309 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 18.2614927123 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 27.2055548609 0
% INFO    : Updated Generator Cost: NG - 356.39 13.959 0.007 -> 0 29.0538942589 0
% INFO    : Updated Generator Cost: NG - 356.39 13.959 0.007 -> 0 31.3553468432 0
% INFO    : Updated Generator Cost: NG - 356.39 13.959 0.007 -> 0 25.4437180442 0
% INFO    : Updated Generator Cost: NG - 356.39 13.959 0.007 -> 0 52.8798323857 0
% INFO    : Updated Generator Cost: NUC - 1062.57 13.009 0.002 -> 0 7.25657856091 0
% INFO    : Updated Generator Cost: COW - 1062.57 13.009 0.002 -> 0 18.7199825489 0
% INFO    : Updated Generator Cost: COW - 528.49 13.352 0.004 -> 0 14.5941587429 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 27.3525273627 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 22.311825768 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 24.9279445809 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 31.9388008614 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 20.890952436 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 13.2887248759 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 42.2082693687 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 21.4844393517 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 24.2453595724 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 11.528579157 0
% INFO    : Updated Generator Cost: PEL - 2249.86 9.547 0.032 -> 0 106.685405577 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 25.6448971018 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 4.18465553387 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 46.7737231254 0
% INFO    : Updated Generator Cost: COW - 284.21 14.265 0.009 -> 0 21.726214511 0
% INFO    : Updated Generator Cost: COW - 1345.25 12.513 0.002 -> 0 21.9708068326 0
% INFO    : Updated Generator Cost: COW - 666.38 13.169 0.003 -> 0 29.656011542 0
% INFO    : Updated Generator Cost: COW - 666.38 13.169 0.003 -> 0 32.9176934683 0
% INFO    : Updated Generator Cost: NG - 259.52 14.452 0.01 -> 0 34.7557626475 0
% INFO    : Updated Generator Cost: NG - 259.52 14.452 0.01 -> 0 24.9069021398 0
% INFO    : Updated Generator Cost: NG - 396.44 13.768 0.006 -> 0 39.2732453596 0
% INFO    : Updated Generator Cost: NG - 246.92 14.56 0.011 -> 0 21.1840222427 0
% INFO    : Updated Generator Cost: PEL - 246.92 14.56 0.011 -> 0 87.5443143508 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 42.6035819406 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 103.893405288 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 125.566939544 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 43.0194348073 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 41.4373883304 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 105.448155533 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 100.515698282 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 124.586380634 0
% INFO    : Updated Generator Cost: NG - 227.69 14.678 0.011 -> 0 33.022447855 0
% INFO    : Updated Generator Cost: NG - 227.69 14.678 0.011 -> 0 28.9095076596 0
% INFO    : Updated Generator Cost: NG - 378.4 13.832 0.006 -> 0 38.6210851509 0
% INFO    : Updated Generator Cost: NG - 227.69 14.678 0.011 -> 0 40.7042694486 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 48.4276648725 0
% INFO    : Updated Generator Cost: COW - 1062.4 13.009 0.002 -> 0 27.8015417481 0
% INFO    : Updated Generator Cost: NG - 298.04 14.143 0.008 -> 0 25.716785417 0
% INFO    : Updated Generator Cost: NG - 694.52 13.19 0.003 -> 0 19.9187536405 0
% INFO    : Updated Generator Cost: NG - 233.84 14.615 0.011 -> 0 38.8496068419 0
% INFO    : Updated Generator Cost: COW - 209.39 14.801 0.013 -> 0 0.709146163058 0
% INFO    : Updated Generator Cost: NG - 210.69 14.784 0.013 -> 0 20.0021744807 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.7762157922 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 14.4768429653 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 50.390166148 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 24.2910992824 0
% INFO    : Updated Generator Cost: COW - 416.32 13.683 0.006 -> 0 19.7945113236 0
% INFO    : Updated Generator Cost: NG - 200.27 14.852 0.013 -> 0 34.3053427017 0
% INFO    : Updated Generator Cost: NG - 281.17 14.312 0.009 -> 0 27.5912268242 0
% INFO    : Updated Generator Cost: NG - 281.17 14.312 0.009 -> 0 41.8518635034 0
% INFO    : Updated Generator Cost: NG - 191.54 14.904 0.014 -> 0 35.6111815426 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 20.5083308933 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.4275967123 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 27.066628034 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 25.5147127939 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.3082017849 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 54.6407024951 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 22.0954854296 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 9.9155325352 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 50.9338582064 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 32.5688631372 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.135928066 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 18.5268384538 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 14.4632883267 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 17.7068240095 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 14.7081845793 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 42.7541967434 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 125.65906102 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 8.0595094523 0
% INFO    : Updated Generator Cost: NG - 165.96 15.194 0.017 -> 0 30.3822501738 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 109.749923674 0
% INFO    : Updated Generator Cost: COW - 1062.2 13.009 0.002 -> 0 24.4171266023 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 43.5572396507 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 20.0281867833 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 29.9921647431 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.6959820286 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 19.9380875462 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 36.2791009567 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 30.8582966364 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 27.9222404132 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 35.9145251134 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 4.3647747113 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 106.426058189 0
% INFO    : Updated Generator Cost: PEL - 137.83 15.579 0.022 -> 0 99.8450134005 0
% INFO    : Updated Generator Cost: PEL - 137.83 15.579 0.022 -> 0 103.056697685 0
% INFO    : Updated Generator Cost: NG - 137.83 15.579 0.022 -> 0 32.3952860364 0
% INFO    : Updated Generator Cost: NG - 137.83 15.579 0.022 -> 0 29.4144568136 0
% INFO    : Updated Generator Cost: PEL - 137.83 15.579 0.022 -> 0 102.911108189 0
% INFO    : Updated Generator Cost: PEL - 137.83 15.579 0.022 -> 0 115.467053735 0
% INFO    : Updated Generator Cost: NG - 216.73 24.939 0.036 -> 0 25.6804677739 0
% INFO    : Updated Generator Cost: NG - 216.73 24.939 0.036 -> 0 37.5148132129 0
% INFO    : Updated Generator Cost: PEL - 216.73 24.939 0.036 -> 0 98.2963493943 0
% INFO    : Updated Generator Cost: NG - 216.73 24.939 0.036 -> 0 44.946118139 0
% INFO    : Updated Generator Cost: NG - 216.73 24.939 0.036 -> 0 35.7160745695 0
% INFO    : Updated Generator Cost: NG - 78.25 25.545 0.105 -> 0 20.3338946879 0
% INFO    : Updated Generator Cost: PEL - 210.86 24.994 0.037 -> 0 102.834312276 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 130.134799281 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 97.8270565021 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 21.5319324607 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 21.7127820752 0
% INFO    : Updated Generator Cost: NG - 301.15 14.14 0.008 -> 0 38.7943465957 0
% INFO    : Updated Generator Cost: NG - 843.83 13.302 0.002 -> 0 26.4171539157 0
% INFO    : Updated Generator Cost: COW - 844.56 13.302 0.002 -> 0 15.7583512568 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 32.5633105635 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 32.1698594122 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 114.845160632 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 132.044157768 0
% INFO    : Updated Generator Cost: NG - 45.9 16.01 0.069 -> 0 29.856801428 0
% INFO    : Updated Generator Cost: COW - 108.31 15.948 0.028 -> 0 24.3387705455 0
% INFO    : Updated Generator Cost: NG - 108.31 15.948 0.028 -> 0 29.6196095838 0
% INFO    : Updated Generator Cost: NG - 108.31 15.948 0.028 -> 0 31.8992361567 0
% INFO    : Updated Generator Cost: PEL - 108.31 15.948 0.028 -> 0 129.440615624 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 35.2625233762 0
% INFO    : Updated Generator Cost: NG - 74.74 16.01 0.042 -> 0 37.5867958547 0
% INFO    : Updated Generator Cost: NG - 74.74 16.01 0.042 -> 0 15.5710872222 0
% INFO    : Updated Generator Cost: PEL - 74.74 16.01 0.042 -> 0 94.834477594 0
% INFO    : Updated Generator Cost: NG - 74.74 16.01 0.042 -> 0 25.795427372 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.5738751666 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 49.8504504863 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 35.5529420096 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 102.142583443 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.8817057469 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 98.5711550372 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 17.8336132032 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 101.759109876 0
% INFO    : Updated Generator Cost: COW - 115.3 25.545 0.074 -> 0 35.9362915916 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 108.373865394 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 46.4230325231 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 32.5570530908 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 27.0634668039 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 32.7387824354 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 17.5068098682 0
% INFO    : Updated Generator Cost: NUC - 0.0 0.0 0.0 -> 0 7.49915533378 0
% INFO    : Updated Generator Cost: NG - 186.54 25.11 0.054 -> 0 44.6600252324 0
% INFO    : Updated Generator Cost: NG - 100.32 25.42 0.104 -> 0 29.8893717463 0
% INFO    : Updated Generator Cost: PEL - 54.74 16.01 0.056 -> 0 116.403169554 0
% INFO    : Updated Generator Cost: NG - 109.21 34.988 0.136 -> 0 24.7112138905 0
% INFO    : Updated Generator Cost: PEL - 141.8 34.988 0.109 -> 0 93.7335834174 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 38.0737247307 0
% INFO    : Updated Generator Cost: COW - 51.34 14.879 0.053 -> 0 31.4968114853 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.9876167648 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 47.2577522494 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 85.4142477056 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 109.667223404 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 20.6167803257 0
% INFO    : Updated Generator Cost: COW - 45.88 16.01 0.07 -> 0 29.9760288046 0
% INFO    : Updated Generator Cost: PEL - 51.45 16.01 0.061 -> 0 105.874160331 0
% INFO    : Updated Generator Cost: NG - 51.45 16.01 0.061 -> 0 17.8381118935 0
% INFO    : Updated Generator Cost: NG - 67.65 25.545 0.125 -> 0 43.8055694377 0
% INFO    : Updated Generator Cost: PEL - 67.65 25.545 0.125 -> 0 98.5406805194 0
% INFO    : Updated Generator Cost: NG - 67.65 25.545 0.125 -> 0 36.5756653369 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 116.238591191 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 31.5741177648 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 40.9503486512 0
% INFO    : Updated Generator Cost: COW - 1184.3 12.792 0.002 -> 0 24.1551310066 0
% INFO    : Updated Generator Cost: NG - 1184.3 12.792 0.002 -> 0 40.7101369151 0
% INFO    : Updated Generator Cost: COW - 1060.47 13.031 0.002 -> 0 26.4020724732 0
% INFO    : Updated Generator Cost: NG - 1060.47 13.031 0.002 -> 0 40.5307178712 0
% INFO    : Updated Generator Cost: COW - 1355.72 21.137 0.003 -> 0 25.0827141932 0
% INFO    : Updated Generator Cost: NG - 1355.72 21.137 0.003 -> 0 26.1784382353 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 25.6166974006 0
% INFO    : Updated Generator Cost: PEL - 714.75 13.203 0.003 -> 0 103.614331513 0
% INFO    : Updated Generator Cost: COW - 714.75 13.203 0.003 -> 0 20.2502430606 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 100.327191161 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 15.0152715536 0
% INFO    : Updated Generator Cost: COW - 668.77 13.173 0.003 -> 0 27.777269743 0
% INFO    : Updated Generator Cost: NG - 668.77 13.173 0.003 -> 0 33.1739561614 0
% INFO    : Updated Generator Cost: NG - 668.77 13.173 0.003 -> 0 49.950032519 0
% INFO    : Updated Generator Cost: PEL - 724.12 13.215 0.003 -> 0 107.983925298 0
% INFO    : Updated Generator Cost: COW - 1193.15 12.726 0.002 -> 0 25.9149764449 0
% INFO    : Updated Generator Cost: COW - 1193.15 12.726 0.002 -> 0 14.4583529652 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 22.3586327868 0
% INFO    : Updated Generator Cost: NG - 660.71 13.165 0.003 -> 0 33.3884330051 0
% INFO    : Updated Generator Cost: NG - 784.35 13.262 0.002 -> 0 39.9259795864 0
% INFO    : Updated Generator Cost: COW - 3251.3 71.187 0.019 -> 0 14.3372907512 0
% INFO    : Updated Generator Cost: NG - 3251.3 71.187 0.019 -> 0 22.7506299217 0
% INFO    : Updated Generator Cost: COW - 372.47 23.332 0.018 -> 0 25.6385870798 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 112.816149867 0
% INFO    : Updated Generator Cost: NG - 313.88 23.727 0.022 -> 0 35.9891822166 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 25.5543265791 0
% INFO    : Updated Generator Cost: NG - 559.29 13.252 0.004 -> 0 7.31374951855 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 19.132663674 0
% INFO    : Updated Generator Cost: NG - 2716.1 72.799 0.024 -> 0 28.583809829 0
% INFO    : Updated Generator Cost: NG - 2716.1 72.799 0.024 -> 0 54.2185227566 0
% INFO    : Updated Generator Cost: COW - 2130.63 13.659 0.009 -> 0 28.753912797 0
% INFO    : Updated Generator Cost: COW - 2130.63 13.659 0.009 -> 0 21.4590971196 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 27.4777467573 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 14.5770027052 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 35.8646774686 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 21.2110758584 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 42.2050283208 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 30.1101459763 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 31.6113283009 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 28.3057366775 0
% INFO    : Updated Generator Cost: COW - 1755.23 50.578 0.008 -> 0 25.1566270292 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 47.6572025289 0
% INFO    : Updated Generator Cost: NG - 1357.4 21.151 0.003 -> 0 49.934431307 0
% INFO    : Updated Generator Cost: NG - 481.81 13.478 0.005 -> 0 25.001151448 0
% INFO    : Updated Generator Cost: NG - 481.81 13.478 0.005 -> 0 36.7666636424 0
% INFO    : Updated Generator Cost: NG - 472.62 13.507 0.005 -> 0 29.3377186724 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 31.3069738641 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 128.403109835 0
% INFO    : Updated Generator Cost: NG - 240.73 24.638 0.032 -> 0 28.1763879295 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 42.2409318772 0
% INFO    : Updated Generator Cost: NG - 416.45 13.676 0.006 -> 0 40.7326838396 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.4077566777 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 29.1029591791 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 46.0879229984 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 28.1983853007 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 35.1530773357 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.2277937618 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 44.5595610539 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.2969109684 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 46.9644016094 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 27.7776700538 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.9143059168 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 35.7277568128 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 42.0081820232 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 48.2182300501 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 37.1380614742 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 26.7524571482 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 37.8759710977 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 47.7850160993 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 26.3909475046 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 31.4891572392 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 36.6051627719 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.9355602244 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 136.350267738 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 31.2581395455 0
% INFO    : Updated Generator Cost: NG - 240.75 24.637 0.032 -> 0 33.776533274 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 22.7576942128 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.6136746769 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 8.96401652758 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 33.2726445863 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 26.7820007257 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 23.5811419972 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 15.7966998465 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 9.77405399054 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 47.8030468928 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 57.2023679784 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 19.5153852202 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 26.3595984263 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 15.0915683572 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 35.3178653693 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 12.3781365456 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 28.7573299789 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 16.8172541091 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 44.7277881818 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 113.575987263 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 52.0106965171 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 11.7451185953 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 43.2163019342 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 45.3933626309 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 60.5182451795 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 25.8580608897 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 30.4108979929 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 36.3384241634 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.336831235 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 33.4205021297 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 38.0906127694 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 20.1356302861 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 37.3513299417 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 42.3924614553 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 20.6490834839 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.8688686572 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 44.9115637069 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 39.358079227 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 33.6125228424 0
% INFO    : Updated Generator Cost: COW - 2130.63 13.659 0.009 -> 0 22.3692415407 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.2428177865 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 37.4085983988 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 37.8350238429 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 47.7928441066 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 46.6722935141 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 35.3052068109 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 22.1801241207 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 20.9111000808 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 44.8195706638 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 42.3288497831 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 28.0070501647 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 36.0547484977 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 16.0455833588 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 28.3503575557 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 39.2830617674 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 62.6579855811 0
% INFO    : Updated Generator Cost: NG - 1535.5 77.526 0.048 -> 0 37.9953436005 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 48.6388898913 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 32.7040688762 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 21.6123565869 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 53.4520566579 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 51.0110952913 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 37.6068785336 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 37.2982197456 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.026828489 0
% INFO    : Updated Generator Cost: COW - 7585.1 67.576 0.009 -> 0 20.4334715601 0
% INFO    : Updated Generator Cost: COW - 7585.1 67.576 0.009 -> 0 38.7800201159 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 11.5674248146 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 43.4635518721 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 29.748031539 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 45.9245712008 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 28.9283731892 0
% INFO    : Updated Generator Cost: COW - 8226.7 67.58 0.008 -> 0 18.5140378654 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 36.4743236745 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 27.6820851185 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 30.0176853061 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 45.9283714983 0
% INFO    : Updated Generator Cost: COW - 8226.7 67.576 0.008 -> 0 13.3171185874 0
% INFO    : Updated Generator Cost: COW - 2130.63 13.659 0.009 -> 0 31.2453231155 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 25.7389803053 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 25.2058997733 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 12.9587727377 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 38.7694778951 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 22.9451219215 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.0140178623 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 17.501778896 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 24.8981288293 0
% INFO    : Updated Generator Cost: COW - 2130.63 13.659 0.009 -> 0 22.4071986875 0
% INFO    : Updated Generator Cost: NG - 3361.43 71.221 0.018 -> 0 31.7662347393 0
% INFO    : Updated Generator Cost: COW - 3361.43 71.221 0.018 -> 0 33.0120793822 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.8334521 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 22.0062632778 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 32.8252144948 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 20.1244393789 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.7693800015 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.3353910695 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 25.6115094435 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.4379221588 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 42.6491943414 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 27.6025308539 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 37.3991768806 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.397751554 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 121.572126297 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.6568893303 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 88.2297099502 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 115.267316652 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 118.800618244 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 31.1760281665 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 48.0519404267 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 102.006396662 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 16.4760734422 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 31.3153670323 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 26.8543885321 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 12.5323604474 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 26.5624500677 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 53.2116561433 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 100.474199566 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 28.1517532796 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.9550292346 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 9.6692321825 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.2586423639 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.8828703789 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.335609819 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.1302242169 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 27.1303526259 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 12.4000505612 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 26.3038204327 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 30.6034856061 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 30.9581546588 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 45.0047430021 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 41.4704069172 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 49.7929669042 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 27.3423159244 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 25.996020005 0
% INFO    : Updated Generator Cost: COW - 1952.1 59.305 0.01 -> 0 28.304939738 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 26.4821675754 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 19.241094444 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 30.6637718979 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 56.7064492654 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 30.8128985587 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 25.3906125457 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 27.0039473796 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 43.2099902377 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 51.4625132057 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 37.4883867623 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 27.8990687726 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 23.9824462905 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 30.4271019012 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 26.2135273906 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 30.3701429666 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 17.3347541251 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 0.941562118709 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.5561873726 0
% INFO    : Updated Generator Cost: COW - 270.8 14.42 0.009 -> 0 12.8882478064 0
% INFO    : Updated Generator Cost: NG - 355.25 13.964 0.007 -> 0 48.164341572 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 32.4409149844 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 26.9521437723 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 28.0983193424 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 21.9999273045 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 29.4457245297 0
% INFO    : Updated Generator Cost: COW - 503.6 31.94 0.025 -> 0 6.38224413898 0
% INFO    : Updated Generator Cost: COW - 78.78 26.977 0.114 -> 0 28.3068240837 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 16.5395069951 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 59.1259977166 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 20.8824567811 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 14.1150383342 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 114.947847878 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 113.581382091 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 42.0062374969 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 44.0766143744 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 40.9391056982 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.4407707201 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 97.1240721444 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.6397620701 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 104.713557377 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 9.58301776888 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 111.481452661 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 95.8482207934 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 26.6085460658 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 21.084452581 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 10.2881971044 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.4758407393 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 128.919960999 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 4.06371976913 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 28.5906361037 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 42.0359571024 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 34.9918655754 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.5950236349 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 40.6760227552 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 113.266774023 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 125.300765154 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 104.135136179 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 47.6842371257 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 35.1687359181 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 24.8606267486 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 44.0648528422 0
% INFO    : Updated Generator Cost: NG - 177.36 15.107 0.015 -> 0 22.9273217905 0
% INFO    : Updated Generator Cost: NG - 177.36 15.107 0.015 -> 0 28.5401233458 0
% INFO    : Updated Generator Cost: NG - 571.27 13.208 0.004 -> 0 39.2138358771 0
% INFO    : Updated Generator Cost: NG - 882.34 13.328 0.002 -> 0 33.3684514671 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 16.3300968475 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 44.7206564225 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 43.8946618211 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 20.3800758186 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 29.1954153384 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 30.4279385408 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 23.582077354 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 27.7830281064 0
% INFO    : Updated Generator Cost: NG - 583.98 21.946 0.01 -> 0 3.83983740901 0
% INFO    : Updated Generator Cost: PEL - 244.41 24.554 0.031 -> 0 111.208274662 0
% INFO    : Updated Generator Cost: NG - 806.48 21.336 0.007 -> 0 55.245996421 0
% INFO    : Updated Generator Cost: NG - 459.02 22.706 0.014 -> 0 27.0465673122 0
% INFO    : Updated Generator Cost: PEL - 234.51 24.697 0.032 -> 0 103.977497166 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 115.085422219 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 106.940466514 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 106.484213724 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 32.9319640403 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 35.8697170794 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.7579051996 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 105.622484512 0
% INFO    : Updated Generator Cost: PEL - 137.84 25.287 0.081 -> 0 117.837803189 0
% INFO    : Updated Generator Cost: NG - 139.75 25.279 0.08 -> 0 40.1611541677 0
% INFO    : Updated Generator Cost: PEL - 240.62 24.641 0.032 -> 0 115.766836755 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 119.241500663 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 37.5178875461 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 35.1192857252 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 37.466352438 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 23.2255457985 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 107.654006649 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 101.678078172 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 108.693543504 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 108.460153309 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 112.02099822 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 37.724353696 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 98.8121042105 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 24.5973133944 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 56.4607054481 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 29.8970681826 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 36.4718080616 0
% INFO    : Updated Generator Cost: PEL - 137.26 25.305 0.083 -> 0 107.052730542 0
% INFO    : Updated Generator Cost: NG - 192.75 25.072 0.049 -> 0 5.65447408167 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 40.864480959 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 25.0481886137 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 120.486623435 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 102.364745182 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 47.8668439005 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 112.575100531 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 32.7327888952 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 24.7431242478 0
% INFO    : Updated Generator Cost: PEL - 237.17 34.836 0.062 -> 0 118.34315435 0
% INFO    : Updated Generator Cost: NG - 319.37 33.769 0.043 -> 0 22.4491848757 0
% INFO    : Updated Generator Cost: NG - 97.71 16.01 0.032 -> 0 31.0629103693 0
% INFO    : Updated Generator Cost: NG - 97.71 16.01 0.032 -> 0 42.897089021 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.6094111832 0
% INFO    : Updated Generator Cost: NG - 201.08 34.988 0.074 -> 0 33.4678471937 0
% INFO    : Updated Generator Cost: NG - 197.65 34.988 0.075 -> 0 39.021815524 0
% INFO    : Updated Generator Cost: NG - 197.65 34.988 0.075 -> 0 33.4849378684 0
% INFO    : Updated Generator Cost: NG - 197.65 34.988 0.075 -> 0 23.9294522261 0
% INFO    : Updated Generator Cost: NG - 197.65 34.988 0.075 -> 0 16.1820257515 0
% INFO    : Updated Generator Cost: NG - 191.29 34.988 0.079 -> 0 18.5942136464 0
% INFO    : Updated Generator Cost: PEL - 319.37 33.769 0.043 -> 0 94.9722215341 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 37.6347380108 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 38.8427417664 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 22.0613728573 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 33.3307421263 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 23.2733800432 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 43.3639797642 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 16.9534538304 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 20.0180154428 0
% INFO    : Updated Generator Cost: NG - 191.15 34.988 0.08 -> 0 36.7578590139 0
% INFO    : Updated Generator Cost: NG - 175.26 34.988 0.085 -> 0 40.6922853563 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 22.3650986401 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 25.3224117576 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 118.358937839 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 39.7402389525 0
% INFO    : Updated Generator Cost: NG - 142.28 15.414 0.038 -> 0 46.472709506 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 32.8938244805 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 45.336542341 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 58.792009643 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 120.586812542 0
% INFO    : Updated Generator Cost: NG - 3338.33 71.322 0.019 -> 0 37.8549999972 0
% INFO    : Updated Generator Cost: NG - 3338.33 71.322 0.019 -> 0 38.8067462269 0
% INFO    : Updated Generator Cost: NG - 2279.4 73.952 0.029 -> 0 49.9988856256 0
% INFO    : Updated Generator Cost: NG - 2279.4 73.952 0.029 -> 0 51.2792420696 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 37.6325777589 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 104.211481143 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 38.6627252791 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 92.9179353529 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 43.2706564146 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 115.302108725 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 13.1847193991 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 37.4262967514 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 106.548397507 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 41.22138828 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 21.3252592901 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 104.401449636 0
% INFO    : Updated Generator Cost: NG - 211.68 34.988 0.07 -> 0 45.4753764382 0
% INFO    : Updated Generator Cost: NG - 146.14 34.988 0.107 -> 0 34.0515165604 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 25.8126847836 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 110.103313837 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 101.210866453 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 116.089453138 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 27.1671532292 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 45.2396352637 0
% INFO    : Updated Generator Cost: NG - 124.04 25.347 0.092 -> 0 41.724241102 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 22.4664868153 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 121.073987926 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 41.8319709127 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.9642932071 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 40.3283704339 0
% INFO    : Updated Generator Cost: NG - 167.13 25.168 0.063 -> 0 50.8367887092 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 35.4252110109 0
% INFO    : Updated Generator Cost: COW - 131.83 25.325 0.087 -> 0 39.2621225609 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 45.4343145509 0
% INFO    : Updated Generator Cost: NG - 102.85 15.566 0.058 -> 0 24.9376704458 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 47.6571423399 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 21.4808995881 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 40.1382065497 0
% INFO    : Updated Generator Cost: COW - 1755.23 50.578 0.008 -> 0 36.4800011685 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 113.950443755 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 112.013438656 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 107.888941857 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 116.887484446 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 100.287344282 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 109.456094225 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 96.7193136142 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 110.048274031 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 101.918920091 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 41.2192226028 0
% INFO    : Updated Generator Cost: NG - 65.1 15.905 0.072 -> 0 36.9925746584 0
% INFO    : Updated Generator Cost: PEL - 93.33 34.988 0.155 -> 0 110.312802913 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 41.0076501761 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 23.6494745812 0
% INFO    : Updated Generator Cost: NUC - 0.0 0.0 0.0 -> 0 7.06801879567 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 15.376354237 0
% INFO    : Updated Generator Cost: COW - 1552.28 12.513 0.002 -> 0 28.6596851787 0
% INFO    : Updated Generator Cost: COW - 1552.28 12.513 0.002 -> 0 21.1022299753 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 21.0216586986 0
% INFO    : Updated Generator Cost: NUC - 1446.8 12.513 0.002 -> 0 8.63847840098 0
% INFO    : Updated Generator Cost: COW - 1446.8 12.513 0.002 -> 0 30.6868891932 0
% INFO    : Updated Generator Cost: COW - 1446.8 12.513 0.002 -> 0 16.9911682528 0
% INFO    : Updated Generator Cost: COW - 1446.8 12.513 0.002 -> 0 25.4204514393 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 20.6941224931 0
% INFO    : Updated Generator Cost: NUC - 0.0 0.0 0.0 -> 0 6.42765946008 0
% INFO    : Updated Generator Cost: COW - 1550.51 12.513 0.002 -> 0 23.8774952146 0
% INFO    : Updated Generator Cost: COW - 1550.51 12.513 0.002 -> 0 43.7808266118 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 35.785819055 0
% INFO    : Updated Generator Cost: COW - 1289.41 12.561 0.002 -> 0 43.4906918368 0
% INFO    : Updated Generator Cost: COW - 1308.8 12.513 0.002 -> 0 14.0196561865 0
% INFO    : Updated Generator Cost: NG - 5397.8 71.378 0.009 -> 0 31.7202444167 0
% INFO    : Updated Generator Cost: NG - 5397.8 71.378 0.009 -> 0 45.4970443513 0
% INFO    : Updated Generator Cost: NG - 5397.8 71.378 0.009 -> 0 62.5883731704 0
% INFO    : Updated Generator Cost: NG - 5397.8 71.378 0.009 -> 0 33.5931010607 0
% INFO    : Updated Generator Cost: NG - 5397.8 71.378 0.009 -> 0 15.3960319643 0
% INFO    : Updated Generator Cost: NG - 5397.8 71.378 0.009 -> 0 36.468429606 0
% INFO    : Updated Generator Cost: NG - 5397.8 71.378 0.009 -> 0 33.371227484 0
% INFO    : Updated Generator Cost: NG - 5397.8 71.378 0.009 -> 0 40.1589871329 0
% INFO    : Updated Generator Cost: NG - 5397.8 71.378 0.009 -> 0 34.5756640512 0
% INFO    : Updated Generator Cost: NG - 5397.8 71.378 0.009 -> 0 43.6000612679 0
% INFO    : Updated Generator Cost: NG - 5397.8 71.378 0.009 -> 0 46.0977165881 0
% INFO    : Updated Generator Cost: PEL - 5397.8 71.378 0.009 -> 0 113.59286353 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 45.0639635566 0
% INFO    : Updated Generator Cost: NG - 359.17 26.977 0.025 -> 0 33.4505857447 0
% INFO    : Updated Generator Cost: NG - 359.17 26.977 0.025 -> 0 48.4394342207 0
% INFO    : Updated Generator Cost: PEL - 359.17 26.977 0.025 -> 0 104.790533611 0
% INFO    : Updated Generator Cost: NG - 359.17 26.977 0.025 -> 0 30.9673697431 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 54.3873761125 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 47.1522658387 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 42.5849052653 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 103.011996173 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 34.8283828655 0
% INFO    : Updated Generator Cost: NG - 359.17 26.977 0.025 -> 0 26.6961377509 0
% INFO    : Updated Generator Cost: NG - 359.17 26.977 0.025 -> 0 34.637925402 0
% INFO    : Updated Generator Cost: NG - 359.17 26.977 0.025 -> 0 37.3689562561 0
% INFO    : Updated Generator Cost: NG - 484.5 13.475 0.005 -> 0 43.9629663774 0
% INFO    : Updated Generator Cost: NG - 554.44 13.269 0.004 -> 0 47.0855445118 0
% INFO    : Updated Generator Cost: COW - 825.96 13.285 0.002 -> 0 15.4327871919 0
% INFO    : Updated Generator Cost: COW - 825.96 13.285 0.002 -> 0 15.8308271732 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.0541179332 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 46.7882259157 0
% INFO    : Updated Generator Cost: NG - 484.82 13.475 0.005 -> 0 32.5658672955 0
% INFO    : Updated Generator Cost: NG - 484.82 13.475 0.005 -> 0 31.1827952905 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 7.66045897476 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 47.9040932228 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 35.2768525156 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 51.8563887792 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 36.0044374633 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 27.7311466874 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 23.226795618 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 32.5052865581 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 34.1021320812 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 33.0021757108 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 29.1500471746 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 37.8372723323 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 46.8860874936 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 28.2396735305 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 47.800890917 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.0132478762 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 39.5475133676 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 45.0036410892 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 55.6799831988 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 30.5390024394 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 36.8082930095 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 38.8249876579 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 27.1754185464 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 23.3554161841 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 40.6193766063 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 38.2418518765 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 29.1094378161 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 58.4283139266 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 15.9062609827 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 28.4831666196 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 22.3482655387 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 44.8061907615 0
% INFO    : Updated Generator Cost: NG - 332.55 14.028 0.007 -> 0 13.8211738777 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 30.0711065677 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 38.4605084111 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 19.8059362534 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 28.0807715493 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 28.0531837423 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 26.1173765001 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 34.8121956238 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 30.9339575566 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 35.5409087009 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 29.266844392 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 36.9270907877 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 22.4126699581 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 47.888957962 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 25.3841954935 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 52.8293592399 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 38.880451461 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 51.3415087406 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 13.2236609786 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 37.1674530355 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 43.4042426311 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 20.0317016113 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 33.3896094651 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 29.5711261888 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 40.9344149165 0
% INFO    : Updated Generator Cost: NG - 292.64 14.239 0.008 -> 0 30.3204244038 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 20.6395550728 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 26.7167213231 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 21.0104033681 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 25.9096686034 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 18.0819354119 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 33.4830968975 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 20.9345331056 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 33.5409643135 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 55.0020233801 0
% INFO    : Updated Generator Cost: NG - 231.92 14.646 0.011 -> 0 34.0759004088 0
% INFO    : Updated Generator Cost: NG - 231.92 14.646 0.011 -> 0 38.3930992206 0
% INFO    : Updated Generator Cost: COW - 231.92 14.646 0.011 -> 0 28.0506608389 0
% INFO    : Updated Generator Cost: COW - 886.5 13.328 0.002 -> 0 18.7035518555 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 41.4091809038 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 21.0402580245 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 7.54839535494 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 44.6761786043 0
% INFO    : Updated Generator Cost: NG - 224.29 14.68 0.011 -> 0 36.2216469612 0
% INFO    : Updated Generator Cost: NG - 224.29 14.68 0.011 -> 0 12.292125006 0
% INFO    : Updated Generator Cost: NG - 224.29 14.68 0.011 -> 0 37.9076418298 0
% INFO    : Updated Generator Cost: COW - 280.73 14.338 0.009 -> 0 35.7206143348 0
% INFO    : Updated Generator Cost: NG - 280.73 14.338 0.009 -> 0 46.5494425122 0
% INFO    : Updated Generator Cost: NG - 966.18 20.939 0.006 -> 0 12.641921095 0
% INFO    : Updated Generator Cost: COW - 966.18 20.939 0.006 -> 0 19.3278155312 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 28.932389193 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 40.2843323635 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 48.8968156457 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 30.3312251364 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 23.0775919692 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 33.834926179 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 48.7796693056 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.0603768282 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.3975360431 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 30.3980224953 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 29.9564121271 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 40.251447268 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 47.1126016879 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.1772303316 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 34.4519329012 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 38.6570810129 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 39.1842491383 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 13.7627907111 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 21.775926967 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 23.4731624414 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 42.790062802 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 12.1061613056 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.725777335 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 19.8985978148 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 13.4713073564 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 28.0575069102 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 32.9009456776 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.6580640966 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 25.2984995877 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 34.1186547575 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 32.8268751502 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 127.427901668 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 36.837744478 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 42.4040204979 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 49.0194745901 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 15.4093602238 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 111.00069799 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 56.2148190271 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 22.93971863 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 39.7581041392 0
% INFO    : Updated Generator Cost: PEL - 119.1 34.988 0.125 -> 0 107.438663549 0
% INFO    : Updated Generator Cost: NG - 135.84 34.988 0.114 -> 0 24.1778913631 0
% INFO    : Updated Generator Cost: NG - 329.16 33.627 0.042 -> 0 36.9998836458 0
% INFO    : Updated Generator Cost: NG - 329.16 33.627 0.042 -> 0 18.8358731698 0
% INFO    : Updated Generator Cost: NG - 329.16 33.627 0.042 -> 0 39.8993718159 0
% INFO    : Updated Generator Cost: NG - 329.16 33.627 0.042 -> 0 26.0000636957 0
% INFO    : Updated Generator Cost: NG - 329.16 33.627 0.042 -> 0 34.6650409047 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 38.9700898875 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.7286049898 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 124.383188104 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 127.673729984 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 37.5993238998 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 25.1783199682 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 20.4450473591 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 46.2260742087 0
% INFO    : Updated Generator Cost: NG - 231.08 34.983 0.065 -> 0 22.2704195252 0
% INFO    : Updated Generator Cost: NG - 316.0 33.866 0.045 -> 0 28.0486118316 0
% INFO    : Updated Generator Cost: NG - 316.0 33.866 0.045 -> 0 32.7124486129 0
% INFO    : Updated Generator Cost: PEL - 316.0 33.866 0.045 -> 0 101.961791977 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 117.752402345 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 117.370262607 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 111.021538055 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 105.123613782 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 52.8256086119 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 48.0072584593 0
% INFO    : Updated Generator Cost: NG - 346.04 33.464 0.039 -> 0 34.4763905634 0
% INFO    : Updated Generator Cost: NG - 227.2 24.774 0.034 -> 0 16.5579088771 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 41.0962249696 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 39.3157902184 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 17.3746346137 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 38.7654515474 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 23.3827470536 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 37.7655932496 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 129.104910107 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 10.5658728511 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 47.4019862485 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 14.4220739831 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 26.3031413542 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 121.984272142 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 101.664530421 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 32.8873751949 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.2804636796 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 41.518483093 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 43.7113976728 0
% INFO    : Updated Generator Cost: NG - 372.67 23.328 0.018 -> 0 44.899399625 0
% INFO    : Updated Generator Cost: COW - 192.28 14.894 0.014 -> 0 12.6854049393 0
% INFO    : Updated Generator Cost: NG - 101.35 16.004 0.031 -> 0 34.7817971498 0
% INFO    : Updated Generator Cost: NG - 108.81 15.928 0.028 -> 0 40.2221811874 0
% INFO    : Updated Generator Cost: NG - 232.75 34.937 0.063 -> 0 44.9272446388 0
% INFO    : Updated Generator Cost: NG - 233.41 34.924 0.063 -> 0 44.48534304 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 26.100859361 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.4642051562 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 46.5770063715 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 19.1756792614 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 54.0383456196 0
% INFO    : Updated Generator Cost: NG - 205.21 34.988 0.072 -> 0 29.5078000142 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 23.758390796 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 25.5734053985 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 47.1223482383 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.5643751265 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 44.0122699067 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 24.8307202012 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 20.8552365386 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.6186521319 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 21.4342361378 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 47.5791668816 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 38.7293205878 0
% INFO    : Updated Generator Cost: NG - 198.97 34.988 0.074 -> 0 29.9199699432 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 18.5953853326 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 119.116196813 0
% INFO    : Updated Generator Cost: PEL - 149.18 34.988 0.101 -> 0 113.822916963 0
% INFO    : Updated Generator Cost: NG - 149.18 34.988 0.101 -> 0 53.7333821216 0
% INFO    : Updated Generator Cost: COW - 149.18 34.988 0.101 -> 0 29.8260281103 0
% INFO    : Updated Generator Cost: COW - 149.18 34.988 0.101 -> 0 16.9845058983 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 106.738746483 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 129.214577325 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 112.87395715 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 49.9609291838 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 109.915570607 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 115.657397911 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 119.910118283 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 97.1562603744 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 115.869336329 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 109.620614734 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 103.705233422 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 92.7698973282 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 41.6143012825 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 41.552748086 0
% INFO    : Updated Generator Cost: PEL - 130.74 23.025 0.049 -> 0 122.399813907 0
% INFO    : Updated Generator Cost: NG - 130.74 23.025 0.049 -> 0 30.1986511343 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 21.3361625117 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 25.0629632792 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 20.0982945299 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 127.539655181 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.0276584214 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 50.5431763464 0
% INFO    : Updated Generator Cost: NG - 98.81 34.988 0.148 -> 0 22.1394656402 0
% INFO    : Updated Generator Cost: NG - 167.8 34.988 0.088 -> 0 39.0183040109 0
% INFO    : Updated Generator Cost: NG - 92.7 34.988 0.158 -> 0 33.6049414515 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 24.2421873281 0
% INFO    : Updated Generator Cost: NUC - 0.0 0.0 0.0 -> 0 7.8656173018 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 23.4564475412 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 33.9677862061 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 24.347791751 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 26.2176810419 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 20.8698400843 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.0366348966 0
% INFO    : Updated Generator Cost: NG - 969.31 13.218 0.002 -> 0 53.3671571562 0
% INFO    : Updated Generator Cost: NG - 841.5 13.301 0.002 -> 0 17.4412705796 0
% INFO    : Updated Generator Cost: NG - 897.6 13.336 0.002 -> 0 41.1340039651 0
% INFO    : Updated Generator Cost: NG - 899.26 13.338 0.002 -> 0 29.8094324778 0
% INFO    : Updated Generator Cost: COW - 1012.43 13.121 0.002 -> 0 21.5006094518 0
% INFO    : Updated Generator Cost: NG - 636.15 13.14 0.003 -> 0 44.1239930933 0
% INFO    : Updated Generator Cost: COW - 583.63 13.177 0.004 -> 0 27.1464807527 0
% INFO    : Updated Generator Cost: NG - 583.63 13.177 0.004 -> 0 38.0232018613 0
% INFO    : Updated Generator Cost: NG - 504.23 13.419 0.004 -> 0 38.0424497809 0
% INFO    : Updated Generator Cost: NG - 504.23 13.419 0.004 -> 0 45.2245722338 0
% INFO    : Updated Generator Cost: COW - 504.23 13.419 0.004 -> 0 15.7290138628 0
% INFO    : Updated Generator Cost: NG - 504.23 13.419 0.004 -> 0 37.926834152 0
% INFO    : Updated Generator Cost: NG - 375.74 13.836 0.006 -> 0 20.0776033211 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 25.0794754316 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 33.2631414927 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 29.8996592341 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 22.1880262117 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 24.2661383436 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 118.539650526 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 112.114658635 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 41.8813172332 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 104.129529578 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 18.3801863866 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 33.1323908406 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 129.885780055 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 104.607918098 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 111.868008567 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 47.0989855916 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 25.1213707102 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 36.0270661337 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 27.3317419 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 40.3050334613 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 16.8763841968 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 29.7842893613 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 16.0937195038 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 34.3096097719 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 51.9452675896 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 28.6650746743 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 44.5875903185 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 18.2333770425 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 28.291792903 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 30.8545461312 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 35.3796519261 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 35.8211152976 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 44.6396700928 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 31.3542035666 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 59.5026713703 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 12.7680726927 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 20.8559404547 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 46.1391751132 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 41.9634641595 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 46.6704752327 0
% INFO    : Updated Generator Cost: NG - 260.12 14.43 0.01 -> 0 44.0676015158 0
% INFO    : Updated Generator Cost: NG - 260.12 14.43 0.01 -> 0 35.0991330397 0
% INFO    : Updated Generator Cost: NG - 251.43 14.515 0.01 -> 0 32.1211939649 0
% INFO    : Updated Generator Cost: NG - 396.52 13.762 0.006 -> 0 39.6009488534 0
% INFO    : Updated Generator Cost: NG - 251.43 14.515 0.01 -> 0 11.5210698536 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 130.958213442 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 111.566976174 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 36.6033218976 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 92.8640456418 0
% INFO    : Updated Generator Cost: COW - 1952.1 59.305 0.01 -> 0 20.4558036887 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 108.797167031 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 14.2764842267 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 116.304214259 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 42.5416798922 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 115.289660456 0
% INFO    : Updated Generator Cost: NG - 307.36 23.767 0.023 -> 0 25.7566303356 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.003859944 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 116.516174168 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.4211501118 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 5.52542095627 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 29.5504029117 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.6459333602 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 44.5437425256 0
% INFO    : Updated Generator Cost: COW - 339.71 33.562 0.041 -> 0 24.5633689249 0
% INFO    : Updated Generator Cost: NG - 440.79 32.359 0.029 -> 0 27.5735932092 0
% INFO    : Updated Generator Cost: NG - 440.79 32.359 0.029 -> 0 36.7773875952 0
% INFO    : Updated Generator Cost: PEL - 440.79 32.359 0.029 -> 0 128.793612621 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 39.7287169661 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 32.0860225357 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 42.4665839518 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 40.9314123729 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.3641435804 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 27.861799389 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 14.3288266867 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.9444593736 0
% INFO    : Updated Generator Cost: NG - 187.0 14.954 0.014 -> 0 39.4929301366 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 18.2763604169 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 26.5675570091 0
% INFO    : Updated Generator Cost: NG - 172.84 15.144 0.016 -> 0 22.5581350425 0
% INFO    : Updated Generator Cost: NG - 172.84 15.144 0.016 -> 0 51.4685413583 0
% INFO    : Updated Generator Cost: NG - 155.95 15.359 0.018 -> 0 38.3348110846 0
% INFO    : Updated Generator Cost: NG - 155.95 15.359 0.018 -> 0 24.8758224758 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 125.147333866 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 87.9589796988 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 25.9037024393 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 30.5759613147 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 134.97252923 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 47.0945440525 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 53.4927745542 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 34.0059047555 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 28.5683589095 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 40.724287998 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 34.5928764515 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.1287004557 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 103.093080728 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 26.7228255589 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 101.770505136 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 97.0253476217 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.3717011395 0
% INFO    : Updated Generator Cost: COW - 1755.23 50.578 0.008 -> 0 15.6753591925 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 39.9637074876 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 42.9465415983 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 22.6346752553 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 6.98855312831 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 19.3111655812 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.041505419 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 44.4776974994 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 35.497290771 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.9840103378 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 23.9539990188 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 117.245792965 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.3471514202 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 33.0574450352 0
% INFO    : Updated Generator Cost: COW - 51.34 14.879 0.053 -> 0 26.9236147199 0
% INFO    : Updated Generator Cost: COW - 51.34 14.879 0.053 -> 0 25.4607667336 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 49.3983871411 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 42.7177640183 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 24.5995882293 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 24.7878238221 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 14.4245455706 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 16.1171653184 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.6059992435 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.6782181669 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 109.129178333 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 25.0208842557 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.7407271186 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 35.9476456991 0
% INFO    : Updated Generator Cost: NG - 237.15 34.884 0.062 -> 0 51.8826808713 0
% INFO    : Updated Generator Cost: NG - 216.05 34.988 0.069 -> 0 8.84323806335 0
% INFO    : Updated Generator Cost: NG - 266.08 34.497 0.055 -> 0 27.8644365341 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 33.2955447311 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 11.6986697181 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 35.0658715849 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 107.156172295 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 35.5298171603 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 106.651690797 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 44.3480112226 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.09284551 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 22.9650872488 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 21.6990455812 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 49.2366320063 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 26.2698690454 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 33.7523520815 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 46.6731382843 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 16.0854396138 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 37.9240654784 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 122.124317731 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.8269574902 0
% INFO    : Updated Generator Cost: NG - 572.09 86.679 0.16 -> 0 38.9704075419 0
% INFO    : Updated Generator Cost: NG - 572.09 86.679 0.16 -> 0 28.3283970602 0
% INFO    : Updated Generator Cost: NG - 133.43 25.322 0.086 -> 0 41.3348061213 0
% INFO    : Updated Generator Cost: NG - 133.43 25.322 0.086 -> 0 56.2208978993 0
% INFO    : Updated Generator Cost: PEL - 133.43 25.322 0.086 -> 0 98.7140072992 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 123.391671839 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 19.2113253974 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 111.374735732 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 42.9465333761 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.3393902867 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 26.5708970218 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 35.3228223676 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.4868643366 0
% INFO    : Updated Generator Cost: PEL - 57.39 16.01 0.053 -> 0 120.834763804 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 48.4526702736 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 117.036746155 0
% INFO    : Updated Generator Cost: COW - 1755.23 50.578 0.008 -> 0 29.1510302784 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 124.829276348 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 112.884252619 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 116.971402223 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 38.8341942793 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 32.826138061 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 114.176553568 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.598267018 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 108.220941654 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 46.0088982031 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 39.7752214726 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 15.8335272804 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 7.19333381015 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 10.4136678417 0
% INFO    : Updated Generator Cost: COW - 1107.49 12.922 0.002 -> 0 34.3528037265 0
% INFO    : Updated Generator Cost: COW - 1107.49 12.922 0.002 -> 0 25.2528507759 0
% INFO    : Updated Generator Cost: COW - 1107.49 12.922 0.002 -> 0 27.8739038462 0
% INFO    : Updated Generator Cost: COW - 1107.49 12.922 0.002 -> 0 24.8609053731 0
% INFO    : Updated Generator Cost: COW - 2130.63 13.659 0.009 -> 0 25.0806778873 0
% INFO    : Updated Generator Cost: COW - 2130.63 13.659 0.009 -> 0 10.7423236488 0
% INFO    : Updated Generator Cost: PEL - 2130.63 13.659 0.009 -> 0 106.657082953 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 33.3310429919 0
% INFO    : Updated Generator Cost: NG - 442.95 22.845 0.014 -> 0 52.0746250196 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 33.9793081278 0
% INFO    : Updated Generator Cost: COW - 613.1 13.125 0.003 -> 0 32.0286220255 0
% INFO    : Updated Generator Cost: NG - 442.95 22.845 0.014 -> 0 27.8392506301 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 23.9322205775 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 33.7758726556 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 41.3217066094 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 34.530815737 0
% INFO    : Updated Generator Cost: COW - 1273.6 12.565 0.002 -> 0 18.6954612635 0
% INFO    : Updated Generator Cost: NG - 446.78 13.582 0.005 -> 0 50.5991810298 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 23.8541236877 0
% INFO    : Updated Generator Cost: NG - 651.34 21.749 0.009 -> 0 18.2650051929 0
% INFO    : Updated Generator Cost: COW - 1545.8 12.513 0.002 -> 0 19.2551719684 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 34.892403721 0
% INFO    : Updated Generator Cost: NG - 447.85 13.579 0.005 -> 0 41.9688503905 0
% INFO    : Updated Generator Cost: NG - 447.85 13.579 0.005 -> 0 40.430927577 0
% INFO    : Updated Generator Cost: COW - 447.85 13.579 0.005 -> 0 24.1371224724 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 43.2008328269 0
% INFO    : Updated Generator Cost: NG - 446.16 13.586 0.005 -> 0 25.8547193993 0
% INFO    : Updated Generator Cost: NG - 484.39 13.475 0.005 -> 0 29.6114084359 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 29.5363915804 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 23.833606147 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 27.3368067718 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 36.6884683774 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 28.0260303114 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 25.2518246905 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 105.92887175 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.2694698824 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 46.025295988 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 24.8202014244 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 33.8726145978 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 47.007106029 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 28.0014632863 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 16.9942637502 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.0156727269 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.5340702187 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 38.1702576397 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 43.4683963685 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 42.7714697467 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 21.9322614441 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 36.083800319 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 36.0146917493 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 42.729137593 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 41.7305179292 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 26.9492924845 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 27.650267875 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.751691848 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 43.8322460789 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 39.5940732803 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 26.1188789616 0
% INFO    : Updated Generator Cost: NG - 361.81 13.915 0.007 -> 0 23.4677979831 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 97.6164482149 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 2.7260848276 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 17.4620351633 0
% INFO    : Updated Generator Cost: NG - 832.75 13.291 0.002 -> 0 49.2141438784 0
% INFO    : Updated Generator Cost: NG - 361.81 13.915 0.007 -> 0 36.6752959671 0
% INFO    : Updated Generator Cost: NG - 361.81 13.915 0.007 -> 0 24.8949181319 0
% INFO    : Updated Generator Cost: NG - 361.81 13.915 0.007 -> 0 28.2915808795 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 16.7607624922 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 117.428652052 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 15.5497369482 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.450739038 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 19.902223232 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 39.503285269 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 38.3000064004 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 29.6810482124 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 24.822461095 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 4.78024153154 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 34.2020758747 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 49.9004133345 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 43.8572507749 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 40.6481259124 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 34.0142256023 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 48.3032334295 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 34.361184821 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 40.8758060394 0
% INFO    : Updated Generator Cost: COW - 2130.63 13.659 0.009 -> 0 33.0348263381 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 37.3297410194 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 24.055755323 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 41.1894362108 0
% INFO    : Updated Generator Cost: COW - 2130.63 13.659 0.009 -> 0 24.0646266367 0
% INFO    : Updated Generator Cost: NG - 256.94 14.466 0.01 -> 0 32.4549560066 0
% INFO    : Updated Generator Cost: NG - 256.94 14.466 0.01 -> 0 36.4587484187 0
% INFO    : Updated Generator Cost: NG - 256.94 14.466 0.01 -> 0 31.5597862624 0
% INFO    : Updated Generator Cost: NG - 256.94 14.466 0.01 -> 0 58.7452132654 0
% INFO    : Updated Generator Cost: NG - 256.94 14.466 0.01 -> 0 33.8817622378 0
% INFO    : Updated Generator Cost: NG - 256.94 14.466 0.01 -> 0 26.8137242827 0
% INFO    : Updated Generator Cost: COW - 833.56 13.291 0.002 -> 0 36.2331595215 0
% INFO    : Updated Generator Cost: COW - 872.28 13.32 0.002 -> 0 28.4257131171 0
% INFO    : Updated Generator Cost: NG - 344.94 13.999 0.007 -> 0 23.8513713897 0
% INFO    : Updated Generator Cost: COW - 354.46 13.965 0.007 -> 0 24.272684338 0
% INFO    : Updated Generator Cost: NG - 230.9 14.648 0.011 -> 0 16.8817378473 0
% INFO    : Updated Generator Cost: COW - 230.9 14.648 0.011 -> 0 25.3802856168 0
% INFO    : Updated Generator Cost: COW - 1278.24 12.564 0.002 -> 0 15.8130758652 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 19.9663636465 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 46.2295356485 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 5.0439043571 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 118.919580273 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 58.1559904746 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 45.8232163295 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 35.5270601052 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 33.8492141156 0
% INFO    : Updated Generator Cost: PEL - 330.65 33.617 0.041 -> 0 108.189367548 0
% INFO    : Updated Generator Cost: PEL - 330.65 33.617 0.041 -> 0 116.678705681 0
% INFO    : Updated Generator Cost: NG - 330.65 33.617 0.041 -> 0 40.1546217273 0
% INFO    : Updated Generator Cost: PEL - 219.39 24.884 0.036 -> 0 104.003442145 0
% INFO    : Updated Generator Cost: NG - 219.39 24.884 0.036 -> 0 32.7420962369 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 115.443739729 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 25.4304300046 0
% INFO    : Updated Generator Cost: PEL - 130.47 15.669 0.023 -> 0 122.020594572 0
% INFO    : Updated Generator Cost: COW - 188.73 14.913 0.014 -> 0 25.9291955061 0
% INFO    : Updated Generator Cost: COW - 188.73 14.913 0.014 -> 0 16.2362307407 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 44.091550165 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 31.4049656092 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.3393590598 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 42.0702136808 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.4633525546 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 23.5132415161 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 18.9225562943 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.8168304464 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 107.760337681 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 35.5932998479 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 43.0806961846 0
% INFO    : Updated Generator Cost: NG - 211.74 34.988 0.07 -> 0 40.458528644 0
% INFO    : Updated Generator Cost: NG - 296.46 34.074 0.047 -> 0 41.0621196574 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.0370998244 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.47061999 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.4483358739 0
% INFO    : Updated Generator Cost: NG - 187.64 34.988 0.082 -> 0 36.1021959008 0
% INFO    : Updated Generator Cost: NG - 187.64 34.988 0.082 -> 0 41.3328740225 0
% INFO    : Updated Generator Cost: COW - 187.64 34.988 0.082 -> 0 26.6453543393 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 98.44103959 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 105.68253588 0
% INFO    : Updated Generator Cost: NG - 182.48 34.988 0.082 -> 0 43.2058848376 0
% INFO    : Updated Generator Cost: NG - 218.39 34.988 0.068 -> 0 25.2645140152 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.796362366 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 25.7552063265 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 114.009945366 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.6105630761 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 42.2807893515 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 42.0241378595 0
% INFO    : Updated Generator Cost: NG - 163.5 34.988 0.09 -> 0 34.8719907358 0
% INFO    : Updated Generator Cost: NG - 180.97 34.988 0.082 -> 0 36.6120270971 0
% INFO    : Updated Generator Cost: PEL - 157.61 34.988 0.095 -> 0 102.469916062 0
% INFO    : Updated Generator Cost: NG - 263.17 34.506 0.055 -> 0 42.7014927459 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 51.6255937476 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.1547499468 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 38.3018566563 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 109.943669838 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 47.3755862042 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 115.364611063 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 99.9240617871 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 12.9027689657 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 48.6557253099 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.7086681499 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 107.415137318 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 108.287739986 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 96.8590531856 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 114.693263251 0
% INFO    : Updated Generator Cost: COW - 142.86 34.988 0.109 -> 0 17.2296006803 0
% INFO    : Updated Generator Cost: NG - 142.86 34.988 0.109 -> 0 31.3585004211 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 104.243552535 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 106.758462988 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 18.9758440273 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 36.4274638289 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 102.794384638 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 22.579535459 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 93.4283036168 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 111.241477336 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 32.4953469216 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 109.0056493 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.7711455413 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 15.4141617658 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 48.5638744572 0
% INFO    : Updated Generator Cost: NG - 83.75 25.545 0.1 -> 0 28.7581042932 0
% INFO    : Updated Generator Cost: NG - 83.75 25.545 0.1 -> 0 47.3378763841 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.3346472774 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 97.3611814324 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 47.1161163481 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 57.8734077694 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 47.7863895276 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 24.9483329742 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 108.396784118 0
% INFO    : Updated Generator Cost: PEL - 146.23 34.988 0.106 -> 0 116.948218548 0
% INFO    : Updated Generator Cost: PEL - 241.71 34.714 0.06 -> 0 114.241163941 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 112.739428701 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 112.954188111 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 112.551765492 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 33.3284623158 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.2825209547 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 44.8005021575 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 110.519919543 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 44.2981101392 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 54.5878773693 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 112.184738692 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 120.217326022 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 15.3729788786 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 44.8185745693 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 102.499469573 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 48.5669417868 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 122.127391931 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 115.638028495 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 27.4800015091 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 126.846685597 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 105.86749965 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 114.295537257 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 96.3998941892 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.7233342134 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.5809026667 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 97.8924642445 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 34.7206260453 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 48.1854442145 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.3505755476 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.5149953169 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.0202615699 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 38.2442085557 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.841180573 0
% INFO    : Updated Generator Cost: NG - 65.44 25.545 0.126 -> 0 24.8767466473 0
% INFO    : Updated Generator Cost: NG - 65.44 25.545 0.126 -> 0 37.0417460133 0
% INFO    : Updated Generator Cost: PEL - 65.44 25.545 0.126 -> 0 116.280473528 0
% INFO    : Updated Generator Cost: PEL - 74.46 25.545 0.122 -> 0 101.319364921 0
% INFO    : Updated Generator Cost: COW - 1248.4 12.617 0.002 -> 0 25.2398364052 0
% INFO    : Updated Generator Cost: NG - 1867.7 12.513 0.001 -> 0 40.8707216359 0
% INFO    : Updated Generator Cost: COW - 1105.34 12.923 0.002 -> 0 20.6403760213 0
% INFO    : Updated Generator Cost: COW - 1105.34 12.923 0.002 -> 0 21.6505852049 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 24.1951356101 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 53.7525825484 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 47.1536409497 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 40.3191329981 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 25.2953037489 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 44.5862224645 0
% INFO    : Updated Generator Cost: COW - 855.72 13.306 0.002 -> 0 22.2729367131 0
% INFO    : Updated Generator Cost: COW - 843.81 13.302 0.002 -> 0 22.9069996658 0
% INFO    : Updated Generator Cost: NG - 842.79 13.302 0.002 -> 0 19.5420417387 0
% INFO    : Updated Generator Cost: COW - 842.37 13.302 0.002 -> 0 25.4814443493 0
% INFO    : Updated Generator Cost: NG - 843.4 13.302 0.002 -> 0 38.7502552491 0
% INFO    : Updated Generator Cost: NG - 765.06 13.241 0.002 -> 0 30.789914207 0
% INFO    : Updated Generator Cost: NG - 694.79 13.191 0.003 -> 0 40.3076576005 0
% INFO    : Updated Generator Cost: NG - 552.4 13.275 0.004 -> 0 21.3172923533 0
% INFO    : Updated Generator Cost: NG - 552.4 13.275 0.004 -> 0 37.814836525 0
% INFO    : Updated Generator Cost: NG - 824.02 13.282 0.002 -> 0 21.2810259656 0
% INFO    : Updated Generator Cost: NG - 526.18 13.359 0.004 -> 0 42.0182048879 0
% INFO    : Updated Generator Cost: COW - 526.18 13.359 0.004 -> 0 28.8772385566 0
% INFO    : Updated Generator Cost: NG - 553.92 13.274 0.004 -> 0 46.9684243955 0
% INFO    : Updated Generator Cost: COW - 900.18 13.339 0.002 -> 0 18.4128169297 0
% INFO    : Updated Generator Cost: NG - 475.93 13.497 0.005 -> 0 42.7268020638 0
% INFO    : Updated Generator Cost: COW - 475.93 13.497 0.005 -> 0 33.4729571385 0
% INFO    : Updated Generator Cost: COW - 1319.08 12.513 0.002 -> 0 31.2024513572 0
% INFO    : Updated Generator Cost: NG - 461.73 13.542 0.005 -> 0 14.1082369305 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 24.3615085601 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 42.6492824606 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 27.459704964 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 32.4791654618 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 42.4554974167 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 42.41606828 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 30.7031591207 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 28.7448664854 0
% INFO    : Updated Generator Cost: NG - 374.29 13.839 0.006 -> 0 24.6809543171 0
% INFO    : Updated Generator Cost: NG - 363.55 13.9 0.007 -> 0 45.351427906 0
% INFO    : Updated Generator Cost: NG - 358.51 13.928 0.007 -> 0 30.7131728012 0
% INFO    : Updated Generator Cost: NG - 374.29 13.839 0.006 -> 0 31.3718052708 0
% INFO    : Updated Generator Cost: NG - 374.29 13.839 0.006 -> 0 10.2369597966 0
% INFO    : Updated Generator Cost: COW - 318.94 14.076 0.008 -> 0 43.8611300499 0
% INFO    : Updated Generator Cost: NG - 318.94 14.076 0.008 -> 0 46.7368626074 0
% INFO    : Updated Generator Cost: NG - 318.94 14.076 0.008 -> 0 8.36763923553 0
% INFO    : Updated Generator Cost: NG - 318.94 14.076 0.008 -> 0 27.1191974853 0
% INFO    : Updated Generator Cost: NG - 318.94 14.076 0.008 -> 0 35.6210098598 0
% INFO    : Updated Generator Cost: NG - 318.94 14.076 0.008 -> 0 32.9895967397 0
% INFO    : Updated Generator Cost: NG - 318.94 14.076 0.008 -> 0 39.1795300702 0
% INFO    : Updated Generator Cost: NG - 318.94 14.076 0.008 -> 0 18.3709834489 0
% INFO    : Updated Generator Cost: NG - 318.94 14.076 0.008 -> 0 45.5242806639 0
% INFO    : Updated Generator Cost: NG - 318.94 14.076 0.008 -> 0 31.0591828417 0
% INFO    : Updated Generator Cost: NG - 294.42 14.232 0.008 -> 0 43.3219574531 0
% INFO    : Updated Generator Cost: NG - 379.34 13.827 0.006 -> 0 39.2172004142 0
% INFO    : Updated Generator Cost: NG - 448.31 13.578 0.005 -> 0 35.757504787 0
% INFO    : Updated Generator Cost: COW - 296.01 14.158 0.008 -> 0 32.3879824634 0
% INFO    : Updated Generator Cost: NG - 464.82 13.535 0.005 -> 0 32.4444412243 0
% INFO    : Updated Generator Cost: COW - 332.82 14.027 0.007 -> 0 16.8006513649 0
% INFO    : Updated Generator Cost: COW - 702.27 13.201 0.003 -> 0 30.0748717852 0
% INFO    : Updated Generator Cost: COW - 211.93 14.777 0.013 -> 0 26.4336913343 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 34.1833370838 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 35.0110696117 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 19.0327645052 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 39.6092788748 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 45.2292751855 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 20.2480115499 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 30.4112345266 0
% INFO    : Updated Generator Cost: NG - 213.95 14.764 0.013 -> 0 36.9538538747 0
% INFO    : Updated Generator Cost: NG - 400.1 13.749 0.006 -> 0 29.8606753998 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 21.1073496169 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.7302349807 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 20.1420891901 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.9644847087 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.760623726 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 36.3979518104 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 72.3150610303 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 37.0422210891 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 38.3481978795 0
% INFO    : Updated Generator Cost: COW - 367.99 33.159 0.036 -> 0 38.5834623983 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.4459722668 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 60.7807025845 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 18.0463866463 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 24.5649884357 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 46.2841350504 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 12.1379075699 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 27.5299344068 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 38.4401484286 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 27.7737341812 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 15.8280936635 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 40.8277956115 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 34.2139230211 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 42.7805250951 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 44.8062544576 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 41.7659149307 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 41.975833605 0
% INFO    : Updated Generator Cost: NG - 147.35 15.434 0.02 -> 0 33.7690134366 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 112.497577914 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 113.18850719 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 111.707856128 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 30.0593431214 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 46.6802291286 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 46.9568686768 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 35.8232912879 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.9666924939 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 28.8516895824 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 19.0235036651 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 44.0141318208 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 23.8799286878 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 22.1695788742 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 21.5781826721 0
% INFO    : Updated Generator Cost: NG - 154.29 15.37 0.019 -> 0 30.7833808845 0
% INFO    : Updated Generator Cost: NG - 154.29 15.37 0.019 -> 0 37.2621062601 0
% INFO    : Updated Generator Cost: NG - 54.54 16.01 0.057 -> 0 33.0484798075 0
% INFO    : Updated Generator Cost: NG - 54.54 16.01 0.057 -> 0 26.1455290523 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 101.738709492 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 117.18643366 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 4.99218120268 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 42.4549769185 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 28.7175316652 0
% INFO    : Updated Generator Cost: COW - 1959.73 20.052 0.003 -> 0 24.43432959 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 27.4148653175 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 41.5151713832 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 33.3290342739 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 58.3853540485 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 25.3841235311 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 29.2780291206 0
% INFO    : Updated Generator Cost: NG - 827.23 13.289 0.002 -> 0 49.7643189451 0
% INFO    : Updated Generator Cost: NG - 827.23 13.289 0.002 -> 0 46.9427539586 0
% INFO    : Updated Generator Cost: COW - 1307.82 21.124 0.003 -> 0 17.968801794 0
% INFO    : Updated Generator Cost: COW - 2017.58 19.968 0.003 -> 0 23.1407107023 0
% INFO    : Updated Generator Cost: NG - 774.48 13.248 0.002 -> 0 33.1191406446 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 19.9072115827 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 35.7027710113 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 31.8773901956 0
% INFO    : Updated Generator Cost: NG - 370.23 13.859 0.007 -> 0 34.3575287613 0
% INFO    : Updated Generator Cost: NG - 370.23 13.859 0.007 -> 0 16.023212798 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 44.3982404322 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 35.764393495 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 31.7876755215 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 14.3768639013 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.3280515802 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 20.6964713474 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 39.2987262272 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 29.197797109 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 15.0460548238 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 24.7642296321 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 30.4004400969 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 16.2382706638 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 23.9053818845 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 13.1663042154 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 11.4431536587 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 30.4179228326 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 29.9033800356 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 30.5095749631 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 24.9664496238 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 11.8192656084 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 23.1178795234 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 34.6577804922 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 58.1334712748 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 34.5883189871 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 20.5731599824 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 40.4799210896 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 20.9820039938 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 28.661850238 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 29.6090185619 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 108.096573228 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 90.1407823362 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 44.1226178525 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 20.6003298846 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 113.456658567 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 19.1730951711 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 64.7929271791 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 31.7939341492 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 27.9913101313 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 29.9985866674 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 35.2173196994 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 36.5617390013 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 44.7160392489 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 34.3366654859 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 36.524006709 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 107.851096256 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 40.6113559624 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 27.9616106882 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 52.3123334046 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 22.5448307193 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.1551470198 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 31.4642399386 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 115.455318874 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 39.7605375851 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 20.3618211478 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 29.0686740329 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 129.185775052 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 19.2424636834 0
% INFO    : Updated Generator Cost: PEL - 209.79 25.022 0.038 -> 0 106.57475514 0
% INFO    : Updated Generator Cost: PEL - 196.28 25.044 0.046 -> 0 88.3162981457 0
% INFO    : Updated Generator Cost: PEL - 196.28 25.044 0.046 -> 0 117.654039297 0
% INFO    : Updated Generator Cost: NG - 196.28 25.044 0.046 -> 0 40.446749744 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.8642845332 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 34.2454112797 0
% INFO    : Updated Generator Cost: NG - 212.32 34.988 0.07 -> 0 42.5138594504 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 22.4489223572 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 120.08629427 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.7508056401 0
% INFO    : Updated Generator Cost: NG - 280.63 34.369 0.052 -> 0 36.4819526592 0
% INFO    : Updated Generator Cost: NG - 202.99 34.988 0.073 -> 0 35.8146745309 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 46.2125385314 0
% INFO    : Updated Generator Cost: NG - 160.32 25.198 0.065 -> 0 21.0105341011 0
% INFO    : Updated Generator Cost: NG - 162.62 25.19 0.064 -> 0 35.5818644267 0
% INFO    : Updated Generator Cost: NG - 324.71 23.644 0.021 -> 0 30.1439617617 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 47.5828627863 0
% INFO    : Updated Generator Cost: COW - 1387.9 21.174 0.003 -> 0 17.5977039515 0
% INFO    : Updated Generator Cost: NG - 287.31 24.002 0.025 -> 0 28.648807696 0
% INFO    : Updated Generator Cost: NG - 287.31 24.002 0.025 -> 0 29.3578084819 0
% INFO    : Updated Generator Cost: NG - 771.02 21.436 0.007 -> 0 33.7697599726 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 53.8273943532 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 44.7415806477 0
% INFO    : Updated Generator Cost: COW - 146.74 34.988 0.105 -> 0 16.5931760657 0
% INFO    : Updated Generator Cost: NG - 147.81 34.988 0.103 -> 0 52.4928701424 0
% INFO    : Updated Generator Cost: PEL - 119.83 25.369 0.095 -> 0 102.772953833 0
% INFO    : Updated Generator Cost: NG - 119.83 25.369 0.095 -> 0 15.2882579332 0
% INFO    : Updated Generator Cost: PEL - 119.83 25.369 0.095 -> 0 101.752674175 0
% INFO    : Updated Generator Cost: PEL - 114.34 34.988 0.129 -> 0 120.893975097 0
% INFO    : Updated Generator Cost: NG - 114.34 34.988 0.129 -> 0 23.363892316 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 109.404142549 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 28.1228012321 0
% INFO    : Updated Generator Cost: PEL - 67.42 25.537 0.125 -> 0 112.073737008 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 101.006893692 0
% INFO    : Updated Generator Cost: COW - 2110.9 12.513 0.001 -> 0 29.5716224061 0
% INFO    : Updated Generator Cost: COW - 2110.9 12.513 0.001 -> 0 32.8033628482 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 30.6038000617 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 30.7146863009 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 31.447276961 0
% INFO    : Updated Generator Cost: COW - 1542.6 12.513 0.002 -> 0 16.4142949136 0
% INFO    : Updated Generator Cost: COW - 573.64 14.879 0.005 -> 0 27.7587931954 0
% INFO    : Updated Generator Cost: NG - 573.64 14.879 0.005 -> 0 40.7553676586 0
% INFO    : Updated Generator Cost: COW - 573.64 14.879 0.005 -> 0 33.215387439 0
% INFO    : Updated Generator Cost: NG - 573.64 14.879 0.005 -> 0 28.9792346474 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 22.1552419381 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 99.232912163 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 54.3583971444 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 112.547724758 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 115.526844745 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.5052177729 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 114.721060977 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 100.073135663 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 120.527463933 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 50.6770920616 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 23.093031346 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 43.7573991841 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 105.658321355 0
% INFO    : Updated Generator Cost: NG - 527.03 13.355 0.004 -> 0 40.3018539504 0
% INFO    : Updated Generator Cost: NG - 527.03 13.355 0.004 -> 0 31.8579531539 0
% INFO    : Updated Generator Cost: COW - 527.03 13.355 0.004 -> 0 8.11916528918 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 135.984348724 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 117.489201163 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 104.809931541 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 115.677920627 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 98.4643061862 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 33.027635917 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 52.8074406761 0
% INFO    : Updated Generator Cost: NG - 364.58 13.899 0.007 -> 0 42.6663254908 0
% INFO    : Updated Generator Cost: COW - 364.58 13.899 0.007 -> 0 23.0118746481 0
% INFO    : Updated Generator Cost: NG - 364.58 13.899 0.007 -> 0 15.5555684969 0
% INFO    : Updated Generator Cost: NG - 364.58 13.899 0.007 -> 0 38.1583815859 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 21.0157512549 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 30.398531739 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 37.1258567956 0
% INFO    : Updated Generator Cost: NG - 369.18 13.891 0.007 -> 0 39.5759390388 0
% INFO    : Updated Generator Cost: NG - 369.18 13.891 0.007 -> 0 60.4640039817 0
% INFO    : Updated Generator Cost: NG - 369.18 13.891 0.007 -> 0 33.6908004523 0
% INFO    : Updated Generator Cost: NG - 369.18 13.891 0.007 -> 0 34.8923413453 0
% INFO    : Updated Generator Cost: NG - 369.18 13.891 0.007 -> 0 26.0434755196 0
% INFO    : Updated Generator Cost: NG - 329.69 14.055 0.007 -> 0 35.756913488 0
% INFO    : Updated Generator Cost: NG - 329.69 14.055 0.007 -> 0 44.0873787569 0
% INFO    : Updated Generator Cost: NG - 329.69 14.055 0.007 -> 0 41.5073148108 0
% INFO    : Updated Generator Cost: NG - 329.69 14.055 0.007 -> 0 47.0202903412 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 29.2465761602 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 31.1379262337 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 20.5019509369 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 24.0587476607 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 18.9782139831 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 30.9190980513 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 11.7198286517 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 37.5518907817 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 36.9596870522 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 29.0929859171 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 51.1823442829 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.6446964707 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 45.1634791699 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 50.9962667145 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 41.4340543823 0
% INFO    : Updated Generator Cost: COW - 237.47 14.597 0.011 -> 0 38.6840825931 0
% INFO    : Updated Generator Cost: NG - 312.1 14.099 0.008 -> 0 37.2246755639 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 28.4787761968 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.4589673739 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 36.0082842704 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 21.5326918436 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 118.879507621 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 113.414869699 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 46.2075023796 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 101.355547132 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 106.110792753 0
% INFO    : Updated Generator Cost: NG - 237.47 14.597 0.011 -> 0 29.7074404929 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 31.1090438687 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 89.6284970011 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.0343559458 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 38.4592324007 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.7250078718 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 41.6605081968 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 100.140320445 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 34.2092608944 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 114.858363917 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 107.952299766 0
% INFO    : Updated Generator Cost: COW - 237.47 14.597 0.011 -> 0 28.8822957451 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.3106204277 0
% INFO    : Updated Generator Cost: NG - 237.47 14.597 0.011 -> 0 48.0565015924 0
% INFO    : Updated Generator Cost: NG - 261.09 14.426 0.009 -> 0 21.5683276568 0
% INFO    : Updated Generator Cost: NG - 261.09 14.426 0.009 -> 0 56.8101012618 0
% INFO    : Updated Generator Cost: NG - 312.1 14.099 0.008 -> 0 49.9500877052 0
% INFO    : Updated Generator Cost: NG - 312.1 14.099 0.008 -> 0 46.3207153342 0
% INFO    : Updated Generator Cost: NG - 312.1 14.099 0.008 -> 0 38.0967342198 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 40.2628378658 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 101.201576296 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.6616003121 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 34.018489255 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 11.0856075584 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 11.3558517122 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 22.7888350764 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 31.531307085 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 56.6841692081 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.3439336352 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 26.7440472297 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 10.1373912621 0
% INFO    : Updated Generator Cost: NG - 273.09 34.379 0.052 -> 0 41.333553493 0
% INFO    : Updated Generator Cost: PEL - 273.09 34.379 0.052 -> 0 106.178535219 0
% INFO    : Updated Generator Cost: PEL - 273.09 34.379 0.052 -> 0 114.534570518 0
% INFO    : Updated Generator Cost: PEL - 112.42 34.988 0.132 -> 0 92.6066209519 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 103.572085228 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.2452070752 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 113.438338175 0
% INFO    : Updated Generator Cost: NG - 222.34 34.987 0.066 -> 0 53.0022443553 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 119.619542465 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 35.5919869825 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 96.6788280712 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.333073501 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 86.3019397557 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 26.4346613281 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 123.228908661 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 37.2630587644 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 29.9414537471 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 27.9663386086 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 38.3041960228 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 104.691222477 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 33.90134179 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 130.399803454 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.3459694657 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 32.6161282323 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 45.6776717782 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 46.6095840565 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.0782098878 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.1418146034 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 32.3361156192 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 28.8159213204 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 19.9289222225 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 114.539247813 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 14.6256851332 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 33.5318364894 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 98.7141654236 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 33.5939881026 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 107.110310729 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.9526265993 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.4471024626 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 108.651650945 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 18.0914869447 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 27.3023376604 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 118.026510153 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.3128340634 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 48.9657651214 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 47.5850425357 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 102.337270865 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.664306317 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 101.475404358 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 20.3354978165 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 27.808452262 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 112.36912035 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.9626378389 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 92.1640555548 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 98.365660898 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 122.367502567 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 112.733479196 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 15.5970840461 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 54.0978943897 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 42.1144425139 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 105.633034909 0
% INFO    : Updated Generator Cost: NG - 51.99 16.01 0.06 -> 0 49.7809381624 0
% INFO    : Updated Generator Cost: NG - 232.59 34.946 0.064 -> 0 40.6210151293 0
% INFO    : Updated Generator Cost: NG - 101.18 34.988 0.147 -> 0 45.2340804978 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 105.224869005 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 95.0174911714 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 3.27945689637 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 114.064517728 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 117.546285686 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 115.438558981 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 116.76799304 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 113.264717472 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 116.594944675 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 119.023342763 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 107.122973859 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 43.5012774707 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 100.042543523 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 44.8350294665 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 108.024613969 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 103.253436518 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 121.064304922 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 103.728109331 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 121.388376584 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 111.873448296 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 132.864587296 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 103.79260785 0
% INFO    : Updated Generator Cost: COW - 1318.5 12.513 0.002 -> 0 27.0522040909 0
% INFO    : Updated Generator Cost: COW - 1091.8 12.957 0.002 -> 0 29.6634413244 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 34.7555196286 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 23.7235452759 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 14.2926110115 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 47.1692104992 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 42.6642568646 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.9434146029 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 41.7119743358 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 42.9696548564 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 49.9332619138 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 57.6205182891 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 31.7151107154 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 44.8674323471 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 39.1905646276 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 47.1226797047 0
% INFO    : Updated Generator Cost: NG - 260.4 14.428 0.01 -> 0 36.2369673856 0
% INFO    : Updated Generator Cost: COW - 544.02 13.307 0.004 -> 0 24.4373430324 0
% INFO    : Updated Generator Cost: NG - 892.27 13.33 0.002 -> 0 33.0275148969 0
% INFO    : Updated Generator Cost: COW - 399.82 23.145 0.017 -> 0 29.3614798343 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 134.894642753 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 118.763617128 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 27.7748340591 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 46.8339134042 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 14.7801431682 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 98.6309057142 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 28.9833992887 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 43.3758234939 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 17.2282470652 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 44.0238884406 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 33.34440695 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 49.7314994717 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 35.3032496364 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 22.1162961259 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 20.2073078764 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 116.691284864 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 41.871065599 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 38.8840945 0
% INFO    : Updated Generator Cost: NG - 142.48 25.268 0.077 -> 0 28.8216795456 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 34.7896533831 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 29.6631122749 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 32.5041639585 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 11.4927513841 0
% INFO    : Updated Generator Cost: NG - 381.02 13.819 0.006 -> 0 52.8508193457 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.8659756828 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 39.42062596 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 113.803411996 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 101.610716472 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 45.9296323779 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 31.7113567612 0
% INFO    : Updated Generator Cost: NG - 196.96 14.869 0.014 -> 0 26.589236913 0
% INFO    : Updated Generator Cost: PEL - 151.3 15.408 0.019 -> 0 110.90534779 0
% INFO    : Updated Generator Cost: COW - 0.38 17.2 0.004 -> 0 32.6089686086 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 102.6756009 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 22.3669686527 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 120.25218308 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 106.075761685 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 112.991390436 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 45.1386872366 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 34.7392613828 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 24.0726329151 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 17.9280093904 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 34.1632845008 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 54.4219284402 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 55.0088994267 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 33.048968556 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 54.0799772074 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 91.2298503758 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 53.8771254073 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 44.7792873606 0
% INFO    : Updated Generator Cost: PEL - 98.78 23.025 0.065 -> 0 138.110758439 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 45.6501154802 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 22.6519001122 0
% INFO    : Updated Generator Cost: NG - 97.72 16.01 0.031 -> 0 19.9725536607 0
% INFO    : Updated Generator Cost: NG - 155.41 15.368 0.018 -> 0 26.5373436299 0
% INFO    : Updated Generator Cost: COW - 1497.9 12.513 0.002 -> 0 28.1213535804 0
% INFO    : Updated Generator Cost: COW - 1133.08 12.834 0.002 -> 0 16.7088682152 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 40.465110861 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 23.5333796782 0
% INFO    : Updated Generator Cost: NG - 77.48 16.01 0.042 -> 0 37.2471267903 0
% INFO    : Updated Generator Cost: NG - 453.47 13.569 0.005 -> 0 36.7496199869 0
% INFO    : Updated Generator Cost: PEL - 140.12 25.275 0.078 -> 0 107.283913856 0
% INFO    : Updated Generator Cost: NG - 140.12 25.275 0.078 -> 0 21.0277047898 0
% INFO    : Updated Generator Cost: NG - 248.51 24.503 0.03 -> 0 33.2028657872 0
% INFO    : Updated Generator Cost: PEL - 138.85 25.285 0.081 -> 0 119.498435512 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 41.2917426691 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 30.5272125186 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 25.3409501164 0
% INFO    : Updated Generator Cost: COW - 139.88 25.278 0.078 -> 0 37.6488200355 0
% INFO    : Updated Generator Cost: PEL - 131.73 25.33 0.088 -> 0 132.891156184 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 98.2909972971 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 99.4942375053 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 126.843488256 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 111.942615996 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 114.755289131 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 120.091479838 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 102.61585226 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 115.50345126 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 126.174981155 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 113.348103839 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 133.502237066 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 112.903092961 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 121.05247763 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 120.119755889 0
% INFO    : Updated Generator Cost: COW - 0.38 17.2 0.004 -> 0 23.7200258663 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 15.6207228984 0
% INFO    : Updated Generator Cost: NG - 51.26 16.01 0.061 -> 0 28.531730169 0
% INFO    : Updated Generator Cost: NG - 78.41 16.01 0.041 -> 0 41.4769517485 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 110.194431382 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 114.538438039 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 108.648505147 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 104.60428434 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 113.424181798 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 112.084709261 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 99.2089936259 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 126.125981809 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 100.045106637 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 95.2575440587 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 98.7389243642 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 104.931628995 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 9.76232425828 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 20.3672639192 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 22.9301260469 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 108.233744726 0
% INFO    : Updated Generator Cost: NG - 268.61 14.423 0.009 -> 0 42.2661335049 0
% INFO    : Updated Generator Cost: PEL - 46.46 16.01 0.067 -> 0 128.230666205 0
% INFO    : Updated Generator Cost: NG - 102.4 15.995 0.03 -> 0 26.5171241723 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 107.661475535 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 35.6694611517 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 31.3696311166 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 14.7036601657 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 104.202456106 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 109.077900369 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 26.4623545409 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 18.2209512387 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 66.8567362088 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 21.8141133344 0
% INFO    : Updated Generator Cost: PEL - 41.34 16.01 0.076 -> 0 115.441725412 0
% INFO    : Updated Generator Cost: NG - 41.34 16.01 0.076 -> 0 45.1346027788 0
% INFO    : Updated Generator Cost: NG - 41.34 16.01 0.076 -> 0 25.1255836565 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 27.6820044778 0
% INFO    : Updated Generator Cost: NG - 40.83 16.01 0.076 -> 0 43.046274966 0
% INFO    : Updated Generator Cost: NG - 40.83 16.01 0.076 -> 0 30.5426795391 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 38.8740795466 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 17.4540157577 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 30.9450129717 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 7.60802696633 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 31.8790540282 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 20.7190137877 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 43.2706637054 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 15.6370424048 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 21.9514542029 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 43.7932189328 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 26.9330252356 0
% INFO    : Updated Generator Cost: NUC - 0.0 0.0 0.0 -> 0 7.3892954988 0
% INFO    : Updated Generator Cost: COW - 1448.4 12.513 0.002 -> 0 24.7899179695 0
% INFO    : Updated Generator Cost: COW - 1448.4 12.513 0.002 -> 0 28.0716076712 0
% INFO    : Updated Generator Cost: COW - 1024.6 13.087 0.002 -> 0 29.6163683682 0
% INFO    : Updated Generator Cost: COW - 1024.6 13.087 0.002 -> 0 22.8223975661 0
% INFO    : Updated Generator Cost: COW - 1019.52 13.1 0.002 -> 0 21.4135271272 0
% INFO    : Updated Generator Cost: COW - 1019.52 13.1 0.002 -> 0 22.3039762924 0
% INFO    : Updated Generator Cost: COW - 969.33 13.215 0.002 -> 0 22.9546863208 0
% INFO    : Updated Generator Cost: COW - 969.33 13.215 0.002 -> 0 27.086485495 0
% INFO    : Updated Generator Cost: NG - 958.07 13.244 0.002 -> 0 24.5562571197 0
% INFO    : Updated Generator Cost: COW - 945.17 13.269 0.002 -> 0 19.5177545666 0
% INFO    : Updated Generator Cost: COW - 945.17 13.269 0.002 -> 0 33.0244696042 0
% INFO    : Updated Generator Cost: COW - 733.81 13.219 0.002 -> 0 28.156144818 0
% INFO    : Updated Generator Cost: NG - 504.56 87.0 0.182 -> 0 50.7087471436 0
% INFO    : Updated Generator Cost: NG - 504.56 87.0 0.182 -> 0 48.8624376704 0
% INFO    : Updated Generator Cost: NG - 504.56 87.0 0.182 -> 0 33.6028223179 0
% INFO    : Updated Generator Cost: PEL - 504.56 87.0 0.182 -> 0 123.26923279 0
% INFO    : Updated Generator Cost: NG - 504.56 87.0 0.182 -> 0 51.3524496751 0
% INFO    : Updated Generator Cost: NG - 662.09 13.165 0.003 -> 0 46.0653634113 0
% INFO    : Updated Generator Cost: COW - 593.71 13.159 0.004 -> 0 25.6030770157 0
% INFO    : Updated Generator Cost: NG - 942.55 13.28 0.002 -> 0 35.8992705871 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 23.3837671922 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 34.0715948542 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 30.8857357887 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 13.8006115433 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 35.3291766827 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 40.159711173 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 29.8909901371 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 41.2530079583 0
% INFO    : Updated Generator Cost: NG - 571.27 13.208 0.004 -> 0 26.0379526169 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 54.1264533052 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 34.2198461138 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 24.3537194468 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 28.1838526321 0
% INFO    : Updated Generator Cost: NG - 523.4 13.381 0.004 -> 0 30.7062789034 0
% INFO    : Updated Generator Cost: NG - 548.89 13.279 0.004 -> 0 41.421000485 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 44.8788039743 0
% INFO    : Updated Generator Cost: NG - 411.14 13.711 0.006 -> 0 30.2789088379 0
% INFO    : Updated Generator Cost: NG - 554.03 13.27 0.004 -> 0 37.5413796963 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 20.8219933732 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 18.3521467357 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 23.1115348659 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 29.515411924 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 18.5117847846 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.5694850327 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 23.3545271489 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 48.3745492241 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 44.4152572618 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 13.7063853133 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 28.6587955087 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 49.6436633652 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 19.3552611438 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 30.9257651045 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 29.3800400682 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 47.6659755047 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 22.4043884332 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 21.8027953224 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 57.277160441 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 41.1333240451 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 61.7357285481 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 43.7575003671 0
% INFO    : Updated Generator Cost: NG - 335.23 14.026 0.007 -> 0 36.4135822536 0
% INFO    : Updated Generator Cost: NG - 345.15 13.996 0.007 -> 0 48.829419109 0
% INFO    : Updated Generator Cost: NG - 485.0 13.475 0.005 -> 0 36.7774373702 0
% INFO    : Updated Generator Cost: COW - 908.7 13.345 0.002 -> 0 20.8580602917 0
% INFO    : Updated Generator Cost: NG - 335.23 14.026 0.007 -> 0 18.4073213194 0
% INFO    : Updated Generator Cost: NG - 335.23 14.026 0.007 -> 0 38.120052572 0
% INFO    : Updated Generator Cost: NG - 335.23 14.026 0.007 -> 0 38.3359670603 0
% INFO    : Updated Generator Cost: NG - 335.23 14.026 0.007 -> 0 23.3460626822 0
% INFO    : Updated Generator Cost: NG - 335.23 14.026 0.007 -> 0 27.7267934061 0
% INFO    : Updated Generator Cost: NG - 335.23 14.026 0.007 -> 0 48.6378018623 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 37.2843938238 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 38.7030315213 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 26.3682220616 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 33.2354399669 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 42.114378254 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 33.3172153193 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 11.5817338886 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 21.4700783882 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 14.3711750227 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 30.2281892299 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 23.3009972785 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 52.4182207515 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 33.7243918408 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 20.7195284246 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 47.0107192671 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 10.9490610234 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 13.5084614049 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 45.6588892435 0
% INFO    : Updated Generator Cost: NG - 249.16 14.529 0.01 -> 0 30.1546742438 0
% INFO    : Updated Generator Cost: NG - 459.26 13.544 0.005 -> 0 26.5785217564 0
% INFO    : Updated Generator Cost: NG - 559.73 13.245 0.004 -> 0 13.4558862189 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 49.140121525 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 36.2492160342 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 31.2665349466 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 31.4587028484 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 44.5553714562 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 40.8990718803 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 122.175077031 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 16.7479537312 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.0481573955 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 45.4591796665 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 11.6427800856 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 54.207016592 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 43.1229172014 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 19.2418620263 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 34.484662881 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 23.4552378522 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 30.0432733134 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 58.4301861997 0
% INFO    : Updated Generator Cost: NG - 205.93 14.813 0.013 -> 0 21.7883951 0
% INFO    : Updated Generator Cost: NG - 168.53 25.168 0.062 -> 0 30.6041108377 0
% INFO    : Updated Generator Cost: NG - 168.53 25.168 0.062 -> 0 31.884647572 0
% INFO    : Updated Generator Cost: PEL - 168.53 25.168 0.062 -> 0 119.631485189 0
% INFO    : Updated Generator Cost: NG - 592.95 13.166 0.004 -> 0 25.1009712593 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 45.9143444705 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 45.5323209314 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 22.0758608323 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 28.9028446954 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 32.5031842368 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 46.7330410874 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 28.4369460397 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 15.0053506475 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 25.1155015603 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 25.0954101656 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 37.9552715622 0
% INFO    : Updated Generator Cost: NG - 376.36 13.834 0.006 -> 0 5.31368150976 0
% INFO    : Updated Generator Cost: NG - 173.25 15.126 0.016 -> 0 40.8947334525 0
% INFO    : Updated Generator Cost: COW - 173.25 15.126 0.016 -> 0 22.5653930674 0
% INFO    : Updated Generator Cost: NG - 399.56 13.752 0.006 -> 0 8.98213128235 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 45.550280591 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.2890456733 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 22.0308706791 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 41.5631985856 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 57.8793638268 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.1363601928 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 24.113538288 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 31.2527672319 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 45.7120711745 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 32.9731109491 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 12.4635510182 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 100.937015783 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 41.6416853006 0
% INFO    : Updated Generator Cost: PEL - 244.41 24.554 0.031 -> 0 125.026373601 0
% INFO    : Updated Generator Cost: NG - 147.2 15.439 0.02 -> 0 45.2851205194 0
% INFO    : Updated Generator Cost: NG - 403.1 13.747 0.006 -> 0 41.4435646476 0
% INFO    : Updated Generator Cost: PEL - 142.73 15.499 0.02 -> 0 116.067130463 0
% INFO    : Updated Generator Cost: COW - 202.06 14.835 0.013 -> 0 16.6734934523 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 44.0714491104 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 110.551836014 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 25.7402002054 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 20.9237519543 0
% INFO    : Updated Generator Cost: COW - 0.38 17.2 0.004 -> 0 15.2935927426 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 54.0022532209 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 36.4884610779 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 26.0599315003 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 27.8909443874 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.5120859529 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 34.8713434029 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 105.88722696 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 47.1977160857 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 54.1345107739 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 30.8898572189 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 37.4335367973 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 111.811107253 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 31.5503593437 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 41.3466771926 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 104.933231778 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 38.7983469977 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 22.8481547431 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 39.5893730156 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 24.2264648644 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 56.9006497268 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 122.041340837 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 99.1786005025 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.1148009373 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.6355210913 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 25.1126762492 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.0289877239 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 41.2042917536 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 48.5556676914 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 99.0819514251 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 21.6231096197 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 33.3886018951 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 40.0855519882 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 117.474023148 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 105.747986983 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 29.8800799062 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 14.6842806774 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 31.9708782007 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 23.6949312674 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.5695664285 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.4432978761 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 32.6293195711 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 16.9799456921 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 35.2363041286 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 30.78099563 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 44.7259988062 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 104.777291982 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 125.380493864 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 32.6491025419 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 43.8620105526 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 11.3230162584 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 33.5879479158 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.8050975866 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 37.6715819563 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 26.8571511171 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 54.4413552224 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.9935487783 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 23.9105793776 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 29.3537178549 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 25.7310724823 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 22.9942772174 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 21.6645569812 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 21.2505004135 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 26.1724186405 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 116.923286653 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 111.087380051 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 123.745963195 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 40.2786473357 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 107.260773212 0
% INFO    : Updated Generator Cost: NG - 200.26 14.857 0.014 -> 0 44.0721340453 0
% INFO    : Updated Generator Cost: NG - 151.41 15.399 0.019 -> 0 44.2204376842 0
% INFO    : Updated Generator Cost: PEL - 66.29 16.01 0.049 -> 0 122.527228429 0
% INFO    : Updated Generator Cost: NG - 66.29 16.01 0.049 -> 0 35.6620318948 0
% INFO    : Updated Generator Cost: PEL - 66.29 16.01 0.049 -> 0 112.543879485 0
% INFO    : Updated Generator Cost: COW - 66.29 16.01 0.049 -> 0 28.7300599874 0
% INFO    : Updated Generator Cost: COW - 66.29 16.01 0.049 -> 0 15.9834526473 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 116.054848411 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 113.824374426 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 104.272668155 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 96.9557835588 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 107.929264423 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 88.495174043 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 113.422013992 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 54.5927139384 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 113.276552285 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 115.1686343 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 116.284644198 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 119.818849331 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 111.766110548 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 111.483606081 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 116.854012286 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 118.264684958 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 127.101888402 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 37.0834620972 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 114.659897517 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 38.3483157611 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 26.2084925706 0
% INFO    : Updated Generator Cost: COW - 78.78 26.977 0.114 -> 0 32.7802963552 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 47.0812415606 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 116.902174139 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 103.593531884 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 123.143607962 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 35.1879705295 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 116.565242921 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 139.043179389 0
% INFO    : Updated Generator Cost: NG - 129.86 25.333 0.088 -> 0 45.3630080255 0
% INFO    : Updated Generator Cost: NG - 129.86 25.333 0.088 -> 0 37.8942480165 0
% INFO    : Updated Generator Cost: NG - 129.86 25.333 0.088 -> 0 47.3956710739 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 21.411807993 0
% INFO    : Updated Generator Cost: PEL - 197.07 25.041 0.044 -> 0 126.321452626 0
% INFO    : Updated Generator Cost: NG - 197.07 25.041 0.044 -> 0 18.4595747806 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 38.7319465578 0
% INFO    : Updated Generator Cost: NG - 197.07 25.041 0.044 -> 0 48.6450667024 0
% INFO    : Updated Generator Cost: PEL - 197.07 25.041 0.044 -> 0 120.336959802 0
% INFO    : Updated Generator Cost: PEL - 197.07 25.041 0.044 -> 0 109.637001023 0
% INFO    : Updated Generator Cost: PEL - 197.07 25.041 0.044 -> 0 103.961990471 0
% INFO    : Updated Generator Cost: NG - 197.07 25.041 0.044 -> 0 28.2733915813 0
% INFO    : Updated Generator Cost: PEL - 197.07 25.041 0.044 -> 0 135.74768972 0
% INFO    : Updated Generator Cost: NG - 197.07 25.041 0.044 -> 0 37.8478961115 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 21.0696155616 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 98.8791753686 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 10.9913701986 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 37.0546465495 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 43.7866304172 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 16.8675074965 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 47.6163080655 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 101.954498166 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.7470224194 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 112.648890603 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 97.4494673083 0
% INFO    : Updated Generator Cost: COW - 46.26 16.01 0.067 -> 0 21.121180446 0
% INFO    : Updated Generator Cost: COW - 1755.23 50.578 0.008 -> 0 24.2594118788 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 45.6315255415 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 112.411799355 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.5295700512 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 17.85183859 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 43.6882585801 0
% INFO    : Updated Generator Cost: COW - 1524.2 12.513 0.002 -> 0 19.1093288777 0
% INFO    : Updated Generator Cost: COW - 1233.11 12.663 0.002 -> 0 26.9365695993 0
% INFO    : Updated Generator Cost: COW - 1233.11 12.663 0.002 -> 0 27.0116271359 0
% INFO    : Updated Generator Cost: NG - 908.82 13.347 0.002 -> 0 33.0932976475 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 42.7968543061 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 23.992266205 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 18.2838121532 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 16.936718232 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 55.6813440596 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 53.8715901899 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 34.2514532979 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 32.8040203272 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 17.7094723424 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 25.8387288084 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 38.9474358866 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 27.458695537 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 38.4620691245 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 18.742580701 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.8158390207 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 28.7086126116 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 30.0788097351 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 126.659401333 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 27.9581279638 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 50.1898347897 0
% INFO    : Updated Generator Cost: NG - 315.71 23.7 0.022 -> 0 27.4050797154 0
% INFO    : Updated Generator Cost: PEL - 315.71 23.7 0.022 -> 0 96.3772339173 0
% INFO    : Updated Generator Cost: NG - 315.71 23.7 0.022 -> 0 50.2838211351 0
% INFO    : Updated Generator Cost: COW - 249.52 24.472 0.03 -> 0 23.8697005089 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 1.43509096868 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 29.6246653537 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 17.2052431232 0
% INFO    : Updated Generator Cost: PEL - 186.72 14.954 0.015 -> 0 118.235606615 0
% INFO    : Updated Generator Cost: PEL - 186.72 14.954 0.015 -> 0 102.093885877 0
% INFO    : Updated Generator Cost: COW - 186.72 14.954 0.015 -> 0 11.6780402017 0
% INFO    : Updated Generator Cost: PEL - 186.72 14.954 0.015 -> 0 105.009323446 0
% INFO    : Updated Generator Cost: NG - 108.62 15.942 0.028 -> 0 41.6581072952 0
% INFO    : Updated Generator Cost: NG - 51.38 16.01 0.061 -> 0 49.8660416925 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 25.5066700321 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 35.4105031144 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 15.028102584 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 114.80397705 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 19.0781780019 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 22.0680805451 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 53.3003093337 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 29.8887491487 0
% INFO    : Updated Generator Cost: NG - 162.06 15.295 0.018 -> 0 25.8794114264 0
% INFO    : Updated Generator Cost: NG - 162.06 15.295 0.018 -> 0 23.7250317804 0
% INFO    : Updated Generator Cost: NG - 162.06 15.295 0.018 -> 0 40.7342189089 0
% INFO    : Updated Generator Cost: PEL - 150.0 15.432 0.02 -> 0 116.855860372 0
% INFO    : Updated Generator Cost: NG - 150.0 15.432 0.02 -> 0 57.0583232683 0
% INFO    : Updated Generator Cost: NG - 567.99 13.235 0.004 -> 0 18.6763321817 0
% INFO    : Updated Generator Cost: NG - 844.66 13.303 0.002 -> 0 36.5735235657 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 111.586974971 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 12.669279058 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 36.8334155352 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.6431585828 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 16.9338740511 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 120.21927162 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 23.8182272248 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 116.4528496 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 28.5520291329 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 121.729272075 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 132.025896642 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 117.446942673 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 25.7996495087 0
% INFO    : Updated Generator Cost: NG - 269.35 34.455 0.053 -> 0 22.279671582 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 31.9504324345 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 41.307366542 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 126.296641766 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 107.454772694 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 115.669428872 0
% INFO    : Updated Generator Cost: NG - 110.54 15.913 0.028 -> 0 43.0910771184 0
% INFO    : Updated Generator Cost: NG - 150.21 15.431 0.019 -> 0 27.8855278887 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 47.2841760054 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.4587535723 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 108.564343844 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 44.7535862861 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 19.270021172 0
% INFO    : Updated Generator Cost: NG - 215.97 34.988 0.07 -> 0 20.9783144739 0
% INFO    : Updated Generator Cost: NG - 215.97 34.988 0.07 -> 0 24.2633045786 0
% INFO    : Updated Generator Cost: COW - 215.97 34.988 0.07 -> 0 32.0481697577 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 28.717719227 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 21.3639367471 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 14.0366946997 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 83.9038104638 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 18.0348058577 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 32.5653182441 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 38.2860046879 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 102.592162338 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 118.298586958 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 117.211222353 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 102.172370773 0
% INFO    : Updated Generator Cost: NG - 163.29 34.988 0.091 -> 0 32.8677685715 0
% INFO    : Updated Generator Cost: PEL - 157.33 34.988 0.095 -> 0 102.615776486 0
% INFO    : Updated Generator Cost: COW - 163.78 34.988 0.09 -> 0 37.3883366526 0
% INFO    : Updated Generator Cost: NG - 136.4 25.308 0.083 -> 0 40.641143272 0
% INFO    : Updated Generator Cost: NG - 129.43 34.988 0.116 -> 0 35.1281842525 0
% INFO    : Updated Generator Cost: NG - 129.43 34.988 0.116 -> 0 36.8179948787 0
% INFO    : Updated Generator Cost: NG - 129.43 34.988 0.116 -> 0 38.8623544874 0
% INFO    : Updated Generator Cost: PEL - 129.43 34.988 0.116 -> 0 111.950858814 0
% INFO    : Updated Generator Cost: PEL - 129.43 34.988 0.116 -> 0 115.983829382 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 125.929757125 0
% INFO    : Updated Generator Cost: NG - 122.35 34.988 0.119 -> 0 44.2834836939 0
% INFO    : Updated Generator Cost: NG - 189.09 34.988 0.081 -> 0 16.4563770319 0
% INFO    : Updated Generator Cost: NG - 128.18 25.336 0.088 -> 0 18.6778214721 0
% INFO    : Updated Generator Cost: NG - 128.18 25.336 0.088 -> 0 53.4990239004 0
% INFO    : Updated Generator Cost: NG - 128.18 25.336 0.088 -> 0 33.4653543699 0
% INFO    : Updated Generator Cost: NG - 128.18 25.336 0.088 -> 0 31.1402819819 0
% INFO    : Updated Generator Cost: NG - 116.37 34.988 0.127 -> 0 32.8733109851 0
% INFO    : Updated Generator Cost: PEL - 116.37 34.988 0.127 -> 0 111.555044733 0
% INFO    : Updated Generator Cost: NG - 114.07 34.988 0.13 -> 0 27.1661310994 0
% INFO    : Updated Generator Cost: NG - 114.07 34.988 0.13 -> 0 5.03996709156 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 36.9285933275 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 44.1922018733 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 28.3256501237 0
% INFO    : Updated Generator Cost: COW - 0.38 17.2 0.004 -> 0 14.9422492688 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 28.4333032709 0
% INFO    : Updated Generator Cost: NG - 103.94 34.988 0.143 -> 0 43.7500608853 0
% INFO    : Updated Generator Cost: NG - 103.94 34.988 0.143 -> 0 31.9097998138 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 98.6421291851 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 36.8260750663 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 28.9159026082 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 113.15581738 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 48.5946010568 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 35.5049355095 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 99.4448620164 0
% INFO    : Updated Generator Cost: PEL - 66.07 25.538 0.125 -> 0 119.303901789 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 45.0437527194 0
% INFO    : Updated Generator Cost: COW - 1100.3 12.93 0.002 -> 0 43.0010429038 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 115.175612781 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 31.6555946807 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 31.5946615476 0
% INFO    : Updated Generator Cost: COW - 942.55 13.28 0.002 -> 0 16.2897512357 0
% INFO    : Updated Generator Cost: COW - 942.55 13.28 0.002 -> 0 12.5155768345 0
% INFO    : Updated Generator Cost: COW - 585.92 13.17 0.004 -> 0 12.13119067 0
% INFO    : Updated Generator Cost: NG - 539.41 13.317 0.004 -> 0 36.2932550947 0
% INFO    : Updated Generator Cost: COW - 507.81 13.408 0.004 -> 0 36.6328204319 0
% INFO    : Updated Generator Cost: NG - 516.48 13.386 0.004 -> 0 60.1861875003 0
% INFO    : Updated Generator Cost: NG - 486.01 13.475 0.005 -> 0 31.2481527524 0
% INFO    : Updated Generator Cost: COW - 486.01 13.475 0.005 -> 0 28.4373627339 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 37.779608021 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 30.020489931 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 32.9616557966 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 37.5284329141 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 25.8600143827 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.1764141334 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 15.5579802999 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 27.4756911327 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 40.3285284583 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 40.1553749207 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 19.9982963983 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 39.3370431847 0
% INFO    : Updated Generator Cost: NG - 333.94 14.027 0.007 -> 0 31.5336335875 0
% INFO    : Updated Generator Cost: NG - 333.94 14.027 0.007 -> 0 25.0427556125 0
% INFO    : Updated Generator Cost: NG - 333.94 14.027 0.007 -> 0 39.1249485324 0
% INFO    : Updated Generator Cost: NG - 333.94 14.027 0.007 -> 0 31.9467404093 0
% INFO    : Updated Generator Cost: PEL - 333.94 14.027 0.007 -> 0 103.65158337 0
% INFO    : Updated Generator Cost: NG - 111.52 15.898 0.027 -> 0 42.1808608617 0
% INFO    : Updated Generator Cost: NG - 156.82 15.343 0.018 -> 0 42.5438391062 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 29.3699424642 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 48.8059141613 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 28.5479147778 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 20.3253335199 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 34.8398589958 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 50.9768001947 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 15.9353228358 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 32.3499789208 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 19.6143260062 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 37.8823786357 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 35.9126197747 0
% INFO    : Updated Generator Cost: NG - 404.69 23.122 0.016 -> 0 29.7090740667 0
% INFO    : Updated Generator Cost: COW - 404.69 23.122 0.016 -> 0 17.0960891108 0
% INFO    : Updated Generator Cost: NG - 214.81 14.754 0.012 -> 0 43.1876671506 0
% INFO    : Updated Generator Cost: NG - 214.81 14.754 0.012 -> 0 40.5834060484 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.9897575894 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 27.7427842599 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.6949077072 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 35.9223158407 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 53.0527479815 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 25.0433257655 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 22.1639434997 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 20.0735086072 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 41.8897864764 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 36.2108771145 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 34.1464774048 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 43.926044153 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.2094663835 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 28.1313887983 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 45.3550166706 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 50.6556586459 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 41.3374209794 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 32.1871749671 0
% INFO    : Updated Generator Cost: NG - 138.68 15.574 0.022 -> 0 35.0097110078 0
% INFO    : Updated Generator Cost: NG - 547.43 13.284 0.004 -> 0 41.5470374973 0
% INFO    : Updated Generator Cost: NG - 632.85 13.139 0.003 -> 0 10.130810585 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 101.257288304 0
% INFO    : Updated Generator Cost: NG - 123.09 15.775 0.025 -> 0 27.2277688266 0
% INFO    : Updated Generator Cost: NG - 123.09 15.775 0.025 -> 0 46.6959228724 0
% INFO    : Updated Generator Cost: COW - 123.09 15.775 0.025 -> 0 16.9102971634 0
% INFO    : Updated Generator Cost: NG - 123.09 15.775 0.025 -> 0 43.4309582393 0
% INFO    : Updated Generator Cost: PEL - 41.69 16.01 0.075 -> 0 107.558407365 0
% INFO    : Updated Generator Cost: NG - 156.46 15.348 0.018 -> 0 46.0522961697 0
% INFO    : Updated Generator Cost: COW - 121.3 15.788 0.025 -> 0 6.70206308449 0
% INFO    : Updated Generator Cost: NG - 545.41 13.297 0.004 -> 0 22.0353708709 0
% INFO    : Updated Generator Cost: COW - 908.7 13.345 0.002 -> 0 25.6319906032 0
% INFO    : Updated Generator Cost: NG - 1.54 27.269 0.123 -> 0 33.6946172434 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 33.1892678439 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 25.327662367 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 46.9484903273 0
% INFO    : Updated Generator Cost: NG - 271.23 14.416 0.009 -> 0 15.6334779743 0
% INFO    : Updated Generator Cost: NG - 155.98 15.352 0.018 -> 0 37.2401388961 0
% INFO    : Updated Generator Cost: NG - 104.89 15.979 0.03 -> 0 54.6487437432 0
% INFO    : Updated Generator Cost: PEL - 139.2 15.558 0.021 -> 0 105.242077031 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 44.6898499454 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 49.139956715 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 32.8512093211 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 31.3938287611 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 109.263550036 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 100.369656684 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 40.306303156 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 24.1313488225 0
% INFO    : Updated Generator Cost: PEL - 243.31 24.565 0.031 -> 0 117.826636089 0
% INFO    : Updated Generator Cost: PEL - 243.31 24.565 0.031 -> 0 101.927755195 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 110.684223429 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 54.1419890233 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 32.32833494 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 15.5884985404 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.6554703453 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 22.2597939214 0
% INFO    : Updated Generator Cost: NG - 154.91 34.988 0.098 -> 0 36.1873146953 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 126.89471485 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 32.0307060471 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 23.7726162778 0
% INFO    : Updated Generator Cost: PEL - 148.61 34.988 0.103 -> 0 107.854477733 0
% INFO    : Updated Generator Cost: NG - 148.61 34.988 0.103 -> 0 26.6807876844 0
% INFO    : Updated Generator Cost: NG - 148.61 34.988 0.103 -> 0 23.3211783569 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.3083597601 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 43.140555378 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.5851526057 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 38.917710833 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 44.8721966157 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.3936975329 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 45.2013233028 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 37.3434229275 0
% INFO    : Updated Generator Cost: NG - 140.79 34.988 0.11 -> 0 22.9209134245 0
% INFO    : Updated Generator Cost: COW - 140.79 34.988 0.11 -> 0 22.9553952711 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 19.5506599716 0
% INFO    : Updated Generator Cost: COW - 0.38 17.2 0.004 -> 0 26.1908037237 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 14.99259149 0
% INFO    : Updated Generator Cost: NG - 88.22 34.988 0.168 -> 0 35.0767169861 0
% INFO    : Updated Generator Cost: PEL - 88.22 34.988 0.168 -> 0 100.9767374 0
% INFO    : Updated Generator Cost: NG - 126.51 25.337 0.09 -> 0 34.3513245318 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 100.904520338 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 38.055293667 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 45.7712095247 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.8900646933 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.0657855789 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 104.714170574 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 33.6687394632 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 119.96192815 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.501718673 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 24.2900160148 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 129.472573321 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 28.1537979894 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 110.637280283 0
% INFO    : Updated Generator Cost: NG - 77.79 25.493 0.116 -> 0 37.5887943525 0
% INFO    : Updated Generator Cost: NG - 77.79 25.493 0.116 -> 0 45.7720737155 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 27.0839812601 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 45.687427501 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 117.348826874 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 45.9289362416 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 37.5336341068 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 37.6696445853 0
% INFO    : Updated Generator Cost: NG - 45.18 15.916 0.073 -> 0 49.5786667978 0
% INFO    : Updated Generator Cost: NG - 45.18 15.916 0.073 -> 0 35.8234772002 0
% INFO    : Updated Generator Cost: PEL - 45.18 15.916 0.073 -> 0 130.251571914 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 37.0193527613 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 9.83539282237 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 116.026361822 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 45.1302516375 0
% INFO    : Updated Generator Cost: NG - 94.09 34.988 0.153 -> 0 38.0212174746 0
% INFO    : Updated Generator Cost: NG - 94.09 34.988 0.153 -> 0 49.4258135666 0
% INFO    : Updated Generator Cost: NG - 40.75 16.01 0.077 -> 0 31.9534011052 0
% INFO    : Updated Generator Cost: NG - 70.95 16.01 0.044 -> 0 33.6008413689 0
% INFO    : Updated Generator Cost: PEL - 47.91 16.01 0.065 -> 0 108.261489739 0
% INFO    : Updated Generator Cost: NG - 183.76 25.131 0.059 -> 0 50.532463936 0
% INFO    : Updated Generator Cost: NG - 183.76 25.131 0.059 -> 0 46.7279867826 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 32.3015834068 0
% INFO    : Updated Generator Cost: NUC - 0.0 0.0 0.0 -> 0 8.33654518533 0
% INFO    : Updated Generator Cost: COW - 1461.4 12.513 0.002 -> 0 18.2360760081 0
% INFO    : Updated Generator Cost: NG - 1461.4 12.513 0.002 -> 0 40.2988847963 0
% INFO    : Updated Generator Cost: COW - 1480.11 12.513 0.002 -> 0 30.4807330376 0
% INFO    : Updated Generator Cost: NG - 1480.11 12.513 0.002 -> 0 28.1984278418 0
% INFO    : Updated Generator Cost: NG - 1126.14 12.868 0.002 -> 0 53.1273405021 0
% INFO    : Updated Generator Cost: NG - 847.6 13.304 0.002 -> 0 25.3548866992 0
% INFO    : Updated Generator Cost: COW - 1303.78 21.122 0.003 -> 0 25.3003628083 0
% INFO    : Updated Generator Cost: NG - 897.77 21.043 0.006 -> 0 20.1927407028 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 33.2608842982 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 37.8364702623 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 26.9976837342 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 18.4976447302 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 37.2040652166 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 46.6491898311 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 26.0965201203 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 46.4896439536 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 36.3902870339 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 43.0305959006 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 42.22147802 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 22.2680866658 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 19.8050088577 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 36.5579626106 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 22.7685851413 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 17.473750551 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 29.4859438874 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 59.3084525296 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 14.7450781914 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 50.7301857398 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 35.2227414438 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 28.5905201962 0
% INFO    : Updated Generator Cost: NG - 399.48 23.148 0.017 -> 0 29.4125933949 0
% INFO    : Updated Generator Cost: NG - 356.82 23.409 0.018 -> 0 30.8070448839 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 32.091367736 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 48.5898626561 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 50.9020583442 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 114.573380573 0
% INFO    : Updated Generator Cost: NG - 446.84 22.826 0.014 -> 0 41.9918244107 0
% INFO    : Updated Generator Cost: PEL - 220.06 24.882 0.035 -> 0 117.663052445 0
% INFO    : Updated Generator Cost: NG - 220.93 24.88 0.035 -> 0 35.1407529065 0
% INFO    : Updated Generator Cost: NG - 220.93 24.88 0.035 -> 0 26.9455696125 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 104.917246209 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 103.21653856 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 39.5829206016 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 56.082434819 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 34.2697324305 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 46.6477281171 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 27.1366653692 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 47.1968907712 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.4296453501 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.652619768 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.7583813569 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.5020344178 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 38.2354185181 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 26.6314400933 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 33.2304194897 0
% INFO    : Updated Generator Cost: NG - 354.58 23.451 0.019 -> 0 51.1913182855 0
% INFO    : Updated Generator Cost: COW - 1324.7 21.128 0.003 -> 0 20.2701179868 0
% INFO    : Updated Generator Cost: COW - 145.71 25.251 0.073 -> 0 27.0566050135 0
% INFO    : Updated Generator Cost: NG - 145.71 25.251 0.073 -> 0 52.1829956358 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.9144835094 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.4535518254 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 95.4745975672 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 29.7622463669 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 101.476313773 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.027999635 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 42.5469282557 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 122.502544631 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 44.886247729 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.8365737866 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 28.3317929856 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 28.0384132676 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 48.652822126 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 47.1320319873 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 100.691123956 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 104.215335893 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 24.3169250529 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 94.9966776557 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 65.9738356597 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.0217613601 0
% INFO    : Updated Generator Cost: NG - 449.85 22.816 0.014 -> 0 47.7883831065 0
% INFO    : Updated Generator Cost: NG - 122.09 25.355 0.092 -> 0 57.7535819309 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 45.4366383176 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.3815175748 0
% INFO    : Updated Generator Cost: NG - 73.03 25.511 0.121 -> 0 37.8121145703 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 38.2446041635 0
% INFO    : Updated Generator Cost: NUC - 0.0 0.0 0.0 -> 0 6.92803692215 0
% INFO    : Updated Generator Cost: COW - 1127.42 12.855 0.002 -> 0 15.6199103219 0
% INFO    : Updated Generator Cost: NG - 1524.1 21.041 0.003 -> 0 24.0870001051 0
% INFO    : Updated Generator Cost: NG - 473.45 22.671 0.013 -> 0 18.7468445062 0
% INFO    : Updated Generator Cost: COW - 303.01 21.262 0.018 -> 0 26.264205919 0
% INFO    : Updated Generator Cost: NG - 303.01 21.262 0.018 -> 0 27.5461141616 0
% INFO    : Updated Generator Cost: COW - 1466.35 21.046 0.003 -> 0 24.1396952314 0
% INFO    : Updated Generator Cost: COW - 934.93 13.296 0.002 -> 0 24.3076628297 0
% INFO    : Updated Generator Cost: NG - 1013.51 20.891 0.005 -> 0 37.4173724385 0
% INFO    : Updated Generator Cost: COW - 1582.5 18.597 0.002 -> 0 23.6321329471 0
% INFO    : Updated Generator Cost: COW - 853.07 13.305 0.002 -> 0 19.864427751 0
% INFO    : Updated Generator Cost: COW - 1755.23 50.578 0.008 -> 0 26.8519567218 0
% INFO    : Updated Generator Cost: COW - 1027.04 20.89 0.005 -> 0 13.292038548 0
% INFO    : Updated Generator Cost: COW - 1027.04 20.89 0.005 -> 0 29.2584261637 0
% INFO    : Updated Generator Cost: COW - 653.94 21.732 0.009 -> 0 22.3183082987 0
% INFO    : Updated Generator Cost: COW - 1416.32 21.191 0.003 -> 0 26.2530009702 0
% INFO    : Updated Generator Cost: NG - 1008.43 20.906 0.005 -> 0 47.980524397 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 17.7946861494 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 53.2791631938 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 41.1148929872 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 23.93601402 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 29.5790638831 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 25.0973999067 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 45.8236605614 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 91.9158959748 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 41.6845503559 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 33.5863262183 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 34.2533012922 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 111.918098901 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 105.959394135 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 30.865406392 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 32.3739578121 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 110.286503544 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.3364956288 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 4.99867728112 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 108.598011885 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 101.879462037 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 111.05646471 0
% INFO    : Updated Generator Cost: PEL - 2894.55 60.757 0.005 -> 0 116.761037145 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 47.6869395651 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 46.195805507 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 45.8398029583 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 21.8444079334 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.9102655631 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 22.8576770703 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.6411556172 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.4534927734 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 8.19501474624 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.926254257 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 28.5913427782 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 53.4730291933 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 44.9648453366 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 44.5331803656 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 60.7323060372 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 32.8698461553 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 13.3102750782 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 39.4256166366 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.7915426935 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 38.1724898698 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 25.1216541792 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 31.1420834616 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 21.7724308623 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 64.0719145092 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 32.0566482241 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 49.7441493788 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 29.2445212973 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 13.7944445083 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 32.8524006034 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 48.954779042 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 15.0106805613 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 33.1443296199 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 56.126734305 0
% INFO    : Updated Generator Cost: PEL - 474.97 22.668 0.013 -> 0 108.564831592 0
% INFO    : Updated Generator Cost: NG - 639.97 21.791 0.009 -> 0 22.7554197656 0
% INFO    : Updated Generator Cost: NG - 1507.59 21.065 0.003 -> 0 38.9100526082 0
% INFO    : Updated Generator Cost: COW - 1507.59 21.065 0.003 -> 0 26.7479222215 0
% INFO    : Updated Generator Cost: COW - 1507.59 21.065 0.003 -> 0 30.6522644071 0
% INFO    : Updated Generator Cost: COW - 341.18 23.532 0.02 -> 0 34.8660932408 0
% INFO    : Updated Generator Cost: NG - 341.18 23.532 0.02 -> 0 32.3704308274 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 113.564169052 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 54.8348572001 0
% INFO    : Updated Generator Cost: NG - 367.1 17.118 0.005 -> 0 36.1766444621 0
% INFO    : Updated Generator Cost: NG - 367.1 17.118 0.005 -> 0 19.6175126383 0
% INFO    : Updated Generator Cost: NG - 200.0 25.16 0.04 -> 0 32.7716516294 0
% INFO    : Updated Generator Cost: NG - 202.25 25.105 0.039 -> 0 34.5295534941 0
% INFO    : Updated Generator Cost: NG - 75.25 25.545 0.11 -> 0 48.5308283161 0
% INFO    : Updated Generator Cost: NG - 240.95 24.622 0.032 -> 0 22.4140492779 0
% INFO    : Updated Generator Cost: NG - 171.11 25.143 0.06 -> 0 27.273393601 0
% INFO    : Updated Generator Cost: NG - 171.11 25.143 0.06 -> 0 31.5412588976 0
% INFO    : Updated Generator Cost: NG - 346.53 23.507 0.02 -> 0 28.9955539475 0
% INFO    : Updated Generator Cost: NG - 1420.8 21.197 0.003 -> 0 35.6631243434 0
% INFO    : Updated Generator Cost: COW - 698.02 21.655 0.008 -> 0 15.9160015615 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 40.7180544367 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 46.264292579 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 104.170901423 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 23.2211493419 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 121.673279257 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 32.7086144524 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 16.5958310618 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 20.4398716975 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 48.2290451186 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 53.2945514276 0
% INFO    : Updated Generator Cost: NG - 105.06 34.988 0.139 -> 0 35.1149342431 0
% INFO    : Updated Generator Cost: NG - 121.4 34.988 0.12 -> 0 29.4450573814 0
% INFO    : Updated Generator Cost: NG - 306.82 33.937 0.046 -> 0 12.5572792956 0
% INFO    : Updated Generator Cost: NG - 306.82 33.937 0.046 -> 0 60.4073623267 0
% INFO    : Updated Generator Cost: NG - 306.82 33.937 0.046 -> 0 53.7484425495 0
% INFO    : Updated Generator Cost: NG - 306.82 33.937 0.046 -> 0 10.51468703 0
% INFO    : Updated Generator Cost: NG - 331.87 23.578 0.021 -> 0 42.1738225413 0
% INFO    : Updated Generator Cost: COW - 483.66 22.582 0.013 -> 0 23.0729697499 0
% INFO    : Updated Generator Cost: NG - 221.58 24.861 0.035 -> 0 20.6306944393 0
% INFO    : Updated Generator Cost: COW - 2305.6 19.79 0.003 -> 0 18.0977675922 0
% INFO    : Updated Generator Cost: COW - 2305.6 19.79 0.003 -> 0 16.4040078606 0
% INFO    : Updated Generator Cost: NG - 172.08 22.731 0.036 -> 0 38.8540318437 0
% INFO    : Updated Generator Cost: NG - 285.36 34.167 0.049 -> 0 43.1653117691 0
% INFO    : Updated Generator Cost: NG - 659.32 21.731 0.009 -> 0 31.098379335 0
% INFO    : Updated Generator Cost: COW - 51.34 14.879 0.053 -> 0 21.1834604403 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 120.571989791 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 44.4582550821 0
% INFO    : Updated Generator Cost: NG - 192.88 25.061 0.048 -> 0 49.4265905952 0
% INFO    : Updated Generator Cost: NG - 263.73 24.333 0.028 -> 0 27.0490053225 0
% INFO    : Updated Generator Cost: NG - 523.61 22.289 0.012 -> 0 25.7543679697 0
% INFO    : Updated Generator Cost: NG - 191.12 25.084 0.052 -> 0 26.6956290961 0
% INFO    : Updated Generator Cost: NG - 302.58 23.782 0.023 -> 0 5.08452334045 0
% INFO    : Updated Generator Cost: PEL - 122.72 15.53 0.04 -> 0 96.3022307954 0
% INFO    : Updated Generator Cost: NG - 193.09 25.06 0.047 -> 0 35.5442056021 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 54.35641042 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 46.852782114 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 54.2273439732 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 22.1759470573 0
% INFO    : Updated Generator Cost: NG - 149.77 15.375 0.033 -> 0 36.0341861911 0
% INFO    : Updated Generator Cost: PEL - 172.97 15.162 0.019 -> 0 112.629181614 0
% INFO    : Updated Generator Cost: NG - 155.15 15.341 0.028 -> 0 29.3923560025 0
% INFO    : Updated Generator Cost: NG - 155.15 15.341 0.028 -> 0 29.4204259027 0
% INFO    : Updated Generator Cost: NG - 155.15 15.341 0.028 -> 0 48.3303315643 0
% INFO    : Updated Generator Cost: NG - 155.15 15.341 0.028 -> 0 13.6384411228 0
% INFO    : Updated Generator Cost: NG - 155.15 15.341 0.028 -> 0 35.8488269858 0
% INFO    : Updated Generator Cost: NG - 42.31 15.988 0.074 -> 0 23.0565833298 0
% INFO    : Updated Generator Cost: NG - 190.9 25.093 0.052 -> 0 44.9335463862 0
% INFO    : Updated Generator Cost: NG - 247.15 24.53 0.031 -> 0 37.000435318 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 49.3825936069 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 40.384412587 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 121.66080361 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 47.7991293096 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 24.0581741126 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 33.4148834922 0
% INFO    : Updated Generator Cost: NG - 116.13 25.372 0.1 -> 0 40.4129679769 0
% INFO    : Updated Generator Cost: NG - 116.13 25.372 0.1 -> 0 43.8389254227 0
% INFO    : Updated Generator Cost: PEL - 84.3 25.545 0.094 -> 0 115.281713234 0
% INFO    : Updated Generator Cost: COW - 84.3 25.545 0.094 -> 0 27.4739719182 0
% INFO    : Updated Generator Cost: PEL - 110.37 25.39 0.102 -> 0 108.879790233 0
% INFO    : Updated Generator Cost: NG - 110.37 25.39 0.102 -> 0 39.4706753354 0
% INFO    : Updated Generator Cost: NG - 110.37 25.39 0.102 -> 0 51.2885400179 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 46.91017555 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 33.4300271287 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 44.4219029385 0
% INFO    : Updated Generator Cost: NG - 88.69 25.442 0.111 -> 0 59.0231599775 0
% INFO    : Updated Generator Cost: NG - 88.69 25.442 0.111 -> 0 39.7030275997 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 26.8700425655 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 11.683872317 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 13.9167470943 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 102.544687207 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 117.985757579 0
% INFO    : Updated Generator Cost: NG - 192.47 25.074 0.05 -> 0 24.8531654391 0
% INFO    : Updated Generator Cost: PEL - 82.47 25.486 0.115 -> 0 102.119514796 0
% INFO    : Updated Generator Cost: COW - 866.84 21.151 0.006 -> 0 32.5511845673 0
% INFO    : Updated Generator Cost: PEL - 74.78 15.836 0.063 -> 0 123.254342382 0
% INFO    : Updated Generator Cost: COW - 74.78 15.836 0.063 -> 0 29.9125742952 0
% INFO    : Updated Generator Cost: NG - 75.38 25.497 0.119 -> 0 35.9310286739 0
% INFO    : Updated Generator Cost: NG - 143.22 25.258 0.077 -> 0 39.7990763832 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 102.631074965 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 119.333430154 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 28.8468408208 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 46.6304119264 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 104.93802163 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 123.115024078 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 50.6440011245 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 134.109898997 0
% INFO    : Updated Generator Cost: NG - 65.76 25.54 0.126 -> 0 26.0581940589 0
% INFO    : Updated Generator Cost: PEL - 83.99 25.477 0.114 -> 0 101.768509693 0
% INFO    : Updated Generator Cost: PEL - 92.66 34.988 0.158 -> 0 105.092602829 0
% INFO    : Updated Generator Cost: COW - 111.67 34.988 0.132 -> 0 18.1900554873 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 9.5220799407 0
% INFO    : Updated Generator Cost: COW - 1484.1 12.513 0.002 -> 0 24.5340650286 0
% INFO    : Updated Generator Cost: COW - 1150.6 12.826 0.002 -> 0 13.127317302 0
% INFO    : Updated Generator Cost: COW - 1004.8 13.139 0.002 -> 0 23.6680486517 0
% INFO    : Updated Generator Cost: COW - 1004.8 13.139 0.002 -> 0 20.2794242362 0
% INFO    : Updated Generator Cost: COW - 957.49 13.257 0.002 -> 0 35.7225894328 0
% INFO    : Updated Generator Cost: NG - 957.49 13.257 0.002 -> 0 23.8456124931 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 38.705753275 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 11.5715311204 0
% INFO    : Updated Generator Cost: COW - 903.0 13.345 0.002 -> 0 8.12253248864 0
% INFO    : Updated Generator Cost: COW - 947.13 13.259 0.002 -> 0 24.61175739 0
% INFO    : Updated Generator Cost: COW - 947.13 13.259 0.002 -> 0 26.3242526252 0
% INFO    : Updated Generator Cost: COW - 868.88 13.318 0.002 -> 0 25.9469333487 0
% INFO    : Updated Generator Cost: COW - 868.88 13.318 0.002 -> 0 30.0849467554 0
% INFO    : Updated Generator Cost: COW - 829.03 13.29 0.002 -> 0 17.8080377194 0
% INFO    : Updated Generator Cost: COW - 829.03 13.29 0.002 -> 0 29.9839549404 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.6331168523 0
% INFO    : Updated Generator Cost: PEL - 590.89 26.977 0.015 -> 0 119.775240745 0
% INFO    : Updated Generator Cost: NG - 590.89 26.977 0.015 -> 0 50.9071496591 0
% INFO    : Updated Generator Cost: PEL - 590.89 26.977 0.015 -> 0 115.183503273 0
% INFO    : Updated Generator Cost: NG - 590.89 26.977 0.015 -> 0 32.9227608262 0
% INFO    : Updated Generator Cost: NG - 590.89 26.977 0.015 -> 0 42.6167217391 0
% INFO    : Updated Generator Cost: NG - 590.89 26.977 0.015 -> 0 40.8877808804 0
% INFO    : Updated Generator Cost: COW - 590.89 26.977 0.015 -> 0 26.2596388312 0
% INFO    : Updated Generator Cost: NG - 590.89 26.977 0.015 -> 0 16.2464404714 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 24.1787693091 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 47.6579302404 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.5458472387 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 46.780749137 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 7.97284006142 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 42.902227856 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.9547636267 0
% INFO    : Updated Generator Cost: NG - 590.89 26.977 0.015 -> 0 36.9008059064 0
% INFO    : Updated Generator Cost: NG - 303.56 14.879 0.009 -> 0 54.2149631432 0
% INFO    : Updated Generator Cost: COW - 303.56 14.879 0.009 -> 0 19.4106410656 0
% INFO    : Updated Generator Cost: NG - 358.86 13.927 0.007 -> 0 28.2871997063 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 95.4193437036 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.4177739938 0
% INFO    : Updated Generator Cost: NG - 349.14 13.99 0.007 -> 0 29.7301859928 0
% INFO    : Updated Generator Cost: NG - 349.14 13.99 0.007 -> 0 46.2457060598 0
% INFO    : Updated Generator Cost: NG - 349.14 13.99 0.007 -> 0 43.5591639745 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 30.9605490984 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 36.9735844899 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 23.8913456588 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 52.4171453016 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 16.9282086841 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 16.0300736454 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 26.4860377256 0
% INFO    : Updated Generator Cost: NG - 311.16 14.103 0.008 -> 0 19.9190991821 0
% INFO    : Updated Generator Cost: NUC - 1190.44 12.786 0.002 -> 0 7.74575878492 0
% INFO    : Updated Generator Cost: COW - 449.88 13.571 0.005 -> 0 15.0086294791 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 16.4072369925 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 32.3758839822 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 57.9197949634 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 29.5801004063 0
% INFO    : Updated Generator Cost: NG - 252.53 14.512 0.01 -> 0 39.9043722184 0
% INFO    : Updated Generator Cost: PEL - 252.53 14.512 0.01 -> 0 118.717114057 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 99.2439428501 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 51.6681381983 0
% INFO    : Updated Generator Cost: NG - 469.88 13.518 0.005 -> 0 27.1123177427 0
% INFO    : Updated Generator Cost: COW - 555.4 13.267 0.004 -> 0 32.7745512411 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 21.4978749016 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 41.6899837575 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 29.1121664405 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 49.9674378699 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 30.9091558748 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 38.250111796 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 35.3625414069 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 19.491927276 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 41.8413368789 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 27.4845432235 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 30.6330996005 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 22.6381644133 0
% INFO    : Updated Generator Cost: NG - 172.53 15.144 0.016 -> 0 7.8594950021 0
% INFO    : Updated Generator Cost: PEL - 82.84 25.482 0.115 -> 0 124.579475888 0
% INFO    : Updated Generator Cost: PEL - 96.73 25.432 0.106 -> 0 108.203909369 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 103.359305398 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 36.8925163596 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.1743928918 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.3567974829 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 35.1202007464 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 104.547149828 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 45.988623144 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 29.6416034896 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 28.2286238544 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 50.0776112512 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 44.6853790793 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 26.074297183 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 18.8563270174 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 100.186020604 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 111.07206495 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 121.70299763 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 98.6712792849 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 114.749263898 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 42.6395941133 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 120.43670795 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 32.9060968019 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 51.5987336604 0
% INFO    : Updated Generator Cost: NG - 112.43 15.886 0.027 -> 0 52.5576803256 0
% INFO    : Updated Generator Cost: NG - 103.7 15.994 0.03 -> 0 42.5442757184 0
% INFO    : Updated Generator Cost: NG - 636.3 13.142 0.003 -> 0 16.4002431258 0
% INFO    : Updated Generator Cost: NG - 90.13 16.01 0.034 -> 0 43.8922832511 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 43.5892343121 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 31.7033544668 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 52.8148764953 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 38.8129457496 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 118.994166475 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 25.5866856989 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 98.6560248312 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 117.205983676 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 13.496785184 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 49.9415547206 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 136.491734093 0
% INFO    : Updated Generator Cost: COW - 128.6 26.977 0.07 -> 0 21.2021123243 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 36.1913622645 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 121.141505955 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 33.4656150854 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.2055846523 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 13.7415583882 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 25.3334872338 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 110.173332349 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 103.314927897 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 135.977408742 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 104.961428395 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 99.1959709665 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 113.004999676 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 111.169978633 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 121.081664132 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 96.9532973471 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 124.821455441 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 114.020097792 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 119.827399253 0
% INFO    : Updated Generator Cost: NG - 122.05 25.36 0.093 -> 0 36.1875197 0
% INFO    : Updated Generator Cost: NG - 122.05 25.36 0.093 -> 0 44.8640297636 0
% INFO    : Updated Generator Cost: NG - 122.05 25.36 0.093 -> 0 23.0126126846 0
% INFO    : Updated Generator Cost: NG - 46.39 16.01 0.067 -> 0 35.1863308214 0
% INFO    : Updated Generator Cost: PEL - 46.39 16.01 0.067 -> 0 104.54887811 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 101.724887135 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 58.7888500485 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.4181993073 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 24.0102517885 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 44.9431712621 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.7196028736 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 18.3314782993 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 26.3869102549 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 41.1816824676 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 127.169083236 0
% INFO    : Updated Generator Cost: NUC - 0.0 0.0 0.0 -> 0 7.02639825755 0
% INFO    : Updated Generator Cost: COW - 1116.42 12.873 0.002 -> 0 20.6389184013 0
% INFO    : Updated Generator Cost: COW - 1116.42 12.873 0.002 -> 0 25.7433861927 0
% INFO    : Updated Generator Cost: NUC - 1116.42 12.873 0.002 -> 0 8.23608916851 0
% INFO    : Updated Generator Cost: COW - 1452.99 12.513 0.002 -> 0 12.3495053873 0
% INFO    : Updated Generator Cost: COW - 1076.35 12.972 0.002 -> 0 39.1473070512 0
% INFO    : Updated Generator Cost: NG - 543.95 13.313 0.004 -> 0 41.1760300537 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 31.5143434065 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 6.40787905794 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 28.8502575391 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 49.5127371122 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 25.1526103858 0
% INFO    : Updated Generator Cost: NG - 434.24 13.619 0.005 -> 0 40.6376806226 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 21.6486042388 0
% INFO    : Updated Generator Cost: COW - 421.98 22.906 0.016 -> 0 15.8545722925 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 19.7340217752 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 41.0117838655 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 40.93986292 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 34.5710261558 0
% INFO    : Updated Generator Cost: NG - 400.37 23.142 0.016 -> 0 34.4578197337 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 35.378299109 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.8833370054 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 43.3494042989 0
% INFO    : Updated Generator Cost: COW - 923.35 20.96 0.006 -> 0 16.4092208735 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 48.3906739886 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 34.1241632426 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 43.8091472403 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 29.0480897255 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.2243478648 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 44.7445125579 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 16.8443370424 0
% INFO    : Updated Generator Cost: NG - 488.6 22.474 0.012 -> 0 27.681007875 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 23.7312379042 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 54.7716290999 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 103.544753243 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.1322507001 0
% INFO    : Updated Generator Cost: NG - 273.91 14.373 0.009 -> 0 41.4557807265 0
% INFO    : Updated Generator Cost: NG - 158.56 15.329 0.018 -> 0 25.9517679112 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 86.2055707106 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 23.6604804438 0
% INFO    : Updated Generator Cost: COW - 248.95 24.501 0.03 -> 0 35.2774507074 0
% INFO    : Updated Generator Cost: PEL - 453.32 22.79 0.014 -> 0 115.948329712 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 110.86995175 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 121.176306744 0
% INFO    : Updated Generator Cost: COW - 249.14 24.474 0.03 -> 0 28.2500965196 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 13.3036445905 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 36.032667364 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 48.0448620186 0
% INFO    : Updated Generator Cost: COW - 128.6 26.977 0.07 -> 0 34.0117199275 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 114.029971965 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 43.5091120021 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 110.440399546 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 39.3101133979 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 30.7191721109 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 51.8506507684 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 43.3877734167 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 111.945692486 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 11.4090898727 0
% INFO    : Updated Generator Cost: NG - 221.33 24.878 0.035 -> 0 20.4770152596 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 28.3565310604 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 43.3845002928 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 41.0518778485 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 22.4260561654 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 49.3307979449 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 19.3466468521 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 44.6428558426 0
% INFO    : Updated Generator Cost: NG - 185.86 25.119 0.055 -> 0 16.3767792116 0
% INFO    : Updated Generator Cost: NG - 185.86 25.119 0.055 -> 0 13.592210424 0
% INFO    : Updated Generator Cost: COW - 209.05 25.023 0.038 -> 0 11.6586689697 0
% INFO    : Updated Generator Cost: NG - 170.25 25.15 0.061 -> 0 30.56750914 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 35.8053141117 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 32.1914538091 0
% INFO    : Updated Generator Cost: COW - 215.5 14.751 0.012 -> 0 32.4506349965 0
% INFO    : Updated Generator Cost: NG - 100.64 16.01 0.031 -> 0 33.723832241 0
% INFO    : Updated Generator Cost: NG - 611.07 13.125 0.003 -> 0 39.1566183632 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 19.9798344523 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 27.6045022562 0
% INFO    : Updated Generator Cost: NG - 344.43 23.52 0.02 -> 0 37.1163306805 0
% INFO    : Updated Generator Cost: NG - 344.43 23.52 0.02 -> 0 53.9216851527 0
% INFO    : Updated Generator Cost: PEL - 160.16 25.203 0.067 -> 0 108.477935824 0
% INFO    : Updated Generator Cost: COW - 240.84 24.623 0.032 -> 0 11.0086981257 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 104.922219239 0
% INFO    : Updated Generator Cost: NG - 147.5 25.236 0.073 -> 0 28.4137782509 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 45.1193155251 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.5190958814 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 124.406062015 0
% INFO    : Updated Generator Cost: NG - 124.52 25.345 0.091 -> 0 52.8423486953 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 47.865914766 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 114.339997619 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 28.0104520406 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 40.3737035209 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 116.170933606 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 40.9664866628 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 53.9412080396 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 39.1611615126 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 25.4788185177 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 34.6074496596 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 36.9334110869 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 111.65456458 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 105.185417688 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 112.656335232 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 114.908315901 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 114.69216781 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 117.77532695 0
% INFO    : Updated Generator Cost: COW - 78.78 26.977 0.114 -> 0 21.7541364994 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 101.562681067 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 133.339266218 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 110.863490986 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 112.230002335 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 124.39530081 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 102.539359204 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 107.855744946 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 123.060899126 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 110.902817913 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 98.2362256934 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 109.988312468 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 119.313489551 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 117.710238641 0
% INFO    : Updated Generator Cost: NG - 65.58 25.544 0.126 -> 0 17.3812730578 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.1469467005 0
% INFO    : Updated Generator Cost: COW - 911.95 13.348 0.002 -> 0 26.3620602223 0
% INFO    : Updated Generator Cost: COW - 911.95 13.348 0.002 -> 0 30.5246308934 0
% INFO    : Updated Generator Cost: COW - 676.09 13.176 0.003 -> 0 31.7982206016 0
% INFO    : Updated Generator Cost: NG - 656.67 13.162 0.003 -> 0 39.0976676607 0
% INFO    : Updated Generator Cost: COW - 656.67 13.162 0.003 -> 0 27.3461584868 0
% INFO    : Updated Generator Cost: NG - 419.94 13.656 0.005 -> 0 31.2577166917 0
% INFO    : Updated Generator Cost: COW - 720.54 13.208 0.003 -> 0 26.2287494032 0
% INFO    : Updated Generator Cost: NG - 383.47 13.813 0.006 -> 0 42.9410021749 0
% INFO    : Updated Generator Cost: NG - 659.13 13.164 0.003 -> 0 32.7065238782 0
% INFO    : Updated Generator Cost: NG - 354.11 13.982 0.007 -> 0 23.8816220286 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 9.91104963885 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 28.6499402625 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 29.7292220147 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 30.2441316378 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 32.8007435518 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 13.2526970672 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 31.9918514525 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 32.9000103955 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 49.3485932204 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 45.8641795246 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 47.4781896877 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 34.9285604459 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 49.0830647956 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 41.5723290927 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 115.038420174 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 35.1214272391 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 105.479340258 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 28.8648560231 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 25.9014840584 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 46.7167394408 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 38.1536229536 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 106.516855949 0
% INFO    : Updated Generator Cost: COW - 0.38 17.2 0.004 -> 0 25.1228177727 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.1106399119 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 22.3255804808 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 22.5704368287 0
% INFO    : Updated Generator Cost: NG - 1063.8 13.01 0.002 -> 0 34.2432008467 0
% INFO    : Updated Generator Cost: COW - 1063.8 13.009 0.002 -> 0 37.1833915256 0
% INFO    : Updated Generator Cost: COW - 1192.03 12.745 0.002 -> 0 35.6043402885 0
% INFO    : Updated Generator Cost: COW - 1009.78 13.132 0.002 -> 0 25.9953694096 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 16.1522623668 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 30.6454473814 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 22.0540524544 0
% INFO    : Updated Generator Cost: COW - 205.57 14.818 0.013 -> 0 30.8026427158 0
% INFO    : Updated Generator Cost: COW - 0.38 17.2 0.004 -> 0 29.2440095597 0
% INFO    : Updated Generator Cost: NG - 251.18 14.519 0.01 -> 0 39.9530607643 0
% INFO    : Updated Generator Cost: NG - 394.07 13.782 0.006 -> 0 14.0128200978 0
% INFO    : Updated Generator Cost: NG - 204.38 14.834 0.013 -> 0 30.0299110544 0
% INFO    : Updated Generator Cost: NG - 204.38 14.834 0.013 -> 0 50.337421866 0
% INFO    : Updated Generator Cost: COW - 144.11 15.498 0.02 -> 0 45.0958212471 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 106.784818144 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 36.9818675714 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 32.2589830502 0
% INFO    : Updated Generator Cost: PEL - 141.09 15.533 0.021 -> 0 114.060560135 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 25.7406553314 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.6208859786 0
% INFO    : Updated Generator Cost: NG - 192.69 25.072 0.049 -> 0 31.5944572234 0
% INFO    : Updated Generator Cost: PEL - 93.54 25.438 0.108 -> 0 106.351928878 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 114.550613376 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 39.0628967343 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 42.2041179057 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 28.9970975659 0
% INFO    : Updated Generator Cost: COW - 0.38 17.2 0.004 -> 0 28.4529197938 0
% INFO    : Updated Generator Cost: COW - 220.84 14.716 0.012 -> 0 25.8023135017 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.4445553856 0
% INFO    : Updated Generator Cost: PEL - 202.72 14.835 0.013 -> 0 111.735983096 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 48.3687906279 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 24.5088701412 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 48.4969431963 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 27.9618763554 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 117.686679144 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 43.4033000376 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 21.8171170599 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 51.8840030755 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.3146843501 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 106.348196891 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 8.60000360441 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.1581015845 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 33.5173889877 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.170576443 0
% INFO    : Updated Generator Cost: NG - 173.6 15.124 0.016 -> 0 16.3127034553 0
% INFO    : Updated Generator Cost: NG - 44.89 16.01 0.071 -> 0 45.9303854076 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 103.591610445 0
% INFO    : Updated Generator Cost: NG - 75.65 25.496 0.117 -> 0 17.2450566307 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 36.3077386375 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 106.247195316 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 42.510835336 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 101.867263735 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 107.785876027 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 108.297232511 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 108.143913801 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 105.582959661 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 20.1997144108 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.2715872343 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 25.6080612958 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 98.0951160627 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 30.9031251992 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 124.999668667 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 35.8878866561 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 30.290657071 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 42.4089203781 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 105.254760993 0
% INFO    : Updated Generator Cost: NG - 492.39 22.474 0.012 -> 0 4.84734661881 0
% INFO    : Updated Generator Cost: COW - 868.16 13.316 0.002 -> 0 28.0593030302 0
% INFO    : Updated Generator Cost: COW - 868.16 13.316 0.002 -> 0 33.7130329131 0
% INFO    : Updated Generator Cost: COW - 868.16 13.316 0.002 -> 0 36.3926633241 0
% INFO    : Updated Generator Cost: COW - 862.76 13.312 0.002 -> 0 37.2548889546 0
% INFO    : Updated Generator Cost: COW - 862.76 13.312 0.002 -> 0 52.9494026712 0
% INFO    : Updated Generator Cost: COW - 902.4 13.341 0.002 -> 0 28.975540911 0
% INFO    : Updated Generator Cost: COW - 813.04 13.277 0.002 -> 0 28.9403728638 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 12.6901904175 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 34.2973162801 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 20.0670762194 0
% INFO    : Updated Generator Cost: NG - 715.04 13.205 0.003 -> 0 42.6238626609 0
% INFO    : Updated Generator Cost: NG - 715.04 13.205 0.003 -> 0 29.6512174611 0
% INFO    : Updated Generator Cost: COW - 715.04 13.205 0.003 -> 0 27.3426081604 0
% INFO    : Updated Generator Cost: NG - 673.46 13.173 0.003 -> 0 48.9129548526 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 20.7612975056 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 24.4417478091 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 32.9469173627 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 23.5415698189 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 35.3120829413 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 36.8613743398 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 21.1884365412 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 25.2741643556 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 26.1124641159 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 21.866845263 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 52.3632766414 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 33.6498525764 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 30.2296255762 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 42.2493225244 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 46.9892825488 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 42.3011821653 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 17.4211589317 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 38.4807819224 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 33.0980475311 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 32.1470212885 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 25.846336751 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 21.2048041275 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 23.7883380991 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 40.8650950313 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 8.79749725824 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 22.2943820491 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 28.1697391427 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 38.5071332871 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 24.1201894892 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 32.2921853198 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 14.0406199318 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 50.4731562762 0
% INFO    : Updated Generator Cost: NG - 331.25 14.039 0.007 -> 0 48.1142468783 0
% INFO    : Updated Generator Cost: NG - 331.25 14.039 0.007 -> 0 15.7021115682 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 39.1067138515 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 41.8416747845 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 40.4447430758 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 14.0012056442 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 30.1276463846 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 53.8474844924 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 40.6524690469 0
% INFO    : Updated Generator Cost: NG - 485.42 22.496 0.013 -> 0 62.0940870868 0
% INFO    : Updated Generator Cost: NG - 485.42 22.496 0.013 -> 0 48.2901482264 0
% INFO    : Updated Generator Cost: NG - 293.9 23.934 0.024 -> 0 40.3684370029 0
% INFO    : Updated Generator Cost: NG - 261.27 24.388 0.029 -> 0 44.8328855573 0
% INFO    : Updated Generator Cost: NG - 261.27 24.388 0.029 -> 0 46.424513419 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 51.8471912956 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 16.7564596273 0
% INFO    : Updated Generator Cost: COW - 802.38 21.345 0.007 -> 0 21.8544335327 0
% INFO    : Updated Generator Cost: NG - 1128.1 20.997 0.004 -> 0 43.0601416588 0
% INFO    : Updated Generator Cost: PEL - 1128.1 20.997 0.004 -> 0 101.255021245 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 45.5969461208 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.3610011929 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 48.6272098111 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 19.6280182246 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 52.691358475 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.5259245299 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.2242521173 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 38.2155827589 0
% INFO    : Updated Generator Cost: NG - 262.93 24.372 0.028 -> 0 41.0769712487 0
% INFO    : Updated Generator Cost: NG - 262.93 24.372 0.028 -> 0 28.3057732939 0
% INFO    : Updated Generator Cost: PEL - 262.93 24.372 0.028 -> 0 118.193713042 0
% INFO    : Updated Generator Cost: NG - 178.19 25.131 0.059 -> 0 13.8370900791 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 34.640546747 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 37.4526117404 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.8238490832 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 10.626230913 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 12.399497924 0
% INFO    : Updated Generator Cost: NG - 161.76 25.197 0.065 -> 0 39.3190302292 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 55.983525512 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 26.6273175404 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 58.7826453808 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 20.7690174964 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 31.4168795011 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 25.6637271128 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 37.116652395 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 18.441098572 0
% INFO    : Updated Generator Cost: NG - 370.63 23.334 0.018 -> 0 47.7583626582 0
% INFO    : Updated Generator Cost: NG - 397.68 23.176 0.017 -> 0 11.0449076725 0
% INFO    : Updated Generator Cost: NG - 156.91 25.203 0.067 -> 0 49.4276433369 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 121.855005502 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 32.4346586092 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 28.4748391703 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 21.6882473026 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 108.028893197 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 102.268908118 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 54.7657944794 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 28.4432019107 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 23.3711401471 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 38.0022768057 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.6883277258 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 15.0199189721 0
% INFO    : Updated Generator Cost: COW - 389.25 23.231 0.017 -> 0 27.576622587 0
% INFO    : Updated Generator Cost: NG - 696.34 21.667 0.008 -> 0 30.0522148765 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 33.4459849186 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 26.5071723456 0
% INFO    : Updated Generator Cost: NG - 201.55 25.035 0.042 -> 0 45.5114259561 0
% INFO    : Updated Generator Cost: NG - 258.46 24.419 0.029 -> 0 27.8664339782 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 49.2943409048 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 15.0191746584 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 46.257960186 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.9826473099 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 24.7496606417 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 110.223137045 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 51.8000645822 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 115.376436785 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 109.389644499 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 20.1568130063 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.7100754089 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 131.53353957 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 55.0990117761 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 43.3758530933 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 54.3179613116 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 50.9526479173 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.8495804387 0
% INFO    : Updated Generator Cost: COW - 468.14 22.68 0.013 -> 0 17.5624257927 0
% INFO    : Updated Generator Cost: NG - 603.95 21.884 0.01 -> 0 10.9967802745 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 31.1554468487 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.0938305423 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 35.1043946415 0
% INFO    : Updated Generator Cost: NG - 1009.41 20.899 0.005 -> 0 31.243372377 0
% INFO    : Updated Generator Cost: NG - 51.93 16.01 0.06 -> 0 36.6512638337 0
% INFO    : Updated Generator Cost: NG - 90.19 16.01 0.034 -> 0 59.339044722 0
% INFO    : Updated Generator Cost: NG - 90.19 16.01 0.034 -> 0 40.8933776537 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 94.8138889749 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 123.275983546 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 102.163036942 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 102.383208669 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 109.624199179 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 100.575330679 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 117.847092437 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 102.234382285 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 120.656292347 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 103.910819993 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 96.6821134192 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 132.531231028 0
% INFO    : Updated Generator Cost: COW - 1372.6 21.162 0.003 -> 0 29.8365279925 0
% INFO    : Updated Generator Cost: COW - 1372.6 21.162 0.003 -> 0 17.7867504376 0
% INFO    : Updated Generator Cost: COW - 1372.6 21.162 0.003 -> 0 28.2056392415 0
% INFO    : Updated Generator Cost: PEL - 81.34 25.489 0.115 -> 0 113.660639895 0
% INFO    : Updated Generator Cost: NG - 81.34 25.489 0.115 -> 0 46.5648832652 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 23.8958668192 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 130.728743829 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.8759552823 0
% INFO    : Updated Generator Cost: NG - 686.14 13.182 0.003 -> 0 40.0566310006 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 22.5492074737 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 32.2211257727 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 35.9277947806 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 19.5166288094 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 38.4766441538 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 39.0489758718 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 30.6503281039 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 12.3247462049 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 26.2540601415 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 36.7134121381 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 43.5972881395 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 29.9811241718 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.8406990406 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 8.50846736268 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 100.267454368 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 113.448811734 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 45.8842757076 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 103.261030212 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 26.2608738507 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 129.912415821 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 27.8237374611 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 10.638423139 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 44.7334276825 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 109.224090264 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 91.2459004378 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 122.924309956 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 28.9485779281 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 42.8266812816 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 25.4729933319 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 51.1310758101 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 112.553015326 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 128.029715898 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 23.080402592 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 27.6795271022 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 14.9956929573 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 18.4140402604 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 35.8842792435 0
% INFO    : Updated Generator Cost: COW - 1755.23 50.578 0.008 -> 0 16.8125398755 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 43.9534853299 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 43.6666309713 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 30.1673820676 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 25.38414962 0
% INFO    : Updated Generator Cost: NUC - 0.0 0.0 0.0 -> 0 9.03943480793 0
% INFO    : Updated Generator Cost: NUC - 0.0 0.0 0.0 -> 0 7.39291793454 0
% INFO    : Updated Generator Cost: NUC - 1494.04 12.513 0.002 -> 0 6.25154205094 0
% INFO    : Updated Generator Cost: COW - 1450.0 12.513 0.002 -> 0 22.9612126676 0
% INFO    : Updated Generator Cost: COW - 1553.6 12.513 0.001 -> 0 24.4490842852 0
% INFO    : Updated Generator Cost: COW - 1290.37 12.544 0.002 -> 0 20.1971756086 0
% INFO    : Updated Generator Cost: COW - 1290.37 12.544 0.002 -> 0 20.8535037239 0
% INFO    : Updated Generator Cost: COW - 1290.37 12.544 0.002 -> 0 31.6035402571 0
% INFO    : Updated Generator Cost: COW - 1932.17 20.127 0.003 -> 0 24.8567170372 0
% INFO    : Updated Generator Cost: COW - 1932.17 20.127 0.003 -> 0 14.581177859 0
% INFO    : Updated Generator Cost: COW - 1132.28 12.843 0.002 -> 0 26.7239917174 0
% INFO    : Updated Generator Cost: COW - 1115.18 12.88 0.002 -> 0 29.7946356097 0
% INFO    : Updated Generator Cost: COW - 1042.7 13.047 0.002 -> 0 26.4472845399 0
% INFO    : Updated Generator Cost: COW - 957.8 13.254 0.002 -> 0 15.6640661752 0
% INFO    : Updated Generator Cost: NG - 527.76 22.242 0.011 -> 0 52.2649132492 0
% INFO    : Updated Generator Cost: NG - 527.76 22.242 0.011 -> 0 38.523808845 0
% INFO    : Updated Generator Cost: COW - 1402.95 21.179 0.003 -> 0 19.2631221446 0
% INFO    : Updated Generator Cost: COW - 1183.24 12.795 0.002 -> 0 22.8634506082 0
% INFO    : Updated Generator Cost: COW - 1183.24 12.795 0.002 -> 0 16.2552823669 0
% INFO    : Updated Generator Cost: NG - 782.46 21.39 0.007 -> 0 27.4671968084 0
% INFO    : Updated Generator Cost: COW - 937.46 13.289 0.002 -> 0 29.3389484837 0
% INFO    : Updated Generator Cost: COW - 1014.15 13.114 0.002 -> 0 26.4537451383 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 30.955678535 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 34.3018462681 0
% INFO    : Updated Generator Cost: COW - 900.88 13.341 0.002 -> 0 37.112588719 0
% INFO    : Updated Generator Cost: COW - 900.88 13.341 0.002 -> 0 32.353500634 0
% INFO    : Updated Generator Cost: PEL - 1297.52 12.531 0.002 -> 0 112.780796 0
% INFO    : Updated Generator Cost: NG - 902.0 13.341 0.002 -> 0 57.5200855462 0
% INFO    : Updated Generator Cost: COW - 902.0 13.341 0.002 -> 0 13.498487214 0
% INFO    : Updated Generator Cost: COW - 893.67 13.334 0.002 -> 0 33.6854921837 0
% INFO    : Updated Generator Cost: COW - 861.41 13.311 0.002 -> 0 22.773256078 0
% INFO    : Updated Generator Cost: COW - 861.41 13.311 0.002 -> 0 32.6501955701 0
% INFO    : Updated Generator Cost: COW - 1425.7 12.513 0.002 -> 0 41.9179987156 0
% INFO    : Updated Generator Cost: COW - 853.25 13.305 0.002 -> 0 26.1541867277 0
% INFO    : Updated Generator Cost: COW - 852.34 13.304 0.002 -> 0 38.0269645102 0
% INFO    : Updated Generator Cost: COW - 852.34 13.304 0.002 -> 0 16.9061787748 0
% INFO    : Updated Generator Cost: COW - 852.34 13.304 0.002 -> 0 20.4606373771 0
% INFO    : Updated Generator Cost: NG - 687.29 13.19 0.003 -> 0 33.9622117227 0
% INFO    : Updated Generator Cost: COW - 938.49 13.288 0.002 -> 0 30.5958566806 0
% INFO    : Updated Generator Cost: NG - 938.49 13.288 0.002 -> 0 22.0037409334 0
% INFO    : Updated Generator Cost: NG - 681.56 13.177 0.003 -> 0 52.7827805274 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 22.8285999355 0
% INFO    : Updated Generator Cost: COW - 2130.63 13.659 0.009 -> 0 12.0707085373 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 16.5289685942 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 39.9637829435 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 25.173444629 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 38.3012014706 0
% INFO    : Updated Generator Cost: COW - 1038.56 20.88 0.005 -> 0 13.051451119 0
% INFO    : Updated Generator Cost: NG - 1038.56 20.88 0.005 -> 0 22.9216943808 0
% INFO    : Updated Generator Cost: NG - 1048.59 20.865 0.005 -> 0 35.4191885242 0
% INFO    : Updated Generator Cost: COW - 671.23 13.173 0.003 -> 0 36.4468931701 0
% INFO    : Updated Generator Cost: NG - 728.07 13.215 0.003 -> 0 16.5868342943 0
% INFO    : Updated Generator Cost: NG - 619.03 13.127 0.003 -> 0 33.4281133082 0
% INFO    : Updated Generator Cost: COW - 1115.38 20.99 0.004 -> 0 11.2684796678 0
% INFO    : Updated Generator Cost: COW - 1115.38 20.99 0.004 -> 0 18.2242889504 0
% INFO    : Updated Generator Cost: NG - 979.98 20.929 0.005 -> 0 23.371051177 0
% INFO    : Updated Generator Cost: COW - 1277.5 21.094 0.003 -> 0 31.44030011 0
% INFO    : Updated Generator Cost: NG - 950.4 20.869 0.006 -> 0 41.1810037142 0
% INFO    : Updated Generator Cost: NG - 556.82 13.263 0.004 -> 0 26.0448677074 0
% INFO    : Updated Generator Cost: COW - 556.82 13.263 0.004 -> 0 24.9371070886 0
% INFO    : Updated Generator Cost: NG - 556.82 13.263 0.004 -> 0 22.0204260786 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 32.0918680126 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 46.3386564365 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 39.7493125228 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 53.4628717893 0
% INFO    : Updated Generator Cost: NG - 710.57 21.618 0.008 -> 0 33.5509080207 0
% INFO    : Updated Generator Cost: COW - 710.57 21.618 0.008 -> 0 19.1090851068 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 39.1464703984 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 30.0767794364 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 13.809905933 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 16.8402031084 0
% INFO    : Updated Generator Cost: NG - 664.19 21.73 0.009 -> 0 31.2640975712 0
% INFO    : Updated Generator Cost: NG - 917.22 20.985 0.006 -> 0 39.1746604908 0
% INFO    : Updated Generator Cost: NG - 652.55 21.744 0.009 -> 0 47.1418734355 0
% INFO    : Updated Generator Cost: NG - 652.55 21.744 0.009 -> 0 36.7477954091 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 45.1454488689 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 10.1707876645 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 39.5728084433 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 61.5133986763 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 33.9078723608 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 15.7156293704 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 29.7288178394 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 39.0008078877 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 30.6777441939 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 60.8430295583 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 45.192305021 0
% INFO    : Updated Generator Cost: NG - 650.05 21.779 0.009 -> 0 33.6084043638 0
% INFO    : Updated Generator Cost: NG - 650.05 21.779 0.009 -> 0 40.8353144477 0
% INFO    : Updated Generator Cost: NG - 1433.6 21.208 0.003 -> 0 56.1387136971 0
% INFO    : Updated Generator Cost: NG - 1136.7 20.991 0.004 -> 0 40.7644845968 0
% INFO    : Updated Generator Cost: NG - 1216.5 21.048 0.004 -> 0 28.7666242633 0
% INFO    : Updated Generator Cost: NG - 636.23 21.853 0.009 -> 0 38.0773764553 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 43.6498381322 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 35.4158281563 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 17.8739278431 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 21.0327987271 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 22.0941199664 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 30.8660855891 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 30.259793202 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 51.354682688 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.1642941004 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.8265763474 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 18.5485343514 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 16.1894270382 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 27.3795495209 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 34.892002133 0
% INFO    : Updated Generator Cost: COW - 128.6 26.977 0.07 -> 0 29.245977665 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 24.5563915552 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 28.9061470495 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 36.9311455005 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 50.6713715014 0
% INFO    : Updated Generator Cost: COW - 128.6 26.977 0.07 -> 0 25.836486322 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 48.1648057447 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 53.1156007836 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 112.219661999 0
% INFO    : Updated Generator Cost: COW - 128.6 26.977 0.07 -> 0 24.7959508654 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 10.6473096499 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 25.3919971163 0
% INFO    : Updated Generator Cost: COW - 128.6 26.977 0.07 -> 0 21.274260619 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 53.0170686544 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 30.8703936622 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 46.442175338 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 35.7490609465 0
% INFO    : Updated Generator Cost: COW - 128.6 26.977 0.07 -> 0 25.1084383542 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 40.6420783756 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 34.0424749009 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 33.2144041478 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 34.8010727245 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 41.7629323352 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 27.6647289274 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 21.7094143497 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 15.3862786528 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 24.2211720851 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 35.7916142602 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 38.723784096 0
% INFO    : Updated Generator Cost: NG - 539.38 22.191 0.011 -> 0 41.003840424 0
% INFO    : Updated Generator Cost: COW - 1403.83 21.185 0.003 -> 0 28.5283893436 0
% INFO    : Updated Generator Cost: NG - 940.86 20.919 0.006 -> 0 49.2346204031 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 45.228107244 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 39.72152529 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 17.2449253088 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 37.049646316 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 12.1279227466 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 36.7787988029 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 51.2018533913 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 19.035880172 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 46.813704334 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 44.8993095745 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 10.945022286 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 35.1697430792 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 43.6892967121 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.7752344944 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 21.5515618069 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 99.8584826403 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.566975403 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 60.125192473 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 29.1033418906 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 46.5765951389 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 16.9195733857 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 51.3329116009 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 25.5317428154 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 15.4132346386 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 17.2038315389 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 29.9855917853 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 53.0644061548 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 21.4389932412 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 17.7086206661 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 33.831356662 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 39.0223233575 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 18.0396356642 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 26.7808256032 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 30.5072410173 0
% INFO    : Updated Generator Cost: NG - 897.55 21.046 0.006 -> 0 43.5333890807 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 8.85363159918 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.5377299167 0
% INFO    : Updated Generator Cost: COW - 2130.63 13.659 0.009 -> 0 16.5357650545 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 35.2942927847 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.8437190782 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 21.0495490923 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 31.0662325237 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 36.0347163093 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 25.9107856509 0
% INFO    : Updated Generator Cost: NG - 526.15 22.266 0.011 -> 0 44.9126152793 0
% INFO    : Updated Generator Cost: NG - 526.15 22.266 0.011 -> 0 16.8221688464 0
% INFO    : Updated Generator Cost: COW - 619.42 21.859 0.009 -> 0 24.1912823357 0
% INFO    : Updated Generator Cost: NG - 619.42 21.859 0.009 -> 0 28.9927134059 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 45.938907833 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 26.7309422785 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 12.80019593 0
% INFO    : Updated Generator Cost: COW - 2130.63 13.659 0.009 -> 0 22.3010866981 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 32.2662845672 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 42.3219006871 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 29.5602823038 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 32.9773423931 0
% INFO    : Updated Generator Cost: COW - 514.31 22.349 0.012 -> 0 24.3882166442 0
% INFO    : Updated Generator Cost: NG - 867.61 21.086 0.006 -> 0 41.8907508041 0
% INFO    : Updated Generator Cost: NG - 867.61 21.086 0.006 -> 0 14.8199090877 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 40.7104566681 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 22.0397190063 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 27.5726630676 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 33.0316725687 0
% INFO    : Updated Generator Cost: COW - 993.75 11.398 0.026 -> 0 24.5445210287 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 25.8511074537 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 42.1723995537 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 43.5093531701 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 35.3327770461 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 69.4174568449 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 18.7044893875 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 21.9577462036 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 33.3227233924 0
% INFO    : Updated Generator Cost: NG - 505.79 22.404 0.012 -> 0 36.2559912546 0
% INFO    : Updated Generator Cost: COW - 1261.8 21.082 0.003 -> 0 21.4179101319 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 23.7790409055 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 36.639067588 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 53.254573871 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 38.4745333943 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 20.8326867153 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 31.9640209233 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 30.1630710478 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 32.306879438 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 25.5653596041 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 15.5233618206 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 32.6118813831 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 30.386981039 0
% INFO    : Updated Generator Cost: PEL - 2249.86 9.547 0.032 -> 0 121.935806363 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 38.1046093795 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 6.28273054197 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 36.1952734802 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 27.7412021405 0
% INFO    : Updated Generator Cost: NG - 316.58 14.083 0.008 -> 0 22.3650110829 0
% INFO    : Updated Generator Cost: NG - 316.58 14.083 0.008 -> 0 32.5015274503 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 35.0338083229 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 34.6415355538 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 36.7668232365 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 15.261193547 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 38.7418911398 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 54.2974196908 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 33.2084357363 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 27.8964133598 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 25.71303562 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 42.0000951348 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.6669995896 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 30.7346474208 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 36.690703849 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 41.4220280631 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 41.4765234553 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 34.4377598143 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 22.0327701092 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 20.4473494852 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 46.2918521437 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 25.1914482076 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 44.4344549738 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 39.5021629456 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 30.3329436264 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 27.473317253 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 116.676119421 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 15.3655907323 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 48.1650773162 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 41.7992277682 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 39.4471353924 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 32.0798361304 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 46.9464437966 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 35.8157645733 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 25.370376186 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 32.8706616462 0
% INFO    : Updated Generator Cost: PEL - 2249.86 9.547 0.032 -> 0 105.953375468 0
% INFO    : Updated Generator Cost: PEL - 2249.86 9.547 0.032 -> 0 116.309708725 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 25.679855689 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 56.6681297892 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 38.9852780912 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 13.9900395896 0
% INFO    : Updated Generator Cost: NG - 2130.63 13.659 0.009 -> 0 43.6855331806 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 52.2542697436 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 41.3797479842 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 52.8753496105 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 22.7608316665 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 28.0177258795 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 48.3369695841 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 35.575919352 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 23.8208195477 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 24.1359261815 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 44.7242220708 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 39.514018717 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 20.5262049873 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 4.26126948225 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 22.750861124 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 25.9528205359 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 20.5199023296 0
% INFO    : Updated Generator Cost: COW - 480.51 22.638 0.013 -> 0 29.4999578138 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 40.4135853184 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 27.6877755481 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 48.2215568201 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 48.8343873588 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 32.3839072034 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 13.3477914396 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 23.0790613743 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 31.1806877157 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 41.779562947 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 34.2207929425 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 35.7912564686 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 35.2133108565 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 33.9234098609 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 106.442362946 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 40.4084081033 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 22.936594516 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 28.7222821926 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 10.4184813151 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 20.7835709531 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 26.7299469537 0
% INFO    : Updated Generator Cost: COW - 2894.55 60.757 0.005 -> 0 36.469044286 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 11.9038566395 0
% INFO    : Updated Generator Cost: NG - 402.81 23.127 0.016 -> 0 30.6419168441 0
% INFO    : Updated Generator Cost: NG - 402.81 23.127 0.016 -> 0 27.352969709 0
% INFO    : Updated Generator Cost: COW - 883.48 21.056 0.006 -> 0 25.9680375303 0
% INFO    : Updated Generator Cost: NG - 399.36 23.158 0.017 -> 0 14.0040579517 0
% INFO    : Updated Generator Cost: NG - 401.48 23.131 0.016 -> 0 10.8352136132 0
% INFO    : Updated Generator Cost: NG - 1397.95 21.178 0.003 -> 0 52.0493186544 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 110.669354298 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 24.1872816439 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 45.6370381784 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 49.3918167759 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 40.8956118093 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 33.072354385 0
% INFO    : Updated Generator Cost: NG - 362.92 23.348 0.018 -> 0 21.9817565809 0
% INFO    : Updated Generator Cost: NG - 525.58 22.288 0.012 -> 0 31.0958631779 0
% INFO    : Updated Generator Cost: NG - 944.62 20.873 0.006 -> 0 30.8944861412 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 53.4973801986 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 45.717816987 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 32.8564534063 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 124.265617808 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 28.7575936616 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 31.7992459353 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 29.6958394848 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 18.9881362191 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 13.4327508574 0
% INFO    : Updated Generator Cost: NG - 653.85 21.738 0.009 -> 0 34.926050034 0
% INFO    : Updated Generator Cost: NG - 343.15 23.525 0.02 -> 0 31.5089078947 0
% INFO    : Updated Generator Cost: NG - 343.15 23.525 0.02 -> 0 36.5213553174 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 38.6955306289 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 32.6048645776 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 38.0378178478 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 39.4584870443 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 110.98453052 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 112.092242959 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 116.625917278 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 62.6654596091 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 37.7036627201 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 50.1912409176 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 25.3044845169 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 30.5256362797 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 58.7066143163 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 27.9459007872 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.3645995657 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 22.7480347692 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 34.2073173635 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 25.4245095547 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 42.3139084447 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 33.3893366243 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 17.6060018046 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 7.42989520335 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 41.9239416381 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 23.119445038 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 60.7627064044 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 38.702529995 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 32.1909435891 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.8787694199 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 37.1478899484 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 129.675634577 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 32.9722798492 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 119.731468765 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 35.8104732458 0
% INFO    : Updated Generator Cost: NG - 487.74 22.492 0.013 -> 0 43.1020519675 0
% INFO    : Updated Generator Cost: COW - 1231.6 21.059 0.004 -> 0 11.8486631681 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 29.5387679709 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 34.9797240334 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.8348573605 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 46.5946473278 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.9344112522 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 34.7393283732 0
% INFO    : Updated Generator Cost: NG - 345.28 23.516 0.02 -> 0 45.0633800871 0
% INFO    : Updated Generator Cost: COW - 1298.58 21.118 0.003 -> 0 30.2132515082 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.2532099306 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 40.7638994922 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 17.6840209988 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 29.2361398905 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 34.2515773217 0
% INFO    : Updated Generator Cost: COW - 2042.45 19.809 0.003 -> 0 25.6183650802 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 24.032102807 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 12.136382393 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 30.4233649308 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 9.47786331143 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 19.83856453 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 111.319074625 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 31.3172716022 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.1875264248 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.4515325355 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 40.5470325695 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 18.4787592768 0
% INFO    : Updated Generator Cost: COW - 362.18 23.397 0.018 -> 0 20.4424384532 0
% INFO    : Updated Generator Cost: NG - 255.61 24.449 0.029 -> 0 39.4800413553 0
% INFO    : Updated Generator Cost: NG - 255.61 24.449 0.029 -> 0 30.3165961263 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 37.2117169435 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 38.8128948935 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 35.2311293723 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 15.9662189391 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 27.437664312 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 113.015613342 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 45.7335721154 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 43.7150685918 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 15.5534587876 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 18.7443862182 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.3111248215 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 53.3912102113 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 25.9954257181 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 33.1697107795 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 127.221115297 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 46.3337254144 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 51.0657445807 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 7.20628574244 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 33.9554522676 0
% INFO    : Updated Generator Cost: NG - 451.68 22.794 0.014 -> 0 23.8258169744 0
% INFO    : Updated Generator Cost: NG - 338.44 23.562 0.02 -> 0 26.7017526155 0
% INFO    : Updated Generator Cost: NG - 242.21 24.602 0.031 -> 0 25.2703789728 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.6813987518 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 41.0016711221 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 31.3466324119 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 37.2684312867 0
% INFO    : Updated Generator Cost: NG - 633.25 21.853 0.009 -> 0 41.5629467013 0
% INFO    : Updated Generator Cost: NG - 245.42 24.54 0.031 -> 0 38.1432223196 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 25.4469100096 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 29.5455897127 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 32.668888415 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 107.046728064 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 127.166910385 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 47.8274761957 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 30.2679722769 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 126.795524762 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 118.134242449 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 38.7535576918 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 52.5970811213 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 42.3270217467 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 109.72832259 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 121.907701134 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 22.6400938249 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 35.9468956925 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 8.81729637894 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 21.2430158143 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.8135261104 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 41.9042362235 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 106.461852498 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 24.0338484488 0
% INFO    : Updated Generator Cost: NG - 1069.37 20.858 0.005 -> 0 43.7552272863 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 29.3079891104 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 30.9297175615 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 37.6867392947 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 114.842775424 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 114.443715212 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 21.423656391 0
% INFO    : Updated Generator Cost: NG - 555.95 22.019 0.011 -> 0 15.0281689009 0
% INFO    : Updated Generator Cost: NG - 313.66 23.733 0.023 -> 0 33.7626444051 0
% INFO    : Updated Generator Cost: PEL - 210.83 25.007 0.037 -> 0 97.0957159786 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 40.1618097421 0
% INFO    : Updated Generator Cost: NG - 614.64 21.866 0.009 -> 0 25.0786314963 0
% INFO    : Updated Generator Cost: NG - 669.8 21.727 0.009 -> 0 33.0561178964 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 61.497520133 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 25.285435977 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 52.2642272237 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 61.1344818049 0
% INFO    : Updated Generator Cost: NG - 988.72 20.921 0.005 -> 0 37.8870857121 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 27.3268324394 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 47.2261585236 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 36.4235723501 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 108.032086223 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 104.47307166 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 50.877459359 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 43.714193354 0
% INFO    : Updated Generator Cost: NG - 249.26 34.683 0.058 -> 0 35.5594236418 0
% INFO    : Updated Generator Cost: PEL - 249.26 34.683 0.058 -> 0 116.886499754 0
% INFO    : Updated Generator Cost: NG - 249.26 34.683 0.058 -> 0 33.6308480639 0
% INFO    : Updated Generator Cost: COW - 148.58 34.988 0.103 -> 0 16.2437294502 0
% INFO    : Updated Generator Cost: NG - 343.48 23.523 0.02 -> 0 59.0606005756 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 113.278783295 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 51.463921226 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 105.846925526 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 25.0135523389 0
% INFO    : Updated Generator Cost: NG - 242.27 24.588 0.031 -> 0 32.2217506353 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 109.588442253 0
% INFO    : Updated Generator Cost: NG - 162.76 15.254 0.026 -> 0 49.6817741191 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.6115030462 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 111.050904085 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 124.559482009 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 38.462288062 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 44.0548178617 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 43.1859978104 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 28.8288600353 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.4174569237 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 14.7371470071 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 21.1195284311 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 20.7988941465 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 49.1955897426 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 25.7199332444 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 25.8490560914 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 25.1624133905 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 127.657920448 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 82.0816561573 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 45.2994846645 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 26.6165599092 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 18.1556505237 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 38.639850795 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 55.9887867165 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 52.2123833944 0
% INFO    : Updated Generator Cost: NG - 980.23 20.922 0.005 -> 0 30.0816896675 0
% INFO    : Updated Generator Cost: NG - 814.9 21.309 0.007 -> 0 33.9007329606 0
% INFO    : Updated Generator Cost: PEL - 367.1 17.118 0.005 -> 0 120.77065248 0
% INFO    : Updated Generator Cost: PEL - 367.1 17.118 0.005 -> 0 113.063099161 0
% INFO    : Updated Generator Cost: NG - 152.07 15.371 0.03 -> 0 33.7515919026 0
% INFO    : Updated Generator Cost: NG - 152.07 15.371 0.03 -> 0 46.9281887937 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 35.7264944267 0
% INFO    : Updated Generator Cost: NG - 85.99 25.463 0.113 -> 0 51.2874316532 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 46.7725466021 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 122.285496756 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 43.2415576681 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 22.491196175 0
% INFO    : Updated Generator Cost: COW - 316.5 23.699 0.022 -> 0 41.0216114133 0
% INFO    : Updated Generator Cost: NG - 163.04 25.187 0.064 -> 0 19.7490502905 0
% INFO    : Updated Generator Cost: NG - 536.84 22.221 0.011 -> 0 41.5179589953 0
% INFO    : Updated Generator Cost: NG - 162.41 25.192 0.064 -> 0 51.0471770374 0
% INFO    : Updated Generator Cost: NG - 294.99 23.892 0.024 -> 0 41.3763869514 0
% INFO    : Updated Generator Cost: NG - 294.99 23.892 0.024 -> 0 45.1542462884 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.2679357279 0
% INFO    : Updated Generator Cost: PEL - 153.94 25.206 0.069 -> 0 113.588240612 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 11.1729329904 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.7625095391 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 13.2053226556 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.0417831914 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 15.4735257599 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 40.1705999733 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 19.0545613178 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 121.395293841 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 47.6721974156 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 41.6433873063 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 38.0908764584 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 28.1700737211 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.0520861958 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 18.6899629806 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 25.4878995307 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 26.6098109452 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 43.0770301194 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.7031427885 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 29.2999709431 0
% INFO    : Updated Generator Cost: NG - 144.65 25.256 0.076 -> 0 16.1497001046 0
% INFO    : Updated Generator Cost: NG - 144.65 25.256 0.076 -> 0 19.0164851541 0
% INFO    : Updated Generator Cost: NG - 234.27 24.706 0.033 -> 0 37.4352324244 0
% INFO    : Updated Generator Cost: NG - 867.35 21.145 0.006 -> 0 36.7687477165 0
% INFO    : Updated Generator Cost: NG - 121.06 25.545 0.068 -> 0 29.5397480318 0
% INFO    : Updated Generator Cost: COW - 0.38 17.2 0.004 -> 0 17.753223809 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 114.698873406 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 111.947168543 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 36.7291465965 0
% INFO    : Updated Generator Cost: COW - 140.23 15.45 0.039 -> 0 9.71664544851 0
% INFO    : Updated Generator Cost: NG - 139.61 25.279 0.08 -> 0 23.8377020423 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 116.682093367 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 35.8384950423 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 20.8133050009 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 43.5970664027 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.8002950314 0
% INFO    : Updated Generator Cost: NG - 84.25 23.025 0.076 -> 0 39.4250255143 0
% INFO    : Updated Generator Cost: COW - 84.25 23.025 0.076 -> 0 10.1534205333 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 25.7748046682 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 42.7302572039 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 31.2311729667 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 116.878123896 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 28.2907453387 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 26.1631525979 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 123.26436633 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 106.502271107 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 28.2222681444 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 32.2754792659 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 35.1307236106 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 26.2299406963 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 47.3288333442 0
% INFO    : Updated Generator Cost: NG - 150.38 25.222 0.069 -> 0 49.111491767 0
% INFO    : Updated Generator Cost: NG - 110.23 25.395 0.102 -> 0 27.7593035614 0
% INFO    : Updated Generator Cost: PEL - 112.66 34.988 0.13 -> 0 106.739491672 0
% INFO    : Updated Generator Cost: NG - 179.98 34.988 0.083 -> 0 31.0378680581 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.0536907896 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 18.3564529586 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 34.3895913307 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 27.1433606887 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.3275947626 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 96.9708170574 0
% INFO    : Updated Generator Cost: PEL - 94.32 15.653 0.061 -> 0 111.339241509 0
% INFO    : Updated Generator Cost: NG - 107.11 34.988 0.137 -> 0 40.0664366217 0
% INFO    : Updated Generator Cost: COW - 107.11 34.988 0.137 -> 0 25.3498669569 0
% INFO    : Updated Generator Cost: NG - 107.11 34.988 0.137 -> 0 16.5584701922 0
% INFO    : Updated Generator Cost: NG - 107.11 34.988 0.137 -> 0 37.9485872896 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 37.0248944105 0
% INFO    : Updated Generator Cost: PEL - 82.91 25.481 0.114 -> 0 114.609183446 0
% INFO    : Updated Generator Cost: NG - 82.91 25.481 0.114 -> 0 38.4533926693 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 36.0046935643 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 33.9353052064 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 21.3444377908 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 100.544952812 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.5835653942 0
% INFO    : Updated Generator Cost: PEL - 105.98 25.402 0.104 -> 0 100.940746596 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 30.708368739 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 36.1035742975 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 26.5370391541 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 34.342808269 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 25.9345158909 0
% INFO    : Updated Generator Cost: NG - 191.18 25.075 0.051 -> 0 18.7589902238 0
% INFO    : Updated Generator Cost: PEL - 86.14 25.462 0.113 -> 0 122.216046317 0
% INFO    : Updated Generator Cost: PEL - 100.76 25.406 0.104 -> 0 119.422907549 0
% INFO    : Updated Generator Cost: PEL - 65.44 25.545 0.126 -> 0 115.394199255 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 50.893002547 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 29.2074553205 0
% INFO    : Updated Generator Cost: COW - 51.34 14.879 0.053 -> 0 23.9553670112 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 48.6129127236 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 41.9310455978 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 31.0346792504 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 54.9424799747 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.8231944053 0
% INFO    : Updated Generator Cost: NG - 134.35 25.318 0.086 -> 0 38.6492870528 0
% INFO    : Updated Generator Cost: PEL - 134.35 25.318 0.086 -> 0 114.110633661 0
% INFO    : Updated Generator Cost: NG - 134.35 25.318 0.086 -> 0 27.7743839031 0
% INFO    : Updated Generator Cost: COW - 134.35 25.318 0.086 -> 0 3.51304198137 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 27.948197502 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 44.8985673376 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 28.7210090759 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 35.0486844789 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 39.946916449 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 32.0457599354 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 37.4056653212 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 19.6143328685 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 117.012387675 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 16.1839397924 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 27.9207675398 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 29.2081533768 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 41.6346614921 0
% INFO    : Updated Generator Cost: NG - 74.92 25.507 0.121 -> 0 34.3049432478 0
% INFO    : Updated Generator Cost: NG - 74.92 25.507 0.121 -> 0 17.8271339277 0
% INFO    : Updated Generator Cost: PEL - 307.97 33.921 0.045 -> 0 114.657791841 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 16.8381965396 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 31.7790734807 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.2629295096 0
% INFO    : Updated Generator Cost: PEL - 887.89 82.832 0.094 -> 0 117.432766504 0
% INFO    : Updated Generator Cost: NG - 887.89 82.832 0.094 -> 0 32.2256011306 0
% INFO    : Updated Generator Cost: PEL - 887.89 82.832 0.094 -> 0 104.12710989 0
% INFO    : Updated Generator Cost: PEL - 887.89 82.832 0.094 -> 0 120.258460479 0
% INFO    : Updated Generator Cost: NG - 255.88 87.0 0.35 -> 0 37.4497947118 0
% INFO    : Updated Generator Cost: PEL - 349.07 87.0 0.271 -> 0 120.038177865 0
% INFO    : Updated Generator Cost: NG - 139.77 34.988 0.113 -> 0 42.0034518579 0
% INFO    : Updated Generator Cost: PEL - 268.83 34.459 0.054 -> 0 109.787701792 0
% INFO    : Updated Generator Cost: PEL - 268.83 34.459 0.054 -> 0 126.222354215 0
% INFO    : Updated Generator Cost: NG - 268.83 34.459 0.054 -> 0 46.8409094377 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 120.970281019 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 116.793911511 0
% INFO    : Updated Generator Cost: COW - 120.08 34.988 0.123 -> 0 43.744944057 0
% INFO    : Updated Generator Cost: PEL - 101.46 34.988 0.146 -> 0 110.270136656 0
% INFO    : Updated Generator Cost: NG - 117.62 34.988 0.126 -> 0 14.3685891034 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 17.5411793821 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 42.1969193295 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.9805200671 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.7544316829 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 14.6143446133 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 118.793858101 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 118.273049119 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.3813103893 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 127.069590165 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 28.3461046219 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 90.620071283 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 112.133565756 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 137.316828012 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 110.88064784 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 129.567791929 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 108.850940142 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 106.726901914 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 132.796803662 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 113.69033864 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.34722713 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 106.081786124 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 33.3751155529 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 30.2621870121 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 95.6897689444 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 113.347722007 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 107.183772559 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 122.260578421 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 101.482690937 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 106.977086325 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 116.001023036 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 107.084843953 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 109.681749962 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 95.6019768517 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 106.077911767 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 105.009341892 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 116.797351852 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 117.01427632 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 111.512638874 0
% INFO    : Updated Generator Cost: PEL - 261.23 34.531 0.055 -> 0 119.477096514 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 23.365289496 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 23.8105730617 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 32.3837666233 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 98.842073624 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 97.0509609388 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 112.648554255 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 106.278707192 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 133.259627488 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 125.003164599 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.6397807954 0
% INFO    : Updated Generator Cost: NG - 307.35 23.778 0.023 -> 0 47.8287907346 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 32.0069909265 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 31.5957798358 0
% INFO    : Updated Generator Cost: COW - 51.34 14.879 0.053 -> 0 22.831777246 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 39.9187104652 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 44.1857382716 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 39.2886869718 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.4467889704 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 38.8550562333 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.6100512491 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 16.7530101406 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 22.0723428709 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 37.1010865402 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 117.120047837 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 106.261067205 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 105.897592242 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 41.3990268429 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 46.7685380103 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 34.9342767969 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 121.393208242 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 96.4689632492 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 43.2274699686 0
% INFO    : Updated Generator Cost: NG - 90.04 25.441 0.109 -> 0 25.685125614 0
% INFO    : Updated Generator Cost: NG - 90.04 25.441 0.109 -> 0 44.0558852434 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 13.6022631623 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 116.881213137 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 48.2344044179 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 26.8280550074 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 111.615452202 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 29.4297504217 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 107.662737141 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 94.7359755458 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 21.5687615773 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 110.567084329 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 17.1761852594 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 27.9639040855 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 23.9666509825 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 29.9507941138 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 45.5571315903 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 48.9811753526 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 96.8143799928 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 31.0169322519 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 54.97065539 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 40.6778668431 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 23.2042535854 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 121.285532915 0
% INFO    : Updated Generator Cost: NG - 96.98 25.545 0.077 -> 0 57.5102042049 0
% INFO    : Updated Generator Cost: COW - 96.98 25.545 0.077 -> 0 12.9851221442 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 138.619796175 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 20.7330924255 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 112.781711728 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 38.31747002 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 35.0730854433 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 22.6340378743 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 33.3585546689 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 44.0613645402 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 38.9326714301 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 22.0646453128 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 42.2005251223 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 43.5979280928 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 14.3708123576 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 101.830301002 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 34.5384875508 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 26.0414907517 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 39.8446725297 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 113.270664002 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 103.756532716 0
% INFO    : Updated Generator Cost: NG - 178.51 15.056 0.015 -> 0 41.3520880444 0
% INFO    : Updated Generator Cost: NG - 168.64 15.193 0.017 -> 0 25.9977133296 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 44.2051574726 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 32.3310040711 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 92.851810027 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 117.312307159 0
% INFO    : Updated Generator Cost: NG - 117.91 15.839 0.026 -> 0 24.9649872318 0
% INFO    : Updated Generator Cost: PEL - 96.96 16.01 0.032 -> 0 119.374986905 0
% INFO    : Updated Generator Cost: NG - 95.87 16.01 0.032 -> 0 38.746612171 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 17.9182088639 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 36.8107425421 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 121.566946206 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 104.136886171 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 39.4199442811 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 50.8980111359 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 25.012469455 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.0112699312 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 104.359795591 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 19.7937707634 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 44.8975209383 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 106.721937999 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 30.8111305902 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 40.3664106449 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 49.7407389213 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 106.760029199 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 104.769356811 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 52.6059115909 0
% INFO    : Updated Generator Cost: PEL - 175.76 58.907 0.252 -> 0 126.654846499 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 16.7009995218 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 52.2175924673 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 99.3906202229 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 110.991239193 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 112.930297877 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 28.3908544854 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 106.127584621 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 26.4120759976 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 20.6812616337 0
% INFO    : Updated Generator Cost: COW - 399.13 13.754 0.006 -> 0 17.8376696611 0
% INFO    : Updated Generator Cost: COW - 315.3 23.71 0.022 -> 0 18.8258683688 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 21.5126697779 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 33.9820427169 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 26.7543939162 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 120.938706867 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 124.942580724 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 45.54267227 0
% INFO    : Updated Generator Cost: PEL - 68.7 16.01 0.045 -> 0 106.188338156 0
% INFO    : Updated Generator Cost: COW - 147.58 15.433 0.02 -> 0 22.9976473994 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 104.970585202 0
% INFO    : Updated Generator Cost: COW - 78.78 26.977 0.114 -> 0 6.54090158276 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 113.541046035 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 23.5894860788 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 103.089240486 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 25.0727856189 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 117.160009256 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 117.400685358 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 46.8583959209 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 43.7586168582 0
% INFO    : Updated Generator Cost: NG - 61.56 16.01 0.052 -> 0 32.9266716539 0
% INFO    : Updated Generator Cost: PEL - 73.25 16.01 0.043 -> 0 95.791129608 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 26.7106734257 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.6287859507 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 114.004795595 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 115.297858312 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 113.726727199 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 109.822009701 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 108.58037073 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 49.6061802681 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 6.61671770663 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 38.4049764839 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 16.7863626193 0
% INFO    : Updated Generator Cost: PEL - 281.72 34.34 0.051 -> 0 118.794183401 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 14.5914228613 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 112.068501879 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 98.5760563562 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 37.5791568163 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 35.4535699589 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 117.598294561 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 133.066581782 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 44.9727468048 0
% INFO    : Updated Generator Cost: NG - 192.33 34.988 0.078 -> 0 39.8879426315 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 114.976212792 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 118.108079825 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 101.504381624 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 111.846109968 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 117.100426501 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 92.4645719515 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 110.246779647 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 111.049793837 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 103.532790399 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 96.7635611219 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 112.603411161 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 127.479237235 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 111.759208452 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 97.9080903611 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 90.7369263913 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 123.316087125 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 39.3321587462 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 103.144156752 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 39.2895504583 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 42.1871564223 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.4525666352 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 42.1851185595 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 22.7708124998 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 36.746774593 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 18.830360683 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 9.76438254681 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 95.0529630698 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 38.0604848981 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 22.7777034953 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 46.2193170723 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 36.3687010827 0
% INFO    : Updated Generator Cost: NG - 210.61 34.988 0.07 -> 0 20.7685366299 0
% INFO    : Updated Generator Cost: NG - 49.55 16.01 0.063 -> 0 43.0590269275 0
% INFO    : Updated Generator Cost: PEL - 49.55 16.01 0.063 -> 0 96.5026365706 0
% INFO    : Updated Generator Cost: NG - 49.55 16.01 0.063 -> 0 25.8011247975 0
% INFO    : Updated Generator Cost: PEL - 49.55 16.01 0.063 -> 0 124.181331192 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 110.467047846 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 47.4348018806 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 121.830498343 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 122.887880925 0
% INFO    : Updated Generator Cost: NG - 398.82 13.758 0.006 -> 0 32.4840021062 0
% INFO    : Updated Generator Cost: NG - 398.82 13.758 0.006 -> 0 26.1506874468 0
% INFO    : Updated Generator Cost: NG - 180.92 15.031 0.015 -> 0 30.5187456109 0
% INFO    : Updated Generator Cost: NG - 153.26 15.375 0.019 -> 0 40.1227606209 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 24.815840816 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 23.9903714003 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 122.307091318 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 43.5963524017 0
% INFO    : Updated Generator Cost: NG - 72.36 16.01 0.044 -> 0 33.8467027656 0
% INFO    : Updated Generator Cost: PEL - 145.82 15.484 0.02 -> 0 120.011148683 0
% INFO    : Updated Generator Cost: PEL - 52.52 16.01 0.059 -> 0 114.961972815 0
% INFO    : Updated Generator Cost: NG - 160.24 15.327 0.018 -> 0 49.4611097125 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 13.3888280403 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 117.39045033 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 44.9151037565 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 38.3385181657 0
% INFO    : Updated Generator Cost: NG - 217.97 14.73 0.012 -> 0 42.382026995 0
% INFO    : Updated Generator Cost: COW - 217.97 14.73 0.012 -> 0 22.0044301319 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 46.3378676693 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 33.7468802604 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 130.336036572 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 40.0723716789 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 101.997556658 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 96.9677216943 0
% INFO    : Updated Generator Cost: PEL - 1952.1 59.305 0.01 -> 0 130.694245089 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 22.6615806985 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.1568502612 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.4349085692 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.6247694644 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 31.0203963873 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 38.297991205 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 35.8092001038 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 15.6323820955 0
% INFO    : Updated Generator Cost: NG - 43.05 16.01 0.073 -> 0 26.7070458162 0
% INFO    : Updated Generator Cost: NG - 397.06 23.176 0.017 -> 0 49.1360719474 0
% INFO    : Updated Generator Cost: NG - 397.06 23.176 0.017 -> 0 25.839945356 0
% INFO    : Updated Generator Cost: NG - 172.08 15.159 0.016 -> 0 46.9745997843 0
% INFO    : Updated Generator Cost: NG - 172.08 15.159 0.016 -> 0 48.9156834988 0
% INFO    : Updated Generator Cost: NG - 172.08 15.159 0.016 -> 0 26.987577407 0
% INFO    : Updated Generator Cost: NG - 172.08 15.159 0.016 -> 0 13.3555959306 0
% INFO    : Updated Generator Cost: NG - 172.08 15.159 0.016 -> 0 22.3281829888 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 31.3454653098 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 113.480024505 0
% INFO    : Updated Generator Cost: NG - 152.1 15.394 0.019 -> 0 43.2557855489 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 24.0382172386 0
% INFO    : Updated Generator Cost: PEL - 0.0 0.0 0.0 -> 0 99.93451342 0
% INFO    : Updated Generator Cost: COW - 1952.1 59.305 0.01 -> 0 29.2411108776 0
% INFO    : Updated Generator Cost: COW - 1952.1 59.305 0.01 -> 0 16.000078073 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 27.0105979363 0
% INFO    : Updated Generator Cost: NG - 1952.1 59.305 0.01 -> 0 21.3423498929 0
% INFO    : Updated Generator Cost: PEL - 41.17 16.01 0.076 -> 0 115.676829185 0
% INFO    : Updated Generator Cost: PEL - 86.2 25.445 0.112 -> 0 113.724219852 0
% INFO    : Updated Generator Cost: COW - 203.9 25.03 0.041 -> 0 30.0513153341 0
% INFO    : Updated Generator Cost: NG - 203.9 25.03 0.041 -> 0 51.5740830065 0
% INFO    : Updated Generator Cost: NG - 203.9 25.03 0.041 -> 0 38.218362961 0
% INFO    : Updated Generator Cost: NG - 203.9 25.03 0.041 -> 0 46.9155311632 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 17.0715661588 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 36.8449233584 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 42.5122645531 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 25.32299201 0
% INFO    : Updated Generator Cost: NG - 191.59 34.988 0.078 -> 0 21.4243208325 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 106.780088751 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 114.691369023 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 25.2210890356 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 46.5143360095 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 118.735284455 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 111.834460811 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 18.5385033951 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 106.718330745 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 46.432194725 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 120.783303262 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 109.646090256 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 102.609440661 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 116.066492079 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 120.039135524 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 95.8546763548 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 107.027773039 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 115.349371571 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 33.927928755 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 32.2733258083 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 106.532027821 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 113.936457587 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 108.588552952 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 105.120010073 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 102.671583057 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 102.611770872 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 93.7658040682 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 122.525522241 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 95.9717465957 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 112.760897435 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 124.659889167 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 123.129600458 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 121.533228524 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 104.249697541 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 108.20480091 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 104.618278291 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 112.60653101 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 122.37755457 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 42.4647750867 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 107.845943695 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 116.854343385 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 98.8333823569 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.5825208071 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 111.231493749 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 126.945196268 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 119.268875116 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 109.712394288 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 42.9479203114 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 107.696189207 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 115.747566244 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 107.018635582 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 86.9413235073 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 109.317430829 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 124.304458919 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 103.036257622 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.2708728927 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 105.163441581 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 122.90976947 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 119.174470373 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 122.701382532 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 127.885987926 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 114.767406896 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 114.195123422 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 107.073060326 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.513732072 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 140.06557299 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 108.608053764 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 134.286335523 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 113.309363231 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 109.17632741 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 100.179809982 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 122.947301938 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 115.584700425 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 121.849576536 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 127.844481137 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 48.8445249586 0
% INFO    : Updated Generator Cost: COW - 168.97 34.988 0.088 -> 0 23.8045838053 0
% INFO    : Updated Generator Cost: NG - 134.34 34.988 0.115 -> 0 42.7387433594 0
% INFO    : Updated Generator Cost: NG - 237.17 34.836 0.062 -> 0 33.099992139 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 28.7680718592 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 60.429174126 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 40.1023801505 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 109.684282245 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 17.8662996542 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.7587313577 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 112.03619682 0
% INFO    : Updated Generator Cost: NG - 89.26 16.01 0.035 -> 0 26.0560572413 0
% INFO    : Updated Generator Cost: PEL - 40.95 16.01 0.076 -> 0 104.035094801 0
% INFO    : Updated Generator Cost: NG - 419.6 13.669 0.006 -> 0 24.7681744843 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 51.1174532944 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 26.5638690352 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.0328651257 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 120.412520211 0
% INFO    : Updated Generator Cost: COW - 1755.23 50.578 0.008 -> 0 28.1548397456 0
% INFO    : Updated Generator Cost: NG - 55.78 16.01 0.056 -> 0 39.5744125754 0
% INFO    : Updated Generator Cost: NG - 55.78 16.01 0.056 -> 0 36.0396577759 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 27.8383152979 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 109.113841935 0
% INFO    : Updated Generator Cost: PEL - 100.32 25.417 0.104 -> 0 99.9598830662 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 91.5312263908 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 29.5847785196 0
% INFO    : Updated Generator Cost: NG - 594.89 13.157 0.004 -> 0 25.6643309267 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 42.2166806504 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 53.373198385 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 31.7142154797 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 47.6235610621 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.187187025 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 34.681613177 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 22.6969666586 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 10.4591199162 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 33.2292342797 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 115.51997681 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 114.666469294 0
% INFO    : Updated Generator Cost: NG - 296.82 34.024 0.047 -> 0 39.8978389836 0
% INFO    : Updated Generator Cost: NG - 296.82 34.024 0.047 -> 0 30.7564283692 0
% INFO    : Updated Generator Cost: COW - 296.82 34.024 0.047 -> 0 22.2154191011 0
% INFO    : Updated Generator Cost: PEL - 296.82 34.024 0.047 -> 0 116.466548307 0
% INFO    : Updated Generator Cost: NG - 101.4 34.988 0.152 -> 0 37.9315371666 0
% INFO    : Updated Generator Cost: PEL - 89.15 34.988 0.165 -> 0 109.656844071 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 38.1626664504 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 18.0629585365 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 38.6135264491 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 112.198762573 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 39.0802762564 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 29.624925114 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 93.0882715013 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 113.009694503 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 108.201218552 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 42.0645108638 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 114.820779556 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 109.024777331 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 38.9347846729 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 114.883712108 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 102.809603117 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 108.127484979 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 43.7664992097 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 114.26195805 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 117.592032101 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 112.273519978 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 110.316535248 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 40.3523557752 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 98.4526095124 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 92.2888272681 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 113.116362669 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 118.234400565 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 115.774806277 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 56.5498764266 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 87.8590676694 0
% INFO    : Updated Generator Cost: NG - 96.44 25.436 0.108 -> 0 43.6918709858 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 40.7689535998 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 20.7677536597 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 38.0434990752 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 117.055363483 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 41.3440694848 0
% INFO    : Updated Generator Cost: NG - 142.38 15.387 0.036 -> 0 28.121046617 0
% INFO    : Updated Generator Cost: PEL - 132.67 15.466 0.039 -> 0 108.709668999 0
% INFO    : Updated Generator Cost: NG - 142.72 15.383 0.035 -> 0 41.3169139528 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 49.4781594304 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 93.0675044175 0
% INFO    : Updated Generator Cost: PEL - 168.27 15.246 0.025 -> 0 118.232762338 0
% INFO    : Updated Generator Cost: PEL - 116.43 15.535 0.041 -> 0 97.0175457152 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 18.994352401 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 20.0317081128 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 112.540593499 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 112.172572853 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 10.8874963327 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.8766462773 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 24.968609018 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 50.9500995849 0
% INFO    : Updated Generator Cost: NG - 119.85 34.988 0.124 -> 0 33.1753604967 0
% INFO    : Updated Generator Cost: NG - 169.69 34.988 0.087 -> 0 47.5586990755 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 106.71899208 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.064390955 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 87.1020340835 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 115.492425211 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 28.4885966782 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 121.677533439 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 37.0911950708 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 23.8983973077 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 118.660890865 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 98.8237792398 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 25.7135716045 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 37.0015358716 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.9955965243 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 93.8736551203 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 114.577675252 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 109.710519881 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 36.5515673629 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 33.9946804625 0
% INFO    : Updated Generator Cost: NG - 994.79 81.316 0.081 -> 0 42.2435067725 0
% INFO    : Updated Generator Cost: PEL - 147.25 15.435 0.02 -> 0 123.391887709 0
% INFO    : Updated Generator Cost: COW - 212.97 14.772 0.013 -> 0 34.5454826924 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 122.209371876 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.1424115237 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.4184253722 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 22.989088995 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 35.5842602253 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 14.2485638578 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 122.796445101 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 28.6590373429 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 108.150505889 0
% INFO    : Updated Generator Cost: NG - 334.77 23.566 0.02 -> 0 54.3842172174 0
% INFO    : Updated Generator Cost: NG - 334.77 23.566 0.02 -> 0 44.1014418442 0
% INFO    : Updated Generator Cost: COW - 358.87 13.926 0.007 -> 0 21.0011829131 0
% INFO    : Updated Generator Cost: NG - 358.87 13.926 0.007 -> 0 50.5872627877 0
% INFO    : Updated Generator Cost: COW - 358.87 13.926 0.007 -> 0 32.5745063792 0
% INFO    : Updated Generator Cost: NG - 358.87 13.926 0.007 -> 0 36.5129100134 0
% INFO    : Updated Generator Cost: NG - 358.87 13.926 0.007 -> 0 27.476642797 0
% INFO    : Updated Generator Cost: NG - 358.87 13.926 0.007 -> 0 30.6197297643 0
% INFO    : Updated Generator Cost: NG - 358.87 13.926 0.007 -> 0 41.9387332577 0
% INFO    : Updated Generator Cost: COW - 358.87 13.926 0.007 -> 0 35.5287486314 0
% INFO    : Updated Generator Cost: NG - 358.87 13.926 0.007 -> 0 25.8015018982 0
% INFO    : Updated Generator Cost: NG - 358.87 13.926 0.007 -> 0 34.6029928528 0
% INFO    : Updated Generator Cost: PEL - 358.87 13.926 0.007 -> 0 120.406163117 0
% INFO    : Updated Generator Cost: NG - 358.87 13.926 0.007 -> 0 42.9534179721 0
% INFO    : Updated Generator Cost: NG - 358.87 13.926 0.007 -> 0 45.3667790439 0
% INFO    : Updated Generator Cost: NG - 358.87 13.926 0.007 -> 0 22.4994430044 0
% INFO    : Updated Generator Cost: NG - 358.87 13.926 0.007 -> 0 50.3033973238 0
% INFO    : Updated Generator Cost: NG - 358.87 13.926 0.007 -> 0 40.2346372834 0
% INFO    : Updated Generator Cost: NG - 358.87 13.926 0.007 -> 0 41.3976067966 0
% INFO    : Updated Generator Cost: PEL - 358.87 13.926 0.007 -> 0 122.851148304 0
% INFO    : Updated Generator Cost: NG - 358.87 13.926 0.007 -> 0 21.2740752758 0
% INFO    : Updated Generator Cost: PEL - 120.27 15.795 0.025 -> 0 113.749587493 0
% INFO    : Updated Generator Cost: PEL - 120.27 15.795 0.025 -> 0 94.6980301075 0
% INFO    : Updated Generator Cost: NG - 120.27 15.795 0.025 -> 0 31.8823713525 0
% INFO    : Updated Generator Cost: NG - 120.27 15.795 0.025 -> 0 20.3033795093 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 23.2866440918 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 50.3481297955 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 21.8038661306 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 19.7571586173 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 29.4835504803 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 99.669599766 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 113.316304709 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.5962487301 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 49.267893842 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 23.3214640692 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 102.73282368 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 39.6034708207 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 125.322807936 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 108.956873445 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 33.0557866241 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 48.6879982907 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 33.4407930624 0
% INFO    : Updated Generator Cost: NG - 396.92 13.759 0.006 -> 0 47.3594944251 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 27.7642336986 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 41.4497094883 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 28.2364597305 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 111.831828175 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 17.4713820739 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 38.5585033655 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 32.1765055621 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 11.008412479 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 114.521501781 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 35.4086710719 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 122.904394583 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 125.25748131 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 34.5232299411 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 39.9409230358 0
% INFO    : Updated Generator Cost: COW - 131.69 14.879 0.021 -> 0 39.7561707298 0
% INFO    : Updated Generator Cost: PEL - 131.69 14.879 0.021 -> 0 93.5654329873 0
% INFO    : Updated Generator Cost: NG - 131.69 14.879 0.021 -> 0 45.1177686031 0
% INFO    : Updated Generator Cost: NG - 163.62 15.261 0.017 -> 0 27.2502104145 0
% INFO    : Updated Generator Cost: NG - 163.62 15.261 0.017 -> 0 33.3685319224 0
% INFO    : Updated Generator Cost: NG - 163.62 15.261 0.017 -> 0 35.6319993295 0
% INFO    : Updated Generator Cost: COW - 163.62 15.261 0.017 -> 0 25.05323656 0
% INFO    : Updated Generator Cost: COW - 163.62 15.261 0.017 -> 0 43.0863732799 0
% INFO    : Updated Generator Cost: NG - 163.62 15.261 0.017 -> 0 40.4404157615 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 30.2956883147 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 27.7197913161 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 25.6912264387 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 36.4245235253 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 44.8341942658 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 30.1445478502 0
% INFO    : Updated Generator Cost: COW - 78.78 26.977 0.114 -> 0 21.4314866246 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 39.709551044 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 28.7357621051 0
% INFO    : Updated Generator Cost: COW - 78.78 26.977 0.114 -> 0 28.3130422745 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 43.1223089375 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 32.3926807019 0
% INFO    : Updated Generator Cost: COW - 78.78 26.977 0.114 -> 0 28.8464676509 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 48.1584347501 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 49.7731461287 0
% INFO    : Updated Generator Cost: NG - 78.78 26.977 0.114 -> 0 48.1087651215 0
% INFO    : Updated Generator Cost: NG - 93.78 16.01 0.033 -> 0 22.4031205401 0
% INFO    : Updated Generator Cost: NG - 93.78 16.01 0.033 -> 0 26.0383110241 0
% INFO    : Updated Generator Cost: NG - 93.78 16.01 0.033 -> 0 38.9327937094 0
% INFO    : Updated Generator Cost: NG - 93.78 16.01 0.033 -> 0 26.351519777 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 20.7726232836 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 22.5000929983 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 45.0996558968 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.5191503193 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 12.7011157834 0
% INFO    : Updated Generator Cost: PEL - 140.24 15.545 0.021 -> 0 117.930465891 0
% INFO    : Updated Generator Cost: PEL - 78.39 16.01 0.041 -> 0 123.726486001 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 118.91228058 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 23.0775046305 0
% INFO    : Updated Generator Cost: NG - 52.75 16.01 0.058 -> 0 27.5123780132 0
% INFO    : Updated Generator Cost: NG - 332.33 14.03 0.007 -> 0 30.3661483931 0
% INFO    : Updated Generator Cost: PEL - 147.23 15.438 0.02 -> 0 103.117674434 0
% INFO    : Updated Generator Cost: NG - 51.19 16.01 0.061 -> 0 50.1771296966 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 120.430553806 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 105.374532907 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 114.273043054 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 104.959177146 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 117.556716759 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 118.085840956 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 119.818695032 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 82.822100387 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 118.803588581 0
% INFO    : Updated Generator Cost: PEL - 78.78 26.977 0.114 -> 0 108.517409795 0
% INFO    : Updated Generator Cost: NG - 557.1 13.259 0.004 -> 0 38.9136315666 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 39.2057886953 0
% INFO    : Updated Generator Cost: NG - 123.37 15.771 0.024 -> 0 4.47365393569 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 17.9066252714 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.4425944816 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.318510637 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 29.9744548507 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 51.6590902735 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 19.3519027448 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 53.307586891 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 31.927926274 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 26.5611417391 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 16.7517088556 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 11.037699573 0
% INFO    : Updated Generator Cost: NG - 367.1 17.118 0.005 -> 0 33.093069477 0
% INFO    : Updated Generator Cost: COW - 130.87 25.545 0.063 -> 0 35.3589169156 0
% INFO    : Updated Generator Cost: NG - 130.87 25.545 0.063 -> 0 40.0387166667 0
% INFO    : Updated Generator Cost: NG - 130.87 25.545 0.063 -> 0 51.9731002433 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 116.939026226 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 30.4646022606 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 40.0466419905 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 39.8611640758 0
% INFO    : Updated Generator Cost: NG - 315.44 14.086 0.008 -> 0 37.5181823742 0
% INFO    : Updated Generator Cost: PEL - 66.71 16.01 0.046 -> 0 83.2116277977 0
% INFO    : Updated Generator Cost: PEL - 66.71 16.01 0.046 -> 0 119.459079779 0
% INFO    : Updated Generator Cost: COW - 66.71 16.01 0.046 -> 0 21.474081984 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 40.8120995635 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 95.8405375776 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 35.8535527972 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 122.037798378 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 23.6491108979 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 46.6878747086 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 54.0609553757 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 119.27157084 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 27.3337990628 0
% INFO    : Updated Generator Cost: COW - 128.6 26.977 0.07 -> 0 21.3308095547 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 19.7663453084 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 46.3152770564 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 48.7552508222 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 15.323363714 0
% INFO    : Updated Generator Cost: COW - 2249.86 9.547 0.032 -> 0 27.9218554569 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 31.319270643 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 20.677583395 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 52.2922660286 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 37.096749862 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 115.271301345 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 42.7085339699 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 114.11863378 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 124.871957998 0
% INFO    : Updated Generator Cost: PEL - 196.11 25.049 0.047 -> 0 127.329977256 0
% INFO    : Updated Generator Cost: PEL - 196.11 25.049 0.047 -> 0 121.262009001 0
% INFO    : Updated Generator Cost: NG - 158.46 15.335 0.018 -> 0 19.3615981514 0
% INFO    : Updated Generator Cost: NG - 106.73 15.962 0.029 -> 0 52.4894800037 0
% INFO    : Updated Generator Cost: NG - 74.7 16.01 0.043 -> 0 33.4381026007 0
% INFO    : Updated Generator Cost: NG - 74.7 16.01 0.043 -> 0 21.2775372437 0
% INFO    : Updated Generator Cost: NG - 74.7 16.01 0.043 -> 0 37.890869607 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 98.4565026408 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.6053795027 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 41.4222320155 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 115.855995834 0
% INFO    : Updated Generator Cost: COW - 1755.23 50.578 0.008 -> 0 21.2488634707 0
% INFO    : Updated Generator Cost: NG - 126.25 25.34 0.09 -> 0 51.71573857 0
% INFO    : Updated Generator Cost: NG - 126.25 25.34 0.09 -> 0 48.6022674042 0
% INFO    : Updated Generator Cost: COW - 126.25 25.34 0.09 -> 0 31.464910098 0
% INFO    : Updated Generator Cost: NG - 114.69 34.988 0.129 -> 0 38.0871323811 0
% INFO    : Updated Generator Cost: NG - 114.69 34.988 0.129 -> 0 45.0519025818 0
% INFO    : Updated Generator Cost: PEL - 101.46 34.988 0.146 -> 0 117.671716198 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 109.784378937 0
% INFO    : Updated Generator Cost: NG - 242.58 14.589 0.011 -> 0 46.3905071263 0
% INFO    : Updated Generator Cost: NG - 242.58 14.589 0.011 -> 0 24.8133005911 0
% INFO    : Updated Generator Cost: PEL - 242.58 14.589 0.011 -> 0 121.209732466 0
% INFO    : Updated Generator Cost: PEL - 242.58 14.589 0.011 -> 0 107.720935537 0
% INFO    : Updated Generator Cost: PEL - 242.58 14.589 0.011 -> 0 94.0494337392 0
% INFO    : Updated Generator Cost: NG - 57.75 16.01 0.053 -> 0 30.0337358733 0
% INFO    : Updated Generator Cost: COW - 57.75 16.01 0.053 -> 0 26.1070789386 0
% INFO    : Updated Generator Cost: NG - 87.87 16.01 0.035 -> 0 20.3153350992 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 35.0680307233 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 25.5965023605 0
% INFO    : Updated Generator Cost: NG - 179.9 22.633 0.035 -> 0 22.1456997138 0
% INFO    : Updated Generator Cost: PEL - 97.73 34.988 0.152 -> 0 136.810006425 0
% INFO    : Updated Generator Cost: NG - 143.8 34.988 0.108 -> 0 44.9958286907 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 42.8321265134 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 104.848033025 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 42.4239648035 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 22.9844054645 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 38.2679901599 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.1289327421 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 22.9200811014 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 115.87857506 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 94.0098237591 0
% INFO    : Updated Generator Cost: NG - 181.34 34.988 0.082 -> 0 43.7465217535 0
% INFO    : Updated Generator Cost: NG - 145.51 34.988 0.107 -> 0 39.7041000397 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 114.185941409 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 109.552624671 0
% INFO    : Updated Generator Cost: NG - 107.54 25.401 0.103 -> 0 42.7512741258 0
% INFO    : Updated Generator Cost: NG - 107.54 25.401 0.103 -> 0 37.8345917706 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 30.9595068284 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 29.4298356047 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 13.3077719285 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 38.931926522 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 21.3189129455 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 19.69747785 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 28.6553128399 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 48.3115054409 0
% INFO    : Updated Generator Cost: NG - 199.65 34.988 0.074 -> 0 48.7391261309 0
% INFO    : Updated Generator Cost: NG - 199.65 34.988 0.074 -> 0 40.0125995725 0
% INFO    : Updated Generator Cost: NG - 206.28 34.988 0.072 -> 0 42.0666832531 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 12.241170265 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 42.492236288 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 21.622758197 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 26.3121246023 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 37.3271937249 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 40.3058064095 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 42.4139588725 0
% INFO    : Updated Generator Cost: NG - 158.11 34.988 0.092 -> 0 31.5500632564 0
% INFO    : Updated Generator Cost: NG - 110.83 34.988 0.133 -> 0 19.805965132 0
% INFO    : Updated Generator Cost: PEL - 141.01 34.988 0.109 -> 0 110.884145756 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 43.5956014748 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 22.1953558759 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 47.1616332323 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 115.304912316 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 35.633168744 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 28.0026952872 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.7768646713 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 38.9241654015 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 107.003625466 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 108.535566059 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 100.75439784 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 106.510658445 0
% INFO    : Updated Generator Cost: PEL - 90.77 34.988 0.166 -> 0 82.0557832323 0
% INFO    : Updated Generator Cost: PEL - 110.89 34.988 0.133 -> 0 115.177932378 0
% INFO    : Updated Generator Cost: NG - 176.45 34.988 0.084 -> 0 47.0495580918 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 16.5800896407 0
% INFO    : Updated Generator Cost: NG - 2894.55 60.757 0.005 -> 0 28.5996786293 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 121.973998295 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 122.681420886 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 25.7919353703 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 39.2380056222 0
% INFO    : Updated Generator Cost: NG - 370.55 23.336 0.018 -> 0 41.8572855421 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 35.9692513252 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 25.8599462641 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 29.9211534749 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 26.8881545386 0
% INFO    : Updated Generator Cost: COW - 371.49 16.922 0.007 -> 0 12.066467367 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 23.3009011978 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 25.2113701539 0
% INFO    : Updated Generator Cost: NG - 336.39 33.595 0.041 -> 0 40.6601490618 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 104.304773231 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 28.3007813962 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.8609929729 0
% INFO    : Updated Generator Cost: NG - 156.87 25.204 0.069 -> 0 13.186742846 0
% INFO    : Updated Generator Cost: PEL - 156.87 25.204 0.069 -> 0 111.626259505 0
% INFO    : Updated Generator Cost: NG - 156.87 25.204 0.069 -> 0 43.6552717646 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 34.9470361279 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 42.6414501929 0
% INFO    : Updated Generator Cost: NG - 96.45 25.435 0.107 -> 0 34.4887463059 0
% INFO    : Updated Generator Cost: PEL - 142.67 25.267 0.077 -> 0 125.204826949 0
% INFO    : Updated Generator Cost: PEL - 241.35 24.615 0.032 -> 0 124.240428408 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 44.0269361659 0
% INFO    : Updated Generator Cost: PEL - 136.8 34.988 0.113 -> 0 112.12210495 0
% INFO    : Updated Generator Cost: NG - 179.49 34.988 0.083 -> 0 17.798860537 0
% INFO    : Updated Generator Cost: NG - 179.49 34.988 0.083 -> 0 60.3363498135 0
% INFO    : Updated Generator Cost: NG - 163.21 34.988 0.091 -> 0 35.8321487506 0
% INFO    : Updated Generator Cost: NG - 165.01 34.988 0.089 -> 0 30.5316467128 0
% INFO    : Updated Generator Cost: NG - 112.84 34.988 0.13 -> 0 23.9816042684 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 128.622433817 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 13.6394820749 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 41.9866384706 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 32.3922363721 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 101.291002223 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 37.4180312189 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 44.2008449647 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 119.883422626 0
% INFO    : Updated Generator Cost: PEL - 92.96 15.795 0.063 -> 0 118.667852563 0
% INFO    : Updated Generator Cost: PEL - 92.96 15.795 0.063 -> 0 93.6250429581 0
% INFO    : Updated Generator Cost: NG - 441.83 13.599 0.005 -> 0 56.4311680767 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 36.0790639521 0
% INFO    : Updated Generator Cost: NG - 993.75 11.398 0.026 -> 0 38.6056722412 0
% INFO    : Updated Generator Cost: NG - 381.39 13.818 0.006 -> 0 34.8081991827 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 115.263624182 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 125.484719171 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 104.187408796 0
% INFO    : Updated Generator Cost: COW - 107.79 15.955 0.029 -> 0 28.9877818514 0
% INFO    : Updated Generator Cost: COW - 107.79 15.955 0.029 -> 0 29.0465492401 0
% INFO    : Updated Generator Cost: COW - 107.79 15.955 0.029 -> 0 11.4373815634 0
% INFO    : Updated Generator Cost: COW - 107.79 15.955 0.029 -> 0 27.013546787 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 43.0366281461 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 37.2293518396 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 42.5773817559 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 32.2107114656 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 32.8229047376 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 46.32234111 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 25.9300831612 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 11.5592350104 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 35.5268834132 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 34.7178255898 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 39.1052272567 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 97.4620204513 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 108.878808084 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 119.937402515 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 42.9181307717 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 42.814784143 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 102.565287236 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 30.2771424991 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 12.0587915546 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 28.7616527277 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 64.1409069152 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 33.5583065094 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 131.614843765 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 103.653552612 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 26.2953332638 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.1747314395 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 114.973054361 0
% INFO    : Updated Generator Cost: PEL - 206.52 25.024 0.04 -> 0 122.240931114 0
% INFO    : Updated Generator Cost: NG - 97.38 25.43 0.105 -> 0 25.7327939736 0
% INFO    : Updated Generator Cost: NG - 97.38 25.43 0.105 -> 0 21.2696308723 0
% INFO    : Updated Generator Cost: PEL - 46.94 16.01 0.066 -> 0 129.663058735 0
% INFO    : Updated Generator Cost: NG - 46.94 16.01 0.066 -> 0 27.5944021547 0
% INFO    : Updated Generator Cost: NG - 43.87 16.01 0.071 -> 0 26.0748097969 0
% INFO    : Updated Generator Cost: NG - 139.23 25.281 0.08 -> 0 41.897813086 0
% INFO    : Updated Generator Cost: NG - 119.65 15.805 0.025 -> 0 42.8350580183 0
% INFO    : Updated Generator Cost: NG - 89.97 16.01 0.035 -> 0 16.5534608341 0
% INFO    : Updated Generator Cost: PEL - 44.29 16.01 0.071 -> 0 107.309911159 0
% INFO    : Updated Generator Cost: NG - 44.29 16.01 0.071 -> 0 48.0611282441 0
% INFO    : Updated Generator Cost: NG - 196.9 14.869 0.014 -> 0 24.6522813153 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 42.7835379542 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 34.2144281026 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 106.631220127 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 103.981733595 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 39.8712933014 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 129.432675545 0
% INFO    : Updated Generator Cost: NG - 82.69 16.01 0.037 -> 0 45.9995497355 0
% INFO    : Updated Generator Cost: NG - 150.79 15.419 0.019 -> 0 44.2988281327 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 24.1010781996 0
% INFO    : Updated Generator Cost: COW - 588.04 18.772 0.009 -> 0 16.7482199981 0
% INFO    : Updated Generator Cost: PEL - 588.04 18.772 0.009 -> 0 119.275622519 0
% INFO    : Updated Generator Cost: PEL - 151.5 15.397 0.019 -> 0 112.091665009 0
% INFO    : Updated Generator Cost: PEL - 1755.23 50.578 0.008 -> 0 109.143209975 0
% INFO    : Updated Generator Cost: NG - 1755.23 50.578 0.008 -> 0 23.515297572 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 27.6574436851 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 111.628194654 0
% INFO    : Updated Generator Cost: PEL - 128.6 26.977 0.07 -> 0 111.393928627 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 32.4496583007 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 36.3113236833 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 35.8855787091 0
% INFO    : Updated Generator Cost: NG - 128.6 26.977 0.07 -> 0 46.0575369594 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 32.1807932617 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 52.0703439302 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 36.9929000047 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 38.0172146336 0
% INFO    : Updated Generator Cost: PEL - 292.81 34.15 0.048 -> 0 119.141222633 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 114.6241381 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 39.3971154349 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 17.2657556059 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 33.299093311 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 34.3665035496 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 22.4603966277 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 30.9043692815 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 41.0030100658 0
% INFO    : Updated Generator Cost: COW - 43.97 14.879 0.062 -> 0 17.7063395369 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 111.353895978 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 31.2111739057 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 49.8391390084 0
% INFO    : Updated Generator Cost: NG - 51.52 16.01 0.061 -> 0 16.13909636 0
% INFO    : Updated Generator Cost: NG - 51.52 16.01 0.061 -> 0 36.707261779 0
% INFO    : Updated Generator Cost: NG - 51.52 16.01 0.061 -> 0 72.402355406 0
% INFO    : Updated Generator Cost: NG - 51.52 16.01 0.061 -> 0 28.9962302256 0
% INFO    : Updated Generator Cost: PEL - 51.52 16.01 0.061 -> 0 122.939513908 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 27.0679633349 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 58.5131668277 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 28.9784277884 0
% INFO    : Updated Generator Cost: PEL - 2249.86 9.547 0.032 -> 0 99.7843117834 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 35.4834686864 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 42.5565188359 0
% INFO    : Updated Generator Cost: NG - 2249.86 9.547 0.032 -> 0 27.3040373584 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 108.045645427 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 32.3915090047 0
% INFO    : Updated Generator Cost: NG - 51.34 14.879 0.053 -> 0 19.3129467579 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 30.9810383103 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 22.0852007704 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 37.8086182081 0
% INFO    : Updated Generator Cost: COW - 0.0 0.0 0.0 -> 0 18.8173278155 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 108.909352307 0
% INFO    : Updated Generator Cost: PEL - 51.34 14.879 0.053 -> 0 101.553678043 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 33.5753768227 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 16.2937555768 0
% INFO    : Updated Generator Cost: NG - 588.04 18.772 0.009 -> 0 40.0243611324 0
% INFO    : Updated Generator Cost: NG - 0.0 0.0 0.0 -> 0 34.9312534967 0
% INFO    : Updated Generator Cost: PEL - 371.49 16.922 0.007 -> 0 126.216505748 0
% INFO    : Updated Generator Cost: NG - 371.49 16.922 0.007 -> 0 41.2607988652 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 43.0183984172 0
% INFO    : Updated Generator Cost: PEL - 0.38 17.2 0.004 -> 0 125.295223701 0
% INFO    : Updated Generator Cost: COW - 0.38 17.2 0.004 -> 0 25.0915496989 0
% INFO    : Updated Generator Cost: NG - 203.71 25.032 0.041 -> 0 55.4484082664 0
% INFO    : Updated Generator Cost: PEL - 203.71 25.032 0.041 -> 0 116.344499895 0
% INFO    : Updated Generator Cost: PEL - 203.71 25.032 0.041 -> 0 114.479828847 0
% INFO    : Updated Generator Cost: NG - 203.71 25.032 0.041 -> 0 26.0948993437 0
% INFO    : Updated Generator Cost: NG - 201.37 25.037 0.042 -> 0 0.283435044202 0
% INFO    : Updated Generator Cost: PEL - 208.25 25.024 0.039 -> 0 128.900387078 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 39.1712105121 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 40.2745022623 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 31.0287347262 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 36.3022339863 0
% INFO    : Updated Generator Cost: COW - 0.38 17.2 0.004 -> 0 35.6257852183 0
% INFO    : Updated Generator Cost: NG - 318.86 13.54 0.026 -> 0 38.3978423885 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.54 0.026 -> 0 108.256089455 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.54 0.026 -> 0 95.0430351551 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.54 0.026 -> 0 105.088716803 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 12.1871205583 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 30.2065271367 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 42.4025336441 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 41.1369548643 0
% INFO    : Updated Generator Cost: NG - 0.38 17.2 0.004 -> 0 33.4747173864 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 107.996023469 0
% INFO    : Updated Generator Cost: NG - 150.5 25.545 0.055 -> 0 27.5955467136 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 27.8347549586 0
% INFO    : Updated Generator Cost: NG - 148.2 25.236 0.071 -> 0 17.2136682564 0
% INFO    : Updated Generator Cost: COW - 318.86 13.537 0.026 -> 0 11.6645842128 0
% INFO    : Updated Generator Cost: NG - 137.52 25.303 0.082 -> 0 35.0569256531 0
% INFO    : Updated Generator Cost: PEL - 137.52 25.303 0.082 -> 0 114.182798802 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 18.6611501573 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 107.452621924 0
% INFO    : Updated Generator Cost: NG - 99.99 15.604 0.06 -> 0 20.427535626 0
% INFO    : Updated Generator Cost: NG - 99.99 15.604 0.06 -> 0 27.8880316889 0
% INFO    : Updated Generator Cost: NG - 99.99 15.604 0.06 -> 0 33.9454147927 0
% INFO    : Updated Generator Cost: PEL - 99.99 15.604 0.06 -> 0 124.621292903 0
% INFO    : Updated Generator Cost: PEL - 43.97 14.879 0.062 -> 0 127.368900834 0
% INFO    : Updated Generator Cost: NG - 43.97 14.879 0.062 -> 0 43.3930724926 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 70.3018723682 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 120.628331626 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 109.377021186 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 117.813792369 0
% INFO    : Updated Generator Cost: PEL - 318.86 13.537 0.026 -> 0 131.768982418 0
% INFO    : Updated Generator Cost: NG - 318.86 13.537 0.026 -> 0 49.335689756 0
% INFO    : 
% INFO    : === Generator Bounds Update Notes ===
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% WARNING : Branch 18504-95342 connects two different voltage levels (69.0, 500.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 45961-45962 connects two different voltage levels (138.0, 230.0), changing tap ratio 0.0 => 1.0
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : Updated Thermal Rating: on line 14540-14541 : Rate C - 26.4 -> 35.0
% INFO    : Updated Thermal Rating: on line 20621-82078 : Rate C - 26.4 -> 35.0
% INFO    : Updated Thermal Rating: on line 21509-82467 : Rate C - 26.4 -> 35.0
% INFO    : Updated Thermal Rating: on line 39699-39700 : Rate C - 26.4 -> 35.0
% INFO    : Updated Thermal Rating: on line 81516-81610 : Rate C - 26.4 -> 35.0
% INFO    : Updated Thermal Rating: on line 84194-84197 : Rate C - 26.4 -> 27.0
% INFO    : Updated Thermal Rating: on line 87411-87423 : Rate C - 26.4 -> 35.0
% INFO    : Updated Thermal Rating: on line 90673-90972 : Rate C - 26.4 -> 35.0
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 1	: V=1.02, theta=-60.778328 -> V=1.0, theta=0.0
% INFO    : Bus 2	: V=1.0156269, theta=-64.310995 -> V=1.0, theta=0.0
% INFO    : Bus 3	: V=1.02, theta=-61.997851 -> V=1.0, theta=0.0
% INFO    : Bus 4	: V=1.02, theta=-62.887085 -> V=1.0, theta=0.0
% INFO    : Bus 5	: V=1.02, theta=-70.677439 -> V=1.0, theta=0.0
% INFO    : Bus 6	: V=1.0199929, theta=-61.986899 -> V=1.0, theta=0.0
% INFO    : Bus 7	: V=1.0151134, theta=-67.034327 -> V=1.0, theta=0.0
% INFO    : Bus 8	: V=0.9794586, theta=-68.497681 -> V=1.0, theta=0.0
% INFO    : Bus 9	: V=1.0001361, theta=-67.324139 -> V=1.0, theta=0.0
% INFO    : Bus 10	: V=1.02, theta=-64.164548 -> V=1.0, theta=0.0
% INFO    : Bus 11	: V=1.0154066, theta=-62.624954 -> V=1.0, theta=0.0
% INFO    : Bus 12	: V=1.0156857, theta=-63.557774 -> V=1.0, theta=0.0
% INFO    : Bus 13	: V=0.9977904, theta=-72.955512 -> V=1.0, theta=0.0
% INFO    : Bus 14	: V=1.0193441, theta=-63.484754 -> V=1.0, theta=0.0
% INFO    : Bus 15	: V=1.0001881, theta=-67.327094 -> V=1.0, theta=0.0
% INFO    : Bus 16	: V=0.9855262, theta=-71.162635 -> V=1.0, theta=0.0
% INFO    : Bus 17	: V=0.9765625, theta=-71.502697 -> V=1.0, theta=0.0
% INFO    : Bus 18	: V=0.9857282, theta=-71.149275 -> V=1.0, theta=0.0
% INFO    : Bus 19	: V=0.989566, theta=-66.899988 -> V=1.0, theta=0.0
% INFO    : Bus 20	: V=0.9785671, theta=-72.018643 -> V=1.0, theta=0.0
% INFO    : Bus 21	: V=0.9927616, theta=-66.285626 -> V=1.0, theta=0.0
% INFO    : Bus 22	: V=1.0103545, theta=-64.34167 -> V=1.0, theta=0.0
% INFO    : Bus 23	: V=0.9823371, theta=-71.081183 -> V=1.0, theta=0.0
% INFO    : Bus 24	: V=0.9830788, theta=-72.165591 -> V=1.0, theta=0.0
% INFO    : Bus 25	: V=0.9841573, theta=-69.153343 -> V=1.0, theta=0.0
% INFO    : Bus 26	: V=1.0079822, theta=-63.367691 -> V=1.0, theta=0.0
% INFO    : Bus 27	: V=0.9874217, theta=-67.46017 -> V=1.0, theta=0.0
% INFO    : Bus 28	: V=0.9709835, theta=-71.912511 -> V=1.0, theta=0.0
% INFO    : Bus 29	: V=0.9685097, theta=-72.746351 -> V=1.0, theta=0.0
% INFO    : Bus 30	: V=0.9828932, theta=-68.945881 -> V=1.0, theta=0.0
% INFO    : Bus 31	: V=0.9937336, theta=-64.5207 -> V=1.0, theta=0.0
% INFO    : Bus 32	: V=1.02, theta=-72.818474 -> V=1.0, theta=0.0
% INFO    : Bus 33	: V=1.02, theta=-69.489227 -> V=1.0, theta=0.0
% INFO    : Bus 34	: V=1.02, theta=-67.212792 -> V=1.0, theta=0.0
% INFO    : Bus 35	: V=1.02, theta=-72.454707 -> V=1.0, theta=0.0
% INFO    : Bus 36	: V=1.02, theta=-74.335172 -> V=1.0, theta=0.0
% INFO    : Bus 37	: V=1.02, theta=-73.547344 -> V=1.0, theta=0.0
% INFO    : Bus 38	: V=1.02, theta=-76.101158 -> V=1.0, theta=0.0
% INFO    : Bus 39	: V=1.02, theta=-76.007233 -> V=1.0, theta=0.0
% INFO    : Bus 40	: V=1.02, theta=-76.162185 -> V=1.0, theta=0.0
% INFO    : Bus 41	: V=1.02, theta=-72.849444 -> V=1.0, theta=0.0
% INFO    : Bus 42	: V=1.02, theta=-69.561431 -> V=1.0, theta=0.0
% INFO    : Bus 43	: V=1.006481, theta=-73.462096 -> V=1.0, theta=0.0
% INFO    : Bus 44	: V=1.0185195, theta=-75.696282 -> V=1.0, theta=0.0
% INFO    : Bus 45	: V=1.0085881, theta=-72.720413 -> V=1.0, theta=0.0
% INFO    : Bus 46	: V=1.0163368, theta=-74.040608 -> V=1.0, theta=0.0
% INFO    : Bus 47	: V=1.0182398, theta=-73.970045 -> V=1.0, theta=0.0
% INFO    : Bus 48	: V=1.0185192, theta=-69.791908 -> V=1.0, theta=0.0
% INFO    : Bus 49	: V=1.0193157, theta=-76.069182 -> V=1.0, theta=0.0
% INFO    : Bus 50	: V=1.0008306, theta=-78.041629 -> V=1.0, theta=0.0
% INFO    : Bus 51	: V=1.02, theta=-72.847119 -> V=1.0, theta=0.0
% INFO    : Bus 52	: V=1.0145496, theta=-72.097275 -> V=1.0, theta=0.0
% INFO    : Bus 53	: V=0.9777893, theta=-78.099897 -> V=1.0, theta=0.0
% INFO    : Bus 54	: V=0.9959708, theta=-78.642239 -> V=1.0, theta=0.0
% INFO    : Bus 55	: V=0.9859331, theta=-77.628248 -> V=1.0, theta=0.0
% INFO    : Bus 56	: V=1.0114012, theta=-75.665542 -> V=1.0, theta=0.0
% INFO    : Bus 57	: V=0.988378, theta=-78.231431 -> V=1.0, theta=0.0
% INFO    : Bus 58	: V=0.9990487, theta=-68.813771 -> V=1.0, theta=0.0
% INFO    : Bus 59	: V=0.9850753, theta=-77.798873 -> V=1.0, theta=0.0
% INFO    : Bus 60	: V=1.0048574, theta=-75.741808 -> V=1.0, theta=0.0
% INFO    : Bus 61	: V=0.9957493, theta=-73.980596 -> V=1.0, theta=0.0
% INFO    : Bus 62	: V=0.9918374, theta=-75.36845 -> V=1.0, theta=0.0
% INFO    : Bus 63	: V=0.9907175, theta=-78.980757 -> V=1.0, theta=0.0
% INFO    : Bus 64	: V=0.9916195, theta=-79.361752 -> V=1.0, theta=0.0
% INFO    : Bus 65	: V=0.9996651, theta=-78.119649 -> V=1.0, theta=0.0
% INFO    : Bus 66	: V=0.990913, theta=-76.902678 -> V=1.0, theta=0.0
% INFO    : Bus 67	: V=1.0162128, theta=-75.87775 -> V=1.0, theta=0.0
% INFO    : Bus 68	: V=0.9610001, theta=-79.513942 -> V=1.0, theta=0.0
% INFO    : Bus 69	: V=0.9769366, theta=-79.276036 -> V=1.0, theta=0.0
% INFO    : Bus 70	: V=0.9971504, theta=-78.244028 -> V=1.0, theta=0.0
% INFO    : Bus 71	: V=0.993162, theta=-70.171372 -> V=1.0, theta=0.0
% INFO    : Bus 72	: V=0.9802484, theta=-72.760733 -> V=1.0, theta=0.0
% INFO    : Bus 73	: V=0.9934609, theta=-73.984884 -> V=1.0, theta=0.0
% INFO    : Bus 74	: V=1.0169792, theta=-78.178028 -> V=1.0, theta=0.0
% INFO    : Bus 75	: V=1.02, theta=-76.854108 -> V=1.0, theta=0.0
% INFO    : Bus 76	: V=1.0219655, theta=-74.779781 -> V=1.0, theta=0.0
% INFO    : Bus 77	: V=1.02, theta=-77.405197 -> V=1.0, theta=0.0
% INFO    : Bus 78	: V=1.02, theta=-77.176301 -> V=1.0, theta=0.0
% INFO    : Bus 79	: V=1.02, theta=-75.099719 -> V=1.0, theta=0.0
% INFO    : Bus 80	: V=1.0227344, theta=-77.742097 -> V=1.0, theta=0.0
% INFO    : Bus 81	: V=1.0181749, theta=-77.586433 -> V=1.0, theta=0.0
% INFO    : Bus 82	: V=1.02, theta=-78.022621 -> V=1.0, theta=0.0
% INFO    : Bus 83	: V=1.02, theta=-78.211325 -> V=1.0, theta=0.0
% INFO    : Bus 84	: V=1.02, theta=-76.138448 -> V=1.0, theta=0.0
% INFO    : Bus 85	: V=0.9928911, theta=-81.316748 -> V=1.0, theta=0.0
% INFO    : Bus 86	: V=1.02, theta=-75.782852 -> V=1.0, theta=0.0
% INFO    : Bus 87	: V=1.02, theta=-75.30914 -> V=1.0, theta=0.0
% INFO    : Bus 88	: V=1.02, theta=-79.990781 -> V=1.0, theta=0.0
% INFO    : Bus 89	: V=1.0081932, theta=-78.835723 -> V=1.0, theta=0.0
% INFO    : Bus 90	: V=1.02, theta=-80.178909 -> V=1.0, theta=0.0
% INFO    : Bus 91	: V=1.0169543, theta=-82.285362 -> V=1.0, theta=0.0
% INFO    : Bus 92	: V=0.9953893, theta=-79.277077 -> V=1.0, theta=0.0
% INFO    : Bus 93	: V=1.02, theta=-79.005634 -> V=1.0, theta=0.0
% INFO    : Bus 94	: V=0.9872572, theta=-80.800791 -> V=1.0, theta=0.0
% INFO    : Bus 95	: V=0.9937431, theta=-81.027178 -> V=1.0, theta=0.0
% INFO    : Bus 96	: V=0.9933952, theta=-78.866212 -> V=1.0, theta=0.0
% INFO    : Bus 97	: V=1.0084165, theta=-82.247119 -> V=1.0, theta=0.0
% INFO    : Bus 98	: V=1.0109111, theta=-78.899764 -> V=1.0, theta=0.0
% INFO    : Bus 99	: V=1.0051408, theta=-83.517287 -> V=1.0, theta=0.0
% INFO    : Bus 100	: V=1.02, theta=-77.972338 -> V=1.0, theta=0.0
% INFO    : Bus 101	: V=0.9986364, theta=-80.4786 -> V=1.0, theta=0.0
% INFO    : Bus 102	: V=1.02, theta=-77.92545 -> V=1.0, theta=0.0
% INFO    : Bus 103	: V=1.0170511, theta=-82.479298 -> V=1.0, theta=0.0
% INFO    : Bus 104	: V=1.02, theta=-82.259799 -> V=1.0, theta=0.0
% INFO    : Bus 105	: V=1.0177739, theta=-74.008898 -> V=1.0, theta=0.0
% INFO    : Bus 106	: V=1.02, theta=-74.207357 -> V=1.0, theta=0.0
% INFO    : Bus 107	: V=1.02, theta=-75.096376 -> V=1.0, theta=0.0
% INFO    : Bus 108	: V=1.02, theta=-74.267861 -> V=1.0, theta=0.0
% INFO    : Bus 109	: V=1.0158407, theta=-75.488391 -> V=1.0, theta=0.0
% INFO    : Bus 110	: V=1.02, theta=-75.325729 -> V=1.0, theta=0.0
% INFO    : Bus 111	: V=1.0239171, theta=-74.751395 -> V=1.0, theta=0.0
% INFO    : Bus 112	: V=1.001889, theta=-80.653771 -> V=1.0, theta=0.0
% INFO    : Bus 113	: V=1.0085459, theta=-76.098394 -> V=1.0, theta=0.0
% INFO    : Bus 114	: V=0.9668988, theta=-82.223185 -> V=1.0, theta=0.0
% INFO    : Bus 115	: V=1.0040896, theta=-77.475568 -> V=1.0, theta=0.0
% INFO    : Bus 116	: V=1.02, theta=-74.795499 -> V=1.0, theta=0.0
% INFO    : Bus 117	: V=1.0085143, theta=-74.600447 -> V=1.0, theta=0.0
% INFO    : Bus 118	: V=1.02, theta=-75.509283 -> V=1.0, theta=0.0
% INFO    : Bus 119	: V=1.02, theta=-72.543667 -> V=1.0, theta=0.0
% INFO    : Bus 120	: V=1.02, theta=-73.639158 -> V=1.0, theta=0.0
% INFO    : Bus 121	: V=1.0111551, theta=-76.033372 -> V=1.0, theta=0.0
% INFO    : Bus 122	: V=1.0192288, theta=-74.797063 -> V=1.0, theta=0.0
% INFO    : Bus 123	: V=1.0000558, theta=-69.135297 -> V=1.0, theta=0.0
% INFO    : Bus 124	: V=0.9891222, theta=-78.783671 -> V=1.0, theta=0.0
% INFO    : Bus 125	: V=0.9878101, theta=-76.25234 -> V=1.0, theta=0.0
% INFO    : Bus 126	: V=1.0021739, theta=-75.515502 -> V=1.0, theta=0.0
% INFO    : Bus 127	: V=0.9959849, theta=-73.847949 -> V=1.0, theta=0.0
% INFO    : Bus 128	: V=1.02, theta=-72.573765 -> V=1.0, theta=0.0
% INFO    : Bus 129	: V=0.9922083, theta=-71.365905 -> V=1.0, theta=0.0
% INFO    : Bus 130	: V=0.966191, theta=-76.060938 -> V=1.0, theta=0.0
% INFO    : Bus 131	: V=0.9643818, theta=-78.983065 -> V=1.0, theta=0.0
% INFO    : Bus 132	: V=0.9698786, theta=-66.350831 -> V=1.0, theta=0.0
% INFO    : Bus 133	: V=0.9686165, theta=-66.375344 -> V=1.0, theta=0.0
% INFO    : Bus 134	: V=0.9727546, theta=-66.323437 -> V=1.0, theta=0.0
% INFO    : Bus 135	: V=0.9759871, theta=-65.938292 -> V=1.0, theta=0.0
% INFO    : Bus 136	: V=0.9756144, theta=-66.162943 -> V=1.0, theta=0.0
% INFO    : Bus 137	: V=0.9722493, theta=-66.55313 -> V=1.0, theta=0.0
% INFO    : Bus 138	: V=0.9736753, theta=-66.53566 -> V=1.0, theta=0.0
% INFO    : Bus 139	: V=0.9923782, theta=-64.592204 -> V=1.0, theta=0.0
% INFO    : Bus 140	: V=0.979103, theta=-65.863242 -> V=1.0, theta=0.0
% INFO    : Bus 141	: V=0.9785593, theta=-65.923659 -> V=1.0, theta=0.0
% INFO    : Bus 142	: V=0.9771057, theta=-65.979176 -> V=1.0, theta=0.0
% INFO    : Bus 143	: V=0.9796822, theta=-65.849488 -> V=1.0, theta=0.0
% INFO    : Bus 144	: V=0.9796985, theta=-65.857384 -> V=1.0, theta=0.0
% INFO    : Bus 145	: V=0.9744364, theta=-66.42553 -> V=1.0, theta=0.0
% INFO    : Bus 146	: V=0.9724923, theta=-66.554727 -> V=1.0, theta=0.0
% INFO    : Bus 147	: V=0.9865221, theta=-64.795979 -> V=1.0, theta=0.0
% INFO    : Bus 148	: V=0.9716476, theta=-65.855977 -> V=1.0, theta=0.0
% INFO    : Bus 149	: V=0.9735651, theta=-65.920511 -> V=1.0, theta=0.0
% INFO    : Bus 150	: V=0.9738862, theta=-65.843925 -> V=1.0, theta=0.0
% INFO    : Bus 151	: V=0.9755869, theta=-65.923652 -> V=1.0, theta=0.0
% INFO    : Bus 152	: V=0.9753535, theta=-65.870849 -> V=1.0, theta=0.0
% INFO    : Bus 153	: V=0.9761704, theta=-65.801067 -> V=1.0, theta=0.0
% INFO    : Bus 154	: V=0.9759748, theta=-65.8298 -> V=1.0, theta=0.0
% INFO    : Bus 155	: V=0.987529, theta=-64.544353 -> V=1.0, theta=0.0
% INFO    : Bus 156	: V=0.9767993, theta=-65.779913 -> V=1.0, theta=0.0
% INFO    : Bus 157	: V=0.977543, theta=-65.770407 -> V=1.0, theta=0.0
% INFO    : Bus 158	: V=0.9766459, theta=-65.79996 -> V=1.0, theta=0.0
% INFO    : Bus 159	: V=0.97615, theta=-65.87363 -> V=1.0, theta=0.0
% INFO    : Bus 160	: V=0.9767397, theta=-65.992015 -> V=1.0, theta=0.0
% INFO    : Bus 161	: V=0.9767334, theta=-65.975485 -> V=1.0, theta=0.0
% INFO    : Bus 162	: V=0.987102, theta=-64.754031 -> V=1.0, theta=0.0
% INFO    : Bus 163	: V=0.9760601, theta=-65.969723 -> V=1.0, theta=0.0
% INFO    : Bus 164	: V=0.9768612, theta=-65.787109 -> V=1.0, theta=0.0
% INFO    : Bus 165	: V=0.9758283, theta=-65.955979 -> V=1.0, theta=0.0
% INFO    : Bus 166	: V=0.9756012, theta=-65.975413 -> V=1.0, theta=0.0
% INFO    : Bus 167	: V=0.9755421, theta=-65.973666 -> V=1.0, theta=0.0
% INFO    : Bus 168	: V=0.9762985, theta=-65.951042 -> V=1.0, theta=0.0
% INFO    : Bus 169	: V=0.9771899, theta=-65.939657 -> V=1.0, theta=0.0
% INFO    : Bus 170	: V=1.0076758, theta=-63.382285 -> V=1.0, theta=0.0
% INFO    : Bus 171	: V=0.9757341, theta=-65.95863 -> V=1.0, theta=0.0
% INFO    : Bus 172	: V=0.9893952, theta=-64.420283 -> V=1.0, theta=0.0
% INFO    : Bus 173	: V=0.9822316, theta=-65.396978 -> V=1.0, theta=0.0
% INFO    : Bus 174	: V=0.9792637, theta=-65.66138 -> V=1.0, theta=0.0
% INFO    : Bus 175	: V=0.9774503, theta=-65.81663 -> V=1.0, theta=0.0
% INFO    : Bus 176	: V=0.9785226, theta=-65.697793 -> V=1.0, theta=0.0
% INFO    : Bus 177	: V=0.9793662, theta=-65.65391 -> V=1.0, theta=0.0
% INFO    : Bus 178	: V=0.9756639, theta=-65.608319 -> V=1.0, theta=0.0
% INFO    : Bus 179	: V=0.9900317, theta=-64.354696 -> V=1.0, theta=0.0
% INFO    : Bus 180	: V=0.9773228, theta=-65.592446 -> V=1.0, theta=0.0
% INFO    : Bus 181	: V=0.9863265, theta=-64.90955 -> V=1.0, theta=0.0
% INFO    : Bus 182	: V=0.9862093, theta=-64.91333 -> V=1.0, theta=0.0
% INFO    : Bus 183	: V=0.9953152, theta=-63.952406 -> V=1.0, theta=0.0
% INFO    : Bus 184	: V=0.9848884, theta=-64.971764 -> V=1.0, theta=0.0
% INFO    : Bus 185	: V=0.9822271, theta=-65.022559 -> V=1.0, theta=0.0
% INFO    : Bus 186	: V=0.982612, theta=-65.018462 -> V=1.0, theta=0.0
% INFO    : Bus 187	: V=0.9917172, theta=-64.236403 -> V=1.0, theta=0.0
% INFO    : Bus 188	: V=0.9825783, theta=-65.076986 -> V=1.0, theta=0.0
% INFO    : Bus 189	: V=0.9836445, theta=-65.036794 -> V=1.0, theta=0.0
% INFO    : Bus 190	: V=0.984581, theta=-64.998351 -> V=1.0, theta=0.0
% INFO    : Bus 191	: V=0.9886736, theta=-64.853436 -> V=1.0, theta=0.0
% INFO    : Bus 192	: V=0.9866784, theta=-64.901703 -> V=1.0, theta=0.0
% INFO    : Bus 193	: V=0.9943337, theta=-64.01819 -> V=1.0, theta=0.0
% INFO    : Bus 194	: V=0.9939115, theta=-64.041687 -> V=1.0, theta=0.0
% INFO    : Bus 195	: V=0.9814474, theta=-65.105346 -> V=1.0, theta=0.0
% INFO    : Bus 196	: V=0.9826658, theta=-65.094402 -> V=1.0, theta=0.0
% INFO    : Bus 197	: V=0.9833789, theta=-65.091468 -> V=1.0, theta=0.0
% INFO    : Bus 198	: V=0.9952444, theta=-63.962064 -> V=1.0, theta=0.0
% INFO    : Bus 199	: V=0.9963983, theta=-63.895064 -> V=1.0, theta=0.0
% INFO    : Bus 200	: V=0.9795485, theta=-65.353036 -> V=1.0, theta=0.0
% INFO    : Bus 201	: V=0.9788115, theta=-65.386044 -> V=1.0, theta=0.0
% INFO    : Bus 202	: V=0.9778917, theta=-65.397759 -> V=1.0, theta=0.0
% INFO    : Bus 203	: V=0.982069, theta=-65.161735 -> V=1.0, theta=0.0
% INFO    : Bus 204	: V=0.9869629, theta=-64.924059 -> V=1.0, theta=0.0
% INFO    : Bus 205	: V=0.9835931, theta=-65.140797 -> V=1.0, theta=0.0
% INFO    : Bus 206	: V=0.9847844, theta=-65.02114 -> V=1.0, theta=0.0
% INFO    : Bus 207	: V=0.9822388, theta=-65.002246 -> V=1.0, theta=0.0
% INFO    : Bus 208	: V=0.9974936, theta=-63.819047 -> V=1.0, theta=0.0
% INFO    : Bus 209	: V=0.998977, theta=-63.727573 -> V=1.0, theta=0.0
% INFO    : Bus 210	: V=1.0010684, theta=-63.593556 -> V=1.0, theta=0.0
% INFO    : Bus 211	: V=0.9985867, theta=-63.773712 -> V=1.0, theta=0.0
% INFO    : Bus 212	: V=1.0007058, theta=-63.656634 -> V=1.0, theta=0.0
% INFO    : Bus 213	: V=1.0044267, theta=-63.441067 -> V=1.0, theta=0.0
% INFO    : Bus 214	: V=0.9918521, theta=-64.537249 -> V=1.0, theta=0.0
% INFO    : Bus 215	: V=0.9970613, theta=-64.098274 -> V=1.0, theta=0.0
% INFO    : Bus 216	: V=1.0029906, theta=-64.194177 -> V=1.0, theta=0.0
% INFO    : Bus 217	: V=1.0027858, theta=-64.137818 -> V=1.0, theta=0.0
% INFO    : Bus 218	: V=1.0008803, theta=-64.175931 -> V=1.0, theta=0.0
% INFO    : Bus 219	: V=1.0029397, theta=-63.65584 -> V=1.0, theta=0.0
% INFO    : Bus 220	: V=1.0097053, theta=-63.111244 -> V=1.0, theta=0.0
% INFO    : Bus 221	: V=1.0089814, theta=-63.174826 -> V=1.0, theta=0.0
% INFO    : Bus 222	: V=1.0179203, theta=-62.001207 -> V=1.0, theta=0.0
% INFO    : Bus 223	: V=1.00546, theta=-63.700808 -> V=1.0, theta=0.0
% INFO    : Bus 224	: V=1.0072648, theta=-63.390829 -> V=1.0, theta=0.0
% INFO    : Bus 225	: V=1.0099169, theta=-63.130409 -> V=1.0, theta=0.0
% INFO    : Bus 226	: V=1.0068733, theta=-63.495633 -> V=1.0, theta=0.0
% INFO    : Bus 227	: V=1.007614, theta=-63.475706 -> V=1.0, theta=0.0
% INFO    : Bus 228	: V=1.0111618, theta=-63.025868 -> V=1.0, theta=0.0
% INFO    : Bus 229	: V=1.0058486, theta=-63.695287 -> V=1.0, theta=0.0
% INFO    : Bus 230	: V=1.0120988, theta=-62.896782 -> V=1.0, theta=0.0
% INFO    : Bus 231	: V=1.0102362, theta=-63.062043 -> V=1.0, theta=0.0
% INFO    : Bus 232	: V=1.0132931, theta=-62.795827 -> V=1.0, theta=0.0
% INFO    : Bus 233	: V=1.0067378, theta=-63.692999 -> V=1.0, theta=0.0
% INFO    : Bus 234	: V=1.0193169, theta=-62.002651 -> V=1.0, theta=0.0
% INFO    : Bus 235	: V=1.0158445, theta=-62.219142 -> V=1.0, theta=0.0
% INFO    : Bus 236	: V=1.0162236, theta=-62.194519 -> V=1.0, theta=0.0
% INFO    : Bus 237	: V=1.0198278, theta=-62.050211 -> V=1.0, theta=0.0
% INFO    : Bus 238	: V=1.0042111, theta=-63.763531 -> V=1.0, theta=0.0
% INFO    : Bus 239	: V=1.016934, theta=-62.067427 -> V=1.0, theta=0.0
% INFO    : Bus 240	: V=1.0127637, theta=-62.922421 -> V=1.0, theta=0.0
% INFO    : Bus 241	: V=1.012855, theta=-62.933129 -> V=1.0, theta=0.0
% INFO    : Bus 242	: V=1.0045975, theta=-63.755817 -> V=1.0, theta=0.0
% INFO    : Bus 243	: V=1.0119342, theta=-63.113467 -> V=1.0, theta=0.0
% INFO    : Bus 244	: V=1.0062751, theta=-63.731702 -> V=1.0, theta=0.0
% INFO    : Bus 245	: V=1.0031735, theta=-63.884003 -> V=1.0, theta=0.0
% INFO    : Bus 246	: V=1.0113274, theta=-63.191454 -> V=1.0, theta=0.0
% INFO    : Bus 247	: V=1.0114134, theta=-63.050558 -> V=1.0, theta=0.0
% INFO    : Bus 248	: V=1.0105294, theta=-63.304975 -> V=1.0, theta=0.0
% INFO    : Bus 249	: V=1.0100778, theta=-63.371319 -> V=1.0, theta=0.0
% INFO    : Bus 250	: V=1.0049793, theta=-64.196724 -> V=1.0, theta=0.0
% INFO    : Bus 251	: V=1.0092481, theta=-63.481588 -> V=1.0, theta=0.0
% INFO    : Bus 252	: V=1.0082276, theta=-63.624618 -> V=1.0, theta=0.0
% INFO    : Bus 253	: V=1.0040574, theta=-64.28037 -> V=1.0, theta=0.0
% INFO    : Bus 254	: V=1.004498, theta=-64.249205 -> V=1.0, theta=0.0
% INFO    : Bus 255	: V=1.0110945, theta=-63.131031 -> V=1.0, theta=0.0
% INFO    : Bus 256	: V=1.0054481, theta=-64.235722 -> V=1.0, theta=0.0
% INFO    : Bus 257	: V=1.0057661, theta=-64.250459 -> V=1.0, theta=0.0
% INFO    : Bus 258	: V=1.0068347, theta=-64.162238 -> V=1.0, theta=0.0
% INFO    : Bus 259	: V=1.0067034, theta=-64.153481 -> V=1.0, theta=0.0
% INFO    : Bus 260	: V=1.006383, theta=-64.077251 -> V=1.0, theta=0.0
% INFO    : Bus 261	: V=1.0066217, theta=-64.019377 -> V=1.0, theta=0.0
% INFO    : Bus 262	: V=1.006451, theta=-64.020287 -> V=1.0, theta=0.0
% INFO    : Bus 263	: V=1.012811, theta=-63.053525 -> V=1.0, theta=0.0
% INFO    : Bus 264	: V=1.006305, theta=-63.954507 -> V=1.0, theta=0.0
% INFO    : Bus 265	: V=1.0126108, theta=-62.990954 -> V=1.0, theta=0.0
% INFO    : Bus 266	: V=1.011296, theta=-63.07399 -> V=1.0, theta=0.0
% INFO    : Bus 267	: V=1.0131384, theta=-63.017596 -> V=1.0, theta=0.0
% INFO    : Bus 268	: V=1.014651, theta=-63.079191 -> V=1.0, theta=0.0
% INFO    : Bus 269	: V=1.0071994, theta=-64.164097 -> V=1.0, theta=0.0
% INFO    : Bus 270	: V=1.006242, theta=-64.17306 -> V=1.0, theta=0.0
% INFO    : Bus 271	: V=1.0152366, theta=-63.288729 -> V=1.0, theta=0.0
% INFO    : Bus 272	: V=1.0145544, theta=-63.51325 -> V=1.0, theta=0.0
% INFO    : Bus 273	: V=1.0160838, theta=-63.41686 -> V=1.0, theta=0.0
% INFO    : Bus 274	: V=1.008992, theta=-64.151896 -> V=1.0, theta=0.0
% INFO    : Bus 275	: V=1.0190444, theta=-63.497947 -> V=1.0, theta=0.0
% INFO    : Bus 276	: V=1.008058, theta=-64.151935 -> V=1.0, theta=0.0
% INFO    : Bus 277	: V=1.0069251, theta=-64.217463 -> V=1.0, theta=0.0
% INFO    : Bus 278	: V=1.0089646, theta=-64.159956 -> V=1.0, theta=0.0
% INFO    : Bus 279	: V=1.0098912, theta=-64.09693 -> V=1.0, theta=0.0
% INFO    : Bus 280	: V=1.0124144, theta=-63.955344 -> V=1.0, theta=0.0
% INFO    : Bus 281	: V=1.0016624, theta=-64.87223 -> V=1.0, theta=0.0
% INFO    : Bus 282	: V=1.0045663, theta=-64.3984 -> V=1.0, theta=0.0
% INFO    : Bus 283	: V=1.0024528, theta=-64.414214 -> V=1.0, theta=0.0
% INFO    : Bus 284	: V=0.999108, theta=-64.538363 -> V=1.0, theta=0.0
% INFO    : Bus 285	: V=1.0019652, theta=-64.487653 -> V=1.0, theta=0.0
% INFO    : Bus 286	: V=1.00088, theta=-64.500027 -> V=1.0, theta=0.0
% INFO    : Bus 287	: V=1.0058908, theta=-64.324573 -> V=1.0, theta=0.0
% INFO    : Bus 288	: V=0.9988777, theta=-65.280953 -> V=1.0, theta=0.0
% INFO    : Bus 289	: V=0.9968116, theta=-65.609122 -> V=1.0, theta=0.0
% INFO    : Bus 290	: V=0.9945047, theta=-65.972833 -> V=1.0, theta=0.0
% INFO    : Bus 291	: V=0.99797, theta=-64.192755 -> V=1.0, theta=0.0
% INFO    : Bus 292	: V=0.9981392, theta=-65.22279 -> V=1.0, theta=0.0
% INFO    : Bus 293	: V=1.0020522, theta=-65.271381 -> V=1.0, theta=0.0
% INFO    : Bus 294	: V=1.0038284, theta=-65.054733 -> V=1.0, theta=0.0
% INFO    : Bus 295	: V=1.017462, theta=-63.299229 -> V=1.0, theta=0.0
% INFO    : Bus 296	: V=1.0057625, theta=-64.623952 -> V=1.0, theta=0.0
% INFO    : Bus 297	: V=1.0097699, theta=-64.104746 -> V=1.0, theta=0.0
% INFO    : Bus 298	: V=1.0075778, theta=-64.232939 -> V=1.0, theta=0.0
% INFO    : Bus 299	: V=0.9912953, theta=-65.856983 -> V=1.0, theta=0.0
% INFO    : Bus 300	: V=1.0045849, theta=-64.689144 -> V=1.0, theta=0.0
% INFO    : Bus 301	: V=0.9730725, theta=-67.868389 -> V=1.0, theta=0.0
% INFO    : Bus 302	: V=0.9863556, theta=-66.513049 -> V=1.0, theta=0.0
% INFO    : Bus 303	: V=0.9768704, theta=-67.325974 -> V=1.0, theta=0.0
% INFO    : Bus 304	: V=0.9880283, theta=-66.328787 -> V=1.0, theta=0.0
% INFO    : Bus 305	: V=0.9658872, theta=-67.970493 -> V=1.0, theta=0.0
% INFO    : Bus 306	: V=0.9668281, theta=-68.026437 -> V=1.0, theta=0.0
% INFO    : Bus 307	: V=0.9697999, theta=-67.913008 -> V=1.0, theta=0.0
% INFO    : Bus 308	: V=0.9695536, theta=-68.461102 -> V=1.0, theta=0.0
% INFO    : Bus 309	: V=0.9832167, theta=-66.837236 -> V=1.0, theta=0.0
% INFO    : Bus 310	: V=0.9837761, theta=-66.828659 -> V=1.0, theta=0.0
% INFO    : Bus 311	: V=1.0021631, theta=-64.800913 -> V=1.0, theta=0.0
% INFO    : Bus 312	: V=0.9773589, theta=-66.080598 -> V=1.0, theta=0.0
% INFO    : Bus 313	: V=0.9676068, theta=-68.635313 -> V=1.0, theta=0.0
% INFO    : Bus 314	: V=0.9683747, theta=-68.475914 -> V=1.0, theta=0.0
% INFO    : Bus 315	: V=0.9664242, theta=-68.701191 -> V=1.0, theta=0.0
% INFO    : Bus 316	: V=0.9631053, theta=-68.813056 -> V=1.0, theta=0.0
% INFO    : Bus 317	: V=0.96652, theta=-68.636694 -> V=1.0, theta=0.0
% INFO    : Bus 318	: V=0.9681888, theta=-68.595672 -> V=1.0, theta=0.0
% INFO    : Bus 319	: V=0.980838, theta=-67.21036 -> V=1.0, theta=0.0
% INFO    : Bus 320	: V=0.9822447, theta=-67.023619 -> V=1.0, theta=0.0
% INFO    : Bus 321	: V=0.9723984, theta=-67.444652 -> V=1.0, theta=0.0
% INFO    : Bus 322	: V=0.9732761, theta=-67.432153 -> V=1.0, theta=0.0
% INFO    : Bus 323	: V=0.9642113, theta=-68.746265 -> V=1.0, theta=0.0
% INFO    : Bus 324	: V=0.9615498, theta=-68.770312 -> V=1.0, theta=0.0
% INFO    : Bus 325	: V=0.9679204, theta=-68.510576 -> V=1.0, theta=0.0
% INFO    : Bus 326	: V=0.9846804, theta=-67.055167 -> V=1.0, theta=0.0
% INFO    : Bus 327	: V=0.9810915, theta=-67.200059 -> V=1.0, theta=0.0
% INFO    : Bus 328	: V=0.9786435, theta=-67.293418 -> V=1.0, theta=0.0
% INFO    : Bus 329	: V=0.9923982, theta=-65.450495 -> V=1.0, theta=0.0
% INFO    : Bus 330	: V=0.977663, theta=-67.458087 -> V=1.0, theta=0.0
% INFO    : Bus 331	: V=0.9805199, theta=-67.385276 -> V=1.0, theta=0.0
% INFO    : Bus 332	: V=0.9788012, theta=-65.207076 -> V=1.0, theta=0.0
% INFO    : Bus 333	: V=0.9923075, theta=-65.833082 -> V=1.0, theta=0.0
% INFO    : Bus 334	: V=0.9714397, theta=-67.121696 -> V=1.0, theta=0.0
% INFO    : Bus 335	: V=0.9721559, theta=-67.112443 -> V=1.0, theta=0.0
% INFO    : Bus 336	: V=0.9790102, theta=-65.765661 -> V=1.0, theta=0.0
% INFO    : Bus 337	: V=0.9763645, theta=-66.355876 -> V=1.0, theta=0.0
% INFO    : Bus 338	: V=0.9800576, theta=-65.594142 -> V=1.0, theta=0.0
% INFO    : Bus 339	: V=0.9760717, theta=-66.744603 -> V=1.0, theta=0.0
% INFO    : Bus 340	: V=0.9763648, theta=-69.016275 -> V=1.0, theta=0.0
% INFO    : Bus 341	: V=1.0118588, theta=-63.057335 -> V=1.0, theta=0.0
% INFO    : Bus 342	: V=0.9613315, theta=-75.153461 -> V=1.0, theta=0.0
% INFO    : Bus 343	: V=0.9814339, theta=-69.870381 -> V=1.0, theta=0.0
% INFO    : Bus 344	: V=0.9859509, theta=-69.407962 -> V=1.0, theta=0.0
% INFO    : Bus 345	: V=0.9819203, theta=-70.082033 -> V=1.0, theta=0.0
% INFO    : Bus 346	: V=0.975545, theta=-71.116627 -> V=1.0, theta=0.0
% INFO    : Bus 347	: V=0.9695418, theta=-71.68614 -> V=1.0, theta=0.0
% INFO    : Bus 348	: V=0.9684472, theta=-71.728713 -> V=1.0, theta=0.0
% INFO    : Bus 349	: V=0.9762698, theta=-71.047596 -> V=1.0, theta=0.0
% INFO    : Bus 350	: V=1.001341, theta=-67.808844 -> V=1.0, theta=0.0
% INFO    : Bus 351	: V=0.9749563, theta=-71.165167 -> V=1.0, theta=0.0
% INFO    : Bus 352	: V=0.9732856, theta=-71.285047 -> V=1.0, theta=0.0
% INFO    : Bus 353	: V=0.9666547, theta=-71.912215 -> V=1.0, theta=0.0
% INFO    : Bus 354	: V=0.965672, theta=-72.224875 -> V=1.0, theta=0.0
% INFO    : Bus 355	: V=0.9755143, theta=-71.129359 -> V=1.0, theta=0.0
% INFO    : Bus 356	: V=0.975772, theta=-71.120629 -> V=1.0, theta=0.0
% INFO    : Bus 357	: V=0.97615, theta=-71.104703 -> V=1.0, theta=0.0
% INFO    : Bus 358	: V=0.9680238, theta=-72.116941 -> V=1.0, theta=0.0
% INFO    : Bus 359	: V=0.9662411, theta=-71.787361 -> V=1.0, theta=0.0
% INFO    : Bus 360	: V=0.957767, theta=-73.642448 -> V=1.0, theta=0.0
% INFO    : Bus 361	: V=0.9714265, theta=-71.355748 -> V=1.0, theta=0.0
% INFO    : Bus 362	: V=0.978971, theta=-70.141087 -> V=1.0, theta=0.0
% INFO    : Bus 363	: V=0.9725759, theta=-71.389116 -> V=1.0, theta=0.0
% INFO    : Bus 364	: V=0.9798112, theta=-70.504253 -> V=1.0, theta=0.0
% INFO    : Bus 365	: V=0.9793337, theta=-70.530219 -> V=1.0, theta=0.0
% INFO    : Bus 366	: V=0.9715712, theta=-71.571974 -> V=1.0, theta=0.0
% INFO    : Bus 367	: V=0.9704256, theta=-71.662761 -> V=1.0, theta=0.0
% INFO    : Bus 368	: V=0.9692271, theta=-71.728725 -> V=1.0, theta=0.0
% INFO    : Bus 369	: V=0.9691104, theta=-71.763518 -> V=1.0, theta=0.0
% INFO    : Bus 370	: V=0.9691882, theta=-71.782406 -> V=1.0, theta=0.0
% INFO    : Bus 371	: V=0.9776036, theta=-70.257119 -> V=1.0, theta=0.0
% INFO    : Bus 372	: V=0.9692992, theta=-71.515743 -> V=1.0, theta=0.0
% INFO    : Bus 373	: V=0.9683641, theta=-71.697748 -> V=1.0, theta=0.0
% INFO    : Bus 374	: V=0.9693017, theta=-71.688383 -> V=1.0, theta=0.0
% INFO    : Bus 375	: V=0.9683591, theta=-71.867641 -> V=1.0, theta=0.0
% INFO    : Bus 376	: V=0.9687691, theta=-71.831874 -> V=1.0, theta=0.0
% INFO    : Bus 377	: V=0.9715045, theta=-71.374417 -> V=1.0, theta=0.0
% INFO    : Bus 378	: V=0.9689721, theta=-71.841733 -> V=1.0, theta=0.0
% INFO    : Bus 379	: V=0.9684888, theta=-71.885802 -> V=1.0, theta=0.0
% INFO    : Bus 380	: V=0.9676199, theta=-71.894732 -> V=1.0, theta=0.0
% INFO    : Bus 381	: V=0.968, theta=-71.973011 -> V=1.0, theta=0.0
% INFO    : Bus 382	: V=0.967008, theta=-71.771382 -> V=1.0, theta=0.0
% INFO    : Bus 383	: V=0.9757893, theta=-71.086875 -> V=1.0, theta=0.0
% INFO    : Bus 384	: V=0.9754253, theta=-71.125434 -> V=1.0, theta=0.0
% INFO    : Bus 385	: V=0.9684543, theta=-71.694124 -> V=1.0, theta=0.0
% INFO    : Bus 386	: V=0.9722159, theta=-70.954271 -> V=1.0, theta=0.0
% INFO    : Bus 387	: V=0.9699954, theta=-71.243043 -> V=1.0, theta=0.0
% INFO    : Bus 388	: V=0.971566, theta=-71.001828 -> V=1.0, theta=0.0
% INFO    : Bus 389	: V=0.9749983, theta=-70.412945 -> V=1.0, theta=0.0
% INFO    : Bus 390	: V=0.9853582, theta=-68.997001 -> V=1.0, theta=0.0
% INFO    : Bus 391	: V=0.9836981, theta=-69.085679 -> V=1.0, theta=0.0
% INFO    : Bus 392	: V=0.973383, theta=-70.510896 -> V=1.0, theta=0.0
% INFO    : Bus 393	: V=0.9716011, theta=-70.591373 -> V=1.0, theta=0.0
% INFO    : Bus 394	: V=0.9693175, theta=-71.582874 -> V=1.0, theta=0.0
% INFO    : Bus 395	: V=0.9718571, theta=-70.985105 -> V=1.0, theta=0.0
% INFO    : Bus 396	: V=0.977316, theta=-71.121145 -> V=1.0, theta=0.0
% INFO    : Bus 397	: V=1.000319, theta=-67.665108 -> V=1.0, theta=0.0
% INFO    : Bus 398	: V=0.9702089, theta=-72.165178 -> V=1.0, theta=0.0
% INFO    : Bus 399	: V=0.9679536, theta=-72.353432 -> V=1.0, theta=0.0
% INFO    : Bus 400	: V=0.9681586, theta=-72.435796 -> V=1.0, theta=0.0
% INFO    : Bus 401	: V=0.967275, theta=-72.634199 -> V=1.0, theta=0.0
% INFO    : Bus 402	: V=0.9658507, theta=-72.895547 -> V=1.0, theta=0.0
% INFO    : Bus 403	: V=0.9643841, theta=-72.919151 -> V=1.0, theta=0.0
% INFO    : Bus 404	: V=0.9743198, theta=-71.570823 -> V=1.0, theta=0.0
% INFO    : Bus 405	: V=0.9658678, theta=-72.882908 -> V=1.0, theta=0.0
% INFO    : Bus 406	: V=0.9519261, theta=-74.416154 -> V=1.0, theta=0.0
% INFO    : Bus 407	: V=0.954089, theta=-74.091349 -> V=1.0, theta=0.0
% INFO    : Bus 408	: V=0.9602407, theta=-74.038706 -> V=1.0, theta=0.0
% INFO    : Bus 409	: V=0.9621135, theta=-73.722782 -> V=1.0, theta=0.0
% INFO    : Bus 410	: V=0.962058, theta=-74.574658 -> V=1.0, theta=0.0
% INFO    : Bus 411	: V=0.9554074, theta=-74.483855 -> V=1.0, theta=0.0
% INFO    : Bus 412	: V=0.9596534, theta=-74.423083 -> V=1.0, theta=0.0
% INFO    : Bus 413	: V=0.9584783, theta=-74.438347 -> V=1.0, theta=0.0
% INFO    : Bus 414	: V=0.9632578, theta=-75.124389 -> V=1.0, theta=0.0
% INFO    : Bus 415	: V=0.9674592, theta=-74.795767 -> V=1.0, theta=0.0
% INFO    : Bus 416	: V=0.9958068, theta=-73.278498 -> V=1.0, theta=0.0
% INFO    : Bus 417	: V=0.962626, theta=-73.288631 -> V=1.0, theta=0.0
% INFO    : Bus 418	: V=0.9649231, theta=-73.283349 -> V=1.0, theta=0.0
% INFO    : Bus 419	: V=0.9636228, theta=-73.18789 -> V=1.0, theta=0.0
% INFO    : Bus 420	: V=0.964765, theta=-73.705324 -> V=1.0, theta=0.0
% INFO    : Bus 421	: V=0.9681256, theta=-73.676434 -> V=1.0, theta=0.0
% INFO    : Bus 422	: V=0.9635992, theta=-73.275219 -> V=1.0, theta=0.0
% INFO    : Bus 423	: V=0.9676887, theta=-73.27064 -> V=1.0, theta=0.0
% INFO    : Bus 424	: V=0.9950687, theta=-73.276027 -> V=1.0, theta=0.0
% INFO    : Bus 425	: V=0.9830277, theta=-73.922388 -> V=1.0, theta=0.0
% INFO    : Bus 426	: V=0.9952128, theta=-72.980418 -> V=1.0, theta=0.0
% INFO    : Bus 427	: V=0.9702132, theta=-73.423551 -> V=1.0, theta=0.0
% INFO    : Bus 428	: V=0.965453, theta=-73.187465 -> V=1.0, theta=0.0
% INFO    : Bus 429	: V=0.9673853, theta=-72.988638 -> V=1.0, theta=0.0
% INFO    : Bus 430	: V=0.9922435, theta=-73.501823 -> V=1.0, theta=0.0
% INFO    : Bus 431	: V=0.9909077, theta=-73.514669 -> V=1.0, theta=0.0
% INFO    : Bus 432	: V=0.9957367, theta=-73.126394 -> V=1.0, theta=0.0
% INFO    : Bus 433	: V=1.0080308, theta=-72.926114 -> V=1.0, theta=0.0
% INFO    : Bus 434	: V=1.0136104, theta=-72.679163 -> V=1.0, theta=0.0
% INFO    : Bus 435	: V=0.9773953, theta=-75.006073 -> V=1.0, theta=0.0
% INFO    : Bus 436	: V=0.9977043, theta=-73.577088 -> V=1.0, theta=0.0
% INFO    : Bus 437	: V=0.9983694, theta=-73.591949 -> V=1.0, theta=0.0
% INFO    : Bus 438	: V=1.0001146, theta=-73.596169 -> V=1.0, theta=0.0
% INFO    : Bus 439	: V=0.9953353, theta=-73.684444 -> V=1.0, theta=0.0
% INFO    : Bus 440	: V=0.9963249, theta=-73.713414 -> V=1.0, theta=0.0
% INFO    : Bus 441	: V=0.9890807, theta=-73.841356 -> V=1.0, theta=0.0
% INFO    : Bus 442	: V=0.9840535, theta=-73.657253 -> V=1.0, theta=0.0
% INFO    : Bus 443	: V=0.9867788, theta=-73.852932 -> V=1.0, theta=0.0
% INFO    : Bus 444	: V=0.9916125, theta=-73.809162 -> V=1.0, theta=0.0
% INFO    : Bus 445	: V=0.9936466, theta=-73.73494 -> V=1.0, theta=0.0
% INFO    : Bus 446	: V=0.9972504, theta=-73.010768 -> V=1.0, theta=0.0
% INFO    : Bus 447	: V=0.9952805, theta=-73.01524 -> V=1.0, theta=0.0
% INFO    : Bus 448	: V=0.9624535, theta=-74.153188 -> V=1.0, theta=0.0
% INFO    : Bus 449	: V=0.9606677, theta=-73.78136 -> V=1.0, theta=0.0
% INFO    : Bus 450	: V=0.9611413, theta=-73.06957 -> V=1.0, theta=0.0
% INFO    : Bus 451	: V=0.95967, theta=-73.232158 -> V=1.0, theta=0.0
% INFO    : Bus 452	: V=0.9624717, theta=-73.336487 -> V=1.0, theta=0.0
% INFO    : Bus 453	: V=0.9603924, theta=-73.415264 -> V=1.0, theta=0.0
% INFO    : Bus 454	: V=0.9616755, theta=-72.82046 -> V=1.0, theta=0.0
% INFO    : Bus 455	: V=0.9697403, theta=-71.14199 -> V=1.0, theta=0.0
% INFO    : Bus 456	: V=0.9787475, theta=-69.7167 -> V=1.0, theta=0.0
% INFO    : Bus 457	: V=1.0110461, theta=-67.975055 -> V=1.0, theta=0.0
% INFO    : Bus 458	: V=0.9829685, theta=-70.920694 -> V=1.0, theta=0.0
% INFO    : Bus 459	: V=0.9721195, theta=-72.255994 -> V=1.0, theta=0.0
% INFO    : Bus 460	: V=0.9820282, theta=-70.928036 -> V=1.0, theta=0.0
% INFO    : Bus 461	: V=0.9710062, theta=-71.33154 -> V=1.0, theta=0.0
% INFO    : Bus 462	: V=0.9696296, theta=-71.272579 -> V=1.0, theta=0.0
% INFO    : Bus 463	: V=0.965964, theta=-70.921608 -> V=1.0, theta=0.0
% INFO    : Bus 464	: V=0.9720846, theta=-71.213767 -> V=1.0, theta=0.0
% INFO    : Bus 465	: V=0.9783212, theta=-69.769654 -> V=1.0, theta=0.0
% INFO    : Bus 466	: V=0.970579, theta=-71.795116 -> V=1.0, theta=0.0
% INFO    : Bus 467	: V=0.9812876, theta=-70.924774 -> V=1.0, theta=0.0
% INFO    : Bus 468	: V=0.9708153, theta=-72.050727 -> V=1.0, theta=0.0
% INFO    : Bus 469	: V=0.9678939, theta=-72.029957 -> V=1.0, theta=0.0
% INFO    : Bus 470	: V=0.9790046, theta=-71.246961 -> V=1.0, theta=0.0
% INFO    : Bus 471	: V=0.9669629, theta=-72.206261 -> V=1.0, theta=0.0
% INFO    : Bus 472	: V=0.9663906, theta=-72.388247 -> V=1.0, theta=0.0
% INFO    : Bus 473	: V=0.9670561, theta=-72.323215 -> V=1.0, theta=0.0
% INFO    : Bus 474	: V=0.9656664, theta=-72.557119 -> V=1.0, theta=0.0
% INFO    : Bus 475	: V=0.9680609, theta=-72.228142 -> V=1.0, theta=0.0
% INFO    : Bus 476	: V=0.9666828, theta=-72.423936 -> V=1.0, theta=0.0
% INFO    : Bus 477	: V=0.9664095, theta=-72.413716 -> V=1.0, theta=0.0
% INFO    : Bus 478	: V=0.9668333, theta=-72.504268 -> V=1.0, theta=0.0
% INFO    : Bus 479	: V=0.9645919, theta=-72.67911 -> V=1.0, theta=0.0
% INFO    : Bus 480	: V=0.9663731, theta=-72.50976 -> V=1.0, theta=0.0
% INFO    : Bus 481	: V=0.9652489, theta=-72.672517 -> V=1.0, theta=0.0
% INFO    : Bus 482	: V=0.9654325, theta=-73.004093 -> V=1.0, theta=0.0
% INFO    : Bus 483	: V=0.964511, theta=-72.761933 -> V=1.0, theta=0.0
% INFO    : Bus 484	: V=0.9640381, theta=-72.935041 -> V=1.0, theta=0.0
% INFO    : Bus 485	: V=0.9654322, theta=-72.634204 -> V=1.0, theta=0.0
% INFO    : Bus 486	: V=0.9662335, theta=-72.675206 -> V=1.0, theta=0.0
% INFO    : Bus 487	: V=0.9706005, theta=-72.35655 -> V=1.0, theta=0.0
% INFO    : Bus 488	: V=0.9712167, theta=-72.348298 -> V=1.0, theta=0.0
% INFO    : Bus 489	: V=0.9709015, theta=-72.35283 -> V=1.0, theta=0.0
% INFO    : Bus 490	: V=0.9822256, theta=-71.320518 -> V=1.0, theta=0.0
% INFO    : Bus 491	: V=0.981223, theta=-71.40144 -> V=1.0, theta=0.0
% INFO    : Bus 492	: V=0.9825449, theta=-71.362961 -> V=1.0, theta=0.0
% INFO    : Bus 493	: V=0.977253, theta=-71.692127 -> V=1.0, theta=0.0
% INFO    : Bus 494	: V=0.9760824, theta=-71.77432 -> V=1.0, theta=0.0
% INFO    : Bus 495	: V=0.9764768, theta=-71.746466 -> V=1.0, theta=0.0
% INFO    : Bus 496	: V=0.9700112, theta=-72.443521 -> V=1.0, theta=0.0
% INFO    : Bus 497	: V=0.9754113, theta=-71.822091 -> V=1.0, theta=0.0
% INFO    : Bus 498	: V=0.9784265, theta=-71.608524 -> V=1.0, theta=0.0
% INFO    : Bus 499	: V=0.9706058, theta=-72.434684 -> V=1.0, theta=0.0
% INFO    : Bus 500	: V=0.9802193, theta=-71.478026 -> V=1.0, theta=0.0
% INFO    : Bus 501	: V=0.9804591, theta=-71.205842 -> V=1.0, theta=0.0
% INFO    : Bus 502	: V=0.9702087, theta=-72.402626 -> V=1.0, theta=0.0
% INFO    : Bus 503	: V=0.9846528, theta=-71.143396 -> V=1.0, theta=0.0
% INFO    : Bus 504	: V=0.980087, theta=-71.250117 -> V=1.0, theta=0.0
% INFO    : Bus 505	: V=0.9698586, theta=-72.382218 -> V=1.0, theta=0.0
% INFO    : Bus 506	: V=0.9759995, theta=-71.946548 -> V=1.0, theta=0.0
% INFO    : Bus 507	: V=0.9704134, theta=-72.332156 -> V=1.0, theta=0.0
% INFO    : Bus 508	: V=0.9709809, theta=-72.340181 -> V=1.0, theta=0.0
% INFO    : Bus 509	: V=0.976357, theta=-71.503884 -> V=1.0, theta=0.0
% INFO    : Bus 510	: V=0.9675915, theta=-72.505602 -> V=1.0, theta=0.0
% INFO    : Bus 511	: V=0.9699105, theta=-72.444205 -> V=1.0, theta=0.0
% INFO    : Bus 512	: V=0.9671846, theta=-72.557272 -> V=1.0, theta=0.0
% INFO    : Bus 513	: V=0.9655465, theta=-72.591085 -> V=1.0, theta=0.0
% INFO    : Bus 514	: V=0.9746848, theta=-71.868179 -> V=1.0, theta=0.0
% INFO    : Bus 515	: V=0.9749489, theta=-71.849768 -> V=1.0, theta=0.0
% INFO    : Bus 516	: V=0.9702225, theta=-72.333267 -> V=1.0, theta=0.0
% INFO    : Bus 517	: V=0.9762787, theta=-71.498229 -> V=1.0, theta=0.0
% INFO    : Bus 518	: V=0.9680648, theta=-72.438526 -> V=1.0, theta=0.0
% INFO    : Bus 519	: V=0.9798387, theta=-71.284322 -> V=1.0, theta=0.0
% INFO    : Bus 520	: V=0.9702182, theta=-72.283973 -> V=1.0, theta=0.0
% INFO    : Bus 521	: V=0.9792221, theta=-71.316511 -> V=1.0, theta=0.0
% INFO    : Bus 522	: V=0.9713105, theta=-72.347315 -> V=1.0, theta=0.0
% INFO    : Bus 523	: V=0.9804608, theta=-71.564869 -> V=1.0, theta=0.0
% INFO    : Bus 524	: V=0.9708481, theta=-72.50904 -> V=1.0, theta=0.0
% INFO    : Bus 525	: V=0.9805449, theta=-71.195399 -> V=1.0, theta=0.0
% INFO    : Bus 526	: V=0.971362, theta=-72.068306 -> V=1.0, theta=0.0
% INFO    : Bus 527	: V=0.9820034, theta=-71.098974 -> V=1.0, theta=0.0
% INFO    : Bus 528	: V=0.9762358, theta=-71.62405 -> V=1.0, theta=0.0
% INFO    : Bus 529	: V=0.9829091, theta=-71.01854 -> V=1.0, theta=0.0
% INFO    : Bus 530	: V=0.9783776, theta=-70.347329 -> V=1.0, theta=0.0
% INFO    : Bus 531	: V=0.9777265, theta=-70.415618 -> V=1.0, theta=0.0
% INFO    : Bus 532	: V=0.9715577, theta=-71.999709 -> V=1.0, theta=0.0
% INFO    : Bus 533	: V=0.9705313, theta=-72.119698 -> V=1.0, theta=0.0
% INFO    : Bus 534	: V=0.970125, theta=-72.180938 -> V=1.0, theta=0.0
% INFO    : Bus 535	: V=0.9699937, theta=-72.266518 -> V=1.0, theta=0.0
% INFO    : Bus 536	: V=0.9605347, theta=-73.088584 -> V=1.0, theta=0.0
% INFO    : Bus 537	: V=0.9730527, theta=-71.471974 -> V=1.0, theta=0.0
% INFO    : Bus 538	: V=0.9634572, theta=-72.745747 -> V=1.0, theta=0.0
% INFO    : Bus 539	: V=0.9642414, theta=-71.308945 -> V=1.0, theta=0.0
% INFO    : Bus 540	: V=0.9625267, theta=-72.678562 -> V=1.0, theta=0.0
% INFO    : Bus 541	: V=0.9636913, theta=-72.621784 -> V=1.0, theta=0.0
% INFO    : Bus 542	: V=0.9644264, theta=-72.560593 -> V=1.0, theta=0.0
% INFO    : Bus 543	: V=0.9636117, theta=-72.618041 -> V=1.0, theta=0.0
% INFO    : Bus 544	: V=0.962744, theta=-72.633221 -> V=1.0, theta=0.0
% INFO    : Bus 545	: V=0.9597538, theta=-73.096401 -> V=1.0, theta=0.0
% INFO    : Bus 546	: V=0.9652543, theta=-71.171636 -> V=1.0, theta=0.0
% INFO    : Bus 547	: V=0.9727482, theta=-71.379833 -> V=1.0, theta=0.0
% INFO    : Bus 548	: V=0.9736016, theta=-71.274127 -> V=1.0, theta=0.0
% INFO    : Bus 549	: V=0.9615215, theta=-72.645056 -> V=1.0, theta=0.0
% INFO    : Bus 550	: V=0.9760687, theta=-70.966235 -> V=1.0, theta=0.0
% INFO    : Bus 551	: V=0.9708992, theta=-71.096611 -> V=1.0, theta=0.0
% INFO    : Bus 552	: V=0.9802582, theta=-70.383011 -> V=1.0, theta=0.0
% INFO    : Bus 553	: V=0.9796558, theta=-70.223991 -> V=1.0, theta=0.0
% INFO    : Bus 554	: V=0.9774643, theta=-71.500539 -> V=1.0, theta=0.0
% INFO    : Bus 555	: V=0.9817571, theta=-70.012533 -> V=1.0, theta=0.0
% INFO    : Bus 556	: V=0.9843767, theta=-69.744 -> V=1.0, theta=0.0
% INFO    : Bus 557	: V=0.9759673, theta=-70.62752 -> V=1.0, theta=0.0
% INFO    : Bus 558	: V=0.977835, theta=-69.787347 -> V=1.0, theta=0.0
% INFO    : Bus 559	: V=1.0039559, theta=-72.498165 -> V=1.0, theta=0.0
% INFO    : Bus 560	: V=0.9691132, theta=-72.780597 -> V=1.0, theta=0.0
% INFO    : Bus 561	: V=0.9674181, theta=-72.530905 -> V=1.0, theta=0.0
% INFO    : Bus 562	: V=0.9668153, theta=-72.610266 -> V=1.0, theta=0.0
% INFO    : Bus 563	: V=0.9761423, theta=-71.532972 -> V=1.0, theta=0.0
% INFO    : Bus 564	: V=0.9699364, theta=-72.260967 -> V=1.0, theta=0.0
% INFO    : Bus 565	: V=0.9834134, theta=-74.163405 -> V=1.0, theta=0.0
% INFO    : Bus 566	: V=0.9654778, theta=-68.041501 -> V=1.0, theta=0.0
% INFO    : Bus 567	: V=0.9807847, theta=-69.487402 -> V=1.0, theta=0.0
% INFO    : Bus 568	: V=0.9791354, theta=-69.180246 -> V=1.0, theta=0.0
% INFO    : Bus 569	: V=0.9788336, theta=-67.812714 -> V=1.0, theta=0.0
% INFO    : Bus 570	: V=0.9786881, theta=-68.98798 -> V=1.0, theta=0.0
% INFO    : Bus 571	: V=0.9748362, theta=-69.874261 -> V=1.0, theta=0.0
% INFO    : Bus 572	: V=0.9824178, theta=-69.115198 -> V=1.0, theta=0.0
% INFO    : Bus 573	: V=0.9425135, theta=-77.245931 -> V=1.0, theta=0.0
% INFO    : Bus 574	: V=0.9388977, theta=-77.868843 -> V=1.0, theta=0.0
% INFO    : Bus 575	: V=0.9425482, theta=-78.046231 -> V=1.0, theta=0.0
% INFO    : Bus 576	: V=0.9489066, theta=-77.480419 -> V=1.0, theta=0.0
% INFO    : Bus 577	: V=0.9639867, theta=-70.728646 -> V=1.0, theta=0.0
% INFO    : Bus 578	: V=0.9679963, theta=-70.411925 -> V=1.0, theta=0.0
% INFO    : Bus 579	: V=0.960056, theta=-71.109553 -> V=1.0, theta=0.0
% INFO    : Bus 580	: V=0.983615, theta=-66.986272 -> V=1.0, theta=0.0
% INFO    : Bus 581	: V=0.9465691, theta=-74.578041 -> V=1.0, theta=0.0
% INFO    : Bus 582	: V=0.9451758, theta=-76.073576 -> V=1.0, theta=0.0
% INFO    : Bus 583	: V=0.9560919, theta=-76.849856 -> V=1.0, theta=0.0
% INFO    : Bus 584	: V=0.970619, theta=-71.840357 -> V=1.0, theta=0.0
% INFO    : Bus 585	: V=0.9705337, theta=-71.701215 -> V=1.0, theta=0.0
% INFO    : Bus 586	: V=0.9579988, theta=-72.308717 -> V=1.0, theta=0.0
% INFO    : Bus 587	: V=0.9601835, theta=-72.62398 -> V=1.0, theta=0.0
% INFO    : Bus 588	: V=0.9551367, theta=-71.463506 -> V=1.0, theta=0.0
% INFO    : Bus 589	: V=0.9580369, theta=-71.783387 -> V=1.0, theta=0.0
% INFO    : Bus 590	: V=0.9771605, theta=-73.817122 -> V=1.0, theta=0.0
% INFO    : Bus 591	: V=0.9662647, theta=-73.115937 -> V=1.0, theta=0.0
% INFO    : Bus 592	: V=0.965988, theta=-72.983816 -> V=1.0, theta=0.0
% INFO    : Bus 593	: V=0.9670333, theta=-72.962927 -> V=1.0, theta=0.0
% INFO    : Bus 594	: V=0.9666945, theta=-73.033787 -> V=1.0, theta=0.0
% INFO    : Bus 595	: V=0.9662486, theta=-73.137681 -> V=1.0, theta=0.0
% INFO    : Bus 596	: V=0.9631103, theta=-73.289978 -> V=1.0, theta=0.0
% INFO    : Bus 597	: V=0.9658748, theta=-73.244151 -> V=1.0, theta=0.0
% INFO    : Bus 598	: V=0.972647, theta=-74.184583 -> V=1.0, theta=0.0
% INFO    : Bus 599	: V=0.9677028, theta=-72.843564 -> V=1.0, theta=0.0
% INFO    : Bus 600	: V=0.9629964, theta=-72.731316 -> V=1.0, theta=0.0
% INFO    : Bus 601	: V=0.9618397, theta=-72.749166 -> V=1.0, theta=0.0
% INFO    : Bus 602	: V=0.9463492, theta=-76.035624 -> V=1.0, theta=0.0
% INFO    : Bus 603	: V=0.9513514, theta=-76.146485 -> V=1.0, theta=0.0
% INFO    : Bus 604	: V=0.9589278, theta=-71.289035 -> V=1.0, theta=0.0
% INFO    : Bus 605	: V=0.9597463, theta=-71.399857 -> V=1.0, theta=0.0
% INFO    : Bus 606	: V=0.9607168, theta=-71.588392 -> V=1.0, theta=0.0
% INFO    : Bus 607	: V=0.9616397, theta=-70.718315 -> V=1.0, theta=0.0
% INFO    : Bus 608	: V=0.9683451, theta=-69.985882 -> V=1.0, theta=0.0
% INFO    : Bus 609	: V=0.9691236, theta=-69.939085 -> V=1.0, theta=0.0
% INFO    : Bus 610	: V=0.9613873, theta=-70.431377 -> V=1.0, theta=0.0
% INFO    : Bus 611	: V=0.9727068, theta=-68.998974 -> V=1.0, theta=0.0
% INFO    : Bus 612	: V=0.9674017, theta=-69.73839 -> V=1.0, theta=0.0
% INFO    : Bus 613	: V=0.9706468, theta=-71.506412 -> V=1.0, theta=0.0
% INFO    : Bus 614	: V=0.9560181, theta=-70.576994 -> V=1.0, theta=0.0
% INFO    : Bus 615	: V=0.9718586, theta=-71.401929 -> V=1.0, theta=0.0
% INFO    : Bus 616	: V=0.9396514, theta=-77.326986 -> V=1.0, theta=0.0
% INFO    : Bus 617	: V=0.9734471, theta=-70.316231 -> V=1.0, theta=0.0
% INFO    : Bus 618	: V=0.9699104, theta=-70.924034 -> V=1.0, theta=0.0
% INFO    : Bus 619	: V=0.9720196, theta=-70.8266 -> V=1.0, theta=0.0
% INFO    : Bus 620	: V=0.9751803, theta=-70.488811 -> V=1.0, theta=0.0
% INFO    : Bus 621	: V=0.9682469, theta=-70.979862 -> V=1.0, theta=0.0
% INFO    : Bus 622	: V=0.9731713, theta=-70.313526 -> V=1.0, theta=0.0
% INFO    : Bus 623	: V=0.9738371, theta=-70.310125 -> V=1.0, theta=0.0
% INFO    : Bus 624	: V=0.986343, theta=-69.004428 -> V=1.0, theta=0.0
% INFO    : Bus 625	: V=0.9872686, theta=-68.883614 -> V=1.0, theta=0.0
% INFO    : Bus 626	: V=0.9805331, theta=-69.395377 -> V=1.0, theta=0.0
% INFO    : Bus 627	: V=0.9818389, theta=-69.436787 -> V=1.0, theta=0.0
% INFO    : Bus 628	: V=0.9858077, theta=-69.635153 -> V=1.0, theta=0.0
% INFO    : Bus 629	: V=0.988289, theta=-68.450865 -> V=1.0, theta=0.0
% INFO    : Bus 630	: V=0.9881084, theta=-68.642683 -> V=1.0, theta=0.0
% INFO    : Bus 631	: V=0.9873153, theta=-68.941214 -> V=1.0, theta=0.0
% INFO    : Bus 632	: V=0.9855042, theta=-69.15904 -> V=1.0, theta=0.0
% INFO    : Bus 633	: V=0.9621454, theta=-71.418537 -> V=1.0, theta=0.0
% INFO    : Bus 634	: V=0.9817899, theta=-69.440004 -> V=1.0, theta=0.0
% INFO    : Bus 635	: V=0.9831963, theta=-69.332489 -> V=1.0, theta=0.0
% INFO    : Bus 636	: V=0.9821391, theta=-69.428906 -> V=1.0, theta=0.0
% INFO    : Bus 637	: V=0.97329, theta=-69.343708 -> V=1.0, theta=0.0
% INFO    : Bus 638	: V=0.9899705, theta=-68.012297 -> V=1.0, theta=0.0
% INFO    : Bus 639	: V=0.994709, theta=-66.878355 -> V=1.0, theta=0.0
% INFO    : Bus 640	: V=0.9934973, theta=-67.012306 -> V=1.0, theta=0.0
% INFO    : Bus 641	: V=0.9826578, theta=-67.83685 -> V=1.0, theta=0.0
% INFO    : Bus 642	: V=0.9844277, theta=-67.304551 -> V=1.0, theta=0.0
% INFO    : Bus 643	: V=0.9938754, theta=-66.438283 -> V=1.0, theta=0.0
% INFO    : Bus 644	: V=0.9835793, theta=-67.269465 -> V=1.0, theta=0.0
% INFO    : Bus 645	: V=0.9839021, theta=-67.306084 -> V=1.0, theta=0.0
% INFO    : Bus 646	: V=0.9940854, theta=-66.555659 -> V=1.0, theta=0.0
% INFO    : Bus 647	: V=0.9954942, theta=-66.457719 -> V=1.0, theta=0.0
% INFO    : Bus 648	: V=0.9786945, theta=-68.134409 -> V=1.0, theta=0.0
% INFO    : Bus 649	: V=0.9882257, theta=-66.759719 -> V=1.0, theta=0.0
% INFO    : Bus 650	: V=0.9988028, theta=-65.880316 -> V=1.0, theta=0.0
% INFO    : Bus 651	: V=0.9939273, theta=-66.475032 -> V=1.0, theta=0.0
% INFO    : Bus 652	: V=0.988834, theta=-68.711314 -> V=1.0, theta=0.0
% INFO    : Bus 653	: V=1.0016428, theta=-65.386025 -> V=1.0, theta=0.0
% INFO    : Bus 654	: V=1.0002396, theta=-65.49416 -> V=1.0, theta=0.0
% INFO    : Bus 655	: V=1.000132, theta=-65.620335 -> V=1.0, theta=0.0
% INFO    : Bus 656	: V=0.9915883, theta=-66.386284 -> V=1.0, theta=0.0
% INFO    : Bus 657	: V=0.9990441, theta=-65.644531 -> V=1.0, theta=0.0
% INFO    : Bus 658	: V=0.9974885, theta=-65.815685 -> V=1.0, theta=0.0
% INFO    : Bus 659	: V=0.9911206, theta=-66.552413 -> V=1.0, theta=0.0
% INFO    : Bus 660	: V=0.9949504, theta=-66.108849 -> V=1.0, theta=0.0
% INFO    : Bus 661	: V=0.9949354, theta=-66.071737 -> V=1.0, theta=0.0
% INFO    : Bus 662	: V=0.9899355, theta=-66.991743 -> V=1.0, theta=0.0
% INFO    : Bus 663	: V=0.9998815, theta=-66.014217 -> V=1.0, theta=0.0
% INFO    : Bus 664	: V=0.9982576, theta=-66.099913 -> V=1.0, theta=0.0
% INFO    : Bus 665	: V=0.9946332, theta=-66.39888 -> V=1.0, theta=0.0
% INFO    : Bus 666	: V=0.9924761, theta=-66.698117 -> V=1.0, theta=0.0
% INFO    : Bus 667	: V=0.9919255, theta=-66.707902 -> V=1.0, theta=0.0
% INFO    : Bus 668	: V=0.99008, theta=-66.973862 -> V=1.0, theta=0.0
% INFO    : Bus 669	: V=0.9984174, theta=-66.070337 -> V=1.0, theta=0.0
% INFO    : Bus 670	: V=0.9898715, theta=-66.959212 -> V=1.0, theta=0.0
% INFO    : Bus 671	: V=0.9892909, theta=-66.96486 -> V=1.0, theta=0.0
% INFO    : Bus 672	: V=0.9921892, theta=-66.695264 -> V=1.0, theta=0.0
% INFO    : Bus 673	: V=0.9911508, theta=-66.893542 -> V=1.0, theta=0.0
% INFO    : Bus 674	: V=0.9906397, theta=-67.01356 -> V=1.0, theta=0.0
% INFO    : Bus 675	: V=0.9973317, theta=-66.147508 -> V=1.0, theta=0.0
% INFO    : Bus 676	: V=0.9905712, theta=-67.073869 -> V=1.0, theta=0.0
% INFO    : Bus 677	: V=0.9892944, theta=-66.979705 -> V=1.0, theta=0.0
% INFO    : Bus 678	: V=0.9902388, theta=-67.056612 -> V=1.0, theta=0.0
% INFO    : Bus 679	: V=0.9914202, theta=-67.023551 -> V=1.0, theta=0.0
% INFO    : Bus 680	: V=0.998089, theta=-66.158256 -> V=1.0, theta=0.0
% INFO    : Bus 681	: V=0.9982735, theta=-66.158309 -> V=1.0, theta=0.0
% INFO    : Bus 682	: V=0.9988985, theta=-66.09914 -> V=1.0, theta=0.0
% INFO    : Bus 683	: V=0.9989308, theta=-66.137363 -> V=1.0, theta=0.0
% INFO    : Bus 684	: V=0.998049, theta=-66.213126 -> V=1.0, theta=0.0
% INFO    : Bus 685	: V=0.9974948, theta=-66.292734 -> V=1.0, theta=0.0
% INFO    : Bus 686	: V=0.9865699, theta=-67.403296 -> V=1.0, theta=0.0
% INFO    : Bus 687	: V=0.9865407, theta=-67.370854 -> V=1.0, theta=0.0
% INFO    : Bus 688	: V=0.9987679, theta=-66.233004 -> V=1.0, theta=0.0
% INFO    : Bus 689	: V=1.0150318, theta=-64.39905 -> V=1.0, theta=0.0
% INFO    : Bus 690	: V=0.9932178, theta=-66.707109 -> V=1.0, theta=0.0
% INFO    : Bus 691	: V=1.0073449, theta=-64.736441 -> V=1.0, theta=0.0
% INFO    : Bus 692	: V=1.0057705, theta=-64.790268 -> V=1.0, theta=0.0
% INFO    : Bus 693	: V=1.0107988, theta=-64.068207 -> V=1.0, theta=0.0
% INFO    : Bus 694	: V=1.0100717, theta=-64.074554 -> V=1.0, theta=0.0
% INFO    : Bus 695	: V=1.0079531, theta=-64.159698 -> V=1.0, theta=0.0
% INFO    : Bus 696	: V=1.0159359, theta=-63.78143 -> V=1.0, theta=0.0
% INFO    : Bus 697	: V=1.0060586, theta=-64.6474 -> V=1.0, theta=0.0
% INFO    : Bus 698	: V=1.0097492, theta=-64.560679 -> V=1.0, theta=0.0
% INFO    : Bus 699	: V=1.0058716, theta=-64.799285 -> V=1.0, theta=0.0
% INFO    : Bus 700	: V=1.0047387, theta=-64.807913 -> V=1.0, theta=0.0
% INFO    : Bus 701	: V=1.0071627, theta=-64.912109 -> V=1.0, theta=0.0
% INFO    : Bus 702	: V=1.005806, theta=-65.07503 -> V=1.0, theta=0.0
% INFO    : Bus 703	: V=0.9996425, theta=-65.889093 -> V=1.0, theta=0.0
% INFO    : Bus 704	: V=1.001962, theta=-65.574749 -> V=1.0, theta=0.0
% INFO    : Bus 705	: V=0.991778, theta=-66.687968 -> V=1.0, theta=0.0
% INFO    : Bus 706	: V=1.0010584, theta=-65.704185 -> V=1.0, theta=0.0
% INFO    : Bus 707	: V=1.0040465, theta=-65.28972 -> V=1.0, theta=0.0
% INFO    : Bus 708	: V=0.9975107, theta=-66.086109 -> V=1.0, theta=0.0
% INFO    : Bus 709	: V=0.9963793, theta=-66.199861 -> V=1.0, theta=0.0
% INFO    : Bus 710	: V=0.9951388, theta=-66.329856 -> V=1.0, theta=0.0
% INFO    : Bus 711	: V=0.9958305, theta=-66.205582 -> V=1.0, theta=0.0
% INFO    : Bus 712	: V=0.9986093, theta=-65.979669 -> V=1.0, theta=0.0
% INFO    : Bus 713	: V=1.0014096, theta=-65.570671 -> V=1.0, theta=0.0
% INFO    : Bus 714	: V=0.9946792, theta=-65.899725 -> V=1.0, theta=0.0
% INFO    : Bus 715	: V=0.9950188, theta=-66.356238 -> V=1.0, theta=0.0
% INFO    : Bus 716	: V=0.9935797, theta=-66.529022 -> V=1.0, theta=0.0
% INFO    : Bus 717	: V=0.9857754, theta=-67.139923 -> V=1.0, theta=0.0
% INFO    : Bus 718	: V=0.9755779, theta=-68.697925 -> V=1.0, theta=0.0
% INFO    : Bus 719	: V=0.9959867, theta=-66.532287 -> V=1.0, theta=0.0
% INFO    : Bus 720	: V=0.9904464, theta=-67.156818 -> V=1.0, theta=0.0
% INFO    : Bus 721	: V=0.9898686, theta=-67.399726 -> V=1.0, theta=0.0
% INFO    : Bus 722	: V=0.9901598, theta=-67.157157 -> V=1.0, theta=0.0
% INFO    : Bus 723	: V=0.9900387, theta=-67.133419 -> V=1.0, theta=0.0
% INFO    : Bus 724	: V=0.9963317, theta=-66.776681 -> V=1.0, theta=0.0
% INFO    : Bus 725	: V=0.9903888, theta=-67.106491 -> V=1.0, theta=0.0
% INFO    : Bus 726	: V=0.9970637, theta=-66.748408 -> V=1.0, theta=0.0
% INFO    : Bus 727	: V=0.9883236, theta=-67.555919 -> V=1.0, theta=0.0
% INFO    : Bus 728	: V=0.9771265, theta=-68.778015 -> V=1.0, theta=0.0
% INFO    : Bus 729	: V=0.9881381, theta=-67.709556 -> V=1.0, theta=0.0
% INFO    : Bus 730	: V=0.9974537, theta=-67.441618 -> V=1.0, theta=0.0
% INFO    : Bus 731	: V=0.9958872, theta=-67.107284 -> V=1.0, theta=0.0
% INFO    : Bus 732	: V=0.9950094, theta=-66.738743 -> V=1.0, theta=0.0
% INFO    : Bus 733	: V=0.9851399, theta=-68.12056 -> V=1.0, theta=0.0
% INFO    : Bus 734	: V=0.9950181, theta=-66.81631 -> V=1.0, theta=0.0
% INFO    : Bus 735	: V=0.9824138, theta=-69.555674 -> V=1.0, theta=0.0
% INFO    : Bus 736	: V=0.9820455, theta=-69.561309 -> V=1.0, theta=0.0
% INFO    : Bus 737	: V=0.9814981, theta=-69.570983 -> V=1.0, theta=0.0
% INFO    : Bus 738	: V=0.9866672, theta=-68.966257 -> V=1.0, theta=0.0
% INFO    : Bus 739	: V=0.9801205, theta=-69.388358 -> V=1.0, theta=0.0
% INFO    : Bus 740	: V=0.9895345, theta=-68.497775 -> V=1.0, theta=0.0
% INFO    : Bus 741	: V=0.9891008, theta=-68.528794 -> V=1.0, theta=0.0
% INFO    : Bus 742	: V=0.9906384, theta=-68.414021 -> V=1.0, theta=0.0
% INFO    : Bus 743	: V=0.9888385, theta=-68.549872 -> V=1.0, theta=0.0
% INFO    : Bus 744	: V=0.9828573, theta=-69.516764 -> V=1.0, theta=0.0
% INFO    : Bus 745	: V=0.9832469, theta=-69.341492 -> V=1.0, theta=0.0
% INFO    : Bus 746	: V=0.983826, theta=-69.344873 -> V=1.0, theta=0.0
% INFO    : Bus 747	: V=0.9815753, theta=-69.564485 -> V=1.0, theta=0.0
% INFO    : Bus 748	: V=0.981937, theta=-69.559229 -> V=1.0, theta=0.0
% INFO    : Bus 749	: V=0.9831674, theta=-69.542896 -> V=1.0, theta=0.0
% INFO    : Bus 750	: V=1.0051273, theta=-66.717997 -> V=1.0, theta=0.0
% INFO    : Bus 751	: V=0.9824989, theta=-69.569141 -> V=1.0, theta=0.0
% INFO    : Bus 752	: V=0.9982908, theta=-67.533928 -> V=1.0, theta=0.0
% INFO    : Bus 753	: V=0.9873116, theta=-68.220644 -> V=1.0, theta=0.0
% INFO    : Bus 754	: V=0.9859726, theta=-68.328461 -> V=1.0, theta=0.0
% INFO    : Bus 755	: V=0.9973404, theta=-67.640749 -> V=1.0, theta=0.0
% INFO    : Bus 756	: V=0.9925272, theta=-67.960481 -> V=1.0, theta=0.0
% INFO    : Bus 757	: V=0.9951809, theta=-67.881671 -> V=1.0, theta=0.0
% INFO    : Bus 758	: V=0.9930814, theta=-68.126569 -> V=1.0, theta=0.0
% INFO    : Bus 759	: V=0.9957885, theta=-67.759471 -> V=1.0, theta=0.0
% INFO    : Bus 760	: V=0.9839828, theta=-68.346215 -> V=1.0, theta=0.0
% INFO    : Bus 761	: V=0.9829001, theta=-68.445926 -> V=1.0, theta=0.0
% INFO    : Bus 762	: V=0.9923477, theta=-66.74472 -> V=1.0, theta=0.0
% INFO    : Bus 763	: V=0.994243, theta=-66.69686 -> V=1.0, theta=0.0
% INFO    : Bus 764	: V=0.9933823, theta=-66.708367 -> V=1.0, theta=0.0
% INFO    : Bus 765	: V=0.9861967, theta=-67.448615 -> V=1.0, theta=0.0
% INFO    : Bus 766	: V=0.997289, theta=-66.422482 -> V=1.0, theta=0.0
% INFO    : Bus 767	: V=0.9963368, theta=-66.549148 -> V=1.0, theta=0.0
% INFO    : Bus 768	: V=0.9956494, theta=-66.686695 -> V=1.0, theta=0.0
% INFO    : Bus 769	: V=0.9871004, theta=-67.329664 -> V=1.0, theta=0.0
% INFO    : Bus 770	: V=0.9855757, theta=-67.455081 -> V=1.0, theta=0.0
% INFO    : Bus 771	: V=0.9857993, theta=-67.425767 -> V=1.0, theta=0.0
% INFO    : Bus 772	: V=0.9862057, theta=-67.33572 -> V=1.0, theta=0.0
% INFO    : Bus 773	: V=0.9865606, theta=-67.402269 -> V=1.0, theta=0.0
% INFO    : Bus 774	: V=0.9846914, theta=-67.456846 -> V=1.0, theta=0.0
% INFO    : Bus 775	: V=0.9858001, theta=-67.574284 -> V=1.0, theta=0.0
% INFO    : Bus 776	: V=0.9861265, theta=-67.424951 -> V=1.0, theta=0.0
% INFO    : Bus 777	: V=0.9785473, theta=-68.518227 -> V=1.0, theta=0.0
% INFO    : Bus 778	: V=0.9791347, theta=-67.608454 -> V=1.0, theta=0.0
% INFO    : Bus 779	: V=0.9812826, theta=-67.561272 -> V=1.0, theta=0.0
% INFO    : Bus 780	: V=0.9911381, theta=-66.8574 -> V=1.0, theta=0.0
% INFO    : Bus 781	: V=0.9920537, theta=-66.827735 -> V=1.0, theta=0.0
% INFO    : Bus 782	: V=0.9768273, theta=-68.640621 -> V=1.0, theta=0.0
% INFO    : Bus 783	: V=0.977712, theta=-67.542602 -> V=1.0, theta=0.0
% INFO    : Bus 784	: V=0.979839, theta=-68.187601 -> V=1.0, theta=0.0
% INFO    : Bus 785	: V=0.9789322, theta=-68.197355 -> V=1.0, theta=0.0
% INFO    : Bus 786	: V=0.9870842, theta=-67.05326 -> V=1.0, theta=0.0
% INFO    : Bus 787	: V=0.985858, theta=-68.860078 -> V=1.0, theta=0.0
% INFO    : Bus 788	: V=0.9887923, theta=-68.493472 -> V=1.0, theta=0.0
% INFO    : Bus 789	: V=0.9822336, theta=-69.093164 -> V=1.0, theta=0.0
% INFO    : Bus 790	: V=0.992134, theta=-68.094355 -> V=1.0, theta=0.0
% INFO    : Bus 791	: V=0.9817928, theta=-68.620206 -> V=1.0, theta=0.0
% INFO    : Bus 792	: V=0.9534217, theta=-71.46955 -> V=1.0, theta=0.0
% INFO    : Bus 793	: V=0.9780478, theta=-68.283905 -> V=1.0, theta=0.0
% INFO    : Bus 794	: V=0.9811227, theta=-68.091809 -> V=1.0, theta=0.0
% INFO    : Bus 795	: V=0.9826302, theta=-67.775782 -> V=1.0, theta=0.0
% INFO    : Bus 796	: V=0.9818229, theta=-68.210578 -> V=1.0, theta=0.0
% INFO    : Bus 797	: V=0.9744225, theta=-68.475391 -> V=1.0, theta=0.0
% INFO    : Bus 798	: V=0.9721329, theta=-68.575122 -> V=1.0, theta=0.0
% INFO    : Bus 799	: V=0.9880507, theta=-66.84167 -> V=1.0, theta=0.0
% INFO    : Bus 800	: V=0.98678, theta=-66.970113 -> V=1.0, theta=0.0
% INFO    : Bus 801	: V=0.9807495, theta=-68.538314 -> V=1.0, theta=0.0
% INFO    : Bus 802	: V=0.980888, theta=-68.408284 -> V=1.0, theta=0.0
% INFO    : Bus 803	: V=0.9865626, theta=-66.941984 -> V=1.0, theta=0.0
% INFO    : Bus 804	: V=0.9812456, theta=-67.786589 -> V=1.0, theta=0.0
% INFO    : Bus 805	: V=0.9765578, theta=-67.912902 -> V=1.0, theta=0.0
% INFO    : Bus 806	: V=0.9802001, theta=-67.9544 -> V=1.0, theta=0.0
% INFO    : Bus 807	: V=0.9820166, theta=-67.70828 -> V=1.0, theta=0.0
% INFO    : Bus 808	: V=0.9775749, theta=-68.663485 -> V=1.0, theta=0.0
% INFO    : Bus 809	: V=0.9686131, theta=-69.955951 -> V=1.0, theta=0.0
% INFO    : Bus 810	: V=0.9683294, theta=-69.980383 -> V=1.0, theta=0.0
% INFO    : Bus 811	: V=0.9780376, theta=-68.63002 -> V=1.0, theta=0.0
% INFO    : Bus 812	: V=0.9720151, theta=-69.577937 -> V=1.0, theta=0.0
% INFO    : Bus 813	: V=0.9677325, theta=-70.030362 -> V=1.0, theta=0.0
% INFO    : Bus 814	: V=0.9659238, theta=-70.159612 -> V=1.0, theta=0.0
% INFO    : Bus 815	: V=0.9665428, theta=-70.12086 -> V=1.0, theta=0.0
% INFO    : Bus 816	: V=0.9631079, theta=-70.337589 -> V=1.0, theta=0.0
% INFO    : Bus 817	: V=0.967959, theta=-70.022817 -> V=1.0, theta=0.0
% INFO    : Bus 818	: V=0.9678143, theta=-70.040182 -> V=1.0, theta=0.0
% INFO    : Bus 819	: V=0.9709625, theta=-69.708073 -> V=1.0, theta=0.0
% INFO    : Bus 820	: V=0.9697213, theta=-69.872635 -> V=1.0, theta=0.0
% INFO    : Bus 821	: V=0.9753752, theta=-68.884434 -> V=1.0, theta=0.0
% INFO    : Bus 822	: V=0.9714187, theta=-69.507838 -> V=1.0, theta=0.0
% INFO    : Bus 823	: V=0.9790646, theta=-68.506701 -> V=1.0, theta=0.0
% INFO    : Bus 824	: V=0.9775965, theta=-68.530519 -> V=1.0, theta=0.0
% INFO    : Bus 825	: V=0.9771263, theta=-68.661106 -> V=1.0, theta=0.0
% INFO    : Bus 826	: V=0.9766428, theta=-68.609609 -> V=1.0, theta=0.0
% INFO    : Bus 827	: V=0.9628482, theta=-70.331531 -> V=1.0, theta=0.0
% INFO    : Bus 828	: V=0.9637115, theta=-70.327196 -> V=1.0, theta=0.0
% INFO    : Bus 829	: V=0.970391, theta=-69.858748 -> V=1.0, theta=0.0
% INFO    : Bus 830	: V=0.9619321, theta=-70.355698 -> V=1.0, theta=0.0
% INFO    : Bus 831	: V=0.9628183, theta=-70.350467 -> V=1.0, theta=0.0
% INFO    : Bus 832	: V=0.9649068, theta=-70.255559 -> V=1.0, theta=0.0
% INFO    : Bus 833	: V=0.9648662, theta=-70.258757 -> V=1.0, theta=0.0
% INFO    : Bus 834	: V=0.9659803, theta=-70.238993 -> V=1.0, theta=0.0
% INFO    : Bus 835	: V=0.9786495, theta=-69.245979 -> V=1.0, theta=0.0
% INFO    : Bus 836	: V=0.9639774, theta=-70.314938 -> V=1.0, theta=0.0
% INFO    : Bus 837	: V=0.960876, theta=-70.453492 -> V=1.0, theta=0.0
% INFO    : Bus 838	: V=0.9570269, theta=-70.497839 -> V=1.0, theta=0.0
% INFO    : Bus 839	: V=0.9977567, theta=-66.133352 -> V=1.0, theta=0.0
% INFO    : Bus 840	: V=0.9979761, theta=-66.153366 -> V=1.0, theta=0.0
% INFO    : Bus 841	: V=1.0001174, theta=-65.860907 -> V=1.0, theta=0.0
% INFO    : Bus 842	: V=0.9997089, theta=-65.983783 -> V=1.0, theta=0.0
% INFO    : Bus 843	: V=0.994545, theta=-66.227462 -> V=1.0, theta=0.0
% INFO    : Bus 844	: V=0.9990996, theta=-65.916974 -> V=1.0, theta=0.0
% INFO    : Bus 845	: V=1.0095848, theta=-64.984676 -> V=1.0, theta=0.0
% INFO    : Bus 846	: V=1.0072531, theta=-65.204523 -> V=1.0, theta=0.0
% INFO    : Bus 847	: V=1.0071396, theta=-65.22355 -> V=1.0, theta=0.0
% INFO    : Bus 848	: V=1.0076893, theta=-65.158884 -> V=1.0, theta=0.0
% INFO    : Bus 849	: V=1.0081244, theta=-65.116404 -> V=1.0, theta=0.0
% INFO    : Bus 850	: V=1.0104994, theta=-64.449359 -> V=1.0, theta=0.0
% INFO    : Bus 851	: V=1.0103252, theta=-64.875737 -> V=1.0, theta=0.0
% INFO    : Bus 852	: V=1.0097683, theta=-64.951271 -> V=1.0, theta=0.0
% INFO    : Bus 853	: V=1.0108031, theta=-64.583745 -> V=1.0, theta=0.0
% INFO    : Bus 854	: V=1.0104354, theta=-65.220496 -> V=1.0, theta=0.0
% INFO    : Bus 855	: V=1.0073549, theta=-65.315883 -> V=1.0, theta=0.0
% INFO    : Bus 856	: V=1.0035771, theta=-66.135811 -> V=1.0, theta=0.0
% INFO    : Bus 857	: V=1.0009307, theta=-66.349105 -> V=1.0, theta=0.0
% INFO    : Bus 858	: V=0.9926922, theta=-67.787449 -> V=1.0, theta=0.0
% INFO    : Bus 859	: V=0.9740519, theta=-69.840669 -> V=1.0, theta=0.0
% INFO    : Bus 860	: V=0.9937202, theta=-67.654368 -> V=1.0, theta=0.0
% INFO    : Bus 861	: V=0.994862, theta=-67.520674 -> V=1.0, theta=0.0
% INFO    : Bus 862	: V=0.9760657, theta=-69.691579 -> V=1.0, theta=0.0
% INFO    : Bus 863	: V=0.9970201, theta=-67.345097 -> V=1.0, theta=0.0
% INFO    : Bus 864	: V=0.9985442, theta=-67.157781 -> V=1.0, theta=0.0
% INFO    : Bus 865	: V=0.9825315, theta=-68.820081 -> V=1.0, theta=0.0
% INFO    : Bus 866	: V=0.9833423, theta=-68.813776 -> V=1.0, theta=0.0
% INFO    : Bus 867	: V=0.9906954, theta=-68.561704 -> V=1.0, theta=0.0
% INFO    : Bus 868	: V=1.002967, theta=-66.737491 -> V=1.0, theta=0.0
% INFO    : Bus 869	: V=1.007437, theta=-65.841107 -> V=1.0, theta=0.0
% INFO    : Bus 870	: V=0.992448, theta=-66.109353 -> V=1.0, theta=0.0
% INFO    : Bus 871	: V=1.0035435, theta=-65.77305 -> V=1.0, theta=0.0
% INFO    : Bus 872	: V=1.0093298, theta=-64.912625 -> V=1.0, theta=0.0
% INFO    : Bus 873	: V=1.0102435, theta=-64.902248 -> V=1.0, theta=0.0
% INFO    : Bus 874	: V=1.0166495, theta=-62.166889 -> V=1.0, theta=0.0
% INFO    : Bus 875	: V=1.0161127, theta=-62.490951 -> V=1.0, theta=0.0
% INFO    : Bus 876	: V=1.0045249, theta=-65.089216 -> V=1.0, theta=0.0
% INFO    : Bus 877	: V=0.9934859, theta=-66.096282 -> V=1.0, theta=0.0
% INFO    : Bus 878	: V=1.0017911, theta=-65.51478 -> V=1.0, theta=0.0
% INFO    : Bus 879	: V=0.9902635, theta=-67.60523 -> V=1.0, theta=0.0
% INFO    : Bus 880	: V=0.9917383, theta=-67.200539 -> V=1.0, theta=0.0
% INFO    : Bus 881	: V=0.995804, theta=-66.506369 -> V=1.0, theta=0.0
% INFO    : Bus 882	: V=0.999489, theta=-65.882317 -> V=1.0, theta=0.0
% INFO    : Bus 883	: V=0.9904189, theta=-67.284617 -> V=1.0, theta=0.0
% INFO    : Bus 884	: V=0.9961129, theta=-68.216487 -> V=1.0, theta=0.0
% INFO    : Bus 885	: V=0.9763005, theta=-69.996487 -> V=1.0, theta=0.0
% INFO    : Bus 886	: V=0.979589, theta=-69.939758 -> V=1.0, theta=0.0
% INFO    : Bus 887	: V=0.9894168, theta=-68.191594 -> V=1.0, theta=0.0
% INFO    : Bus 888	: V=0.9916961, theta=-67.923751 -> V=1.0, theta=0.0
% INFO    : Bus 889	: V=0.9785869, theta=-70.119006 -> V=1.0, theta=0.0
% INFO    : Bus 890	: V=0.9729663, theta=-70.213251 -> V=1.0, theta=0.0
% INFO    : Bus 891	: V=0.9928765, theta=-67.898378 -> V=1.0, theta=0.0
% INFO    : Bus 892	: V=0.9656602, theta=-68.927816 -> V=1.0, theta=0.0
% INFO    : Bus 893	: V=0.9695643, theta=-68.772109 -> V=1.0, theta=0.0
% INFO    : Bus 894	: V=0.9784564, theta=-68.436399 -> V=1.0, theta=0.0
% INFO    : Bus 895	: V=0.9971359, theta=-66.652507 -> V=1.0, theta=0.0
% INFO    : Bus 896	: V=1.0051218, theta=-65.421556 -> V=1.0, theta=0.0
% INFO    : Bus 897	: V=0.9966119, theta=-65.961909 -> V=1.0, theta=0.0
% INFO    : Bus 898	: V=0.9861078, theta=-68.87467 -> V=1.0, theta=0.0
% INFO    : Bus 899	: V=1.0069954, theta=-65.003886 -> V=1.0, theta=0.0
% INFO    : Bus 900	: V=1.0094978, theta=-65.023866 -> V=1.0, theta=0.0
% INFO    : Bus 901	: V=1.0024287, theta=-66.633436 -> V=1.0, theta=0.0
% INFO    : Bus 902	: V=1.0072974, theta=-65.885699 -> V=1.0, theta=0.0
% INFO    : Bus 903	: V=1.0059826, theta=-65.063098 -> V=1.0, theta=0.0
% INFO    : Bus 904	: V=1.0044613, theta=-65.526509 -> V=1.0, theta=0.0
% INFO    : Bus 905	: V=1.0075792, theta=-65.267275 -> V=1.0, theta=0.0
% INFO    : Bus 906	: V=1.0172463, theta=-63.983407 -> V=1.0, theta=0.0
% INFO    : Bus 907	: V=0.9610121, theta=-68.971461 -> V=1.0, theta=0.0
% INFO    : Bus 908	: V=0.9738017, theta=-70.782294 -> V=1.0, theta=0.0
% INFO    : Bus 909	: V=0.9658485, theta=-70.78203 -> V=1.0, theta=0.0
% INFO    : Bus 910	: V=0.9673774, theta=-70.919487 -> V=1.0, theta=0.0
% INFO    : Bus 911	: V=0.9546639, theta=-73.661347 -> V=1.0, theta=0.0
% INFO    : Bus 912	: V=0.9555731, theta=-73.653431 -> V=1.0, theta=0.0
% INFO    : Bus 913	: V=0.9573943, theta=-73.619744 -> V=1.0, theta=0.0
% INFO    : Bus 914	: V=0.9583709, theta=-73.398743 -> V=1.0, theta=0.0
% INFO    : Bus 915	: V=0.9566445, theta=-73.585026 -> V=1.0, theta=0.0
% INFO    : Bus 916	: V=0.9596, theta=-73.283683 -> V=1.0, theta=0.0
% INFO    : Bus 917	: V=0.9592544, theta=-73.462514 -> V=1.0, theta=0.0
% INFO    : Bus 918	: V=0.9600335, theta=-73.885296 -> V=1.0, theta=0.0
% INFO    : Bus 919	: V=0.9577082, theta=-73.509425 -> V=1.0, theta=0.0
% INFO    : Bus 920	: V=0.9625751, theta=-73.846196 -> V=1.0, theta=0.0
% INFO    : Bus 921	: V=0.9611703, theta=-74.001751 -> V=1.0, theta=0.0
% INFO    : Bus 922	: V=0.9905123, theta=-73.538717 -> V=1.0, theta=0.0
% INFO    : Bus 923	: V=0.9761784, theta=-73.906893 -> V=1.0, theta=0.0
% INFO    : Bus 924	: V=0.9736757, theta=-73.938977 -> V=1.0, theta=0.0
% INFO    : Bus 925	: V=0.9839308, theta=-73.012856 -> V=1.0, theta=0.0
% INFO    : Bus 926	: V=0.9622963, theta=-73.451987 -> V=1.0, theta=0.0
% INFO    : Bus 927	: V=0.9741133, theta=-70.156777 -> V=1.0, theta=0.0
% INFO    : Bus 928	: V=0.9738895, theta=-70.807223 -> V=1.0, theta=0.0
% INFO    : Bus 929	: V=0.9865729, theta=-71.971462 -> V=1.0, theta=0.0
% INFO    : Bus 930	: V=0.9832645, theta=-72.154052 -> V=1.0, theta=0.0
% INFO    : Bus 931	: V=0.9815597, theta=-72.237282 -> V=1.0, theta=0.0
% INFO    : Bus 932	: V=0.9779673, theta=-71.118203 -> V=1.0, theta=0.0
% INFO    : Bus 933	: V=0.9602537, theta=-74.574054 -> V=1.0, theta=0.0
% INFO    : Bus 934	: V=0.9820988, theta=-73.865644 -> V=1.0, theta=0.0
% INFO    : Bus 935	: V=0.9648201, theta=-74.494168 -> V=1.0, theta=0.0
% INFO    : Bus 936	: V=0.9801984, theta=-69.587574 -> V=1.0, theta=0.0
% INFO    : Bus 937	: V=0.9816097, theta=-69.451092 -> V=1.0, theta=0.0
% INFO    : Bus 938	: V=0.9786955, theta=-70.687763 -> V=1.0, theta=0.0
% INFO    : Bus 939	: V=0.9739372, theta=-70.804492 -> V=1.0, theta=0.0
% INFO    : Bus 940	: V=0.9748176, theta=-70.792182 -> V=1.0, theta=0.0
% INFO    : Bus 941	: V=0.9915747, theta=-71.820539 -> V=1.0, theta=0.0
% INFO    : Bus 942	: V=0.9911602, theta=-71.938713 -> V=1.0, theta=0.0
% INFO    : Bus 943	: V=0.9766477, theta=-70.141942 -> V=1.0, theta=0.0
% INFO    : Bus 944	: V=0.987382, theta=-72.000764 -> V=1.0, theta=0.0
% INFO    : Bus 945	: V=1.0103254, theta=-72.556008 -> V=1.0, theta=0.0
% INFO    : Bus 946	: V=0.9983417, theta=-72.617339 -> V=1.0, theta=0.0
% INFO    : Bus 947	: V=0.9948112, theta=-73.032218 -> V=1.0, theta=0.0
% INFO    : Bus 948	: V=0.9891919, theta=-71.988816 -> V=1.0, theta=0.0
% INFO    : Bus 949	: V=1.0042762, theta=-71.41386 -> V=1.0, theta=0.0
% INFO    : Bus 950	: V=1.0097558, theta=-71.868242 -> V=1.0, theta=0.0
% INFO    : Bus 951	: V=1.0116316, theta=-71.700948 -> V=1.0, theta=0.0
% INFO    : Bus 952	: V=0.9995969, theta=-72.669362 -> V=1.0, theta=0.0
% INFO    : Bus 953	: V=1.0088882, theta=-71.24999 -> V=1.0, theta=0.0
% INFO    : Bus 954	: V=0.9898151, theta=-71.997536 -> V=1.0, theta=0.0
% INFO    : Bus 955	: V=1.0061156, theta=-71.243768 -> V=1.0, theta=0.0
% INFO    : Bus 956	: V=0.983234, theta=-71.128717 -> V=1.0, theta=0.0
% INFO    : Bus 957	: V=0.9830379, theta=-71.567255 -> V=1.0, theta=0.0
% INFO    : Bus 958	: V=0.9810433, theta=-71.406693 -> V=1.0, theta=0.0
% INFO    : Bus 959	: V=0.982001, theta=-70.867713 -> V=1.0, theta=0.0
% INFO    : Bus 960	: V=0.9782909, theta=-72.065395 -> V=1.0, theta=0.0
% INFO    : Bus 961	: V=0.9900038, theta=-79.36588 -> V=1.0, theta=0.0
% INFO    : Bus 962	: V=0.9855402, theta=-79.996103 -> V=1.0, theta=0.0
% INFO    : Bus 963	: V=0.9938659, theta=-78.834595 -> V=1.0, theta=0.0
% INFO    : Bus 964	: V=0.9912403, theta=-79.281116 -> V=1.0, theta=0.0
% INFO    : Bus 965	: V=0.9889074, theta=-79.420759 -> V=1.0, theta=0.0
% INFO    : Bus 966	: V=0.9883317, theta=-79.372527 -> V=1.0, theta=0.0
% INFO    : Bus 967	: V=1.0147786, theta=-76.446493 -> V=1.0, theta=0.0
% INFO    : Bus 968	: V=0.9948375, theta=-78.763897 -> V=1.0, theta=0.0
% INFO    : Bus 969	: V=0.992983, theta=-78.878309 -> V=1.0, theta=0.0
% INFO    : Bus 970	: V=0.9933724, theta=-78.889601 -> V=1.0, theta=0.0
% INFO    : Bus 971	: V=0.9920528, theta=-78.844762 -> V=1.0, theta=0.0
% INFO    : Bus 972	: V=0.9922954, theta=-78.884029 -> V=1.0, theta=0.0
% INFO    : Bus 973	: V=0.985496, theta=-79.571499 -> V=1.0, theta=0.0
% INFO    : Bus 974	: V=0.990661, theta=-79.045693 -> V=1.0, theta=0.0
% INFO    : Bus 975	: V=0.9854248, theta=-79.701302 -> V=1.0, theta=0.0
% INFO    : Bus 976	: V=0.9924246, theta=-78.590711 -> V=1.0, theta=0.0
% INFO    : Bus 977	: V=0.9938291, theta=-78.954145 -> V=1.0, theta=0.0
% INFO    : Bus 978	: V=0.9905442, theta=-79.089338 -> V=1.0, theta=0.0
% INFO    : Bus 979	: V=0.9894662, theta=-79.16253 -> V=1.0, theta=0.0
% INFO    : Bus 980	: V=0.993549, theta=-78.925233 -> V=1.0, theta=0.0
% INFO    : Bus 981	: V=0.9800229, theta=-80.062583 -> V=1.0, theta=0.0
% INFO    : Bus 982	: V=0.9808115, theta=-80.184903 -> V=1.0, theta=0.0
% INFO    : Bus 983	: V=0.9985884, theta=-79.048566 -> V=1.0, theta=0.0
% INFO    : Bus 984	: V=0.9947254, theta=-79.954986 -> V=1.0, theta=0.0
% INFO    : Bus 985	: V=0.995385, theta=-79.918899 -> V=1.0, theta=0.0
% INFO    : Bus 986	: V=0.9887699, theta=-79.956667 -> V=1.0, theta=0.0
% INFO    : Bus 987	: V=0.9953469, theta=-79.018905 -> V=1.0, theta=0.0
% INFO    : Bus 988	: V=0.9753609, theta=-80.614045 -> V=1.0, theta=0.0
% INFO    : Bus 989	: V=0.9914781, theta=-83.222201 -> V=1.0, theta=0.0
% INFO    : Bus 990	: V=0.995305, theta=-83.169509 -> V=1.0, theta=0.0
% INFO    : Bus 991	: V=1.0071725, theta=-82.896912 -> V=1.0, theta=0.0
% INFO    : Bus 992	: V=1.0068401, theta=-82.555299 -> V=1.0, theta=0.0
% INFO    : Bus 993	: V=1.0142012, theta=-81.280673 -> V=1.0, theta=0.0
% INFO    : Bus 994	: V=1.0183942, theta=-80.458296 -> V=1.0, theta=0.0
% INFO    : Bus 995	: V=1.0195205, theta=-80.241424 -> V=1.0, theta=0.0
% INFO    : Bus 996	: V=1.0002757, theta=-83.029495 -> V=1.0, theta=0.0
% INFO    : Bus 997	: V=1.0061032, theta=-81.732721 -> V=1.0, theta=0.0
% INFO    : Bus 998	: V=1.0002397, theta=-83.396216 -> V=1.0, theta=0.0
% INFO    : Bus 999	: V=0.9991617, theta=-83.674063 -> V=1.0, theta=0.0
% INFO    : Bus 1000	: V=1.0015517, theta=-83.284101 -> V=1.0, theta=0.0
% INFO    : Bus 1001	: V=0.9994656, theta=-83.523865 -> V=1.0, theta=0.0
% INFO    : Bus 1002	: V=1.0081744, theta=-82.267333 -> V=1.0, theta=0.0
% INFO    : Bus 1003	: V=0.9999119, theta=-82.858099 -> V=1.0, theta=0.0
% INFO    : Bus 1004	: V=1.0073715, theta=-81.970007 -> V=1.0, theta=0.0
% INFO    : Bus 1005	: V=1.0168064, theta=-79.944684 -> V=1.0, theta=0.0
% INFO    : Bus 1006	: V=1.0147443, theta=-80.692149 -> V=1.0, theta=0.0
% INFO    : Bus 1007	: V=0.9933074, theta=-81.165326 -> V=1.0, theta=0.0
% INFO    : Bus 1008	: V=0.9840093, theta=-80.753801 -> V=1.0, theta=0.0
% INFO    : Bus 1009	: V=0.9994858, theta=-79.289759 -> V=1.0, theta=0.0
% INFO    : Bus 1010	: V=0.9872657, theta=-80.637878 -> V=1.0, theta=0.0
% INFO    : Bus 1011	: V=1.0136451, theta=-79.242088 -> V=1.0, theta=0.0
% INFO    : Bus 1012	: V=0.9988824, theta=-79.468048 -> V=1.0, theta=0.0
% INFO    : Bus 1013	: V=1.0063674, theta=-77.853391 -> V=1.0, theta=0.0
% INFO    : Bus 1014	: V=0.9970064, theta=-79.034782 -> V=1.0, theta=0.0
% INFO    : Bus 1015	: V=0.9938809, theta=-79.27933 -> V=1.0, theta=0.0
% INFO    : Bus 1016	: V=0.9960136, theta=-79.124059 -> V=1.0, theta=0.0
% INFO    : Bus 1017	: V=0.9947673, theta=-79.207616 -> V=1.0, theta=0.0
% INFO    : Bus 1018	: V=0.9952967, theta=-79.200377 -> V=1.0, theta=0.0
% INFO    : Bus 1019	: V=0.9969626, theta=-79.163501 -> V=1.0, theta=0.0
% INFO    : Bus 1020	: V=0.9968644, theta=-79.164356 -> V=1.0, theta=0.0
% INFO    : Bus 1021	: V=0.9958161, theta=-79.192461 -> V=1.0, theta=0.0
% INFO    : Bus 1022	: V=0.9952113, theta=-79.180966 -> V=1.0, theta=0.0
% INFO    : Bus 1023	: V=0.9933015, theta=-79.278694 -> V=1.0, theta=0.0
% INFO    : Bus 1024	: V=1.0064832, theta=-77.775395 -> V=1.0, theta=0.0
% INFO    : Bus 1025	: V=0.9944002, theta=-79.267541 -> V=1.0, theta=0.0
% INFO    : Bus 1026	: V=0.9935922, theta=-79.360812 -> V=1.0, theta=0.0
% INFO    : Bus 1027	: V=0.9958132, theta=-79.158895 -> V=1.0, theta=0.0
% INFO    : Bus 1028	: V=0.9909308, theta=-79.585275 -> V=1.0, theta=0.0
% INFO    : Bus 1029	: V=1.0039697, theta=-77.95552 -> V=1.0, theta=0.0
% INFO    : Bus 1030	: V=1.0060811, theta=-77.817341 -> V=1.0, theta=0.0
% INFO    : Bus 1031	: V=1.0180117, theta=-76.242619 -> V=1.0, theta=0.0
% INFO    : Bus 1032	: V=1.0051416, theta=-78.039817 -> V=1.0, theta=0.0
% INFO    : Bus 1033	: V=1.0189528, theta=-76.193824 -> V=1.0, theta=0.0
% INFO    : Bus 1034	: V=0.9866129, theta=-79.770581 -> V=1.0, theta=0.0
% INFO    : Bus 1035	: V=0.9997042, theta=-78.745497 -> V=1.0, theta=0.0
% INFO    : Bus 1036	: V=0.9887191, theta=-79.754696 -> V=1.0, theta=0.0
% INFO    : Bus 1037	: V=1.0021266, theta=-78.577695 -> V=1.0, theta=0.0
% INFO    : Bus 1038	: V=1.0195947, theta=-76.889684 -> V=1.0, theta=0.0
% INFO    : Bus 1039	: V=1.0010605, theta=-78.676086 -> V=1.0, theta=0.0
% INFO    : Bus 1040	: V=0.9989842, theta=-78.723556 -> V=1.0, theta=0.0
% INFO    : Bus 1041	: V=0.9912643, theta=-79.421673 -> V=1.0, theta=0.0
% INFO    : Bus 1042	: V=0.993494, theta=-79.297817 -> V=1.0, theta=0.0
% INFO    : Bus 1043	: V=0.9993915, theta=-78.666868 -> V=1.0, theta=0.0
% INFO    : Bus 1044	: V=0.9952818, theta=-79.278547 -> V=1.0, theta=0.0
% INFO    : Bus 1045	: V=1.0004659, theta=-78.530822 -> V=1.0, theta=0.0
% INFO    : Bus 1046	: V=0.9896702, theta=-79.464337 -> V=1.0, theta=0.0
% INFO    : Bus 1047	: V=1.0013793, theta=-78.652885 -> V=1.0, theta=0.0
% INFO    : Bus 1048	: V=0.9987172, theta=-78.836577 -> V=1.0, theta=0.0
% INFO    : Bus 1049	: V=0.9853474, theta=-80.021438 -> V=1.0, theta=0.0
% INFO    : Bus 1050	: V=0.9972383, theta=-78.582451 -> V=1.0, theta=0.0
% INFO    : Bus 1051	: V=0.9950039, theta=-78.70099 -> V=1.0, theta=0.0
% INFO    : Bus 1052	: V=0.9995824, theta=-78.601176 -> V=1.0, theta=0.0
% INFO    : Bus 1053	: V=0.9925648, theta=-79.124788 -> V=1.0, theta=0.0
% INFO    : Bus 1054	: V=1.0004711, theta=-78.534434 -> V=1.0, theta=0.0
% INFO    : Bus 1055	: V=0.993093, theta=-78.86745 -> V=1.0, theta=0.0
% INFO    : Bus 1056	: V=0.9945636, theta=-78.671475 -> V=1.0, theta=0.0
% INFO    : Bus 1057	: V=0.9965549, theta=-78.560982 -> V=1.0, theta=0.0
% INFO    : Bus 1058	: V=0.9919668, theta=-78.813438 -> V=1.0, theta=0.0
% INFO    : Bus 1059	: V=0.9804688, theta=-80.184495 -> V=1.0, theta=0.0
% INFO    : Bus 1060	: V=0.9836592, theta=-80.043311 -> V=1.0, theta=0.0
% INFO    : Bus 1061	: V=1.0153472, theta=-77.026287 -> V=1.0, theta=0.0
% INFO    : Bus 1062	: V=0.9883204, theta=-79.808424 -> V=1.0, theta=0.0
% INFO    : Bus 1063	: V=0.995132, theta=-79.210019 -> V=1.0, theta=0.0
% INFO    : Bus 1064	: V=0.9902981, theta=-79.656839 -> V=1.0, theta=0.0
% INFO    : Bus 1065	: V=0.9964025, theta=-78.609096 -> V=1.0, theta=0.0
% INFO    : Bus 1066	: V=0.9687546, theta=-80.685097 -> V=1.0, theta=0.0
% INFO    : Bus 1067	: V=0.9629838, theta=-80.738757 -> V=1.0, theta=0.0
% INFO    : Bus 1068	: V=0.955559, theta=-81.253007 -> V=1.0, theta=0.0
% INFO    : Bus 1069	: V=0.9672828, theta=-80.571661 -> V=1.0, theta=0.0
% INFO    : Bus 1070	: V=0.9592137, theta=-80.967707 -> V=1.0, theta=0.0
% INFO    : Bus 1071	: V=0.9563724, theta=-81.384392 -> V=1.0, theta=0.0
% INFO    : Bus 1072	: V=0.9697947, theta=-81.140995 -> V=1.0, theta=0.0
% INFO    : Bus 1073	: V=0.9909799, theta=-79.264038 -> V=1.0, theta=0.0
% INFO    : Bus 1074	: V=0.9989153, theta=-78.786863 -> V=1.0, theta=0.0
% INFO    : Bus 1075	: V=0.9981295, theta=-78.923349 -> V=1.0, theta=0.0
% INFO    : Bus 1076	: V=1.0162781, theta=-77.151457 -> V=1.0, theta=0.0
% INFO    : Bus 1077	: V=0.9914287, theta=-79.330777 -> V=1.0, theta=0.0
% INFO    : Bus 1078	: V=0.9863484, theta=-79.598694 -> V=1.0, theta=0.0
% INFO    : Bus 1079	: V=0.9932192, theta=-79.06634 -> V=1.0, theta=0.0
% INFO    : Bus 1080	: V=1.0034703, theta=-77.01004 -> V=1.0, theta=0.0
% INFO    : Bus 1081	: V=1.0056063, theta=-76.816482 -> V=1.0, theta=0.0
% INFO    : Bus 1082	: V=0.9981864, theta=-77.6485 -> V=1.0, theta=0.0
% INFO    : Bus 1083	: V=0.9859308, theta=-79.242205 -> V=1.0, theta=0.0
% INFO    : Bus 1084	: V=0.9774232, theta=-79.675786 -> V=1.0, theta=0.0
% INFO    : Bus 1085	: V=0.9833555, theta=-79.603767 -> V=1.0, theta=0.0
% INFO    : Bus 1086	: V=0.9984347, theta=-79.144427 -> V=1.0, theta=0.0
% INFO    : Bus 1087	: V=1.0188244, theta=-78.131489 -> V=1.0, theta=0.0
% INFO    : Bus 1088	: V=0.9663549, theta=-81.721694 -> V=1.0, theta=0.0
% INFO    : Bus 1089	: V=0.9847554, theta=-81.344619 -> V=1.0, theta=0.0
% INFO    : Bus 1090	: V=1.0087279, theta=-79.444002 -> V=1.0, theta=0.0
% INFO    : Bus 1091	: V=0.9945287, theta=-80.628833 -> V=1.0, theta=0.0
% INFO    : Bus 1092	: V=0.9824232, theta=-81.117057 -> V=1.0, theta=0.0
% INFO    : Bus 1093	: V=0.9863065, theta=-80.835128 -> V=1.0, theta=0.0
% INFO    : Bus 1094	: V=0.9588898, theta=-82.882697 -> V=1.0, theta=0.0
% INFO    : Bus 1095	: V=0.9638633, theta=-83.966909 -> V=1.0, theta=0.0
% INFO    : Bus 1096	: V=0.9783789, theta=-81.620657 -> V=1.0, theta=0.0
% INFO    : Bus 1097	: V=0.9646734, theta=-83.041036 -> V=1.0, theta=0.0
% INFO    : Bus 1098	: V=0.9582303, theta=-83.603975 -> V=1.0, theta=0.0
% INFO    : Bus 1099	: V=0.9516731, theta=-83.808664 -> V=1.0, theta=0.0
% INFO    : Bus 1100	: V=0.9782243, theta=-81.815598 -> V=1.0, theta=0.0
% INFO    : Bus 1101	: V=0.9983587, theta=-80.471196 -> V=1.0, theta=0.0
% INFO    : Bus 1102	: V=0.9821415, theta=-81.544897 -> V=1.0, theta=0.0
% INFO    : Bus 1103	: V=0.9709277, theta=-82.47615 -> V=1.0, theta=0.0
% INFO    : Bus 1104	: V=0.9702388, theta=-82.747752 -> V=1.0, theta=0.0
% INFO    : Bus 1105	: V=0.958389, theta=-83.540201 -> V=1.0, theta=0.0
% INFO    : Bus 1106	: V=0.979715, theta=-80.9312 -> V=1.0, theta=0.0
% INFO    : Bus 1107	: V=0.9577354, theta=-83.218149 -> V=1.0, theta=0.0
% INFO    : Bus 1108	: V=0.9553421, theta=-83.425055 -> V=1.0, theta=0.0
% INFO    : Bus 1109	: V=0.9548634, theta=-83.771024 -> V=1.0, theta=0.0
% INFO    : Bus 1110	: V=0.9731017, theta=-81.92318 -> V=1.0, theta=0.0
% INFO    : Bus 1111	: V=0.9544432, theta=-83.538353 -> V=1.0, theta=0.0
% INFO    : Bus 1112	: V=0.9576509, theta=-83.091601 -> V=1.0, theta=0.0
% INFO    : Bus 1113	: V=0.9530634, theta=-83.819766 -> V=1.0, theta=0.0
% INFO    : Bus 1114	: V=0.9508628, theta=-84.228186 -> V=1.0, theta=0.0
% INFO    : Bus 1115	: V=0.9524248, theta=-84.1861 -> V=1.0, theta=0.0
% INFO    : Bus 1116	: V=0.9688464, theta=-81.438311 -> V=1.0, theta=0.0
% INFO    : Bus 1117	: V=0.9652304, theta=-82.001339 -> V=1.0, theta=0.0
% INFO    : Bus 1118	: V=0.9591453, theta=-82.733365 -> V=1.0, theta=0.0
% INFO    : Bus 1119	: V=0.9912757, theta=-79.966878 -> V=1.0, theta=0.0
% INFO    : Bus 1120	: V=0.9861146, theta=-80.031203 -> V=1.0, theta=0.0
% INFO    : Bus 1121	: V=0.9811832, theta=-81.217455 -> V=1.0, theta=0.0
% INFO    : Bus 1122	: V=0.9714177, theta=-82.094857 -> V=1.0, theta=0.0
% INFO    : Bus 1123	: V=0.9659363, theta=-82.673112 -> V=1.0, theta=0.0
% INFO    : Bus 1124	: V=0.9584923, theta=-83.587438 -> V=1.0, theta=0.0
% INFO    : Bus 1125	: V=0.9731901, theta=-81.946003 -> V=1.0, theta=0.0
% INFO    : Bus 1126	: V=0.9605547, theta=-83.428187 -> V=1.0, theta=0.0
% INFO    : Bus 1127	: V=0.9695849, theta=-82.761499 -> V=1.0, theta=0.0
% INFO    : Bus 1128	: V=0.9833506, theta=-81.76665 -> V=1.0, theta=0.0
% INFO    : Bus 1129	: V=0.977795, theta=-82.09136 -> V=1.0, theta=0.0
% INFO    : Bus 1130	: V=0.9735637, theta=-82.314234 -> V=1.0, theta=0.0
% INFO    : Bus 1131	: V=0.9720018, theta=-82.3977 -> V=1.0, theta=0.0
% INFO    : Bus 1132	: V=0.9758116, theta=-82.157829 -> V=1.0, theta=0.0
% INFO    : Bus 1133	: V=0.9738095, theta=-82.251511 -> V=1.0, theta=0.0
% INFO    : Bus 1134	: V=0.9721431, theta=-82.338429 -> V=1.0, theta=0.0
% INFO    : Bus 1135	: V=0.9639529, theta=-82.979868 -> V=1.0, theta=0.0
% INFO    : Bus 1136	: V=0.9783553, theta=-81.340568 -> V=1.0, theta=0.0
% INFO    : Bus 1137	: V=0.9534192, theta=-83.022704 -> V=1.0, theta=0.0
% INFO    : Bus 1138	: V=0.9759809, theta=-81.413504 -> V=1.0, theta=0.0
% INFO    : Bus 1139	: V=0.9755929, theta=-81.510372 -> V=1.0, theta=0.0
% INFO    : Bus 1140	: V=0.9527055, theta=-84.46739 -> V=1.0, theta=0.0
% INFO    : Bus 1141	: V=0.9739087, theta=-81.608548 -> V=1.0, theta=0.0
% INFO    : Bus 1142	: V=0.9517352, theta=-84.422862 -> V=1.0, theta=0.0
% INFO    : Bus 1143	: V=0.9516578, theta=-82.92182 -> V=1.0, theta=0.0
% INFO    : Bus 1144	: V=0.9546519, theta=-82.831335 -> V=1.0, theta=0.0
% INFO    : Bus 1145	: V=0.9599384, theta=-83.412178 -> V=1.0, theta=0.0
% INFO    : Bus 1146	: V=0.9725166, theta=-81.984696 -> V=1.0, theta=0.0
% INFO    : Bus 1147	: V=0.9772025, theta=-81.141478 -> V=1.0, theta=0.0
% INFO    : Bus 1148	: V=0.9791266, theta=-80.903435 -> V=1.0, theta=0.0
% INFO    : Bus 1149	: V=0.9816619, theta=-80.618752 -> V=1.0, theta=0.0
% INFO    : Bus 1150	: V=0.9844674, theta=-80.313292 -> V=1.0, theta=0.0
% INFO    : Bus 1151	: V=0.9792608, theta=-80.857814 -> V=1.0, theta=0.0
% INFO    : Bus 1152	: V=0.9806182, theta=-80.694605 -> V=1.0, theta=0.0
% INFO    : Bus 1153	: V=0.9820243, theta=-80.524175 -> V=1.0, theta=0.0
% INFO    : Bus 1154	: V=0.9840598, theta=-80.316902 -> V=1.0, theta=0.0
% INFO    : Bus 1155	: V=1.0013169, theta=-76.951198 -> V=1.0, theta=0.0
% INFO    : Bus 1156	: V=1.0127355, theta=-75.881289 -> V=1.0, theta=0.0
% INFO    : Bus 1157	: V=1.0219747, theta=-74.978918 -> V=1.0, theta=0.0
% INFO    : Bus 1158	: V=1.0133978, theta=-76.027818 -> V=1.0, theta=0.0
% INFO    : Bus 1159	: V=1.0155621, theta=-78.269045 -> V=1.0, theta=0.0
% INFO    : Bus 1160	: V=1.0096744, theta=-78.264173 -> V=1.0, theta=0.0
% INFO    : Bus 1161	: V=1.0069776, theta=-76.792806 -> V=1.0, theta=0.0
% INFO    : Bus 1162	: V=0.9948329, theta=-76.965496 -> V=1.0, theta=0.0
% INFO    : Bus 1163	: V=1.0046662, theta=-78.197556 -> V=1.0, theta=0.0
% INFO    : Bus 1164	: V=1.0013983, theta=-78.1295 -> V=1.0, theta=0.0
% INFO    : Bus 1165	: V=0.9834208, theta=-79.56303 -> V=1.0, theta=0.0
% INFO    : Bus 1166	: V=0.9766323, theta=-80.012265 -> V=1.0, theta=0.0
% INFO    : Bus 1167	: V=1.0011589, theta=-77.830339 -> V=1.0, theta=0.0
% INFO    : Bus 1168	: V=0.977068, theta=-79.593939 -> V=1.0, theta=0.0
% INFO    : Bus 1169	: V=0.9627594, theta=-81.21026 -> V=1.0, theta=0.0
% INFO    : Bus 1170	: V=0.9414431, theta=-82.35657 -> V=1.0, theta=0.0
% INFO    : Bus 1171	: V=0.9472107, theta=-82.1759 -> V=1.0, theta=0.0
% INFO    : Bus 1172	: V=1.0011289, theta=-79.776986 -> V=1.0, theta=0.0
% INFO    : Bus 1173	: V=1.0024028, theta=-79.680549 -> V=1.0, theta=0.0
% INFO    : Bus 1174	: V=1.0009469, theta=-79.789378 -> V=1.0, theta=0.0
% INFO    : Bus 1175	: V=1.0009234, theta=-79.790985 -> V=1.0, theta=0.0
% INFO    : Bus 1176	: V=0.9956355, theta=-80.52454 -> V=1.0, theta=0.0
% INFO    : Bus 1177	: V=1.0171912, theta=-77.823414 -> V=1.0, theta=0.0
% INFO    : Bus 1178	: V=0.9859257, theta=-81.160056 -> V=1.0, theta=0.0
% INFO    : Bus 1179	: V=0.9962414, theta=-80.33706 -> V=1.0, theta=0.0
% INFO    : Bus 1180	: V=0.9989116, theta=-80.344493 -> V=1.0, theta=0.0
% INFO    : Bus 1181	: V=0.9944896, theta=-80.494265 -> V=1.0, theta=0.0
% INFO    : Bus 1182	: V=0.9957395, theta=-80.379579 -> V=1.0, theta=0.0
% INFO    : Bus 1183	: V=1.0000333, theta=-80.06696 -> V=1.0, theta=0.0
% INFO    : Bus 1184	: V=1.0043833, theta=-79.499501 -> V=1.0, theta=0.0
% INFO    : Bus 1185	: V=0.9939424, theta=-80.887855 -> V=1.0, theta=0.0
% INFO    : Bus 1186	: V=0.9935662, theta=-80.826613 -> V=1.0, theta=0.0
% INFO    : Bus 1187	: V=0.9928147, theta=-80.957279 -> V=1.0, theta=0.0
% INFO    : Bus 1188	: V=0.990439, theta=-81.180322 -> V=1.0, theta=0.0
% INFO    : Bus 1189	: V=1.002761, theta=-79.646568 -> V=1.0, theta=0.0
% INFO    : Bus 1190	: V=0.9887263, theta=-81.305778 -> V=1.0, theta=0.0
% INFO    : Bus 1191	: V=0.9984328, theta=-79.951997 -> V=1.0, theta=0.0
% INFO    : Bus 1192	: V=0.9955295, theta=-80.196614 -> V=1.0, theta=0.0
% INFO    : Bus 1193	: V=0.9892632, theta=-80.680789 -> V=1.0, theta=0.0
% INFO    : Bus 1194	: V=0.9976897, theta=-80.215331 -> V=1.0, theta=0.0
% INFO    : Bus 1195	: V=0.9829341, theta=-81.167744 -> V=1.0, theta=0.0
% INFO    : Bus 1196	: V=0.9612894, theta=-83.070405 -> V=1.0, theta=0.0
% INFO    : Bus 1197	: V=0.9797675, theta=-81.418972 -> V=1.0, theta=0.0
% INFO    : Bus 1198	: V=0.9625639, theta=-82.766589 -> V=1.0, theta=0.0
% INFO    : Bus 1199	: V=0.9745209, theta=-81.783445 -> V=1.0, theta=0.0
% INFO    : Bus 1200	: V=0.9656405, theta=-82.376926 -> V=1.0, theta=0.0
% INFO    : Bus 1201	: V=0.9762887, theta=-81.533702 -> V=1.0, theta=0.0
% INFO    : Bus 1202	: V=0.9773487, theta=-81.519342 -> V=1.0, theta=0.0
% INFO    : Bus 1203	: V=0.9881561, theta=-80.747769 -> V=1.0, theta=0.0
% INFO    : Bus 1204	: V=0.9962293, theta=-80.252947 -> V=1.0, theta=0.0
% INFO    : Bus 1205	: V=0.9987282, theta=-79.79999 -> V=1.0, theta=0.0
% INFO    : Bus 1206	: V=1.0172688, theta=-78.523833 -> V=1.0, theta=0.0
% INFO    : Bus 1207	: V=1.0118437, theta=-77.874652 -> V=1.0, theta=0.0
% INFO    : Bus 1208	: V=1.0112332, theta=-78.529414 -> V=1.0, theta=0.0
% INFO    : Bus 1209	: V=1.0038135, theta=-79.448932 -> V=1.0, theta=0.0
% INFO    : Bus 1210	: V=1.0059582, theta=-79.162015 -> V=1.0, theta=0.0
% INFO    : Bus 1211	: V=1.0137645, theta=-79.305535 -> V=1.0, theta=0.0
% INFO    : Bus 1212	: V=1.0199545, theta=-77.179641 -> V=1.0, theta=0.0
% INFO    : Bus 1213	: V=1.0178643, theta=-77.610392 -> V=1.0, theta=0.0
% INFO    : Bus 1214	: V=1.0001028, theta=-79.822966 -> V=1.0, theta=0.0
% INFO    : Bus 1215	: V=0.9756865, theta=-81.654038 -> V=1.0, theta=0.0
% INFO    : Bus 1216	: V=0.9775977, theta=-81.529325 -> V=1.0, theta=0.0
% INFO    : Bus 1217	: V=1.0044619, theta=-79.452998 -> V=1.0, theta=0.0
% INFO    : Bus 1218	: V=0.9944444, theta=-81.138403 -> V=1.0, theta=0.0
% INFO    : Bus 1219	: V=1.0146385, theta=-79.398308 -> V=1.0, theta=0.0
% INFO    : Bus 1220	: V=0.9825049, theta=-81.799597 -> V=1.0, theta=0.0
% INFO    : Bus 1221	: V=0.9679947, theta=-82.306839 -> V=1.0, theta=0.0
% INFO    : Bus 1222	: V=0.9733072, theta=-82.202409 -> V=1.0, theta=0.0
% INFO    : Bus 1223	: V=0.9806201, theta=-81.172472 -> V=1.0, theta=0.0
% INFO    : Bus 1224	: V=1.0023442, theta=-78.582755 -> V=1.0, theta=0.0
% INFO    : Bus 1225	: V=1.0074261, theta=-78.215225 -> V=1.0, theta=0.0
% INFO    : Bus 1226	: V=0.9466274, theta=-84.357288 -> V=1.0, theta=0.0
% INFO    : Bus 1227	: V=0.9732996, theta=-80.51494 -> V=1.0, theta=0.0
% INFO    : Bus 1228	: V=0.9811553, theta=-80.262799 -> V=1.0, theta=0.0
% INFO    : Bus 1229	: V=0.9851632, theta=-80.136685 -> V=1.0, theta=0.0
% INFO    : Bus 1230	: V=0.9801201, theta=-80.51761 -> V=1.0, theta=0.0
% INFO    : Bus 1231	: V=0.9918798, theta=-79.584142 -> V=1.0, theta=0.0
% INFO    : Bus 1232	: V=0.9916924, theta=-79.591149 -> V=1.0, theta=0.0
% INFO    : Bus 1233	: V=0.9844306, theta=-80.229795 -> V=1.0, theta=0.0
% INFO    : Bus 1234	: V=0.9837137, theta=-80.893634 -> V=1.0, theta=0.0
% INFO    : Bus 1235	: V=0.9761272, theta=-80.996305 -> V=1.0, theta=0.0
% INFO    : Bus 1236	: V=0.9669414, theta=-82.822993 -> V=1.0, theta=0.0
% INFO    : Bus 1237	: V=0.97221, theta=-82.130568 -> V=1.0, theta=0.0
% INFO    : Bus 1238	: V=0.9653298, theta=-82.760358 -> V=1.0, theta=0.0
% INFO    : Bus 1239	: V=0.9699901, theta=-82.467076 -> V=1.0, theta=0.0
% INFO    : Bus 1240	: V=0.9792763, theta=-81.854847 -> V=1.0, theta=0.0
% INFO    : Bus 1241	: V=0.9620423, theta=-82.913327 -> V=1.0, theta=0.0
% INFO    : Bus 1242	: V=0.9726137, theta=-82.463993 -> V=1.0, theta=0.0
% INFO    : Bus 1243	: V=0.9876845, theta=-80.230937 -> V=1.0, theta=0.0
% INFO    : Bus 1244	: V=0.9845918, theta=-80.989331 -> V=1.0, theta=0.0
% INFO    : Bus 1245	: V=0.9856669, theta=-81.097767 -> V=1.0, theta=0.0
% INFO    : Bus 1246	: V=0.9707424, theta=-82.591204 -> V=1.0, theta=0.0
% INFO    : Bus 1247	: V=0.9716492, theta=-82.595595 -> V=1.0, theta=0.0
% INFO    : Bus 1248	: V=0.9835529, theta=-81.783367 -> V=1.0, theta=0.0
% INFO    : Bus 1249	: V=0.9843328, theta=-81.042094 -> V=1.0, theta=0.0
% INFO    : Bus 1250	: V=0.966666, theta=-82.468703 -> V=1.0, theta=0.0
% INFO    : Bus 1251	: V=1.0008357, theta=-80.174628 -> V=1.0, theta=0.0
% INFO    : Bus 1252	: V=1.0162813, theta=-78.256489 -> V=1.0, theta=0.0
% INFO    : Bus 1253	: V=0.9931898, theta=-80.271718 -> V=1.0, theta=0.0
% INFO    : Bus 1254	: V=0.98486, theta=-80.874944 -> V=1.0, theta=0.0
% INFO    : Bus 1255	: V=0.9583186, theta=-82.641684 -> V=1.0, theta=0.0
% INFO    : Bus 1256	: V=0.9751753, theta=-81.800985 -> V=1.0, theta=0.0
% INFO    : Bus 1257	: V=0.9779907, theta=-81.535724 -> V=1.0, theta=0.0
% INFO    : Bus 1258	: V=0.9915062, theta=-80.675593 -> V=1.0, theta=0.0
% INFO    : Bus 1259	: V=1.0111666, theta=-80.761933 -> V=1.0, theta=0.0
% INFO    : Bus 1260	: V=1.0109887, theta=-81.743534 -> V=1.0, theta=0.0
% INFO    : Bus 1261	: V=1.0141376, theta=-80.867228 -> V=1.0, theta=0.0
% INFO    : Bus 1262	: V=1.0044938, theta=-83.096608 -> V=1.0, theta=0.0
% INFO    : Bus 1263	: V=0.9929314, theta=-83.389086 -> V=1.0, theta=0.0
% INFO    : Bus 1264	: V=0.9883764, theta=-83.580875 -> V=1.0, theta=0.0
% INFO    : Bus 1265	: V=1.0050905, theta=-82.989826 -> V=1.0, theta=0.0
% INFO    : Bus 1266	: V=1.0057105, theta=-82.713682 -> V=1.0, theta=0.0
% INFO    : Bus 1267	: V=0.9988298, theta=-83.182375 -> V=1.0, theta=0.0
% INFO    : Bus 1268	: V=1.0045744, theta=-82.996332 -> V=1.0, theta=0.0
% INFO    : Bus 1269	: V=1.007049, theta=-82.30731 -> V=1.0, theta=0.0
% INFO    : Bus 1270	: V=0.9779072, theta=-83.896784 -> V=1.0, theta=0.0
% INFO    : Bus 1271	: V=0.9647329, theta=-84.310074 -> V=1.0, theta=0.0
% INFO    : Bus 1272	: V=0.9754185, theta=-79.741719 -> V=1.0, theta=0.0
% INFO    : Bus 1273	: V=0.992155, theta=-78.78056 -> V=1.0, theta=0.0
% INFO    : Bus 1274	: V=0.9896418, theta=-78.802275 -> V=1.0, theta=0.0
% INFO    : Bus 1275	: V=0.9759078, theta=-80.044187 -> V=1.0, theta=0.0
% INFO    : Bus 1276	: V=0.9803558, theta=-79.899754 -> V=1.0, theta=0.0
% INFO    : Bus 1277	: V=0.9792405, theta=-79.996676 -> V=1.0, theta=0.0
% INFO    : Bus 1278	: V=0.9899844, theta=-79.395794 -> V=1.0, theta=0.0
% INFO    : Bus 1279	: V=0.983769, theta=-79.776228 -> V=1.0, theta=0.0
% INFO    : Bus 1280	: V=0.9625422, theta=-81.437532 -> V=1.0, theta=0.0
% INFO    : Bus 1281	: V=0.9552297, theta=-81.744023 -> V=1.0, theta=0.0
% INFO    : Bus 1282	: V=0.9621589, theta=-81.401237 -> V=1.0, theta=0.0
% INFO    : Bus 1283	: V=0.9691901, theta=-80.854504 -> V=1.0, theta=0.0
% INFO    : Bus 1284	: V=0.9759353, theta=-80.334265 -> V=1.0, theta=0.0
% INFO    : Bus 1285	: V=0.9739846, theta=-79.886717 -> V=1.0, theta=0.0
% INFO    : Bus 1286	: V=0.9902824, theta=-78.620885 -> V=1.0, theta=0.0
% INFO    : Bus 1287	: V=0.9773334, theta=-80.042882 -> V=1.0, theta=0.0
% INFO    : Bus 1288	: V=0.9881136, theta=-78.865238 -> V=1.0, theta=0.0
% INFO    : Bus 1289	: V=0.9877807, theta=-78.804128 -> V=1.0, theta=0.0
% INFO    : Bus 1290	: V=0.9714574, theta=-80.290949 -> V=1.0, theta=0.0
% INFO    : Bus 1291	: V=0.9757121, theta=-79.921991 -> V=1.0, theta=0.0
% INFO    : Bus 1292	: V=0.987654, theta=-78.682654 -> V=1.0, theta=0.0
% INFO    : Bus 1293	: V=0.9727056, theta=-79.78195 -> V=1.0, theta=0.0
% INFO    : Bus 1294	: V=0.9881353, theta=-78.508194 -> V=1.0, theta=0.0
% INFO    : Bus 1295	: V=0.9734736, theta=-79.578359 -> V=1.0, theta=0.0
% INFO    : Bus 1296	: V=0.9658058, theta=-79.981586 -> V=1.0, theta=0.0
% INFO    : Bus 1297	: V=0.9791196, theta=-78.540095 -> V=1.0, theta=0.0
% INFO    : Bus 1298	: V=0.9807442, theta=-78.440873 -> V=1.0, theta=0.0
% INFO    : Bus 1299	: V=0.9658259, theta=-80.048984 -> V=1.0, theta=0.0
% INFO    : Bus 1300	: V=0.9849745, theta=-78.110229 -> V=1.0, theta=0.0
% INFO    : Bus 1301	: V=0.9630448, theta=-80.673733 -> V=1.0, theta=0.0
% INFO    : Bus 1302	: V=0.9696485, theta=-79.747759 -> V=1.0, theta=0.0
% INFO    : Bus 1303	: V=0.9641153, theta=-80.177607 -> V=1.0, theta=0.0
% INFO    : Bus 1304	: V=0.991114, theta=-78.115919 -> V=1.0, theta=0.0
% INFO    : Bus 1305	: V=0.9755039, theta=-79.467989 -> V=1.0, theta=0.0
% INFO    : Bus 1306	: V=0.9831606, theta=-77.886863 -> V=1.0, theta=0.0
% INFO    : Bus 1307	: V=1.0022652, theta=-76.908915 -> V=1.0, theta=0.0
% INFO    : Bus 1308	: V=0.9761906, theta=-78.075157 -> V=1.0, theta=0.0
% INFO    : Bus 1309	: V=1.0116433, theta=-75.517085 -> V=1.0, theta=0.0
% INFO    : Bus 1310	: V=1.0074145, theta=-76.355056 -> V=1.0, theta=0.0
% INFO    : Bus 1311	: V=1.0081933, theta=-75.847049 -> V=1.0, theta=0.0
% INFO    : Bus 1312	: V=0.957296, theta=-77.415586 -> V=1.0, theta=0.0
% INFO    : Bus 1313	: V=0.9489403, theta=-80.612837 -> V=1.0, theta=0.0
% INFO    : Bus 1314	: V=0.9518523, theta=-77.485399 -> V=1.0, theta=0.0
% INFO    : Bus 1315	: V=0.9507209, theta=-80.554843 -> V=1.0, theta=0.0
% INFO    : Bus 1316	: V=0.9521024, theta=-80.517044 -> V=1.0, theta=0.0
% INFO    : Bus 1317	: V=0.9593979, theta=-80.057133 -> V=1.0, theta=0.0
% INFO    : Bus 1318	: V=0.9576954, theta=-80.106421 -> V=1.0, theta=0.0
% INFO    : Bus 1319	: V=0.9562498, theta=-79.144969 -> V=1.0, theta=0.0
% INFO    : Bus 1320	: V=0.9541466, theta=-79.172566 -> V=1.0, theta=0.0
% INFO    : Bus 1321	: V=0.964084, theta=-78.44097 -> V=1.0, theta=0.0
% INFO    : Bus 1322	: V=0.9585291, theta=-78.94181 -> V=1.0, theta=0.0
% INFO    : Bus 1323	: V=0.9796804, theta=-77.042171 -> V=1.0, theta=0.0
% INFO    : Bus 1324	: V=0.9619066, theta=-78.882515 -> V=1.0, theta=0.0
% INFO    : Bus 1325	: V=0.9671336, theta=-78.341979 -> V=1.0, theta=0.0
% INFO    : Bus 1326	: V=0.9675428, theta=-78.423624 -> V=1.0, theta=0.0
% INFO    : Bus 1327	: V=0.9706627, theta=-78.228277 -> V=1.0, theta=0.0
% INFO    : Bus 1328	: V=0.9739069, theta=-78.196093 -> V=1.0, theta=0.0
% INFO    : Bus 1329	: V=0.975989, theta=-77.941712 -> V=1.0, theta=0.0
% INFO    : Bus 1330	: V=0.9777667, theta=-77.729105 -> V=1.0, theta=0.0
% INFO    : Bus 1331	: V=0.9692059, theta=-78.40874 -> V=1.0, theta=0.0
% INFO    : Bus 1332	: V=0.9710484, theta=-78.376066 -> V=1.0, theta=0.0
% INFO    : Bus 1333	: V=0.9846744, theta=-76.718297 -> V=1.0, theta=0.0
% INFO    : Bus 1334	: V=0.9801711, theta=-77.450045 -> V=1.0, theta=0.0
% INFO    : Bus 1335	: V=0.9829808, theta=-77.131528 -> V=1.0, theta=0.0
% INFO    : Bus 1336	: V=0.9800205, theta=-77.15879 -> V=1.0, theta=0.0
% INFO    : Bus 1337	: V=0.9821166, theta=-76.92373 -> V=1.0, theta=0.0
% INFO    : Bus 1338	: V=0.9778121, theta=-77.310762 -> V=1.0, theta=0.0
% INFO    : Bus 1339	: V=0.9778085, theta=-77.357575 -> V=1.0, theta=0.0
% INFO    : Bus 1340	: V=0.9931429, theta=-75.887583 -> V=1.0, theta=0.0
% INFO    : Bus 1341	: V=0.977313, theta=-77.342103 -> V=1.0, theta=0.0
% INFO    : Bus 1342	: V=0.9768318, theta=-77.370165 -> V=1.0, theta=0.0
% INFO    : Bus 1343	: V=0.9785541, theta=-77.282688 -> V=1.0, theta=0.0
% INFO    : Bus 1344	: V=0.9664461, theta=-77.95669 -> V=1.0, theta=0.0
% INFO    : Bus 1345	: V=0.9810715, theta=-77.1541 -> V=1.0, theta=0.0
% INFO    : Bus 1346	: V=0.9698647, theta=-77.902149 -> V=1.0, theta=0.0
% INFO    : Bus 1347	: V=1.0031243, theta=-75.162546 -> V=1.0, theta=0.0
% INFO    : Bus 1348	: V=0.9980688, theta=-75.572926 -> V=1.0, theta=0.0
% INFO    : Bus 1349	: V=0.9945415, theta=-75.817041 -> V=1.0, theta=0.0
% INFO    : Bus 1350	: V=0.9927587, theta=-75.922624 -> V=1.0, theta=0.0
% INFO    : Bus 1351	: V=1.0189366, theta=-72.939464 -> V=1.0, theta=0.0
% INFO    : Bus 1352	: V=1.0026967, theta=-75.363674 -> V=1.0, theta=0.0
% INFO    : Bus 1353	: V=0.9911153, theta=-76.617211 -> V=1.0, theta=0.0
% INFO    : Bus 1354	: V=0.9871941, theta=-76.77835 -> V=1.0, theta=0.0
% INFO    : Bus 1355	: V=0.9953768, theta=-75.763147 -> V=1.0, theta=0.0
% INFO    : Bus 1356	: V=0.9546452, theta=-78.974434 -> V=1.0, theta=0.0
% INFO    : Bus 1357	: V=0.9570467, theta=-78.929262 -> V=1.0, theta=0.0
% INFO    : Bus 1358	: V=0.9829519, theta=-76.547988 -> V=1.0, theta=0.0
% INFO    : Bus 1359	: V=0.9821053, theta=-76.608266 -> V=1.0, theta=0.0
% INFO    : Bus 1360	: V=0.9815253, theta=-76.652957 -> V=1.0, theta=0.0
% INFO    : Bus 1361	: V=0.9811683, theta=-76.683361 -> V=1.0, theta=0.0
% INFO    : Bus 1362	: V=0.9810235, theta=-76.825908 -> V=1.0, theta=0.0
% INFO    : Bus 1363	: V=0.9779135, theta=-77.019833 -> V=1.0, theta=0.0
% INFO    : Bus 1364	: V=0.9759768, theta=-77.032506 -> V=1.0, theta=0.0
% INFO    : Bus 1365	: V=0.9847426, theta=-76.426621 -> V=1.0, theta=0.0
% INFO    : Bus 1366	: V=0.9728339, theta=-77.704105 -> V=1.0, theta=0.0
% INFO    : Bus 1367	: V=1.0124775, theta=-73.569137 -> V=1.0, theta=0.0
% INFO    : Bus 1368	: V=0.9952221, theta=-68.968028 -> V=1.0, theta=0.0
% INFO    : Bus 1369	: V=0.9946467, theta=-69.021776 -> V=1.0, theta=0.0
% INFO    : Bus 1370	: V=0.9942176, theta=-69.075306 -> V=1.0, theta=0.0
% INFO    : Bus 1371	: V=0.9905758, theta=-70.323337 -> V=1.0, theta=0.0
% INFO    : Bus 1372	: V=0.9797213, theta=-70.53509 -> V=1.0, theta=0.0
% INFO    : Bus 1373	: V=0.9830108, theta=-70.304487 -> V=1.0, theta=0.0
% INFO    : Bus 1374	: V=0.9802433, theta=-70.389283 -> V=1.0, theta=0.0
% INFO    : Bus 1375	: V=0.9946908, theta=-68.811595 -> V=1.0, theta=0.0
% INFO    : Bus 1376	: V=0.9824344, theta=-70.368983 -> V=1.0, theta=0.0
% INFO    : Bus 1377	: V=0.9897118, theta=-70.404192 -> V=1.0, theta=0.0
% INFO    : Bus 1378	: V=0.9879495, theta=-70.687711 -> V=1.0, theta=0.0
% INFO    : Bus 1379	: V=0.987, theta=-70.79237 -> V=1.0, theta=0.0
% INFO    : Bus 1380	: V=0.994557, theta=-68.491697 -> V=1.0, theta=0.0
% INFO    : Bus 1381	: V=0.9793951, theta=-72.956965 -> V=1.0, theta=0.0
% INFO    : Bus 1382	: V=0.9849533, theta=-71.815497 -> V=1.0, theta=0.0
% INFO    : Bus 1383	: V=0.9711567, theta=-73.131035 -> V=1.0, theta=0.0
% INFO    : Bus 1384	: V=0.9912512, theta=-71.432822 -> V=1.0, theta=0.0
% INFO    : Bus 1385	: V=0.9828945, theta=-71.740226 -> V=1.0, theta=0.0
% INFO    : Bus 1386	: V=0.9867256, theta=-71.69412 -> V=1.0, theta=0.0
% INFO    : Bus 1387	: V=0.9837228, theta=-71.50011 -> V=1.0, theta=0.0
% INFO    : Bus 1388	: V=0.9839495, theta=-71.563797 -> V=1.0, theta=0.0
% INFO    : Bus 1389	: V=0.9837856, theta=-71.442155 -> V=1.0, theta=0.0
% INFO    : Bus 1390	: V=0.9853233, theta=-71.084453 -> V=1.0, theta=0.0
% INFO    : Bus 1391	: V=0.9657802, theta=-74.57051 -> V=1.0, theta=0.0
% INFO    : Bus 1392	: V=0.9555662, theta=-76.172443 -> V=1.0, theta=0.0
% INFO    : Bus 1393	: V=0.9471686, theta=-76.933864 -> V=1.0, theta=0.0
% INFO    : Bus 1394	: V=0.9845768, theta=-71.748934 -> V=1.0, theta=0.0
% INFO    : Bus 1395	: V=0.996124, theta=-71.229881 -> V=1.0, theta=0.0
% INFO    : Bus 1396	: V=0.9815265, theta=-70.878111 -> V=1.0, theta=0.0
% INFO    : Bus 1397	: V=0.9844299, theta=-70.848665 -> V=1.0, theta=0.0
% INFO    : Bus 1398	: V=0.9833219, theta=-70.85353 -> V=1.0, theta=0.0
% INFO    : Bus 1399	: V=0.9604507, theta=-76.725489 -> V=1.0, theta=0.0
% INFO    : Bus 1400	: V=0.9514289, theta=-77.062202 -> V=1.0, theta=0.0
% INFO    : Bus 1401	: V=0.9620647, theta=-76.669095 -> V=1.0, theta=0.0
% INFO    : Bus 1402	: V=0.9648768, theta=-74.585549 -> V=1.0, theta=0.0
% INFO    : Bus 1403	: V=0.9521051, theta=-76.273439 -> V=1.0, theta=0.0
% INFO    : Bus 1404	: V=0.9775021, theta=-70.566267 -> V=1.0, theta=0.0
% INFO    : Bus 1405	: V=0.9915853, theta=-70.225294 -> V=1.0, theta=0.0
% INFO    : Bus 1406	: V=0.988841, theta=-71.563913 -> V=1.0, theta=0.0
% INFO    : Bus 1407	: V=0.9693414, theta=-79.600309 -> V=1.0, theta=0.0
% INFO    : Bus 1408	: V=0.9964886, theta=-76.903888 -> V=1.0, theta=0.0
% INFO    : Bus 1409	: V=0.9834971, theta=-78.005 -> V=1.0, theta=0.0
% INFO    : Bus 1410	: V=0.9898958, theta=-77.788458 -> V=1.0, theta=0.0
% INFO    : Bus 1411	: V=0.9901767, theta=-77.314761 -> V=1.0, theta=0.0
% INFO    : Bus 1412	: V=0.9914456, theta=-77.251508 -> V=1.0, theta=0.0
% INFO    : Bus 1413	: V=0.9934261, theta=-77.296372 -> V=1.0, theta=0.0
% INFO    : Bus 1414	: V=0.9918962, theta=-77.455049 -> V=1.0, theta=0.0
% INFO    : Bus 1415	: V=0.9971532, theta=-76.980512 -> V=1.0, theta=0.0
% INFO    : Bus 1416	: V=1.0086695, theta=-76.315561 -> V=1.0, theta=0.0
% INFO    : Bus 1417	: V=0.9900255, theta=-78.283553 -> V=1.0, theta=0.0
% INFO    : Bus 1418	: V=0.9946382, theta=-77.1165 -> V=1.0, theta=0.0
% INFO    : Bus 1419	: V=0.9991396, theta=-76.735013 -> V=1.0, theta=0.0
% INFO    : Bus 1420	: V=1.0038654, theta=-76.562414 -> V=1.0, theta=0.0
% INFO    : Bus 1421	: V=1.0112648, theta=-75.110541 -> V=1.0, theta=0.0
% INFO    : Bus 1422	: V=1.0113913, theta=-76.166576 -> V=1.0, theta=0.0
% INFO    : Bus 1423	: V=1.0132814, theta=-76.059529 -> V=1.0, theta=0.0
% INFO    : Bus 1424	: V=0.996333, theta=-77.648462 -> V=1.0, theta=0.0
% INFO    : Bus 1425	: V=1.0115091, theta=-76.15145 -> V=1.0, theta=0.0
% INFO    : Bus 1426	: V=0.9955071, theta=-77.766781 -> V=1.0, theta=0.0
% INFO    : Bus 1427	: V=1.0069989, theta=-76.902702 -> V=1.0, theta=0.0
% INFO    : Bus 1428	: V=1.0157185, theta=-75.901267 -> V=1.0, theta=0.0
% INFO    : Bus 1429	: V=0.9944925, theta=-77.804538 -> V=1.0, theta=0.0
% INFO    : Bus 1430	: V=1.0029267, theta=-76.940505 -> V=1.0, theta=0.0
% INFO    : Bus 1431	: V=0.9981111, theta=-77.052973 -> V=1.0, theta=0.0
% INFO    : Bus 1432	: V=1.0099627, theta=-76.414521 -> V=1.0, theta=0.0
% INFO    : Bus 1433	: V=1.007379, theta=-76.418947 -> V=1.0, theta=0.0
% INFO    : Bus 1434	: V=1.0016189, theta=-75.607589 -> V=1.0, theta=0.0
% INFO    : Bus 1435	: V=0.9861255, theta=-76.81922 -> V=1.0, theta=0.0
% INFO    : Bus 1436	: V=0.9837332, theta=-77.685457 -> V=1.0, theta=0.0
% INFO    : Bus 1437	: V=0.990443, theta=-76.963305 -> V=1.0, theta=0.0
% INFO    : Bus 1438	: V=0.9797826, theta=-78.010786 -> V=1.0, theta=0.0
% INFO    : Bus 1439	: V=0.9922901, theta=-76.871213 -> V=1.0, theta=0.0
% INFO    : Bus 1440	: V=0.9936261, theta=-76.807857 -> V=1.0, theta=0.0
% INFO    : Bus 1441	: V=0.9962956, theta=-76.83308 -> V=1.0, theta=0.0
% INFO    : Bus 1442	: V=0.9961532, theta=-76.669048 -> V=1.0, theta=0.0
% INFO    : Bus 1443	: V=0.9833853, theta=-78.138769 -> V=1.0, theta=0.0
% INFO    : Bus 1444	: V=0.9977138, theta=-76.976796 -> V=1.0, theta=0.0
% INFO    : Bus 1445	: V=0.9872358, theta=-77.88668 -> V=1.0, theta=0.0
% INFO    : Bus 1446	: V=0.9859191, theta=-78.014642 -> V=1.0, theta=0.0
% INFO    : Bus 1447	: V=0.9989363, theta=-76.920908 -> V=1.0, theta=0.0
% INFO    : Bus 1448	: V=0.9974447, theta=-76.501183 -> V=1.0, theta=0.0
% INFO    : Bus 1449	: V=0.9881301, theta=-78.175021 -> V=1.0, theta=0.0
% INFO    : Bus 1450	: V=1.0032534, theta=-76.982276 -> V=1.0, theta=0.0
% INFO    : Bus 1451	: V=0.9999956, theta=-76.206152 -> V=1.0, theta=0.0
% INFO    : Bus 1452	: V=1.0044756, theta=-75.708503 -> V=1.0, theta=0.0
% INFO    : Bus 1453	: V=1.0041321, theta=-75.049739 -> V=1.0, theta=0.0
% INFO    : Bus 1454	: V=1.0057792, theta=-74.94206 -> V=1.0, theta=0.0
% INFO    : Bus 1455	: V=1.0003507, theta=-75.463623 -> V=1.0, theta=0.0
% INFO    : Bus 1456	: V=1.0055637, theta=-74.966211 -> V=1.0, theta=0.0
% INFO    : Bus 1457	: V=1.0054307, theta=-74.98256 -> V=1.0, theta=0.0
% INFO    : Bus 1458	: V=0.9972127, theta=-75.610179 -> V=1.0, theta=0.0
% INFO    : Bus 1459	: V=0.9930283, theta=-76.053377 -> V=1.0, theta=0.0
% INFO    : Bus 1460	: V=0.9934087, theta=-76.048703 -> V=1.0, theta=0.0
% INFO    : Bus 1461	: V=0.984077, theta=-77.437486 -> V=1.0, theta=0.0
% INFO    : Bus 1462	: V=1.0054937, theta=-74.987261 -> V=1.0, theta=0.0
% INFO    : Bus 1463	: V=0.9841292, theta=-77.438922 -> V=1.0, theta=0.0
% INFO    : Bus 1464	: V=1.0048602, theta=-75.019569 -> V=1.0, theta=0.0
% INFO    : Bus 1465	: V=0.9910379, theta=-76.212252 -> V=1.0, theta=0.0
% INFO    : Bus 1466	: V=0.9916569, theta=-76.160066 -> V=1.0, theta=0.0
% INFO    : Bus 1467	: V=0.9910666, theta=-76.16659 -> V=1.0, theta=0.0
% INFO    : Bus 1468	: V=0.9909152, theta=-76.168507 -> V=1.0, theta=0.0
% INFO    : Bus 1469	: V=0.9896301, theta=-76.294624 -> V=1.0, theta=0.0
% INFO    : Bus 1470	: V=0.9868332, theta=-76.860191 -> V=1.0, theta=0.0
% INFO    : Bus 1471	: V=0.9869693, theta=-76.858493 -> V=1.0, theta=0.0
% INFO    : Bus 1472	: V=1.0048658, theta=-75.019061 -> V=1.0, theta=0.0
% INFO    : Bus 1473	: V=0.9898949, theta=-76.689365 -> V=1.0, theta=0.0
% INFO    : Bus 1474	: V=0.9839976, theta=-77.023786 -> V=1.0, theta=0.0
% INFO    : Bus 1475	: V=0.9832137, theta=-77.047829 -> V=1.0, theta=0.0
% INFO    : Bus 1476	: V=0.9827561, theta=-77.052635 -> V=1.0, theta=0.0
% INFO    : Bus 1477	: V=1.016535, theta=-73.269693 -> V=1.0, theta=0.0
% INFO    : Bus 1478	: V=0.9879376, theta=-76.800492 -> V=1.0, theta=0.0
% INFO    : Bus 1479	: V=0.9854022, theta=-76.835936 -> V=1.0, theta=0.0
% INFO    : Bus 1480	: V=1.0085125, theta=-74.952972 -> V=1.0, theta=0.0
% INFO    : Bus 1481	: V=1.0090045, theta=-74.702909 -> V=1.0, theta=0.0
% INFO    : Bus 1482	: V=1.0094374, theta=-75.232365 -> V=1.0, theta=0.0
% INFO    : Bus 1483	: V=1.0036623, theta=-75.035661 -> V=1.0, theta=0.0
% INFO    : Bus 1484	: V=1.000851, theta=-75.348469 -> V=1.0, theta=0.0
% INFO    : Bus 1485	: V=0.9994261, theta=-75.414906 -> V=1.0, theta=0.0
% INFO    : Bus 1486	: V=0.991879, theta=-76.095952 -> V=1.0, theta=0.0
% INFO    : Bus 1487	: V=0.9790553, theta=-77.717689 -> V=1.0, theta=0.0
% INFO    : Bus 1488	: V=0.9796954, theta=-77.684207 -> V=1.0, theta=0.0
% INFO    : Bus 1489	: V=0.9955496, theta=-76.007795 -> V=1.0, theta=0.0
% INFO    : Bus 1490	: V=0.9773732, theta=-77.832089 -> V=1.0, theta=0.0
% INFO    : Bus 1491	: V=0.9942358, theta=-76.125836 -> V=1.0, theta=0.0
% INFO    : Bus 1492	: V=0.9936596, theta=-76.154903 -> V=1.0, theta=0.0
% INFO    : Bus 1493	: V=0.976908, theta=-77.836713 -> V=1.0, theta=0.0
% INFO    : Bus 1494	: V=0.9791129, theta=-77.568423 -> V=1.0, theta=0.0
% INFO    : Bus 1495	: V=0.9787644, theta=-77.576077 -> V=1.0, theta=0.0
% INFO    : Bus 1496	: V=0.9782733, theta=-77.58156 -> V=1.0, theta=0.0
% INFO    : Bus 1497	: V=0.9777003, theta=-77.590744 -> V=1.0, theta=0.0
% INFO    : Bus 1498	: V=0.9792772, theta=-77.514793 -> V=1.0, theta=0.0
% INFO    : Bus 1499	: V=0.9814486, theta=-77.450688 -> V=1.0, theta=0.0
% INFO    : Bus 1500	: V=0.9787794, theta=-77.528239 -> V=1.0, theta=0.0
% INFO    : Bus 1501	: V=0.9788585, theta=-77.563558 -> V=1.0, theta=0.0
% INFO    : Bus 1502	: V=0.9793219, theta=-77.522032 -> V=1.0, theta=0.0
% INFO    : Bus 1503	: V=0.9796842, theta=-77.513624 -> V=1.0, theta=0.0
% INFO    : Bus 1504	: V=0.9803686, theta=-77.495692 -> V=1.0, theta=0.0
% INFO    : Bus 1505	: V=0.9799252, theta=-77.477404 -> V=1.0, theta=0.0
% INFO    : Bus 1506	: V=0.9796283, theta=-77.494743 -> V=1.0, theta=0.0
% INFO    : Bus 1507	: V=0.9798088, theta=-77.495698 -> V=1.0, theta=0.0
% INFO    : Bus 1508	: V=0.9909553, theta=-76.165804 -> V=1.0, theta=0.0
% INFO    : Bus 1509	: V=0.9806464, theta=-77.406341 -> V=1.0, theta=0.0
% INFO    : Bus 1510	: V=0.9804107, theta=-77.413336 -> V=1.0, theta=0.0
% INFO    : Bus 1511	: V=0.9801912, theta=-77.437752 -> V=1.0, theta=0.0
% INFO    : Bus 1512	: V=0.9803454, theta=-77.421596 -> V=1.0, theta=0.0
% INFO    : Bus 1513	: V=0.9801577, theta=-77.436598 -> V=1.0, theta=0.0
% INFO    : Bus 1514	: V=0.9801094, theta=-77.439707 -> V=1.0, theta=0.0
% INFO    : Bus 1515	: V=0.9803412, theta=-77.43463 -> V=1.0, theta=0.0
% INFO    : Bus 1516	: V=0.9799914, theta=-77.451466 -> V=1.0, theta=0.0
% INFO    : Bus 1517	: V=0.9792362, theta=-77.48799 -> V=1.0, theta=0.0
% INFO    : Bus 1518	: V=0.9962489, theta=-75.718856 -> V=1.0, theta=0.0
% INFO    : Bus 1519	: V=0.9895251, theta=-76.907074 -> V=1.0, theta=0.0
% INFO    : Bus 1520	: V=0.9808631, theta=-77.378709 -> V=1.0, theta=0.0
% INFO    : Bus 1521	: V=0.9835123, theta=-77.158145 -> V=1.0, theta=0.0
% INFO    : Bus 1522	: V=0.9784234, theta=-77.4176 -> V=1.0, theta=0.0
% INFO    : Bus 1523	: V=0.9820903, theta=-76.932455 -> V=1.0, theta=0.0
% INFO    : Bus 1524	: V=0.9787057, theta=-77.728318 -> V=1.0, theta=0.0
% INFO    : Bus 1525	: V=0.9782261, theta=-77.771745 -> V=1.0, theta=0.0
% INFO    : Bus 1526	: V=0.9917991, theta=-76.136463 -> V=1.0, theta=0.0
% INFO    : Bus 1527	: V=0.9808176, theta=-77.471325 -> V=1.0, theta=0.0
% INFO    : Bus 1528	: V=0.9918488, theta=-76.132841 -> V=1.0, theta=0.0
% INFO    : Bus 1529	: V=0.9779973, theta=-77.537513 -> V=1.0, theta=0.0
% INFO    : Bus 1530	: V=0.9863742, theta=-76.878856 -> V=1.0, theta=0.0
% INFO    : Bus 1531	: V=0.9710693, theta=-79.541103 -> V=1.0, theta=0.0
% INFO    : Bus 1532	: V=0.975393, theta=-77.190071 -> V=1.0, theta=0.0
% INFO    : Bus 1533	: V=0.95853, theta=-79.323462 -> V=1.0, theta=0.0
% INFO    : Bus 1534	: V=0.9523021, theta=-79.503918 -> V=1.0, theta=0.0
% INFO    : Bus 1535	: V=0.9546835, theta=-79.271678 -> V=1.0, theta=0.0
% INFO    : Bus 1536	: V=0.9884544, theta=-79.25578 -> V=1.0, theta=0.0
% INFO    : Bus 1537	: V=0.9673327, theta=-81.236791 -> V=1.0, theta=0.0
% INFO    : Bus 1538	: V=0.9677532, theta=-81.232165 -> V=1.0, theta=0.0
% INFO    : Bus 1539	: V=0.9659299, theta=-81.253824 -> V=1.0, theta=0.0
% INFO    : Bus 1540	: V=0.965776, theta=-81.122058 -> V=1.0, theta=0.0
% INFO    : Bus 1541	: V=0.9636598, theta=-81.24509 -> V=1.0, theta=0.0
% INFO    : Bus 1542	: V=0.9626813, theta=-81.280709 -> V=1.0, theta=0.0
% INFO    : Bus 1543	: V=0.9620386, theta=-81.286621 -> V=1.0, theta=0.0
% INFO    : Bus 1544	: V=0.9657644, theta=-81.076899 -> V=1.0, theta=0.0
% INFO    : Bus 1545	: V=0.981228, theta=-79.608485 -> V=1.0, theta=0.0
% INFO    : Bus 1546	: V=0.9646957, theta=-81.087265 -> V=1.0, theta=0.0
% INFO    : Bus 1547	: V=0.964889, theta=-81.092247 -> V=1.0, theta=0.0
% INFO    : Bus 1548	: V=0.9636906, theta=-81.109741 -> V=1.0, theta=0.0
% INFO    : Bus 1549	: V=0.9647448, theta=-81.081252 -> V=1.0, theta=0.0
% INFO    : Bus 1550	: V=0.9653555, theta=-81.011028 -> V=1.0, theta=0.0
% INFO    : Bus 1551	: V=0.9828102, theta=-79.516021 -> V=1.0, theta=0.0
% INFO    : Bus 1552	: V=0.9632898, theta=-81.072364 -> V=1.0, theta=0.0
% INFO    : Bus 1553	: V=0.9698719, theta=-81.081293 -> V=1.0, theta=0.0
% INFO    : Bus 1554	: V=0.9864007, theta=-79.240661 -> V=1.0, theta=0.0
% INFO    : Bus 1555	: V=0.9853544, theta=-79.279385 -> V=1.0, theta=0.0
% INFO    : Bus 1556	: V=0.975329, theta=-80.27968 -> V=1.0, theta=0.0
% INFO    : Bus 1557	: V=0.9877682, theta=-79.40167 -> V=1.0, theta=0.0
% INFO    : Bus 1558	: V=0.987624, theta=-79.378868 -> V=1.0, theta=0.0
% INFO    : Bus 1559	: V=0.988024, theta=-79.374171 -> V=1.0, theta=0.0
% INFO    : Bus 1560	: V=0.9940191, theta=-78.779853 -> V=1.0, theta=0.0
% INFO    : Bus 1561	: V=0.9926792, theta=-78.872048 -> V=1.0, theta=0.0
% INFO    : Bus 1562	: V=0.9920446, theta=-78.911361 -> V=1.0, theta=0.0
% INFO    : Bus 1563	: V=0.9913879, theta=-78.953061 -> V=1.0, theta=0.0
% INFO    : Bus 1564	: V=0.9797095, theta=-80.083558 -> V=1.0, theta=0.0
% INFO    : Bus 1565	: V=0.9796017, theta=-80.084769 -> V=1.0, theta=0.0
% INFO    : Bus 1566	: V=0.978097, theta=-80.163734 -> V=1.0, theta=0.0
% INFO    : Bus 1567	: V=0.9787246, theta=-80.16042 -> V=1.0, theta=0.0
% INFO    : Bus 1568	: V=0.9781886, theta=-80.167056 -> V=1.0, theta=0.0
% INFO    : Bus 1569	: V=0.9825442, theta=-79.878079 -> V=1.0, theta=0.0
% INFO    : Bus 1570	: V=0.9883939, theta=-79.127731 -> V=1.0, theta=0.0
% INFO    : Bus 1571	: V=0.9828852, theta=-79.874571 -> V=1.0, theta=0.0
% INFO    : Bus 1572	: V=0.990788, theta=-78.989473 -> V=1.0, theta=0.0
% INFO    : Bus 1573	: V=0.9882527, theta=-79.360703 -> V=1.0, theta=0.0
% INFO    : Bus 1574	: V=0.9898097, theta=-79.047255 -> V=1.0, theta=0.0
% INFO    : Bus 1575	: V=0.9853212, theta=-79.489772 -> V=1.0, theta=0.0
% INFO    : Bus 1576	: V=0.996253, theta=-78.59488 -> V=1.0, theta=0.0
% INFO    : Bus 1577	: V=0.9863376, theta=-79.47789 -> V=1.0, theta=0.0
% INFO    : Bus 1578	: V=0.9776108, theta=-80.216541 -> V=1.0, theta=0.0
% INFO    : Bus 1579	: V=0.9912832, theta=-78.783962 -> V=1.0, theta=0.0
% INFO    : Bus 1580	: V=0.9753378, theta=-80.345088 -> V=1.0, theta=0.0
% INFO    : Bus 1581	: V=0.9586755, theta=-81.01538 -> V=1.0, theta=0.0
% INFO    : Bus 1582	: V=0.9625036, theta=-80.971278 -> V=1.0, theta=0.0
% INFO    : Bus 1583	: V=0.973287, theta=-80.438491 -> V=1.0, theta=0.0
% INFO    : Bus 1584	: V=0.9831837, theta=-79.327482 -> V=1.0, theta=0.0
% INFO    : Bus 1585	: V=0.9649303, theta=-80.923589 -> V=1.0, theta=0.0
% INFO    : Bus 1586	: V=0.9837152, theta=-79.332904 -> V=1.0, theta=0.0
% INFO    : Bus 1587	: V=0.9655582, theta=-80.925226 -> V=1.0, theta=0.0
% INFO    : Bus 1588	: V=0.9637704, theta=-81.020329 -> V=1.0, theta=0.0
% INFO    : Bus 1589	: V=0.9643816, theta=-80.967965 -> V=1.0, theta=0.0
% INFO    : Bus 1590	: V=0.9657888, theta=-80.886588 -> V=1.0, theta=0.0
% INFO    : Bus 1591	: V=0.9700736, theta=-80.246523 -> V=1.0, theta=0.0
% INFO    : Bus 1592	: V=0.9811379, theta=-79.408869 -> V=1.0, theta=0.0
% INFO    : Bus 1593	: V=0.9832499, theta=-78.496208 -> V=1.0, theta=0.0
% INFO    : Bus 1594	: V=0.9676516, theta=-80.215705 -> V=1.0, theta=0.0
% INFO    : Bus 1595	: V=0.9690295, theta=-80.279189 -> V=1.0, theta=0.0
% INFO    : Bus 1596	: V=0.9672335, theta=-80.011673 -> V=1.0, theta=0.0
% INFO    : Bus 1597	: V=0.9822903, theta=-77.939895 -> V=1.0, theta=0.0
% INFO    : Bus 1598	: V=0.9881175, theta=-78.158663 -> V=1.0, theta=0.0
% INFO    : Bus 1599	: V=0.9674671, theta=-80.201528 -> V=1.0, theta=0.0
% INFO    : Bus 1600	: V=0.9890714, theta=-78.077017 -> V=1.0, theta=0.0
% INFO    : Bus 1601	: V=0.985178, theta=-78.345408 -> V=1.0, theta=0.0
% INFO    : Bus 1602	: V=0.9832187, theta=-78.478156 -> V=1.0, theta=0.0
% INFO    : Bus 1603	: V=0.9694581, theta=-80.204264 -> V=1.0, theta=0.0
% INFO    : Bus 1604	: V=0.9697258, theta=-80.161297 -> V=1.0, theta=0.0
% INFO    : Bus 1605	: V=0.9742478, theta=-79.419597 -> V=1.0, theta=0.0
% INFO    : Bus 1606	: V=0.9682851, theta=-80.214814 -> V=1.0, theta=0.0
% INFO    : Bus 1607	: V=0.9671464, theta=-80.231311 -> V=1.0, theta=0.0
% INFO    : Bus 1608	: V=0.9656512, theta=-80.39591 -> V=1.0, theta=0.0
% INFO    : Bus 1609	: V=0.9588505, theta=-80.501118 -> V=1.0, theta=0.0
% INFO    : Bus 1610	: V=0.9589156, theta=-80.654775 -> V=1.0, theta=0.0
% INFO    : Bus 1611	: V=0.957512, theta=-80.675607 -> V=1.0, theta=0.0
% INFO    : Bus 1612	: V=0.9581933, theta=-80.595925 -> V=1.0, theta=0.0
% INFO    : Bus 1613	: V=0.9728137, theta=-79.205636 -> V=1.0, theta=0.0
% INFO    : Bus 1614	: V=0.961886, theta=-80.465999 -> V=1.0, theta=0.0
% INFO    : Bus 1615	: V=0.9719829, theta=-79.276273 -> V=1.0, theta=0.0
% INFO    : Bus 1616	: V=0.9603381, theta=-80.571055 -> V=1.0, theta=0.0
% INFO    : Bus 1617	: V=0.9611409, theta=-80.548457 -> V=1.0, theta=0.0
% INFO    : Bus 1618	: V=0.9603965, theta=-80.559634 -> V=1.0, theta=0.0
% INFO    : Bus 1619	: V=0.9592336, theta=-80.520782 -> V=1.0, theta=0.0
% INFO    : Bus 1620	: V=0.9586969, theta=-80.581593 -> V=1.0, theta=0.0
% INFO    : Bus 1621	: V=0.9792547, theta=-78.520982 -> V=1.0, theta=0.0
% INFO    : Bus 1622	: V=0.9833721, theta=-78.491239 -> V=1.0, theta=0.0
% INFO    : Bus 1623	: V=0.984862, theta=-78.475904 -> V=1.0, theta=0.0
% INFO    : Bus 1624	: V=1.0084098, theta=-75.927091 -> V=1.0, theta=0.0
% INFO    : Bus 1625	: V=0.9803504, theta=-78.135992 -> V=1.0, theta=0.0
% INFO    : Bus 1626	: V=0.9807289, theta=-77.998319 -> V=1.0, theta=0.0
% INFO    : Bus 1627	: V=0.9809469, theta=-77.983683 -> V=1.0, theta=0.0
% INFO    : Bus 1628	: V=0.9812078, theta=-77.965792 -> V=1.0, theta=0.0
% INFO    : Bus 1629	: V=0.9754854, theta=-78.63038 -> V=1.0, theta=0.0
% INFO    : Bus 1630	: V=0.9758666, theta=-78.624629 -> V=1.0, theta=0.0
% INFO    : Bus 1631	: V=0.9812618, theta=-78.073079 -> V=1.0, theta=0.0
% INFO    : Bus 1632	: V=0.9822773, theta=-78.002414 -> V=1.0, theta=0.0
% INFO    : Bus 1633	: V=0.9764387, theta=-78.602286 -> V=1.0, theta=0.0
% INFO    : Bus 1634	: V=0.9808493, theta=-78.101121 -> V=1.0, theta=0.0
% INFO    : Bus 1635	: V=0.975244, theta=-78.620221 -> V=1.0, theta=0.0
% INFO    : Bus 1636	: V=0.975034, theta=-78.622949 -> V=1.0, theta=0.0
% INFO    : Bus 1637	: V=0.9797843, theta=-78.172394 -> V=1.0, theta=0.0
% INFO    : Bus 1638	: V=0.9731901, theta=-79.01588 -> V=1.0, theta=0.0
% INFO    : Bus 1639	: V=0.9732081, theta=-79.029602 -> V=1.0, theta=0.0
% INFO    : Bus 1640	: V=0.9770525, theta=-78.628754 -> V=1.0, theta=0.0
% INFO    : Bus 1641	: V=0.9835041, theta=-77.789267 -> V=1.0, theta=0.0
% INFO    : Bus 1642	: V=0.982736, theta=-77.705765 -> V=1.0, theta=0.0
% INFO    : Bus 1643	: V=0.9732713, theta=-78.992536 -> V=1.0, theta=0.0
% INFO    : Bus 1644	: V=0.9685842, theta=-79.16432 -> V=1.0, theta=0.0
% INFO    : Bus 1645	: V=0.9688643, theta=-79.156603 -> V=1.0, theta=0.0
% INFO    : Bus 1646	: V=0.9593242, theta=-79.729438 -> V=1.0, theta=0.0
% INFO    : Bus 1647	: V=0.9794102, theta=-78.012797 -> V=1.0, theta=0.0
% INFO    : Bus 1648	: V=0.9816022, theta=-77.939897 -> V=1.0, theta=0.0
% INFO    : Bus 1649	: V=0.9732799, theta=-78.806069 -> V=1.0, theta=0.0
% INFO    : Bus 1650	: V=0.982833, theta=-77.859216 -> V=1.0, theta=0.0
% INFO    : Bus 1651	: V=0.9858744, theta=-77.704503 -> V=1.0, theta=0.0
% INFO    : Bus 1652	: V=0.9858268, theta=-77.955154 -> V=1.0, theta=0.0
% INFO    : Bus 1653	: V=0.9850381, theta=-77.964777 -> V=1.0, theta=0.0
% INFO    : Bus 1654	: V=0.9851389, theta=-77.666845 -> V=1.0, theta=0.0
% INFO    : Bus 1655	: V=0.9998511, theta=-75.666503 -> V=1.0, theta=0.0
% INFO    : Bus 1656	: V=0.9764785, theta=-78.61666 -> V=1.0, theta=0.0
% INFO    : Bus 1657	: V=0.9780032, theta=-78.732918 -> V=1.0, theta=0.0
% INFO    : Bus 1658	: V=0.9717128, theta=-79.398394 -> V=1.0, theta=0.0
% INFO    : Bus 1659	: V=0.9746834, theta=-79.116613 -> V=1.0, theta=0.0
% INFO    : Bus 1660	: V=0.9821124, theta=-77.876668 -> V=1.0, theta=0.0
% INFO    : Bus 1661	: V=0.9715554, theta=-79.139164 -> V=1.0, theta=0.0
% INFO    : Bus 1662	: V=0.9663965, theta=-79.728988 -> V=1.0, theta=0.0
% INFO    : Bus 1663	: V=0.9695403, theta=-79.433944 -> V=1.0, theta=0.0
% INFO    : Bus 1664	: V=0.9697407, theta=-79.398679 -> V=1.0, theta=0.0
% INFO    : Bus 1665	: V=1.0000768, theta=-75.52857 -> V=1.0, theta=0.0
% INFO    : Bus 1666	: V=0.9675153, theta=-79.655401 -> V=1.0, theta=0.0
% INFO    : Bus 1667	: V=0.9879573, theta=-77.405964 -> V=1.0, theta=0.0
% INFO    : Bus 1668	: V=0.9820483, theta=-78.091001 -> V=1.0, theta=0.0
% INFO    : Bus 1669	: V=0.9802185, theta=-78.216673 -> V=1.0, theta=0.0
% INFO    : Bus 1670	: V=0.9914222, theta=-77.029249 -> V=1.0, theta=0.0
% INFO    : Bus 1671	: V=0.9609033, theta=-80.075306 -> V=1.0, theta=0.0
% INFO    : Bus 1672	: V=0.9852232, theta=-77.904715 -> V=1.0, theta=0.0
% INFO    : Bus 1673	: V=0.9895079, theta=-77.227721 -> V=1.0, theta=0.0
% INFO    : Bus 1674	: V=0.9888098, theta=-77.311238 -> V=1.0, theta=0.0
% INFO    : Bus 1675	: V=0.9866795, theta=-77.86358 -> V=1.0, theta=0.0
% INFO    : Bus 1676	: V=0.9831588, theta=-78.067494 -> V=1.0, theta=0.0
% INFO    : Bus 1677	: V=0.9851159, theta=-77.994119 -> V=1.0, theta=0.0
% INFO    : Bus 1678	: V=0.9822778, theta=-78.082158 -> V=1.0, theta=0.0
% INFO    : Bus 1679	: V=0.9778367, theta=-78.313477 -> V=1.0, theta=0.0
% INFO    : Bus 1680	: V=1.0009795, theta=-75.591326 -> V=1.0, theta=0.0
% INFO    : Bus 1681	: V=0.994469, theta=-76.708092 -> V=1.0, theta=0.0
% INFO    : Bus 1682	: V=0.9838922, theta=-78.245661 -> V=1.0, theta=0.0
% INFO    : Bus 1683	: V=0.9860388, theta=-77.659728 -> V=1.0, theta=0.0
% INFO    : Bus 1684	: V=0.9838962, theta=-77.818742 -> V=1.0, theta=0.0
% INFO    : Bus 1685	: V=0.9759752, theta=-78.438783 -> V=1.0, theta=0.0
% INFO    : Bus 1686	: V=0.997944, theta=-76.355984 -> V=1.0, theta=0.0
% INFO    : Bus 1687	: V=1.0000186, theta=-76.224491 -> V=1.0, theta=0.0
% INFO    : Bus 1688	: V=1.0000117, theta=-76.174386 -> V=1.0, theta=0.0
% INFO    : Bus 1689	: V=1.002019, theta=-76.093747 -> V=1.0, theta=0.0
% INFO    : Bus 1690	: V=0.9877822, theta=-77.566339 -> V=1.0, theta=0.0
% INFO    : Bus 1691	: V=1.0037408, theta=-75.89692 -> V=1.0, theta=0.0
% INFO    : Bus 1692	: V=0.9878694, theta=-78.055444 -> V=1.0, theta=0.0
% INFO    : Bus 1693	: V=1.0114181, theta=-75.05249 -> V=1.0, theta=0.0
% INFO    : Bus 1694	: V=1.0107603, theta=-75.195444 -> V=1.0, theta=0.0
% INFO    : Bus 1695	: V=0.9905073, theta=-77.75915 -> V=1.0, theta=0.0
% INFO    : Bus 1696	: V=1.0100419, theta=-75.404662 -> V=1.0, theta=0.0
% INFO    : Bus 1697	: V=1.0091093, theta=-75.700929 -> V=1.0, theta=0.0
% INFO    : Bus 1698	: V=1.000686, theta=-71.754244 -> V=1.0, theta=0.0
% INFO    : Bus 1699	: V=0.9998922, theta=-72.997313 -> V=1.0, theta=0.0
% INFO    : Bus 1700	: V=1.0016226, theta=-72.891801 -> V=1.0, theta=0.0
% INFO    : Bus 1701	: V=0.9990892, theta=-72.943396 -> V=1.0, theta=0.0
% INFO    : Bus 1702	: V=0.9946162, theta=-73.418598 -> V=1.0, theta=0.0
% INFO    : Bus 1703	: V=0.992533, theta=-73.636009 -> V=1.0, theta=0.0
% INFO    : Bus 1704	: V=0.9865117, theta=-73.619167 -> V=1.0, theta=0.0
% INFO    : Bus 1705	: V=1.0193006, theta=-72.847894 -> V=1.0, theta=0.0
% INFO    : Bus 1706	: V=0.9946849, theta=-73.418608 -> V=1.0, theta=0.0
% INFO    : Bus 1707	: V=0.9835012, theta=-74.753034 -> V=1.0, theta=0.0
% INFO    : Bus 1708	: V=0.9964078, theta=-74.635147 -> V=1.0, theta=0.0
% INFO    : Bus 1709	: V=0.9998938, theta=-73.11993 -> V=1.0, theta=0.0
% INFO    : Bus 1710	: V=1.002, theta=-72.606316 -> V=1.0, theta=0.0
% INFO    : Bus 1711	: V=0.9984574, theta=-74.248233 -> V=1.0, theta=0.0
% INFO    : Bus 1712	: V=1.0189638, theta=-72.879674 -> V=1.0, theta=0.0
% INFO    : Bus 1713	: V=0.998095, theta=-74.15377 -> V=1.0, theta=0.0
% INFO    : Bus 1714	: V=0.986859, theta=-74.28746 -> V=1.0, theta=0.0
% INFO    : Bus 1715	: V=0.9930763, theta=-73.83162 -> V=1.0, theta=0.0
% INFO    : Bus 1716	: V=1.0025277, theta=-72.395278 -> V=1.0, theta=0.0
% INFO    : Bus 1717	: V=1.0013271, theta=-72.425983 -> V=1.0, theta=0.0
% INFO    : Bus 1718	: V=1.0091342, theta=-71.774708 -> V=1.0, theta=0.0
% INFO    : Bus 1719	: V=1.0183861, theta=-69.812195 -> V=1.0, theta=0.0
% INFO    : Bus 1720	: V=0.9982756, theta=-73.233821 -> V=1.0, theta=0.0
% INFO    : Bus 1721	: V=0.9935153, theta=-73.508481 -> V=1.0, theta=0.0
% INFO    : Bus 1722	: V=0.9931541, theta=-73.540806 -> V=1.0, theta=0.0
% INFO    : Bus 1723	: V=0.991673, theta=-73.650178 -> V=1.0, theta=0.0
% INFO    : Bus 1724	: V=0.9901666, theta=-73.789499 -> V=1.0, theta=0.0
% INFO    : Bus 1725	: V=0.9941785, theta=-73.544582 -> V=1.0, theta=0.0
% INFO    : Bus 1726	: V=0.9956099, theta=-73.434616 -> V=1.0, theta=0.0
% INFO    : Bus 1727	: V=1.0127549, theta=-72.097278 -> V=1.0, theta=0.0
% INFO    : Bus 1728	: V=1.0039237, theta=-73.070397 -> V=1.0, theta=0.0
% INFO    : Bus 1729	: V=0.9958503, theta=-73.430431 -> V=1.0, theta=0.0
% INFO    : Bus 1730	: V=1.0105871, theta=-71.980211 -> V=1.0, theta=0.0
% INFO    : Bus 1731	: V=1.0100256, theta=-71.524807 -> V=1.0, theta=0.0
% INFO    : Bus 1732	: V=1.0004957, theta=-72.759985 -> V=1.0, theta=0.0
% INFO    : Bus 1733	: V=0.99883, theta=-72.917402 -> V=1.0, theta=0.0
% INFO    : Bus 1734	: V=1.0089546, theta=-71.646027 -> V=1.0, theta=0.0
% INFO    : Bus 1735	: V=1.0164281, theta=-70.825508 -> V=1.0, theta=0.0
% INFO    : Bus 1736	: V=0.9976204, theta=-73.123772 -> V=1.0, theta=0.0
% INFO    : Bus 1737	: V=1.0025579, theta=-72.413871 -> V=1.0, theta=0.0
% INFO    : Bus 1738	: V=1.0154923, theta=-70.880628 -> V=1.0, theta=0.0
% INFO    : Bus 1739	: V=0.9991597, theta=-72.798146 -> V=1.0, theta=0.0
% INFO    : Bus 1740	: V=0.9957933, theta=-73.158572 -> V=1.0, theta=0.0
% INFO    : Bus 1741	: V=0.9983152, theta=-73.168531 -> V=1.0, theta=0.0
% INFO    : Bus 1742	: V=0.9976707, theta=-73.269938 -> V=1.0, theta=0.0
% INFO    : Bus 1743	: V=0.9990158, theta=-73.333066 -> V=1.0, theta=0.0
% INFO    : Bus 1744	: V=0.9972002, theta=-73.334546 -> V=1.0, theta=0.0
% INFO    : Bus 1745	: V=1.0018807, theta=-73.234773 -> V=1.0, theta=0.0
% INFO    : Bus 1746	: V=0.9999224, theta=-73.258698 -> V=1.0, theta=0.0
% INFO    : Bus 1747	: V=0.9979976, theta=-73.379658 -> V=1.0, theta=0.0
% INFO    : Bus 1748	: V=0.9964647, theta=-73.416239 -> V=1.0, theta=0.0
% INFO    : Bus 1749	: V=0.9974766, theta=-73.178028 -> V=1.0, theta=0.0
% INFO    : Bus 1750	: V=0.9959024, theta=-73.306201 -> V=1.0, theta=0.0
% INFO    : Bus 1751	: V=0.9959314, theta=-73.426716 -> V=1.0, theta=0.0
% INFO    : Bus 1752	: V=0.9965514, theta=-73.448708 -> V=1.0, theta=0.0
% INFO    : Bus 1753	: V=0.9926046, theta=-72.943917 -> V=1.0, theta=0.0
% INFO    : Bus 1754	: V=0.9805463, theta=-74.502667 -> V=1.0, theta=0.0
% INFO    : Bus 1755	: V=0.9821494, theta=-74.24656 -> V=1.0, theta=0.0
% INFO    : Bus 1756	: V=1.0004975, theta=-72.415906 -> V=1.0, theta=0.0
% INFO    : Bus 1757	: V=0.9898624, theta=-73.415478 -> V=1.0, theta=0.0
% INFO    : Bus 1758	: V=1.0006616, theta=-72.368302 -> V=1.0, theta=0.0
% INFO    : Bus 1759	: V=0.9946105, theta=-73.015349 -> V=1.0, theta=0.0
% INFO    : Bus 1760	: V=1.0076032, theta=-71.799094 -> V=1.0, theta=0.0
% INFO    : Bus 1761	: V=1.0143341, theta=-70.107444 -> V=1.0, theta=0.0
% INFO    : Bus 1762	: V=1.0104164, theta=-71.606837 -> V=1.0, theta=0.0
% INFO    : Bus 1763	: V=0.9935914, theta=-73.536507 -> V=1.0, theta=0.0
% INFO    : Bus 1764	: V=1.0057599, theta=-71.95651 -> V=1.0, theta=0.0
% INFO    : Bus 1765	: V=1.005985, theta=-71.955987 -> V=1.0, theta=0.0
% INFO    : Bus 1766	: V=1.005619, theta=-71.941267 -> V=1.0, theta=0.0
% INFO    : Bus 1767	: V=0.9912984, theta=-73.792921 -> V=1.0, theta=0.0
% INFO    : Bus 1768	: V=1.0041312, theta=-72.034343 -> V=1.0, theta=0.0
% INFO    : Bus 1769	: V=0.9946039, theta=-73.493288 -> V=1.0, theta=0.0
% INFO    : Bus 1770	: V=1.0081667, theta=-71.942409 -> V=1.0, theta=0.0
% INFO    : Bus 1771	: V=1.0189765, theta=-69.630515 -> V=1.0, theta=0.0
% INFO    : Bus 1772	: V=1.0077967, theta=-72.078857 -> V=1.0, theta=0.0
% INFO    : Bus 1773	: V=0.9974748, theta=-73.951899 -> V=1.0, theta=0.0
% INFO    : Bus 1774	: V=0.9934293, theta=-73.984368 -> V=1.0, theta=0.0
% INFO    : Bus 1775	: V=0.9957202, theta=-73.982061 -> V=1.0, theta=0.0
% INFO    : Bus 1776	: V=0.9943675, theta=-74.028291 -> V=1.0, theta=0.0
% INFO    : Bus 1777	: V=0.992138, theta=-74.133289 -> V=1.0, theta=0.0
% INFO    : Bus 1778	: V=0.9937287, theta=-74.031301 -> V=1.0, theta=0.0
% INFO    : Bus 1779	: V=0.990715, theta=-73.922628 -> V=1.0, theta=0.0
% INFO    : Bus 1780	: V=0.9921499, theta=-72.905725 -> V=1.0, theta=0.0
% INFO    : Bus 1781	: V=0.9953653, theta=-72.755197 -> V=1.0, theta=0.0
% INFO    : Bus 1782	: V=0.9898161, theta=-73.928655 -> V=1.0, theta=0.0
% INFO    : Bus 1783	: V=0.9883232, theta=-73.953787 -> V=1.0, theta=0.0
% INFO    : Bus 1784	: V=1.0030408, theta=-72.095973 -> V=1.0, theta=0.0
% INFO    : Bus 1785	: V=1.0134704, theta=-72.148652 -> V=1.0, theta=0.0
% INFO    : Bus 1786	: V=0.9833919, theta=-73.718718 -> V=1.0, theta=0.0
% INFO    : Bus 1787	: V=0.985774, theta=-74.070404 -> V=1.0, theta=0.0
% INFO    : Bus 1788	: V=0.986921, theta=-74.000416 -> V=1.0, theta=0.0
% INFO    : Bus 1789	: V=0.9829676, theta=-73.675624 -> V=1.0, theta=0.0
% INFO    : Bus 1790	: V=0.9712343, theta=-75.357609 -> V=1.0, theta=0.0
% INFO    : Bus 1791	: V=0.9735032, theta=-75.247983 -> V=1.0, theta=0.0
% INFO    : Bus 1792	: V=0.9811228, theta=-73.813394 -> V=1.0, theta=0.0
% INFO    : Bus 1793	: V=0.9642343, theta=-75.931103 -> V=1.0, theta=0.0
% INFO    : Bus 1794	: V=0.9749753, theta=-75.389733 -> V=1.0, theta=0.0
% INFO    : Bus 1795	: V=0.9797221, theta=-75.61727 -> V=1.0, theta=0.0
% INFO    : Bus 1796	: V=0.9786849, theta=-75.634648 -> V=1.0, theta=0.0
% INFO    : Bus 1797	: V=0.9796071, theta=-76.005482 -> V=1.0, theta=0.0
% INFO    : Bus 1798	: V=0.9701628, theta=-75.30866 -> V=1.0, theta=0.0
% INFO    : Bus 1799	: V=0.9737621, theta=-75.675378 -> V=1.0, theta=0.0
% INFO    : Bus 1800	: V=0.9859126, theta=-74.35285 -> V=1.0, theta=0.0
% INFO    : Bus 1801	: V=1.0189959, theta=-72.488431 -> V=1.0, theta=0.0
% INFO    : Bus 1802	: V=0.9872007, theta=-74.336142 -> V=1.0, theta=0.0
% INFO    : Bus 1803	: V=0.985587, theta=-74.265513 -> V=1.0, theta=0.0
% INFO    : Bus 1804	: V=1.0048741, theta=-73.271054 -> V=1.0, theta=0.0
% INFO    : Bus 1805	: V=1.0119985, theta=-72.246141 -> V=1.0, theta=0.0
% INFO    : Bus 1806	: V=1.0026522, theta=-73.335102 -> V=1.0, theta=0.0
% INFO    : Bus 1807	: V=0.9976546, theta=-73.475291 -> V=1.0, theta=0.0
% INFO    : Bus 1808	: V=0.9986518, theta=-73.477249 -> V=1.0, theta=0.0
% INFO    : Bus 1809	: V=0.9937335, theta=-73.165969 -> V=1.0, theta=0.0
% INFO    : Bus 1810	: V=0.9952171, theta=-73.093725 -> V=1.0, theta=0.0
% INFO    : Bus 1811	: V=0.9922624, theta=-73.322717 -> V=1.0, theta=0.0
% INFO    : Bus 1812	: V=0.9749398, theta=-74.252113 -> V=1.0, theta=0.0
% INFO    : Bus 1813	: V=0.9983136, theta=-72.397659 -> V=1.0, theta=0.0
% INFO    : Bus 1814	: V=0.9818981, theta=-73.960449 -> V=1.0, theta=0.0
% INFO    : Bus 1815	: V=0.9812238, theta=-74.526601 -> V=1.0, theta=0.0
% INFO    : Bus 1816	: V=0.9819331, theta=-74.361544 -> V=1.0, theta=0.0
% INFO    : Bus 1817	: V=0.9814107, theta=-74.584058 -> V=1.0, theta=0.0
% INFO    : Bus 1818	: V=0.9814332, theta=-74.567572 -> V=1.0, theta=0.0
% INFO    : Bus 1819	: V=0.983961, theta=-73.694149 -> V=1.0, theta=0.0
% INFO    : Bus 1820	: V=0.9740876, theta=-75.270547 -> V=1.0, theta=0.0
% INFO    : Bus 1821	: V=0.9830603, theta=-73.643142 -> V=1.0, theta=0.0
% INFO    : Bus 1822	: V=0.9906136, theta=-73.14187 -> V=1.0, theta=0.0
% INFO    : Bus 1823	: V=0.9769167, theta=-74.222857 -> V=1.0, theta=0.0
% INFO    : Bus 1824	: V=0.9782683, theta=-74.534136 -> V=1.0, theta=0.0
% INFO    : Bus 1825	: V=0.9750275, theta=-74.655841 -> V=1.0, theta=0.0
% INFO    : Bus 1826	: V=0.9857181, theta=-73.342999 -> V=1.0, theta=0.0
% INFO    : Bus 1827	: V=0.9860629, theta=-73.32099 -> V=1.0, theta=0.0
% INFO    : Bus 1828	: V=0.9870041, theta=-73.261763 -> V=1.0, theta=0.0
% INFO    : Bus 1829	: V=0.9898751, theta=-73.073645 -> V=1.0, theta=0.0
% INFO    : Bus 1830	: V=0.9831105, theta=-73.71239 -> V=1.0, theta=0.0
% INFO    : Bus 1831	: V=0.995744, theta=-72.715678 -> V=1.0, theta=0.0
% INFO    : Bus 1832	: V=1.0072453, theta=-71.757343 -> V=1.0, theta=0.0
% INFO    : Bus 1833	: V=0.9938306, theta=-74.052853 -> V=1.0, theta=0.0
% INFO    : Bus 1834	: V=0.9945711, theta=-73.923045 -> V=1.0, theta=0.0
% INFO    : Bus 1835	: V=0.9958521, theta=-73.896211 -> V=1.0, theta=0.0
% INFO    : Bus 1836	: V=0.975942, theta=-74.874779 -> V=1.0, theta=0.0
% INFO    : Bus 1837	: V=0.9802732, theta=-74.826001 -> V=1.0, theta=0.0
% INFO    : Bus 1838	: V=1.0024872, theta=-73.067489 -> V=1.0, theta=0.0
% INFO    : Bus 1839	: V=1.0021751, theta=-73.097608 -> V=1.0, theta=0.0
% INFO    : Bus 1840	: V=0.9810218, theta=-74.661837 -> V=1.0, theta=0.0
% INFO    : Bus 1841	: V=0.978479, theta=-75.595334 -> V=1.0, theta=0.0
% INFO    : Bus 1842	: V=0.9786301, theta=-75.60162 -> V=1.0, theta=0.0
% INFO    : Bus 1843	: V=0.9781599, theta=-75.601018 -> V=1.0, theta=0.0
% INFO    : Bus 1844	: V=0.9791841, theta=-75.589638 -> V=1.0, theta=0.0
% INFO    : Bus 1845	: V=1.0034756, theta=-73.053526 -> V=1.0, theta=0.0
% INFO    : Bus 1846	: V=0.993197, theta=-74.133062 -> V=1.0, theta=0.0
% INFO    : Bus 1847	: V=0.9886691, theta=-74.351456 -> V=1.0, theta=0.0
% INFO    : Bus 1848	: V=0.9902727, theta=-74.32993 -> V=1.0, theta=0.0
% INFO    : Bus 1849	: V=0.9862375, theta=-73.728439 -> V=1.0, theta=0.0
% INFO    : Bus 1850	: V=0.984276, theta=-73.166847 -> V=1.0, theta=0.0
% INFO    : Bus 1851	: V=0.9779625, theta=-74.708261 -> V=1.0, theta=0.0
% INFO    : Bus 1852	: V=0.9810882, theta=-74.560326 -> V=1.0, theta=0.0
% INFO    : Bus 1853	: V=0.9823498, theta=-74.544128 -> V=1.0, theta=0.0
% INFO    : Bus 1854	: V=0.9847373, theta=-72.117902 -> V=1.0, theta=0.0
% INFO    : Bus 1855	: V=0.9571502, theta=-78.345278 -> V=1.0, theta=0.0
% INFO    : Bus 1856	: V=0.9558745, theta=-79.344155 -> V=1.0, theta=0.0
% INFO    : Bus 1857	: V=0.9570321, theta=-79.154794 -> V=1.0, theta=0.0
% INFO    : Bus 1858	: V=0.9606728, theta=-79.62206 -> V=1.0, theta=0.0
% INFO    : Bus 1859	: V=0.9765731, theta=-78.020085 -> V=1.0, theta=0.0
% INFO    : Bus 1860	: V=0.9606782, theta=-79.546557 -> V=1.0, theta=0.0
% INFO    : Bus 1861	: V=0.9611134, theta=-79.552744 -> V=1.0, theta=0.0
% INFO    : Bus 1862	: V=0.9605827, theta=-79.521047 -> V=1.0, theta=0.0
% INFO    : Bus 1863	: V=0.9563804, theta=-80.141698 -> V=1.0, theta=0.0
% INFO    : Bus 1864	: V=0.9597304, theta=-79.576741 -> V=1.0, theta=0.0
% INFO    : Bus 1865	: V=0.9597631, theta=-79.735357 -> V=1.0, theta=0.0
% INFO    : Bus 1866	: V=0.9611996, theta=-79.62559 -> V=1.0, theta=0.0
% INFO    : Bus 1867	: V=0.9766227, theta=-78.137894 -> V=1.0, theta=0.0
% INFO    : Bus 1868	: V=0.9602989, theta=-79.751283 -> V=1.0, theta=0.0
% INFO    : Bus 1869	: V=0.9588466, theta=-79.926133 -> V=1.0, theta=0.0
% INFO    : Bus 1870	: V=0.9599974, theta=-79.754723 -> V=1.0, theta=0.0
% INFO    : Bus 1871	: V=0.9612586, theta=-79.891527 -> V=1.0, theta=0.0
% INFO    : Bus 1872	: V=0.9630317, theta=-79.748255 -> V=1.0, theta=0.0
% INFO    : Bus 1873	: V=0.9772671, theta=-78.117852 -> V=1.0, theta=0.0
% INFO    : Bus 1874	: V=0.9643158, theta=-79.623103 -> V=1.0, theta=0.0
% INFO    : Bus 1875	: V=0.9646859, theta=-79.61691 -> V=1.0, theta=0.0
% INFO    : Bus 1876	: V=0.9641604, theta=-79.629794 -> V=1.0, theta=0.0
% INFO    : Bus 1877	: V=0.9630419, theta=-79.823277 -> V=1.0, theta=0.0
% INFO    : Bus 1878	: V=0.964841, theta=-79.799842 -> V=1.0, theta=0.0
% INFO    : Bus 1879	: V=0.9599184, theta=-79.640354 -> V=1.0, theta=0.0
% INFO    : Bus 1880	: V=0.9659208, theta=-79.566345 -> V=1.0, theta=0.0
% INFO    : Bus 1881	: V=0.9651118, theta=-79.576758 -> V=1.0, theta=0.0
% INFO    : Bus 1882	: V=0.9507313, theta=-80.413976 -> V=1.0, theta=0.0
% INFO    : Bus 1883	: V=0.9525923, theta=-80.192598 -> V=1.0, theta=0.0
% INFO    : Bus 1884	: V=0.9604412, theta=-79.572557 -> V=1.0, theta=0.0
% INFO    : Bus 1885	: V=0.961735, theta=-79.553456 -> V=1.0, theta=0.0
% INFO    : Bus 1886	: V=0.9636709, theta=-79.462155 -> V=1.0, theta=0.0
% INFO    : Bus 1887	: V=0.9778503, theta=-77.952133 -> V=1.0, theta=0.0
% INFO    : Bus 1888	: V=0.9678422, theta=-79.207158 -> V=1.0, theta=0.0
% INFO    : Bus 1889	: V=0.9786163, theta=-78.042317 -> V=1.0, theta=0.0
% INFO    : Bus 1890	: V=0.9707586, theta=-79.23303 -> V=1.0, theta=0.0
% INFO    : Bus 1891	: V=0.9631988, theta=-79.869858 -> V=1.0, theta=0.0
% INFO    : Bus 1892	: V=0.9647973, theta=-79.85863 -> V=1.0, theta=0.0
% INFO    : Bus 1893	: V=0.9784542, theta=-79.535806 -> V=1.0, theta=0.0
% INFO    : Bus 1894	: V=0.9845632, theta=-78.725704 -> V=1.0, theta=0.0
% INFO    : Bus 1895	: V=0.9834949, theta=-78.76771 -> V=1.0, theta=0.0
% INFO    : Bus 1896	: V=0.9620711, theta=-80.169534 -> V=1.0, theta=0.0
% INFO    : Bus 1897	: V=0.9614373, theta=-81.521405 -> V=1.0, theta=0.0
% INFO    : Bus 1898	: V=0.9631872, theta=-81.445182 -> V=1.0, theta=0.0
% INFO    : Bus 1899	: V=0.9737125, theta=-79.22771 -> V=1.0, theta=0.0
% INFO    : Bus 1900	: V=0.9591694, theta=-80.18883 -> V=1.0, theta=0.0
% INFO    : Bus 1901	: V=0.9626763, theta=-80.060068 -> V=1.0, theta=0.0
% INFO    : Bus 1902	: V=0.9627967, theta=-79.340974 -> V=1.0, theta=0.0
% INFO    : Bus 1903	: V=0.9599598, theta=-80.081964 -> V=1.0, theta=0.0
% INFO    : Bus 1904	: V=0.9599956, theta=-79.99348 -> V=1.0, theta=0.0
% INFO    : Bus 1905	: V=0.9574388, theta=-80.010552 -> V=1.0, theta=0.0
% INFO    : Bus 1906	: V=0.9565237, theta=-80.017652 -> V=1.0, theta=0.0
% INFO    : Bus 1907	: V=0.9604738, theta=-79.967806 -> V=1.0, theta=0.0
% INFO    : Bus 1908	: V=0.9563908, theta=-80.016415 -> V=1.0, theta=0.0
% INFO    : Bus 1909	: V=0.9561016, theta=-80.018622 -> V=1.0, theta=0.0
% INFO    : Bus 1910	: V=0.9576104, theta=-79.909153 -> V=1.0, theta=0.0
% INFO    : Bus 1911	: V=0.9612203, theta=-79.625464 -> V=1.0, theta=0.0
% INFO    : Bus 1912	: V=0.9592588, theta=-79.615731 -> V=1.0, theta=0.0
% INFO    : Bus 1913	: V=0.9642962, theta=-79.21059 -> V=1.0, theta=0.0
% INFO    : Bus 1914	: V=0.9964989, theta=-75.533945 -> V=1.0, theta=0.0
% INFO    : Bus 1915	: V=0.9934769, theta=-76.683919 -> V=1.0, theta=0.0
% INFO    : Bus 1916	: V=1.0046896, theta=-75.72364 -> V=1.0, theta=0.0
% INFO    : Bus 1917	: V=0.9679667, theta=-78.813884 -> V=1.0, theta=0.0
% INFO    : Bus 1918	: V=0.9695756, theta=-78.575286 -> V=1.0, theta=0.0
% INFO    : Bus 1919	: V=0.9856404, theta=-76.757693 -> V=1.0, theta=0.0
% INFO    : Bus 1920	: V=1.0053445, theta=-74.167116 -> V=1.0, theta=0.0
% INFO    : Bus 1921	: V=0.9840473, theta=-77.019246 -> V=1.0, theta=0.0
% INFO    : Bus 1922	: V=0.9814825, theta=-77.332939 -> V=1.0, theta=0.0
% INFO    : Bus 1923	: V=0.9787628, theta=-77.666979 -> V=1.0, theta=0.0
% INFO    : Bus 1924	: V=0.9820546, theta=-77.134367 -> V=1.0, theta=0.0
% INFO    : Bus 1925	: V=0.9805917, theta=-77.212593 -> V=1.0, theta=0.0
% INFO    : Bus 1926	: V=0.9750702, theta=-77.630863 -> V=1.0, theta=0.0
% INFO    : Bus 1927	: V=0.9644323, theta=-79.019896 -> V=1.0, theta=0.0
% INFO    : Bus 1928	: V=0.9644849, theta=-79.21313 -> V=1.0, theta=0.0
% INFO    : Bus 1929	: V=0.9657105, theta=-79.142876 -> V=1.0, theta=0.0
% INFO    : Bus 1930	: V=0.9996916, theta=-74.741954 -> V=1.0, theta=0.0
% INFO    : Bus 1931	: V=0.9784136, theta=-77.543333 -> V=1.0, theta=0.0
% INFO    : Bus 1932	: V=0.9759134, theta=-77.855666 -> V=1.0, theta=0.0
% INFO    : Bus 1933	: V=0.9619309, theta=-79.429849 -> V=1.0, theta=0.0
% INFO    : Bus 1934	: V=0.9627506, theta=-79.358517 -> V=1.0, theta=0.0
% INFO    : Bus 1935	: V=0.9676997, theta=-78.385701 -> V=1.0, theta=0.0
% INFO    : Bus 1936	: V=0.9564432, theta=-80.075145 -> V=1.0, theta=0.0
% INFO    : Bus 1937	: V=0.9740319, theta=-80.162487 -> V=1.0, theta=0.0
% INFO    : Bus 1938	: V=0.9771591, theta=-80.068647 -> V=1.0, theta=0.0
% INFO    : Bus 1939	: V=0.9881763, theta=-78.597898 -> V=1.0, theta=0.0
% INFO    : Bus 1940	: V=1.0108978, theta=-76.538724 -> V=1.0, theta=0.0
% INFO    : Bus 1941	: V=0.9870211, theta=-78.65414 -> V=1.0, theta=0.0
% INFO    : Bus 1942	: V=0.9884991, theta=-78.65946 -> V=1.0, theta=0.0
% INFO    : Bus 1943	: V=0.9655229, theta=-80.326893 -> V=1.0, theta=0.0
% INFO    : Bus 1944	: V=0.9695898, theta=-80.213287 -> V=1.0, theta=0.0
% INFO    : Bus 1945	: V=0.9679695, theta=-80.28909 -> V=1.0, theta=0.0
% INFO    : Bus 1946	: V=0.979783, theta=-78.872442 -> V=1.0, theta=0.0
% INFO    : Bus 1947	: V=0.9682268, theta=-80.321256 -> V=1.0, theta=0.0
% INFO    : Bus 1948	: V=0.9675644, theta=-80.415376 -> V=1.0, theta=0.0
% INFO    : Bus 1949	: V=0.9660773, theta=-80.444149 -> V=1.0, theta=0.0
% INFO    : Bus 1950	: V=0.9873834, theta=-78.82787 -> V=1.0, theta=0.0
% INFO    : Bus 1951	: V=0.9858508, theta=-78.858007 -> V=1.0, theta=0.0
% INFO    : Bus 1952	: V=0.9720729, theta=-80.349834 -> V=1.0, theta=0.0
% INFO    : Bus 1953	: V=1.0115495, theta=-76.548207 -> V=1.0, theta=0.0
% INFO    : Bus 1954	: V=0.972162, theta=-80.319212 -> V=1.0, theta=0.0
% INFO    : Bus 1955	: V=0.9711019, theta=-80.334297 -> V=1.0, theta=0.0
% INFO    : Bus 1956	: V=0.9790211, theta=-79.836853 -> V=1.0, theta=0.0
% INFO    : Bus 1957	: V=0.9752786, theta=-80.241438 -> V=1.0, theta=0.0
% INFO    : Bus 1958	: V=0.9864, theta=-79.087584 -> V=1.0, theta=0.0
% INFO    : Bus 1959	: V=0.9871422, theta=-79.050317 -> V=1.0, theta=0.0
% INFO    : Bus 1960	: V=0.9883732, theta=-78.986285 -> V=1.0, theta=0.0
% INFO    : Bus 1961	: V=0.9709681, theta=-80.381813 -> V=1.0, theta=0.0
% INFO    : Bus 1962	: V=0.9894954, theta=-78.920528 -> V=1.0, theta=0.0
% INFO    : Bus 1963	: V=0.9911738, theta=-78.811828 -> V=1.0, theta=0.0
% INFO    : Bus 1964	: V=0.9849373, theta=-79.512154 -> V=1.0, theta=0.0
% INFO    : Bus 1965	: V=0.9866771, theta=-79.476694 -> V=1.0, theta=0.0
% INFO    : Bus 1966	: V=0.993293, theta=-78.676414 -> V=1.0, theta=0.0
% INFO    : Bus 1967	: V=0.9860531, theta=-79.360707 -> V=1.0, theta=0.0
% INFO    : Bus 1968	: V=0.9848821, theta=-79.340394 -> V=1.0, theta=0.0
% INFO    : Bus 1969	: V=0.9799008, theta=-79.650601 -> V=1.0, theta=0.0
% INFO    : Bus 1970	: V=0.9820323, theta=-79.599479 -> V=1.0, theta=0.0
% INFO    : Bus 1971	: V=0.9704886, theta=-80.466812 -> V=1.0, theta=0.0
% INFO    : Bus 1972	: V=0.9905242, theta=-78.663819 -> V=1.0, theta=0.0
% INFO    : Bus 1973	: V=0.9893825, theta=-78.724901 -> V=1.0, theta=0.0
% INFO    : Bus 1974	: V=0.9885172, theta=-78.769449 -> V=1.0, theta=0.0
% INFO    : Bus 1975	: V=0.9839239, theta=-79.29996 -> V=1.0, theta=0.0
% INFO    : Bus 1976	: V=0.9848331, theta=-79.290522 -> V=1.0, theta=0.0
% INFO    : Bus 1977	: V=0.9827902, theta=-79.498932 -> V=1.0, theta=0.0
% INFO    : Bus 1978	: V=0.9942133, theta=-78.434926 -> V=1.0, theta=0.0
% INFO    : Bus 1979	: V=0.9852656, theta=-79.312247 -> V=1.0, theta=0.0
% INFO    : Bus 1980	: V=0.9851915, theta=-79.322666 -> V=1.0, theta=0.0
% INFO    : Bus 1981	: V=0.9853485, theta=-79.322352 -> V=1.0, theta=0.0
% INFO    : Bus 1982	: V=0.9971374, theta=-78.234342 -> V=1.0, theta=0.0
% INFO    : Bus 1983	: V=0.9989289, theta=-78.089393 -> V=1.0, theta=0.0
% INFO    : Bus 1984	: V=0.9987604, theta=-78.104987 -> V=1.0, theta=0.0
% INFO    : Bus 1985	: V=1.0089503, theta=-77.123819 -> V=1.0, theta=0.0
% INFO    : Bus 1986	: V=1.0084045, theta=-77.16575 -> V=1.0, theta=0.0
% INFO    : Bus 1987	: V=0.9997669, theta=-78.033277 -> V=1.0, theta=0.0
% INFO    : Bus 1988	: V=0.9993387, theta=-78.039236 -> V=1.0, theta=0.0
% INFO    : Bus 1989	: V=0.9768461, theta=-80.526508 -> V=1.0, theta=0.0
% INFO    : Bus 1990	: V=0.9773201, theta=-80.524553 -> V=1.0, theta=0.0
% INFO    : Bus 1991	: V=0.977782, theta=-80.517648 -> V=1.0, theta=0.0
% INFO    : Bus 1992	: V=0.9779962, theta=-80.474299 -> V=1.0, theta=0.0
% INFO    : Bus 1993	: V=0.9961427, theta=-78.473096 -> V=1.0, theta=0.0
% INFO    : Bus 1994	: V=0.9970287, theta=-78.402752 -> V=1.0, theta=0.0
% INFO    : Bus 1995	: V=0.9780725, theta=-80.457046 -> V=1.0, theta=0.0
% INFO    : Bus 1996	: V=0.9947169, theta=-78.575794 -> V=1.0, theta=0.0
% INFO    : Bus 1997	: V=0.9764789, theta=-80.535977 -> V=1.0, theta=0.0
% INFO    : Bus 1998	: V=0.9771388, theta=-80.527393 -> V=1.0, theta=0.0
% INFO    : Bus 1999	: V=0.9970474, theta=-78.367087 -> V=1.0, theta=0.0
% INFO    : Bus 2000	: V=0.9964081, theta=-78.408421 -> V=1.0, theta=0.0
% INFO    : Bus 2001	: V=0.9905784, theta=-79.089461 -> V=1.0, theta=0.0
% INFO    : Bus 2002	: V=0.9977072, theta=-78.325518 -> V=1.0, theta=0.0
% INFO    : Bus 2003	: V=0.9909542, theta=-79.079911 -> V=1.0, theta=0.0
% INFO    : Bus 2004	: V=0.9905431, theta=-79.083549 -> V=1.0, theta=0.0
% INFO    : Bus 2005	: V=0.9977135, theta=-78.348638 -> V=1.0, theta=0.0
% INFO    : Bus 2006	: V=1.0192601, theta=-76.149282 -> V=1.0, theta=0.0
% INFO    : Bus 2007	: V=0.9988435, theta=-78.254915 -> V=1.0, theta=0.0
% INFO    : Bus 2008	: V=0.9912105, theta=-79.081125 -> V=1.0, theta=0.0
% INFO    : Bus 2009	: V=1.0019644, theta=-77.935557 -> V=1.0, theta=0.0
% INFO    : Bus 2010	: V=1.0194466, theta=-76.146733 -> V=1.0, theta=0.0
% INFO    : Bus 2011	: V=1.0002397, theta=-78.026068 -> V=1.0, theta=0.0
% INFO    : Bus 2012	: V=0.9999019, theta=-78.033302 -> V=1.0, theta=0.0
% INFO    : Bus 2013	: V=0.9991456, theta=-78.069108 -> V=1.0, theta=0.0
% INFO    : Bus 2014	: V=0.9988439, theta=-78.085395 -> V=1.0, theta=0.0
% INFO    : Bus 2015	: V=0.9921625, theta=-78.783086 -> V=1.0, theta=0.0
% INFO    : Bus 2016	: V=0.991324, theta=-78.791582 -> V=1.0, theta=0.0
% INFO    : Bus 2017	: V=0.9986769, theta=-78.094069 -> V=1.0, theta=0.0
% INFO    : Bus 2018	: V=0.9973194, theta=-78.155157 -> V=1.0, theta=0.0
% INFO    : Bus 2019	: V=0.9977652, theta=-78.150921 -> V=1.0, theta=0.0
% INFO    : Bus 2020	: V=0.9988458, theta=-78.103663 -> V=1.0, theta=0.0
% INFO    : Bus 2021	: V=0.9976089, theta=-78.185345 -> V=1.0, theta=0.0
% INFO    : Bus 2022	: V=0.9871825, theta=-79.385999 -> V=1.0, theta=0.0
% INFO    : Bus 2023	: V=0.9985102, theta=-78.134958 -> V=1.0, theta=0.0
% INFO    : Bus 2024	: V=1.0012696, theta=-77.974261 -> V=1.0, theta=0.0
% INFO    : Bus 2025	: V=1.0007073, theta=-78.006559 -> V=1.0, theta=0.0
% INFO    : Bus 2026	: V=1.0197666, theta=-76.15413 -> V=1.0, theta=0.0
% INFO    : Bus 2027	: V=0.9929776, theta=-78.919807 -> V=1.0, theta=0.0
% INFO    : Bus 2028	: V=0.993328, theta=-78.902507 -> V=1.0, theta=0.0
% INFO    : Bus 2029	: V=0.9974423, theta=-78.210471 -> V=1.0, theta=0.0
% INFO    : Bus 2030	: V=1.0094188, theta=-76.988595 -> V=1.0, theta=0.0
% INFO    : Bus 2031	: V=1.0195495, theta=-76.196599 -> V=1.0, theta=0.0
% INFO    : Bus 2032	: V=0.9972222, theta=-78.219727 -> V=1.0, theta=0.0
% INFO    : Bus 2033	: V=0.9975195, theta=-78.204838 -> V=1.0, theta=0.0
% INFO    : Bus 2034	: V=0.9928583, theta=-78.693545 -> V=1.0, theta=0.0
% INFO    : Bus 2035	: V=0.9927604, theta=-78.694316 -> V=1.0, theta=0.0
% INFO    : Bus 2036	: V=0.9857984, theta=-79.42669 -> V=1.0, theta=0.0
% INFO    : Bus 2037	: V=0.9967692, theta=-78.242545 -> V=1.0, theta=0.0
% INFO    : Bus 2038	: V=1.0192338, theta=-76.220276 -> V=1.0, theta=0.0
% INFO    : Bus 2039	: V=0.9969802, theta=-78.25134 -> V=1.0, theta=0.0
% INFO    : Bus 2040	: V=0.9959357, theta=-78.314114 -> V=1.0, theta=0.0
% INFO    : Bus 2041	: V=0.9847661, theta=-79.486748 -> V=1.0, theta=0.0
% INFO    : Bus 2042	: V=0.9851252, theta=-79.488467 -> V=1.0, theta=0.0
% INFO    : Bus 2043	: V=0.9857324, theta=-79.456442 -> V=1.0, theta=0.0
% INFO    : Bus 2044	: V=0.996864, theta=-78.211642 -> V=1.0, theta=0.0
% INFO    : Bus 2045	: V=0.9864094, theta=-79.420772 -> V=1.0, theta=0.0
% INFO    : Bus 2046	: V=0.9962632, theta=-78.268886 -> V=1.0, theta=0.0
% INFO    : Bus 2047	: V=0.9952649, theta=-78.328945 -> V=1.0, theta=0.0
% INFO    : Bus 2048	: V=0.9961864, theta=-78.252463 -> V=1.0, theta=0.0
% INFO    : Bus 2049	: V=0.9870447, theta=-79.260394 -> V=1.0, theta=0.0
% INFO    : Bus 2050	: V=0.9947175, theta=-78.337383 -> V=1.0, theta=0.0
% INFO    : Bus 2051	: V=0.995165, theta=-78.205633 -> V=1.0, theta=0.0
% INFO    : Bus 2052	: V=0.9869725, theta=-79.261203 -> V=1.0, theta=0.0
% INFO    : Bus 2053	: V=0.9872056, theta=-79.257524 -> V=1.0, theta=0.0
% INFO    : Bus 2054	: V=0.996668, theta=-78.143294 -> V=1.0, theta=0.0
% INFO    : Bus 2055	: V=0.9933057, theta=-78.748304 -> V=1.0, theta=0.0
% INFO    : Bus 2056	: V=0.9970782, theta=-78.151264 -> V=1.0, theta=0.0
% INFO    : Bus 2057	: V=1.0150631, theta=-76.219 -> V=1.0, theta=0.0
% INFO    : Bus 2058	: V=0.9920781, theta=-78.814129 -> V=1.0, theta=0.0
% INFO    : Bus 2059	: V=0.9909384, theta=-78.873799 -> V=1.0, theta=0.0
% INFO    : Bus 2060	: V=0.989319, theta=-78.975743 -> V=1.0, theta=0.0
% INFO    : Bus 2061	: V=0.9864675, theta=-79.227466 -> V=1.0, theta=0.0
% INFO    : Bus 2062	: V=0.9690749, theta=-80.370355 -> V=1.0, theta=0.0
% INFO    : Bus 2063	: V=0.9942636, theta=-78.245512 -> V=1.0, theta=0.0
% INFO    : Bus 2064	: V=0.9764243, theta=-79.877328 -> V=1.0, theta=0.0
% INFO    : Bus 2065	: V=0.9886338, theta=-78.984111 -> V=1.0, theta=0.0
% INFO    : Bus 2066	: V=0.9949668, theta=-78.209811 -> V=1.0, theta=0.0
% INFO    : Bus 2067	: V=0.9878007, theta=-79.035969 -> V=1.0, theta=0.0
% INFO    : Bus 2068	: V=0.9955879, theta=-78.19879 -> V=1.0, theta=0.0
% INFO    : Bus 2069	: V=0.994017, theta=-78.249813 -> V=1.0, theta=0.0
% INFO    : Bus 2070	: V=0.9931486, theta=-78.282332 -> V=1.0, theta=0.0
% INFO    : Bus 2071	: V=0.9876161, theta=-79.037172 -> V=1.0, theta=0.0
% INFO    : Bus 2072	: V=0.9873248, theta=-79.039491 -> V=1.0, theta=0.0
% INFO    : Bus 2073	: V=0.9933492, theta=-78.311348 -> V=1.0, theta=0.0
% INFO    : Bus 2074	: V=0.9940066, theta=-78.278414 -> V=1.0, theta=0.0
% INFO    : Bus 2075	: V=0.9687835, theta=-80.383606 -> V=1.0, theta=0.0
% INFO    : Bus 2076	: V=0.9688515, theta=-80.376405 -> V=1.0, theta=0.0
% INFO    : Bus 2077	: V=0.9671985, theta=-80.390529 -> V=1.0, theta=0.0
% INFO    : Bus 2078	: V=0.9609949, theta=-81.029677 -> V=1.0, theta=0.0
% INFO    : Bus 2079	: V=0.9829685, theta=-78.68093 -> V=1.0, theta=0.0
% INFO    : Bus 2080	: V=0.9815542, theta=-78.762002 -> V=1.0, theta=0.0
% INFO    : Bus 2081	: V=0.9757878, theta=-79.191816 -> V=1.0, theta=0.0
% INFO    : Bus 2082	: V=0.9725692, theta=-79.20406 -> V=1.0, theta=0.0
% INFO    : Bus 2083	: V=0.9739142, theta=-79.642291 -> V=1.0, theta=0.0
% INFO    : Bus 2084	: V=0.9840851, theta=-78.395634 -> V=1.0, theta=0.0
% INFO    : Bus 2085	: V=0.9788682, theta=-78.530855 -> V=1.0, theta=0.0
% INFO    : Bus 2086	: V=0.9721841, theta=-78.528841 -> V=1.0, theta=0.0
% INFO    : Bus 2087	: V=0.9756307, theta=-78.892957 -> V=1.0, theta=0.0
% INFO    : Bus 2088	: V=0.962912, theta=-79.721739 -> V=1.0, theta=0.0
% INFO    : Bus 2089	: V=0.9665238, theta=-79.004919 -> V=1.0, theta=0.0
% INFO    : Bus 2090	: V=0.9681897, theta=-78.851774 -> V=1.0, theta=0.0
% INFO    : Bus 2091	: V=0.9712127, theta=-78.58865 -> V=1.0, theta=0.0
% INFO    : Bus 2092	: V=0.9637193, theta=-79.362613 -> V=1.0, theta=0.0
% INFO    : Bus 2093	: V=0.9702972, theta=-78.690532 -> V=1.0, theta=0.0
% INFO    : Bus 2094	: V=0.9743327, theta=-78.341657 -> V=1.0, theta=0.0
% INFO    : Bus 2095	: V=0.9757878, theta=-78.291117 -> V=1.0, theta=0.0
% INFO    : Bus 2096	: V=0.9789578, theta=-78.172722 -> V=1.0, theta=0.0
% INFO    : Bus 2097	: V=0.9823038, theta=-77.801449 -> V=1.0, theta=0.0
% INFO    : Bus 2098	: V=0.984705, theta=-77.543017 -> V=1.0, theta=0.0
% INFO    : Bus 2099	: V=0.9638725, theta=-80.435044 -> V=1.0, theta=0.0
% INFO    : Bus 2100	: V=0.9590315, theta=-80.675567 -> V=1.0, theta=0.0
% INFO    : Bus 2101	: V=0.9609091, theta=-80.650347 -> V=1.0, theta=0.0
% INFO    : Bus 2102	: V=0.9833579, theta=-79.00609 -> V=1.0, theta=0.0
% INFO    : Bus 2103	: V=0.975627, theta=-79.633143 -> V=1.0, theta=0.0
% INFO    : Bus 2104	: V=0.9699069, theta=-80.263839 -> V=1.0, theta=0.0
% INFO    : Bus 2105	: V=0.990324, theta=-78.194144 -> V=1.0, theta=0.0
% INFO    : Bus 2106	: V=1.0114614, theta=-76.011542 -> V=1.0, theta=0.0
% INFO    : Bus 2107	: V=0.9838007, theta=-79.03976 -> V=1.0, theta=0.0
% INFO    : Bus 2108	: V=0.988331, theta=-78.348331 -> V=1.0, theta=0.0
% INFO    : Bus 2109	: V=0.9773643, theta=-79.490279 -> V=1.0, theta=0.0
% INFO    : Bus 2110	: V=0.9873848, theta=-78.402557 -> V=1.0, theta=0.0
% INFO    : Bus 2111	: V=0.978422, theta=-79.486837 -> V=1.0, theta=0.0
% INFO    : Bus 2112	: V=0.9791882, theta=-79.449843 -> V=1.0, theta=0.0
% INFO    : Bus 2113	: V=0.9813741, theta=-79.322206 -> V=1.0, theta=0.0
% INFO    : Bus 2114	: V=0.9807586, theta=-79.344241 -> V=1.0, theta=0.0
% INFO    : Bus 2115	: V=0.9928423, theta=-78.336845 -> V=1.0, theta=0.0
% INFO    : Bus 2116	: V=0.9814334, theta=-79.405118 -> V=1.0, theta=0.0
% INFO    : Bus 2117	: V=0.9901214, theta=-78.394864 -> V=1.0, theta=0.0
% INFO    : Bus 2118	: V=0.9889815, theta=-78.435503 -> V=1.0, theta=0.0
% INFO    : Bus 2119	: V=0.9922746, theta=-78.459502 -> V=1.0, theta=0.0
% INFO    : Bus 2120	: V=0.9914737, theta=-78.344641 -> V=1.0, theta=0.0
% INFO    : Bus 2121	: V=0.9933219, theta=-78.408398 -> V=1.0, theta=0.0
% INFO    : Bus 2122	: V=0.9915668, theta=-78.490826 -> V=1.0, theta=0.0
% INFO    : Bus 2123	: V=0.9810512, theta=-79.464907 -> V=1.0, theta=0.0
% INFO    : Bus 2124	: V=0.9885347, theta=-78.439053 -> V=1.0, theta=0.0
% INFO    : Bus 2125	: V=0.9773128, theta=-79.545613 -> V=1.0, theta=0.0
% INFO    : Bus 2126	: V=0.9774575, theta=-79.583222 -> V=1.0, theta=0.0
% INFO    : Bus 2127	: V=0.9775905, theta=-79.588778 -> V=1.0, theta=0.0
% INFO    : Bus 2128	: V=0.9763496, theta=-79.766265 -> V=1.0, theta=0.0
% INFO    : Bus 2129	: V=0.9757535, theta=-79.658905 -> V=1.0, theta=0.0
% INFO    : Bus 2130	: V=0.9756023, theta=-79.759548 -> V=1.0, theta=0.0
% INFO    : Bus 2131	: V=0.9747257, theta=-79.748958 -> V=1.0, theta=0.0
% INFO    : Bus 2132	: V=0.9744866, theta=-79.691746 -> V=1.0, theta=0.0
% INFO    : Bus 2133	: V=0.9864184, theta=-78.443645 -> V=1.0, theta=0.0
% INFO    : Bus 2134	: V=0.9756015, theta=-79.683818 -> V=1.0, theta=0.0
% INFO    : Bus 2135	: V=0.9752345, theta=-79.540859 -> V=1.0, theta=0.0
% INFO    : Bus 2136	: V=0.9758025, theta=-79.565458 -> V=1.0, theta=0.0
% INFO    : Bus 2137	: V=0.9771774, theta=-79.535909 -> V=1.0, theta=0.0
% INFO    : Bus 2138	: V=0.9772828, theta=-79.52357 -> V=1.0, theta=0.0
% INFO    : Bus 2139	: V=0.9762951, theta=-79.543558 -> V=1.0, theta=0.0
% INFO    : Bus 2140	: V=0.9753004, theta=-79.563549 -> V=1.0, theta=0.0
% INFO    : Bus 2141	: V=0.9697541, theta=-79.881061 -> V=1.0, theta=0.0
% INFO    : Bus 2142	: V=0.9860275, theta=-78.217346 -> V=1.0, theta=0.0
% INFO    : Bus 2143	: V=0.9691655, theta=-79.933648 -> V=1.0, theta=0.0
% INFO    : Bus 2144	: V=0.9788451, theta=-78.777331 -> V=1.0, theta=0.0
% INFO    : Bus 2145	: V=0.9870733, theta=-78.091203 -> V=1.0, theta=0.0
% INFO    : Bus 2146	: V=0.9840883, theta=-78.426441 -> V=1.0, theta=0.0
% INFO    : Bus 2147	: V=0.9824194, theta=-78.523919 -> V=1.0, theta=0.0
% INFO    : Bus 2148	: V=0.9875532, theta=-78.270928 -> V=1.0, theta=0.0
% INFO    : Bus 2149	: V=0.9855329, theta=-78.32983 -> V=1.0, theta=0.0
% INFO    : Bus 2150	: V=0.9944204, theta=-76.745171 -> V=1.0, theta=0.0
% INFO    : Bus 2151	: V=0.9808327, theta=-78.085672 -> V=1.0, theta=0.0
% INFO    : Bus 2152	: V=0.992007, theta=-76.966579 -> V=1.0, theta=0.0
% INFO    : Bus 2153	: V=0.9908539, theta=-77.048636 -> V=1.0, theta=0.0
% INFO    : Bus 2154	: V=0.9842945, theta=-78.129322 -> V=1.0, theta=0.0
% INFO    : Bus 2155	: V=0.9897007, theta=-77.118882 -> V=1.0, theta=0.0
% INFO    : Bus 2156	: V=0.9848464, theta=-78.219815 -> V=1.0, theta=0.0
% INFO    : Bus 2157	: V=0.9645032, theta=-80.436088 -> V=1.0, theta=0.0
% INFO    : Bus 2158	: V=0.9874326, theta=-77.216164 -> V=1.0, theta=0.0
% INFO    : Bus 2159	: V=0.9891661, theta=-76.98895 -> V=1.0, theta=0.0
% INFO    : Bus 2160	: V=0.991266, theta=-76.727647 -> V=1.0, theta=0.0
% INFO    : Bus 2161	: V=0.9935807, theta=-76.608065 -> V=1.0, theta=0.0
% INFO    : Bus 2162	: V=0.9975568, theta=-76.352733 -> V=1.0, theta=0.0
% INFO    : Bus 2163	: V=0.9987418, theta=-76.330154 -> V=1.0, theta=0.0
% INFO    : Bus 2164	: V=0.9971141, theta=-76.495559 -> V=1.0, theta=0.0
% INFO    : Bus 2165	: V=0.9856155, theta=-78.274211 -> V=1.0, theta=0.0
% INFO    : Bus 2166	: V=0.9932961, theta=-77.369962 -> V=1.0, theta=0.0
% INFO    : Bus 2167	: V=1.0028851, theta=-75.992866 -> V=1.0, theta=0.0
% INFO    : Bus 2168	: V=1.0058107, theta=-75.656231 -> V=1.0, theta=0.0
% INFO    : Bus 2169	: V=0.9550149, theta=-79.964448 -> V=1.0, theta=0.0
% INFO    : Bus 2170	: V=0.9785262, theta=-77.320329 -> V=1.0, theta=0.0
% INFO    : Bus 2171	: V=0.9607077, theta=-79.549783 -> V=1.0, theta=0.0
% INFO    : Bus 2172	: V=0.9753849, theta=-76.969694 -> V=1.0, theta=0.0
% INFO    : Bus 2173	: V=0.9610361, theta=-78.424521 -> V=1.0, theta=0.0
% INFO    : Bus 2174	: V=0.9611102, theta=-78.442605 -> V=1.0, theta=0.0
% INFO    : Bus 2175	: V=0.958568, theta=-78.484177 -> V=1.0, theta=0.0
% INFO    : Bus 2176	: V=0.9573456, theta=-78.501294 -> V=1.0, theta=0.0
% INFO    : Bus 2177	: V=0.9836327, theta=-79.550862 -> V=1.0, theta=0.0
% INFO    : Bus 2178	: V=0.98346, theta=-79.588087 -> V=1.0, theta=0.0
% INFO    : Bus 2179	: V=0.9876167, theta=-78.982676 -> V=1.0, theta=0.0
% INFO    : Bus 2180	: V=0.9825701, theta=-79.628872 -> V=1.0, theta=0.0
% INFO    : Bus 2181	: V=0.9824704, theta=-79.638803 -> V=1.0, theta=0.0
% INFO    : Bus 2182	: V=0.9801845, theta=-79.762306 -> V=1.0, theta=0.0
% INFO    : Bus 2183	: V=0.9828504, theta=-79.644412 -> V=1.0, theta=0.0
% INFO    : Bus 2184	: V=0.9829749, theta=-79.631801 -> V=1.0, theta=0.0
% INFO    : Bus 2185	: V=0.9989449, theta=-78.158911 -> V=1.0, theta=0.0
% INFO    : Bus 2186	: V=0.9831839, theta=-79.627442 -> V=1.0, theta=0.0
% INFO    : Bus 2187	: V=0.9794226, theta=-79.769515 -> V=1.0, theta=0.0
% INFO    : Bus 2188	: V=0.9746408, theta=-79.743693 -> V=1.0, theta=0.0
% INFO    : Bus 2189	: V=0.9694391, theta=-80.045039 -> V=1.0, theta=0.0
% INFO    : Bus 2190	: V=0.975641, theta=-79.645662 -> V=1.0, theta=0.0
% INFO    : Bus 2191	: V=0.9796345, theta=-79.348837 -> V=1.0, theta=0.0
% INFO    : Bus 2192	: V=0.9784151, theta=-79.373372 -> V=1.0, theta=0.0
% INFO    : Bus 2193	: V=0.9872648, theta=-78.361318 -> V=1.0, theta=0.0
% INFO    : Bus 2194	: V=0.9722604, theta=-79.817438 -> V=1.0, theta=0.0
% INFO    : Bus 2195	: V=0.9753149, theta=-79.332581 -> V=1.0, theta=0.0
% INFO    : Bus 2196	: V=0.989217, theta=-78.046178 -> V=1.0, theta=0.0
% INFO    : Bus 2197	: V=0.9768891, theta=-79.263739 -> V=1.0, theta=0.0
% INFO    : Bus 2198	: V=0.9863716, theta=-78.41042 -> V=1.0, theta=0.0
% INFO    : Bus 2199	: V=0.9756246, theta=-79.481909 -> V=1.0, theta=0.0
% INFO    : Bus 2200	: V=0.9738766, theta=-79.447454 -> V=1.0, theta=0.0
% INFO    : Bus 2201	: V=0.9752163, theta=-79.432463 -> V=1.0, theta=0.0
% INFO    : Bus 2202	: V=0.9761797, theta=-79.250838 -> V=1.0, theta=0.0
% INFO    : Bus 2203	: V=0.9858716, theta=-78.29878 -> V=1.0, theta=0.0
% INFO    : Bus 2204	: V=0.9764332, theta=-79.264464 -> V=1.0, theta=0.0
% INFO    : Bus 2205	: V=0.9929238, theta=-77.478171 -> V=1.0, theta=0.0
% INFO    : Bus 2206	: V=0.9967415, theta=-76.937115 -> V=1.0, theta=0.0
% INFO    : Bus 2207	: V=0.9980319, theta=-76.708046 -> V=1.0, theta=0.0
% INFO    : Bus 2208	: V=1.0018599, theta=-76.464604 -> V=1.0, theta=0.0
% INFO    : Bus 2209	: V=1.0076439, theta=-75.892758 -> V=1.0, theta=0.0
% INFO    : Bus 2210	: V=1.0141272, theta=-75.281464 -> V=1.0, theta=0.0
% INFO    : Bus 2211	: V=1.0013094, theta=-76.262262 -> V=1.0, theta=0.0
% INFO    : Bus 2212	: V=1.0032039, theta=-76.079439 -> V=1.0, theta=0.0
% INFO    : Bus 2213	: V=0.9823761, theta=-77.985037 -> V=1.0, theta=0.0
% INFO    : Bus 2214	: V=0.9823612, theta=-77.925145 -> V=1.0, theta=0.0
% INFO    : Bus 2215	: V=0.9793748, theta=-78.097649 -> V=1.0, theta=0.0
% INFO    : Bus 2216	: V=0.9986534, theta=-76.492004 -> V=1.0, theta=0.0
% INFO    : Bus 2217	: V=0.9858256, theta=-78.662168 -> V=1.0, theta=0.0
% INFO    : Bus 2218	: V=0.9777874, theta=-79.338761 -> V=1.0, theta=0.0
% INFO    : Bus 2219	: V=0.9999958, theta=-76.415892 -> V=1.0, theta=0.0
% INFO    : Bus 2220	: V=0.9740239, theta=-79.840415 -> V=1.0, theta=0.0
% INFO    : Bus 2221	: V=0.9712474, theta=-79.882937 -> V=1.0, theta=0.0
% INFO    : Bus 2222	: V=0.9884513, theta=-78.291455 -> V=1.0, theta=0.0
% INFO    : Bus 2223	: V=0.9909126, theta=-78.055187 -> V=1.0, theta=0.0
% INFO    : Bus 2224	: V=0.9724861, theta=-79.949076 -> V=1.0, theta=0.0
% INFO    : Bus 2225	: V=0.9764729, theta=-79.660851 -> V=1.0, theta=0.0
% INFO    : Bus 2226	: V=0.9779161, theta=-79.553619 -> V=1.0, theta=0.0
% INFO    : Bus 2227	: V=0.9923986, theta=-77.839823 -> V=1.0, theta=0.0
% INFO    : Bus 2228	: V=1.0121644, theta=-75.527511 -> V=1.0, theta=0.0
% INFO    : Bus 2229	: V=0.9831908, theta=-78.310142 -> V=1.0, theta=0.0
% INFO    : Bus 2230	: V=0.990137, theta=-77.708042 -> V=1.0, theta=0.0
% INFO    : Bus 2231	: V=0.9906462, theta=-77.779003 -> V=1.0, theta=0.0
% INFO    : Bus 2232	: V=0.9844331, theta=-78.837246 -> V=1.0, theta=0.0
% INFO    : Bus 2233	: V=0.9831742, theta=-78.927114 -> V=1.0, theta=0.0
% INFO    : Bus 2234	: V=1.0115577, theta=-75.756254 -> V=1.0, theta=0.0
% INFO    : Bus 2235	: V=0.9920305, theta=-78.035644 -> V=1.0, theta=0.0
% INFO    : Bus 2236	: V=0.9938297, theta=-78.251941 -> V=1.0, theta=0.0
% INFO    : Bus 2237	: V=0.989987, theta=-78.223004 -> V=1.0, theta=0.0
% INFO    : Bus 2238	: V=0.9913324, theta=-78.35758 -> V=1.0, theta=0.0
% INFO    : Bus 2239	: V=0.9846604, theta=-79.063332 -> V=1.0, theta=0.0
% INFO    : Bus 2240	: V=0.9913709, theta=-78.763909 -> V=1.0, theta=0.0
% INFO    : Bus 2241	: V=0.9997374, theta=-78.040491 -> V=1.0, theta=0.0
% INFO    : Bus 2242	: V=0.9984545, theta=-78.107477 -> V=1.0, theta=0.0
% INFO    : Bus 2243	: V=0.9981624, theta=-78.16556 -> V=1.0, theta=0.0
% INFO    : Bus 2244	: V=0.9931081, theta=-78.655339 -> V=1.0, theta=0.0
% INFO    : Bus 2245	: V=0.9922855, theta=-78.734692 -> V=1.0, theta=0.0
% INFO    : Bus 2246	: V=0.9990002, theta=-78.119945 -> V=1.0, theta=0.0
% INFO    : Bus 2247	: V=0.9999321, theta=-78.067497 -> V=1.0, theta=0.0
% INFO    : Bus 2248	: V=1.0012346, theta=-77.959268 -> V=1.0, theta=0.0
% INFO    : Bus 2249	: V=1.0023304, theta=-77.898131 -> V=1.0, theta=0.0
% INFO    : Bus 2250	: V=1.0030792, theta=-77.825018 -> V=1.0, theta=0.0
% INFO    : Bus 2251	: V=1.0028327, theta=-77.91636 -> V=1.0, theta=0.0
% INFO    : Bus 2252	: V=1.002436, theta=-77.920385 -> V=1.0, theta=0.0
% INFO    : Bus 2253	: V=1.0188692, theta=-76.034169 -> V=1.0, theta=0.0
% INFO    : Bus 2254	: V=0.9995777, theta=-78.264302 -> V=1.0, theta=0.0
% INFO    : Bus 2255	: V=0.9945482, theta=-78.345211 -> V=1.0, theta=0.0
% INFO    : Bus 2256	: V=0.9902815, theta=-78.825356 -> V=1.0, theta=0.0
% INFO    : Bus 2257	: V=1.000829, theta=-77.904046 -> V=1.0, theta=0.0
% INFO    : Bus 2258	: V=1.0009636, theta=-77.973732 -> V=1.0, theta=0.0
% INFO    : Bus 2259	: V=0.9951858, theta=-78.588893 -> V=1.0, theta=0.0
% INFO    : Bus 2260	: V=0.9964321, theta=-78.133497 -> V=1.0, theta=0.0
% INFO    : Bus 2261	: V=0.9849474, theta=-79.068221 -> V=1.0, theta=0.0
% INFO    : Bus 2262	: V=0.9945188, theta=-78.333651 -> V=1.0, theta=0.0
% INFO    : Bus 2263	: V=0.9946042, theta=-78.320657 -> V=1.0, theta=0.0
% INFO    : Bus 2264	: V=1.0193735, theta=-76.061261 -> V=1.0, theta=0.0
% INFO    : Bus 2265	: V=0.9902465, theta=-78.718611 -> V=1.0, theta=0.0
% INFO    : Bus 2266	: V=0.9801706, theta=-79.391446 -> V=1.0, theta=0.0
% INFO    : Bus 2267	: V=0.9789619, theta=-79.4065 -> V=1.0, theta=0.0
% INFO    : Bus 2268	: V=0.9904819, theta=-78.461756 -> V=1.0, theta=0.0
% INFO    : Bus 2269	: V=0.9790234, theta=-79.310317 -> V=1.0, theta=0.0
% INFO    : Bus 2270	: V=0.9807669, theta=-79.245359 -> V=1.0, theta=0.0
% INFO    : Bus 2271	: V=0.982774, theta=-79.120991 -> V=1.0, theta=0.0
% INFO    : Bus 2272	: V=0.9774271, theta=-79.362718 -> V=1.0, theta=0.0
% INFO    : Bus 2273	: V=0.9786927, theta=-79.334721 -> V=1.0, theta=0.0
% INFO    : Bus 2274	: V=0.9734836, theta=-79.482855 -> V=1.0, theta=0.0
% INFO    : Bus 2275	: V=0.975183, theta=-79.442856 -> V=1.0, theta=0.0
% INFO    : Bus 2276	: V=0.9667487, theta=-80.395314 -> V=1.0, theta=0.0
% INFO    : Bus 2277	: V=0.9687349, theta=-80.342263 -> V=1.0, theta=0.0
% INFO    : Bus 2278	: V=0.9846889, theta=-79.050987 -> V=1.0, theta=0.0
% INFO    : Bus 2279	: V=0.9721486, theta=-80.147365 -> V=1.0, theta=0.0
% INFO    : Bus 2280	: V=0.9937746, theta=-78.357292 -> V=1.0, theta=0.0
% INFO    : Bus 2281	: V=0.9871646, theta=-78.903648 -> V=1.0, theta=0.0
% INFO    : Bus 2282	: V=0.9885158, theta=-78.889711 -> V=1.0, theta=0.0
% INFO    : Bus 2283	: V=0.992023, theta=-78.693547 -> V=1.0, theta=0.0
% INFO    : Bus 2284	: V=0.9969271, theta=-78.425319 -> V=1.0, theta=0.0
% INFO    : Bus 2285	: V=0.9998026, theta=-78.255729 -> V=1.0, theta=0.0
% INFO    : Bus 2286	: V=0.9743942, theta=-79.692615 -> V=1.0, theta=0.0
% INFO    : Bus 2287	: V=0.9853602, theta=-77.557502 -> V=1.0, theta=0.0
% INFO    : Bus 2288	: V=0.9912142, theta=-76.933935 -> V=1.0, theta=0.0
% INFO    : Bus 2289	: V=0.9868032, theta=-77.476841 -> V=1.0, theta=0.0
% INFO    : Bus 2290	: V=1.0030616, theta=-76.035443 -> V=1.0, theta=0.0
% INFO    : Bus 2291	: V=1.0057768, theta=-75.870581 -> V=1.0, theta=0.0
% INFO    : Bus 2292	: V=1.008706, theta=-75.618573 -> V=1.0, theta=0.0
% INFO    : Bus 2293	: V=1.0062938, theta=-75.851968 -> V=1.0, theta=0.0
% INFO    : Bus 2294	: V=0.9950242, theta=-76.570961 -> V=1.0, theta=0.0
% INFO    : Bus 2295	: V=0.9977691, theta=-76.73847 -> V=1.0, theta=0.0
% INFO    : Bus 2296	: V=1.0117122, theta=-75.360981 -> V=1.0, theta=0.0
% INFO    : Bus 2297	: V=1.0114047, theta=-74.958209 -> V=1.0, theta=0.0
% INFO    : Bus 2298	: V=0.9847159, theta=-78.554614 -> V=1.0, theta=0.0
% INFO    : Bus 2299	: V=0.9849937, theta=-78.577475 -> V=1.0, theta=0.0
% INFO    : Bus 2300	: V=0.985782, theta=-78.581807 -> V=1.0, theta=0.0
% INFO    : Bus 2301	: V=0.9805842, theta=-79.124731 -> V=1.0, theta=0.0
% INFO    : Bus 2302	: V=0.9793986, theta=-79.151245 -> V=1.0, theta=0.0
% INFO    : Bus 2303	: V=0.9917366, theta=-77.814725 -> V=1.0, theta=0.0
% INFO    : Bus 2304	: V=0.9745213, theta=-79.277139 -> V=1.0, theta=0.0
% INFO    : Bus 2305	: V=0.9765863, theta=-79.388051 -> V=1.0, theta=0.0
% INFO    : Bus 2306	: V=0.9871198, theta=-78.33139 -> V=1.0, theta=0.0
% INFO    : Bus 2307	: V=0.9855809, theta=-79.445897 -> V=1.0, theta=0.0
% INFO    : Bus 2308	: V=0.9823938, theta=-79.305473 -> V=1.0, theta=0.0
% INFO    : Bus 2309	: V=0.9838147, theta=-79.469961 -> V=1.0, theta=0.0
% INFO    : Bus 2310	: V=0.9831468, theta=-79.295946 -> V=1.0, theta=0.0
% INFO    : Bus 2311	: V=1.0006451, theta=-77.887655 -> V=1.0, theta=0.0
% INFO    : Bus 2312	: V=0.9837666, theta=-79.299103 -> V=1.0, theta=0.0
% INFO    : Bus 2313	: V=0.9808956, theta=-79.421623 -> V=1.0, theta=0.0
% INFO    : Bus 2314	: V=0.982411, theta=-78.62932 -> V=1.0, theta=0.0
% INFO    : Bus 2315	: V=0.9718187, theta=-79.648096 -> V=1.0, theta=0.0
% INFO    : Bus 2316	: V=0.9813967, theta=-78.697749 -> V=1.0, theta=0.0
% INFO    : Bus 2317	: V=0.9899022, theta=-78.251448 -> V=1.0, theta=0.0
% INFO    : Bus 2318	: V=0.9881598, theta=-78.276712 -> V=1.0, theta=0.0
% INFO    : Bus 2319	: V=0.9822241, theta=-78.420091 -> V=1.0, theta=0.0
% INFO    : Bus 2320	: V=0.9834215, theta=-78.272332 -> V=1.0, theta=0.0
% INFO    : Bus 2321	: V=0.9669788, theta=-79.992846 -> V=1.0, theta=0.0
% INFO    : Bus 2322	: V=0.969912, theta=-79.91641 -> V=1.0, theta=0.0
% INFO    : Bus 2323	: V=0.9833176, theta=-78.219369 -> V=1.0, theta=0.0
% INFO    : Bus 2324	: V=0.9731343, theta=-79.346003 -> V=1.0, theta=0.0
% INFO    : Bus 2325	: V=0.9850133, theta=-78.09193 -> V=1.0, theta=0.0
% INFO    : Bus 2326	: V=0.97458, theta=-78.778291 -> V=1.0, theta=0.0
% INFO    : Bus 2327	: V=0.9761554, theta=-78.758556 -> V=1.0, theta=0.0
% INFO    : Bus 2328	: V=0.9747267, theta=-78.773257 -> V=1.0, theta=0.0
% INFO    : Bus 2329	: V=0.9799392, theta=-78.449698 -> V=1.0, theta=0.0
% INFO    : Bus 2330	: V=0.9831282, theta=-78.283347 -> V=1.0, theta=0.0
% INFO    : Bus 2331	: V=0.9804709, theta=-78.357599 -> V=1.0, theta=0.0
% INFO    : Bus 2332	: V=0.9863829, theta=-77.945139 -> V=1.0, theta=0.0
% INFO    : Bus 2333	: V=0.9862416, theta=-77.86171 -> V=1.0, theta=0.0
% INFO    : Bus 2334	: V=0.9882332, theta=-77.774668 -> V=1.0, theta=0.0
% INFO    : Bus 2335	: V=0.9931839, theta=-77.01736 -> V=1.0, theta=0.0
% INFO    : Bus 2336	: V=1.0119447, theta=-75.277185 -> V=1.0, theta=0.0
% INFO    : Bus 2337	: V=0.9742184, theta=-79.396165 -> V=1.0, theta=0.0
% INFO    : Bus 2338	: V=0.9707398, theta=-79.522156 -> V=1.0, theta=0.0
% INFO    : Bus 2339	: V=0.9740551, theta=-79.455909 -> V=1.0, theta=0.0
% INFO    : Bus 2340	: V=0.9730359, theta=-79.505489 -> V=1.0, theta=0.0
% INFO    : Bus 2341	: V=0.9820655, theta=-78.583247 -> V=1.0, theta=0.0
% INFO    : Bus 2342	: V=0.9828292, theta=-78.539369 -> V=1.0, theta=0.0
% INFO    : Bus 2343	: V=0.9847891, theta=-78.504808 -> V=1.0, theta=0.0
% INFO    : Bus 2344	: V=0.985215, theta=-78.438723 -> V=1.0, theta=0.0
% INFO    : Bus 2345	: V=0.9731179, theta=-79.497184 -> V=1.0, theta=0.0
% INFO    : Bus 2346	: V=0.9723909, theta=-79.527381 -> V=1.0, theta=0.0
% INFO    : Bus 2347	: V=0.9720555, theta=-79.536594 -> V=1.0, theta=0.0
% INFO    : Bus 2348	: V=0.9711894, theta=-79.571761 -> V=1.0, theta=0.0
% INFO    : Bus 2349	: V=0.9705828, theta=-79.551481 -> V=1.0, theta=0.0
% INFO    : Bus 2350	: V=0.976329, theta=-78.499076 -> V=1.0, theta=0.0
% INFO    : Bus 2351	: V=0.9767036, theta=-78.467609 -> V=1.0, theta=0.0
% INFO    : Bus 2352	: V=0.9731235, theta=-79.21862 -> V=1.0, theta=0.0
% INFO    : Bus 2353	: V=0.9736349, theta=-79.410726 -> V=1.0, theta=0.0
% INFO    : Bus 2354	: V=0.9740619, theta=-79.405022 -> V=1.0, theta=0.0
% INFO    : Bus 2355	: V=0.977499, theta=-78.408885 -> V=1.0, theta=0.0
% INFO    : Bus 2356	: V=0.9847257, theta=-78.409406 -> V=1.0, theta=0.0
% INFO    : Bus 2357	: V=1.0095208, theta=-75.617375 -> V=1.0, theta=0.0
% INFO    : Bus 2358	: V=0.9782105, theta=-78.383613 -> V=1.0, theta=0.0
% INFO    : Bus 2359	: V=0.9720808, theta=-79.455052 -> V=1.0, theta=0.0
% INFO    : Bus 2360	: V=0.9770371, theta=-78.480535 -> V=1.0, theta=0.0
% INFO    : Bus 2361	: V=0.9737858, theta=-78.859015 -> V=1.0, theta=0.0
% INFO    : Bus 2362	: V=0.9738251, theta=-78.861788 -> V=1.0, theta=0.0
% INFO    : Bus 2363	: V=0.9795185, theta=-78.291831 -> V=1.0, theta=0.0
% INFO    : Bus 2364	: V=0.9805282, theta=-78.209989 -> V=1.0, theta=0.0
% INFO    : Bus 2365	: V=0.9734269, theta=-78.853285 -> V=1.0, theta=0.0
% INFO    : Bus 2366	: V=0.9836913, theta=-77.964898 -> V=1.0, theta=0.0
% INFO    : Bus 2367	: V=0.9840046, theta=-77.901682 -> V=1.0, theta=0.0
% INFO    : Bus 2368	: V=0.9802655, theta=-78.18726 -> V=1.0, theta=0.0
% INFO    : Bus 2369	: V=0.97768, theta=-78.489783 -> V=1.0, theta=0.0
% INFO    : Bus 2370	: V=0.9951234, theta=-76.977629 -> V=1.0, theta=0.0
% INFO    : Bus 2371	: V=0.9816222, theta=-78.337703 -> V=1.0, theta=0.0
% INFO    : Bus 2372	: V=0.996859, theta=-76.891783 -> V=1.0, theta=0.0
% INFO    : Bus 2373	: V=0.992928, theta=-77.112723 -> V=1.0, theta=0.0
% INFO    : Bus 2374	: V=0.98691, theta=-77.662892 -> V=1.0, theta=0.0
% INFO    : Bus 2375	: V=0.9802948, theta=-78.402582 -> V=1.0, theta=0.0
% INFO    : Bus 2376	: V=0.9936041, theta=-76.978969 -> V=1.0, theta=0.0
% INFO    : Bus 2377	: V=0.9871991, theta=-77.610996 -> V=1.0, theta=0.0
% INFO    : Bus 2378	: V=1.0121848, theta=-74.901564 -> V=1.0, theta=0.0
% INFO    : Bus 2379	: V=0.9887511, theta=-77.233302 -> V=1.0, theta=0.0
% INFO    : Bus 2380	: V=0.9902627, theta=-77.188473 -> V=1.0, theta=0.0
% INFO    : Bus 2381	: V=0.9973066, theta=-76.600684 -> V=1.0, theta=0.0
% INFO    : Bus 2382	: V=0.9968054, theta=-76.543147 -> V=1.0, theta=0.0
% INFO    : Bus 2383	: V=0.9986982, theta=-76.312694 -> V=1.0, theta=0.0
% INFO    : Bus 2384	: V=0.9972469, theta=-76.380754 -> V=1.0, theta=0.0
% INFO    : Bus 2385	: V=0.9981185, theta=-76.138707 -> V=1.0, theta=0.0
% INFO    : Bus 2386	: V=0.9919614, theta=-76.758402 -> V=1.0, theta=0.0
% INFO    : Bus 2387	: V=0.9945773, theta=-76.317357 -> V=1.0, theta=0.0
% INFO    : Bus 2388	: V=0.9997752, theta=-75.843805 -> V=1.0, theta=0.0
% INFO    : Bus 2389	: V=0.9976185, theta=-76.419143 -> V=1.0, theta=0.0
% INFO    : Bus 2390	: V=0.9960591, theta=-76.679127 -> V=1.0, theta=0.0
% INFO    : Bus 2391	: V=0.9998285, theta=-76.04841 -> V=1.0, theta=0.0
% INFO    : Bus 2392	: V=0.9991902, theta=-75.998788 -> V=1.0, theta=0.0
% INFO    : Bus 2393	: V=0.9996962, theta=-76.237594 -> V=1.0, theta=0.0
% INFO    : Bus 2394	: V=0.9932688, theta=-76.886397 -> V=1.0, theta=0.0
% INFO    : Bus 2395	: V=0.99499, theta=-76.779331 -> V=1.0, theta=0.0
% INFO    : Bus 2396	: V=0.9965864, theta=-76.569222 -> V=1.0, theta=0.0
% INFO    : Bus 2397	: V=0.9756039, theta=-78.32203 -> V=1.0, theta=0.0
% INFO    : Bus 2398	: V=0.9902653, theta=-77.156354 -> V=1.0, theta=0.0
% INFO    : Bus 2399	: V=0.9957517, theta=-76.371092 -> V=1.0, theta=0.0
% INFO    : Bus 2400	: V=1.0028731, theta=-75.823781 -> V=1.0, theta=0.0
% INFO    : Bus 2401	: V=1.0016701, theta=-75.861223 -> V=1.0, theta=0.0
% INFO    : Bus 2402	: V=0.9959401, theta=-76.271621 -> V=1.0, theta=0.0
% INFO    : Bus 2403	: V=0.9981353, theta=-75.668453 -> V=1.0, theta=0.0
% INFO    : Bus 2404	: V=0.9929818, theta=-76.055691 -> V=1.0, theta=0.0
% INFO    : Bus 2405	: V=0.9952541, theta=-75.887063 -> V=1.0, theta=0.0
% INFO    : Bus 2406	: V=0.9795693, theta=-78.393037 -> V=1.0, theta=0.0
% INFO    : Bus 2407	: V=0.980835, theta=-79.714367 -> V=1.0, theta=0.0
% INFO    : Bus 2408	: V=0.9781408, theta=-79.608791 -> V=1.0, theta=0.0
% INFO    : Bus 2409	: V=0.9784443, theta=-79.605048 -> V=1.0, theta=0.0
% INFO    : Bus 2410	: V=0.9776689, theta=-79.604756 -> V=1.0, theta=0.0
% INFO    : Bus 2411	: V=0.978243, theta=-79.773553 -> V=1.0, theta=0.0
% INFO    : Bus 2412	: V=0.9793076, theta=-79.750972 -> V=1.0, theta=0.0
% INFO    : Bus 2413	: V=0.9785527, theta=-79.771846 -> V=1.0, theta=0.0
% INFO    : Bus 2414	: V=0.9779287, theta=-79.772421 -> V=1.0, theta=0.0
% INFO    : Bus 2415	: V=0.9791651, theta=-79.752595 -> V=1.0, theta=0.0
% INFO    : Bus 2416	: V=0.9789448, theta=-79.75292 -> V=1.0, theta=0.0
% INFO    : Bus 2417	: V=0.9896007, theta=-78.554061 -> V=1.0, theta=0.0
% INFO    : Bus 2418	: V=0.9902033, theta=-78.552893 -> V=1.0, theta=0.0
% INFO    : Bus 2419	: V=0.9909136, theta=-78.533192 -> V=1.0, theta=0.0
% INFO    : Bus 2420	: V=0.9924859, theta=-78.478589 -> V=1.0, theta=0.0
% INFO    : Bus 2421	: V=0.9917051, theta=-78.509165 -> V=1.0, theta=0.0
% INFO    : Bus 2422	: V=0.9931059, theta=-78.460734 -> V=1.0, theta=0.0
% INFO    : Bus 2423	: V=0.9936207, theta=-78.428778 -> V=1.0, theta=0.0
% INFO    : Bus 2424	: V=0.9847829, theta=-79.481527 -> V=1.0, theta=0.0
% INFO    : Bus 2425	: V=0.9877044, theta=-79.271628 -> V=1.0, theta=0.0
% INFO    : Bus 2426	: V=0.9861389, theta=-79.389789 -> V=1.0, theta=0.0
% INFO    : Bus 2427	: V=0.9848007, theta=-79.47277 -> V=1.0, theta=0.0
% INFO    : Bus 2428	: V=0.9994673, theta=-78.126985 -> V=1.0, theta=0.0
% INFO    : Bus 2429	: V=0.9870451, theta=-79.323381 -> V=1.0, theta=0.0
% INFO    : Bus 2430	: V=0.9864775, theta=-79.354939 -> V=1.0, theta=0.0
% INFO    : Bus 2431	: V=0.9962999, theta=-78.301601 -> V=1.0, theta=0.0
% INFO    : Bus 2432	: V=0.9861, theta=-79.390003 -> V=1.0, theta=0.0
% INFO    : Bus 2433	: V=0.9879366, theta=-79.294764 -> V=1.0, theta=0.0
% INFO    : Bus 2434	: V=0.9887622, theta=-79.227145 -> V=1.0, theta=0.0
% INFO    : Bus 2435	: V=0.9880285, theta=-79.243501 -> V=1.0, theta=0.0
% INFO    : Bus 2436	: V=0.9903604, theta=-79.15158 -> V=1.0, theta=0.0
% INFO    : Bus 2437	: V=0.9910683, theta=-79.093186 -> V=1.0, theta=0.0
% INFO    : Bus 2438	: V=0.9881609, theta=-79.241886 -> V=1.0, theta=0.0
% INFO    : Bus 2439	: V=0.9909165, theta=-79.07583 -> V=1.0, theta=0.0
% INFO    : Bus 2440	: V=0.9913005, theta=-79.056715 -> V=1.0, theta=0.0
% INFO    : Bus 2441	: V=0.9996101, theta=-78.106856 -> V=1.0, theta=0.0
% INFO    : Bus 2442	: V=0.9912057, theta=-79.057736 -> V=1.0, theta=0.0
% INFO    : Bus 2443	: V=0.9915931, theta=-79.017788 -> V=1.0, theta=0.0
% INFO    : Bus 2444	: V=0.9914145, theta=-79.013687 -> V=1.0, theta=0.0
% INFO    : Bus 2445	: V=0.9914859, theta=-79.012796 -> V=1.0, theta=0.0
% INFO    : Bus 2446	: V=0.9916618, theta=-78.986997 -> V=1.0, theta=0.0
% INFO    : Bus 2447	: V=0.9915101, theta=-79.007429 -> V=1.0, theta=0.0
% INFO    : Bus 2448	: V=0.9898637, theta=-79.153898 -> V=1.0, theta=0.0
% INFO    : Bus 2449	: V=0.9923526, theta=-78.969369 -> V=1.0, theta=0.0
% INFO    : Bus 2450	: V=0.9901883, theta=-79.167273 -> V=1.0, theta=0.0
% INFO    : Bus 2451	: V=1.001146, theta=-78.026796 -> V=1.0, theta=0.0
% INFO    : Bus 2452	: V=1.0005594, theta=-78.059027 -> V=1.0, theta=0.0
% INFO    : Bus 2453	: V=1.002023, theta=-77.970101 -> V=1.0, theta=0.0
% INFO    : Bus 2454	: V=0.9898871, theta=-79.187059 -> V=1.0, theta=0.0
% INFO    : Bus 2455	: V=0.9905586, theta=-79.139936 -> V=1.0, theta=0.0
% INFO    : Bus 2456	: V=0.9885086, theta=-79.319419 -> V=1.0, theta=0.0
% INFO    : Bus 2457	: V=0.9889181, theta=-79.253595 -> V=1.0, theta=0.0
% INFO    : Bus 2458	: V=0.9879336, theta=-79.351933 -> V=1.0, theta=0.0
% INFO    : Bus 2459	: V=0.9882961, theta=-79.313917 -> V=1.0, theta=0.0
% INFO    : Bus 2460	: V=0.9883822, theta=-79.31255 -> V=1.0, theta=0.0
% INFO    : Bus 2461	: V=0.988428, theta=-79.319722 -> V=1.0, theta=0.0
% INFO    : Bus 2462	: V=1.0008819, theta=-78.037756 -> V=1.0, theta=0.0
% INFO    : Bus 2463	: V=0.9873973, theta=-79.339029 -> V=1.0, theta=0.0
% INFO    : Bus 2464	: V=0.9868927, theta=-79.679118 -> V=1.0, theta=0.0
% INFO    : Bus 2465	: V=0.9874021, theta=-79.390306 -> V=1.0, theta=0.0
% INFO    : Bus 2466	: V=0.9935178, theta=-78.815961 -> V=1.0, theta=0.0
% INFO    : Bus 2467	: V=0.993197, theta=-78.83924 -> V=1.0, theta=0.0
% INFO    : Bus 2468	: V=0.9932885, theta=-78.838036 -> V=1.0, theta=0.0
% INFO    : Bus 2469	: V=0.9928456, theta=-78.843661 -> V=1.0, theta=0.0
% INFO    : Bus 2470	: V=0.9935378, theta=-78.835459 -> V=1.0, theta=0.0
% INFO    : Bus 2471	: V=0.9996441, theta=-78.103911 -> V=1.0, theta=0.0
% INFO    : Bus 2472	: V=0.99399, theta=-78.795757 -> V=1.0, theta=0.0
% INFO    : Bus 2473	: V=0.9934806, theta=-78.824105 -> V=1.0, theta=0.0
% INFO    : Bus 2474	: V=0.9931865, theta=-78.827712 -> V=1.0, theta=0.0
% INFO    : Bus 2475	: V=0.9829653, theta=-79.894012 -> V=1.0, theta=0.0
% INFO    : Bus 2476	: V=1.0189132, theta=-76.209996 -> V=1.0, theta=0.0
% INFO    : Bus 2477	: V=0.9982401, theta=-78.19218 -> V=1.0, theta=0.0
% INFO    : Bus 2478	: V=0.9984662, theta=-78.178904 -> V=1.0, theta=0.0
% INFO    : Bus 2479	: V=0.9896063, theta=-79.163143 -> V=1.0, theta=0.0
% INFO    : Bus 2480	: V=0.990555, theta=-79.150294 -> V=1.0, theta=0.0
% INFO    : Bus 2481	: V=0.998475, theta=-78.178859 -> V=1.0, theta=0.0
% INFO    : Bus 2482	: V=0.9887546, theta=-79.210043 -> V=1.0, theta=0.0
% INFO    : Bus 2483	: V=0.9888219, theta=-79.223809 -> V=1.0, theta=0.0
% INFO    : Bus 2484	: V=0.9885161, theta=-79.212605 -> V=1.0, theta=0.0
% INFO    : Bus 2485	: V=0.9884557, theta=-79.256818 -> V=1.0, theta=0.0
% INFO    : Bus 2486	: V=0.9975275, theta=-78.251701 -> V=1.0, theta=0.0
% INFO    : Bus 2487	: V=0.9986272, theta=-78.170763 -> V=1.0, theta=0.0
% INFO    : Bus 2488	: V=0.9971649, theta=-78.268173 -> V=1.0, theta=0.0
% INFO    : Bus 2489	: V=0.9877905, theta=-79.287269 -> V=1.0, theta=0.0
% INFO    : Bus 2490	: V=0.9879272, theta=-79.285723 -> V=1.0, theta=0.0
% INFO    : Bus 2491	: V=0.9876187, theta=-79.288436 -> V=1.0, theta=0.0
% INFO    : Bus 2492	: V=0.9857591, theta=-79.381304 -> V=1.0, theta=0.0
% INFO    : Bus 2493	: V=0.9852621, theta=-79.465408 -> V=1.0, theta=0.0
% INFO    : Bus 2494	: V=0.9846276, theta=-79.517703 -> V=1.0, theta=0.0
% INFO    : Bus 2495	: V=0.9994069, theta=-78.130955 -> V=1.0, theta=0.0
% INFO    : Bus 2496	: V=0.9830815, theta=-79.619429 -> V=1.0, theta=0.0
% INFO    : Bus 2497	: V=0.9825915, theta=-79.624083 -> V=1.0, theta=0.0
% INFO    : Bus 2498	: V=0.9805742, theta=-79.620147 -> V=1.0, theta=0.0
% INFO    : Bus 2499	: V=0.9803017, theta=-79.609773 -> V=1.0, theta=0.0
% INFO    : Bus 2500	: V=0.9803136, theta=-79.605358 -> V=1.0, theta=0.0
% INFO    : Bus 2501	: V=0.9809344, theta=-79.60227 -> V=1.0, theta=0.0
% INFO    : Bus 2502	: V=0.980656, theta=-79.606184 -> V=1.0, theta=0.0
% INFO    : Bus 2503	: V=0.9800185, theta=-79.60822 -> V=1.0, theta=0.0
% INFO    : Bus 2504	: V=0.9815884, theta=-79.9386 -> V=1.0, theta=0.0
% INFO    : Bus 2505	: V=0.9833942, theta=-79.510615 -> V=1.0, theta=0.0
% INFO    : Bus 2506	: V=0.9849364, theta=-79.413593 -> V=1.0, theta=0.0
% INFO    : Bus 2507	: V=0.9846253, theta=-79.442899 -> V=1.0, theta=0.0
% INFO    : Bus 2508	: V=0.9851499, theta=-79.420873 -> V=1.0, theta=0.0
% INFO    : Bus 2509	: V=0.9818957, theta=-79.935742 -> V=1.0, theta=0.0
% INFO    : Bus 2510	: V=0.9822082, theta=-79.933323 -> V=1.0, theta=0.0
% INFO    : Bus 2511	: V=0.9976826, theta=-78.212105 -> V=1.0, theta=0.0
% INFO    : Bus 2512	: V=0.9891902, theta=-78.974276 -> V=1.0, theta=0.0
% INFO    : Bus 2513	: V=0.9970344, theta=-78.228697 -> V=1.0, theta=0.0
% INFO    : Bus 2514	: V=0.991196, theta=-78.817342 -> V=1.0, theta=0.0
% INFO    : Bus 2515	: V=0.9971277, theta=-78.234624 -> V=1.0, theta=0.0
% INFO    : Bus 2516	: V=0.9824968, theta=-79.9285 -> V=1.0, theta=0.0
% INFO    : Bus 2517	: V=0.98227, theta=-79.931227 -> V=1.0, theta=0.0
% INFO    : Bus 2518	: V=0.9968921, theta=-78.242577 -> V=1.0, theta=0.0
% INFO    : Bus 2519	: V=0.9968571, theta=-78.239447 -> V=1.0, theta=0.0
% INFO    : Bus 2520	: V=0.9854173, theta=-79.43826 -> V=1.0, theta=0.0
% INFO    : Bus 2521	: V=0.9851375, theta=-79.440369 -> V=1.0, theta=0.0
% INFO    : Bus 2522	: V=0.9850771, theta=-79.438992 -> V=1.0, theta=0.0
% INFO    : Bus 2523	: V=0.9858179, theta=-79.429849 -> V=1.0, theta=0.0
% INFO    : Bus 2524	: V=0.9966949, theta=-78.241462 -> V=1.0, theta=0.0
% INFO    : Bus 2525	: V=0.9855641, theta=-79.432513 -> V=1.0, theta=0.0
% INFO    : Bus 2526	: V=0.9952691, theta=-78.339573 -> V=1.0, theta=0.0
% INFO    : Bus 2527	: V=0.9948, theta=-78.363322 -> V=1.0, theta=0.0
% INFO    : Bus 2528	: V=0.9848072, theta=-79.363239 -> V=1.0, theta=0.0
% INFO    : Bus 2529	: V=0.9846338, theta=-79.341884 -> V=1.0, theta=0.0
% INFO    : Bus 2530	: V=0.9869393, theta=-79.03972 -> V=1.0, theta=0.0
% INFO    : Bus 2531	: V=0.9873045, theta=-79.035109 -> V=1.0, theta=0.0
% INFO    : Bus 2532	: V=0.9957374, theta=-78.314171 -> V=1.0, theta=0.0
% INFO    : Bus 2533	: V=0.9866809, theta=-79.255254 -> V=1.0, theta=0.0
% INFO    : Bus 2534	: V=0.9872657, theta=-79.248813 -> V=1.0, theta=0.0
% INFO    : Bus 2535	: V=0.9970809, theta=-78.24809 -> V=1.0, theta=0.0
% INFO    : Bus 2536	: V=0.9947875, theta=-78.282146 -> V=1.0, theta=0.0
% INFO    : Bus 2537	: V=0.9932599, theta=-78.335071 -> V=1.0, theta=0.0
% INFO    : Bus 2538	: V=0.9839918, theta=-79.297664 -> V=1.0, theta=0.0
% INFO    : Bus 2539	: V=0.9922352, theta=-78.368262 -> V=1.0, theta=0.0
% INFO    : Bus 2540	: V=0.9846056, theta=-79.314055 -> V=1.0, theta=0.0
% INFO    : Bus 2541	: V=0.9917999, theta=-78.393934 -> V=1.0, theta=0.0
% INFO    : Bus 2542	: V=0.9805608, theta=-79.378471 -> V=1.0, theta=0.0
% INFO    : Bus 2543	: V=0.9815283, theta=-79.297451 -> V=1.0, theta=0.0
% INFO    : Bus 2544	: V=0.9910489, theta=-78.430428 -> V=1.0, theta=0.0
% INFO    : Bus 2545	: V=0.9814749, theta=-79.318089 -> V=1.0, theta=0.0
% INFO    : Bus 2546	: V=0.9858905, theta=-78.625217 -> V=1.0, theta=0.0
% INFO    : Bus 2547	: V=0.9849174, theta=-78.683982 -> V=1.0, theta=0.0
% INFO    : Bus 2548	: V=0.9852881, theta=-78.664784 -> V=1.0, theta=0.0
% INFO    : Bus 2549	: V=0.9799383, theta=-79.354816 -> V=1.0, theta=0.0
% INFO    : Bus 2550	: V=0.9804584, theta=-79.347518 -> V=1.0, theta=0.0
% INFO    : Bus 2551	: V=0.9820967, theta=-79.610374 -> V=1.0, theta=0.0
% INFO    : Bus 2552	: V=0.9819516, theta=-79.373362 -> V=1.0, theta=0.0
% INFO    : Bus 2553	: V=0.9795308, theta=-79.39877 -> V=1.0, theta=0.0
% INFO    : Bus 2554	: V=0.9942745, theta=-78.390367 -> V=1.0, theta=0.0
% INFO    : Bus 2555	: V=0.9811863, theta=-79.624378 -> V=1.0, theta=0.0
% INFO    : Bus 2556	: V=0.9944093, theta=-78.386615 -> V=1.0, theta=0.0
% INFO    : Bus 2557	: V=0.9824099, theta=-79.626277 -> V=1.0, theta=0.0
% INFO    : Bus 2558	: V=0.9820154, theta=-79.6251 -> V=1.0, theta=0.0
% INFO    : Bus 2559	: V=0.9822018, theta=-79.622635 -> V=1.0, theta=0.0
% INFO    : Bus 2560	: V=0.9686901, theta=-80.062029 -> V=1.0, theta=0.0
% INFO    : Bus 2561	: V=0.9707346, theta=-80.018855 -> V=1.0, theta=0.0
% INFO    : Bus 2562	: V=0.9845396, theta=-78.703376 -> V=1.0, theta=0.0
% INFO    : Bus 2563	: V=0.9703578, theta=-80.033822 -> V=1.0, theta=0.0
% INFO    : Bus 2564	: V=0.9761863, theta=-79.603969 -> V=1.0, theta=0.0
% INFO    : Bus 2565	: V=0.9767028, theta=-79.594948 -> V=1.0, theta=0.0
% INFO    : Bus 2566	: V=0.9808767, theta=-79.361115 -> V=1.0, theta=0.0
% INFO    : Bus 2567	: V=0.9802888, theta=-79.383607 -> V=1.0, theta=0.0
% INFO    : Bus 2568	: V=0.9813923, theta=-79.297374 -> V=1.0, theta=0.0
% INFO    : Bus 2569	: V=0.9796476, theta=-79.444129 -> V=1.0, theta=0.0
% INFO    : Bus 2570	: V=0.9886838, theta=-78.348406 -> V=1.0, theta=0.0
% INFO    : Bus 2571	: V=0.9801011, theta=-79.388252 -> V=1.0, theta=0.0
% INFO    : Bus 2572	: V=0.9888999, theta=-78.418961 -> V=1.0, theta=0.0
% INFO    : Bus 2573	: V=0.9874298, theta=-78.521801 -> V=1.0, theta=0.0
% INFO    : Bus 2574	: V=0.9881694, theta=-79.331306 -> V=1.0, theta=0.0
% INFO    : Bus 2575	: V=0.9906837, theta=-79.136535 -> V=1.0, theta=0.0
% INFO    : Bus 2576	: V=1.0009466, theta=-78.080271 -> V=1.0, theta=0.0
% INFO    : Bus 2577	: V=1.0002038, theta=-78.142998 -> V=1.0, theta=0.0
% INFO    : Bus 2578	: V=0.9996238, theta=-78.18768 -> V=1.0, theta=0.0
% INFO    : Bus 2579	: V=0.9987534, theta=-78.227339 -> V=1.0, theta=0.0
% INFO    : Bus 2580	: V=0.9991924, theta=-78.222647 -> V=1.0, theta=0.0
% INFO    : Bus 2581	: V=0.9990275, theta=-78.235141 -> V=1.0, theta=0.0
% INFO    : Bus 2582	: V=0.984055, theta=-79.847949 -> V=1.0, theta=0.0
% INFO    : Bus 2583	: V=0.9833723, theta=-79.858829 -> V=1.0, theta=0.0
% INFO    : Bus 2584	: V=0.9972066, theta=-78.469724 -> V=1.0, theta=0.0
% INFO    : Bus 2585	: V=0.9876727, theta=-79.430656 -> V=1.0, theta=0.0
% INFO    : Bus 2586	: V=0.9870686, theta=-79.439165 -> V=1.0, theta=0.0
% INFO    : Bus 2587	: V=0.9901773, theta=-79.231047 -> V=1.0, theta=0.0
% INFO    : Bus 2588	: V=0.9852956, theta=-79.789888 -> V=1.0, theta=0.0
% INFO    : Bus 2589	: V=0.9889762, theta=-79.339618 -> V=1.0, theta=0.0
% INFO    : Bus 2590	: V=0.9884115, theta=-79.345039 -> V=1.0, theta=0.0
% INFO    : Bus 2591	: V=0.9888826, theta=-79.362893 -> V=1.0, theta=0.0
% INFO    : Bus 2592	: V=0.9891472, theta=-79.376078 -> V=1.0, theta=0.0
% INFO    : Bus 2593	: V=0.987407, theta=-79.651377 -> V=1.0, theta=0.0
% INFO    : Bus 2594	: V=0.9880683, theta=-79.606507 -> V=1.0, theta=0.0
% INFO    : Bus 2595	: V=0.9893284, theta=-79.515418 -> V=1.0, theta=0.0
% INFO    : Bus 2596	: V=0.9895744, theta=-79.512821 -> V=1.0, theta=0.0
% INFO    : Bus 2597	: V=0.9913771, theta=-79.36705 -> V=1.0, theta=0.0
% INFO    : Bus 2598	: V=0.9945362, theta=-78.376267 -> V=1.0, theta=0.0
% INFO    : Bus 2599	: V=0.9782921, theta=-79.507245 -> V=1.0, theta=0.0
% INFO    : Bus 2600	: V=0.9799326, theta=-79.393284 -> V=1.0, theta=0.0
% INFO    : Bus 2601	: V=0.9912688, theta=-78.420377 -> V=1.0, theta=0.0
% INFO    : Bus 2602	: V=0.9926989, theta=-78.844744 -> V=1.0, theta=0.0
% INFO    : Bus 2603	: V=1.0004702, theta=-78.061577 -> V=1.0, theta=0.0
% INFO    : Bus 2604	: V=0.98653, theta=-79.485123 -> V=1.0, theta=0.0
% INFO    : Bus 2605	: V=0.9936935, theta=-78.872625 -> V=1.0, theta=0.0
% INFO    : Bus 2606	: V=1.0184415, theta=-76.230772 -> V=1.0, theta=0.0
% INFO    : Bus 2607	: V=0.9872453, theta=-79.653807 -> V=1.0, theta=0.0
% INFO    : Bus 2608	: V=0.9904585, theta=-79.100548 -> V=1.0, theta=0.0
% INFO    : Bus 2609	: V=0.9831548, theta=-79.62331 -> V=1.0, theta=0.0
% INFO    : Bus 2610	: V=0.9926393, theta=-78.845608 -> V=1.0, theta=0.0
% INFO    : Bus 2611	: V=0.9664976, theta=-77.039881 -> V=1.0, theta=0.0
% INFO    : Bus 2612	: V=0.9824482, theta=-76.108564 -> V=1.0, theta=0.0
% INFO    : Bus 2613	: V=0.9728122, theta=-75.028679 -> V=1.0, theta=0.0
% INFO    : Bus 2614	: V=0.9907146, theta=-73.849565 -> V=1.0, theta=0.0
% INFO    : Bus 2615	: V=0.9776508, theta=-74.966323 -> V=1.0, theta=0.0
% INFO    : Bus 2616	: V=0.9796417, theta=-75.028193 -> V=1.0, theta=0.0
% INFO    : Bus 2617	: V=0.9718682, theta=-75.860684 -> V=1.0, theta=0.0
% INFO    : Bus 2618	: V=0.9838078, theta=-75.168406 -> V=1.0, theta=0.0
% INFO    : Bus 2619	: V=0.9586391, theta=-77.521654 -> V=1.0, theta=0.0
% INFO    : Bus 2620	: V=0.9561414, theta=-78.050465 -> V=1.0, theta=0.0
% INFO    : Bus 2621	: V=0.957268, theta=-78.101952 -> V=1.0, theta=0.0
% INFO    : Bus 2622	: V=0.9818563, theta=-75.720359 -> V=1.0, theta=0.0
% INFO    : Bus 2623	: V=0.9820592, theta=-75.573653 -> V=1.0, theta=0.0
% INFO    : Bus 2624	: V=0.9590521, theta=-78.262769 -> V=1.0, theta=0.0
% INFO    : Bus 2625	: V=1.0034817, theta=-73.974485 -> V=1.0, theta=0.0
% INFO    : Bus 2626	: V=0.9719794, theta=-77.024547 -> V=1.0, theta=0.0
% INFO    : Bus 2627	: V=0.9665026, theta=-77.556062 -> V=1.0, theta=0.0
% INFO    : Bus 2628	: V=0.9650245, theta=-77.750934 -> V=1.0, theta=0.0
% INFO    : Bus 2629	: V=0.9629794, theta=-77.90649 -> V=1.0, theta=0.0
% INFO    : Bus 2630	: V=0.9553007, theta=-78.76437 -> V=1.0, theta=0.0
% INFO    : Bus 2631	: V=0.9589171, theta=-78.858135 -> V=1.0, theta=0.0
% INFO    : Bus 2632	: V=0.9618663, theta=-77.988971 -> V=1.0, theta=0.0
% INFO    : Bus 2633	: V=0.9613869, theta=-78.032447 -> V=1.0, theta=0.0
% INFO    : Bus 2634	: V=0.9615553, theta=-78.01409 -> V=1.0, theta=0.0
% INFO    : Bus 2635	: V=0.9595754, theta=-78.744404 -> V=1.0, theta=0.0
% INFO    : Bus 2636	: V=0.9625533, theta=-78.238186 -> V=1.0, theta=0.0
% INFO    : Bus 2637	: V=0.9764703, theta=-76.665913 -> V=1.0, theta=0.0
% INFO    : Bus 2638	: V=0.9632249, theta=-78.211733 -> V=1.0, theta=0.0
% INFO    : Bus 2639	: V=0.9637791, theta=-78.176346 -> V=1.0, theta=0.0
% INFO    : Bus 2640	: V=0.9726785, theta=-76.985444 -> V=1.0, theta=0.0
% INFO    : Bus 2641	: V=0.962003, theta=-78.235781 -> V=1.0, theta=0.0
% INFO    : Bus 2642	: V=0.9712927, theta=-77.085654 -> V=1.0, theta=0.0
% INFO    : Bus 2643	: V=0.9703823, theta=-77.161596 -> V=1.0, theta=0.0
% INFO    : Bus 2644	: V=0.9598345, theta=-78.317058 -> V=1.0, theta=0.0
% INFO    : Bus 2645	: V=0.960099, theta=-78.833537 -> V=1.0, theta=0.0
% INFO    : Bus 2646	: V=0.96036, theta=-78.844794 -> V=1.0, theta=0.0
% INFO    : Bus 2647	: V=0.9752124, theta=-77.495624 -> V=1.0, theta=0.0
% INFO    : Bus 2648	: V=0.978231, theta=-77.339283 -> V=1.0, theta=0.0
% INFO    : Bus 2649	: V=0.9646528, theta=-77.931728 -> V=1.0, theta=0.0
% INFO    : Bus 2650	: V=0.9651111, theta=-77.900397 -> V=1.0, theta=0.0
% INFO    : Bus 2651	: V=0.9656913, theta=-77.912806 -> V=1.0, theta=0.0
% INFO    : Bus 2652	: V=0.9726575, theta=-77.655815 -> V=1.0, theta=0.0
% INFO    : Bus 2653	: V=0.9768823, theta=-76.588851 -> V=1.0, theta=0.0
% INFO    : Bus 2654	: V=0.9719455, theta=-77.038648 -> V=1.0, theta=0.0
% INFO    : Bus 2655	: V=0.9523535, theta=-77.698226 -> V=1.0, theta=0.0
% INFO    : Bus 2656	: V=0.9638874, theta=-76.696108 -> V=1.0, theta=0.0
% INFO    : Bus 2657	: V=0.9616859, theta=-77.124764 -> V=1.0, theta=0.0
% INFO    : Bus 2658	: V=0.9634272, theta=-76.654258 -> V=1.0, theta=0.0
% INFO    : Bus 2659	: V=0.9687487, theta=-75.996244 -> V=1.0, theta=0.0
% INFO    : Bus 2660	: V=0.9748766, theta=-75.791922 -> V=1.0, theta=0.0
% INFO    : Bus 2661	: V=0.9755524, theta=-75.923965 -> V=1.0, theta=0.0
% INFO    : Bus 2662	: V=0.9887886, theta=-75.078118 -> V=1.0, theta=0.0
% INFO    : Bus 2663	: V=0.9786698, theta=-75.878133 -> V=1.0, theta=0.0
% INFO    : Bus 2664	: V=0.9580422, theta=-77.599114 -> V=1.0, theta=0.0
% INFO    : Bus 2665	: V=0.9620017, theta=-77.380965 -> V=1.0, theta=0.0
% INFO    : Bus 2666	: V=0.9740535, theta=-76.830893 -> V=1.0, theta=0.0
% INFO    : Bus 2667	: V=0.9665211, theta=-77.210104 -> V=1.0, theta=0.0
% INFO    : Bus 2668	: V=0.9564227, theta=-77.642098 -> V=1.0, theta=0.0
% INFO    : Bus 2669	: V=0.977828, theta=-76.448394 -> V=1.0, theta=0.0
% INFO    : Bus 2670	: V=0.9815369, theta=-76.143849 -> V=1.0, theta=0.0
% INFO    : Bus 2671	: V=0.9829129, theta=-76.005181 -> V=1.0, theta=0.0
% INFO    : Bus 2672	: V=0.9845421, theta=-75.888453 -> V=1.0, theta=0.0
% INFO    : Bus 2673	: V=0.9859788, theta=-75.757232 -> V=1.0, theta=0.0
% INFO    : Bus 2674	: V=0.9865026, theta=-75.706767 -> V=1.0, theta=0.0
% INFO    : Bus 2675	: V=0.9789232, theta=-76.507141 -> V=1.0, theta=0.0
% INFO    : Bus 2676	: V=0.984448, theta=-75.727684 -> V=1.0, theta=0.0
% INFO    : Bus 2677	: V=0.9709579, theta=-77.01996 -> V=1.0, theta=0.0
% INFO    : Bus 2678	: V=0.9728072, theta=-76.937354 -> V=1.0, theta=0.0
% INFO    : Bus 2679	: V=0.9726767, theta=-76.961436 -> V=1.0, theta=0.0
% INFO    : Bus 2680	: V=0.9731555, theta=-76.937991 -> V=1.0, theta=0.0
% INFO    : Bus 2681	: V=0.9737464, theta=-76.898269 -> V=1.0, theta=0.0
% INFO    : Bus 2682	: V=0.9833057, theta=-75.720935 -> V=1.0, theta=0.0
% INFO    : Bus 2683	: V=0.9839595, theta=-75.641376 -> V=1.0, theta=0.0
% INFO    : Bus 2684	: V=0.975562, theta=-76.612126 -> V=1.0, theta=0.0
% INFO    : Bus 2685	: V=0.9811187, theta=-76.006799 -> V=1.0, theta=0.0
% INFO    : Bus 2686	: V=0.9728046, theta=-76.955818 -> V=1.0, theta=0.0
% INFO    : Bus 2687	: V=0.9760461, theta=-76.838873 -> V=1.0, theta=0.0
% INFO    : Bus 2688	: V=0.981362, theta=-75.992949 -> V=1.0, theta=0.0
% INFO    : Bus 2689	: V=0.9817853, theta=-75.965129 -> V=1.0, theta=0.0
% INFO    : Bus 2690	: V=0.9734403, theta=-76.918396 -> V=1.0, theta=0.0
% INFO    : Bus 2691	: V=0.971507, theta=-77.001474 -> V=1.0, theta=0.0
% INFO    : Bus 2692	: V=0.9720682, theta=-76.994968 -> V=1.0, theta=0.0
% INFO    : Bus 2693	: V=0.9724412, theta=-76.975787 -> V=1.0, theta=0.0
% INFO    : Bus 2694	: V=0.9741661, theta=-76.920719 -> V=1.0, theta=0.0
% INFO    : Bus 2695	: V=0.9828831, theta=-76.035743 -> V=1.0, theta=0.0
% INFO    : Bus 2696	: V=0.979852, theta=-76.484812 -> V=1.0, theta=0.0
% INFO    : Bus 2697	: V=0.9716692, theta=-77.234143 -> V=1.0, theta=0.0
% INFO    : Bus 2698	: V=1.0048409, theta=-73.484104 -> V=1.0, theta=0.0
% INFO    : Bus 2699	: V=0.9803991, theta=-76.41108 -> V=1.0, theta=0.0
% INFO    : Bus 2700	: V=0.973559, theta=-77.112489 -> V=1.0, theta=0.0
% INFO    : Bus 2701	: V=0.982977, theta=-76.029258 -> V=1.0, theta=0.0
% INFO    : Bus 2702	: V=0.9840508, theta=-75.962923 -> V=1.0, theta=0.0
% INFO    : Bus 2703	: V=0.9737381, theta=-77.107393 -> V=1.0, theta=0.0
% INFO    : Bus 2704	: V=0.9715432, theta=-76.981291 -> V=1.0, theta=0.0
% INFO    : Bus 2705	: V=0.9726534, theta=-76.968807 -> V=1.0, theta=0.0
% INFO    : Bus 2706	: V=0.9733438, theta=-76.94588 -> V=1.0, theta=0.0
% INFO    : Bus 2707	: V=0.9716091, theta=-76.970678 -> V=1.0, theta=0.0
% INFO    : Bus 2708	: V=0.9848938, theta=-75.910609 -> V=1.0, theta=0.0
% INFO    : Bus 2709	: V=0.9708571, theta=-76.956489 -> V=1.0, theta=0.0
% INFO    : Bus 2710	: V=0.9832357, theta=-75.860218 -> V=1.0, theta=0.0
% INFO    : Bus 2711	: V=0.9823814, theta=-75.919232 -> V=1.0, theta=0.0
% INFO    : Bus 2712	: V=0.9741108, theta=-76.906155 -> V=1.0, theta=0.0
% INFO    : Bus 2713	: V=0.9825102, theta=-75.921325 -> V=1.0, theta=0.0
% INFO    : Bus 2714	: V=0.9762754, theta=-76.579145 -> V=1.0, theta=0.0
% INFO    : Bus 2715	: V=0.9865312, theta=-75.324515 -> V=1.0, theta=0.0
% INFO    : Bus 2716	: V=0.9744799, theta=-76.542692 -> V=1.0, theta=0.0
% INFO    : Bus 2717	: V=0.9664526, theta=-77.612768 -> V=1.0, theta=0.0
% INFO    : Bus 2718	: V=0.9721748, theta=-77.050341 -> V=1.0, theta=0.0
% INFO    : Bus 2719	: V=0.9841454, theta=-75.809616 -> V=1.0, theta=0.0
% INFO    : Bus 2720	: V=0.9722535, theta=-77.050491 -> V=1.0, theta=0.0
% INFO    : Bus 2721	: V=0.9872128, theta=-75.584628 -> V=1.0, theta=0.0
% INFO    : Bus 2722	: V=0.9905239, theta=-75.464601 -> V=1.0, theta=0.0
% INFO    : Bus 2723	: V=0.9891074, theta=-75.640101 -> V=1.0, theta=0.0
% INFO    : Bus 2724	: V=0.9869385, theta=-75.784137 -> V=1.0, theta=0.0
% INFO    : Bus 2725	: V=0.9951615, theta=-75.356091 -> V=1.0, theta=0.0
% INFO    : Bus 2726	: V=0.9909787, theta=-75.631416 -> V=1.0, theta=0.0
% INFO    : Bus 2727	: V=0.9982493, theta=-75.334916 -> V=1.0, theta=0.0
% INFO    : Bus 2728	: V=0.9884981, theta=-75.911725 -> V=1.0, theta=0.0
% INFO    : Bus 2729	: V=0.9813286, theta=-76.395661 -> V=1.0, theta=0.0
% INFO    : Bus 2730	: V=0.9815496, theta=-76.440247 -> V=1.0, theta=0.0
% INFO    : Bus 2731	: V=0.9892733, theta=-75.951233 -> V=1.0, theta=0.0
% INFO    : Bus 2732	: V=0.9853336, theta=-75.860739 -> V=1.0, theta=0.0
% INFO    : Bus 2733	: V=0.98322, theta=-76.081062 -> V=1.0, theta=0.0
% INFO    : Bus 2734	: V=0.9779143, theta=-77.281601 -> V=1.0, theta=0.0
% INFO    : Bus 2735	: V=0.9784688, theta=-77.219766 -> V=1.0, theta=0.0
% INFO    : Bus 2736	: V=0.9849575, theta=-77.212636 -> V=1.0, theta=0.0
% INFO    : Bus 2737	: V=0.9912326, theta=-76.394991 -> V=1.0, theta=0.0
% INFO    : Bus 2738	: V=0.9926224, theta=-75.863319 -> V=1.0, theta=0.0
% INFO    : Bus 2739	: V=0.9942866, theta=-75.719651 -> V=1.0, theta=0.0
% INFO    : Bus 2740	: V=0.9912622, theta=-75.966002 -> V=1.0, theta=0.0
% INFO    : Bus 2741	: V=1.0007089, theta=-75.202863 -> V=1.0, theta=0.0
% INFO    : Bus 2742	: V=1.0095183, theta=-75.236043 -> V=1.0, theta=0.0
% INFO    : Bus 2743	: V=1.0036014, theta=-75.455367 -> V=1.0, theta=0.0
% INFO    : Bus 2744	: V=1.0187353, theta=-74.066784 -> V=1.0, theta=0.0
% INFO    : Bus 2745	: V=1.0131489, theta=-74.89898 -> V=1.0, theta=0.0
% INFO    : Bus 2746	: V=1.0121355, theta=-74.95347 -> V=1.0, theta=0.0
% INFO    : Bus 2747	: V=1.015235, theta=-74.918711 -> V=1.0, theta=0.0
% INFO    : Bus 2748	: V=1.0113937, theta=-74.732953 -> V=1.0, theta=0.0
% INFO    : Bus 2749	: V=1.0115478, theta=-74.740386 -> V=1.0, theta=0.0
% INFO    : Bus 2750	: V=1.0063903, theta=-75.078325 -> V=1.0, theta=0.0
% INFO    : Bus 2751	: V=1.0062712, theta=-74.951854 -> V=1.0, theta=0.0
% INFO    : Bus 2752	: V=1.0190245, theta=-72.701697 -> V=1.0, theta=0.0
% INFO    : Bus 2753	: V=1.0062071, theta=-74.506031 -> V=1.0, theta=0.0
% INFO    : Bus 2754	: V=1.003187, theta=-74.783901 -> V=1.0, theta=0.0
% INFO    : Bus 2755	: V=1.0019257, theta=-74.905418 -> V=1.0, theta=0.0
% INFO    : Bus 2756	: V=1.0013696, theta=-75.023832 -> V=1.0, theta=0.0
% INFO    : Bus 2757	: V=0.9966715, theta=-75.153725 -> V=1.0, theta=0.0
% INFO    : Bus 2758	: V=0.9963329, theta=-74.93134 -> V=1.0, theta=0.0
% INFO    : Bus 2759	: V=1.0097268, theta=-73.763818 -> V=1.0, theta=0.0
% INFO    : Bus 2760	: V=0.9857059, theta=-75.36017 -> V=1.0, theta=0.0
% INFO    : Bus 2761	: V=0.9881634, theta=-75.200842 -> V=1.0, theta=0.0
% INFO    : Bus 2762	: V=0.994511, theta=-74.943581 -> V=1.0, theta=0.0
% INFO    : Bus 2763	: V=0.9956605, theta=-74.84755 -> V=1.0, theta=0.0
% INFO    : Bus 2764	: V=0.9967005, theta=-74.768019 -> V=1.0, theta=0.0
% INFO    : Bus 2765	: V=0.9973841, theta=-74.619262 -> V=1.0, theta=0.0
% INFO    : Bus 2766	: V=1.0066345, theta=-73.571752 -> V=1.0, theta=0.0
% INFO    : Bus 2767	: V=1.0057551, theta=-73.433118 -> V=1.0, theta=0.0
% INFO    : Bus 2768	: V=1.0020953, theta=-73.880568 -> V=1.0, theta=0.0
% INFO    : Bus 2769	: V=0.9934221, theta=-74.420211 -> V=1.0, theta=0.0
% INFO    : Bus 2770	: V=1.0041579, theta=-73.560249 -> V=1.0, theta=0.0
% INFO    : Bus 2771	: V=0.9890183, theta=-74.512818 -> V=1.0, theta=0.0
% INFO    : Bus 2772	: V=1.0029841, theta=-73.606546 -> V=1.0, theta=0.0
% INFO    : Bus 2773	: V=0.9887308, theta=-74.513747 -> V=1.0, theta=0.0
% INFO    : Bus 2774	: V=0.9872643, theta=-74.582492 -> V=1.0, theta=0.0
% INFO    : Bus 2775	: V=0.9840773, theta=-74.490626 -> V=1.0, theta=0.0
% INFO    : Bus 2776	: V=1.0029335, theta=-73.633357 -> V=1.0, theta=0.0
% INFO    : Bus 2777	: V=0.9766687, theta=-75.70954 -> V=1.0, theta=0.0
% INFO    : Bus 2778	: V=0.9790732, theta=-75.669445 -> V=1.0, theta=0.0
% INFO    : Bus 2779	: V=0.9746319, theta=-75.411633 -> V=1.0, theta=0.0
% INFO    : Bus 2780	: V=0.992974, theta=-76.077455 -> V=1.0, theta=0.0
% INFO    : Bus 2781	: V=0.9893091, theta=-75.81333 -> V=1.0, theta=0.0
% INFO    : Bus 2782	: V=0.9608455, theta=-79.669818 -> V=1.0, theta=0.0
% INFO    : Bus 2783	: V=0.9634627, theta=-82.168658 -> V=1.0, theta=0.0
% INFO    : Bus 2784	: V=0.9562201, theta=-82.01096 -> V=1.0, theta=0.0
% INFO    : Bus 2785	: V=0.9631216, theta=-81.980257 -> V=1.0, theta=0.0
% INFO    : Bus 2786	: V=0.9651032, theta=-80.030549 -> V=1.0, theta=0.0
% INFO    : Bus 2787	: V=0.9746274, theta=-79.053567 -> V=1.0, theta=0.0
% INFO    : Bus 2788	: V=0.9700105, theta=-79.536176 -> V=1.0, theta=0.0
% INFO    : Bus 2789	: V=0.965039, theta=-79.564447 -> V=1.0, theta=0.0
% INFO    : Bus 2790	: V=0.9679789, theta=-79.779322 -> V=1.0, theta=0.0
% INFO    : Bus 2791	: V=0.9643284, theta=-81.07427 -> V=1.0, theta=0.0
% INFO    : Bus 2792	: V=0.9713552, theta=-80.784831 -> V=1.0, theta=0.0
% INFO    : Bus 2793	: V=0.9622906, theta=-81.792013 -> V=1.0, theta=0.0
% INFO    : Bus 2794	: V=0.9607925, theta=-81.888935 -> V=1.0, theta=0.0
% INFO    : Bus 2795	: V=0.9603591, theta=-82.065913 -> V=1.0, theta=0.0
% INFO    : Bus 2796	: V=0.9584226, theta=-82.203359 -> V=1.0, theta=0.0
% INFO    : Bus 2797	: V=0.9726435, theta=-79.230871 -> V=1.0, theta=0.0
% INFO    : Bus 2798	: V=0.9788991, theta=-80.39342 -> V=1.0, theta=0.0
% INFO    : Bus 2799	: V=0.9740089, theta=-81.108624 -> V=1.0, theta=0.0
% INFO    : Bus 2800	: V=0.9768736, theta=-81.650896 -> V=1.0, theta=0.0
% INFO    : Bus 2801	: V=0.9700464, theta=-82.047143 -> V=1.0, theta=0.0
% INFO    : Bus 2802	: V=0.9911478, theta=-81.003171 -> V=1.0, theta=0.0
% INFO    : Bus 2803	: V=0.9527389, theta=-82.617456 -> V=1.0, theta=0.0
% INFO    : Bus 2804	: V=0.9594226, theta=-81.746999 -> V=1.0, theta=0.0
% INFO    : Bus 2805	: V=0.9645221, theta=-81.265054 -> V=1.0, theta=0.0
% INFO    : Bus 2806	: V=0.9612117, theta=-81.563748 -> V=1.0, theta=0.0
% INFO    : Bus 2807	: V=0.9439617, theta=-82.809005 -> V=1.0, theta=0.0
% INFO    : Bus 2808	: V=0.9539243, theta=-82.032826 -> V=1.0, theta=0.0
% INFO    : Bus 2809	: V=0.9690671, theta=-78.158181 -> V=1.0, theta=0.0
% INFO    : Bus 2810	: V=0.9757471, theta=-77.229806 -> V=1.0, theta=0.0
% INFO    : Bus 2811	: V=0.9498708, theta=-78.259713 -> V=1.0, theta=0.0
% INFO    : Bus 2812	: V=0.957342, theta=-78.014845 -> V=1.0, theta=0.0
% INFO    : Bus 2813	: V=0.9643884, theta=-77.393258 -> V=1.0, theta=0.0
% INFO    : Bus 2814	: V=0.9761788, theta=-74.224375 -> V=1.0, theta=0.0
% INFO    : Bus 2815	: V=0.9610529, theta=-77.731753 -> V=1.0, theta=0.0
% INFO    : Bus 2816	: V=0.9796824, theta=-75.638346 -> V=1.0, theta=0.0
% INFO    : Bus 2817	: V=0.9599192, theta=-77.081883 -> V=1.0, theta=0.0
% INFO    : Bus 2818	: V=0.9641341, theta=-76.8915 -> V=1.0, theta=0.0
% INFO    : Bus 2819	: V=0.9677801, theta=-76.426517 -> V=1.0, theta=0.0
% INFO    : Bus 2820	: V=0.9787068, theta=-75.637694 -> V=1.0, theta=0.0
% INFO    : Bus 2821	: V=0.9666408, theta=-76.58775 -> V=1.0, theta=0.0
% INFO    : Bus 2822	: V=0.9840379, theta=-75.19594 -> V=1.0, theta=0.0
% INFO    : Bus 2823	: V=0.9953735, theta=-73.887893 -> V=1.0, theta=0.0
% INFO    : Bus 2824	: V=0.9902783, theta=-74.015996 -> V=1.0, theta=0.0
% INFO    : Bus 2825	: V=0.9700233, theta=-79.299719 -> V=1.0, theta=0.0
% INFO    : Bus 2826	: V=0.9817703, theta=-78.702039 -> V=1.0, theta=0.0
% INFO    : Bus 2827	: V=0.9832, theta=-78.874005 -> V=1.0, theta=0.0
% INFO    : Bus 2828	: V=0.9782001, theta=-79.23506 -> V=1.0, theta=0.0
% INFO    : Bus 2829	: V=0.9943089, theta=-77.695413 -> V=1.0, theta=0.0
% INFO    : Bus 2830	: V=1.0100717, theta=-76.440318 -> V=1.0, theta=0.0
% INFO    : Bus 2831	: V=0.9986343, theta=-77.540655 -> V=1.0, theta=0.0
% INFO    : Bus 2832	: V=0.9904839, theta=-77.644281 -> V=1.0, theta=0.0
% INFO    : Bus 2833	: V=1.0123874, theta=-76.256696 -> V=1.0, theta=0.0
% INFO    : Bus 2834	: V=0.99678, theta=-78.233389 -> V=1.0, theta=0.0
% INFO    : Bus 2835	: V=0.976263, theta=-79.566326 -> V=1.0, theta=0.0
% INFO    : Bus 2836	: V=0.9802063, theta=-78.391567 -> V=1.0, theta=0.0
% INFO    : Bus 2837	: V=0.9888797, theta=-77.906335 -> V=1.0, theta=0.0
% INFO    : Bus 2838	: V=0.9551143, theta=-79.34717 -> V=1.0, theta=0.0
% INFO    : Bus 2839	: V=0.9773575, theta=-81.219443 -> V=1.0, theta=0.0
% INFO    : Bus 2840	: V=0.9382726, theta=-83.762292 -> V=1.0, theta=0.0
% INFO    : Bus 2841	: V=0.9687187, theta=-80.253231 -> V=1.0, theta=0.0
% INFO    : Bus 2842	: V=0.962608, theta=-79.549471 -> V=1.0, theta=0.0
% INFO    : Bus 2843	: V=0.9518608, theta=-83.335354 -> V=1.0, theta=0.0
% INFO    : Bus 2844	: V=0.9881968, theta=-76.658747 -> V=1.0, theta=0.0
% INFO    : Bus 2845	: V=0.9617508, theta=-82.667883 -> V=1.0, theta=0.0
% INFO    : Bus 2846	: V=0.9650727, theta=-81.549126 -> V=1.0, theta=0.0
% INFO    : Bus 2847	: V=0.9539347, theta=-82.936974 -> V=1.0, theta=0.0
% INFO    : Bus 2848	: V=0.9921663, theta=-76.955195 -> V=1.0, theta=0.0
% INFO    : Bus 2849	: V=0.9984085, theta=-76.10481 -> V=1.0, theta=0.0
% INFO    : Bus 2850	: V=0.9831797, theta=-76.611736 -> V=1.0, theta=0.0
% INFO    : Bus 2851	: V=1.005385, theta=-75.213679 -> V=1.0, theta=0.0
% INFO    : Bus 2852	: V=1.0234249, theta=-72.899085 -> V=1.0, theta=0.0
% INFO    : Bus 2853	: V=1.0227333, theta=-72.86004 -> V=1.0, theta=0.0
% INFO    : Bus 2854	: V=1.0084977, theta=-74.71155 -> V=1.0, theta=0.0
% INFO    : Bus 2855	: V=0.9728804, theta=-79.772772 -> V=1.0, theta=0.0
% INFO    : Bus 2856	: V=0.9732305, theta=-79.759204 -> V=1.0, theta=0.0
% INFO    : Bus 2857	: V=0.9714932, theta=-79.904242 -> V=1.0, theta=0.0
% INFO    : Bus 2858	: V=0.9752866, theta=-79.705885 -> V=1.0, theta=0.0
% INFO    : Bus 2859	: V=0.9893224, theta=-78.117721 -> V=1.0, theta=0.0
% INFO    : Bus 2860	: V=0.9718859, theta=-79.901258 -> V=1.0, theta=0.0
% INFO    : Bus 2861	: V=0.9732422, theta=-79.780263 -> V=1.0, theta=0.0
% INFO    : Bus 2862	: V=0.9693468, theta=-80.105911 -> V=1.0, theta=0.0
% INFO    : Bus 2863	: V=0.9819139, theta=-78.861113 -> V=1.0, theta=0.0
% INFO    : Bus 2864	: V=0.9699609, theta=-80.099227 -> V=1.0, theta=0.0
% INFO    : Bus 2865	: V=0.9683118, theta=-80.113603 -> V=1.0, theta=0.0
% INFO    : Bus 2866	: V=0.9912671, theta=-77.880578 -> V=1.0, theta=0.0
% INFO    : Bus 2867	: V=0.9868156, theta=-78.40665 -> V=1.0, theta=0.0
% INFO    : Bus 2868	: V=0.9861569, theta=-78.433013 -> V=1.0, theta=0.0
% INFO    : Bus 2869	: V=0.9820896, theta=-78.858754 -> V=1.0, theta=0.0
% INFO    : Bus 2870	: V=0.9892414, theta=-78.083165 -> V=1.0, theta=0.0
% INFO    : Bus 2871	: V=0.9894121, theta=-78.067924 -> V=1.0, theta=0.0
% INFO    : Bus 2872	: V=0.9896665, theta=-78.045576 -> V=1.0, theta=0.0
% INFO    : Bus 2873	: V=0.9903183, theta=-77.996828 -> V=1.0, theta=0.0
% INFO    : Bus 2874	: V=0.9857859, theta=-78.451005 -> V=1.0, theta=0.0
% INFO    : Bus 2875	: V=0.9807251, theta=-78.984722 -> V=1.0, theta=0.0
% INFO    : Bus 2876	: V=0.9719208, theta=-79.889455 -> V=1.0, theta=0.0
% INFO    : Bus 2877	: V=0.9723963, theta=-79.881046 -> V=1.0, theta=0.0
% INFO    : Bus 2878	: V=0.9718282, theta=-79.886217 -> V=1.0, theta=0.0
% INFO    : Bus 2879	: V=0.9792238, theta=-79.008097 -> V=1.0, theta=0.0
% INFO    : Bus 2880	: V=0.982966, theta=-78.794002 -> V=1.0, theta=0.0
% INFO    : Bus 2881	: V=0.9919949, theta=-77.863025 -> V=1.0, theta=0.0
% INFO    : Bus 2882	: V=1.0188412, theta=-75.227103 -> V=1.0, theta=0.0
% INFO    : Bus 2883	: V=0.970068, theta=-79.845024 -> V=1.0, theta=0.0
% INFO    : Bus 2884	: V=0.9718845, theta=-79.7752 -> V=1.0, theta=0.0
% INFO    : Bus 2885	: V=0.9848822, theta=-78.391189 -> V=1.0, theta=0.0
% INFO    : Bus 2886	: V=0.9977923, theta=-77.176843 -> V=1.0, theta=0.0
% INFO    : Bus 2887	: V=0.9779815, theta=-79.134588 -> V=1.0, theta=0.0
% INFO    : Bus 2888	: V=0.9748477, theta=-79.261177 -> V=1.0, theta=0.0
% INFO    : Bus 2889	: V=0.9689354, theta=-79.313075 -> V=1.0, theta=0.0
% INFO    : Bus 2890	: V=0.9812026, theta=-77.975039 -> V=1.0, theta=0.0
% INFO    : Bus 2891	: V=0.9622498, theta=-79.896665 -> V=1.0, theta=0.0
% INFO    : Bus 2892	: V=0.9636163, theta=-79.826738 -> V=1.0, theta=0.0
% INFO    : Bus 2893	: V=0.9681501, theta=-79.372859 -> V=1.0, theta=0.0
% INFO    : Bus 2894	: V=0.9681994, theta=-79.377161 -> V=1.0, theta=0.0
% INFO    : Bus 2895	: V=0.979164, theta=-78.214986 -> V=1.0, theta=0.0
% INFO    : Bus 2896	: V=0.9692233, theta=-79.380577 -> V=1.0, theta=0.0
% INFO    : Bus 2897	: V=0.9786092, theta=-78.218772 -> V=1.0, theta=0.0
% INFO    : Bus 2898	: V=0.9651113, theta=-79.695398 -> V=1.0, theta=0.0
% INFO    : Bus 2899	: V=0.9775978, theta=-78.309294 -> V=1.0, theta=0.0
% INFO    : Bus 2900	: V=0.9587602, theta=-80.205818 -> V=1.0, theta=0.0
% INFO    : Bus 2901	: V=0.9592982, theta=-80.202203 -> V=1.0, theta=0.0
% INFO    : Bus 2902	: V=0.9586046, theta=-80.191847 -> V=1.0, theta=0.0
% INFO    : Bus 2903	: V=0.9756523, theta=-78.417926 -> V=1.0, theta=0.0
% INFO    : Bus 2904	: V=0.9585742, theta=-80.042227 -> V=1.0, theta=0.0
% INFO    : Bus 2905	: V=0.9750686, theta=-78.447979 -> V=1.0, theta=0.0
% INFO    : Bus 2906	: V=0.9599769, theta=-79.998622 -> V=1.0, theta=0.0
% INFO    : Bus 2907	: V=0.9811215, theta=-78.139921 -> V=1.0, theta=0.0
% INFO    : Bus 2908	: V=0.9795775, theta=-78.206855 -> V=1.0, theta=0.0
% INFO    : Bus 2909	: V=0.9789659, theta=-78.188679 -> V=1.0, theta=0.0
% INFO    : Bus 2910	: V=0.9919895, theta=-77.383017 -> V=1.0, theta=0.0
% INFO    : Bus 2911	: V=1.0138199, theta=-75.243464 -> V=1.0, theta=0.0
% INFO    : Bus 2912	: V=0.9766163, theta=-78.931882 -> V=1.0, theta=0.0
% INFO    : Bus 2913	: V=0.9802116, theta=-78.895187 -> V=1.0, theta=0.0
% INFO    : Bus 2914	: V=0.9843444, theta=-77.655733 -> V=1.0, theta=0.0
% INFO    : Bus 2915	: V=0.9591848, theta=-79.491814 -> V=1.0, theta=0.0
% INFO    : Bus 2916	: V=0.9787134, theta=-77.78709 -> V=1.0, theta=0.0
% INFO    : Bus 2917	: V=0.9537391, theta=-79.896084 -> V=1.0, theta=0.0
% INFO    : Bus 2918	: V=0.9556787, theta=-79.873896 -> V=1.0, theta=0.0
% INFO    : Bus 2919	: V=0.9533132, theta=-79.923506 -> V=1.0, theta=0.0
% INFO    : Bus 2920	: V=0.9624356, theta=-79.428301 -> V=1.0, theta=0.0
% INFO    : Bus 2921	: V=0.9575873, theta=-79.455818 -> V=1.0, theta=0.0
% INFO    : Bus 2922	: V=0.952662, theta=-79.78665 -> V=1.0, theta=0.0
% INFO    : Bus 2923	: V=0.9528061, theta=-79.731961 -> V=1.0, theta=0.0
% INFO    : Bus 2924	: V=0.9466462, theta=-80.414657 -> V=1.0, theta=0.0
% INFO    : Bus 2925	: V=0.9531966, theta=-79.57797 -> V=1.0, theta=0.0
% INFO    : Bus 2926	: V=0.9555059, theta=-79.547155 -> V=1.0, theta=0.0
% INFO    : Bus 2927	: V=0.9612261, theta=-80.76629 -> V=1.0, theta=0.0
% INFO    : Bus 2928	: V=0.9517059, theta=-81.217373 -> V=1.0, theta=0.0
% INFO    : Bus 2929	: V=0.9571199, theta=-79.801479 -> V=1.0, theta=0.0
% INFO    : Bus 2930	: V=0.9575712, theta=-78.983909 -> V=1.0, theta=0.0
% INFO    : Bus 2931	: V=0.9542877, theta=-79.721049 -> V=1.0, theta=0.0
% INFO    : Bus 2932	: V=0.9745269, theta=-77.089471 -> V=1.0, theta=0.0
% INFO    : Bus 2933	: V=0.960001, theta=-78.870996 -> V=1.0, theta=0.0
% INFO    : Bus 2934	: V=0.9521336, theta=-79.954561 -> V=1.0, theta=0.0
% INFO    : Bus 2935	: V=0.9595934, theta=-79.941528 -> V=1.0, theta=0.0
% INFO    : Bus 2936	: V=0.9692581, theta=-79.501837 -> V=1.0, theta=0.0
% INFO    : Bus 2937	: V=0.9789366, theta=-78.306599 -> V=1.0, theta=0.0
% INFO    : Bus 2938	: V=0.9696577, theta=-79.282372 -> V=1.0, theta=0.0
% INFO    : Bus 2939	: V=0.9889222, theta=-78.112264 -> V=1.0, theta=0.0
% INFO    : Bus 2940	: V=0.9909807, theta=-78.188454 -> V=1.0, theta=0.0
% INFO    : Bus 2941	: V=0.9922348, theta=-77.976056 -> V=1.0, theta=0.0
% INFO    : Bus 2942	: V=0.9675326, theta=-80.166986 -> V=1.0, theta=0.0
% INFO    : Bus 2943	: V=0.990947, theta=-78.261588 -> V=1.0, theta=0.0
% INFO    : Bus 2944	: V=0.9945733, theta=-78.099087 -> V=1.0, theta=0.0
% INFO    : Bus 2945	: V=0.9654211, theta=-79.873625 -> V=1.0, theta=0.0
% INFO    : Bus 2946	: V=0.998504, theta=-77.605587 -> V=1.0, theta=0.0
% INFO    : Bus 2947	: V=0.9693633, theta=-79.827898 -> V=1.0, theta=0.0
% INFO    : Bus 2948	: V=0.9958534, theta=-77.854898 -> V=1.0, theta=0.0
% INFO    : Bus 2949	: V=0.988809, theta=-78.661005 -> V=1.0, theta=0.0
% INFO    : Bus 2950	: V=0.9872586, theta=-78.711472 -> V=1.0, theta=0.0
% INFO    : Bus 2951	: V=0.9941562, theta=-77.982601 -> V=1.0, theta=0.0
% INFO    : Bus 2952	: V=0.9942169, theta=-77.931356 -> V=1.0, theta=0.0
% INFO    : Bus 2953	: V=0.990707, theta=-78.237193 -> V=1.0, theta=0.0
% INFO    : Bus 2954	: V=0.9786784, theta=-79.201053 -> V=1.0, theta=0.0
% INFO    : Bus 2955	: V=0.9876899, theta=-78.421377 -> V=1.0, theta=0.0
% INFO    : Bus 2956	: V=0.9769478, theta=-79.482132 -> V=1.0, theta=0.0
% INFO    : Bus 2957	: V=0.9899969, theta=-78.394981 -> V=1.0, theta=0.0
% INFO    : Bus 2958	: V=0.9775175, theta=-78.811467 -> V=1.0, theta=0.0
% INFO    : Bus 2959	: V=0.9865791, theta=-78.005431 -> V=1.0, theta=0.0
% INFO    : Bus 2960	: V=0.972124, theta=-79.458501 -> V=1.0, theta=0.0
% INFO    : Bus 2961	: V=0.9709351, theta=-79.700301 -> V=1.0, theta=0.0
% INFO    : Bus 2962	: V=0.9819455, theta=-78.714339 -> V=1.0, theta=0.0
% INFO    : Bus 2963	: V=0.9723578, theta=-79.418082 -> V=1.0, theta=0.0
% INFO    : Bus 2964	: V=0.9661849, theta=-79.674048 -> V=1.0, theta=0.0
% INFO    : Bus 2965	: V=0.987798, theta=-78.275982 -> V=1.0, theta=0.0
% INFO    : Bus 2966	: V=0.9696751, theta=-79.707474 -> V=1.0, theta=0.0
% INFO    : Bus 2967	: V=0.9483903, theta=-80.544893 -> V=1.0, theta=0.0
% INFO    : Bus 2968	: V=0.9977352, theta=-77.557243 -> V=1.0, theta=0.0
% INFO    : Bus 2969	: V=0.9849051, theta=-77.748748 -> V=1.0, theta=0.0
% INFO    : Bus 2970	: V=0.9795755, theta=-78.339965 -> V=1.0, theta=0.0
% INFO    : Bus 2971	: V=0.9759541, theta=-78.793796 -> V=1.0, theta=0.0
% INFO    : Bus 2972	: V=0.9595631, theta=-80.481868 -> V=1.0, theta=0.0
% INFO    : Bus 2973	: V=0.9775987, theta=-78.930192 -> V=1.0, theta=0.0
% INFO    : Bus 2974	: V=1.0170889, theta=-75.590434 -> V=1.0, theta=0.0
% INFO    : Bus 2975	: V=0.9741456, theta=-79.724714 -> V=1.0, theta=0.0
% INFO    : Bus 2976	: V=0.9797378, theta=-79.189335 -> V=1.0, theta=0.0
% INFO    : Bus 2977	: V=0.9848507, theta=-77.81998 -> V=1.0, theta=0.0
% INFO    : Bus 2978	: V=0.9793697, theta=-78.560117 -> V=1.0, theta=0.0
% INFO    : Bus 2979	: V=0.9840625, theta=-77.926996 -> V=1.0, theta=0.0
% INFO    : Bus 2980	: V=0.9812421, theta=-78.584595 -> V=1.0, theta=0.0
% INFO    : Bus 2981	: V=0.9795594, theta=-78.644705 -> V=1.0, theta=0.0
% INFO    : Bus 2982	: V=0.9745753, theta=-78.826532 -> V=1.0, theta=0.0
% INFO    : Bus 2983	: V=0.9934892, theta=-77.429108 -> V=1.0, theta=0.0
% INFO    : Bus 2984	: V=0.998892, theta=-77.23552 -> V=1.0, theta=0.0
% INFO    : Bus 2985	: V=0.9893574, theta=-77.714103 -> V=1.0, theta=0.0
% INFO    : Bus 2986	: V=0.996493, theta=-77.158122 -> V=1.0, theta=0.0
% INFO    : Bus 2987	: V=0.9883622, theta=-77.739778 -> V=1.0, theta=0.0
% INFO    : Bus 2988	: V=0.9846245, theta=-77.957275 -> V=1.0, theta=0.0
% INFO    : Bus 2989	: V=0.9908025, theta=-77.820883 -> V=1.0, theta=0.0
% INFO    : Bus 2990	: V=0.9908477, theta=-77.675723 -> V=1.0, theta=0.0
% INFO    : Bus 2991	: V=0.9618179, theta=-79.158411 -> V=1.0, theta=0.0
% INFO    : Bus 2992	: V=0.9677088, theta=-79.114228 -> V=1.0, theta=0.0
% INFO    : Bus 2993	: V=0.9756892, theta=-78.613657 -> V=1.0, theta=0.0
% INFO    : Bus 2994	: V=0.991516, theta=-77.148221 -> V=1.0, theta=0.0
% INFO    : Bus 2995	: V=0.9922273, theta=-77.417462 -> V=1.0, theta=0.0
% INFO    : Bus 2996	: V=0.9802062, theta=-78.42889 -> V=1.0, theta=0.0
% INFO    : Bus 2997	: V=0.9903717, theta=-77.702647 -> V=1.0, theta=0.0
% INFO    : Bus 2998	: V=0.9760132, theta=-79.135092 -> V=1.0, theta=0.0
% INFO    : Bus 2999	: V=0.9932342, theta=-77.378141 -> V=1.0, theta=0.0
% INFO    : Bus 3000	: V=0.996723, theta=-76.884066 -> V=1.0, theta=0.0
% INFO    : Bus 3001	: V=0.9949243, theta=-76.823328 -> V=1.0, theta=0.0
% INFO    : Bus 3002	: V=0.9983472, theta=-76.556302 -> V=1.0, theta=0.0
% INFO    : Bus 3003	: V=0.9828252, theta=-77.822711 -> V=1.0, theta=0.0
% INFO    : Bus 3004	: V=0.9848337, theta=-77.808938 -> V=1.0, theta=0.0
% INFO    : Bus 3005	: V=1.0054634, theta=-75.859869 -> V=1.0, theta=0.0
% INFO    : Bus 3006	: V=1.0078303, theta=-75.568776 -> V=1.0, theta=0.0
% INFO    : Bus 3007	: V=1.0069597, theta=-75.535849 -> V=1.0, theta=0.0
% INFO    : Bus 3008	: V=1.0081143, theta=-75.702305 -> V=1.0, theta=0.0
% INFO    : Bus 3009	: V=1.0058203, theta=-75.966292 -> V=1.0, theta=0.0
% INFO    : Bus 3010	: V=1.0055651, theta=-76.022172 -> V=1.0, theta=0.0
% INFO    : Bus 3011	: V=1.0062583, theta=-75.891924 -> V=1.0, theta=0.0
% INFO    : Bus 3012	: V=1.0053202, theta=-75.899395 -> V=1.0, theta=0.0
% INFO    : Bus 3013	: V=1.0092896, theta=-75.704374 -> V=1.0, theta=0.0
% INFO    : Bus 3014	: V=1.0055646, theta=-75.995934 -> V=1.0, theta=0.0
% INFO    : Bus 3015	: V=1.0018979, theta=-76.372788 -> V=1.0, theta=0.0
% INFO    : Bus 3016	: V=1.0035724, theta=-76.24225 -> V=1.0, theta=0.0
% INFO    : Bus 3017	: V=1.0056109, theta=-76.273437 -> V=1.0, theta=0.0
% INFO    : Bus 3018	: V=1.0135345, theta=-75.549154 -> V=1.0, theta=0.0
% INFO    : Bus 3019	: V=1.0140548, theta=-75.523638 -> V=1.0, theta=0.0
% INFO    : Bus 3020	: V=1.0129043, theta=-75.571856 -> V=1.0, theta=0.0
% INFO    : Bus 3021	: V=1.0110954, theta=-75.614244 -> V=1.0, theta=0.0
% INFO    : Bus 3022	: V=0.9746802, theta=-78.428637 -> V=1.0, theta=0.0
% INFO    : Bus 3023	: V=0.9650036, theta=-79.391705 -> V=1.0, theta=0.0
% INFO    : Bus 3024	: V=0.9828581, theta=-78.00094 -> V=1.0, theta=0.0
% INFO    : Bus 3025	: V=0.9608052, theta=-79.708738 -> V=1.0, theta=0.0
% INFO    : Bus 3026	: V=0.9808854, theta=-77.929196 -> V=1.0, theta=0.0
% INFO    : Bus 3027	: V=0.9780134, theta=-78.204767 -> V=1.0, theta=0.0
% INFO    : Bus 3028	: V=0.9820098, theta=-77.700195 -> V=1.0, theta=0.0
% INFO    : Bus 3029	: V=0.9753134, theta=-78.382184 -> V=1.0, theta=0.0
% INFO    : Bus 3030	: V=0.9673014, theta=-79.138383 -> V=1.0, theta=0.0
% INFO    : Bus 3031	: V=0.9659224, theta=-79.151927 -> V=1.0, theta=0.0
% INFO    : Bus 3032	: V=0.995752, theta=-76.648917 -> V=1.0, theta=0.0
% INFO    : Bus 3033	: V=0.9649083, theta=-79.570915 -> V=1.0, theta=0.0
% INFO    : Bus 3034	: V=0.9822363, theta=-78.102044 -> V=1.0, theta=0.0
% INFO    : Bus 3035	: V=0.9916953, theta=-77.233442 -> V=1.0, theta=0.0
% INFO    : Bus 3036	: V=1.0041148, theta=-75.95906 -> V=1.0, theta=0.0
% INFO    : Bus 3037	: V=1.0149099, theta=-75.480244 -> V=1.0, theta=0.0
% INFO    : Bus 3038	: V=1.0004737, theta=-76.572013 -> V=1.0, theta=0.0
% INFO    : Bus 3039	: V=1.0130712, theta=-75.610953 -> V=1.0, theta=0.0
% INFO    : Bus 3040	: V=1.0177317, theta=-74.414778 -> V=1.0, theta=0.0
% INFO    : Bus 3041	: V=1.0000582, theta=-77.058066 -> V=1.0, theta=0.0
% INFO    : Bus 3042	: V=1.0010307, theta=-76.490387 -> V=1.0, theta=0.0
% INFO    : Bus 3043	: V=0.9885143, theta=-77.748989 -> V=1.0, theta=0.0
% INFO    : Bus 3044	: V=0.9984268, theta=-76.783677 -> V=1.0, theta=0.0
% INFO    : Bus 3045	: V=0.9902907, theta=-77.550893 -> V=1.0, theta=0.0
% INFO    : Bus 3046	: V=0.9968847, theta=-76.98194 -> V=1.0, theta=0.0
% INFO    : Bus 3047	: V=1.0151934, theta=-74.740027 -> V=1.0, theta=0.0
% INFO    : Bus 3048	: V=0.9891635, theta=-77.7594 -> V=1.0, theta=0.0
% INFO    : Bus 3049	: V=0.9937605, theta=-77.333818 -> V=1.0, theta=0.0
% INFO    : Bus 3050	: V=0.98448, theta=-78.43444 -> V=1.0, theta=0.0
% INFO    : Bus 3051	: V=0.9919995, theta=-77.46447 -> V=1.0, theta=0.0
% INFO    : Bus 3052	: V=0.9902126, theta=-77.594228 -> V=1.0, theta=0.0
% INFO    : Bus 3053	: V=0.9823586, theta=-78.466298 -> V=1.0, theta=0.0
% INFO    : Bus 3054	: V=0.9870701, theta=-77.78717 -> V=1.0, theta=0.0
% INFO    : Bus 3055	: V=0.9877142, theta=-77.746145 -> V=1.0, theta=0.0
% INFO    : Bus 3056	: V=0.9778821, theta=-78.922381 -> V=1.0, theta=0.0
% INFO    : Bus 3057	: V=0.9811754, theta=-78.426571 -> V=1.0, theta=0.0
% INFO    : Bus 3058	: V=0.9827582, theta=-78.277299 -> V=1.0, theta=0.0
% INFO    : Bus 3059	: V=0.9844764, theta=-78.100594 -> V=1.0, theta=0.0
% INFO    : Bus 3060	: V=1.0109841, theta=-75.141803 -> V=1.0, theta=0.0
% INFO    : Bus 3061	: V=0.9734841, theta=-79.16363 -> V=1.0, theta=0.0
% INFO    : Bus 3062	: V=0.9746186, theta=-79.206665 -> V=1.0, theta=0.0
% INFO    : Bus 3063	: V=0.9664402, theta=-79.243185 -> V=1.0, theta=0.0
% INFO    : Bus 3064	: V=0.9792158, theta=-78.579297 -> V=1.0, theta=0.0
% INFO    : Bus 3065	: V=0.9557592, theta=-81.324771 -> V=1.0, theta=0.0
% INFO    : Bus 3066	: V=0.9475359, theta=-81.569269 -> V=1.0, theta=0.0
% INFO    : Bus 3067	: V=0.9846903, theta=-76.594917 -> V=1.0, theta=0.0
% INFO    : Bus 3068	: V=0.9987082, theta=-77.672927 -> V=1.0, theta=0.0
% INFO    : Bus 3069	: V=0.9949646, theta=-77.581573 -> V=1.0, theta=0.0
% INFO    : Bus 3070	: V=0.9873497, theta=-77.674435 -> V=1.0, theta=0.0
% INFO    : Bus 3071	: V=1.0069593, theta=-76.119141 -> V=1.0, theta=0.0
% INFO    : Bus 3072	: V=0.9541205, theta=-79.81679 -> V=1.0, theta=0.0
% INFO    : Bus 3073	: V=0.9600977, theta=-79.64292 -> V=1.0, theta=0.0
% INFO    : Bus 3074	: V=0.9775387, theta=-77.106192 -> V=1.0, theta=0.0
% INFO    : Bus 3075	: V=0.968703, theta=-78.064908 -> V=1.0, theta=0.0
% INFO    : Bus 3076	: V=0.9745454, theta=-77.970582 -> V=1.0, theta=0.0
% INFO    : Bus 3077	: V=0.9932107, theta=-76.111439 -> V=1.0, theta=0.0
% INFO    : Bus 3078	: V=1.0040026, theta=-75.149142 -> V=1.0, theta=0.0
% INFO    : Bus 3079	: V=0.9923563, theta=-76.111482 -> V=1.0, theta=0.0
% INFO    : Bus 3080	: V=1.0047868, theta=-74.92893 -> V=1.0, theta=0.0
% INFO    : Bus 3081	: V=1.018001, theta=-73.109993 -> V=1.0, theta=0.0
% INFO    : Bus 3082	: V=1.017796, theta=-73.13748 -> V=1.0, theta=0.0
% INFO    : Bus 3083	: V=1.0045617, theta=-75.010499 -> V=1.0, theta=0.0
% INFO    : Bus 3084	: V=0.9896488, theta=-76.199983 -> V=1.0, theta=0.0
% INFO    : Bus 3085	: V=0.9899949, theta=-76.168123 -> V=1.0, theta=0.0
% INFO    : Bus 3086	: V=0.9880994, theta=-76.284313 -> V=1.0, theta=0.0
% INFO    : Bus 3087	: V=1.0051173, theta=-74.905019 -> V=1.0, theta=0.0
% INFO    : Bus 3088	: V=0.9857372, theta=-76.310896 -> V=1.0, theta=0.0
% INFO    : Bus 3089	: V=1.0031869, theta=-75.336219 -> V=1.0, theta=0.0
% INFO    : Bus 3090	: V=1.0045723, theta=-75.280681 -> V=1.0, theta=0.0
% INFO    : Bus 3091	: V=1.0057454, theta=-75.248233 -> V=1.0, theta=0.0
% INFO    : Bus 3092	: V=1.0080282, theta=-75.178993 -> V=1.0, theta=0.0
% INFO    : Bus 3093	: V=0.983962, theta=-76.492196 -> V=1.0, theta=0.0
% INFO    : Bus 3094	: V=0.9809297, theta=-75.438494 -> V=1.0, theta=0.0
% INFO    : Bus 3095	: V=0.9825974, theta=-75.177234 -> V=1.0, theta=0.0
% INFO    : Bus 3096	: V=0.98071, theta=-75.247999 -> V=1.0, theta=0.0
% INFO    : Bus 3097	: V=0.983356, theta=-75.407336 -> V=1.0, theta=0.0
% INFO    : Bus 3098	: V=0.9784089, theta=-73.68628 -> V=1.0, theta=0.0
% INFO    : Bus 3099	: V=0.9804665, theta=-74.327804 -> V=1.0, theta=0.0
% INFO    : Bus 3100	: V=0.9815482, theta=-74.922614 -> V=1.0, theta=0.0
% INFO    : Bus 3101	: V=0.9799501, theta=-73.479651 -> V=1.0, theta=0.0
% INFO    : Bus 3102	: V=0.9837587, theta=-75.918954 -> V=1.0, theta=0.0
% INFO    : Bus 3103	: V=0.9777314, theta=-75.898052 -> V=1.0, theta=0.0
% INFO    : Bus 3104	: V=0.9806943, theta=-75.934556 -> V=1.0, theta=0.0
% INFO    : Bus 3105	: V=1.0006446, theta=-76.649228 -> V=1.0, theta=0.0
% INFO    : Bus 3106	: V=0.9991614, theta=-76.73552 -> V=1.0, theta=0.0
% INFO    : Bus 3107	: V=1.0109577, theta=-75.597539 -> V=1.0, theta=0.0
% INFO    : Bus 3108	: V=0.9938653, theta=-76.360018 -> V=1.0, theta=0.0
% INFO    : Bus 3109	: V=0.9977739, theta=-76.751981 -> V=1.0, theta=0.0
% INFO    : Bus 3110	: V=0.9929459, theta=-76.306448 -> V=1.0, theta=0.0
% INFO    : Bus 3111	: V=0.9931693, theta=-76.269871 -> V=1.0, theta=0.0
% INFO    : Bus 3112	: V=0.9937092, theta=-76.203471 -> V=1.0, theta=0.0
% INFO    : Bus 3113	: V=0.999247, theta=-75.288263 -> V=1.0, theta=0.0
% INFO    : Bus 3114	: V=0.9931241, theta=-76.202651 -> V=1.0, theta=0.0
% INFO    : Bus 3115	: V=0.9974096, theta=-75.380566 -> V=1.0, theta=0.0
% INFO    : Bus 3116	: V=0.9917634, theta=-76.316638 -> V=1.0, theta=0.0
% INFO    : Bus 3117	: V=0.9838806, theta=-76.491967 -> V=1.0, theta=0.0
% INFO    : Bus 3118	: V=0.9920152, theta=-76.320833 -> V=1.0, theta=0.0
% INFO    : Bus 3119	: V=0.9962341, theta=-75.427928 -> V=1.0, theta=0.0
% INFO    : Bus 3120	: V=0.9953612, theta=-75.476136 -> V=1.0, theta=0.0
% INFO    : Bus 3121	: V=0.9857785, theta=-76.469381 -> V=1.0, theta=0.0
% INFO    : Bus 3122	: V=0.986923, theta=-76.111683 -> V=1.0, theta=0.0
% INFO    : Bus 3123	: V=1.0013836, theta=-75.391883 -> V=1.0, theta=0.0
% INFO    : Bus 3124	: V=0.9850938, theta=-76.441155 -> V=1.0, theta=0.0
% INFO    : Bus 3125	: V=0.983944, theta=-75.762736 -> V=1.0, theta=0.0
% INFO    : Bus 3126	: V=0.9831396, theta=-76.49887 -> V=1.0, theta=0.0
% INFO    : Bus 3127	: V=1.0013283, theta=-74.704832 -> V=1.0, theta=0.0
% INFO    : Bus 3128	: V=0.9836782, theta=-75.261029 -> V=1.0, theta=0.0
% INFO    : Bus 3129	: V=0.9955876, theta=-74.742613 -> V=1.0, theta=0.0
% INFO    : Bus 3130	: V=0.9898601, theta=-74.139544 -> V=1.0, theta=0.0
% INFO    : Bus 3131	: V=0.9765798, theta=-75.154788 -> V=1.0, theta=0.0
% INFO    : Bus 3132	: V=0.9805314, theta=-74.823626 -> V=1.0, theta=0.0
% INFO    : Bus 3133	: V=0.9811055, theta=-75.055691 -> V=1.0, theta=0.0
% INFO    : Bus 3134	: V=0.978435, theta=-75.173188 -> V=1.0, theta=0.0
% INFO    : Bus 3135	: V=0.9884018, theta=-73.943367 -> V=1.0, theta=0.0
% INFO    : Bus 3136	: V=0.9759596, theta=-75.259709 -> V=1.0, theta=0.0
% INFO    : Bus 3137	: V=0.9755414, theta=-75.264337 -> V=1.0, theta=0.0
% INFO    : Bus 3138	: V=0.9739146, theta=-75.289689 -> V=1.0, theta=0.0
% INFO    : Bus 3139	: V=0.9721567, theta=-75.320278 -> V=1.0, theta=0.0
% INFO    : Bus 3140	: V=0.9742951, theta=-75.285957 -> V=1.0, theta=0.0
% INFO    : Bus 3141	: V=0.9755689, theta=-75.263899 -> V=1.0, theta=0.0
% INFO    : Bus 3142	: V=0.9771329, theta=-75.148094 -> V=1.0, theta=0.0
% INFO    : Bus 3143	: V=0.9794527, theta=-74.04551 -> V=1.0, theta=0.0
% INFO    : Bus 3144	: V=0.9907188, theta=-75.737373 -> V=1.0, theta=0.0
% INFO    : Bus 3145	: V=1.0002724, theta=-75.451135 -> V=1.0, theta=0.0
% INFO    : Bus 3146	: V=1.005323, theta=-74.656652 -> V=1.0, theta=0.0
% INFO    : Bus 3147	: V=0.9987485, theta=-75.510391 -> V=1.0, theta=0.0
% INFO    : Bus 3148	: V=0.994271, theta=-75.710445 -> V=1.0, theta=0.0
% INFO    : Bus 3149	: V=1.0003588, theta=-75.62356 -> V=1.0, theta=0.0
% INFO    : Bus 3150	: V=1.0001387, theta=-76.644872 -> V=1.0, theta=0.0
% INFO    : Bus 3151	: V=1.0021459, theta=-76.572708 -> V=1.0, theta=0.0
% INFO    : Bus 3152	: V=1.0029747, theta=-76.542322 -> V=1.0, theta=0.0
% INFO    : Bus 3153	: V=1.0030703, theta=-76.498085 -> V=1.0, theta=0.0
% INFO    : Bus 3154	: V=1.0026325, theta=-76.502197 -> V=1.0, theta=0.0
% INFO    : Bus 3155	: V=1.0180557, theta=-75.603176 -> V=1.0, theta=0.0
% INFO    : Bus 3156	: V=1.0094939, theta=-76.562254 -> V=1.0, theta=0.0
% INFO    : Bus 3157	: V=1.0185656, theta=-75.524085 -> V=1.0, theta=0.0
% INFO    : Bus 3158	: V=1.0056114, theta=-76.68187 -> V=1.0, theta=0.0
% INFO    : Bus 3159	: V=1.0066891, theta=-76.655787 -> V=1.0, theta=0.0
% INFO    : Bus 3160	: V=1.0069973, theta=-76.652999 -> V=1.0, theta=0.0
% INFO    : Bus 3161	: V=1.0020871, theta=-76.571428 -> V=1.0, theta=0.0
% INFO    : Bus 3162	: V=1.0017794, theta=-76.572995 -> V=1.0, theta=0.0
% INFO    : Bus 3163	: V=1.0021794, theta=-76.572284 -> V=1.0, theta=0.0
% INFO    : Bus 3164	: V=1.0147343, theta=-75.404706 -> V=1.0, theta=0.0
% INFO    : Bus 3165	: V=1.0019108, theta=-76.681913 -> V=1.0, theta=0.0
% INFO    : Bus 3166	: V=1.0024388, theta=-76.606926 -> V=1.0, theta=0.0
% INFO    : Bus 3167	: V=1.0028905, theta=-76.602014 -> V=1.0, theta=0.0
% INFO    : Bus 3168	: V=1.0014321, theta=-76.732869 -> V=1.0, theta=0.0
% INFO    : Bus 3169	: V=0.9990503, theta=-76.837076 -> V=1.0, theta=0.0
% INFO    : Bus 3170	: V=1.0008529, theta=-76.791191 -> V=1.0, theta=0.0
% INFO    : Bus 3171	: V=1.0014116, theta=-76.757283 -> V=1.0, theta=0.0
% INFO    : Bus 3172	: V=1.0026439, theta=-76.742879 -> V=1.0, theta=0.0
% INFO    : Bus 3173	: V=0.9999493, theta=-76.83006 -> V=1.0, theta=0.0
% INFO    : Bus 3174	: V=1.0160265, theta=-75.452603 -> V=1.0, theta=0.0
% INFO    : Bus 3175	: V=1.0173175, theta=-75.51701 -> V=1.0, theta=0.0
% INFO    : Bus 3176	: V=1.0029074, theta=-76.767749 -> V=1.0, theta=0.0
% INFO    : Bus 3177	: V=1.001162, theta=-76.792675 -> V=1.0, theta=0.0
% INFO    : Bus 3178	: V=0.9991449, theta=-76.889382 -> V=1.0, theta=0.0
% INFO    : Bus 3179	: V=0.9980869, theta=-77.040206 -> V=1.0, theta=0.0
% INFO    : Bus 3180	: V=1.015887, theta=-75.767836 -> V=1.0, theta=0.0
% INFO    : Bus 3181	: V=1.0143705, theta=-75.852132 -> V=1.0, theta=0.0
% INFO    : Bus 3182	: V=1.0133131, theta=-75.909583 -> V=1.0, theta=0.0
% INFO    : Bus 3183	: V=1.0145702, theta=-75.842597 -> V=1.0, theta=0.0
% INFO    : Bus 3184	: V=1.017113, theta=-75.698316 -> V=1.0, theta=0.0
% INFO    : Bus 3185	: V=1.0175703, theta=-75.67 -> V=1.0, theta=0.0
% INFO    : Bus 3186	: V=1.0173206, theta=-75.68775 -> V=1.0, theta=0.0
% INFO    : Bus 3187	: V=1.0114745, theta=-76.437906 -> V=1.0, theta=0.0
% INFO    : Bus 3188	: V=1.0148103, theta=-75.827234 -> V=1.0, theta=0.0
% INFO    : Bus 3189	: V=1.0066171, theta=-76.607915 -> V=1.0, theta=0.0
% INFO    : Bus 3190	: V=1.016103, theta=-75.749181 -> V=1.0, theta=0.0
% INFO    : Bus 3191	: V=0.9919316, theta=-78.055459 -> V=1.0, theta=0.0
% INFO    : Bus 3192	: V=1.0089746, theta=-76.584713 -> V=1.0, theta=0.0
% INFO    : Bus 3193	: V=1.0071284, theta=-76.645602 -> V=1.0, theta=0.0
% INFO    : Bus 3194	: V=1.0011363, theta=-75.498485 -> V=1.0, theta=0.0
% INFO    : Bus 3195	: V=1.0021882, theta=-75.363379 -> V=1.0, theta=0.0
% INFO    : Bus 3196	: V=0.9970273, theta=-75.804548 -> V=1.0, theta=0.0
% INFO    : Bus 3197	: V=1.0027036, theta=-75.30439 -> V=1.0, theta=0.0
% INFO    : Bus 3198	: V=1.0024569, theta=-76.808215 -> V=1.0, theta=0.0
% INFO    : Bus 3199	: V=1.0036878, theta=-76.395194 -> V=1.0, theta=0.0
% INFO    : Bus 3200	: V=1.0047755, theta=-76.348341 -> V=1.0, theta=0.0
% INFO    : Bus 3201	: V=1.0056777, theta=-76.308114 -> V=1.0, theta=0.0
% INFO    : Bus 3202	: V=1.0020493, theta=-76.464099 -> V=1.0, theta=0.0
% INFO    : Bus 3203	: V=0.9928072, theta=-76.946219 -> V=1.0, theta=0.0
% INFO    : Bus 3204	: V=0.991754, theta=-76.957171 -> V=1.0, theta=0.0
% INFO    : Bus 3205	: V=0.9928801, theta=-76.786855 -> V=1.0, theta=0.0
% INFO    : Bus 3206	: V=0.994871, theta=-76.485632 -> V=1.0, theta=0.0
% INFO    : Bus 3207	: V=0.9903759, theta=-76.347037 -> V=1.0, theta=0.0
% INFO    : Bus 3208	: V=0.9921323, theta=-76.327701 -> V=1.0, theta=0.0
% INFO    : Bus 3209	: V=0.9981895, theta=-76.73717 -> V=1.0, theta=0.0
% INFO    : Bus 3210	: V=1.001647, theta=-76.669658 -> V=1.0, theta=0.0
% INFO    : Bus 3211	: V=1.0046682, theta=-76.570045 -> V=1.0, theta=0.0
% INFO    : Bus 3212	: V=0.9963443, theta=-77.098234 -> V=1.0, theta=0.0
% INFO    : Bus 3213	: V=0.9984178, theta=-76.894197 -> V=1.0, theta=0.0
% INFO    : Bus 3214	: V=0.9972503, theta=-76.935572 -> V=1.0, theta=0.0
% INFO    : Bus 3215	: V=0.9989734, theta=-76.913136 -> V=1.0, theta=0.0
% INFO    : Bus 3216	: V=0.9981339, theta=-76.926624 -> V=1.0, theta=0.0
% INFO    : Bus 3217	: V=1.0062406, theta=-75.918884 -> V=1.0, theta=0.0
% INFO    : Bus 3218	: V=1.0125001, theta=-75.268045 -> V=1.0, theta=0.0
% INFO    : Bus 3219	: V=1.0171282, theta=-74.856566 -> V=1.0, theta=0.0
% INFO    : Bus 3220	: V=1.0132652, theta=-75.227255 -> V=1.0, theta=0.0
% INFO    : Bus 3221	: V=1.0151663, theta=-75.119061 -> V=1.0, theta=0.0
% INFO    : Bus 3222	: V=1.0105748, theta=-75.533591 -> V=1.0, theta=0.0
% INFO    : Bus 3223	: V=1.0187874, theta=-74.851304 -> V=1.0, theta=0.0
% INFO    : Bus 3224	: V=1.0119394, theta=-74.87079 -> V=1.0, theta=0.0
% INFO    : Bus 3225	: V=1.00359, theta=-76.150703 -> V=1.0, theta=0.0
% INFO    : Bus 3226	: V=1.0001657, theta=-76.289007 -> V=1.0, theta=0.0
% INFO    : Bus 3227	: V=1.0143839, theta=-74.88802 -> V=1.0, theta=0.0
% INFO    : Bus 3228	: V=0.9984461, theta=-75.671112 -> V=1.0, theta=0.0
% INFO    : Bus 3229	: V=1.0108743, theta=-74.778732 -> V=1.0, theta=0.0
% INFO    : Bus 3230	: V=1.0117655, theta=-74.736221 -> V=1.0, theta=0.0
% INFO    : Bus 3231	: V=1.0096516, theta=-74.369124 -> V=1.0, theta=0.0
% INFO    : Bus 3232	: V=1.002057, theta=-74.822004 -> V=1.0, theta=0.0
% INFO    : Bus 3233	: V=1.015671, theta=-74.281297 -> V=1.0, theta=0.0
% INFO    : Bus 3234	: V=1.0031047, theta=-74.463535 -> V=1.0, theta=0.0
% INFO    : Bus 3235	: V=0.9954565, theta=-76.348618 -> V=1.0, theta=0.0
% INFO    : Bus 3236	: V=1.0160235, theta=-74.246276 -> V=1.0, theta=0.0
% INFO    : Bus 3237	: V=1.0105307, theta=-73.833309 -> V=1.0, theta=0.0
% INFO    : Bus 3238	: V=1.0046363, theta=-73.372936 -> V=1.0, theta=0.0
% INFO    : Bus 3239	: V=0.9985149, theta=-76.62455 -> V=1.0, theta=0.0
% INFO    : Bus 3240	: V=0.9999007, theta=-76.624735 -> V=1.0, theta=0.0
% INFO    : Bus 3241	: V=1.0135563, theta=-75.545505 -> V=1.0, theta=0.0
% INFO    : Bus 3242	: V=0.997683, theta=-76.408049 -> V=1.0, theta=0.0
% INFO    : Bus 3243	: V=0.9982243, theta=-76.394818 -> V=1.0, theta=0.0
% INFO    : Bus 3244	: V=0.9970856, theta=-76.264722 -> V=1.0, theta=0.0
% INFO    : Bus 3245	: V=0.9981077, theta=-76.252146 -> V=1.0, theta=0.0
% INFO    : Bus 3246	: V=0.9989195, theta=-76.387819 -> V=1.0, theta=0.0
% INFO    : Bus 3247	: V=1.0154773, theta=-75.366673 -> V=1.0, theta=0.0
% INFO    : Bus 3248	: V=0.9922583, theta=-76.486507 -> V=1.0, theta=0.0
% INFO    : Bus 3249	: V=1.001345, theta=-76.044877 -> V=1.0, theta=0.0
% INFO    : Bus 3250	: V=0.9996362, theta=-76.068099 -> V=1.0, theta=0.0
% INFO    : Bus 3251	: V=1.0026673, theta=-75.806667 -> V=1.0, theta=0.0
% INFO    : Bus 3252	: V=1.0040077, theta=-75.796072 -> V=1.0, theta=0.0
% INFO    : Bus 3253	: V=1.0130849, theta=-75.017365 -> V=1.0, theta=0.0
% INFO    : Bus 3254	: V=1.0166695, theta=-75.297842 -> V=1.0, theta=0.0
% INFO    : Bus 3255	: V=1.0175127, theta=-74.903622 -> V=1.0, theta=0.0
% INFO    : Bus 3256	: V=1.0079754, theta=-76.462313 -> V=1.0, theta=0.0
% INFO    : Bus 3257	: V=1.0072154, theta=-76.238472 -> V=1.0, theta=0.0
% INFO    : Bus 3258	: V=1.0034405, theta=-76.729502 -> V=1.0, theta=0.0
% INFO    : Bus 3259	: V=1.0012651, theta=-76.870669 -> V=1.0, theta=0.0
% INFO    : Bus 3260	: V=1.0013853, theta=-76.864201 -> V=1.0, theta=0.0
% INFO    : Bus 3261	: V=1.0012696, theta=-76.877097 -> V=1.0, theta=0.0
% INFO    : Bus 3262	: V=1.0015325, theta=-76.877797 -> V=1.0, theta=0.0
% INFO    : Bus 3263	: V=1.0008249, theta=-76.884656 -> V=1.0, theta=0.0
% INFO    : Bus 3264	: V=1.001627, theta=-76.865199 -> V=1.0, theta=0.0
% INFO    : Bus 3265	: V=1.0022312, theta=-76.858364 -> V=1.0, theta=0.0
% INFO    : Bus 3266	: V=1.0016815, theta=-76.850506 -> V=1.0, theta=0.0
% INFO    : Bus 3267	: V=1.0082647, theta=-76.192743 -> V=1.0, theta=0.0
% INFO    : Bus 3268	: V=1.011393, theta=-76.295355 -> V=1.0, theta=0.0
% INFO    : Bus 3269	: V=1.01017, theta=-76.38276 -> V=1.0, theta=0.0
% INFO    : Bus 3270	: V=1.0085773, theta=-76.470139 -> V=1.0, theta=0.0
% INFO    : Bus 3271	: V=1.0072346, theta=-76.548485 -> V=1.0, theta=0.0
% INFO    : Bus 3272	: V=1.0054161, theta=-76.66606 -> V=1.0, theta=0.0
% INFO    : Bus 3273	: V=1.0033651, theta=-76.800138 -> V=1.0, theta=0.0
% INFO    : Bus 3274	: V=1.0034613, theta=-76.74326 -> V=1.0, theta=0.0
% INFO    : Bus 3275	: V=1.003857, theta=-76.738986 -> V=1.0, theta=0.0
% INFO    : Bus 3276	: V=1.0135746, theta=-75.895385 -> V=1.0, theta=0.0
% INFO    : Bus 3277	: V=0.9983763, theta=-76.012533 -> V=1.0, theta=0.0
% INFO    : Bus 3278	: V=0.9975882, theta=-76.020545 -> V=1.0, theta=0.0
% INFO    : Bus 3279	: V=0.9997615, theta=-75.934335 -> V=1.0, theta=0.0
% INFO    : Bus 3280	: V=0.9993891, theta=-75.963629 -> V=1.0, theta=0.0
% INFO    : Bus 3281	: V=0.9989795, theta=-75.942163 -> V=1.0, theta=0.0
% INFO    : Bus 3282	: V=0.9990781, theta=-75.988131 -> V=1.0, theta=0.0
% INFO    : Bus 3283	: V=0.9989565, theta=-75.99988 -> V=1.0, theta=0.0
% INFO    : Bus 3284	: V=0.9988524, theta=-76.008091 -> V=1.0, theta=0.0
% INFO    : Bus 3285	: V=1.0097261, theta=-74.850451 -> V=1.0, theta=0.0
% INFO    : Bus 3286	: V=0.9992359, theta=-75.984066 -> V=1.0, theta=0.0
% INFO    : Bus 3287	: V=0.9990886, theta=-75.99162 -> V=1.0, theta=0.0
% INFO    : Bus 3288	: V=0.9981465, theta=-76.059693 -> V=1.0, theta=0.0
% INFO    : Bus 3289	: V=0.9977231, theta=-76.038637 -> V=1.0, theta=0.0
% INFO    : Bus 3290	: V=0.9639295, theta=-69.150118 -> V=1.0, theta=0.0
% INFO    : Bus 3291	: V=0.985236, theta=-74.57517 -> V=1.0, theta=0.0
% INFO    : Bus 3292	: V=0.978451, theta=-75.328643 -> V=1.0, theta=0.0
% INFO    : Bus 3293	: V=0.9827075, theta=-75.511569 -> V=1.0, theta=0.0
% INFO    : Bus 3294	: V=0.9847621, theta=-74.510361 -> V=1.0, theta=0.0
% INFO    : Bus 3295	: V=0.9801355, theta=-74.389001 -> V=1.0, theta=0.0
% INFO    : Bus 3296	: V=0.9759905, theta=-73.350366 -> V=1.0, theta=0.0
% INFO    : Bus 3297	: V=0.9794203, theta=-73.911032 -> V=1.0, theta=0.0
% INFO    : Bus 3298	: V=0.9762715, theta=-71.097163 -> V=1.0, theta=0.0
% INFO    : Bus 3299	: V=0.9871977, theta=-70.694298 -> V=1.0, theta=0.0
% INFO    : Bus 3300	: V=0.9905612, theta=-69.627214 -> V=1.0, theta=0.0
% INFO    : Bus 3301	: V=0.9900804, theta=-67.49768 -> V=1.0, theta=0.0
% INFO    : Bus 3302	: V=0.9897371, theta=-67.752438 -> V=1.0, theta=0.0
% INFO    : Bus 3303	: V=0.9887791, theta=-67.744181 -> V=1.0, theta=0.0
% INFO    : Bus 3304	: V=0.9865888, theta=-68.185302 -> V=1.0, theta=0.0
% INFO    : Bus 3305	: V=0.9786622, theta=-68.940989 -> V=1.0, theta=0.0
% INFO    : Bus 3306	: V=0.9834083, theta=-68.916574 -> V=1.0, theta=0.0
% INFO    : Bus 3307	: V=0.9815367, theta=-69.413886 -> V=1.0, theta=0.0
% INFO    : Bus 3308	: V=0.9745152, theta=-71.884253 -> V=1.0, theta=0.0
% INFO    : Bus 3309	: V=0.9791941, theta=-70.427168 -> V=1.0, theta=0.0
% INFO    : Bus 3310	: V=0.9797749, theta=-69.977232 -> V=1.0, theta=0.0
% INFO    : Bus 3311	: V=0.9781845, theta=-71.180769 -> V=1.0, theta=0.0
% INFO    : Bus 3312	: V=0.9740188, theta=-71.900617 -> V=1.0, theta=0.0
% INFO    : Bus 3313	: V=0.9764963, theta=-71.997154 -> V=1.0, theta=0.0
% INFO    : Bus 3314	: V=0.9760983, theta=-72.064248 -> V=1.0, theta=0.0
% INFO    : Bus 3315	: V=0.9778566, theta=-70.914276 -> V=1.0, theta=0.0
% INFO    : Bus 3316	: V=0.9738015, theta=-71.902322 -> V=1.0, theta=0.0
% INFO    : Bus 3317	: V=0.9766137, theta=-71.45658 -> V=1.0, theta=0.0
% INFO    : Bus 3318	: V=0.9813635, theta=-72.867807 -> V=1.0, theta=0.0
% INFO    : Bus 3319	: V=0.9780453, theta=-72.198449 -> V=1.0, theta=0.0
% INFO    : Bus 3320	: V=0.984726, theta=-71.497973 -> V=1.0, theta=0.0
% INFO    : Bus 3321	: V=0.9725923, theta=-72.366498 -> V=1.0, theta=0.0
% INFO    : Bus 3322	: V=0.9830793, theta=-72.300102 -> V=1.0, theta=0.0
% INFO    : Bus 3323	: V=0.9869427, theta=-71.380293 -> V=1.0, theta=0.0
% INFO    : Bus 3324	: V=0.9688959, theta=-73.150214 -> V=1.0, theta=0.0
% INFO    : Bus 3325	: V=0.9852036, theta=-70.971116 -> V=1.0, theta=0.0
% INFO    : Bus 3326	: V=0.9716216, theta=-70.887276 -> V=1.0, theta=0.0
% INFO    : Bus 3327	: V=0.9855245, theta=-70.598122 -> V=1.0, theta=0.0
% INFO    : Bus 3328	: V=0.9603326, theta=-72.743312 -> V=1.0, theta=0.0
% INFO    : Bus 3329	: V=0.968118, theta=-72.577539 -> V=1.0, theta=0.0
% INFO    : Bus 3330	: V=0.978021, theta=-71.527939 -> V=1.0, theta=0.0
% INFO    : Bus 3331	: V=0.9666523, theta=-72.611806 -> V=1.0, theta=0.0
% INFO    : Bus 3332	: V=0.9739941, theta=-72.990895 -> V=1.0, theta=0.0
% INFO    : Bus 3333	: V=0.9788403, theta=-71.747784 -> V=1.0, theta=0.0
% INFO    : Bus 3334	: V=0.9733972, theta=-73.002132 -> V=1.0, theta=0.0
% INFO    : Bus 3335	: V=0.9798613, theta=-72.921298 -> V=1.0, theta=0.0
% INFO    : Bus 3336	: V=0.9755175, theta=-72.970077 -> V=1.0, theta=0.0
% INFO    : Bus 3337	: V=0.9858312, theta=-72.997443 -> V=1.0, theta=0.0
% INFO    : Bus 3338	: V=0.9820285, theta=-71.859701 -> V=1.0, theta=0.0
% INFO    : Bus 3339	: V=0.9757889, theta=-72.93763 -> V=1.0, theta=0.0
% INFO    : Bus 3340	: V=0.9666019, theta=-80.029561 -> V=1.0, theta=0.0
% INFO    : Bus 3341	: V=0.9763166, theta=-79.050992 -> V=1.0, theta=0.0
% INFO    : Bus 3342	: V=0.9742356, theta=-79.191736 -> V=1.0, theta=0.0
% INFO    : Bus 3343	: V=0.9725617, theta=-79.314052 -> V=1.0, theta=0.0
% INFO    : Bus 3344	: V=0.9567362, theta=-80.492669 -> V=1.0, theta=0.0
% INFO    : Bus 3345	: V=0.955478, theta=-80.497106 -> V=1.0, theta=0.0
% INFO    : Bus 3346	: V=0.9541118, theta=-80.572297 -> V=1.0, theta=0.0
% INFO    : Bus 3347	: V=0.9647268, theta=-79.540265 -> V=1.0, theta=0.0
% INFO    : Bus 3348	: V=0.9642056, theta=-79.309177 -> V=1.0, theta=0.0
% INFO    : Bus 3349	: V=0.9581114, theta=-79.962106 -> V=1.0, theta=0.0
% INFO    : Bus 3350	: V=0.9928072, theta=-71.469675 -> V=1.0, theta=0.0
% INFO    : Bus 3351	: V=0.992132, theta=-71.452499 -> V=1.0, theta=0.0
% INFO    : Bus 3352	: V=1.0118375, theta=-68.773753 -> V=1.0, theta=0.0
% INFO    : Bus 3353	: V=0.9911894, theta=-71.160804 -> V=1.0, theta=0.0
% INFO    : Bus 3354	: V=0.9993908, theta=-69.21724 -> V=1.0, theta=0.0
% INFO    : Bus 3355	: V=1.0115027, theta=-68.762807 -> V=1.0, theta=0.0
% INFO    : Bus 3356	: V=0.9891572, theta=-71.486343 -> V=1.0, theta=0.0
% INFO    : Bus 3357	: V=0.9904624, theta=-71.294012 -> V=1.0, theta=0.0
% INFO    : Bus 3358	: V=0.9898346, theta=-71.382426 -> V=1.0, theta=0.0
% INFO    : Bus 3359	: V=0.9865123, theta=-71.575669 -> V=1.0, theta=0.0
% INFO    : Bus 3360	: V=0.9915674, theta=-72.736396 -> V=1.0, theta=0.0
% INFO    : Bus 3361	: V=0.9986594, theta=-71.893843 -> V=1.0, theta=0.0
% INFO    : Bus 3362	: V=1.0226097, theta=-69.444748 -> V=1.0, theta=0.0
% INFO    : Bus 3363	: V=0.9978325, theta=-72.038488 -> V=1.0, theta=0.0
% INFO    : Bus 3364	: V=0.9940384, theta=-71.452431 -> V=1.0, theta=0.0
% INFO    : Bus 3365	: V=1.0116962, theta=-68.805971 -> V=1.0, theta=0.0
% INFO    : Bus 3366	: V=1.0109247, theta=-68.80936 -> V=1.0, theta=0.0
% INFO    : Bus 3367	: V=0.9876528, theta=-72.618299 -> V=1.0, theta=0.0
% INFO    : Bus 3368	: V=1.0011233, theta=-71.232562 -> V=1.0, theta=0.0
% INFO    : Bus 3369	: V=0.9959249, theta=-71.769841 -> V=1.0, theta=0.0
% INFO    : Bus 3370	: V=0.9813891, theta=-73.210896 -> V=1.0, theta=0.0
% INFO    : Bus 3371	: V=0.9746352, theta=-73.500214 -> V=1.0, theta=0.0
% INFO    : Bus 3372	: V=0.9695712, theta=-73.527379 -> V=1.0, theta=0.0
% INFO    : Bus 3373	: V=0.9803873, theta=-72.646727 -> V=1.0, theta=0.0
% INFO    : Bus 3374	: V=0.9836542, theta=-72.788592 -> V=1.0, theta=0.0
% INFO    : Bus 3375	: V=0.9808599, theta=-71.664284 -> V=1.0, theta=0.0
% INFO    : Bus 3376	: V=0.9836185, theta=-71.625987 -> V=1.0, theta=0.0
% INFO    : Bus 3377	: V=0.993049, theta=-71.441502 -> V=1.0, theta=0.0
% INFO    : Bus 3378	: V=0.9899032, theta=-71.487574 -> V=1.0, theta=0.0
% INFO    : Bus 3379	: V=0.9818664, theta=-72.887742 -> V=1.0, theta=0.0
% INFO    : Bus 3380	: V=0.9788541, theta=-74.794447 -> V=1.0, theta=0.0
% INFO    : Bus 3381	: V=0.9985911, theta=-71.206959 -> V=1.0, theta=0.0
% INFO    : Bus 3382	: V=0.988686, theta=-71.571051 -> V=1.0, theta=0.0
% INFO    : Bus 3383	: V=0.9990184, theta=-71.199795 -> V=1.0, theta=0.0
% INFO    : Bus 3384	: V=0.9879643, theta=-72.33537 -> V=1.0, theta=0.0
% INFO    : Bus 3385	: V=0.9739027, theta=-79.353737 -> V=1.0, theta=0.0
% INFO    : Bus 3386	: V=0.9684636, theta=-79.719263 -> V=1.0, theta=0.0
% INFO    : Bus 3387	: V=0.9820849, theta=-78.657946 -> V=1.0, theta=0.0
% INFO    : Bus 3388	: V=0.9630031, theta=-76.25012 -> V=1.0, theta=0.0
% INFO    : Bus 3389	: V=0.9490893, theta=-78.34367 -> V=1.0, theta=0.0
% INFO    : Bus 3390	: V=0.9590662, theta=-78.046995 -> V=1.0, theta=0.0
% INFO    : Bus 3391	: V=0.9753269, theta=-74.662824 -> V=1.0, theta=0.0
% INFO    : Bus 3392	: V=0.9683802, theta=-75.636664 -> V=1.0, theta=0.0
% INFO    : Bus 3393	: V=0.9818117, theta=-73.497309 -> V=1.0, theta=0.0
% INFO    : Bus 3394	: V=0.9822255, theta=-73.43061 -> V=1.0, theta=0.0
% INFO    : Bus 3395	: V=0.9828464, theta=-73.368647 -> V=1.0, theta=0.0
% INFO    : Bus 3396	: V=0.9896301, theta=-72.704384 -> V=1.0, theta=0.0
% INFO    : Bus 3397	: V=0.9808741, theta=-74.597948 -> V=1.0, theta=0.0
% INFO    : Bus 3398	: V=0.9579123, theta=-75.995275 -> V=1.0, theta=0.0
% INFO    : Bus 3399	: V=1.0006978, theta=-70.370252 -> V=1.0, theta=0.0
% INFO    : Bus 3400	: V=0.964436, theta=-77.814412 -> V=1.0, theta=0.0
% INFO    : Bus 3401	: V=0.9728213, theta=-76.388046 -> V=1.0, theta=0.0
% INFO    : Bus 3402	: V=0.9682266, theta=-77.575679 -> V=1.0, theta=0.0
% INFO    : Bus 3403	: V=0.9610035, theta=-78.764024 -> V=1.0, theta=0.0
% INFO    : Bus 3404	: V=0.9650024, theta=-79.160121 -> V=1.0, theta=0.0
% INFO    : Bus 3405	: V=0.9673878, theta=-79.034012 -> V=1.0, theta=0.0
% INFO    : Bus 3406	: V=0.9676447, theta=-80.958918 -> V=1.0, theta=0.0
% INFO    : Bus 3407	: V=0.9690868, theta=-79.375867 -> V=1.0, theta=0.0
% INFO    : Bus 3408	: V=0.9723264, theta=-78.905858 -> V=1.0, theta=0.0
% INFO    : Bus 3409	: V=0.9717652, theta=-79.151949 -> V=1.0, theta=0.0
% INFO    : Bus 3410	: V=0.9730913, theta=-78.018247 -> V=1.0, theta=0.0
% INFO    : Bus 3411	: V=0.9687966, theta=-77.770246 -> V=1.0, theta=0.0
% INFO    : Bus 3412	: V=0.9858085, theta=-76.010461 -> V=1.0, theta=0.0
% INFO    : Bus 3413	: V=0.959999, theta=-78.068229 -> V=1.0, theta=0.0
% INFO    : Bus 3414	: V=1.0028926, theta=-75.112317 -> V=1.0, theta=0.0
% INFO    : Bus 3415	: V=0.9666456, theta=-79.426626 -> V=1.0, theta=0.0
% INFO    : Bus 3416	: V=0.9731294, theta=-79.300728 -> V=1.0, theta=0.0
% INFO    : Bus 3417	: V=0.9648622, theta=-79.934367 -> V=1.0, theta=0.0
% INFO    : Bus 3418	: V=0.9621747, theta=-80.074079 -> V=1.0, theta=0.0
% INFO    : Bus 3419	: V=0.9616764, theta=-80.079145 -> V=1.0, theta=0.0
% INFO    : Bus 3420	: V=0.9614468, theta=-80.067556 -> V=1.0, theta=0.0
% INFO    : Bus 3421	: V=0.9615008, theta=-80.03401 -> V=1.0, theta=0.0
% INFO    : Bus 3422	: V=0.9583503, theta=-79.275874 -> V=1.0, theta=0.0
% INFO    : Bus 3423	: V=0.9389343, theta=-81.893584 -> V=1.0, theta=0.0
% INFO    : Bus 3424	: V=0.9488573, theta=-81.394252 -> V=1.0, theta=0.0
% INFO    : Bus 3425	: V=0.9537027, theta=-81.043807 -> V=1.0, theta=0.0
% INFO    : Bus 3426	: V=0.965281, theta=-79.87331 -> V=1.0, theta=0.0
% INFO    : Bus 3427	: V=0.9828089, theta=-69.587257 -> V=1.0, theta=0.0
% INFO    : Bus 3428	: V=0.993811, theta=-70.005024 -> V=1.0, theta=0.0
% INFO    : Bus 3429	: V=0.9803824, theta=-69.747188 -> V=1.0, theta=0.0
% INFO    : Bus 3430	: V=0.9896981, theta=-69.451603 -> V=1.0, theta=0.0
% INFO    : Bus 3431	: V=0.9956846, theta=-69.205968 -> V=1.0, theta=0.0
% INFO    : Bus 3432	: V=0.9929809, theta=-69.4026 -> V=1.0, theta=0.0
% INFO    : Bus 3433	: V=1.0111553, theta=-66.546228 -> V=1.0, theta=0.0
% INFO    : Bus 3434	: V=0.9822319, theta=-69.583358 -> V=1.0, theta=0.0
% INFO    : Bus 3435	: V=0.992148, theta=-69.500898 -> V=1.0, theta=0.0
% INFO    : Bus 3436	: V=0.9940789, theta=-69.373082 -> V=1.0, theta=0.0
% INFO    : Bus 3437	: V=0.9948284, theta=-69.366554 -> V=1.0, theta=0.0
% INFO    : Bus 3438	: V=0.9926761, theta=-69.526852 -> V=1.0, theta=0.0
% INFO    : Bus 3439	: V=0.9862335, theta=-69.621784 -> V=1.0, theta=0.0
% INFO    : Bus 3440	: V=0.9885432, theta=-70.020795 -> V=1.0, theta=0.0
% INFO    : Bus 3441	: V=0.9856491, theta=-69.686846 -> V=1.0, theta=0.0
% INFO    : Bus 3442	: V=0.9738503, theta=-70.835987 -> V=1.0, theta=0.0
% INFO    : Bus 3443	: V=0.9914784, theta=-69.637999 -> V=1.0, theta=0.0
% INFO    : Bus 3444	: V=0.9692554, theta=-71.431034 -> V=1.0, theta=0.0
% INFO    : Bus 3445	: V=0.9828264, theta=-70.766832 -> V=1.0, theta=0.0
% INFO    : Bus 3446	: V=0.9562402, theta=-72.808426 -> V=1.0, theta=0.0
% INFO    : Bus 3447	: V=0.9665377, theta=-79.500474 -> V=1.0, theta=0.0
% INFO    : Bus 3448	: V=0.9633698, theta=-79.598061 -> V=1.0, theta=0.0
% INFO    : Bus 3449	: V=0.9719736, theta=-80.541008 -> V=1.0, theta=0.0
% INFO    : Bus 3450	: V=0.9754019, theta=-80.442061 -> V=1.0, theta=0.0
% INFO    : Bus 3451	: V=0.9794877, theta=-78.907035 -> V=1.0, theta=0.0
% INFO    : Bus 3452	: V=0.9696487, theta=-79.033405 -> V=1.0, theta=0.0
% INFO    : Bus 3453	: V=0.9866061, theta=-78.821114 -> V=1.0, theta=0.0
% INFO    : Bus 3454	: V=0.9853984, theta=-78.907046 -> V=1.0, theta=0.0
% INFO    : Bus 3455	: V=0.9860273, theta=-78.897613 -> V=1.0, theta=0.0
% INFO    : Bus 3456	: V=0.9869891, theta=-78.886668 -> V=1.0, theta=0.0
% INFO    : Bus 3457	: V=0.9832619, theta=-78.862609 -> V=1.0, theta=0.0
% INFO    : Bus 3458	: V=0.9757725, theta=-78.694394 -> V=1.0, theta=0.0
% INFO    : Bus 3459	: V=0.9833246, theta=-77.629756 -> V=1.0, theta=0.0
% INFO    : Bus 3460	: V=0.9742917, theta=-78.718579 -> V=1.0, theta=0.0
% INFO    : Bus 3461	: V=0.974123, theta=-78.592883 -> V=1.0, theta=0.0
% INFO    : Bus 3462	: V=0.9801655, theta=-76.227675 -> V=1.0, theta=0.0
% INFO    : Bus 3463	: V=0.9657843, theta=-76.754163 -> V=1.0, theta=0.0
% INFO    : Bus 3464	: V=0.9759937, theta=-75.989655 -> V=1.0, theta=0.0
% INFO    : Bus 3465	: V=0.9769585, theta=-75.473681 -> V=1.0, theta=0.0
% INFO    : Bus 3466	: V=0.9818882, theta=-76.812945 -> V=1.0, theta=0.0
% INFO    : Bus 3467	: V=0.9659577, theta=-77.404253 -> V=1.0, theta=0.0
% INFO    : Bus 3468	: V=0.9669175, theta=-77.023318 -> V=1.0, theta=0.0
% INFO    : Bus 3469	: V=0.9910747, theta=-73.93826 -> V=1.0, theta=0.0
% INFO    : Bus 3470	: V=0.9936182, theta=-73.892879 -> V=1.0, theta=0.0
% INFO    : Bus 3471	: V=0.9987269, theta=-73.776855 -> V=1.0, theta=0.0
% INFO    : Bus 3472	: V=0.977093, theta=-76.01064 -> V=1.0, theta=0.0
% INFO    : Bus 3473	: V=0.9798496, theta=-75.684076 -> V=1.0, theta=0.0
% INFO    : Bus 3474	: V=0.9968465, theta=-74.013028 -> V=1.0, theta=0.0
% INFO    : Bus 3475	: V=1.0009037, theta=-73.753753 -> V=1.0, theta=0.0
% INFO    : Bus 3476	: V=1.0078687, theta=-73.363553 -> V=1.0, theta=0.0
% INFO    : Bus 3477	: V=1.0192451, theta=-72.58528 -> V=1.0, theta=0.0
% INFO    : Bus 3478	: V=1.0040015, theta=-73.392918 -> V=1.0, theta=0.0
% INFO    : Bus 3479	: V=0.9949084, theta=-74.123178 -> V=1.0, theta=0.0
% INFO    : Bus 3480	: V=0.9909042, theta=-74.199211 -> V=1.0, theta=0.0
% INFO    : Bus 3481	: V=0.9953654, theta=-73.920626 -> V=1.0, theta=0.0
% INFO    : Bus 3482	: V=1.0015144, theta=-73.008767 -> V=1.0, theta=0.0
% INFO    : Bus 3483	: V=0.9977224, theta=-73.52384 -> V=1.0, theta=0.0
% INFO    : Bus 3484	: V=1.0071119, theta=-75.06822 -> V=1.0, theta=0.0
% INFO    : Bus 3485	: V=0.9687897, theta=-77.432257 -> V=1.0, theta=0.0
% INFO    : Bus 3486	: V=0.9594258, theta=-78.028628 -> V=1.0, theta=0.0
% INFO    : Bus 3487	: V=0.9590147, theta=-78.034128 -> V=1.0, theta=0.0
% INFO    : Bus 3488	: V=0.9715231, theta=-77.207057 -> V=1.0, theta=0.0
% INFO    : Bus 3489	: V=0.9864135, theta=-76.691501 -> V=1.0, theta=0.0
% INFO    : Bus 3490	: V=0.993543, theta=-76.146955 -> V=1.0, theta=0.0
% INFO    : Bus 3491	: V=0.9974715, theta=-75.835048 -> V=1.0, theta=0.0
% INFO    : Bus 3492	: V=0.9788148, theta=-77.273862 -> V=1.0, theta=0.0
% INFO    : Bus 3493	: V=0.9831093, theta=-76.368213 -> V=1.0, theta=0.0
% INFO    : Bus 3494	: V=0.977605, theta=-76.425252 -> V=1.0, theta=0.0
% INFO    : Bus 3495	: V=0.9719985, theta=-77.807195 -> V=1.0, theta=0.0
% INFO    : Bus 3496	: V=0.9683782, theta=-78.040932 -> V=1.0, theta=0.0
% INFO    : Bus 3497	: V=0.9545401, theta=-79.894401 -> V=1.0, theta=0.0
% INFO    : Bus 3498	: V=0.9471023, theta=-80.091808 -> V=1.0, theta=0.0
% INFO    : Bus 3499	: V=0.9535567, theta=-77.787269 -> V=1.0, theta=0.0
% INFO    : Bus 3500	: V=0.9772996, theta=-77.242024 -> V=1.0, theta=0.0
% INFO    : Bus 3501	: V=0.9638975, theta=-79.136395 -> V=1.0, theta=0.0
% INFO    : Bus 3502	: V=1.02, theta=-58.910373 -> V=1.0, theta=0.0
% INFO    : Bus 3503	: V=1.0200004, theta=-58.9105 -> V=1.0, theta=0.0
% INFO    : Bus 3504	: V=1.02, theta=-49.90923 -> V=1.0, theta=0.0
% INFO    : Bus 3505	: V=1.00011, theta=-62.471483 -> V=1.0, theta=0.0
% INFO    : Bus 3506	: V=1.02, theta=-49.200364 -> V=1.0, theta=0.0
% INFO    : Bus 3507	: V=1.02, theta=-66.491945 -> V=1.0, theta=0.0
% INFO    : Bus 3508	: V=1.0199484, theta=-49.209161 -> V=1.0, theta=0.0
% INFO    : Bus 3509	: V=1.0175731, theta=-59.669796 -> V=1.0, theta=0.0
% INFO    : Bus 3510	: V=1.02, theta=-59.04803 -> V=1.0, theta=0.0
% INFO    : Bus 3511	: V=1.02, theta=-63.42499 -> V=1.0, theta=0.0
% INFO    : Bus 3512	: V=1.02, theta=-62.158496 -> V=1.0, theta=0.0
% INFO    : Bus 3513	: V=1.02, theta=-56.693538 -> V=1.0, theta=0.0
% INFO    : Bus 3514	: V=1.0163377, theta=-59.120695 -> V=1.0, theta=0.0
% INFO    : Bus 3515	: V=1.02, theta=-61.95262 -> V=1.0, theta=0.0
% INFO    : Bus 3516	: V=1.02, theta=-60.115307 -> V=1.0, theta=0.0
% INFO    : Bus 3517	: V=1.0119392, theta=-58.13428 -> V=1.0, theta=0.0
% INFO    : Bus 3518	: V=1.0100888, theta=-57.549771 -> V=1.0, theta=0.0
% INFO    : Bus 3519	: V=1.0045162, theta=-62.958456 -> V=1.0, theta=0.0
% INFO    : Bus 3520	: V=1.0035485, theta=-61.641433 -> V=1.0, theta=0.0
% INFO    : Bus 3521	: V=1.0117265, theta=-59.904958 -> V=1.0, theta=0.0
% INFO    : Bus 3522	: V=1.02, theta=-64.350087 -> V=1.0, theta=0.0
% INFO    : Bus 3523	: V=1.0066057, theta=-61.393172 -> V=1.0, theta=0.0
% INFO    : Bus 3524	: V=1.0009904, theta=-62.659952 -> V=1.0, theta=0.0
% INFO    : Bus 3525	: V=1.0043567, theta=-61.527186 -> V=1.0, theta=0.0
% INFO    : Bus 3526	: V=1.02, theta=-49.448881 -> V=1.0, theta=0.0
% INFO    : Bus 3527	: V=1.02, theta=-68.874143 -> V=1.0, theta=0.0
% INFO    : Bus 3528	: V=1.0044108, theta=-61.543615 -> V=1.0, theta=0.0
% INFO    : Bus 3529	: V=1.0105188, theta=-68.382665 -> V=1.0, theta=0.0
% INFO    : Bus 3530	: V=1.02, theta=-66.101977 -> V=1.0, theta=0.0
% INFO    : Bus 3531	: V=0.9959155, theta=-63.180064 -> V=1.0, theta=0.0
% INFO    : Bus 3532	: V=1.0001928, theta=-63.983197 -> V=1.0, theta=0.0
% INFO    : Bus 3533	: V=1.0121928, theta=-68.375643 -> V=1.0, theta=0.0
% INFO    : Bus 3534	: V=1.0191316, theta=-69.901779 -> V=1.0, theta=0.0
% INFO    : Bus 3535	: V=1.0024857, theta=-59.156648 -> V=1.0, theta=0.0
% INFO    : Bus 3536	: V=1.02, theta=-61.390025 -> V=1.0, theta=0.0
% INFO    : Bus 3537	: V=1.02, theta=-61.4355 -> V=1.0, theta=0.0
% INFO    : Bus 3538	: V=1.02, theta=-66.968153 -> V=1.0, theta=0.0
% INFO    : Bus 3539	: V=0.9877225, theta=-65.77158 -> V=1.0, theta=0.0
% INFO    : Bus 3540	: V=1.02, theta=-65.534775 -> V=1.0, theta=0.0
% INFO    : Bus 3541	: V=1.02, theta=-65.351961 -> V=1.0, theta=0.0
% INFO    : Bus 3542	: V=1.02, theta=-68.555545 -> V=1.0, theta=0.0
% INFO    : Bus 3543	: V=1.02, theta=-68.194611 -> V=1.0, theta=0.0
% INFO    : Bus 3544	: V=1.0186597, theta=-70.70155 -> V=1.0, theta=0.0
% INFO    : Bus 3545	: V=1.02, theta=-58.056849 -> V=1.0, theta=0.0
% INFO    : Bus 3546	: V=1.0085404, theta=-60.444633 -> V=1.0, theta=0.0
% INFO    : Bus 3547	: V=1.02, theta=-59.102929 -> V=1.0, theta=0.0
% INFO    : Bus 3548	: V=1.02, theta=-64.407282 -> V=1.0, theta=0.0
% INFO    : Bus 3549	: V=0.9985628, theta=-69.75398 -> V=1.0, theta=0.0
% INFO    : Bus 3550	: V=0.9828162, theta=-61.120404 -> V=1.0, theta=0.0
% INFO    : Bus 3551	: V=0.9830438, theta=-62.46751 -> V=1.0, theta=0.0
% INFO    : Bus 3552	: V=0.9868285, theta=-65.22143 -> V=1.0, theta=0.0
% INFO    : Bus 3553	: V=0.9947695, theta=-65.611315 -> V=1.0, theta=0.0
% INFO    : Bus 3554	: V=1.0110828, theta=-74.358791 -> V=1.0, theta=0.0
% INFO    : Bus 3555	: V=1.0064655, theta=-61.386136 -> V=1.0, theta=0.0
% INFO    : Bus 3556	: V=1.0167863, theta=-51.419858 -> V=1.0, theta=0.0
% INFO    : Bus 3557	: V=1.0339905, theta=-64.688114 -> V=1.0, theta=0.0
% INFO    : Bus 3558	: V=1.0186984, theta=-58.474907 -> V=1.0, theta=0.0
% INFO    : Bus 3559	: V=1.02, theta=-68.355405 -> V=1.0, theta=0.0
% INFO    : Bus 3560	: V=1.02, theta=-73.645411 -> V=1.0, theta=0.0
% INFO    : Bus 3561	: V=1.0047779, theta=-70.303165 -> V=1.0, theta=0.0
% INFO    : Bus 3562	: V=0.992891, theta=-63.963298 -> V=1.0, theta=0.0
% INFO    : Bus 3563	: V=1.0044614, theta=-59.943911 -> V=1.0, theta=0.0
% INFO    : Bus 3564	: V=1.02, theta=-58.668766 -> V=1.0, theta=0.0
% INFO    : Bus 3565	: V=1.000116, theta=-63.989484 -> V=1.0, theta=0.0
% INFO    : Bus 3566	: V=1.0173238, theta=-58.28443 -> V=1.0, theta=0.0
% INFO    : Bus 3567	: V=0.9882321, theta=-63.663349 -> V=1.0, theta=0.0
% INFO    : Bus 3568	: V=0.9938527, theta=-61.519421 -> V=1.0, theta=0.0
% INFO    : Bus 3569	: V=1.0192314, theta=-58.108461 -> V=1.0, theta=0.0
% INFO    : Bus 3570	: V=0.9892082, theta=-63.282104 -> V=1.0, theta=0.0
% INFO    : Bus 3571	: V=1.0199839, theta=-64.350642 -> V=1.0, theta=0.0
% INFO    : Bus 3572	: V=0.997165, theta=-63.177994 -> V=1.0, theta=0.0
% INFO    : Bus 3573	: V=0.9862675, theta=-60.478428 -> V=1.0, theta=0.0
% INFO    : Bus 3574	: V=1.0059528, theta=-69.773702 -> V=1.0, theta=0.0
% INFO    : Bus 3575	: V=0.9576704, theta=-75.53205 -> V=1.0, theta=0.0
% INFO    : Bus 3576	: V=0.9746541, theta=-70.761687 -> V=1.0, theta=0.0
% INFO    : Bus 3577	: V=1.0045506, theta=-70.133909 -> V=1.0, theta=0.0
% INFO    : Bus 3578	: V=0.9906606, theta=-64.082173 -> V=1.0, theta=0.0
% INFO    : Bus 3579	: V=0.9882094, theta=-63.350295 -> V=1.0, theta=0.0
% INFO    : Bus 3580	: V=1.0041595, theta=-60.403319 -> V=1.0, theta=0.0
% INFO    : Bus 3581	: V=0.9896345, theta=-64.223133 -> V=1.0, theta=0.0
% INFO    : Bus 3582	: V=0.9895716, theta=-64.208907 -> V=1.0, theta=0.0
% INFO    : Bus 3583	: V=0.9861938, theta=-64.705785 -> V=1.0, theta=0.0
% INFO    : Bus 3584	: V=0.9895201, theta=-62.693197 -> V=1.0, theta=0.0
% INFO    : Bus 3585	: V=0.9986486, theta=-66.335889 -> V=1.0, theta=0.0
% INFO    : Bus 3586	: V=1.0059034, theta=-59.73912 -> V=1.0, theta=0.0
% INFO    : Bus 3587	: V=0.9813006, theta=-63.933177 -> V=1.0, theta=0.0
% INFO    : Bus 3588	: V=0.9909952, theta=-74.107253 -> V=1.0, theta=0.0
% INFO    : Bus 3589	: V=0.9935953, theta=-69.66357 -> V=1.0, theta=0.0
% INFO    : Bus 3590	: V=1.0068595, theta=-68.434361 -> V=1.0, theta=0.0
% INFO    : Bus 3591	: V=0.9691566, theta=-71.709079 -> V=1.0, theta=0.0
% INFO    : Bus 3592	: V=1.02, theta=-69.586386 -> V=1.0, theta=0.0
% INFO    : Bus 3593	: V=0.9990287, theta=-61.657676 -> V=1.0, theta=0.0
% INFO    : Bus 3594	: V=0.9858061, theta=-66.507648 -> V=1.0, theta=0.0
% INFO    : Bus 3595	: V=0.9795691, theta=-61.727105 -> V=1.0, theta=0.0
% INFO    : Bus 3596	: V=0.9978045, theta=-71.193285 -> V=1.0, theta=0.0
% INFO    : Bus 3597	: V=1.0120431, theta=-71.342935 -> V=1.0, theta=0.0
% INFO    : Bus 3598	: V=0.9921099, theta=-63.971814 -> V=1.0, theta=0.0
% INFO    : Bus 3599	: V=1.007061, theta=-69.912859 -> V=1.0, theta=0.0
% INFO    : Bus 3600	: V=1.0004105, theta=-58.142449 -> V=1.0, theta=0.0
% INFO    : Bus 3601	: V=1.02, theta=-69.527386 -> V=1.0, theta=0.0
% INFO    : Bus 3602	: V=1.0104789, theta=-69.869455 -> V=1.0, theta=0.0
% INFO    : Bus 3603	: V=0.984619, theta=-61.837448 -> V=1.0, theta=0.0
% INFO    : Bus 3604	: V=1.02, theta=-57.345055 -> V=1.0, theta=0.0
% INFO    : Bus 3605	: V=0.9807606, theta=-64.962134 -> V=1.0, theta=0.0
% INFO    : Bus 3606	: V=0.9926629, theta=-65.178244 -> V=1.0, theta=0.0
% INFO    : Bus 3607	: V=0.9855168, theta=-61.651622 -> V=1.0, theta=0.0
% INFO    : Bus 3608	: V=1.0066333, theta=-60.35934 -> V=1.0, theta=0.0
% INFO    : Bus 3609	: V=0.9980376, theta=-67.904128 -> V=1.0, theta=0.0
% INFO    : Bus 3610	: V=1.02, theta=-63.555953 -> V=1.0, theta=0.0
% INFO    : Bus 3611	: V=0.9859262, theta=-69.637375 -> V=1.0, theta=0.0
% INFO    : Bus 3612	: V=0.9901977, theta=-63.993454 -> V=1.0, theta=0.0
% INFO    : Bus 3613	: V=1.02, theta=-64.700844 -> V=1.0, theta=0.0
% INFO    : Bus 3614	: V=1.02, theta=-74.602388 -> V=1.0, theta=0.0
% INFO    : Bus 3615	: V=1.015231, theta=-69.149308 -> V=1.0, theta=0.0
% INFO    : Bus 3616	: V=1.0161514, theta=-66.276392 -> V=1.0, theta=0.0
% INFO    : Bus 3617	: V=0.9866419, theta=-63.190045 -> V=1.0, theta=0.0
% INFO    : Bus 3618	: V=1.0044292, theta=-70.042218 -> V=1.0, theta=0.0
% INFO    : Bus 3619	: V=0.9882332, theta=-63.302424 -> V=1.0, theta=0.0
% INFO    : Bus 3620	: V=0.987837, theta=-69.935129 -> V=1.0, theta=0.0
% INFO    : Bus 3621	: V=0.9882114, theta=-66.016536 -> V=1.0, theta=0.0
% INFO    : Bus 3622	: V=0.9905962, theta=-65.053609 -> V=1.0, theta=0.0
% INFO    : Bus 3623	: V=1.0015698, theta=-64.743152 -> V=1.0, theta=0.0
% INFO    : Bus 3624	: V=0.9840056, theta=-63.493108 -> V=1.0, theta=0.0
% INFO    : Bus 3625	: V=1.02, theta=-64.550782 -> V=1.0, theta=0.0
% INFO    : Bus 3626	: V=0.9729189, theta=-68.651477 -> V=1.0, theta=0.0
% INFO    : Bus 3627	: V=1.0044136, theta=-61.02118 -> V=1.0, theta=0.0
% INFO    : Bus 3628	: V=1.0166688, theta=-71.379734 -> V=1.0, theta=0.0
% INFO    : Bus 3629	: V=1.0025521, theta=-73.8487 -> V=1.0, theta=0.0
% INFO    : Bus 3630	: V=0.9890193, theta=-67.494867 -> V=1.0, theta=0.0
% INFO    : Bus 3631	: V=0.9911223, theta=-67.302905 -> V=1.0, theta=0.0
% INFO    : Bus 3632	: V=0.9693457, theta=-69.405473 -> V=1.0, theta=0.0
% INFO    : Bus 3633	: V=0.9646955, theta=-69.610647 -> V=1.0, theta=0.0
% INFO    : Bus 3634	: V=0.9673308, theta=-69.463953 -> V=1.0, theta=0.0
% INFO    : Bus 3635	: V=0.9654643, theta=-69.533529 -> V=1.0, theta=0.0
% INFO    : Bus 3636	: V=0.971609, theta=-69.203005 -> V=1.0, theta=0.0
% INFO    : Bus 3637	: V=0.9720423, theta=-69.157744 -> V=1.0, theta=0.0
% INFO    : Bus 3638	: V=0.972741, theta=-69.117643 -> V=1.0, theta=0.0
% INFO    : Bus 3639	: V=0.972289, theta=-69.181462 -> V=1.0, theta=0.0
% INFO    : Bus 3640	: V=0.9738709, theta=-69.007622 -> V=1.0, theta=0.0
% INFO    : Bus 3641	: V=0.9784198, theta=-68.664113 -> V=1.0, theta=0.0
% INFO    : Bus 3642	: V=0.9742208, theta=-69.004641 -> V=1.0, theta=0.0
% INFO    : Bus 3643	: V=0.9732859, theta=-69.03784 -> V=1.0, theta=0.0
% INFO    : Bus 3644	: V=0.9744424, theta=-68.951498 -> V=1.0, theta=0.0
% INFO    : Bus 3645	: V=0.9715127, theta=-69.039753 -> V=1.0, theta=0.0
% INFO    : Bus 3646	: V=0.972372, theta=-68.947629 -> V=1.0, theta=0.0
% INFO    : Bus 3647	: V=0.9664466, theta=-69.474407 -> V=1.0, theta=0.0
% INFO    : Bus 3648	: V=0.9762644, theta=-68.822712 -> V=1.0, theta=0.0
% INFO    : Bus 3649	: V=0.9778864, theta=-68.690391 -> V=1.0, theta=0.0
% INFO    : Bus 3650	: V=0.981231, theta=-68.407375 -> V=1.0, theta=0.0
% INFO    : Bus 3651	: V=0.993347, theta=-66.924928 -> V=1.0, theta=0.0
% INFO    : Bus 3652	: V=0.9759869, theta=-68.833219 -> V=1.0, theta=0.0
% INFO    : Bus 3653	: V=0.9771435, theta=-68.757255 -> V=1.0, theta=0.0
% INFO    : Bus 3654	: V=0.9973052, theta=-66.688545 -> V=1.0, theta=0.0
% INFO    : Bus 3655	: V=0.9962978, theta=-66.733979 -> V=1.0, theta=0.0
% INFO    : Bus 3656	: V=0.9650047, theta=-72.01334 -> V=1.0, theta=0.0
% INFO    : Bus 3657	: V=0.9654363, theta=-72.00121 -> V=1.0, theta=0.0
% INFO    : Bus 3658	: V=0.9691692, theta=-71.656507 -> V=1.0, theta=0.0
% INFO    : Bus 3659	: V=0.9693488, theta=-71.389788 -> V=1.0, theta=0.0
% INFO    : Bus 3660	: V=0.9628471, theta=-71.9558 -> V=1.0, theta=0.0
% INFO    : Bus 3661	: V=0.9634834, theta=-71.826915 -> V=1.0, theta=0.0
% INFO    : Bus 3662	: V=0.9634745, theta=-71.810464 -> V=1.0, theta=0.0
% INFO    : Bus 3663	: V=0.9659208, theta=-71.636156 -> V=1.0, theta=0.0
% INFO    : Bus 3664	: V=0.9702844, theta=-70.069118 -> V=1.0, theta=0.0
% INFO    : Bus 3665	: V=0.9634208, theta=-71.716539 -> V=1.0, theta=0.0
% INFO    : Bus 3666	: V=0.9685039, theta=-70.295793 -> V=1.0, theta=0.0
% INFO    : Bus 3667	: V=0.9606605, theta=-70.402642 -> V=1.0, theta=0.0
% INFO    : Bus 3668	: V=0.9683017, theta=-71.139869 -> V=1.0, theta=0.0
% INFO    : Bus 3669	: V=0.9676013, theta=-71.321519 -> V=1.0, theta=0.0
% INFO    : Bus 3670	: V=0.9861315, theta=-67.787298 -> V=1.0, theta=0.0
% INFO    : Bus 3671	: V=0.9758931, theta=-68.454823 -> V=1.0, theta=0.0
% INFO    : Bus 3672	: V=0.9660315, theta=-69.6307 -> V=1.0, theta=0.0
% INFO    : Bus 3673	: V=0.9670348, theta=-69.693364 -> V=1.0, theta=0.0
% INFO    : Bus 3674	: V=0.9627145, theta=-70.017177 -> V=1.0, theta=0.0
% INFO    : Bus 3675	: V=0.9824741, theta=-67.702321 -> V=1.0, theta=0.0
% INFO    : Bus 3676	: V=0.9650514, theta=-70.242118 -> V=1.0, theta=0.0
% INFO    : Bus 3677	: V=0.9652902, theta=-69.647663 -> V=1.0, theta=0.0
% INFO    : Bus 3678	: V=0.9750251, theta=-68.50659 -> V=1.0, theta=0.0
% INFO    : Bus 3679	: V=0.9649703, theta=-69.657051 -> V=1.0, theta=0.0
% INFO    : Bus 3680	: V=0.9668978, theta=-69.588487 -> V=1.0, theta=0.0
% INFO    : Bus 3681	: V=0.9741142, theta=-68.769612 -> V=1.0, theta=0.0
% INFO    : Bus 3682	: V=0.9840336, theta=-67.938381 -> V=1.0, theta=0.0
% INFO    : Bus 3683	: V=0.9805565, theta=-68.110971 -> V=1.0, theta=0.0
% INFO    : Bus 3684	: V=0.9959299, theta=-65.892673 -> V=1.0, theta=0.0
% INFO    : Bus 3685	: V=0.9969918, theta=-66.510551 -> V=1.0, theta=0.0
% INFO    : Bus 3686	: V=1.0000124, theta=-65.249382 -> V=1.0, theta=0.0
% INFO    : Bus 3687	: V=0.9991199, theta=-64.818675 -> V=1.0, theta=0.0
% INFO    : Bus 3688	: V=0.9822465, theta=-65.765519 -> V=1.0, theta=0.0
% INFO    : Bus 3689	: V=0.9832082, theta=-67.679058 -> V=1.0, theta=0.0
% INFO    : Bus 3690	: V=0.9914012, theta=-66.53828 -> V=1.0, theta=0.0
% INFO    : Bus 3691	: V=0.9811816, theta=-67.987314 -> V=1.0, theta=0.0
% INFO    : Bus 3692	: V=0.969277, theta=-69.56356 -> V=1.0, theta=0.0
% INFO    : Bus 3693	: V=0.9834613, theta=-67.522495 -> V=1.0, theta=0.0
% INFO    : Bus 3694	: V=0.9666226, theta=-69.41566 -> V=1.0, theta=0.0
% INFO    : Bus 3695	: V=0.9687178, theta=-69.194724 -> V=1.0, theta=0.0
% INFO    : Bus 3696	: V=0.9854774, theta=-67.234202 -> V=1.0, theta=0.0
% INFO    : Bus 3697	: V=0.9683914, theta=-68.942535 -> V=1.0, theta=0.0
% INFO    : Bus 3698	: V=0.9688546, theta=-68.937175 -> V=1.0, theta=0.0
% INFO    : Bus 3699	: V=0.9685227, theta=-69.195016 -> V=1.0, theta=0.0
% INFO    : Bus 3700	: V=0.971781, theta=-68.903072 -> V=1.0, theta=0.0
% INFO    : Bus 3701	: V=0.9649007, theta=-69.000937 -> V=1.0, theta=0.0
% INFO    : Bus 3702	: V=0.976385, theta=-67.773702 -> V=1.0, theta=0.0
% INFO    : Bus 3703	: V=0.980197, theta=-66.420809 -> V=1.0, theta=0.0
% INFO    : Bus 3704	: V=0.9837171, theta=-66.36806 -> V=1.0, theta=0.0
% INFO    : Bus 3705	: V=0.9718689, theta=-74.763119 -> V=1.0, theta=0.0
% INFO    : Bus 3706	: V=1.0070979, theta=-69.956041 -> V=1.0, theta=0.0
% INFO    : Bus 3707	: V=1.0106509, theta=-69.77025 -> V=1.0, theta=0.0
% INFO    : Bus 3708	: V=0.987276, theta=-72.690265 -> V=1.0, theta=0.0
% INFO    : Bus 3709	: V=0.9718142, theta=-74.759042 -> V=1.0, theta=0.0
% INFO    : Bus 3710	: V=0.9713334, theta=-75.29707 -> V=1.0, theta=0.0
% INFO    : Bus 3711	: V=0.970826, theta=-75.43124 -> V=1.0, theta=0.0
% INFO    : Bus 3712	: V=0.9782972, theta=-73.775568 -> V=1.0, theta=0.0
% INFO    : Bus 3713	: V=0.9722494, theta=-75.263564 -> V=1.0, theta=0.0
% INFO    : Bus 3714	: V=0.9541441, theta=-76.473027 -> V=1.0, theta=0.0
% INFO    : Bus 3715	: V=0.9600019, theta=-75.596701 -> V=1.0, theta=0.0
% INFO    : Bus 3716	: V=0.9720941, theta=-75.089545 -> V=1.0, theta=0.0
% INFO    : Bus 3717	: V=1.012122, theta=-69.882308 -> V=1.0, theta=0.0
% INFO    : Bus 3718	: V=0.9919135, theta=-64.068072 -> V=1.0, theta=0.0
% INFO    : Bus 3719	: V=0.9748277, theta=-66.675436 -> V=1.0, theta=0.0
% INFO    : Bus 3720	: V=0.9742826, theta=-66.773654 -> V=1.0, theta=0.0
% INFO    : Bus 3721	: V=0.9749814, theta=-66.7271 -> V=1.0, theta=0.0
% INFO    : Bus 3722	: V=1.0017335, theta=-61.905768 -> V=1.0, theta=0.0
% INFO    : Bus 3723	: V=0.9750058, theta=-66.670542 -> V=1.0, theta=0.0
% INFO    : Bus 3724	: V=0.9837167, theta=-65.469628 -> V=1.0, theta=0.0
% INFO    : Bus 3725	: V=0.9752678, theta=-66.6046 -> V=1.0, theta=0.0
% INFO    : Bus 3726	: V=0.9888299, theta=-64.354618 -> V=1.0, theta=0.0
% INFO    : Bus 3727	: V=0.9889315, theta=-64.335401 -> V=1.0, theta=0.0
% INFO    : Bus 3728	: V=0.9890364, theta=-64.318138 -> V=1.0, theta=0.0
% INFO    : Bus 3729	: V=0.9832609, theta=-65.161196 -> V=1.0, theta=0.0
% INFO    : Bus 3730	: V=0.9819866, theta=-65.681527 -> V=1.0, theta=0.0
% INFO    : Bus 3731	: V=0.9823888, theta=-65.694988 -> V=1.0, theta=0.0
% INFO    : Bus 3732	: V=0.9819186, theta=-65.765305 -> V=1.0, theta=0.0
% INFO    : Bus 3733	: V=0.9821551, theta=-65.729103 -> V=1.0, theta=0.0
% INFO    : Bus 3734	: V=0.9755459, theta=-66.65037 -> V=1.0, theta=0.0
% INFO    : Bus 3735	: V=0.9828536, theta=-65.658735 -> V=1.0, theta=0.0
% INFO    : Bus 3736	: V=0.9821281, theta=-65.327162 -> V=1.0, theta=0.0
% INFO    : Bus 3737	: V=0.9825229, theta=-65.703469 -> V=1.0, theta=0.0
% INFO    : Bus 3738	: V=0.9821347, theta=-65.338912 -> V=1.0, theta=0.0
% INFO    : Bus 3739	: V=0.9822852, theta=-65.712885 -> V=1.0, theta=0.0
% INFO    : Bus 3740	: V=0.9752255, theta=-66.659514 -> V=1.0, theta=0.0
% INFO    : Bus 3741	: V=0.9747308, theta=-66.678097 -> V=1.0, theta=0.0
% INFO    : Bus 3742	: V=0.9745894, theta=-66.72927 -> V=1.0, theta=0.0
% INFO    : Bus 3743	: V=0.9756777, theta=-66.608293 -> V=1.0, theta=0.0
% INFO    : Bus 3744	: V=0.9745991, theta=-66.72877 -> V=1.0, theta=0.0
% INFO    : Bus 3745	: V=0.9882183, theta=-64.420474 -> V=1.0, theta=0.0
% INFO    : Bus 3746	: V=0.9748295, theta=-66.665267 -> V=1.0, theta=0.0
% INFO    : Bus 3747	: V=0.9736876, theta=-66.960765 -> V=1.0, theta=0.0
% INFO    : Bus 3748	: V=0.9747387, theta=-66.717441 -> V=1.0, theta=0.0
% INFO    : Bus 3749	: V=0.9746338, theta=-66.720324 -> V=1.0, theta=0.0
% INFO    : Bus 3750	: V=0.9802143, theta=-65.82756 -> V=1.0, theta=0.0
% INFO    : Bus 3751	: V=0.9750091, theta=-66.45159 -> V=1.0, theta=0.0
% INFO    : Bus 3752	: V=0.98009, theta=-65.830935 -> V=1.0, theta=0.0
% INFO    : Bus 3753	: V=0.982309, theta=-65.283499 -> V=1.0, theta=0.0
% INFO    : Bus 3754	: V=0.9797672, theta=-65.87946 -> V=1.0, theta=0.0
% INFO    : Bus 3755	: V=0.9766999, theta=-66.341764 -> V=1.0, theta=0.0
% INFO    : Bus 3756	: V=0.981118, theta=-65.77024 -> V=1.0, theta=0.0
% INFO    : Bus 3757	: V=0.9790069, theta=-65.960289 -> V=1.0, theta=0.0
% INFO    : Bus 3758	: V=0.9746906, theta=-66.721862 -> V=1.0, theta=0.0
% INFO    : Bus 3759	: V=0.9787535, theta=-65.974928 -> V=1.0, theta=0.0
% INFO    : Bus 3760	: V=0.9749026, theta=-66.704858 -> V=1.0, theta=0.0
% INFO    : Bus 3761	: V=0.9788035, theta=-65.965319 -> V=1.0, theta=0.0
% INFO    : Bus 3762	: V=0.98213, theta=-65.319495 -> V=1.0, theta=0.0
% INFO    : Bus 3763	: V=0.9848584, theta=-64.93746 -> V=1.0, theta=0.0
% INFO    : Bus 3764	: V=0.9745736, theta=-66.761898 -> V=1.0, theta=0.0
% INFO    : Bus 3765	: V=0.9806785, theta=-65.924541 -> V=1.0, theta=0.0
% INFO    : Bus 3766	: V=0.9764752, theta=-66.347907 -> V=1.0, theta=0.0
% INFO    : Bus 3767	: V=0.9805705, theta=-65.927211 -> V=1.0, theta=0.0
% INFO    : Bus 3768	: V=0.9778978, theta=-66.217012 -> V=1.0, theta=0.0
% INFO    : Bus 3769	: V=0.9849956, theta=-64.922927 -> V=1.0, theta=0.0
% INFO    : Bus 3770	: V=0.9851319, theta=-64.907309 -> V=1.0, theta=0.0
% INFO    : Bus 3771	: V=0.97421, theta=-66.775662 -> V=1.0, theta=0.0
% INFO    : Bus 3772	: V=0.9763909, theta=-66.464331 -> V=1.0, theta=0.0
% INFO    : Bus 3773	: V=0.9744408, theta=-66.765536 -> V=1.0, theta=0.0
% INFO    : Bus 3774	: V=0.9760825, theta=-66.485212 -> V=1.0, theta=0.0
% INFO    : Bus 3775	: V=0.9764805, theta=-66.443812 -> V=1.0, theta=0.0
% INFO    : Bus 3776	: V=0.9755385, theta=-66.501324 -> V=1.0, theta=0.0
% INFO    : Bus 3777	: V=0.9780365, theta=-66.196352 -> V=1.0, theta=0.0
% INFO    : Bus 3778	: V=0.9854634, theta=-64.874746 -> V=1.0, theta=0.0
% INFO    : Bus 3779	: V=0.9782173, theta=-66.202898 -> V=1.0, theta=0.0
% INFO    : Bus 3780	: V=0.9750731, theta=-66.533712 -> V=1.0, theta=0.0
% INFO    : Bus 3781	: V=0.9754138, theta=-66.504352 -> V=1.0, theta=0.0
% INFO    : Bus 3782	: V=0.9758395, theta=-66.590193 -> V=1.0, theta=0.0
% INFO    : Bus 3783	: V=0.9753188, theta=-66.60325 -> V=1.0, theta=0.0
% INFO    : Bus 3784	: V=0.9789093, theta=-65.975794 -> V=1.0, theta=0.0
% INFO    : Bus 3785	: V=0.9752966, theta=-66.645068 -> V=1.0, theta=0.0
% INFO    : Bus 3786	: V=0.9749651, theta=-66.653929 -> V=1.0, theta=0.0
% INFO    : Bus 3787	: V=0.9750454, theta=-66.651908 -> V=1.0, theta=0.0
% INFO    : Bus 3788	: V=0.9749438, theta=-66.662128 -> V=1.0, theta=0.0
% INFO    : Bus 3789	: V=0.9748748, theta=-66.656354 -> V=1.0, theta=0.0
% INFO    : Bus 3790	: V=0.9750098, theta=-66.652847 -> V=1.0, theta=0.0
% INFO    : Bus 3791	: V=0.9758704, theta=-66.490514 -> V=1.0, theta=0.0
% INFO    : Bus 3792	: V=0.9776818, theta=-66.255866 -> V=1.0, theta=0.0
% INFO    : Bus 3793	: V=0.9790588, theta=-66.081692 -> V=1.0, theta=0.0
% INFO    : Bus 3794	: V=0.9798784, theta=-65.802918 -> V=1.0, theta=0.0
% INFO    : Bus 3795	: V=0.9794592, theta=-66.070817 -> V=1.0, theta=0.0
% INFO    : Bus 3796	: V=0.9785559, theta=-66.16137 -> V=1.0, theta=0.0
% INFO    : Bus 3797	: V=0.9794285, theta=-65.883235 -> V=1.0, theta=0.0
% INFO    : Bus 3798	: V=0.9785929, theta=-65.979311 -> V=1.0, theta=0.0
% INFO    : Bus 3799	: V=0.9793078, theta=-65.894129 -> V=1.0, theta=0.0
% INFO    : Bus 3800	: V=0.9801936, theta=-65.745915 -> V=1.0, theta=0.0
% INFO    : Bus 3801	: V=0.9799222, theta=-65.536526 -> V=1.0, theta=0.0
% INFO    : Bus 3802	: V=0.9768071, theta=-66.293623 -> V=1.0, theta=0.0
% INFO    : Bus 3803	: V=0.9766221, theta=-66.299513 -> V=1.0, theta=0.0
% INFO    : Bus 3804	: V=0.977122, theta=-66.285304 -> V=1.0, theta=0.0
% INFO    : Bus 3805	: V=0.9775319, theta=-66.250233 -> V=1.0, theta=0.0
% INFO    : Bus 3806	: V=0.9805716, theta=-65.678846 -> V=1.0, theta=0.0
% INFO    : Bus 3807	: V=0.9772404, theta=-66.25818 -> V=1.0, theta=0.0
% INFO    : Bus 3808	: V=0.9758624, theta=-66.398758 -> V=1.0, theta=0.0
% INFO    : Bus 3809	: V=0.9743507, theta=-66.72866 -> V=1.0, theta=0.0
% INFO    : Bus 3810	: V=0.9781264, theta=-66.172176 -> V=1.0, theta=0.0
% INFO    : Bus 3811	: V=0.9763293, theta=-66.447981 -> V=1.0, theta=0.0
% INFO    : Bus 3812	: V=0.9779268, theta=-66.177636 -> V=1.0, theta=0.0
% INFO    : Bus 3813	: V=0.9754468, theta=-66.43416 -> V=1.0, theta=0.0
% INFO    : Bus 3814	: V=0.9779522, theta=-66.194134 -> V=1.0, theta=0.0
% INFO    : Bus 3815	: V=0.9780483, theta=-66.191502 -> V=1.0, theta=0.0
% INFO    : Bus 3816	: V=0.9802609, theta=-65.4943 -> V=1.0, theta=0.0
% INFO    : Bus 3817	: V=0.9783578, theta=-66.180462 -> V=1.0, theta=0.0
% INFO    : Bus 3818	: V=0.9801737, theta=-65.502883 -> V=1.0, theta=0.0
% INFO    : Bus 3819	: V=0.9765762, theta=-66.300662 -> V=1.0, theta=0.0
% INFO    : Bus 3820	: V=0.9785758, theta=-65.980187 -> V=1.0, theta=0.0
% INFO    : Bus 3821	: V=0.9785658, theta=-65.970012 -> V=1.0, theta=0.0
% INFO    : Bus 3822	: V=0.9786481, theta=-65.940374 -> V=1.0, theta=0.0
% INFO    : Bus 3823	: V=0.9775021, theta=-66.293607 -> V=1.0, theta=0.0
% INFO    : Bus 3824	: V=0.977875, theta=-66.284597 -> V=1.0, theta=0.0
% INFO    : Bus 3825	: V=0.9792793, theta=-65.964091 -> V=1.0, theta=0.0
% INFO    : Bus 3826	: V=0.9780865, theta=-66.264597 -> V=1.0, theta=0.0
% INFO    : Bus 3827	: V=0.9849801, theta=-64.86881 -> V=1.0, theta=0.0
% INFO    : Bus 3828	: V=0.9855269, theta=-64.792759 -> V=1.0, theta=0.0
% INFO    : Bus 3829	: V=0.9800895, theta=-65.840776 -> V=1.0, theta=0.0
% INFO    : Bus 3830	: V=0.981611, theta=-65.505918 -> V=1.0, theta=0.0
% INFO    : Bus 3831	: V=0.979409, theta=-65.891699 -> V=1.0, theta=0.0
% INFO    : Bus 3832	: V=0.9803002, theta=-65.87106 -> V=1.0, theta=0.0
% INFO    : Bus 3833	: V=0.9802799, theta=-65.868836 -> V=1.0, theta=0.0
% INFO    : Bus 3834	: V=0.9782692, theta=-66.192967 -> V=1.0, theta=0.0
% INFO    : Bus 3835	: V=0.9800571, theta=-65.849004 -> V=1.0, theta=0.0
% INFO    : Bus 3836	: V=0.9796095, theta=-65.928891 -> V=1.0, theta=0.0
% INFO    : Bus 3837	: V=0.9804633, theta=-65.851976 -> V=1.0, theta=0.0
% INFO    : Bus 3838	: V=0.9838044, theta=-65.118575 -> V=1.0, theta=0.0
% INFO    : Bus 3839	: V=0.9809794, theta=-65.798991 -> V=1.0, theta=0.0
% INFO    : Bus 3840	: V=0.9778007, theta=-66.229908 -> V=1.0, theta=0.0
% INFO    : Bus 3841	: V=0.9779192, theta=-66.227431 -> V=1.0, theta=0.0
% INFO    : Bus 3842	: V=0.983831, theta=-65.036301 -> V=1.0, theta=0.0
% INFO    : Bus 3843	: V=0.9738578, theta=-66.956149 -> V=1.0, theta=0.0
% INFO    : Bus 3844	: V=0.9777451, theta=-66.231658 -> V=1.0, theta=0.0
% INFO    : Bus 3845	: V=0.9784329, theta=-66.055276 -> V=1.0, theta=0.0
% INFO    : Bus 3846	: V=0.9822684, theta=-65.290502 -> V=1.0, theta=0.0
% INFO    : Bus 3847	: V=0.9821709, theta=-65.304139 -> V=1.0, theta=0.0
% INFO    : Bus 3848	: V=0.9808082, theta=-65.814561 -> V=1.0, theta=0.0
% INFO    : Bus 3849	: V=0.9820848, theta=-65.319479 -> V=1.0, theta=0.0
% INFO    : Bus 3850	: V=0.9808382, theta=-65.792771 -> V=1.0, theta=0.0
% INFO    : Bus 3851	: V=0.98397, theta=-65.011048 -> V=1.0, theta=0.0
% INFO    : Bus 3852	: V=0.973696, theta=-66.96997 -> V=1.0, theta=0.0
% INFO    : Bus 3853	: V=0.9735529, theta=-66.975226 -> V=1.0, theta=0.0
% INFO    : Bus 3854	: V=0.9821578, theta=-65.299738 -> V=1.0, theta=0.0
% INFO    : Bus 3855	: V=0.9804396, theta=-65.662831 -> V=1.0, theta=0.0
% INFO    : Bus 3856	: V=0.974019, theta=-66.924759 -> V=1.0, theta=0.0
% INFO    : Bus 3857	: V=0.9821416, theta=-65.299425 -> V=1.0, theta=0.0
% INFO    : Bus 3858	: V=0.9841589, theta=-64.98095 -> V=1.0, theta=0.0
% INFO    : Bus 3859	: V=0.9753262, theta=-66.606063 -> V=1.0, theta=0.0
% INFO    : Bus 3860	: V=0.9792919, theta=-65.963736 -> V=1.0, theta=0.0
% INFO    : Bus 3861	: V=0.9843544, theta=-64.953701 -> V=1.0, theta=0.0
% INFO    : Bus 3862	: V=0.9820804, theta=-65.317266 -> V=1.0, theta=0.0
% INFO    : Bus 3863	: V=0.9790542, theta=-65.992674 -> V=1.0, theta=0.0
% INFO    : Bus 3864	: V=0.9767646, theta=-66.320859 -> V=1.0, theta=0.0
% INFO    : Bus 3865	: V=0.9769329, theta=-66.316318 -> V=1.0, theta=0.0
% INFO    : Bus 3866	: V=0.9789116, theta=-65.970819 -> V=1.0, theta=0.0
% INFO    : Bus 3867	: V=0.9800673, theta=-65.520266 -> V=1.0, theta=0.0
% INFO    : Bus 3868	: V=0.9739575, theta=-66.928686 -> V=1.0, theta=0.0
% INFO    : Bus 3869	: V=0.9783346, theta=-66.057951 -> V=1.0, theta=0.0
% INFO    : Bus 3870	: V=0.9801246, theta=-65.512162 -> V=1.0, theta=0.0
% INFO    : Bus 3871	: V=0.9822924, theta=-65.274259 -> V=1.0, theta=0.0
% INFO    : Bus 3872	: V=0.9802736, theta=-65.495553 -> V=1.0, theta=0.0
% INFO    : Bus 3873	: V=0.9739401, theta=-66.917334 -> V=1.0, theta=0.0
% INFO    : Bus 3874	: V=0.9785984, theta=-65.978589 -> V=1.0, theta=0.0
% INFO    : Bus 3875	: V=0.9803045, theta=-65.491248 -> V=1.0, theta=0.0
% INFO    : Bus 3876	: V=0.9781235, theta=-66.199074 -> V=1.0, theta=0.0
% INFO    : Bus 3877	: V=0.9737416, theta=-66.943646 -> V=1.0, theta=0.0
% INFO    : Bus 3878	: V=0.9804331, theta=-65.480159 -> V=1.0, theta=0.0
% INFO    : Bus 3879	: V=0.9808525, theta=-65.429954 -> V=1.0, theta=0.0
% INFO    : Bus 3880	: V=0.9807018, theta=-65.44693 -> V=1.0, theta=0.0
% INFO    : Bus 3881	: V=0.9779755, theta=-66.202999 -> V=1.0, theta=0.0
% INFO    : Bus 3882	: V=0.9784184, theta=-65.965783 -> V=1.0, theta=0.0
% INFO    : Bus 3883	: V=0.9816198, theta=-65.309243 -> V=1.0, theta=0.0
% INFO    : Bus 3884	: V=0.9787221, theta=-65.930939 -> V=1.0, theta=0.0
% INFO    : Bus 3885	: V=0.9782309, theta=-66.196126 -> V=1.0, theta=0.0
% INFO    : Bus 3886	: V=0.9815058, theta=-65.325433 -> V=1.0, theta=0.0
% INFO    : Bus 3887	: V=0.9756068, theta=-66.598376 -> V=1.0, theta=0.0
% INFO    : Bus 3888	: V=0.9810802, theta=-65.402133 -> V=1.0, theta=0.0
% INFO    : Bus 3889	: V=0.9735222, theta=-66.948253 -> V=1.0, theta=0.0
% INFO    : Bus 3890	: V=0.9827185, theta=-65.243491 -> V=1.0, theta=0.0
% INFO    : Bus 3891	: V=0.9736215, theta=-66.971125 -> V=1.0, theta=0.0
% INFO    : Bus 3892	: V=0.9734096, theta=-66.976891 -> V=1.0, theta=0.0
% INFO    : Bus 3893	: V=0.9789684, theta=-65.960133 -> V=1.0, theta=0.0
% INFO    : Bus 3894	: V=0.9845339, theta=-64.93898 -> V=1.0, theta=0.0
% INFO    : Bus 3895	: V=0.9823892, theta=-65.25679 -> V=1.0, theta=0.0
% INFO    : Bus 3896	: V=0.9840085, theta=-64.956279 -> V=1.0, theta=0.0
% INFO    : Bus 3897	: V=0.9831684, theta=-65.199097 -> V=1.0, theta=0.0
% INFO    : Bus 3898	: V=0.9816137, theta=-65.334029 -> V=1.0, theta=0.0
% INFO    : Bus 3899	: V=0.9829104, theta=-65.22281 -> V=1.0, theta=0.0
% INFO    : Bus 3900	: V=0.9814986, theta=-65.331184 -> V=1.0, theta=0.0
% INFO    : Bus 3901	: V=0.9831326, theta=-65.198622 -> V=1.0, theta=0.0
% INFO    : Bus 3902	: V=0.9815331, theta=-65.334427 -> V=1.0, theta=0.0
% INFO    : Bus 3903	: V=0.9838871, theta=-65.108096 -> V=1.0, theta=0.0
% INFO    : Bus 3904	: V=0.9841291, theta=-64.953399 -> V=1.0, theta=0.0
% INFO    : Bus 3905	: V=0.9830931, theta=-65.097394 -> V=1.0, theta=0.0
% INFO    : Bus 3906	: V=0.982858, theta=-65.134222 -> V=1.0, theta=0.0
% INFO    : Bus 3907	: V=0.9820885, theta=-65.416192 -> V=1.0, theta=0.0
% INFO    : Bus 3908	: V=0.9825497, theta=-65.179365 -> V=1.0, theta=0.0
% INFO    : Bus 3909	: V=0.9828785, theta=-65.276853 -> V=1.0, theta=0.0
% INFO    : Bus 3910	: V=0.9825142, theta=-65.339779 -> V=1.0, theta=0.0
% INFO    : Bus 3911	: V=0.9788336, theta=-65.907393 -> V=1.0, theta=0.0
% INFO    : Bus 3912	: V=0.9785019, theta=-65.980643 -> V=1.0, theta=0.0
% INFO    : Bus 3913	: V=0.9793166, theta=-65.878547 -> V=1.0, theta=0.0
% INFO    : Bus 3914	: V=0.9829556, theta=-65.098327 -> V=1.0, theta=0.0
% INFO    : Bus 3915	: V=0.9779321, theta=-66.191174 -> V=1.0, theta=0.0
% INFO    : Bus 3916	: V=0.9777267, theta=-66.196756 -> V=1.0, theta=0.0
% INFO    : Bus 3917	: V=0.9843272, theta=-65.104787 -> V=1.0, theta=0.0
% INFO    : Bus 3918	: V=0.982969, theta=-65.089891 -> V=1.0, theta=0.0
% INFO    : Bus 3919	: V=0.9828006, theta=-65.097227 -> V=1.0, theta=0.0
% INFO    : Bus 3920	: V=0.9827169, theta=-65.099709 -> V=1.0, theta=0.0
% INFO    : Bus 3921	: V=0.9830026, theta=-65.082856 -> V=1.0, theta=0.0
% INFO    : Bus 3922	: V=0.984162, theta=-65.068811 -> V=1.0, theta=0.0
% INFO    : Bus 3923	: V=0.9846217, theta=-64.871358 -> V=1.0, theta=0.0
% INFO    : Bus 3924	: V=0.9839972, theta=-65.092128 -> V=1.0, theta=0.0
% INFO    : Bus 3925	: V=0.9784708, theta=-65.98167 -> V=1.0, theta=0.0
% INFO    : Bus 3926	: V=0.9832129, theta=-65.198681 -> V=1.0, theta=0.0
% INFO    : Bus 3927	: V=0.9832967, theta=-65.05162 -> V=1.0, theta=0.0
% INFO    : Bus 3928	: V=0.9767012, theta=-66.377616 -> V=1.0, theta=0.0
% INFO    : Bus 3929	: V=0.9838108, theta=-64.989288 -> V=1.0, theta=0.0
% INFO    : Bus 3930	: V=0.9843737, theta=-64.909394 -> V=1.0, theta=0.0
% INFO    : Bus 3931	: V=0.9832793, theta=-65.196298 -> V=1.0, theta=0.0
% INFO    : Bus 3932	: V=0.9842716, theta=-64.92529 -> V=1.0, theta=0.0
% INFO    : Bus 3933	: V=0.9835423, theta=-65.199359 -> V=1.0, theta=0.0
% INFO    : Bus 3934	: V=0.9840234, theta=-64.959504 -> V=1.0, theta=0.0
% INFO    : Bus 3935	: V=0.9845503, theta=-65.032725 -> V=1.0, theta=0.0
% INFO    : Bus 3936	: V=0.9805091, theta=-65.75202 -> V=1.0, theta=0.0
% INFO    : Bus 3937	: V=0.9851517, theta=-64.768048 -> V=1.0, theta=0.0
% INFO    : Bus 3938	: V=0.9812852, theta=-65.559559 -> V=1.0, theta=0.0
% INFO    : Bus 3939	: V=0.9835406, theta=-65.140863 -> V=1.0, theta=0.0
% INFO    : Bus 3940	: V=0.9833529, theta=-65.157839 -> V=1.0, theta=0.0
% INFO    : Bus 3941	: V=0.9831662, theta=-65.174611 -> V=1.0, theta=0.0
% INFO    : Bus 3942	: V=0.9830136, theta=-65.187583 -> V=1.0, theta=0.0
% INFO    : Bus 3943	: V=0.9865397, theta=-64.525986 -> V=1.0, theta=0.0
% INFO    : Bus 3944	: V=0.9859405, theta=-64.621203 -> V=1.0, theta=0.0
% INFO    : Bus 3945	: V=0.98256, theta=-65.227995 -> V=1.0, theta=0.0
% INFO    : Bus 3946	: V=0.9827955, theta=-65.206993 -> V=1.0, theta=0.0
% INFO    : Bus 3947	: V=0.9774627, theta=-66.26971 -> V=1.0, theta=0.0
% INFO    : Bus 3948	: V=0.9821352, theta=-65.262002 -> V=1.0, theta=0.0
% INFO    : Bus 3949	: V=0.9772481, theta=-66.295811 -> V=1.0, theta=0.0
% INFO    : Bus 3950	: V=0.9821459, theta=-65.25047 -> V=1.0, theta=0.0
% INFO    : Bus 3951	: V=0.9815504, theta=-65.317334 -> V=1.0, theta=0.0
% INFO    : Bus 3952	: V=0.9815813, theta=-65.453018 -> V=1.0, theta=0.0
% INFO    : Bus 3953	: V=0.9821999, theta=-65.225867 -> V=1.0, theta=0.0
% INFO    : Bus 3954	: V=0.9860733, theta=-64.601532 -> V=1.0, theta=0.0
% INFO    : Bus 3955	: V=0.9822416, theta=-65.213997 -> V=1.0, theta=0.0
% INFO    : Bus 3956	: V=0.9792162, theta=-65.902372 -> V=1.0, theta=0.0
% INFO    : Bus 3957	: V=0.9793361, theta=-65.899161 -> V=1.0, theta=0.0
% INFO    : Bus 3958	: V=0.9864363, theta=-64.545342 -> V=1.0, theta=0.0
% INFO    : Bus 3959	: V=0.9829526, theta=-65.176424 -> V=1.0, theta=0.0
% INFO    : Bus 3960	: V=0.9857968, theta=-64.650485 -> V=1.0, theta=0.0
% INFO    : Bus 3961	: V=0.9831479, theta=-65.148851 -> V=1.0, theta=0.0
% INFO    : Bus 3962	: V=0.9809292, theta=-65.578246 -> V=1.0, theta=0.0
% INFO    : Bus 3963	: V=0.9851736, theta=-64.769347 -> V=1.0, theta=0.0
% INFO    : Bus 3964	: V=0.9810944, theta=-65.564778 -> V=1.0, theta=0.0
% INFO    : Bus 3965	: V=0.983859, theta=-65.056753 -> V=1.0, theta=0.0
% INFO    : Bus 3966	: V=0.9752835, theta=-66.437579 -> V=1.0, theta=0.0
% INFO    : Bus 3967	: V=0.9815125, theta=-65.549962 -> V=1.0, theta=0.0
% INFO    : Bus 3968	: V=0.9759005, theta=-66.404405 -> V=1.0, theta=0.0
% INFO    : Bus 3969	: V=0.9757596, theta=-66.413359 -> V=1.0, theta=0.0
% INFO    : Bus 3970	: V=0.9808458, theta=-65.585874 -> V=1.0, theta=0.0
% INFO    : Bus 3971	: V=0.9756792, theta=-66.416328 -> V=1.0, theta=0.0
% INFO    : Bus 3972	: V=0.9756645, theta=-66.414503 -> V=1.0, theta=0.0
% INFO    : Bus 3973	: V=0.9756889, theta=-66.411635 -> V=1.0, theta=0.0
% INFO    : Bus 3974	: V=0.9827005, theta=-65.144638 -> V=1.0, theta=0.0
% INFO    : Bus 3975	: V=0.9773132, theta=-66.178445 -> V=1.0, theta=0.0
% INFO    : Bus 3976	: V=0.9772083, theta=-66.180619 -> V=1.0, theta=0.0
% INFO    : Bus 3977	: V=0.9825306, theta=-65.163955 -> V=1.0, theta=0.0
% INFO    : Bus 3978	: V=0.9758824, theta=-66.402384 -> V=1.0, theta=0.0
% INFO    : Bus 3979	: V=0.9823454, theta=-65.182854 -> V=1.0, theta=0.0
% INFO    : Bus 3980	: V=0.9760032, theta=-66.388558 -> V=1.0, theta=0.0
% INFO    : Bus 3981	: V=0.9822262, theta=-65.194327 -> V=1.0, theta=0.0
% INFO    : Bus 3982	: V=0.9758341, theta=-66.392665 -> V=1.0, theta=0.0
% INFO    : Bus 3983	: V=0.9792732, theta=-65.798427 -> V=1.0, theta=0.0
% INFO    : Bus 3984	: V=0.9823439, theta=-65.168289 -> V=1.0, theta=0.0
% INFO    : Bus 3985	: V=0.9770706, theta=-66.175475 -> V=1.0, theta=0.0
% INFO    : Bus 3986	: V=0.9824614, theta=-65.158985 -> V=1.0, theta=0.0
% INFO    : Bus 3987	: V=0.9772035, theta=-66.169164 -> V=1.0, theta=0.0
% INFO    : Bus 3988	: V=0.9828328, theta=-65.130021 -> V=1.0, theta=0.0
% INFO    : Bus 3989	: V=0.9785668, theta=-65.935182 -> V=1.0, theta=0.0
% INFO    : Bus 3990	: V=0.976606, theta=-66.27704 -> V=1.0, theta=0.0
% INFO    : Bus 3991	: V=0.9812633, theta=-65.344483 -> V=1.0, theta=0.0
% INFO    : Bus 3992	: V=0.9831781, theta=-65.092135 -> V=1.0, theta=0.0
% INFO    : Bus 3993	: V=0.9812287, theta=-65.345289 -> V=1.0, theta=0.0
% INFO    : Bus 3994	: V=0.9817496, theta=-65.346538 -> V=1.0, theta=0.0
% INFO    : Bus 3995	: V=0.9811644, theta=-65.357117 -> V=1.0, theta=0.0
% INFO    : Bus 3996	: V=0.9824838, theta=-65.147906 -> V=1.0, theta=0.0
% INFO    : Bus 3997	: V=0.9808178, theta=-65.407442 -> V=1.0, theta=0.0
% INFO    : Bus 3998	: V=0.9824383, theta=-65.148814 -> V=1.0, theta=0.0
% INFO    : Bus 3999	: V=0.9809574, theta=-65.385707 -> V=1.0, theta=0.0
% INFO    : Bus 4000	: V=0.9825284, theta=-65.130158 -> V=1.0, theta=0.0
% INFO    : Bus 4001	: V=0.9804989, theta=-65.462824 -> V=1.0, theta=0.0
% INFO    : Bus 4002	: V=0.9825278, theta=-65.13441 -> V=1.0, theta=0.0
% INFO    : Bus 4003	: V=0.9813383, theta=-65.325602 -> V=1.0, theta=0.0
% INFO    : Bus 4004	: V=0.9808322, theta=-65.581668 -> V=1.0, theta=0.0
% INFO    : Bus 4005	: V=0.9820183, theta=-65.256986 -> V=1.0, theta=0.0
% INFO    : Bus 4006	: V=0.9818188, theta=-65.282474 -> V=1.0, theta=0.0
% INFO    : Bus 4007	: V=0.9823201, theta=-65.212949 -> V=1.0, theta=0.0
% INFO    : Bus 4008	: V=0.9765247, theta=-66.327047 -> V=1.0, theta=0.0
% INFO    : Bus 4009	: V=0.9743483, theta=-66.725956 -> V=1.0, theta=0.0
% INFO    : Bus 4010	: V=0.9741818, theta=-66.730484 -> V=1.0, theta=0.0
% INFO    : Bus 4011	: V=0.9809332, theta=-65.5748 -> V=1.0, theta=0.0
% INFO    : Bus 4012	: V=0.9766114, theta=-66.324776 -> V=1.0, theta=0.0
% INFO    : Bus 4013	: V=0.9817601, theta=-65.277598 -> V=1.0, theta=0.0
% INFO    : Bus 4014	: V=0.9825984, theta=-65.117252 -> V=1.0, theta=0.0
% INFO    : Bus 4015	: V=0.9815933, theta=-65.28492 -> V=1.0, theta=0.0
% INFO    : Bus 4016	: V=0.9816097, theta=-65.287726 -> V=1.0, theta=0.0
% INFO    : Bus 4017	: V=0.9826412, theta=-65.108746 -> V=1.0, theta=0.0
% INFO    : Bus 4018	: V=0.9826196, theta=-65.108245 -> V=1.0, theta=0.0
% INFO    : Bus 4019	: V=0.9759047, theta=-66.456673 -> V=1.0, theta=0.0
% INFO    : Bus 4020	: V=0.9815873, theta=-65.279832 -> V=1.0, theta=0.0
% INFO    : Bus 4021	: V=0.983261, theta=-65.000488 -> V=1.0, theta=0.0
% INFO    : Bus 4022	: V=0.9816731, theta=-65.280444 -> V=1.0, theta=0.0
% INFO    : Bus 4023	: V=0.9782441, theta=-65.979979 -> V=1.0, theta=0.0
% INFO    : Bus 4024	: V=0.9816941, theta=-65.266768 -> V=1.0, theta=0.0
% INFO    : Bus 4025	: V=0.9827701, theta=-65.084938 -> V=1.0, theta=0.0
% INFO    : Bus 4026	: V=0.9826777, theta=-65.096769 -> V=1.0, theta=0.0
% INFO    : Bus 4027	: V=0.9826814, theta=-65.099912 -> V=1.0, theta=0.0
% INFO    : Bus 4028	: V=0.9818864, theta=-65.236415 -> V=1.0, theta=0.0
% INFO    : Bus 4029	: V=0.9807635, theta=-65.470437 -> V=1.0, theta=0.0
% INFO    : Bus 4030	: V=0.9818021, theta=-65.266443 -> V=1.0, theta=0.0
% INFO    : Bus 4031	: V=0.9836979, theta=-64.964736 -> V=1.0, theta=0.0
% INFO    : Bus 4032	: V=0.9811317, theta=-65.456875 -> V=1.0, theta=0.0
% INFO    : Bus 4033	: V=0.979535, theta=-65.722782 -> V=1.0, theta=0.0
% INFO    : Bus 4034	: V=0.9820473, theta=-65.212616 -> V=1.0, theta=0.0
% INFO    : Bus 4035	: V=0.9828107, theta=-65.075337 -> V=1.0, theta=0.0
% INFO    : Bus 4036	: V=0.978341, theta=-65.957555 -> V=1.0, theta=0.0
% INFO    : Bus 4037	: V=0.9830432, theta=-65.03321 -> V=1.0, theta=0.0
% INFO    : Bus 4038	: V=0.9788364, theta=-65.688966 -> V=1.0, theta=0.0
% INFO    : Bus 4039	: V=0.9829578, theta=-65.047938 -> V=1.0, theta=0.0
% INFO    : Bus 4040	: V=0.9835813, theta=-64.951721 -> V=1.0, theta=0.0
% INFO    : Bus 4041	: V=0.9812708, theta=-65.413338 -> V=1.0, theta=0.0
% INFO    : Bus 4042	: V=0.981184, theta=-65.449071 -> V=1.0, theta=0.0
% INFO    : Bus 4043	: V=0.9774219, theta=-66.002473 -> V=1.0, theta=0.0
% INFO    : Bus 4044	: V=0.977522, theta=-65.999755 -> V=1.0, theta=0.0
% INFO    : Bus 4045	: V=0.9777999, theta=-65.992125 -> V=1.0, theta=0.0
% INFO    : Bus 4046	: V=0.9778648, theta=-65.990341 -> V=1.0, theta=0.0
% INFO    : Bus 4047	: V=0.9809151, theta=-65.436394 -> V=1.0, theta=0.0
% INFO    : Bus 4048	: V=0.9834385, theta=-65.029202 -> V=1.0, theta=0.0
% INFO    : Bus 4049	: V=0.980895, theta=-65.565551 -> V=1.0, theta=0.0
% INFO    : Bus 4050	: V=0.9972789, theta=-62.488918 -> V=1.0, theta=0.0
% INFO    : Bus 4051	: V=0.9903966, theta=-63.674759 -> V=1.0, theta=0.0
% INFO    : Bus 4052	: V=0.9804861, theta=-65.490491 -> V=1.0, theta=0.0
% INFO    : Bus 4053	: V=0.9805511, theta=-65.445391 -> V=1.0, theta=0.0
% INFO    : Bus 4054	: V=0.956225, theta=-75.707478 -> V=1.0, theta=0.0
% INFO    : Bus 4055	: V=0.9574197, theta=-75.548087 -> V=1.0, theta=0.0
% INFO    : Bus 4056	: V=0.9571399, theta=-75.61415 -> V=1.0, theta=0.0
% INFO    : Bus 4057	: V=0.9549126, theta=-75.493849 -> V=1.0, theta=0.0
% INFO    : Bus 4058	: V=0.9530631, theta=-74.375976 -> V=1.0, theta=0.0
% INFO    : Bus 4059	: V=0.9557908, theta=-75.35033 -> V=1.0, theta=0.0
% INFO    : Bus 4060	: V=0.9523862, theta=-74.295257 -> V=1.0, theta=0.0
% INFO    : Bus 4061	: V=0.9539821, theta=-75.600438 -> V=1.0, theta=0.0
% INFO    : Bus 4062	: V=0.9557111, theta=-75.488134 -> V=1.0, theta=0.0
% INFO    : Bus 4063	: V=0.9553578, theta=-75.531118 -> V=1.0, theta=0.0
% INFO    : Bus 4064	: V=0.9574368, theta=-75.543029 -> V=1.0, theta=0.0
% INFO    : Bus 4065	: V=0.9549353, theta=-75.699446 -> V=1.0, theta=0.0
% INFO    : Bus 4066	: V=0.9545519, theta=-75.822336 -> V=1.0, theta=0.0
% INFO    : Bus 4067	: V=0.9535988, theta=-75.937159 -> V=1.0, theta=0.0
% INFO    : Bus 4068	: V=0.9529812, theta=-75.961455 -> V=1.0, theta=0.0
% INFO    : Bus 4069	: V=0.9543775, theta=-75.585016 -> V=1.0, theta=0.0
% INFO    : Bus 4070	: V=0.9441096, theta=-74.279184 -> V=1.0, theta=0.0
% INFO    : Bus 4071	: V=0.9597213, theta=-71.779461 -> V=1.0, theta=0.0
% INFO    : Bus 4072	: V=0.9574946, theta=-72.605876 -> V=1.0, theta=0.0
% INFO    : Bus 4073	: V=0.9562247, theta=-72.268039 -> V=1.0, theta=0.0
% INFO    : Bus 4074	: V=0.9574514, theta=-72.626302 -> V=1.0, theta=0.0
% INFO    : Bus 4075	: V=0.9556513, theta=-73.251949 -> V=1.0, theta=0.0
% INFO    : Bus 4076	: V=0.9545333, theta=-73.575978 -> V=1.0, theta=0.0
% INFO    : Bus 4077	: V=0.9530833, theta=-73.411089 -> V=1.0, theta=0.0
% INFO    : Bus 4078	: V=0.9538578, theta=-73.775995 -> V=1.0, theta=0.0
% INFO    : Bus 4079	: V=0.9517743, theta=-72.069038 -> V=1.0, theta=0.0
% INFO    : Bus 4080	: V=0.96698, theta=-65.714204 -> V=1.0, theta=0.0
% INFO    : Bus 4081	: V=0.9797458, theta=-65.212868 -> V=1.0, theta=0.0
% INFO    : Bus 4082	: V=0.940732, theta=-78.061645 -> V=1.0, theta=0.0
% INFO    : Bus 4083	: V=0.9507219, theta=-74.455309 -> V=1.0, theta=0.0
% INFO    : Bus 4084	: V=0.9443168, theta=-78.12764 -> V=1.0, theta=0.0
% INFO    : Bus 4085	: V=0.9515797, theta=-76.034442 -> V=1.0, theta=0.0
% INFO    : Bus 4086	: V=0.9561019, theta=-75.663586 -> V=1.0, theta=0.0
% INFO    : Bus 4087	: V=0.9506538, theta=-76.183138 -> V=1.0, theta=0.0
% INFO    : Bus 4088	: V=0.9522841, theta=-73.593989 -> V=1.0, theta=0.0
% INFO    : Bus 4089	: V=0.9507534, theta=-76.345706 -> V=1.0, theta=0.0
% INFO    : Bus 4090	: V=0.9504998, theta=-76.356832 -> V=1.0, theta=0.0
% INFO    : Bus 4091	: V=0.9496711, theta=-76.388333 -> V=1.0, theta=0.0
% INFO    : Bus 4092	: V=0.9455716, theta=-76.361602 -> V=1.0, theta=0.0
% INFO    : Bus 4093	: V=0.9469164, theta=-76.756569 -> V=1.0, theta=0.0
% INFO    : Bus 4094	: V=0.9480376, theta=-76.702522 -> V=1.0, theta=0.0
% INFO    : Bus 4095	: V=0.9492366, theta=-76.589562 -> V=1.0, theta=0.0
% INFO    : Bus 4096	: V=0.9486952, theta=-76.618921 -> V=1.0, theta=0.0
% INFO    : Bus 4097	: V=0.9478759, theta=-76.126069 -> V=1.0, theta=0.0
% INFO    : Bus 4098	: V=0.9467826, theta=-76.307337 -> V=1.0, theta=0.0
% INFO    : Bus 4099	: V=0.9521689, theta=-76.075485 -> V=1.0, theta=0.0
% INFO    : Bus 4100	: V=0.9519238, theta=-76.05708 -> V=1.0, theta=0.0
% INFO    : Bus 4101	: V=0.951986, theta=-76.03874 -> V=1.0, theta=0.0
% INFO    : Bus 4102	: V=0.9522221, theta=-76.001959 -> V=1.0, theta=0.0
% INFO    : Bus 4103	: V=0.9514972, theta=-76.142523 -> V=1.0, theta=0.0
% INFO    : Bus 4104	: V=0.9516046, theta=-73.78087 -> V=1.0, theta=0.0
% INFO    : Bus 4105	: V=0.9532524, theta=-75.852833 -> V=1.0, theta=0.0
% INFO    : Bus 4106	: V=0.9505437, theta=-73.979026 -> V=1.0, theta=0.0
% INFO    : Bus 4107	: V=0.9450945, theta=-76.378597 -> V=1.0, theta=0.0
% INFO    : Bus 4108	: V=0.9490731, theta=-75.844007 -> V=1.0, theta=0.0
% INFO    : Bus 4109	: V=0.9849054, theta=-71.428535 -> V=1.0, theta=0.0
% INFO    : Bus 4110	: V=0.9636844, theta=-75.028336 -> V=1.0, theta=0.0
% INFO    : Bus 4111	: V=1.00852, theta=-68.787197 -> V=1.0, theta=0.0
% INFO    : Bus 4112	: V=0.9835931, theta=-71.783487 -> V=1.0, theta=0.0
% INFO    : Bus 4113	: V=0.9571005, theta=-74.372477 -> V=1.0, theta=0.0
% INFO    : Bus 4114	: V=0.9770802, theta=-70.471807 -> V=1.0, theta=0.0
% INFO    : Bus 4115	: V=0.9663939, theta=-70.865426 -> V=1.0, theta=0.0
% INFO    : Bus 4116	: V=0.9610039, theta=-75.093069 -> V=1.0, theta=0.0
% INFO    : Bus 4117	: V=0.9628397, theta=-74.946393 -> V=1.0, theta=0.0
% INFO    : Bus 4118	: V=0.9727749, theta=-73.910165 -> V=1.0, theta=0.0
% INFO    : Bus 4119	: V=0.9726554, theta=-75.346149 -> V=1.0, theta=0.0
% INFO    : Bus 4120	: V=0.9740563, theta=-74.783901 -> V=1.0, theta=0.0
% INFO    : Bus 4121	: V=0.9739656, theta=-75.294433 -> V=1.0, theta=0.0
% INFO    : Bus 4122	: V=0.9705324, theta=-75.213276 -> V=1.0, theta=0.0
% INFO    : Bus 4123	: V=0.9604849, theta=-73.863933 -> V=1.0, theta=0.0
% INFO    : Bus 4124	: V=0.9749142, theta=-75.33473 -> V=1.0, theta=0.0
% INFO    : Bus 4125	: V=0.9833114, theta=-74.688258 -> V=1.0, theta=0.0
% INFO    : Bus 4126	: V=0.9897248, theta=-74.192407 -> V=1.0, theta=0.0
% INFO    : Bus 4127	: V=0.9746008, theta=-75.325953 -> V=1.0, theta=0.0
% INFO    : Bus 4128	: V=0.9719827, theta=-74.66491 -> V=1.0, theta=0.0
% INFO    : Bus 4129	: V=0.9966413, theta=-57.710497 -> V=1.0, theta=0.0
% INFO    : Bus 4130	: V=0.9872027, theta=-58.649737 -> V=1.0, theta=0.0
% INFO    : Bus 4131	: V=0.978898, theta=-60.544606 -> V=1.0, theta=0.0
% INFO    : Bus 4132	: V=0.9737823, theta=-61.736047 -> V=1.0, theta=0.0
% INFO    : Bus 4133	: V=0.9704005, theta=-62.908429 -> V=1.0, theta=0.0
% INFO    : Bus 4134	: V=0.9691003, theta=-62.783011 -> V=1.0, theta=0.0
% INFO    : Bus 4135	: V=0.9686871, theta=-64.767945 -> V=1.0, theta=0.0
% INFO    : Bus 4136	: V=0.9726437, theta=-66.125776 -> V=1.0, theta=0.0
% INFO    : Bus 4137	: V=0.9750705, theta=-67.66013 -> V=1.0, theta=0.0
% INFO    : Bus 4138	: V=0.9938866, theta=-68.336686 -> V=1.0, theta=0.0
% INFO    : Bus 4139	: V=0.981014, theta=-66.529381 -> V=1.0, theta=0.0
% INFO    : Bus 4140	: V=0.9686184, theta=-65.733945 -> V=1.0, theta=0.0
% INFO    : Bus 4141	: V=0.9671033, theta=-63.407589 -> V=1.0, theta=0.0
% INFO    : Bus 4142	: V=0.9647956, theta=-64.033646 -> V=1.0, theta=0.0
% INFO    : Bus 4143	: V=0.9640605, theta=-64.05445 -> V=1.0, theta=0.0
% INFO    : Bus 4144	: V=0.9638584, theta=-64.059923 -> V=1.0, theta=0.0
% INFO    : Bus 4145	: V=0.9698963, theta=-65.158934 -> V=1.0, theta=0.0
% INFO    : Bus 4146	: V=0.9720153, theta=-65.285018 -> V=1.0, theta=0.0
% INFO    : Bus 4147	: V=0.9667073, theta=-63.528971 -> V=1.0, theta=0.0
% INFO    : Bus 4148	: V=0.9673227, theta=-71.210947 -> V=1.0, theta=0.0
% INFO    : Bus 4149	: V=0.9666887, theta=-71.220472 -> V=1.0, theta=0.0
% INFO    : Bus 4150	: V=0.9810126, theta=-70.189355 -> V=1.0, theta=0.0
% INFO    : Bus 4151	: V=0.9818992, theta=-70.128913 -> V=1.0, theta=0.0
% INFO    : Bus 4152	: V=0.9807331, theta=-70.267585 -> V=1.0, theta=0.0
% INFO    : Bus 4153	: V=0.9735204, theta=-70.817116 -> V=1.0, theta=0.0
% INFO    : Bus 4154	: V=0.9756513, theta=-70.577793 -> V=1.0, theta=0.0
% INFO    : Bus 4155	: V=0.9818964, theta=-70.131724 -> V=1.0, theta=0.0
% INFO    : Bus 4156	: V=1.0061585, theta=-68.031412 -> V=1.0, theta=0.0
% INFO    : Bus 4157	: V=1.007718, theta=-66.024692 -> V=1.0, theta=0.0
% INFO    : Bus 4158	: V=1.0122631, theta=-65.975058 -> V=1.0, theta=0.0
% INFO    : Bus 4159	: V=1.0130804, theta=-65.966794 -> V=1.0, theta=0.0
% INFO    : Bus 4160	: V=1.0192331, theta=-65.401192 -> V=1.0, theta=0.0
% INFO    : Bus 4161	: V=0.9986892, theta=-67.714706 -> V=1.0, theta=0.0
% INFO    : Bus 4162	: V=0.9963537, theta=-67.822562 -> V=1.0, theta=0.0
% INFO    : Bus 4163	: V=0.9965779, theta=-67.839375 -> V=1.0, theta=0.0
% INFO    : Bus 4164	: V=0.9971713, theta=-67.780329 -> V=1.0, theta=0.0
% INFO    : Bus 4165	: V=1.0040759, theta=-66.771348 -> V=1.0, theta=0.0
% INFO    : Bus 4166	: V=0.9861158, theta=-67.92806 -> V=1.0, theta=0.0
% INFO    : Bus 4167	: V=0.9948084, theta=-67.573199 -> V=1.0, theta=0.0
% INFO    : Bus 4168	: V=0.9584886, theta=-71.305429 -> V=1.0, theta=0.0
% INFO    : Bus 4169	: V=0.97695, theta=-70.178118 -> V=1.0, theta=0.0
% INFO    : Bus 4170	: V=0.9641239, theta=-71.114084 -> V=1.0, theta=0.0
% INFO    : Bus 4171	: V=0.9567973, theta=-71.336127 -> V=1.0, theta=0.0
% INFO    : Bus 4172	: V=0.9893588, theta=-67.998763 -> V=1.0, theta=0.0
% INFO    : Bus 4173	: V=0.9771453, theta=-69.954321 -> V=1.0, theta=0.0
% INFO    : Bus 4174	: V=0.9694804, theta=-70.494442 -> V=1.0, theta=0.0
% INFO    : Bus 4175	: V=0.9739425, theta=-70.408746 -> V=1.0, theta=0.0
% INFO    : Bus 4176	: V=0.9766138, theta=-70.452954 -> V=1.0, theta=0.0
% INFO    : Bus 4177	: V=0.976126, theta=-70.332845 -> V=1.0, theta=0.0
% INFO    : Bus 4178	: V=0.9794171, theta=-70.25488 -> V=1.0, theta=0.0
% INFO    : Bus 4179	: V=0.9835809, theta=-68.688057 -> V=1.0, theta=0.0
% INFO    : Bus 4180	: V=0.9624865, theta=-72.481829 -> V=1.0, theta=0.0
% INFO    : Bus 4181	: V=0.9562308, theta=-72.43604 -> V=1.0, theta=0.0
% INFO    : Bus 4182	: V=1.0095543, theta=-67.318578 -> V=1.0, theta=0.0
% INFO    : Bus 4183	: V=0.9619766, theta=-74.377258 -> V=1.0, theta=0.0
% INFO    : Bus 4184	: V=0.9554563, theta=-75.975464 -> V=1.0, theta=0.0
% INFO    : Bus 4185	: V=0.9559225, theta=-75.966863 -> V=1.0, theta=0.0
% INFO    : Bus 4186	: V=0.9561572, theta=-75.960014 -> V=1.0, theta=0.0
% INFO    : Bus 4187	: V=0.9565917, theta=-75.896848 -> V=1.0, theta=0.0
% INFO    : Bus 4188	: V=0.9623715, theta=-74.324386 -> V=1.0, theta=0.0
% INFO    : Bus 4189	: V=0.9556415, theta=-75.96602 -> V=1.0, theta=0.0
% INFO    : Bus 4190	: V=0.9547666, theta=-75.991292 -> V=1.0, theta=0.0
% INFO    : Bus 4191	: V=0.9559601, theta=-75.885945 -> V=1.0, theta=0.0
% INFO    : Bus 4192	: V=0.9555909, theta=-75.896544 -> V=1.0, theta=0.0
% INFO    : Bus 4193	: V=0.9621424, theta=-73.519595 -> V=1.0, theta=0.0
% INFO    : Bus 4194	: V=0.9715716, theta=-73.086675 -> V=1.0, theta=0.0
% INFO    : Bus 4195	: V=0.9529542, theta=-76.254587 -> V=1.0, theta=0.0
% INFO    : Bus 4196	: V=0.9656733, theta=-73.82588 -> V=1.0, theta=0.0
% INFO    : Bus 4197	: V=0.9648072, theta=-73.937857 -> V=1.0, theta=0.0
% INFO    : Bus 4198	: V=0.9633168, theta=-74.178031 -> V=1.0, theta=0.0
% INFO    : Bus 4199	: V=0.957367, theta=-75.145721 -> V=1.0, theta=0.0
% INFO    : Bus 4200	: V=0.9565456, theta=-75.972769 -> V=1.0, theta=0.0
% INFO    : Bus 4201	: V=0.9552718, theta=-75.985493 -> V=1.0, theta=0.0
% INFO    : Bus 4202	: V=0.9508441, theta=-77.837331 -> V=1.0, theta=0.0
% INFO    : Bus 4203	: V=0.9540562, theta=-76.167474 -> V=1.0, theta=0.0
% INFO    : Bus 4204	: V=0.952123, theta=-76.354381 -> V=1.0, theta=0.0
% INFO    : Bus 4205	: V=0.9782222, theta=-62.958748 -> V=1.0, theta=0.0
% INFO    : Bus 4206	: V=0.9844097, theta=-62.721778 -> V=1.0, theta=0.0
% INFO    : Bus 4207	: V=0.9966058, theta=-60.718177 -> V=1.0, theta=0.0
% INFO    : Bus 4208	: V=0.9823894, theta=-63.765329 -> V=1.0, theta=0.0
% INFO    : Bus 4209	: V=0.9767822, theta=-63.290942 -> V=1.0, theta=0.0
% INFO    : Bus 4210	: V=0.986541, theta=-63.224547 -> V=1.0, theta=0.0
% INFO    : Bus 4211	: V=0.979362, theta=-63.947361 -> V=1.0, theta=0.0
% INFO    : Bus 4212	: V=0.9665532, theta=-67.965297 -> V=1.0, theta=0.0
% INFO    : Bus 4213	: V=0.9786632, theta=-64.691567 -> V=1.0, theta=0.0
% INFO    : Bus 4214	: V=0.9607006, theta=-69.556512 -> V=1.0, theta=0.0
% INFO    : Bus 4215	: V=0.97845, theta=-64.951202 -> V=1.0, theta=0.0
% INFO    : Bus 4216	: V=0.9565228, theta=-70.831308 -> V=1.0, theta=0.0
% INFO    : Bus 4217	: V=0.9791264, theta=-68.588108 -> V=1.0, theta=0.0
% INFO    : Bus 4218	: V=0.9974269, theta=-67.291768 -> V=1.0, theta=0.0
% INFO    : Bus 4219	: V=1.0187009, theta=-64.675539 -> V=1.0, theta=0.0
% INFO    : Bus 4220	: V=1.0187727, theta=-62.771468 -> V=1.0, theta=0.0
% INFO    : Bus 4221	: V=1.0156209, theta=-67.344228 -> V=1.0, theta=0.0
% INFO    : Bus 4222	: V=0.987427, theta=-68.935861 -> V=1.0, theta=0.0
% INFO    : Bus 4223	: V=1.0141177, theta=-68.408249 -> V=1.0, theta=0.0
% INFO    : Bus 4224	: V=1.0071784, theta=-69.290891 -> V=1.0, theta=0.0
% INFO    : Bus 4225	: V=0.9995073, theta=-69.594338 -> V=1.0, theta=0.0
% INFO    : Bus 4226	: V=0.9980628, theta=-69.632258 -> V=1.0, theta=0.0
% INFO    : Bus 4227	: V=0.9967509, theta=-69.662921 -> V=1.0, theta=0.0
% INFO    : Bus 4228	: V=0.9938562, theta=-69.705118 -> V=1.0, theta=0.0
% INFO    : Bus 4229	: V=0.9977056, theta=-69.689893 -> V=1.0, theta=0.0
% INFO    : Bus 4230	: V=0.9916185, theta=-68.878007 -> V=1.0, theta=0.0
% INFO    : Bus 4231	: V=1.0020815, theta=-65.431884 -> V=1.0, theta=0.0
% INFO    : Bus 4232	: V=0.9988138, theta=-67.192753 -> V=1.0, theta=0.0
% INFO    : Bus 4233	: V=0.988012, theta=-68.527423 -> V=1.0, theta=0.0
% INFO    : Bus 4234	: V=0.991629, theta=-69.623763 -> V=1.0, theta=0.0
% INFO    : Bus 4235	: V=0.9944826, theta=-69.697167 -> V=1.0, theta=0.0
% INFO    : Bus 4236	: V=0.9618289, theta=-68.976845 -> V=1.0, theta=0.0
% INFO    : Bus 4237	: V=0.9651693, theta=-68.703504 -> V=1.0, theta=0.0
% INFO    : Bus 4238	: V=0.9705394, theta=-68.609427 -> V=1.0, theta=0.0
% INFO    : Bus 4239	: V=0.9893689, theta=-65.957455 -> V=1.0, theta=0.0
% INFO    : Bus 4240	: V=0.9952434, theta=-66.150541 -> V=1.0, theta=0.0
% INFO    : Bus 4241	: V=0.9831471, theta=-66.356031 -> V=1.0, theta=0.0
% INFO    : Bus 4242	: V=0.9938439, theta=-65.420762 -> V=1.0, theta=0.0
% INFO    : Bus 4243	: V=0.9953125, theta=-65.804783 -> V=1.0, theta=0.0
% INFO    : Bus 4244	: V=0.9631493, theta=-68.733446 -> V=1.0, theta=0.0
% INFO    : Bus 4245	: V=0.9880827, theta=-66.070878 -> V=1.0, theta=0.0
% INFO    : Bus 4246	: V=0.9823979, theta=-66.220177 -> V=1.0, theta=0.0
% INFO    : Bus 4247	: V=0.9987363, theta=-63.884912 -> V=1.0, theta=0.0
% INFO    : Bus 4248	: V=0.9955916, theta=-64.840678 -> V=1.0, theta=0.0
% INFO    : Bus 4249	: V=1.0006274, theta=-63.691232 -> V=1.0, theta=0.0
% INFO    : Bus 4250	: V=0.9926415, theta=-64.483733 -> V=1.0, theta=0.0
% INFO    : Bus 4251	: V=0.9862112, theta=-65.35257 -> V=1.0, theta=0.0
% INFO    : Bus 4252	: V=0.9826299, theta=-66.255518 -> V=1.0, theta=0.0
% INFO    : Bus 4253	: V=0.9772301, theta=-66.305984 -> V=1.0, theta=0.0
% INFO    : Bus 4254	: V=0.9849369, theta=-65.1674 -> V=1.0, theta=0.0
% INFO    : Bus 4255	: V=0.974123, theta=-65.727232 -> V=1.0, theta=0.0
% INFO    : Bus 4256	: V=0.9795518, theta=-65.563334 -> V=1.0, theta=0.0
% INFO    : Bus 4257	: V=0.9641555, theta=-68.275409 -> V=1.0, theta=0.0
% INFO    : Bus 4258	: V=0.9731508, theta=-67.561288 -> V=1.0, theta=0.0
% INFO    : Bus 4259	: V=0.9734677, theta=-68.623401 -> V=1.0, theta=0.0
% INFO    : Bus 4260	: V=0.9701244, theta=-68.996921 -> V=1.0, theta=0.0
% INFO    : Bus 4261	: V=0.9714725, theta=-68.843422 -> V=1.0, theta=0.0
% INFO    : Bus 4262	: V=0.9712298, theta=-68.868724 -> V=1.0, theta=0.0
% INFO    : Bus 4263	: V=0.9582397, theta=-71.427592 -> V=1.0, theta=0.0
% INFO    : Bus 4264	: V=0.9578615, theta=-71.438479 -> V=1.0, theta=0.0
% INFO    : Bus 4265	: V=0.9587491, theta=-71.375439 -> V=1.0, theta=0.0
% INFO    : Bus 4266	: V=0.9621186, theta=-70.801443 -> V=1.0, theta=0.0
% INFO    : Bus 4267	: V=0.9638158, theta=-70.565589 -> V=1.0, theta=0.0
% INFO    : Bus 4268	: V=0.9708985, theta=-70.0537 -> V=1.0, theta=0.0
% INFO    : Bus 4269	: V=0.9584102, theta=-67.069209 -> V=1.0, theta=0.0
% INFO    : Bus 4270	: V=0.9534852, theta=-67.216974 -> V=1.0, theta=0.0
% INFO    : Bus 4271	: V=0.9483815, theta=-68.240557 -> V=1.0, theta=0.0
% INFO    : Bus 4272	: V=0.9940123, theta=-62.833277 -> V=1.0, theta=0.0
% INFO    : Bus 4273	: V=0.9707277, theta=-64.641132 -> V=1.0, theta=0.0
% INFO    : Bus 4274	: V=0.9957342, theta=-63.961064 -> V=1.0, theta=0.0
% INFO    : Bus 4275	: V=0.96234, theta=-66.035173 -> V=1.0, theta=0.0
% INFO    : Bus 4276	: V=0.9715613, theta=-65.78525 -> V=1.0, theta=0.0
% INFO    : Bus 4277	: V=0.9713234, theta=-65.791263 -> V=1.0, theta=0.0
% INFO    : Bus 4278	: V=0.96832, theta=-65.819421 -> V=1.0, theta=0.0
% INFO    : Bus 4279	: V=0.9782082, theta=-64.546588 -> V=1.0, theta=0.0
% INFO    : Bus 4280	: V=0.9745721, theta=-64.93552 -> V=1.0, theta=0.0
% INFO    : Bus 4281	: V=0.993283, theta=-64.648026 -> V=1.0, theta=0.0
% INFO    : Bus 4282	: V=0.9833011, theta=-65.527596 -> V=1.0, theta=0.0
% INFO    : Bus 4283	: V=0.9698613, theta=-66.628444 -> V=1.0, theta=0.0
% INFO    : Bus 4284	: V=0.9636672, theta=-66.201915 -> V=1.0, theta=0.0
% INFO    : Bus 4285	: V=0.9610806, theta=-66.460992 -> V=1.0, theta=0.0
% INFO    : Bus 4286	: V=0.9628557, theta=-66.410632 -> V=1.0, theta=0.0
% INFO    : Bus 4287	: V=0.9657653, theta=-66.624775 -> V=1.0, theta=0.0
% INFO    : Bus 4288	: V=0.9662542, theta=-66.78153 -> V=1.0, theta=0.0
% INFO    : Bus 4289	: V=0.9651747, theta=-66.873422 -> V=1.0, theta=0.0
% INFO    : Bus 4290	: V=0.9736444, theta=-65.232136 -> V=1.0, theta=0.0
% INFO    : Bus 4291	: V=0.9694349, theta=-65.755458 -> V=1.0, theta=0.0
% INFO    : Bus 4292	: V=0.9662463, theta=-66.162117 -> V=1.0, theta=0.0
% INFO    : Bus 4293	: V=0.9817036, theta=-64.080119 -> V=1.0, theta=0.0
% INFO    : Bus 4294	: V=0.9719344, theta=-64.116731 -> V=1.0, theta=0.0
% INFO    : Bus 4295	: V=0.9678283, theta=-65.531101 -> V=1.0, theta=0.0
% INFO    : Bus 4296	: V=0.9952055, theta=-62.364188 -> V=1.0, theta=0.0
% INFO    : Bus 4297	: V=0.9757377, theta=-63.987447 -> V=1.0, theta=0.0
% INFO    : Bus 4298	: V=0.9946681, theta=-62.35474 -> V=1.0, theta=0.0
% INFO    : Bus 4299	: V=0.9748993, theta=-64.082895 -> V=1.0, theta=0.0
% INFO    : Bus 4300	: V=0.9764237, theta=-63.989422 -> V=1.0, theta=0.0
% INFO    : Bus 4301	: V=0.9770766, theta=-63.983275 -> V=1.0, theta=0.0
% INFO    : Bus 4302	: V=0.9611028, theta=-66.551577 -> V=1.0, theta=0.0
% INFO    : Bus 4303	: V=0.961998, theta=-66.434794 -> V=1.0, theta=0.0
% INFO    : Bus 4304	: V=0.9706912, theta=-65.227129 -> V=1.0, theta=0.0
% INFO    : Bus 4305	: V=0.9623182, theta=-65.980783 -> V=1.0, theta=0.0
% INFO    : Bus 4306	: V=0.9715668, theta=-65.059735 -> V=1.0, theta=0.0
% INFO    : Bus 4307	: V=0.9614916, theta=-66.284829 -> V=1.0, theta=0.0
% INFO    : Bus 4308	: V=0.9589633, theta=-66.159514 -> V=1.0, theta=0.0
% INFO    : Bus 4309	: V=0.9638066, theta=-65.965525 -> V=1.0, theta=0.0
% INFO    : Bus 4310	: V=0.9615459, theta=-66.084441 -> V=1.0, theta=0.0
% INFO    : Bus 4311	: V=0.9599622, theta=-66.554547 -> V=1.0, theta=0.0
% INFO    : Bus 4312	: V=0.9739782, theta=-66.54481 -> V=1.0, theta=0.0
% INFO    : Bus 4313	: V=0.9607281, theta=-67.081883 -> V=1.0, theta=0.0
% INFO    : Bus 4314	: V=0.9599455, theta=-67.104006 -> V=1.0, theta=0.0
% INFO    : Bus 4315	: V=0.9643025, theta=-66.919332 -> V=1.0, theta=0.0
% INFO    : Bus 4316	: V=0.9786766, theta=-65.711722 -> V=1.0, theta=0.0
% INFO    : Bus 4317	: V=0.9603284, theta=-66.50917 -> V=1.0, theta=0.0
% INFO    : Bus 4318	: V=0.9614647, theta=-66.623804 -> V=1.0, theta=0.0
% INFO    : Bus 4319	: V=0.9599326, theta=-66.604652 -> V=1.0, theta=0.0
% INFO    : Bus 4320	: V=0.97277, theta=-64.892699 -> V=1.0, theta=0.0
% INFO    : Bus 4321	: V=0.9611118, theta=-66.4533 -> V=1.0, theta=0.0
% INFO    : Bus 4322	: V=0.963115, theta=-66.290578 -> V=1.0, theta=0.0
% INFO    : Bus 4323	: V=0.969932, theta=-64.659324 -> V=1.0, theta=0.0
% INFO    : Bus 4324	: V=0.9700518, theta=-64.691415 -> V=1.0, theta=0.0
% INFO    : Bus 4325	: V=0.9715091, theta=-64.548214 -> V=1.0, theta=0.0
% INFO    : Bus 4326	: V=0.9705815, theta=-65.359368 -> V=1.0, theta=0.0
% INFO    : Bus 4327	: V=0.9770479, theta=-64.683482 -> V=1.0, theta=0.0
% INFO    : Bus 4328	: V=0.9693238, theta=-65.994318 -> V=1.0, theta=0.0
% INFO    : Bus 4329	: V=0.9700105, theta=-65.920791 -> V=1.0, theta=0.0
% INFO    : Bus 4330	: V=0.961647, theta=-66.508505 -> V=1.0, theta=0.0
% INFO    : Bus 4331	: V=0.9637637, theta=-66.445217 -> V=1.0, theta=0.0
% INFO    : Bus 4332	: V=0.9656957, theta=-66.491761 -> V=1.0, theta=0.0
% INFO    : Bus 4333	: V=0.9654401, theta=-66.499514 -> V=1.0, theta=0.0
% INFO    : Bus 4334	: V=0.9701713, theta=-65.861207 -> V=1.0, theta=0.0
% INFO    : Bus 4335	: V=0.9734448, theta=-66.132619 -> V=1.0, theta=0.0
% INFO    : Bus 4336	: V=0.9633653, theta=-66.536283 -> V=1.0, theta=0.0
% INFO    : Bus 4337	: V=0.974925, theta=-64.913502 -> V=1.0, theta=0.0
% INFO    : Bus 4338	: V=0.9679179, theta=-65.399117 -> V=1.0, theta=0.0
% INFO    : Bus 4339	: V=0.9770672, theta=-64.678182 -> V=1.0, theta=0.0
% INFO    : Bus 4340	: V=0.9870566, theta=-63.151304 -> V=1.0, theta=0.0
% INFO    : Bus 4341	: V=0.9909183, theta=-63.119975 -> V=1.0, theta=0.0
% INFO    : Bus 4342	: V=0.9866695, theta=-63.22068 -> V=1.0, theta=0.0
% INFO    : Bus 4343	: V=0.9736395, theta=-64.095023 -> V=1.0, theta=0.0
% INFO    : Bus 4344	: V=0.9692454, theta=-66.536305 -> V=1.0, theta=0.0
% INFO    : Bus 4345	: V=0.9645516, theta=-66.7172 -> V=1.0, theta=0.0
% INFO    : Bus 4346	: V=0.9946405, theta=-62.385967 -> V=1.0, theta=0.0
% INFO    : Bus 4347	: V=0.9835101, theta=-63.616853 -> V=1.0, theta=0.0
% INFO    : Bus 4348	: V=0.983798, theta=-63.534317 -> V=1.0, theta=0.0
% INFO    : Bus 4349	: V=0.9649678, theta=-65.695782 -> V=1.0, theta=0.0
% INFO    : Bus 4350	: V=0.974671, theta=-64.675913 -> V=1.0, theta=0.0
% INFO    : Bus 4351	: V=0.9672919, theta=-65.013402 -> V=1.0, theta=0.0
% INFO    : Bus 4352	: V=0.9669934, theta=-65.013894 -> V=1.0, theta=0.0
% INFO    : Bus 4353	: V=0.9665049, theta=-65.017903 -> V=1.0, theta=0.0
% INFO    : Bus 4354	: V=0.9672555, theta=-64.98533 -> V=1.0, theta=0.0
% INFO    : Bus 4355	: V=0.9697086, theta=-64.681469 -> V=1.0, theta=0.0
% INFO    : Bus 4356	: V=0.9760776, theta=-64.515635 -> V=1.0, theta=0.0
% INFO    : Bus 4357	: V=0.9895311, theta=-62.920378 -> V=1.0, theta=0.0
% INFO    : Bus 4358	: V=0.9617998, theta=-66.378877 -> V=1.0, theta=0.0
% INFO    : Bus 4359	: V=0.9622875, theta=-66.427154 -> V=1.0, theta=0.0
% INFO    : Bus 4360	: V=0.9889373, theta=-62.9225 -> V=1.0, theta=0.0
% INFO    : Bus 4361	: V=0.9972754, theta=-74.0098 -> V=1.0, theta=0.0
% INFO    : Bus 4362	: V=0.9978505, theta=-73.891225 -> V=1.0, theta=0.0
% INFO    : Bus 4363	: V=0.9997754, theta=-72.856245 -> V=1.0, theta=0.0
% INFO    : Bus 4364	: V=0.9977078, theta=-73.929627 -> V=1.0, theta=0.0
% INFO    : Bus 4365	: V=0.9977758, theta=-73.901469 -> V=1.0, theta=0.0
% INFO    : Bus 4366	: V=0.9978863, theta=-73.854636 -> V=1.0, theta=0.0
% INFO    : Bus 4367	: V=0.9977103, theta=-73.862606 -> V=1.0, theta=0.0
% INFO    : Bus 4368	: V=0.9985643, theta=-73.780502 -> V=1.0, theta=0.0
% INFO    : Bus 4369	: V=0.999791, theta=-73.574566 -> V=1.0, theta=0.0
% INFO    : Bus 4370	: V=0.9982132, theta=-74.554084 -> V=1.0, theta=0.0
% INFO    : Bus 4371	: V=0.9984997, theta=-74.381282 -> V=1.0, theta=0.0
% INFO    : Bus 4372	: V=0.999025, theta=-74.176383 -> V=1.0, theta=0.0
% INFO    : Bus 4373	: V=0.9989101, theta=-74.160574 -> V=1.0, theta=0.0
% INFO    : Bus 4374	: V=1.0000264, theta=-73.565772 -> V=1.0, theta=0.0
% INFO    : Bus 4375	: V=1.0013948, theta=-73.405973 -> V=1.0, theta=0.0
% INFO    : Bus 4376	: V=1.0014467, theta=-73.365145 -> V=1.0, theta=0.0
% INFO    : Bus 4377	: V=0.9985614, theta=-74.559008 -> V=1.0, theta=0.0
% INFO    : Bus 4378	: V=0.9993725, theta=-72.794657 -> V=1.0, theta=0.0
% INFO    : Bus 4379	: V=0.999674, theta=-72.73115 -> V=1.0, theta=0.0
% INFO    : Bus 4380	: V=0.9992938, theta=-73.104841 -> V=1.0, theta=0.0
% INFO    : Bus 4381	: V=1.0001473, theta=-72.645473 -> V=1.0, theta=0.0
% INFO    : Bus 4382	: V=0.9990948, theta=-74.536384 -> V=1.0, theta=0.0
% INFO    : Bus 4383	: V=1.000281, theta=-74.573489 -> V=1.0, theta=0.0
% INFO    : Bus 4384	: V=0.9996993, theta=-74.663756 -> V=1.0, theta=0.0
% INFO    : Bus 4385	: V=1.0009498, theta=-74.431625 -> V=1.0, theta=0.0
% INFO    : Bus 4386	: V=1.0005618, theta=-74.3897 -> V=1.0, theta=0.0
% INFO    : Bus 4387	: V=1.0014819, theta=-74.253577 -> V=1.0, theta=0.0
% INFO    : Bus 4388	: V=1.0017091, theta=-74.200539 -> V=1.0, theta=0.0
% INFO    : Bus 4389	: V=1.0018811, theta=-74.142486 -> V=1.0, theta=0.0
% INFO    : Bus 4390	: V=1.0011431, theta=-74.309654 -> V=1.0, theta=0.0
% INFO    : Bus 4391	: V=1.0009108, theta=-74.350863 -> V=1.0, theta=0.0
% INFO    : Bus 4392	: V=1.0005374, theta=-74.39801 -> V=1.0, theta=0.0
% INFO    : Bus 4393	: V=1.0009457, theta=-74.367078 -> V=1.0, theta=0.0
% INFO    : Bus 4394	: V=1.0006697, theta=-74.386096 -> V=1.0, theta=0.0
% INFO    : Bus 4395	: V=1.0011147, theta=-74.369533 -> V=1.0, theta=0.0
% INFO    : Bus 4396	: V=1.0008025, theta=-74.385968 -> V=1.0, theta=0.0
% INFO    : Bus 4397	: V=1.0016098, theta=-74.411435 -> V=1.0, theta=0.0
% INFO    : Bus 4398	: V=1.0023563, theta=-74.406869 -> V=1.0, theta=0.0
% INFO    : Bus 4399	: V=1.0010088, theta=-74.28952 -> V=1.0, theta=0.0
% INFO    : Bus 4400	: V=1.001253, theta=-74.416504 -> V=1.0, theta=0.0
% INFO    : Bus 4401	: V=1.0019661, theta=-74.493196 -> V=1.0, theta=0.0
% INFO    : Bus 4402	: V=1.0022547, theta=-74.547986 -> V=1.0, theta=0.0
% INFO    : Bus 4403	: V=1.002574, theta=-74.68454 -> V=1.0, theta=0.0
% INFO    : Bus 4404	: V=1.002609, theta=-74.576745 -> V=1.0, theta=0.0
% INFO    : Bus 4405	: V=1.0009072, theta=-74.562915 -> V=1.0, theta=0.0
% INFO    : Bus 4406	: V=1.0003759, theta=-74.581122 -> V=1.0, theta=0.0
% INFO    : Bus 4407	: V=1.0010614, theta=-74.642427 -> V=1.0, theta=0.0
% INFO    : Bus 4408	: V=1.0013535, theta=-74.728566 -> V=1.0, theta=0.0
% INFO    : Bus 4409	: V=1.0005869, theta=-74.833016 -> V=1.0, theta=0.0
% INFO    : Bus 4410	: V=1.0036346, theta=-74.698584 -> V=1.0, theta=0.0
% INFO    : Bus 4411	: V=1.0054202, theta=-74.676595 -> V=1.0, theta=0.0
% INFO    : Bus 4412	: V=1.0089445, theta=-74.50761 -> V=1.0, theta=0.0
% INFO    : Bus 4413	: V=1.0074149, theta=-74.624321 -> V=1.0, theta=0.0
% INFO    : Bus 4414	: V=1.0001088, theta=-74.854781 -> V=1.0, theta=0.0
% INFO    : Bus 4415	: V=0.9984707, theta=-74.992252 -> V=1.0, theta=0.0
% INFO    : Bus 4416	: V=1.0005766, theta=-74.832168 -> V=1.0, theta=0.0
% INFO    : Bus 4417	: V=0.9997869, theta=-74.887233 -> V=1.0, theta=0.0
% INFO    : Bus 4418	: V=0.9999449, theta=-74.870453 -> V=1.0, theta=0.0
% INFO    : Bus 4419	: V=0.9995882, theta=-74.87084 -> V=1.0, theta=0.0
% INFO    : Bus 4420	: V=0.9994996, theta=-74.855249 -> V=1.0, theta=0.0
% INFO    : Bus 4421	: V=0.9993468, theta=-74.8163 -> V=1.0, theta=0.0
% INFO    : Bus 4422	: V=0.9977997, theta=-74.944966 -> V=1.0, theta=0.0
% INFO    : Bus 4423	: V=0.9980345, theta=-74.945902 -> V=1.0, theta=0.0
% INFO    : Bus 4424	: V=0.9978194, theta=-74.922399 -> V=1.0, theta=0.0
% INFO    : Bus 4425	: V=0.9982191, theta=-75.003257 -> V=1.0, theta=0.0
% INFO    : Bus 4426	: V=0.9979094, theta=-74.938647 -> V=1.0, theta=0.0
% INFO    : Bus 4427	: V=0.9980075, theta=-74.966469 -> V=1.0, theta=0.0
% INFO    : Bus 4428	: V=0.997903, theta=-74.887914 -> V=1.0, theta=0.0
% INFO    : Bus 4429	: V=0.9979956, theta=-74.812447 -> V=1.0, theta=0.0
% INFO    : Bus 4430	: V=0.9978257, theta=-74.820193 -> V=1.0, theta=0.0
% INFO    : Bus 4431	: V=1.0091047, theta=-74.641548 -> V=1.0, theta=0.0
% INFO    : Bus 4432	: V=1.0137336, theta=-73.878456 -> V=1.0, theta=0.0
% INFO    : Bus 4433	: V=1.0113817, theta=-73.88209 -> V=1.0, theta=0.0
% INFO    : Bus 4434	: V=1.0069265, theta=-73.158391 -> V=1.0, theta=0.0
% INFO    : Bus 4435	: V=1.0060942, theta=-74.003625 -> V=1.0, theta=0.0
% INFO    : Bus 4436	: V=1.0057787, theta=-74.083735 -> V=1.0, theta=0.0
% INFO    : Bus 4437	: V=1.0064743, theta=-72.90636 -> V=1.0, theta=0.0
% INFO    : Bus 4438	: V=1.0051087, theta=-73.008714 -> V=1.0, theta=0.0
% INFO    : Bus 4439	: V=1.0057868, theta=-73.993044 -> V=1.0, theta=0.0
% INFO    : Bus 4440	: V=1.0057594, theta=-73.992641 -> V=1.0, theta=0.0
% INFO    : Bus 4441	: V=1.0058787, theta=-72.957223 -> V=1.0, theta=0.0
% INFO    : Bus 4442	: V=1.0042555, theta=-72.999835 -> V=1.0, theta=0.0
% INFO    : Bus 4443	: V=1.0043682, theta=-74.378006 -> V=1.0, theta=0.0
% INFO    : Bus 4444	: V=1.00294, theta=-74.349805 -> V=1.0, theta=0.0
% INFO    : Bus 4445	: V=1.0065418, theta=-73.26005 -> V=1.0, theta=0.0
% INFO    : Bus 4446	: V=1.0054784, theta=-74.441831 -> V=1.0, theta=0.0
% INFO    : Bus 4447	: V=1.0063294, theta=-73.319947 -> V=1.0, theta=0.0
% INFO    : Bus 4448	: V=1.0060649, theta=-73.394866 -> V=1.0, theta=0.0
% INFO    : Bus 4449	: V=1.0087691, theta=-74.601101 -> V=1.0, theta=0.0
% INFO    : Bus 4450	: V=1.0033454, theta=-74.442303 -> V=1.0, theta=0.0
% INFO    : Bus 4451	: V=1.0037634, theta=-74.548595 -> V=1.0, theta=0.0
% INFO    : Bus 4452	: V=1.0052379, theta=-74.508642 -> V=1.0, theta=0.0
% INFO    : Bus 4453	: V=1.0059001, theta=-73.445494 -> V=1.0, theta=0.0
% INFO    : Bus 4454	: V=1.0076147, theta=-74.464677 -> V=1.0, theta=0.0
% INFO    : Bus 4455	: V=1.0002566, theta=-73.602482 -> V=1.0, theta=0.0
% INFO    : Bus 4456	: V=0.9968006, theta=-71.530246 -> V=1.0, theta=0.0
% INFO    : Bus 4457	: V=1.0009795, theta=-73.408482 -> V=1.0, theta=0.0
% INFO    : Bus 4458	: V=1.0013468, theta=-73.219304 -> V=1.0, theta=0.0
% INFO    : Bus 4459	: V=1.0003278, theta=-73.272212 -> V=1.0, theta=0.0
% INFO    : Bus 4460	: V=1.0019078, theta=-71.155363 -> V=1.0, theta=0.0
% INFO    : Bus 4461	: V=0.9996881, theta=-71.491835 -> V=1.0, theta=0.0
% INFO    : Bus 4462	: V=1.0011985, theta=-73.465087 -> V=1.0, theta=0.0
% INFO    : Bus 4463	: V=1.0027804, theta=-73.740248 -> V=1.0, theta=0.0
% INFO    : Bus 4464	: V=1.0073218, theta=-72.84721 -> V=1.0, theta=0.0
% INFO    : Bus 4465	: V=1.0000945, theta=-73.726927 -> V=1.0, theta=0.0
% INFO    : Bus 4466	: V=1.0008086, theta=-73.694314 -> V=1.0, theta=0.0
% INFO    : Bus 4467	: V=0.999789, theta=-73.740789 -> V=1.0, theta=0.0
% INFO    : Bus 4468	: V=0.9992077, theta=-71.602538 -> V=1.0, theta=0.0
% INFO    : Bus 4469	: V=1.0014509, theta=-73.450746 -> V=1.0, theta=0.0
% INFO    : Bus 4470	: V=1.0013261, theta=-73.779385 -> V=1.0, theta=0.0
% INFO    : Bus 4471	: V=1.0017519, theta=-73.761676 -> V=1.0, theta=0.0
% INFO    : Bus 4472	: V=0.9997301, theta=-74.221579 -> V=1.0, theta=0.0
% INFO    : Bus 4473	: V=1.0020958, theta=-74.304946 -> V=1.0, theta=0.0
% INFO    : Bus 4474	: V=0.9999795, theta=-74.303967 -> V=1.0, theta=0.0
% INFO    : Bus 4475	: V=1.0005413, theta=-74.278634 -> V=1.0, theta=0.0
% INFO    : Bus 4476	: V=0.9991675, theta=-74.340682 -> V=1.0, theta=0.0
% INFO    : Bus 4477	: V=1.0009734, theta=-74.159467 -> V=1.0, theta=0.0
% INFO    : Bus 4478	: V=1.000334, theta=-73.69135 -> V=1.0, theta=0.0
% INFO    : Bus 4479	: V=1.0008844, theta=-73.461187 -> V=1.0, theta=0.0
% INFO    : Bus 4480	: V=1.0009763, theta=-72.98785 -> V=1.0, theta=0.0
% INFO    : Bus 4481	: V=1.0002595, theta=-73.094277 -> V=1.0, theta=0.0
% INFO    : Bus 4482	: V=1.0012171, theta=-72.564929 -> V=1.0, theta=0.0
% INFO    : Bus 4483	: V=1.0013061, theta=-73.401951 -> V=1.0, theta=0.0
% INFO    : Bus 4484	: V=0.9995258, theta=-73.156922 -> V=1.0, theta=0.0
% INFO    : Bus 4485	: V=1.0001965, theta=-73.10316 -> V=1.0, theta=0.0
% INFO    : Bus 4486	: V=1.0017882, theta=-72.919449 -> V=1.0, theta=0.0
% INFO    : Bus 4487	: V=1.0011319, theta=-73.688346 -> V=1.0, theta=0.0
% INFO    : Bus 4488	: V=1.0011321, theta=-73.42754 -> V=1.0, theta=0.0
% INFO    : Bus 4489	: V=1.0007021, theta=-73.698792 -> V=1.0, theta=0.0
% INFO    : Bus 4490	: V=1.0011855, theta=-73.950017 -> V=1.0, theta=0.0
% INFO    : Bus 4491	: V=1.0016026, theta=-74.243409 -> V=1.0, theta=0.0
% INFO    : Bus 4492	: V=1.0020798, theta=-74.04052 -> V=1.0, theta=0.0
% INFO    : Bus 4493	: V=1.0020325, theta=-74.042671 -> V=1.0, theta=0.0
% INFO    : Bus 4494	: V=1.0007891, theta=-72.474163 -> V=1.0, theta=0.0
% INFO    : Bus 4495	: V=1.0013887, theta=-73.282548 -> V=1.0, theta=0.0
% INFO    : Bus 4496	: V=1.0011595, theta=-72.378443 -> V=1.0, theta=0.0
% INFO    : Bus 4497	: V=1.0027342, theta=-69.537742 -> V=1.0, theta=0.0
% INFO    : Bus 4498	: V=1.00179, theta=-72.613745 -> V=1.0, theta=0.0
% INFO    : Bus 4499	: V=0.9980853, theta=-73.640443 -> V=1.0, theta=0.0
% INFO    : Bus 4500	: V=0.9989613, theta=-73.600446 -> V=1.0, theta=0.0
% INFO    : Bus 4501	: V=1.0015656, theta=-72.195732 -> V=1.0, theta=0.0
% INFO    : Bus 4502	: V=1.0013729, theta=-72.65251 -> V=1.0, theta=0.0
% INFO    : Bus 4503	: V=1.0015027, theta=-73.379278 -> V=1.0, theta=0.0
% INFO    : Bus 4504	: V=1.0016921, theta=-72.071264 -> V=1.0, theta=0.0
% INFO    : Bus 4505	: V=1.0013591, theta=-73.439942 -> V=1.0, theta=0.0
% INFO    : Bus 4506	: V=1.0010932, theta=-72.189628 -> V=1.0, theta=0.0
% INFO    : Bus 4507	: V=1.0005085, theta=-72.045894 -> V=1.0, theta=0.0
% INFO    : Bus 4508	: V=1.0006334, theta=-72.534999 -> V=1.0, theta=0.0
% INFO    : Bus 4509	: V=0.9989925, theta=-73.730818 -> V=1.0, theta=0.0
% INFO    : Bus 4510	: V=0.9995638, theta=-73.655499 -> V=1.0, theta=0.0
% INFO    : Bus 4511	: V=0.9979473, theta=-73.852345 -> V=1.0, theta=0.0
% INFO    : Bus 4512	: V=0.9985742, theta=-73.823762 -> V=1.0, theta=0.0
% INFO    : Bus 4513	: V=0.9981777, theta=-73.610657 -> V=1.0, theta=0.0
% INFO    : Bus 4514	: V=0.9971726, theta=-73.886439 -> V=1.0, theta=0.0
% INFO    : Bus 4515	: V=0.9978126, theta=-73.852493 -> V=1.0, theta=0.0
% INFO    : Bus 4516	: V=0.9971237, theta=-73.800725 -> V=1.0, theta=0.0
% INFO    : Bus 4517	: V=0.9988668, theta=-73.902086 -> V=1.0, theta=0.0
% INFO    : Bus 4518	: V=0.9972327, theta=-73.753872 -> V=1.0, theta=0.0
% INFO    : Bus 4519	: V=0.9970675, theta=-73.933827 -> V=1.0, theta=0.0
% INFO    : Bus 4520	: V=0.9968816, theta=-73.899922 -> V=1.0, theta=0.0
% INFO    : Bus 4521	: V=0.9965835, theta=-73.644405 -> V=1.0, theta=0.0
% INFO    : Bus 4522	: V=0.9946759, theta=-74.096434 -> V=1.0, theta=0.0
% INFO    : Bus 4523	: V=0.9932447, theta=-74.260497 -> V=1.0, theta=0.0
% INFO    : Bus 4524	: V=0.9966967, theta=-72.182553 -> V=1.0, theta=0.0
% INFO    : Bus 4525	: V=0.9943393, theta=-73.514087 -> V=1.0, theta=0.0
% INFO    : Bus 4526	: V=0.9965637, theta=-71.800362 -> V=1.0, theta=0.0
% INFO    : Bus 4527	: V=0.996802, theta=-71.336914 -> V=1.0, theta=0.0
% INFO    : Bus 4528	: V=0.9854608, theta=-73.221544 -> V=1.0, theta=0.0
% INFO    : Bus 4529	: V=0.9852617, theta=-73.703463 -> V=1.0, theta=0.0
% INFO    : Bus 4530	: V=0.984629, theta=-73.732711 -> V=1.0, theta=0.0
% INFO    : Bus 4531	: V=0.9865076, theta=-73.441233 -> V=1.0, theta=0.0
% INFO    : Bus 4532	: V=0.9849594, theta=-73.799242 -> V=1.0, theta=0.0
% INFO    : Bus 4533	: V=0.9823854, theta=-73.918161 -> V=1.0, theta=0.0
% INFO    : Bus 4534	: V=0.9954764, theta=-73.847499 -> V=1.0, theta=0.0
% INFO    : Bus 4535	: V=0.9976424, theta=-72.332503 -> V=1.0, theta=0.0
% INFO    : Bus 4536	: V=0.9949116, theta=-73.993737 -> V=1.0, theta=0.0
% INFO    : Bus 4537	: V=0.9886877, theta=-73.498798 -> V=1.0, theta=0.0
% INFO    : Bus 4538	: V=0.9858441, theta=-73.794244 -> V=1.0, theta=0.0
% INFO    : Bus 4539	: V=0.9862879, theta=-73.777355 -> V=1.0, theta=0.0
% INFO    : Bus 4540	: V=1.0037497, theta=-71.394325 -> V=1.0, theta=0.0
% INFO    : Bus 4541	: V=1.0018321, theta=-71.724549 -> V=1.0, theta=0.0
% INFO    : Bus 4542	: V=1.0015567, theta=-71.692358 -> V=1.0, theta=0.0
% INFO    : Bus 4543	: V=0.9996536, theta=-72.72093 -> V=1.0, theta=0.0
% INFO    : Bus 4544	: V=0.9976914, theta=-73.22984 -> V=1.0, theta=0.0
% INFO    : Bus 4545	: V=0.9982524, theta=-72.737297 -> V=1.0, theta=0.0
% INFO    : Bus 4546	: V=0.9992182, theta=-73.173797 -> V=1.0, theta=0.0
% INFO    : Bus 4547	: V=0.9982578, theta=-73.182903 -> V=1.0, theta=0.0
% INFO    : Bus 4548	: V=0.9992267, theta=-73.075325 -> V=1.0, theta=0.0
% INFO    : Bus 4549	: V=0.9997025, theta=-73.151718 -> V=1.0, theta=0.0
% INFO    : Bus 4550	: V=0.9992478, theta=-73.139028 -> V=1.0, theta=0.0
% INFO    : Bus 4551	: V=0.9963549, theta=-72.769955 -> V=1.0, theta=0.0
% INFO    : Bus 4552	: V=0.9955419, theta=-72.666105 -> V=1.0, theta=0.0
% INFO    : Bus 4553	: V=0.9979634, theta=-71.610555 -> V=1.0, theta=0.0
% INFO    : Bus 4554	: V=0.9890732, theta=-71.596275 -> V=1.0, theta=0.0
% INFO    : Bus 4555	: V=0.9949706, theta=-71.629967 -> V=1.0, theta=0.0
% INFO    : Bus 4556	: V=0.9912563, theta=-71.35936 -> V=1.0, theta=0.0
% INFO    : Bus 4557	: V=0.9919921, theta=-71.433655 -> V=1.0, theta=0.0
% INFO    : Bus 4558	: V=1.0026315, theta=-71.139138 -> V=1.0, theta=0.0
% INFO    : Bus 4559	: V=1.0022284, theta=-71.30592 -> V=1.0, theta=0.0
% INFO    : Bus 4560	: V=1.001887, theta=-71.449886 -> V=1.0, theta=0.0
% INFO    : Bus 4561	: V=1.0075632, theta=-70.904081 -> V=1.0, theta=0.0
% INFO    : Bus 4562	: V=1.0013472, theta=-71.097381 -> V=1.0, theta=0.0
% INFO    : Bus 4563	: V=0.9955649, theta=-71.128647 -> V=1.0, theta=0.0
% INFO    : Bus 4564	: V=0.9861581, theta=-71.689419 -> V=1.0, theta=0.0
% INFO    : Bus 4565	: V=1.0023806, theta=-68.330038 -> V=1.0, theta=0.0
% INFO    : Bus 4566	: V=0.9820254, theta=-72.160284 -> V=1.0, theta=0.0
% INFO    : Bus 4567	: V=0.9825156, theta=-71.976882 -> V=1.0, theta=0.0
% INFO    : Bus 4568	: V=0.9861507, theta=-71.945226 -> V=1.0, theta=0.0
% INFO    : Bus 4569	: V=0.9839224, theta=-72.55794 -> V=1.0, theta=0.0
% INFO    : Bus 4570	: V=0.9973701, theta=-70.795373 -> V=1.0, theta=0.0
% INFO    : Bus 4571	: V=0.9977438, theta=-70.492824 -> V=1.0, theta=0.0
% INFO    : Bus 4572	: V=0.9901465, theta=-71.356556 -> V=1.0, theta=0.0
% INFO    : Bus 4573	: V=0.9987064, theta=-69.906249 -> V=1.0, theta=0.0
% INFO    : Bus 4574	: V=0.9880932, theta=-71.389262 -> V=1.0, theta=0.0
% INFO    : Bus 4575	: V=0.9868579, theta=-71.40733 -> V=1.0, theta=0.0
% INFO    : Bus 4576	: V=0.9807991, theta=-71.556194 -> V=1.0, theta=0.0
% INFO    : Bus 4577	: V=0.983908, theta=-71.871182 -> V=1.0, theta=0.0
% INFO    : Bus 4578	: V=0.9800046, theta=-72.003747 -> V=1.0, theta=0.0
% INFO    : Bus 4579	: V=0.9986346, theta=-68.098198 -> V=1.0, theta=0.0
% INFO    : Bus 4580	: V=0.9978913, theta=-73.844167 -> V=1.0, theta=0.0
% INFO    : Bus 4581	: V=1.0004996, theta=-72.741181 -> V=1.0, theta=0.0
% INFO    : Bus 4582	: V=0.998342, theta=-74.404769 -> V=1.0, theta=0.0
% INFO    : Bus 4583	: V=0.9976272, theta=-74.744141 -> V=1.0, theta=0.0
% INFO    : Bus 4584	: V=0.9992631, theta=-74.34399 -> V=1.0, theta=0.0
% INFO    : Bus 4585	: V=1.0004259, theta=-73.520158 -> V=1.0, theta=0.0
% INFO    : Bus 4586	: V=0.999287, theta=-74.706592 -> V=1.0, theta=0.0
% INFO    : Bus 4587	: V=0.9991607, theta=-74.884874 -> V=1.0, theta=0.0
% INFO    : Bus 4588	: V=1.0012215, theta=-72.881271 -> V=1.0, theta=0.0
% INFO    : Bus 4589	: V=0.9998153, theta=-74.921275 -> V=1.0, theta=0.0
% INFO    : Bus 4590	: V=1.0072311, theta=-73.079624 -> V=1.0, theta=0.0
% INFO    : Bus 4591	: V=0.9981141, theta=-73.758277 -> V=1.0, theta=0.0
% INFO    : Bus 4592	: V=1.0001462, theta=-73.997534 -> V=1.0, theta=0.0
% INFO    : Bus 4593	: V=0.9840268, theta=-70.137412 -> V=1.0, theta=0.0
% INFO    : Bus 4594	: V=0.9819123, theta=-70.818947 -> V=1.0, theta=0.0
% INFO    : Bus 4595	: V=0.9849698, theta=-71.427468 -> V=1.0, theta=0.0
% INFO    : Bus 4596	: V=0.9789285, theta=-71.586725 -> V=1.0, theta=0.0
% INFO    : Bus 4597	: V=0.9815554, theta=-68.694297 -> V=1.0, theta=0.0
% INFO    : Bus 4598	: V=0.9761304, theta=-68.789039 -> V=1.0, theta=0.0
% INFO    : Bus 4599	: V=0.9801435, theta=-66.995815 -> V=1.0, theta=0.0
% INFO    : Bus 4600	: V=0.9784281, theta=-67.063774 -> V=1.0, theta=0.0
% INFO    : Bus 4601	: V=0.98711, theta=-65.633423 -> V=1.0, theta=0.0
% INFO    : Bus 4602	: V=0.9773468, theta=-68.952445 -> V=1.0, theta=0.0
% INFO    : Bus 4603	: V=0.9786353, theta=-68.743194 -> V=1.0, theta=0.0
% INFO    : Bus 4604	: V=0.9737022, theta=-69.191194 -> V=1.0, theta=0.0
% INFO    : Bus 4605	: V=0.976485, theta=-70.259577 -> V=1.0, theta=0.0
% INFO    : Bus 4606	: V=0.9793906, theta=-70.431763 -> V=1.0, theta=0.0
% INFO    : Bus 4607	: V=0.9974978, theta=-68.933167 -> V=1.0, theta=0.0
% INFO    : Bus 4608	: V=0.9736811, theta=-69.796565 -> V=1.0, theta=0.0
% INFO    : Bus 4609	: V=0.9754723, theta=-68.587709 -> V=1.0, theta=0.0
% INFO    : Bus 4610	: V=1.0000376, theta=-65.806133 -> V=1.0, theta=0.0
% INFO    : Bus 4611	: V=0.9911485, theta=-64.416333 -> V=1.0, theta=0.0
% INFO    : Bus 4612	: V=0.979193, theta=-66.533634 -> V=1.0, theta=0.0
% INFO    : Bus 4613	: V=0.9559024, theta=-66.394956 -> V=1.0, theta=0.0
% INFO    : Bus 4614	: V=0.9583083, theta=-66.615285 -> V=1.0, theta=0.0
% INFO    : Bus 4615	: V=0.971435, theta=-65.85154 -> V=1.0, theta=0.0
% INFO    : Bus 4616	: V=0.9640055, theta=-66.291199 -> V=1.0, theta=0.0
% INFO    : Bus 4617	: V=0.9519819, theta=-66.808429 -> V=1.0, theta=0.0
% INFO    : Bus 4618	: V=0.9989132, theta=-65.638883 -> V=1.0, theta=0.0
% INFO    : Bus 4619	: V=0.9772288, theta=-67.025212 -> V=1.0, theta=0.0
% INFO    : Bus 4620	: V=0.9805424, theta=-67.098559 -> V=1.0, theta=0.0
% INFO    : Bus 4621	: V=0.9771097, theta=-67.215717 -> V=1.0, theta=0.0
% INFO    : Bus 4622	: V=0.9922732, theta=-66.210341 -> V=1.0, theta=0.0
% INFO    : Bus 4623	: V=0.9764084, theta=-67.157709 -> V=1.0, theta=0.0
% INFO    : Bus 4624	: V=0.9795412, theta=-70.622917 -> V=1.0, theta=0.0
% INFO    : Bus 4625	: V=0.975353, theta=-70.679844 -> V=1.0, theta=0.0
% INFO    : Bus 4626	: V=0.9613577, theta=-71.410501 -> V=1.0, theta=0.0
% INFO    : Bus 4627	: V=0.9686946, theta=-70.642258 -> V=1.0, theta=0.0
% INFO    : Bus 4628	: V=0.9679812, theta=-69.509959 -> V=1.0, theta=0.0
% INFO    : Bus 4629	: V=0.9579591, theta=-70.238668 -> V=1.0, theta=0.0
% INFO    : Bus 4630	: V=0.9600009, theta=-71.612883 -> V=1.0, theta=0.0
% INFO    : Bus 4631	: V=0.9579558, theta=-71.658117 -> V=1.0, theta=0.0
% INFO    : Bus 4632	: V=0.9609934, theta=-71.57184 -> V=1.0, theta=0.0
% INFO    : Bus 4633	: V=0.9616553, theta=-71.553162 -> V=1.0, theta=0.0
% INFO    : Bus 4634	: V=0.9769914, theta=-70.803062 -> V=1.0, theta=0.0
% INFO    : Bus 4635	: V=0.9558451, theta=-71.762472 -> V=1.0, theta=0.0
% INFO    : Bus 4636	: V=0.955681, theta=-71.730432 -> V=1.0, theta=0.0
% INFO    : Bus 4637	: V=0.9611929, theta=-70.418531 -> V=1.0, theta=0.0
% INFO    : Bus 4638	: V=0.9614512, theta=-70.582855 -> V=1.0, theta=0.0
% INFO    : Bus 4639	: V=0.9804061, theta=-71.554691 -> V=1.0, theta=0.0
% INFO    : Bus 4640	: V=0.9900909, theta=-69.686591 -> V=1.0, theta=0.0
% INFO    : Bus 4641	: V=0.9768453, theta=-71.815727 -> V=1.0, theta=0.0
% INFO    : Bus 4642	: V=0.9891764, theta=-71.001491 -> V=1.0, theta=0.0
% INFO    : Bus 4643	: V=0.9935632, theta=-70.330029 -> V=1.0, theta=0.0
% INFO    : Bus 4644	: V=0.9939887, theta=-70.181349 -> V=1.0, theta=0.0
% INFO    : Bus 4645	: V=0.9936809, theta=-70.159261 -> V=1.0, theta=0.0
% INFO    : Bus 4646	: V=0.9952945, theta=-70.051537 -> V=1.0, theta=0.0
% INFO    : Bus 4647	: V=0.9934802, theta=-70.13881 -> V=1.0, theta=0.0
% INFO    : Bus 4648	: V=0.9932275, theta=-70.106192 -> V=1.0, theta=0.0
% INFO    : Bus 4649	: V=0.9974028, theta=-69.85464 -> V=1.0, theta=0.0
% INFO    : Bus 4650	: V=0.9836068, theta=-70.374129 -> V=1.0, theta=0.0
% INFO    : Bus 4651	: V=0.980623, theta=-69.762072 -> V=1.0, theta=0.0
% INFO    : Bus 4652	: V=0.9874911, theta=-70.05093 -> V=1.0, theta=0.0
% INFO    : Bus 4653	: V=0.9965185, theta=-70.633877 -> V=1.0, theta=0.0
% INFO    : Bus 4654	: V=1.0007702, theta=-64.205152 -> V=1.0, theta=0.0
% INFO    : Bus 4655	: V=0.9868254, theta=-65.677908 -> V=1.0, theta=0.0
% INFO    : Bus 4656	: V=0.9826197, theta=-64.637419 -> V=1.0, theta=0.0
% INFO    : Bus 4657	: V=0.9888544, theta=-62.698135 -> V=1.0, theta=0.0
% INFO    : Bus 4658	: V=0.9783282, theta=-64.923171 -> V=1.0, theta=0.0
% INFO    : Bus 4659	: V=0.9831894, theta=-63.447513 -> V=1.0, theta=0.0
% INFO    : Bus 4660	: V=0.9991118, theta=-64.876592 -> V=1.0, theta=0.0
% INFO    : Bus 4661	: V=0.9946113, theta=-64.988818 -> V=1.0, theta=0.0
% INFO    : Bus 4662	: V=1.0028477, theta=-63.563188 -> V=1.0, theta=0.0
% INFO    : Bus 4663	: V=0.9985552, theta=-65.013684 -> V=1.0, theta=0.0
% INFO    : Bus 4664	: V=1.0009271, theta=-64.802717 -> V=1.0, theta=0.0
% INFO    : Bus 4665	: V=1.0052216, theta=-63.18256 -> V=1.0, theta=0.0
% INFO    : Bus 4666	: V=0.9814169, theta=-65.837253 -> V=1.0, theta=0.0
% INFO    : Bus 4667	: V=0.9875598, theta=-65.033519 -> V=1.0, theta=0.0
% INFO    : Bus 4668	: V=0.9959908, theta=-64.107777 -> V=1.0, theta=0.0
% INFO    : Bus 4669	: V=0.9694943, theta=-66.168783 -> V=1.0, theta=0.0
% INFO    : Bus 4670	: V=0.9597852, theta=-66.296102 -> V=1.0, theta=0.0
% INFO    : Bus 4671	: V=0.9551005, theta=-72.190076 -> V=1.0, theta=0.0
% INFO    : Bus 4672	: V=0.9465974, theta=-64.867394 -> V=1.0, theta=0.0
% INFO    : Bus 4673	: V=0.9650452, theta=-65.745546 -> V=1.0, theta=0.0
% INFO    : Bus 4674	: V=0.9593924, theta=-67.253365 -> V=1.0, theta=0.0
% INFO    : Bus 4675	: V=0.9658968, theta=-65.725343 -> V=1.0, theta=0.0
% INFO    : Bus 4676	: V=0.9585421, theta=-67.438469 -> V=1.0, theta=0.0
% INFO    : Bus 4677	: V=0.9583091, theta=-67.499975 -> V=1.0, theta=0.0
% INFO    : Bus 4678	: V=0.9565876, theta=-67.549475 -> V=1.0, theta=0.0
% INFO    : Bus 4679	: V=0.956266, theta=-67.49205 -> V=1.0, theta=0.0
% INFO    : Bus 4680	: V=0.9645988, theta=-67.326474 -> V=1.0, theta=0.0
% INFO    : Bus 4681	: V=0.964773, theta=-67.404888 -> V=1.0, theta=0.0
% INFO    : Bus 4682	: V=0.96223, theta=-68.110494 -> V=1.0, theta=0.0
% INFO    : Bus 4683	: V=0.9662342, theta=-68.449466 -> V=1.0, theta=0.0
% INFO    : Bus 4684	: V=0.969048, theta=-68.62672 -> V=1.0, theta=0.0
% INFO    : Bus 4685	: V=0.9574612, theta=-67.460154 -> V=1.0, theta=0.0
% INFO    : Bus 4686	: V=0.9600447, theta=-67.383328 -> V=1.0, theta=0.0
% INFO    : Bus 4687	: V=0.9644669, theta=-66.870866 -> V=1.0, theta=0.0
% INFO    : Bus 4688	: V=0.9664673, theta=-66.136103 -> V=1.0, theta=0.0
% INFO    : Bus 4689	: V=0.9759227, theta=-67.775886 -> V=1.0, theta=0.0
% INFO    : Bus 4690	: V=0.9835446, theta=-66.157294 -> V=1.0, theta=0.0
% INFO    : Bus 4691	: V=0.961586, theta=-64.334916 -> V=1.0, theta=0.0
% INFO    : Bus 4692	: V=0.9703702, theta=-68.156716 -> V=1.0, theta=0.0
% INFO    : Bus 4693	: V=0.9595537, theta=-67.862291 -> V=1.0, theta=0.0
% INFO    : Bus 4694	: V=0.9636847, theta=-65.497559 -> V=1.0, theta=0.0
% INFO    : Bus 4695	: V=0.9720548, theta=-65.274886 -> V=1.0, theta=0.0
% INFO    : Bus 4696	: V=0.9668316, theta=-66.996873 -> V=1.0, theta=0.0
% INFO    : Bus 4697	: V=0.9751459, theta=-66.567098 -> V=1.0, theta=0.0
% INFO    : Bus 4698	: V=0.9700161, theta=-68.849121 -> V=1.0, theta=0.0
% INFO    : Bus 4699	: V=0.9765064, theta=-65.913724 -> V=1.0, theta=0.0
% INFO    : Bus 4700	: V=0.9760022, theta=-66.013765 -> V=1.0, theta=0.0
% INFO    : Bus 4701	: V=0.9790272, theta=-67.579094 -> V=1.0, theta=0.0
% INFO    : Bus 4702	: V=0.9824717, theta=-66.418694 -> V=1.0, theta=0.0
% INFO    : Bus 4703	: V=0.9789875, theta=-66.034853 -> V=1.0, theta=0.0
% INFO    : Bus 4704	: V=0.9786873, theta=-65.31872 -> V=1.0, theta=0.0
% INFO    : Bus 4705	: V=0.9834953, theta=-62.576916 -> V=1.0, theta=0.0
% INFO    : Bus 4706	: V=0.9783546, theta=-65.225588 -> V=1.0, theta=0.0
% INFO    : Bus 4707	: V=0.9773383, theta=-65.330038 -> V=1.0, theta=0.0
% INFO    : Bus 4708	: V=0.97699, theta=-64.907354 -> V=1.0, theta=0.0
% INFO    : Bus 4709	: V=0.9717129, theta=-63.238864 -> V=1.0, theta=0.0
% INFO    : Bus 4710	: V=0.9746583, theta=-63.161235 -> V=1.0, theta=0.0
% INFO    : Bus 4711	: V=0.9757885, theta=-65.407602 -> V=1.0, theta=0.0
% INFO    : Bus 4712	: V=0.976934, theta=-65.338606 -> V=1.0, theta=0.0
% INFO    : Bus 4713	: V=0.9777232, theta=-65.339139 -> V=1.0, theta=0.0
% INFO    : Bus 4714	: V=0.9912955, theta=-61.445546 -> V=1.0, theta=0.0
% INFO    : Bus 4715	: V=0.978556, theta=-61.62177 -> V=1.0, theta=0.0
% INFO    : Bus 4716	: V=0.9750075, theta=-68.134054 -> V=1.0, theta=0.0
% INFO    : Bus 4717	: V=0.9952095, theta=-63.319085 -> V=1.0, theta=0.0
% INFO    : Bus 4718	: V=0.9889269, theta=-63.381523 -> V=1.0, theta=0.0
% INFO    : Bus 4719	: V=0.9864859, theta=-64.962483 -> V=1.0, theta=0.0
% INFO    : Bus 4720	: V=0.986592, theta=-64.955716 -> V=1.0, theta=0.0
% INFO    : Bus 4721	: V=0.9948544, theta=-63.345513 -> V=1.0, theta=0.0
% INFO    : Bus 4722	: V=0.986382, theta=-64.965249 -> V=1.0, theta=0.0
% INFO    : Bus 4723	: V=0.9945155, theta=-63.371855 -> V=1.0, theta=0.0
% INFO    : Bus 4724	: V=0.9901408, theta=-64.261507 -> V=1.0, theta=0.0
% INFO    : Bus 4725	: V=0.9896095, theta=-64.310053 -> V=1.0, theta=0.0
% INFO    : Bus 4726	: V=0.9899853, theta=-64.296331 -> V=1.0, theta=0.0
% INFO    : Bus 4727	: V=1.0046081, theta=-60.997601 -> V=1.0, theta=0.0
% INFO    : Bus 4728	: V=0.9880403, theta=-63.379657 -> V=1.0, theta=0.0
% INFO    : Bus 4729	: V=0.9963647, theta=-63.216014 -> V=1.0, theta=0.0
% INFO    : Bus 4730	: V=0.9880307, theta=-63.31316 -> V=1.0, theta=0.0
% INFO    : Bus 4731	: V=0.9905558, theta=-64.299651 -> V=1.0, theta=0.0
% INFO    : Bus 4732	: V=0.9910322, theta=-64.094359 -> V=1.0, theta=0.0
% INFO    : Bus 4733	: V=0.983413, theta=-64.352257 -> V=1.0, theta=0.0
% INFO    : Bus 4734	: V=0.9943362, theta=-63.314941 -> V=1.0, theta=0.0
% INFO    : Bus 4735	: V=0.989737, theta=-64.19259 -> V=1.0, theta=0.0
% INFO    : Bus 4736	: V=0.9831111, theta=-64.35026 -> V=1.0, theta=0.0
% INFO    : Bus 4737	: V=0.9897886, theta=-64.199085 -> V=1.0, theta=0.0
% INFO    : Bus 4738	: V=0.9832034, theta=-64.350187 -> V=1.0, theta=0.0
% INFO    : Bus 4739	: V=0.989953, theta=-64.242571 -> V=1.0, theta=0.0
% INFO    : Bus 4740	: V=0.9831518, theta=-64.351584 -> V=1.0, theta=0.0
% INFO    : Bus 4741	: V=0.9931013, theta=-63.402656 -> V=1.0, theta=0.0
% INFO    : Bus 4742	: V=0.9899549, theta=-64.218468 -> V=1.0, theta=0.0
% INFO    : Bus 4743	: V=0.9904475, theta=-64.247554 -> V=1.0, theta=0.0
% INFO    : Bus 4744	: V=0.9830784, theta=-64.353533 -> V=1.0, theta=0.0
% INFO    : Bus 4745	: V=0.9942826, theta=-63.389338 -> V=1.0, theta=0.0
% INFO    : Bus 4746	: V=0.9833092, theta=-64.330218 -> V=1.0, theta=0.0
% INFO    : Bus 4747	: V=0.988171, theta=-64.268626 -> V=1.0, theta=0.0
% INFO    : Bus 4748	: V=0.9883837, theta=-64.263832 -> V=1.0, theta=0.0
% INFO    : Bus 4749	: V=0.9832995, theta=-64.322289 -> V=1.0, theta=0.0
% INFO    : Bus 4750	: V=0.9879529, theta=-64.300513 -> V=1.0, theta=0.0
% INFO    : Bus 4751	: V=0.9833165, theta=-64.314597 -> V=1.0, theta=0.0
% INFO    : Bus 4752	: V=0.9832295, theta=-64.31694 -> V=1.0, theta=0.0
% INFO    : Bus 4753	: V=0.9925895, theta=-63.343635 -> V=1.0, theta=0.0
% INFO    : Bus 4754	: V=0.9832681, theta=-64.294474 -> V=1.0, theta=0.0
% INFO    : Bus 4755	: V=0.9831872, theta=-64.296658 -> V=1.0, theta=0.0
% INFO    : Bus 4756	: V=0.9828766, theta=-64.310969 -> V=1.0, theta=0.0
% INFO    : Bus 4757	: V=0.985984, theta=-63.429942 -> V=1.0, theta=0.0
% INFO    : Bus 4758	: V=0.9878471, theta=-64.297991 -> V=1.0, theta=0.0
% INFO    : Bus 4759	: V=0.9833942, theta=-64.304873 -> V=1.0, theta=0.0
% INFO    : Bus 4760	: V=0.983369, theta=-64.317977 -> V=1.0, theta=0.0
% INFO    : Bus 4761	: V=0.9878436, theta=-64.306182 -> V=1.0, theta=0.0
% INFO    : Bus 4762	: V=0.9833598, theta=-64.335445 -> V=1.0, theta=0.0
% INFO    : Bus 4763	: V=0.9877686, theta=-64.306655 -> V=1.0, theta=0.0
% INFO    : Bus 4764	: V=0.9834027, theta=-64.341444 -> V=1.0, theta=0.0
% INFO    : Bus 4765	: V=0.988232, theta=-64.283665 -> V=1.0, theta=0.0
% INFO    : Bus 4766	: V=0.9880333, theta=-63.265815 -> V=1.0, theta=0.0
% INFO    : Bus 4767	: V=0.9902021, theta=-64.281388 -> V=1.0, theta=0.0
% INFO    : Bus 4768	: V=0.9834791, theta=-64.350881 -> V=1.0, theta=0.0
% INFO    : Bus 4769	: V=0.9896998, theta=-64.186896 -> V=1.0, theta=0.0
% INFO    : Bus 4770	: V=0.9833625, theta=-64.360398 -> V=1.0, theta=0.0
% INFO    : Bus 4771	: V=0.9836946, theta=-64.3325 -> V=1.0, theta=0.0
% INFO    : Bus 4772	: V=0.9898847, theta=-64.289822 -> V=1.0, theta=0.0
% INFO    : Bus 4773	: V=0.9838461, theta=-64.311809 -> V=1.0, theta=0.0
% INFO    : Bus 4774	: V=0.987679, theta=-64.299604 -> V=1.0, theta=0.0
% INFO    : Bus 4775	: V=0.9878738, theta=-63.456093 -> V=1.0, theta=0.0
% INFO    : Bus 4776	: V=0.9881352, theta=-63.440064 -> V=1.0, theta=0.0
% INFO    : Bus 4777	: V=0.9867855, theta=-63.743823 -> V=1.0, theta=0.0
% INFO    : Bus 4778	: V=0.988874, theta=-63.392352 -> V=1.0, theta=0.0
% INFO    : Bus 4779	: V=0.9880329, theta=-64.259624 -> V=1.0, theta=0.0
% INFO    : Bus 4780	: V=0.9867144, theta=-63.747332 -> V=1.0, theta=0.0
% INFO    : Bus 4781	: V=0.9876511, theta=-63.480909 -> V=1.0, theta=0.0
% INFO    : Bus 4782	: V=0.987343, theta=-63.535369 -> V=1.0, theta=0.0
% INFO    : Bus 4783	: V=0.9840107, theta=-64.24964 -> V=1.0, theta=0.0
% INFO    : Bus 4784	: V=0.9840162, theta=-64.249917 -> V=1.0, theta=0.0
% INFO    : Bus 4785	: V=0.9863146, theta=-63.767217 -> V=1.0, theta=0.0
% INFO    : Bus 4786	: V=0.9875261, theta=-63.538669 -> V=1.0, theta=0.0
% INFO    : Bus 4787	: V=0.9872735, theta=-63.603682 -> V=1.0, theta=0.0
% INFO    : Bus 4788	: V=0.9874702, theta=-64.159747 -> V=1.0, theta=0.0
% INFO    : Bus 4789	: V=0.9832129, theta=-64.414897 -> V=1.0, theta=0.0
% INFO    : Bus 4790	: V=0.9831629, theta=-64.435013 -> V=1.0, theta=0.0
% INFO    : Bus 4791	: V=0.9869643, theta=-63.688688 -> V=1.0, theta=0.0
% INFO    : Bus 4792	: V=0.9867823, theta=-63.73975 -> V=1.0, theta=0.0
% INFO    : Bus 4793	: V=0.9870226, theta=-63.591414 -> V=1.0, theta=0.0
% INFO    : Bus 4794	: V=0.9806666, theta=-64.991817 -> V=1.0, theta=0.0
% INFO    : Bus 4795	: V=0.9865575, theta=-63.805302 -> V=1.0, theta=0.0
% INFO    : Bus 4796	: V=0.9831882, theta=-64.433773 -> V=1.0, theta=0.0
% INFO    : Bus 4797	: V=0.9877568, theta=-64.222267 -> V=1.0, theta=0.0
% INFO    : Bus 4798	: V=0.9821116, theta=-64.635183 -> V=1.0, theta=0.0
% INFO    : Bus 4799	: V=0.9878647, theta=-64.276218 -> V=1.0, theta=0.0
% INFO    : Bus 4800	: V=0.9821791, theta=-64.63362 -> V=1.0, theta=0.0
% INFO    : Bus 4801	: V=0.9878039, theta=-64.251035 -> V=1.0, theta=0.0
% INFO    : Bus 4802	: V=0.983072, theta=-64.429791 -> V=1.0, theta=0.0
% INFO    : Bus 4803	: V=0.9831436, theta=-64.385497 -> V=1.0, theta=0.0
% INFO    : Bus 4804	: V=0.9900385, theta=-64.177923 -> V=1.0, theta=0.0
% INFO    : Bus 4805	: V=0.9819299, theta=-64.69102 -> V=1.0, theta=0.0
% INFO    : Bus 4806	: V=0.9926294, theta=-63.428904 -> V=1.0, theta=0.0
% INFO    : Bus 4807	: V=0.9899767, theta=-63.945578 -> V=1.0, theta=0.0
% INFO    : Bus 4808	: V=0.9832415, theta=-64.368947 -> V=1.0, theta=0.0
% INFO    : Bus 4809	: V=0.9921251, theta=-63.455381 -> V=1.0, theta=0.0
% INFO    : Bus 4810	: V=0.9815716, theta=-64.77538 -> V=1.0, theta=0.0
% INFO    : Bus 4811	: V=0.9918167, theta=-63.46988 -> V=1.0, theta=0.0
% INFO    : Bus 4812	: V=0.9830928, theta=-64.376094 -> V=1.0, theta=0.0
% INFO    : Bus 4813	: V=0.9915491, theta=-63.479233 -> V=1.0, theta=0.0
% INFO    : Bus 4814	: V=0.9830139, theta=-64.375092 -> V=1.0, theta=0.0
% INFO    : Bus 4815	: V=0.9912883, theta=-63.487837 -> V=1.0, theta=0.0
% INFO    : Bus 4816	: V=0.9828206, theta=-64.379042 -> V=1.0, theta=0.0
% INFO    : Bus 4817	: V=0.9879193, theta=-64.129287 -> V=1.0, theta=0.0
% INFO    : Bus 4818	: V=0.9829218, theta=-64.358045 -> V=1.0, theta=0.0
% INFO    : Bus 4819	: V=0.9878146, theta=-64.141339 -> V=1.0, theta=0.0
% INFO    : Bus 4820	: V=0.9830483, theta=-64.355006 -> V=1.0, theta=0.0
% INFO    : Bus 4821	: V=0.9877501, theta=-64.14782 -> V=1.0, theta=0.0
% INFO    : Bus 4822	: V=0.9875748, theta=-64.152428 -> V=1.0, theta=0.0
% INFO    : Bus 4823	: V=0.9876332, theta=-64.150964 -> V=1.0, theta=0.0
% INFO    : Bus 4824	: V=0.9805684, theta=-64.898425 -> V=1.0, theta=0.0
% INFO    : Bus 4825	: V=0.9894553, theta=-63.760105 -> V=1.0, theta=0.0
% INFO    : Bus 4826	: V=0.9805965, theta=-64.897746 -> V=1.0, theta=0.0
% INFO    : Bus 4827	: V=0.9862518, theta=-64.511914 -> V=1.0, theta=0.0
% INFO    : Bus 4828	: V=0.9829689, theta=-64.321771 -> V=1.0, theta=0.0
% INFO    : Bus 4829	: V=0.9908229, theta=-63.57892 -> V=1.0, theta=0.0
% INFO    : Bus 4830	: V=0.9845819, theta=-63.697484 -> V=1.0, theta=0.0
% INFO    : Bus 4831	: V=0.9910113, theta=-63.572987 -> V=1.0, theta=0.0
% INFO    : Bus 4832	: V=0.9912105, theta=-63.565775 -> V=1.0, theta=0.0
% INFO    : Bus 4833	: V=0.9914831, theta=-63.552716 -> V=1.0, theta=0.0
% INFO    : Bus 4834	: V=0.9855423, theta=-63.51743 -> V=1.0, theta=0.0
% INFO    : Bus 4835	: V=0.9919232, theta=-63.528336 -> V=1.0, theta=0.0
% INFO    : Bus 4836	: V=0.9830509, theta=-64.306685 -> V=1.0, theta=0.0
% INFO    : Bus 4837	: V=0.9895506, theta=-64.21219 -> V=1.0, theta=0.0
% INFO    : Bus 4838	: V=0.9830017, theta=-64.307954 -> V=1.0, theta=0.0
% INFO    : Bus 4839	: V=0.9876938, theta=-64.241325 -> V=1.0, theta=0.0
% INFO    : Bus 4840	: V=0.9828466, theta=-64.360078 -> V=1.0, theta=0.0
% INFO    : Bus 4841	: V=0.9859993, theta=-64.520966 -> V=1.0, theta=0.0
% INFO    : Bus 4842	: V=0.9823925, theta=-64.130292 -> V=1.0, theta=0.0
% INFO    : Bus 4843	: V=0.9861119, theta=-64.414612 -> V=1.0, theta=0.0
% INFO    : Bus 4844	: V=0.9808805, theta=-64.828668 -> V=1.0, theta=0.0
% INFO    : Bus 4845	: V=0.9858023, theta=-64.421793 -> V=1.0, theta=0.0
% INFO    : Bus 4846	: V=0.983931, theta=-63.822172 -> V=1.0, theta=0.0
% INFO    : Bus 4847	: V=0.9808502, theta=-64.400272 -> V=1.0, theta=0.0
% INFO    : Bus 4848	: V=0.987135, theta=-64.16877 -> V=1.0, theta=0.0
% INFO    : Bus 4849	: V=0.9808978, theta=-64.399117 -> V=1.0, theta=0.0
% INFO    : Bus 4850	: V=0.987445, theta=-64.247434 -> V=1.0, theta=0.0
% INFO    : Bus 4851	: V=0.9834844, theta=-63.914881 -> V=1.0, theta=0.0
% INFO    : Bus 4852	: V=0.989502, theta=-64.208449 -> V=1.0, theta=0.0
% INFO    : Bus 4853	: V=0.9836957, theta=-63.871172 -> V=1.0, theta=0.0
% INFO    : Bus 4854	: V=0.9919024, theta=-64.05784 -> V=1.0, theta=0.0
% INFO    : Bus 4855	: V=0.9798187, theta=-65.142555 -> V=1.0, theta=0.0
% INFO    : Bus 4856	: V=0.9918848, theta=-64.26946 -> V=1.0, theta=0.0
% INFO    : Bus 4857	: V=0.9797105, theta=-65.145511 -> V=1.0, theta=0.0
% INFO    : Bus 4858	: V=0.9949755, theta=-63.285915 -> V=1.0, theta=0.0
% INFO    : Bus 4859	: V=0.9801191, theta=-64.964116 -> V=1.0, theta=0.0
% INFO    : Bus 4860	: V=0.9919982, theta=-64.266723 -> V=1.0, theta=0.0
% INFO    : Bus 4861	: V=0.9801795, theta=-64.962474 -> V=1.0, theta=0.0
% INFO    : Bus 4862	: V=0.9797078, theta=-65.199727 -> V=1.0, theta=0.0
% INFO    : Bus 4863	: V=0.9917021, theta=-64.314754 -> V=1.0, theta=0.0
% INFO    : Bus 4864	: V=0.9805058, theta=-64.98103 -> V=1.0, theta=0.0
% INFO    : Bus 4865	: V=0.9945754, theta=-63.949678 -> V=1.0, theta=0.0
% INFO    : Bus 4866	: V=0.980594, theta=-64.963786 -> V=1.0, theta=0.0
% INFO    : Bus 4867	: V=0.993847, theta=-63.38592 -> V=1.0, theta=0.0
% INFO    : Bus 4868	: V=0.9807307, theta=-64.938618 -> V=1.0, theta=0.0
% INFO    : Bus 4869	: V=0.9932639, theta=-63.433211 -> V=1.0, theta=0.0
% INFO    : Bus 4870	: V=0.9803629, theta=-64.957479 -> V=1.0, theta=0.0
% INFO    : Bus 4871	: V=0.9927102, theta=-63.473959 -> V=1.0, theta=0.0
% INFO    : Bus 4872	: V=0.9805674, theta=-64.935988 -> V=1.0, theta=0.0
% INFO    : Bus 4873	: V=0.989803, theta=-64.229491 -> V=1.0, theta=0.0
% INFO    : Bus 4874	: V=0.9807805, theta=-64.90765 -> V=1.0, theta=0.0
% INFO    : Bus 4875	: V=0.9896552, theta=-64.232896 -> V=1.0, theta=0.0
% INFO    : Bus 4876	: V=0.9810076, theta=-64.87792 -> V=1.0, theta=0.0
% INFO    : Bus 4877	: V=0.989444, theta=-64.254756 -> V=1.0, theta=0.0
% INFO    : Bus 4878	: V=0.9812539, theta=-64.848977 -> V=1.0, theta=0.0
% INFO    : Bus 4879	: V=0.9894408, theta=-64.254998 -> V=1.0, theta=0.0
% INFO    : Bus 4880	: V=0.9809424, theta=-64.901047 -> V=1.0, theta=0.0
% INFO    : Bus 4881	: V=0.9810112, theta=-64.899213 -> V=1.0, theta=0.0
% INFO    : Bus 4882	: V=0.9954403, theta=-63.23631 -> V=1.0, theta=0.0
% INFO    : Bus 4883	: V=0.9808125, theta=-64.928707 -> V=1.0, theta=0.0
% INFO    : Bus 4884	: V=0.9887074, theta=-64.461839 -> V=1.0, theta=0.0
% INFO    : Bus 4885	: V=0.9806043, theta=-64.96557 -> V=1.0, theta=0.0
% INFO    : Bus 4886	: V=0.989337, theta=-64.270154 -> V=1.0, theta=0.0
% INFO    : Bus 4887	: V=0.9804286, theta=-64.998424 -> V=1.0, theta=0.0
% INFO    : Bus 4888	: V=0.9896409, theta=-64.384241 -> V=1.0, theta=0.0
% INFO    : Bus 4889	: V=0.980374, theta=-65.025512 -> V=1.0, theta=0.0
% INFO    : Bus 4890	: V=0.9776983, theta=-66.089553 -> V=1.0, theta=0.0
% INFO    : Bus 4891	: V=0.9805246, theta=-65.015662 -> V=1.0, theta=0.0
% INFO    : Bus 4892	: V=0.9876897, theta=-64.866515 -> V=1.0, theta=0.0
% INFO    : Bus 4893	: V=0.9841852, theta=-64.138626 -> V=1.0, theta=0.0
% INFO    : Bus 4894	: V=0.9867255, theta=-63.642657 -> V=1.0, theta=0.0
% INFO    : Bus 4895	: V=0.9865158, theta=-63.678941 -> V=1.0, theta=0.0
% INFO    : Bus 4896	: V=0.9915542, theta=-64.227604 -> V=1.0, theta=0.0
% INFO    : Bus 4897	: V=0.9862396, theta=-63.72521 -> V=1.0, theta=0.0
% INFO    : Bus 4898	: V=0.9899837, theta=-64.231646 -> V=1.0, theta=0.0
% INFO    : Bus 4899	: V=0.9805711, theta=-65.274042 -> V=1.0, theta=0.0
% INFO    : Bus 4900	: V=0.9899592, theta=-64.221368 -> V=1.0, theta=0.0
% INFO    : Bus 4901	: V=0.9805447, theta=-65.250043 -> V=1.0, theta=0.0
% INFO    : Bus 4902	: V=0.9936554, theta=-64.03137 -> V=1.0, theta=0.0
% INFO    : Bus 4903	: V=0.9852346, theta=-64.099287 -> V=1.0, theta=0.0
% INFO    : Bus 4904	: V=0.9908075, theta=-64.699314 -> V=1.0, theta=0.0
% INFO    : Bus 4905	: V=0.9802545, theta=-65.232014 -> V=1.0, theta=0.0
% INFO    : Bus 4906	: V=0.9801476, theta=-65.227446 -> V=1.0, theta=0.0
% INFO    : Bus 4907	: V=0.9800674, theta=-65.217339 -> V=1.0, theta=0.0
% INFO    : Bus 4908	: V=0.9947004, theta=-63.945986 -> V=1.0, theta=0.0
% INFO    : Bus 4909	: V=0.9799852, theta=-65.198358 -> V=1.0, theta=0.0
% INFO    : Bus 4910	: V=0.9940949, theta=-63.996117 -> V=1.0, theta=0.0
% INFO    : Bus 4911	: V=0.9791434, theta=-65.305842 -> V=1.0, theta=0.0
% INFO    : Bus 4912	: V=0.9830705, theta=-65.442789 -> V=1.0, theta=0.0
% INFO    : Bus 4913	: V=0.9784161, theta=-65.443214 -> V=1.0, theta=0.0
% INFO    : Bus 4914	: V=0.9797095, theta=-65.90743 -> V=1.0, theta=0.0
% INFO    : Bus 4915	: V=0.979256, theta=-65.303038 -> V=1.0, theta=0.0
% INFO    : Bus 4916	: V=0.9827749, theta=-65.468197 -> V=1.0, theta=0.0
% INFO    : Bus 4917	: V=0.9799411, theta=-65.17992 -> V=1.0, theta=0.0
% INFO    : Bus 4918	: V=0.9924054, theta=-64.320409 -> V=1.0, theta=0.0
% INFO    : Bus 4919	: V=0.9790962, theta=-65.310151 -> V=1.0, theta=0.0
% INFO    : Bus 4920	: V=0.9908843, theta=-64.697232 -> V=1.0, theta=0.0
% INFO    : Bus 4921	: V=0.9784835, theta=-65.427546 -> V=1.0, theta=0.0
% INFO    : Bus 4922	: V=0.9849404, theta=-65.10692 -> V=1.0, theta=0.0
% INFO    : Bus 4923	: V=0.9785536, theta=-65.410647 -> V=1.0, theta=0.0
% INFO    : Bus 4924	: V=0.9844924, theta=-65.143775 -> V=1.0, theta=0.0
% INFO    : Bus 4925	: V=0.978633, theta=-65.390884 -> V=1.0, theta=0.0
% INFO    : Bus 4926	: V=0.9825275, theta=-65.155799 -> V=1.0, theta=0.0
% INFO    : Bus 4927	: V=0.9843453, theta=-65.15462 -> V=1.0, theta=0.0
% INFO    : Bus 4928	: V=0.9789796, theta=-65.31321 -> V=1.0, theta=0.0
% INFO    : Bus 4929	: V=0.9824958, theta=-65.159871 -> V=1.0, theta=0.0
% INFO    : Bus 4930	: V=0.9796215, theta=-65.201529 -> V=1.0, theta=0.0
% INFO    : Bus 4931	: V=0.9821448, theta=-65.507205 -> V=1.0, theta=0.0
% INFO    : Bus 4932	: V=0.9796137, theta=-65.209019 -> V=1.0, theta=0.0
% INFO    : Bus 4933	: V=0.9822863, theta=-65.502723 -> V=1.0, theta=0.0
% INFO    : Bus 4934	: V=0.9788074, theta=-65.359966 -> V=1.0, theta=0.0
% INFO    : Bus 4935	: V=0.982147, theta=-65.506487 -> V=1.0, theta=0.0
% INFO    : Bus 4936	: V=0.9789888, theta=-65.325128 -> V=1.0, theta=0.0
% INFO    : Bus 4937	: V=0.9790547, theta=-65.71663 -> V=1.0, theta=0.0
% INFO    : Bus 4938	: V=0.9791311, theta=-65.309135 -> V=1.0, theta=0.0
% INFO    : Bus 4939	: V=0.9813083, theta=-65.234749 -> V=1.0, theta=0.0
% INFO    : Bus 4940	: V=0.979198, theta=-65.267551 -> V=1.0, theta=0.0
% INFO    : Bus 4941	: V=0.9814489, theta=-65.226406 -> V=1.0, theta=0.0
% INFO    : Bus 4942	: V=0.9793261, theta=-65.26439 -> V=1.0, theta=0.0
% INFO    : Bus 4943	: V=0.9816455, theta=-65.215161 -> V=1.0, theta=0.0
% INFO    : Bus 4944	: V=0.9796528, theta=-65.206865 -> V=1.0, theta=0.0
% INFO    : Bus 4945	: V=0.9818644, theta=-65.200406 -> V=1.0, theta=0.0
% INFO    : Bus 4946	: V=0.9832475, theta=-63.96452 -> V=1.0, theta=0.0
% INFO    : Bus 4947	: V=0.9814543, theta=-65.53617 -> V=1.0, theta=0.0
% INFO    : Bus 4948	: V=0.9810697, theta=-64.394404 -> V=1.0, theta=0.0
% INFO    : Bus 4949	: V=0.9823046, theta=-65.166572 -> V=1.0, theta=0.0
% INFO    : Bus 4950	: V=0.9811093, theta=-64.393337 -> V=1.0, theta=0.0
% INFO    : Bus 4951	: V=0.9825375, theta=-65.148381 -> V=1.0, theta=0.0
% INFO    : Bus 4952	: V=0.9830865, theta=-63.994474 -> V=1.0, theta=0.0
% INFO    : Bus 4953	: V=0.9833731, theta=-65.076706 -> V=1.0, theta=0.0
% INFO    : Bus 4954	: V=0.9805567, theta=-65.606155 -> V=1.0, theta=0.0
% INFO    : Bus 4955	: V=0.9832534, theta=-63.95643 -> V=1.0, theta=0.0
% INFO    : Bus 4956	: V=0.9832293, theta=-65.088001 -> V=1.0, theta=0.0
% INFO    : Bus 4957	: V=0.9829313, theta=-64.023173 -> V=1.0, theta=0.0
% INFO    : Bus 4958	: V=0.9807702, theta=-65.610352 -> V=1.0, theta=0.0
% INFO    : Bus 4959	: V=0.982784, theta=-64.05048 -> V=1.0, theta=0.0
% INFO    : Bus 4960	: V=0.9805247, theta=-65.638741 -> V=1.0, theta=0.0
% INFO    : Bus 4961	: V=0.9812026, theta=-64.384344 -> V=1.0, theta=0.0
% INFO    : Bus 4962	: V=0.9802438, theta=-65.663487 -> V=1.0, theta=0.0
% INFO    : Bus 4963	: V=0.9810266, theta=-64.389092 -> V=1.0, theta=0.0
% INFO    : Bus 4964	: V=0.9799378, theta=-65.683856 -> V=1.0, theta=0.0
% INFO    : Bus 4965	: V=0.9825438, theta=-64.093773 -> V=1.0, theta=0.0
% INFO    : Bus 4966	: V=0.9795602, theta=-65.697902 -> V=1.0, theta=0.0
% INFO    : Bus 4967	: V=0.9786647, theta=-65.355395 -> V=1.0, theta=0.0
% INFO    : Bus 4968	: V=0.9786015, theta=-65.781598 -> V=1.0, theta=0.0
% INFO    : Bus 4969	: V=0.9788779, theta=-65.304322 -> V=1.0, theta=0.0
% INFO    : Bus 4970	: V=0.9752903, theta=-66.551996 -> V=1.0, theta=0.0
% INFO    : Bus 4971	: V=0.9820138, theta=-64.189806 -> V=1.0, theta=0.0
% INFO    : Bus 4972	: V=0.9751462, theta=-66.563775 -> V=1.0, theta=0.0
% INFO    : Bus 4973	: V=0.9816862, theta=-64.251851 -> V=1.0, theta=0.0
% INFO    : Bus 4974	: V=0.9906044, theta=-64.304705 -> V=1.0, theta=0.0
% INFO    : Bus 4975	: V=0.9718196, theta=-66.416117 -> V=1.0, theta=0.0
% INFO    : Bus 4976	: V=0.9782916, theta=-65.816619 -> V=1.0, theta=0.0
% INFO    : Bus 4977	: V=0.9805374, theta=-64.469555 -> V=1.0, theta=0.0
% INFO    : Bus 4978	: V=0.9791971, theta=-65.708828 -> V=1.0, theta=0.0
% INFO    : Bus 4979	: V=0.9811772, theta=-65.240919 -> V=1.0, theta=0.0
% INFO    : Bus 4980	: V=0.9772539, theta=-66.1299 -> V=1.0, theta=0.0
% INFO    : Bus 4981	: V=0.9717337, theta=-66.412112 -> V=1.0, theta=0.0
% INFO    : Bus 4982	: V=0.9796502, theta=-65.911902 -> V=1.0, theta=0.0
% INFO    : Bus 4983	: V=0.9796087, theta=-65.914013 -> V=1.0, theta=0.0
% INFO    : Bus 4984	: V=0.9779673, theta=-66.082329 -> V=1.0, theta=0.0
% INFO    : Bus 4985	: V=0.9785947, theta=-66.033668 -> V=1.0, theta=0.0
% INFO    : Bus 4986	: V=0.978924, theta=-66.012109 -> V=1.0, theta=0.0
% INFO    : Bus 4987	: V=0.9792179, theta=-65.976969 -> V=1.0, theta=0.0
% INFO    : Bus 4988	: V=0.988253, theta=-64.499428 -> V=1.0, theta=0.0
% INFO    : Bus 4989	: V=0.9710609, theta=-66.55828 -> V=1.0, theta=0.0
% INFO    : Bus 4990	: V=0.9855102, theta=-64.600217 -> V=1.0, theta=0.0
% INFO    : Bus 4991	: V=0.9699758, theta=-66.657448 -> V=1.0, theta=0.0
% INFO    : Bus 4992	: V=0.9788043, theta=-66.009245 -> V=1.0, theta=0.0
% INFO    : Bus 4993	: V=0.9697962, theta=-66.668587 -> V=1.0, theta=0.0
% INFO    : Bus 4994	: V=0.9806401, theta=-65.243941 -> V=1.0, theta=0.0
% INFO    : Bus 4995	: V=0.9806786, theta=-65.246228 -> V=1.0, theta=0.0
% INFO    : Bus 4996	: V=0.9780335, theta=-65.804916 -> V=1.0, theta=0.0
% INFO    : Bus 4997	: V=0.9696568, theta=-66.6662 -> V=1.0, theta=0.0
% INFO    : Bus 4998	: V=0.9807869, theta=-65.248873 -> V=1.0, theta=0.0
% INFO    : Bus 4999	: V=0.980865, theta=-65.248181 -> V=1.0, theta=0.0
% INFO    : Bus 5000	: V=0.9699959, theta=-66.655304 -> V=1.0, theta=0.0
% INFO    : Bus 5001	: V=0.9774059, theta=-66.120595 -> V=1.0, theta=0.0
% INFO    : Bus 5002	: V=0.9701598, theta=-66.65083 -> V=1.0, theta=0.0
% INFO    : Bus 5003	: V=0.976838, theta=-66.170312 -> V=1.0, theta=0.0
% INFO    : Bus 5004	: V=0.9765592, theta=-66.202695 -> V=1.0, theta=0.0
% INFO    : Bus 5005	: V=0.9779379, theta=-65.855467 -> V=1.0, theta=0.0
% INFO    : Bus 5006	: V=0.9800471, theta=-64.517055 -> V=1.0, theta=0.0
% INFO    : Bus 5007	: V=0.9760614, theta=-66.249805 -> V=1.0, theta=0.0
% INFO    : Bus 5008	: V=0.9715398, theta=-66.467458 -> V=1.0, theta=0.0
% INFO    : Bus 5009	: V=0.9774446, theta=-65.911127 -> V=1.0, theta=0.0
% INFO    : Bus 5010	: V=0.9714522, theta=-66.469648 -> V=1.0, theta=0.0
% INFO    : Bus 5011	: V=0.976292, theta=-66.231568 -> V=1.0, theta=0.0
% INFO    : Bus 5012	: V=0.9799215, theta=-64.537404 -> V=1.0, theta=0.0
% INFO    : Bus 5013	: V=0.9771227, theta=-65.946909 -> V=1.0, theta=0.0
% INFO    : Bus 5014	: V=0.9713019, theta=-66.473348 -> V=1.0, theta=0.0
% INFO    : Bus 5015	: V=0.9710048, theta=-66.540432 -> V=1.0, theta=0.0
% INFO    : Bus 5016	: V=0.9759281, theta=-66.253461 -> V=1.0, theta=0.0
% INFO    : Bus 5017	: V=0.9758768, theta=-66.274484 -> V=1.0, theta=0.0
% INFO    : Bus 5018	: V=0.9703924, theta=-66.63089 -> V=1.0, theta=0.0
% INFO    : Bus 5019	: V=0.9703144, theta=-66.660266 -> V=1.0, theta=0.0
% INFO    : Bus 5020	: V=0.9757886, theta=-66.276629 -> V=1.0, theta=0.0
% INFO    : Bus 5021	: V=0.9705132, theta=-66.628326 -> V=1.0, theta=0.0
% INFO    : Bus 5022	: V=0.9748906, theta=-66.570501 -> V=1.0, theta=0.0
% INFO    : Bus 5023	: V=0.9704348, theta=-66.630374 -> V=1.0, theta=0.0
% INFO    : Bus 5024	: V=0.974842, theta=-66.602632 -> V=1.0, theta=0.0
% INFO    : Bus 5025	: V=0.974601, theta=-66.627921 -> V=1.0, theta=0.0
% INFO    : Bus 5026	: V=0.9708281, theta=-66.609598 -> V=1.0, theta=0.0
% INFO    : Bus 5027	: V=0.9748903, theta=-66.611403 -> V=1.0, theta=0.0
% INFO    : Bus 5028	: V=0.977668, theta=-65.943379 -> V=1.0, theta=0.0
% INFO    : Bus 5029	: V=0.9712299, theta=-66.549555 -> V=1.0, theta=0.0
% INFO    : Bus 5030	: V=0.975579, theta=-66.50331 -> V=1.0, theta=0.0
% INFO    : Bus 5031	: V=0.9757677, theta=-66.498135 -> V=1.0, theta=0.0
% INFO    : Bus 5032	: V=0.9714677, theta=-66.520048 -> V=1.0, theta=0.0
% INFO    : Bus 5033	: V=0.9717407, theta=-66.486889 -> V=1.0, theta=0.0
% INFO    : Bus 5034	: V=0.9757404, theta=-66.503198 -> V=1.0, theta=0.0
% INFO    : Bus 5035	: V=0.9756802, theta=-66.51872 -> V=1.0, theta=0.0
% INFO    : Bus 5036	: V=0.9755716, theta=-66.525774 -> V=1.0, theta=0.0
% INFO    : Bus 5037	: V=0.9789668, theta=-65.740377 -> V=1.0, theta=0.0
% INFO    : Bus 5038	: V=0.9719406, theta=-66.412757 -> V=1.0, theta=0.0
% INFO    : Bus 5039	: V=0.9794576, theta=-65.684899 -> V=1.0, theta=0.0
% INFO    : Bus 5040	: V=0.9798761, theta=-65.638197 -> V=1.0, theta=0.0
% INFO    : Bus 5041	: V=0.9718455, theta=-66.45795 -> V=1.0, theta=0.0
% INFO    : Bus 5042	: V=0.9803343, theta=-65.587167 -> V=1.0, theta=0.0
% INFO    : Bus 5043	: V=0.9715848, theta=-66.506908 -> V=1.0, theta=0.0
% INFO    : Bus 5044	: V=0.9830235, theta=-65.100044 -> V=1.0, theta=0.0
% INFO    : Bus 5045	: V=0.9714173, theta=-66.539716 -> V=1.0, theta=0.0
% INFO    : Bus 5046	: V=0.9813148, theta=-65.4448 -> V=1.0, theta=0.0
% INFO    : Bus 5047	: V=0.9713011, theta=-66.562015 -> V=1.0, theta=0.0
% INFO    : Bus 5048	: V=0.9791773, theta=-65.931512 -> V=1.0, theta=0.0
% INFO    : Bus 5049	: V=0.9715897, theta=-66.53132 -> V=1.0, theta=0.0
% INFO    : Bus 5050	: V=0.9808239, theta=-65.531718 -> V=1.0, theta=0.0
% INFO    : Bus 5051	: V=0.972438, theta=-66.388352 -> V=1.0, theta=0.0
% INFO    : Bus 5052	: V=0.9758211, theta=-66.500995 -> V=1.0, theta=0.0
% INFO    : Bus 5053	: V=0.9724231, theta=-66.388735 -> V=1.0, theta=0.0
% INFO    : Bus 5054	: V=0.9759706, theta=-66.497074 -> V=1.0, theta=0.0
% INFO    : Bus 5055	: V=0.9725538, theta=-66.385137 -> V=1.0, theta=0.0
% INFO    : Bus 5056	: V=0.9759953, theta=-66.488124 -> V=1.0, theta=0.0
% INFO    : Bus 5057	: V=0.9783349, theta=-65.363432 -> V=1.0, theta=0.0
% INFO    : Bus 5058	: V=0.9752678, theta=-66.533894 -> V=1.0, theta=0.0
% INFO    : Bus 5059	: V=0.9785811, theta=-65.357637 -> V=1.0, theta=0.0
% INFO    : Bus 5060	: V=0.9780868, theta=-65.909318 -> V=1.0, theta=0.0
% INFO    : Bus 5061	: V=0.9779936, theta=-65.420519 -> V=1.0, theta=0.0
% INFO    : Bus 5062	: V=0.9747443, theta=-66.640975 -> V=1.0, theta=0.0
% INFO    : Bus 5063	: V=0.9780817, theta=-65.418218 -> V=1.0, theta=0.0
% INFO    : Bus 5064	: V=0.9779922, theta=-66.139517 -> V=1.0, theta=0.0
% INFO    : Bus 5065	: V=0.9780283, theta=-65.419334 -> V=1.0, theta=0.0
% INFO    : Bus 5066	: V=0.9788386, theta=-65.829493 -> V=1.0, theta=0.0
% INFO    : Bus 5067	: V=0.9729807, theta=-66.348941 -> V=1.0, theta=0.0
% INFO    : Bus 5068	: V=0.9786914, theta=-65.971378 -> V=1.0, theta=0.0
% INFO    : Bus 5069	: V=0.9729029, theta=-66.351068 -> V=1.0, theta=0.0
% INFO    : Bus 5070	: V=0.972012, theta=-66.482059 -> V=1.0, theta=0.0
% INFO    : Bus 5071	: V=0.9787847, theta=-65.963408 -> V=1.0, theta=0.0
% INFO    : Bus 5072	: V=0.9722914, theta=-66.438518 -> V=1.0, theta=0.0
% INFO    : Bus 5073	: V=0.9789086, theta=-65.950669 -> V=1.0, theta=0.0
% INFO    : Bus 5074	: V=0.9723732, theta=-66.436266 -> V=1.0, theta=0.0
% INFO    : Bus 5075	: V=0.9813794, theta=-65.468399 -> V=1.0, theta=0.0
% INFO    : Bus 5076	: V=0.9726239, theta=-66.401508 -> V=1.0, theta=0.0
% INFO    : Bus 5077	: V=0.9816193, theta=-65.439004 -> V=1.0, theta=0.0
% INFO    : Bus 5078	: V=0.9727404, theta=-66.393152 -> V=1.0, theta=0.0
% INFO    : Bus 5079	: V=0.9818736, theta=-65.409881 -> V=1.0, theta=0.0
% INFO    : Bus 5080	: V=0.9819752, theta=-64.373157 -> V=1.0, theta=0.0
% INFO    : Bus 5081	: V=0.9788128, theta=-66.066907 -> V=1.0, theta=0.0
% INFO    : Bus 5082	: V=0.9784242, theta=-65.405545 -> V=1.0, theta=0.0
% INFO    : Bus 5083	: V=0.9822851, theta=-65.357225 -> V=1.0, theta=0.0
% INFO    : Bus 5084	: V=0.9786501, theta=-65.389988 -> V=1.0, theta=0.0
% INFO    : Bus 5085	: V=0.9787206, theta=-66.069657 -> V=1.0, theta=0.0
% INFO    : Bus 5086	: V=0.9823952, theta=-64.323043 -> V=1.0, theta=0.0
% INFO    : Bus 5087	: V=0.98171, theta=-65.427863 -> V=1.0, theta=0.0
% INFO    : Bus 5088	: V=0.9782065, theta=-65.442539 -> V=1.0, theta=0.0
% INFO    : Bus 5089	: V=0.9765294, theta=-66.434954 -> V=1.0, theta=0.0
% INFO    : Bus 5090	: V=0.978096, theta=-65.445526 -> V=1.0, theta=0.0
% INFO    : Bus 5091	: V=0.9763118, theta=-66.440826 -> V=1.0, theta=0.0
% INFO    : Bus 5092	: V=0.9770377, theta=-65.625803 -> V=1.0, theta=0.0
% INFO    : Bus 5093	: V=0.9795309, theta=-65.757651 -> V=1.0, theta=0.0
% INFO    : Bus 5094	: V=0.9754808, theta=-65.877925 -> V=1.0, theta=0.0
% INFO    : Bus 5095	: V=0.98014, theta=-65.69104 -> V=1.0, theta=0.0
% INFO    : Bus 5096	: V=0.9755889, theta=-65.875003 -> V=1.0, theta=0.0
% INFO    : Bus 5097	: V=0.9805131, theta=-65.743261 -> V=1.0, theta=0.0
% INFO    : Bus 5098	: V=0.9728981, theta=-66.36705 -> V=1.0, theta=0.0
% INFO    : Bus 5099	: V=0.982183, theta=-65.375169 -> V=1.0, theta=0.0
% INFO    : Bus 5100	: V=0.9750113, theta=-65.98111 -> V=1.0, theta=0.0
% INFO    : Bus 5101	: V=0.98251, theta=-65.326754 -> V=1.0, theta=0.0
% INFO    : Bus 5102	: V=0.9765053, theta=-65.71216 -> V=1.0, theta=0.0
% INFO    : Bus 5103	: V=0.98278, theta=-65.290685 -> V=1.0, theta=0.0
% INFO    : Bus 5104	: V=0.9778072, theta=-65.490594 -> V=1.0, theta=0.0
% INFO    : Bus 5105	: V=1.0049001, theta=-61.421773 -> V=1.0, theta=0.0
% INFO    : Bus 5106	: V=0.978178, theta=-65.532389 -> V=1.0, theta=0.0
% INFO    : Bus 5107	: V=0.9741214, theta=-66.135778 -> V=1.0, theta=0.0
% INFO    : Bus 5108	: V=0.9788703, theta=-66.075739 -> V=1.0, theta=0.0
% INFO    : Bus 5109	: V=0.9827366, theta=-64.558838 -> V=1.0, theta=0.0
% INFO    : Bus 5110	: V=0.9774597, theta=-65.68479 -> V=1.0, theta=0.0
% INFO    : Bus 5111	: V=0.9776705, theta=-65.650947 -> V=1.0, theta=0.0
% INFO    : Bus 5112	: V=0.9767034, theta=-65.798596 -> V=1.0, theta=0.0
% INFO    : Bus 5113	: V=0.9781352, theta=-65.57825 -> V=1.0, theta=0.0
% INFO    : Bus 5114	: V=0.9782006, theta=-65.531747 -> V=1.0, theta=0.0
% INFO    : Bus 5115	: V=0.9782804, theta=-65.480729 -> V=1.0, theta=0.0
% INFO    : Bus 5116	: V=0.9781578, theta=-65.484064 -> V=1.0, theta=0.0
% INFO    : Bus 5117	: V=0.9785794, theta=-65.4439 -> V=1.0, theta=0.0
% INFO    : Bus 5118	: V=0.9786565, theta=-65.442098 -> V=1.0, theta=0.0
% INFO    : Bus 5119	: V=0.9788551, theta=-65.436908 -> V=1.0, theta=0.0
% INFO    : Bus 5120	: V=0.9845463, theta=-64.261357 -> V=1.0, theta=0.0
% INFO    : Bus 5121	: V=0.9821912, theta=-65.527403 -> V=1.0, theta=0.0
% INFO    : Bus 5122	: V=0.9795013, theta=-65.367916 -> V=1.0, theta=0.0
% INFO    : Bus 5123	: V=0.9785109, theta=-65.519349 -> V=1.0, theta=0.0
% INFO    : Bus 5124	: V=0.9816607, theta=-65.560639 -> V=1.0, theta=0.0
% INFO    : Bus 5125	: V=0.9837444, theta=-64.46034 -> V=1.0, theta=0.0
% INFO    : Bus 5126	: V=0.9840395, theta=-64.419219 -> V=1.0, theta=0.0
% INFO    : Bus 5127	: V=0.9788131, theta=-66.083644 -> V=1.0, theta=0.0
% INFO    : Bus 5128	: V=0.9803743, theta=-65.338897 -> V=1.0, theta=0.0
% INFO    : Bus 5129	: V=0.9800639, theta=-65.393151 -> V=1.0, theta=0.0
% INFO    : Bus 5130	: V=0.9834321, theta=-65.059723 -> V=1.0, theta=0.0
% INFO    : Bus 5131	: V=0.9840977, theta=-64.452169 -> V=1.0, theta=0.0
% INFO    : Bus 5132	: V=0.9835486, theta=-65.05775 -> V=1.0, theta=0.0
% INFO    : Bus 5133	: V=0.9789312, theta=-65.568483 -> V=1.0, theta=0.0
% INFO    : Bus 5134	: V=0.9840248, theta=-64.999844 -> V=1.0, theta=0.0
% INFO    : Bus 5135	: V=0.9795061, theta=-65.482203 -> V=1.0, theta=0.0
% INFO    : Bus 5136	: V=0.98186, theta=-65.555246 -> V=1.0, theta=0.0
% INFO    : Bus 5137	: V=0.9853055, theta=-64.304612 -> V=1.0, theta=0.0
% INFO    : Bus 5138	: V=0.9819587, theta=-65.533687 -> V=1.0, theta=0.0
% INFO    : Bus 5139	: V=0.9804985, theta=-65.332243 -> V=1.0, theta=0.0
% INFO    : Bus 5140	: V=0.9861479, theta=-64.755416 -> V=1.0, theta=0.0
% INFO    : Bus 5141	: V=0.9862864, theta=-64.177463 -> V=1.0, theta=0.0
% INFO    : Bus 5142	: V=0.9823346, theta=-65.524044 -> V=1.0, theta=0.0
% INFO    : Bus 5143	: V=0.9857008, theta=-64.424215 -> V=1.0, theta=0.0
% INFO    : Bus 5144	: V=0.981836, theta=-65.555815 -> V=1.0, theta=0.0
% INFO    : Bus 5145	: V=0.9805311, theta=-65.317935 -> V=1.0, theta=0.0
% INFO    : Bus 5146	: V=0.9786784, theta=-66.080054 -> V=1.0, theta=0.0
% INFO    : Bus 5147	: V=0.9770505, theta=-65.844565 -> V=1.0, theta=0.0
% INFO    : Bus 5148	: V=0.9848248, theta=-64.918684 -> V=1.0, theta=0.0
% INFO    : Bus 5149	: V=0.9858281, theta=-64.668785 -> V=1.0, theta=0.0
% INFO    : Bus 5150	: V=0.9755194, theta=-66.221005 -> V=1.0, theta=0.0
% INFO    : Bus 5151	: V=0.9759417, theta=-66.171358 -> V=1.0, theta=0.0
% INFO    : Bus 5152	: V=0.9820284, theta=-65.46421 -> V=1.0, theta=0.0
% INFO    : Bus 5153	: V=0.9778129, theta=-65.75918 -> V=1.0, theta=0.0
% INFO    : Bus 5154	: V=0.9856598, theta=-64.679538 -> V=1.0, theta=0.0
% INFO    : Bus 5155	: V=0.9784835, theta=-66.091864 -> V=1.0, theta=0.0
% INFO    : Bus 5156	: V=0.9777263, theta=-65.753445 -> V=1.0, theta=0.0
% INFO    : Bus 5157	: V=0.9851963, theta=-64.871408 -> V=1.0, theta=0.0
% INFO    : Bus 5158	: V=0.9758184, theta=-66.013674 -> V=1.0, theta=0.0
% INFO    : Bus 5159	: V=0.9861071, theta=-64.756958 -> V=1.0, theta=0.0
% INFO    : Bus 5160	: V=0.975318, theta=-66.074972 -> V=1.0, theta=0.0
% INFO    : Bus 5161	: V=0.9754475, theta=-66.07062 -> V=1.0, theta=0.0
% INFO    : Bus 5162	: V=0.9863153, theta=-64.736766 -> V=1.0, theta=0.0
% INFO    : Bus 5163	: V=0.9756933, theta=-65.989964 -> V=1.0, theta=0.0
% INFO    : Bus 5164	: V=0.9858176, theta=-64.780357 -> V=1.0, theta=0.0
% INFO    : Bus 5165	: V=0.976002, theta=-65.947694 -> V=1.0, theta=0.0
% INFO    : Bus 5166	: V=0.9901152, theta=-64.483018 -> V=1.0, theta=0.0
% INFO    : Bus 5167	: V=0.9905937, theta=-64.452308 -> V=1.0, theta=0.0
% INFO    : Bus 5168	: V=0.9763607, theta=-65.896261 -> V=1.0, theta=0.0
% INFO    : Bus 5169	: V=0.9850653, theta=-64.887177 -> V=1.0, theta=0.0
% INFO    : Bus 5170	: V=0.9766405, theta=-65.8003 -> V=1.0, theta=0.0
% INFO    : Bus 5171	: V=0.9849878, theta=-64.896942 -> V=1.0, theta=0.0
% INFO    : Bus 5172	: V=0.9771988, theta=-65.724057 -> V=1.0, theta=0.0
% INFO    : Bus 5173	: V=0.9848684, theta=-64.912559 -> V=1.0, theta=0.0
% INFO    : Bus 5174	: V=0.9737604, theta=-66.247196 -> V=1.0, theta=0.0
% INFO    : Bus 5175	: V=0.9849272, theta=-64.904713 -> V=1.0, theta=0.0
% INFO    : Bus 5176	: V=0.9739481, theta=-66.196485 -> V=1.0, theta=0.0
% INFO    : Bus 5177	: V=0.9908276, theta=-64.425485 -> V=1.0, theta=0.0
% INFO    : Bus 5178	: V=0.9913533, theta=-64.36702 -> V=1.0, theta=0.0
% INFO    : Bus 5179	: V=0.9737111, theta=-66.22985 -> V=1.0, theta=0.0
% INFO    : Bus 5180	: V=0.9968473, theta=-63.763093 -> V=1.0, theta=0.0
% INFO    : Bus 5181	: V=0.9732362, theta=-66.326018 -> V=1.0, theta=0.0
% INFO    : Bus 5182	: V=0.9940154, theta=-64.014639 -> V=1.0, theta=0.0
% INFO    : Bus 5183	: V=0.972979, theta=-66.372366 -> V=1.0, theta=0.0
% INFO    : Bus 5184	: V=0.9975206, theta=-63.702174 -> V=1.0, theta=0.0
% INFO    : Bus 5185	: V=0.9727298, theta=-66.413864 -> V=1.0, theta=0.0
% INFO    : Bus 5186	: V=0.9982782, theta=-63.635172 -> V=1.0, theta=0.0
% INFO    : Bus 5187	: V=0.9717741, theta=-66.570389 -> V=1.0, theta=0.0
% INFO    : Bus 5188	: V=0.9914609, theta=-64.41148 -> V=1.0, theta=0.0
% INFO    : Bus 5189	: V=0.9719979, theta=-66.526868 -> V=1.0, theta=0.0
% INFO    : Bus 5190	: V=0.9860283, theta=-64.737185 -> V=1.0, theta=0.0
% INFO    : Bus 5191	: V=0.9722511, theta=-66.472098 -> V=1.0, theta=0.0
% INFO    : Bus 5192	: V=0.9824638, theta=-65.450493 -> V=1.0, theta=0.0
% INFO    : Bus 5193	: V=0.9720913, theta=-66.476522 -> V=1.0, theta=0.0
% INFO    : Bus 5194	: V=0.9825368, theta=-65.448695 -> V=1.0, theta=0.0
% INFO    : Bus 5195	: V=0.9721333, theta=-66.472938 -> V=1.0, theta=0.0
% INFO    : Bus 5196	: V=0.9827265, theta=-65.436935 -> V=1.0, theta=0.0
% INFO    : Bus 5197	: V=0.972002, theta=-66.490916 -> V=1.0, theta=0.0
% INFO    : Bus 5198	: V=0.9717477, theta=-66.541771 -> V=1.0, theta=0.0
% INFO    : Bus 5199	: V=0.9867012, theta=-64.699164 -> V=1.0, theta=0.0
% INFO    : Bus 5200	: V=0.9715238, theta=-66.587089 -> V=1.0, theta=0.0
% INFO    : Bus 5201	: V=0.987187, theta=-64.641557 -> V=1.0, theta=0.0
% INFO    : Bus 5202	: V=0.9712531, theta=-66.650336 -> V=1.0, theta=0.0
% INFO    : Bus 5203	: V=0.9870046, theta=-64.66254 -> V=1.0, theta=0.0
% INFO    : Bus 5204	: V=0.9710809, theta=-66.664044 -> V=1.0, theta=0.0
% INFO    : Bus 5205	: V=0.9710388, theta=-66.700333 -> V=1.0, theta=0.0
% INFO    : Bus 5206	: V=0.9823423, theta=-65.628205 -> V=1.0, theta=0.0
% INFO    : Bus 5207	: V=0.9734047, theta=-66.418421 -> V=1.0, theta=0.0
% INFO    : Bus 5208	: V=0.9865408, theta=-64.713997 -> V=1.0, theta=0.0
% INFO    : Bus 5209	: V=0.973457, theta=-66.415708 -> V=1.0, theta=0.0
% INFO    : Bus 5210	: V=0.9869079, theta=-64.671902 -> V=1.0, theta=0.0
% INFO    : Bus 5211	: V=0.9712461, theta=-66.634602 -> V=1.0, theta=0.0
% INFO    : Bus 5212	: V=0.9872102, theta=-64.638187 -> V=1.0, theta=0.0
% INFO    : Bus 5213	: V=0.970896, theta=-66.670436 -> V=1.0, theta=0.0
% INFO    : Bus 5214	: V=0.97084, theta=-66.669542 -> V=1.0, theta=0.0
% INFO    : Bus 5215	: V=0.9876084, theta=-64.591796 -> V=1.0, theta=0.0
% INFO    : Bus 5216	: V=0.9708272, theta=-66.664521 -> V=1.0, theta=0.0
% INFO    : Bus 5217	: V=0.9708619, theta=-66.653145 -> V=1.0, theta=0.0
% INFO    : Bus 5218	: V=0.971009, theta=-66.624102 -> V=1.0, theta=0.0
% INFO    : Bus 5219	: V=0.9703607, theta=-66.676105 -> V=1.0, theta=0.0
% INFO    : Bus 5220	: V=0.9709486, theta=-66.590429 -> V=1.0, theta=0.0
% INFO    : Bus 5221	: V=0.9817817, theta=-65.678558 -> V=1.0, theta=0.0
% INFO    : Bus 5222	: V=0.9707736, theta=-66.61709 -> V=1.0, theta=0.0
% INFO    : Bus 5223	: V=0.9819124, theta=-65.660951 -> V=1.0, theta=0.0
% INFO    : Bus 5224	: V=0.9705817, theta=-66.669961 -> V=1.0, theta=0.0
% INFO    : Bus 5225	: V=0.9816569, theta=-65.682527 -> V=1.0, theta=0.0
% INFO    : Bus 5226	: V=0.9703946, theta=-66.698627 -> V=1.0, theta=0.0
% INFO    : Bus 5227	: V=0.9703697, theta=-66.712581 -> V=1.0, theta=0.0
% INFO    : Bus 5228	: V=0.9699928, theta=-66.750307 -> V=1.0, theta=0.0
% INFO    : Bus 5229	: V=0.9696381, theta=-66.760059 -> V=1.0, theta=0.0
% INFO    : Bus 5230	: V=0.9699262, theta=-66.742181 -> V=1.0, theta=0.0
% INFO    : Bus 5231	: V=0.9701872, theta=-66.699524 -> V=1.0, theta=0.0
% INFO    : Bus 5232	: V=0.9699425, theta=-66.734062 -> V=1.0, theta=0.0
% INFO    : Bus 5233	: V=0.9700737, theta=-66.700561 -> V=1.0, theta=0.0
% INFO    : Bus 5234	: V=0.9705147, theta=-66.656868 -> V=1.0, theta=0.0
% INFO    : Bus 5235	: V=0.9698109, theta=-66.716701 -> V=1.0, theta=0.0
% INFO    : Bus 5236	: V=0.9698658, theta=-66.736196 -> V=1.0, theta=0.0
% INFO    : Bus 5237	: V=0.9690673, theta=-66.801008 -> V=1.0, theta=0.0
% INFO    : Bus 5238	: V=0.969611, theta=-66.742459 -> V=1.0, theta=0.0
% INFO    : Bus 5239	: V=0.9695349, theta=-66.762919 -> V=1.0, theta=0.0
% INFO    : Bus 5240	: V=0.970188, theta=-66.729044 -> V=1.0, theta=0.0
% INFO    : Bus 5241	: V=0.9695677, theta=-66.747581 -> V=1.0, theta=0.0
% INFO    : Bus 5242	: V=0.9710238, theta=-66.68667 -> V=1.0, theta=0.0
% INFO    : Bus 5243	: V=0.9707721, theta=-66.704425 -> V=1.0, theta=0.0
% INFO    : Bus 5244	: V=0.970928, theta=-66.683449 -> V=1.0, theta=0.0
% INFO    : Bus 5245	: V=0.9709376, theta=-66.654115 -> V=1.0, theta=0.0
% INFO    : Bus 5246	: V=0.9715568, theta=-66.609832 -> V=1.0, theta=0.0
% INFO    : Bus 5247	: V=0.971359, theta=-66.63005 -> V=1.0, theta=0.0
% INFO    : Bus 5248	: V=0.9712204, theta=-66.646246 -> V=1.0, theta=0.0
% INFO    : Bus 5249	: V=0.9710211, theta=-66.677341 -> V=1.0, theta=0.0
% INFO    : Bus 5250	: V=0.9708291, theta=-66.708546 -> V=1.0, theta=0.0
% INFO    : Bus 5251	: V=0.9705941, theta=-66.733172 -> V=1.0, theta=0.0
% INFO    : Bus 5252	: V=0.9705542, theta=-66.734267 -> V=1.0, theta=0.0
% INFO    : Bus 5253	: V=0.9706774, theta=-66.718049 -> V=1.0, theta=0.0
% INFO    : Bus 5254	: V=0.9709024, theta=-66.727216 -> V=1.0, theta=0.0
% INFO    : Bus 5255	: V=0.9708321, theta=-66.741938 -> V=1.0, theta=0.0
% INFO    : Bus 5256	: V=0.9708871, theta=-66.740578 -> V=1.0, theta=0.0
% INFO    : Bus 5257	: V=0.9694124, theta=-66.75186 -> V=1.0, theta=0.0
% INFO    : Bus 5258	: V=0.9709362, theta=-66.742279 -> V=1.0, theta=0.0
% INFO    : Bus 5259	: V=0.9705737, theta=-66.743239 -> V=1.0, theta=0.0
% INFO    : Bus 5260	: V=0.9705267, theta=-66.744515 -> V=1.0, theta=0.0
% INFO    : Bus 5261	: V=0.9716555, theta=-66.60756 -> V=1.0, theta=0.0
% INFO    : Bus 5262	: V=0.9706724, theta=-66.755313 -> V=1.0, theta=0.0
% INFO    : Bus 5263	: V=0.9704738, theta=-66.763514 -> V=1.0, theta=0.0
% INFO    : Bus 5264	: V=0.9703713, theta=-66.748357 -> V=1.0, theta=0.0
% INFO    : Bus 5265	: V=0.9709483, theta=-66.743204 -> V=1.0, theta=0.0
% INFO    : Bus 5266	: V=0.970798, theta=-66.74968 -> V=1.0, theta=0.0
% INFO    : Bus 5267	: V=0.970655, theta=-66.754985 -> V=1.0, theta=0.0
% INFO    : Bus 5268	: V=0.9706352, theta=-66.759001 -> V=1.0, theta=0.0
% INFO    : Bus 5269	: V=0.9746996, theta=-66.226648 -> V=1.0, theta=0.0
% INFO    : Bus 5270	: V=0.9699034, theta=-66.849354 -> V=1.0, theta=0.0
% INFO    : Bus 5271	: V=0.9743276, theta=-66.346725 -> V=1.0, theta=0.0
% INFO    : Bus 5272	: V=0.9697139, theta=-66.854473 -> V=1.0, theta=0.0
% INFO    : Bus 5273	: V=0.9748021, theta=-66.3117 -> V=1.0, theta=0.0
% INFO    : Bus 5274	: V=0.9765346, theta=-66.264737 -> V=1.0, theta=0.0
% INFO    : Bus 5275	: V=0.9694547, theta=-66.860045 -> V=1.0, theta=0.0
% INFO    : Bus 5276	: V=0.9708087, theta=-66.752415 -> V=1.0, theta=0.0
% INFO    : Bus 5277	: V=0.9748681, theta=-66.167172 -> V=1.0, theta=0.0
% INFO    : Bus 5278	: V=0.971632, theta=-66.607421 -> V=1.0, theta=0.0
% INFO    : Bus 5279	: V=0.9714434, theta=-66.612223 -> V=1.0, theta=0.0
% INFO    : Bus 5280	: V=0.9717586, theta=-66.608593 -> V=1.0, theta=0.0
% INFO    : Bus 5281	: V=0.9716983, theta=-66.606365 -> V=1.0, theta=0.0
% INFO    : Bus 5282	: V=0.9717042, theta=-66.600438 -> V=1.0, theta=0.0
% INFO    : Bus 5283	: V=0.9716425, theta=-66.602128 -> V=1.0, theta=0.0
% INFO    : Bus 5284	: V=0.9717619, theta=-66.58585 -> V=1.0, theta=0.0
% INFO    : Bus 5285	: V=0.9718478, theta=-66.569267 -> V=1.0, theta=0.0
% INFO    : Bus 5286	: V=0.9728352, theta=-66.447558 -> V=1.0, theta=0.0
% INFO    : Bus 5287	: V=0.9729433, theta=-66.417098 -> V=1.0, theta=0.0
% INFO    : Bus 5288	: V=0.9717658, theta=-66.571003 -> V=1.0, theta=0.0
% INFO    : Bus 5289	: V=0.9715011, theta=-66.613171 -> V=1.0, theta=0.0
% INFO    : Bus 5290	: V=0.9731919, theta=-66.351916 -> V=1.0, theta=0.0
% INFO    : Bus 5291	: V=0.9731653, theta=-66.324466 -> V=1.0, theta=0.0
% INFO    : Bus 5292	: V=0.9731292, theta=-66.325378 -> V=1.0, theta=0.0
% INFO    : Bus 5293	: V=0.9733792, theta=-66.310888 -> V=1.0, theta=0.0
% INFO    : Bus 5294	: V=0.9723252, theta=-66.484909 -> V=1.0, theta=0.0
% INFO    : Bus 5295	: V=0.972168, theta=-66.489232 -> V=1.0, theta=0.0
% INFO    : Bus 5296	: V=0.9733981, theta=-66.25659 -> V=1.0, theta=0.0
% INFO    : Bus 5297	: V=0.9735376, theta=-66.252783 -> V=1.0, theta=0.0
% INFO    : Bus 5298	: V=0.9741626, theta=-66.235331 -> V=1.0, theta=0.0
% INFO    : Bus 5299	: V=0.9743896, theta=-66.209301 -> V=1.0, theta=0.0
% INFO    : Bus 5300	: V=0.9739381, theta=-66.190976 -> V=1.0, theta=0.0
% INFO    : Bus 5301	: V=0.9748635, theta=-66.140207 -> V=1.0, theta=0.0
% INFO    : Bus 5302	: V=0.9736607, theta=-66.304469 -> V=1.0, theta=0.0
% INFO    : Bus 5303	: V=0.9730984, theta=-66.442407 -> V=1.0, theta=0.0
% INFO    : Bus 5304	: V=0.9727474, theta=-66.471775 -> V=1.0, theta=0.0
% INFO    : Bus 5305	: V=0.972682, theta=-66.501811 -> V=1.0, theta=0.0
% INFO    : Bus 5306	: V=0.9807552, theta=-65.089313 -> V=1.0, theta=0.0
% INFO    : Bus 5307	: V=0.9731732, theta=-66.421264 -> V=1.0, theta=0.0
% INFO    : Bus 5308	: V=0.973365, theta=-66.415979 -> V=1.0, theta=0.0
% INFO    : Bus 5309	: V=0.9743015, theta=-66.244433 -> V=1.0, theta=0.0
% INFO    : Bus 5310	: V=0.9750115, theta=-66.133685 -> V=1.0, theta=0.0
% INFO    : Bus 5311	: V=0.9773124, theta=-65.792972 -> V=1.0, theta=0.0
% INFO    : Bus 5312	: V=0.9775764, theta=-65.782716 -> V=1.0, theta=0.0
% INFO    : Bus 5313	: V=0.9856242, theta=-64.597492 -> V=1.0, theta=0.0
% INFO    : Bus 5314	: V=0.975718, theta=-66.215575 -> V=1.0, theta=0.0
% INFO    : Bus 5315	: V=0.9856911, theta=-64.596183 -> V=1.0, theta=0.0
% INFO    : Bus 5316	: V=0.986666, theta=-64.599183 -> V=1.0, theta=0.0
% INFO    : Bus 5317	: V=0.9745438, theta=-66.295214 -> V=1.0, theta=0.0
% INFO    : Bus 5318	: V=0.9747805, theta=-66.289071 -> V=1.0, theta=0.0
% INFO    : Bus 5319	: V=0.974009, theta=-66.451104 -> V=1.0, theta=0.0
% INFO    : Bus 5320	: V=0.9786283, theta=-65.992807 -> V=1.0, theta=0.0
% INFO    : Bus 5321	: V=0.9806623, theta=-65.210712 -> V=1.0, theta=0.0
% INFO    : Bus 5322	: V=0.9743166, theta=-66.442661 -> V=1.0, theta=0.0
% INFO    : Bus 5323	: V=0.9747068, theta=-66.318145 -> V=1.0, theta=0.0
% INFO    : Bus 5324	: V=0.9809011, theta=-65.15859 -> V=1.0, theta=0.0
% INFO    : Bus 5325	: V=0.974923, theta=-66.293935 -> V=1.0, theta=0.0
% INFO    : Bus 5326	: V=0.9751452, theta=-66.26435 -> V=1.0, theta=0.0
% INFO    : Bus 5327	: V=0.9753829, theta=-66.247363 -> V=1.0, theta=0.0
% INFO    : Bus 5328	: V=0.9775824, theta=-65.783089 -> V=1.0, theta=0.0
% INFO    : Bus 5329	: V=0.9772811, theta=-65.793207 -> V=1.0, theta=0.0
% INFO    : Bus 5330	: V=0.9745492, theta=-66.237628 -> V=1.0, theta=0.0
% INFO    : Bus 5331	: V=0.9741402, theta=-66.327857 -> V=1.0, theta=0.0
% INFO    : Bus 5332	: V=0.9809668, theta=-65.068854 -> V=1.0, theta=0.0
% INFO    : Bus 5333	: V=0.9734535, theta=-66.436225 -> V=1.0, theta=0.0
% INFO    : Bus 5334	: V=0.9726285, theta=-66.529864 -> V=1.0, theta=0.0
% INFO    : Bus 5335	: V=0.9731357, theta=-66.476452 -> V=1.0, theta=0.0
% INFO    : Bus 5336	: V=0.9728403, theta=-66.535148 -> V=1.0, theta=0.0
% INFO    : Bus 5337	: V=0.9725716, theta=-66.58485 -> V=1.0, theta=0.0
% INFO    : Bus 5338	: V=0.9731253, theta=-66.532524 -> V=1.0, theta=0.0
% INFO    : Bus 5339	: V=0.9731911, theta=-66.530924 -> V=1.0, theta=0.0
% INFO    : Bus 5340	: V=0.9739115, theta=-66.428997 -> V=1.0, theta=0.0
% INFO    : Bus 5341	: V=0.9813615, theta=-65.027828 -> V=1.0, theta=0.0
% INFO    : Bus 5342	: V=0.9811344, theta=-65.088148 -> V=1.0, theta=0.0
% INFO    : Bus 5343	: V=0.9739125, theta=-66.428939 -> V=1.0, theta=0.0
% INFO    : Bus 5344	: V=0.9734395, theta=-66.524056 -> V=1.0, theta=0.0
% INFO    : Bus 5345	: V=0.9730642, theta=-66.574866 -> V=1.0, theta=0.0
% INFO    : Bus 5346	: V=0.9731992, theta=-66.593487 -> V=1.0, theta=0.0
% INFO    : Bus 5347	: V=0.9734844, theta=-66.549414 -> V=1.0, theta=0.0
% INFO    : Bus 5348	: V=0.9737967, theta=-66.498984 -> V=1.0, theta=0.0
% INFO    : Bus 5349	: V=0.97393, theta=-66.462633 -> V=1.0, theta=0.0
% INFO    : Bus 5350	: V=0.9740781, theta=-66.424822 -> V=1.0, theta=0.0
% INFO    : Bus 5351	: V=0.9744554, theta=-66.431802 -> V=1.0, theta=0.0
% INFO    : Bus 5352	: V=0.9743323, theta=-66.43517 -> V=1.0, theta=0.0
% INFO    : Bus 5353	: V=0.9766581, theta=-65.990461 -> V=1.0, theta=0.0
% INFO    : Bus 5354	: V=0.9768591, theta=-65.973151 -> V=1.0, theta=0.0
% INFO    : Bus 5355	: V=0.9743088, theta=-66.464518 -> V=1.0, theta=0.0
% INFO    : Bus 5356	: V=0.9744081, theta=-66.457969 -> V=1.0, theta=0.0
% INFO    : Bus 5357	: V=0.9728613, theta=-66.647825 -> V=1.0, theta=0.0
% INFO    : Bus 5358	: V=0.9723696, theta=-66.690797 -> V=1.0, theta=0.0
% INFO    : Bus 5359	: V=0.976248, theta=-66.050257 -> V=1.0, theta=0.0
% INFO    : Bus 5360	: V=0.9745917, theta=-66.445273 -> V=1.0, theta=0.0
% INFO    : Bus 5361	: V=0.9744423, theta=-66.456822 -> V=1.0, theta=0.0
% INFO    : Bus 5362	: V=0.9762417, theta=-66.052978 -> V=1.0, theta=0.0
% INFO    : Bus 5363	: V=0.9743759, theta=-66.458658 -> V=1.0, theta=0.0
% INFO    : Bus 5364	: V=0.9750484, theta=-66.40236 -> V=1.0, theta=0.0
% INFO    : Bus 5365	: V=0.9724232, theta=-66.888224 -> V=1.0, theta=0.0
% INFO    : Bus 5366	: V=0.9769543, theta=-66.006656 -> V=1.0, theta=0.0
% INFO    : Bus 5367	: V=0.9743308, theta=-66.655064 -> V=1.0, theta=0.0
% INFO    : Bus 5368	: V=0.9723405, theta=-66.791478 -> V=1.0, theta=0.0
% INFO    : Bus 5369	: V=0.9723628, theta=-66.776378 -> V=1.0, theta=0.0
% INFO    : Bus 5370	: V=0.9762578, theta=-66.053311 -> V=1.0, theta=0.0
% INFO    : Bus 5371	: V=0.9763099, theta=-66.051443 -> V=1.0, theta=0.0
% INFO    : Bus 5372	: V=0.9723039, theta=-66.746252 -> V=1.0, theta=0.0
% INFO    : Bus 5373	: V=0.9739474, theta=-66.473263 -> V=1.0, theta=0.0
% INFO    : Bus 5374	: V=0.9766791, theta=-66.027078 -> V=1.0, theta=0.0
% INFO    : Bus 5375	: V=0.9720407, theta=-66.693514 -> V=1.0, theta=0.0
% INFO    : Bus 5376	: V=0.972179, theta=-66.690019 -> V=1.0, theta=0.0
% INFO    : Bus 5377	: V=0.9723175, theta=-66.599741 -> V=1.0, theta=0.0
% INFO    : Bus 5378	: V=0.9723963, theta=-66.662079 -> V=1.0, theta=0.0
% INFO    : Bus 5379	: V=0.9725663, theta=-66.643806 -> V=1.0, theta=0.0
% INFO    : Bus 5380	: V=0.9729691, theta=-66.577405 -> V=1.0, theta=0.0
% INFO    : Bus 5381	: V=0.9721807, theta=-66.656035 -> V=1.0, theta=0.0
% INFO    : Bus 5382	: V=0.9717788, theta=-66.716015 -> V=1.0, theta=0.0
% INFO    : Bus 5383	: V=0.9723989, theta=-66.589554 -> V=1.0, theta=0.0
% INFO    : Bus 5384	: V=0.9750547, theta=-66.154477 -> V=1.0, theta=0.0
% INFO    : Bus 5385	: V=0.971596, theta=-66.753449 -> V=1.0, theta=0.0
% INFO    : Bus 5386	: V=0.9714393, theta=-66.780634 -> V=1.0, theta=0.0
% INFO    : Bus 5387	: V=0.9713785, theta=-66.784496 -> V=1.0, theta=0.0
% INFO    : Bus 5388	: V=0.9718293, theta=-66.715267 -> V=1.0, theta=0.0
% INFO    : Bus 5389	: V=0.9716044, theta=-66.721467 -> V=1.0, theta=0.0
% INFO    : Bus 5390	: V=0.9711173, theta=-66.791783 -> V=1.0, theta=0.0
% INFO    : Bus 5391	: V=0.9710372, theta=-66.79373 -> V=1.0, theta=0.0
% INFO    : Bus 5392	: V=0.970787, theta=-66.800707 -> V=1.0, theta=0.0
% INFO    : Bus 5393	: V=0.9715302, theta=-66.723023 -> V=1.0, theta=0.0
% INFO    : Bus 5394	: V=0.9706399, theta=-66.80433 -> V=1.0, theta=0.0
% INFO    : Bus 5395	: V=0.9712227, theta=-66.773991 -> V=1.0, theta=0.0
% INFO    : Bus 5396	: V=0.9708314, theta=-66.868554 -> V=1.0, theta=0.0
% INFO    : Bus 5397	: V=0.9708852, theta=-66.86742 -> V=1.0, theta=0.0
% INFO    : Bus 5398	: V=0.9709321, theta=-66.858364 -> V=1.0, theta=0.0
% INFO    : Bus 5399	: V=0.9709649, theta=-66.809445 -> V=1.0, theta=0.0
% INFO    : Bus 5400	: V=0.9710084, theta=-66.808397 -> V=1.0, theta=0.0
% INFO    : Bus 5401	: V=0.9711093, theta=-66.805592 -> V=1.0, theta=0.0
% INFO    : Bus 5402	: V=0.971272, theta=-66.801074 -> V=1.0, theta=0.0
% INFO    : Bus 5403	: V=0.9712403, theta=-66.73543 -> V=1.0, theta=0.0
% INFO    : Bus 5404	: V=0.9709052, theta=-66.84617 -> V=1.0, theta=0.0
% INFO    : Bus 5405	: V=0.9707934, theta=-66.859444 -> V=1.0, theta=0.0
% INFO    : Bus 5406	: V=0.9707135, theta=-66.86168 -> V=1.0, theta=0.0
% INFO    : Bus 5407	: V=0.9709154, theta=-66.86996 -> V=1.0, theta=0.0
% INFO    : Bus 5408	: V=0.9709617, theta=-66.869728 -> V=1.0, theta=0.0
% INFO    : Bus 5409	: V=0.9710023, theta=-66.868621 -> V=1.0, theta=0.0
% INFO    : Bus 5410	: V=0.9707296, theta=-66.875281 -> V=1.0, theta=0.0
% INFO    : Bus 5411	: V=0.9707361, theta=-66.869487 -> V=1.0, theta=0.0
% INFO    : Bus 5412	: V=0.9707311, theta=-66.861166 -> V=1.0, theta=0.0
% INFO    : Bus 5413	: V=0.9691494, theta=-66.870366 -> V=1.0, theta=0.0
% INFO    : Bus 5414	: V=0.9707469, theta=-66.87986 -> V=1.0, theta=0.0
% INFO    : Bus 5415	: V=0.9754787, theta=-66.286753 -> V=1.0, theta=0.0
% INFO    : Bus 5416	: V=0.9753365, theta=-66.296396 -> V=1.0, theta=0.0
% INFO    : Bus 5417	: V=0.9691081, theta=-67.141855 -> V=1.0, theta=0.0
% INFO    : Bus 5418	: V=0.9697965, theta=-67.113879 -> V=1.0, theta=0.0
% INFO    : Bus 5419	: V=0.9716627, theta=-66.761849 -> V=1.0, theta=0.0
% INFO    : Bus 5420	: V=0.9760137, theta=-66.198867 -> V=1.0, theta=0.0
% INFO    : Bus 5421	: V=0.9761273, theta=-66.179173 -> V=1.0, theta=0.0
% INFO    : Bus 5422	: V=0.9762978, theta=-66.151954 -> V=1.0, theta=0.0
% INFO    : Bus 5423	: V=0.9765471, theta=-66.113389 -> V=1.0, theta=0.0
% INFO    : Bus 5424	: V=0.9768855, theta=-66.068746 -> V=1.0, theta=0.0
% INFO    : Bus 5425	: V=0.9723037, theta=-66.971861 -> V=1.0, theta=0.0
% INFO    : Bus 5426	: V=0.9717326, theta=-66.826269 -> V=1.0, theta=0.0
% INFO    : Bus 5427	: V=0.971822, theta=-66.824367 -> V=1.0, theta=0.0
% INFO    : Bus 5428	: V=0.9722271, theta=-66.813117 -> V=1.0, theta=0.0
% INFO    : Bus 5429	: V=0.9717378, theta=-66.835537 -> V=1.0, theta=0.0
% INFO    : Bus 5430	: V=0.9719936, theta=-66.829435 -> V=1.0, theta=0.0
% INFO    : Bus 5431	: V=0.9719471, theta=-66.830716 -> V=1.0, theta=0.0
% INFO    : Bus 5432	: V=0.9724368, theta=-66.793837 -> V=1.0, theta=0.0
% INFO    : Bus 5433	: V=0.9775006, theta=-66.010328 -> V=1.0, theta=0.0
% INFO    : Bus 5434	: V=0.9743868, theta=-66.680591 -> V=1.0, theta=0.0
% INFO    : Bus 5435	: V=0.9767194, theta=-66.100623 -> V=1.0, theta=0.0
% INFO    : Bus 5436	: V=0.9725048, theta=-66.841878 -> V=1.0, theta=0.0
% INFO    : Bus 5437	: V=0.9731675, theta=-66.798506 -> V=1.0, theta=0.0
% INFO    : Bus 5438	: V=0.9729222, theta=-66.822081 -> V=1.0, theta=0.0
% INFO    : Bus 5439	: V=0.9763334, theta=-66.143937 -> V=1.0, theta=0.0
% INFO    : Bus 5440	: V=0.9725309, theta=-66.79426 -> V=1.0, theta=0.0
% INFO    : Bus 5441	: V=0.972605, theta=-66.792718 -> V=1.0, theta=0.0
% INFO    : Bus 5442	: V=0.9727586, theta=-66.788771 -> V=1.0, theta=0.0
% INFO    : Bus 5443	: V=0.9729986, theta=-66.783151 -> V=1.0, theta=0.0
% INFO    : Bus 5444	: V=0.9734619, theta=-66.771011 -> V=1.0, theta=0.0
% INFO    : Bus 5445	: V=0.9740667, theta=-66.714345 -> V=1.0, theta=0.0
% INFO    : Bus 5446	: V=0.9731411, theta=-66.778895 -> V=1.0, theta=0.0
% INFO    : Bus 5447	: V=0.972338, theta=-66.846432 -> V=1.0, theta=0.0
% INFO    : Bus 5448	: V=0.9741295, theta=-66.709734 -> V=1.0, theta=0.0
% INFO    : Bus 5449	: V=0.9740461, theta=-66.717646 -> V=1.0, theta=0.0
% INFO    : Bus 5450	: V=0.9769319, theta=-66.17874 -> V=1.0, theta=0.0
% INFO    : Bus 5451	: V=0.9783469, theta=-65.894394 -> V=1.0, theta=0.0
% INFO    : Bus 5452	: V=0.9780118, theta=-65.931855 -> V=1.0, theta=0.0
% INFO    : Bus 5453	: V=0.9786696, theta=-65.858669 -> V=1.0, theta=0.0
% INFO    : Bus 5454	: V=0.9786457, theta=-65.861302 -> V=1.0, theta=0.0
% INFO    : Bus 5455	: V=0.9786398, theta=-65.8619 -> V=1.0, theta=0.0
% INFO    : Bus 5456	: V=0.9736049, theta=-66.73089 -> V=1.0, theta=0.0
% INFO    : Bus 5457	: V=0.973769, theta=-66.716593 -> V=1.0, theta=0.0
% INFO    : Bus 5458	: V=0.9738823, theta=-66.721316 -> V=1.0, theta=0.0
% INFO    : Bus 5459	: V=0.9739081, theta=-66.712771 -> V=1.0, theta=0.0
% INFO    : Bus 5460	: V=0.9740643, theta=-66.714618 -> V=1.0, theta=0.0
% INFO    : Bus 5461	: V=0.9772059, theta=-66.025036 -> V=1.0, theta=0.0
% INFO    : Bus 5462	: V=0.9776474, theta=-65.968776 -> V=1.0, theta=0.0
% INFO    : Bus 5463	: V=0.9728095, theta=-66.834776 -> V=1.0, theta=0.0
% INFO    : Bus 5464	: V=0.9741026, theta=-66.715236 -> V=1.0, theta=0.0
% INFO    : Bus 5465	: V=0.9740373, theta=-66.716829 -> V=1.0, theta=0.0
% INFO    : Bus 5466	: V=0.9741546, theta=-66.706161 -> V=1.0, theta=0.0
% INFO    : Bus 5467	: V=0.9742015, theta=-66.701914 -> V=1.0, theta=0.0
% INFO    : Bus 5468	: V=0.9727973, theta=-66.791733 -> V=1.0, theta=0.0
% INFO    : Bus 5469	: V=0.973047, theta=-66.784843 -> V=1.0, theta=0.0
% INFO    : Bus 5470	: V=0.9954042, theta=-63.88635 -> V=1.0, theta=0.0
% INFO    : Bus 5471	: V=0.9859169, theta=-64.419846 -> V=1.0, theta=0.0
% INFO    : Bus 5472	: V=0.9783353, theta=-65.650375 -> V=1.0, theta=0.0
% INFO    : Bus 5473	: V=0.9650116, theta=-68.404988 -> V=1.0, theta=0.0
% INFO    : Bus 5474	: V=0.9719092, theta=-68.212313 -> V=1.0, theta=0.0
% INFO    : Bus 5475	: V=1.0120489, theta=-58.948952 -> V=1.0, theta=0.0
% INFO    : Bus 5476	: V=0.9891593, theta=-61.792363 -> V=1.0, theta=0.0
% INFO    : Bus 5477	: V=1.0121614, theta=-59.573403 -> V=1.0, theta=0.0
% INFO    : Bus 5478	: V=0.9774822, theta=-63.513076 -> V=1.0, theta=0.0
% INFO    : Bus 5479	: V=1.0030341, theta=-61.56373 -> V=1.0, theta=0.0
% INFO    : Bus 5480	: V=0.9809221, theta=-69.515624 -> V=1.0, theta=0.0
% INFO    : Bus 5481	: V=0.9657289, theta=-71.34477 -> V=1.0, theta=0.0
% INFO    : Bus 5482	: V=0.9752858, theta=-69.306159 -> V=1.0, theta=0.0
% INFO    : Bus 5483	: V=0.9722524, theta=-70.20275 -> V=1.0, theta=0.0
% INFO    : Bus 5484	: V=0.9767316, theta=-71.53586 -> V=1.0, theta=0.0
% INFO    : Bus 5485	: V=0.9775035, theta=-71.515553 -> V=1.0, theta=0.0
% INFO    : Bus 5486	: V=0.9688734, theta=-69.711861 -> V=1.0, theta=0.0
% INFO    : Bus 5487	: V=0.9684117, theta=-71.847833 -> V=1.0, theta=0.0
% INFO    : Bus 5488	: V=0.9869994, theta=-71.039898 -> V=1.0, theta=0.0
% INFO    : Bus 5489	: V=0.9847982, theta=-71.177389 -> V=1.0, theta=0.0
% INFO    : Bus 5490	: V=0.9856468, theta=-71.077408 -> V=1.0, theta=0.0
% INFO    : Bus 5491	: V=0.9589594, theta=-72.601372 -> V=1.0, theta=0.0
% INFO    : Bus 5492	: V=0.9991212, theta=-69.295346 -> V=1.0, theta=0.0
% INFO    : Bus 5493	: V=0.9797962, theta=-72.67085 -> V=1.0, theta=0.0
% INFO    : Bus 5494	: V=0.9842282, theta=-72.548771 -> V=1.0, theta=0.0
% INFO    : Bus 5495	: V=0.9820012, theta=-61.338225 -> V=1.0, theta=0.0
% INFO    : Bus 5496	: V=0.9762644, theta=-61.852417 -> V=1.0, theta=0.0
% INFO    : Bus 5497	: V=0.9819638, theta=-61.757461 -> V=1.0, theta=0.0
% INFO    : Bus 5498	: V=0.9659714, theta=-63.250632 -> V=1.0, theta=0.0
% INFO    : Bus 5499	: V=0.9809506, theta=-62.379515 -> V=1.0, theta=0.0
% INFO    : Bus 5500	: V=0.9722475, theta=-63.169959 -> V=1.0, theta=0.0
% INFO    : Bus 5501	: V=0.9655445, theta=-65.294291 -> V=1.0, theta=0.0
% INFO    : Bus 5502	: V=0.972259, theta=-63.204437 -> V=1.0, theta=0.0
% INFO    : Bus 5503	: V=0.9715354, theta=-63.19381 -> V=1.0, theta=0.0
% INFO    : Bus 5504	: V=0.9699651, theta=-63.2447 -> V=1.0, theta=0.0
% INFO    : Bus 5505	: V=0.9710334, theta=-62.485133 -> V=1.0, theta=0.0
% INFO    : Bus 5506	: V=0.970867, theta=-62.329461 -> V=1.0, theta=0.0
% INFO    : Bus 5507	: V=0.9623901, theta=-62.070746 -> V=1.0, theta=0.0
% INFO    : Bus 5508	: V=0.9755714, theta=-61.543168 -> V=1.0, theta=0.0
% INFO    : Bus 5509	: V=0.9635011, theta=-64.149794 -> V=1.0, theta=0.0
% INFO    : Bus 5510	: V=0.9744324, theta=-61.733503 -> V=1.0, theta=0.0
% INFO    : Bus 5511	: V=0.9878841, theta=-69.797581 -> V=1.0, theta=0.0
% INFO    : Bus 5512	: V=0.9908749, theta=-69.67348 -> V=1.0, theta=0.0
% INFO    : Bus 5513	: V=0.9881941, theta=-69.43932 -> V=1.0, theta=0.0
% INFO    : Bus 5514	: V=0.9899588, theta=-69.651067 -> V=1.0, theta=0.0
% INFO    : Bus 5515	: V=0.9895038, theta=-69.563773 -> V=1.0, theta=0.0
% INFO    : Bus 5516	: V=1.0093185, theta=-68.454864 -> V=1.0, theta=0.0
% INFO    : Bus 5517	: V=1.0104726, theta=-68.38463 -> V=1.0, theta=0.0
% INFO    : Bus 5518	: V=1.0072843, theta=-68.420615 -> V=1.0, theta=0.0
% INFO    : Bus 5519	: V=0.9965707, theta=-69.591969 -> V=1.0, theta=0.0
% INFO    : Bus 5520	: V=1.0042593, theta=-68.404377 -> V=1.0, theta=0.0
% INFO    : Bus 5521	: V=1.0018783, theta=-68.388769 -> V=1.0, theta=0.0
% INFO    : Bus 5522	: V=0.9916088, theta=-69.725774 -> V=1.0, theta=0.0
% INFO    : Bus 5523	: V=0.9855198, theta=-69.775727 -> V=1.0, theta=0.0
% INFO    : Bus 5524	: V=0.9870061, theta=-69.492833 -> V=1.0, theta=0.0
% INFO    : Bus 5525	: V=0.9858295, theta=-69.547074 -> V=1.0, theta=0.0
% INFO    : Bus 5526	: V=0.986333, theta=-69.437089 -> V=1.0, theta=0.0
% INFO    : Bus 5527	: V=0.9843065, theta=-69.647069 -> V=1.0, theta=0.0
% INFO    : Bus 5528	: V=0.9849242, theta=-69.602397 -> V=1.0, theta=0.0
% INFO    : Bus 5529	: V=0.9846804, theta=-69.639377 -> V=1.0, theta=0.0
% INFO    : Bus 5530	: V=0.9848761, theta=-69.635327 -> V=1.0, theta=0.0
% INFO    : Bus 5531	: V=0.985024, theta=-69.599823 -> V=1.0, theta=0.0
% INFO    : Bus 5532	: V=0.9820464, theta=-69.220606 -> V=1.0, theta=0.0
% INFO    : Bus 5533	: V=0.9858273, theta=-69.669561 -> V=1.0, theta=0.0
% INFO    : Bus 5534	: V=0.9891706, theta=-67.547914 -> V=1.0, theta=0.0
% INFO    : Bus 5535	: V=0.9933746, theta=-69.664972 -> V=1.0, theta=0.0
% INFO    : Bus 5536	: V=0.9903285, theta=-69.763654 -> V=1.0, theta=0.0
% INFO    : Bus 5537	: V=0.9882326, theta=-69.793475 -> V=1.0, theta=0.0
% INFO    : Bus 5538	: V=0.99438, theta=-69.644226 -> V=1.0, theta=0.0
% INFO    : Bus 5539	: V=0.9947716, theta=-69.615267 -> V=1.0, theta=0.0
% INFO    : Bus 5540	: V=0.9919386, theta=-69.677359 -> V=1.0, theta=0.0
% INFO    : Bus 5541	: V=0.9913782, theta=-69.614509 -> V=1.0, theta=0.0
% INFO    : Bus 5542	: V=0.9914841, theta=-69.612357 -> V=1.0, theta=0.0
% INFO    : Bus 5543	: V=0.9932653, theta=-69.667177 -> V=1.0, theta=0.0
% INFO    : Bus 5544	: V=0.9925267, theta=-69.663493 -> V=1.0, theta=0.0
% INFO    : Bus 5545	: V=0.9907937, theta=-69.675663 -> V=1.0, theta=0.0
% INFO    : Bus 5546	: V=0.9927238, theta=-69.310338 -> V=1.0, theta=0.0
% INFO    : Bus 5547	: V=0.9931528, theta=-67.403143 -> V=1.0, theta=0.0
% INFO    : Bus 5548	: V=0.9941016, theta=-69.221024 -> V=1.0, theta=0.0
% INFO    : Bus 5549	: V=0.9924297, theta=-67.495202 -> V=1.0, theta=0.0
% INFO    : Bus 5550	: V=0.992176, theta=-67.51561 -> V=1.0, theta=0.0
% INFO    : Bus 5551	: V=0.9887224, theta=-68.870853 -> V=1.0, theta=0.0
% INFO    : Bus 5552	: V=0.9919054, theta=-67.536622 -> V=1.0, theta=0.0
% INFO    : Bus 5553	: V=0.9879991, theta=-68.984753 -> V=1.0, theta=0.0
% INFO    : Bus 5554	: V=0.9890733, theta=-69.024937 -> V=1.0, theta=0.0
% INFO    : Bus 5555	: V=0.9843809, theta=-69.896741 -> V=1.0, theta=0.0
% INFO    : Bus 5556	: V=0.9851144, theta=-69.838578 -> V=1.0, theta=0.0
% INFO    : Bus 5557	: V=0.985398, theta=-69.749463 -> V=1.0, theta=0.0
% INFO    : Bus 5558	: V=0.9854657, theta=-69.720833 -> V=1.0, theta=0.0
% INFO    : Bus 5559	: V=0.9853873, theta=-69.745813 -> V=1.0, theta=0.0
% INFO    : Bus 5560	: V=0.9852864, theta=-69.781712 -> V=1.0, theta=0.0
% INFO    : Bus 5561	: V=0.9837499, theta=-69.923436 -> V=1.0, theta=0.0
% INFO    : Bus 5562	: V=0.9856538, theta=-69.710081 -> V=1.0, theta=0.0
% INFO    : Bus 5563	: V=0.9855831, theta=-69.712777 -> V=1.0, theta=0.0
% INFO    : Bus 5564	: V=0.9853527, theta=-69.71896 -> V=1.0, theta=0.0
% INFO    : Bus 5565	: V=0.9856068, theta=-69.840476 -> V=1.0, theta=0.0
% INFO    : Bus 5566	: V=0.9873156, theta=-69.04937 -> V=1.0, theta=0.0
% INFO    : Bus 5567	: V=0.9865438, theta=-69.099663 -> V=1.0, theta=0.0
% INFO    : Bus 5568	: V=0.985014, theta=-69.28516 -> V=1.0, theta=0.0
% INFO    : Bus 5569	: V=0.9853728, theta=-69.27564 -> V=1.0, theta=0.0
% INFO    : Bus 5570	: V=0.9909728, theta=-69.364239 -> V=1.0, theta=0.0
% INFO    : Bus 5571	: V=0.9907305, theta=-69.530615 -> V=1.0, theta=0.0
% INFO    : Bus 5572	: V=0.9912416, theta=-69.358784 -> V=1.0, theta=0.0
% INFO    : Bus 5573	: V=0.9946692, theta=-69.07387 -> V=1.0, theta=0.0
% INFO    : Bus 5574	: V=0.9938022, theta=-67.310354 -> V=1.0, theta=0.0
% INFO    : Bus 5575	: V=0.9913269, theta=-69.40635 -> V=1.0, theta=0.0
% INFO    : Bus 5576	: V=0.9941009, theta=-67.284052 -> V=1.0, theta=0.0
% INFO    : Bus 5577	: V=0.9948806, theta=-69.643557 -> V=1.0, theta=0.0
% INFO    : Bus 5578	: V=0.983553, theta=-70.086775 -> V=1.0, theta=0.0
% INFO    : Bus 5579	: V=0.9947825, theta=-68.15407 -> V=1.0, theta=0.0
% INFO    : Bus 5580	: V=0.9827419, theta=-70.138078 -> V=1.0, theta=0.0
% INFO    : Bus 5581	: V=0.9902576, theta=-69.823454 -> V=1.0, theta=0.0
% INFO    : Bus 5582	: V=0.9882191, theta=-69.596634 -> V=1.0, theta=0.0
% INFO    : Bus 5583	: V=0.9863815, theta=-69.578797 -> V=1.0, theta=0.0
% INFO    : Bus 5584	: V=0.9862801, theta=-69.637329 -> V=1.0, theta=0.0
% INFO    : Bus 5585	: V=0.9853017, theta=-69.705385 -> V=1.0, theta=0.0
% INFO    : Bus 5586	: V=0.9845666, theta=-69.853298 -> V=1.0, theta=0.0
% INFO    : Bus 5587	: V=0.9859538, theta=-69.81816 -> V=1.0, theta=0.0
% INFO    : Bus 5588	: V=0.9888494, theta=-69.792252 -> V=1.0, theta=0.0
% INFO    : Bus 5589	: V=0.9871014, theta=-69.806359 -> V=1.0, theta=0.0
% INFO    : Bus 5590	: V=0.9945496, theta=-67.204071 -> V=1.0, theta=0.0
% INFO    : Bus 5591	: V=0.9922448, theta=-67.575608 -> V=1.0, theta=0.0
% INFO    : Bus 5592	: V=0.994768, theta=-69.578183 -> V=1.0, theta=0.0
% INFO    : Bus 5593	: V=0.9950052, theta=-69.514772 -> V=1.0, theta=0.0
% INFO    : Bus 5594	: V=0.9956397, theta=-67.025112 -> V=1.0, theta=0.0
% INFO    : Bus 5595	: V=0.9900546, theta=-69.214518 -> V=1.0, theta=0.0
% INFO    : Bus 5596	: V=0.9961493, theta=-69.019805 -> V=1.0, theta=0.0
% INFO    : Bus 5597	: V=0.9973875, theta=-66.712077 -> V=1.0, theta=0.0
% INFO    : Bus 5598	: V=0.9906501, theta=-69.093633 -> V=1.0, theta=0.0
% INFO    : Bus 5599	: V=0.9901301, theta=-69.381333 -> V=1.0, theta=0.0
% INFO    : Bus 5600	: V=0.9911455, theta=-69.081501 -> V=1.0, theta=0.0
% INFO    : Bus 5601	: V=0.995415, theta=-67.04675 -> V=1.0, theta=0.0
% INFO    : Bus 5602	: V=0.9908119, theta=-68.994179 -> V=1.0, theta=0.0
% INFO    : Bus 5603	: V=0.9987671, theta=-66.468165 -> V=1.0, theta=0.0
% INFO    : Bus 5604	: V=0.9998193, theta=-65.393497 -> V=1.0, theta=0.0
% INFO    : Bus 5605	: V=1.0024074, theta=-65.898923 -> V=1.0, theta=0.0
% INFO    : Bus 5606	: V=1.0004653, theta=-66.200268 -> V=1.0, theta=0.0
% INFO    : Bus 5607	: V=1.0028484, theta=-65.914853 -> V=1.0, theta=0.0
% INFO    : Bus 5608	: V=1.0109571, theta=-64.785265 -> V=1.0, theta=0.0
% INFO    : Bus 5609	: V=1.0054391, theta=-65.488277 -> V=1.0, theta=0.0
% INFO    : Bus 5610	: V=1.0080305, theta=-65.26619 -> V=1.0, theta=0.0
% INFO    : Bus 5611	: V=1.0019678, theta=-65.998363 -> V=1.0, theta=0.0
% INFO    : Bus 5612	: V=0.9884467, theta=-68.743846 -> V=1.0, theta=0.0
% INFO    : Bus 5613	: V=0.9912127, theta=-68.285995 -> V=1.0, theta=0.0
% INFO    : Bus 5614	: V=0.9911102, theta=-66.916399 -> V=1.0, theta=0.0
% INFO    : Bus 5615	: V=0.9892266, theta=-68.264977 -> V=1.0, theta=0.0
% INFO    : Bus 5616	: V=0.9824976, theta=-68.548708 -> V=1.0, theta=0.0
% INFO    : Bus 5617	: V=0.9890076, theta=-68.316637 -> V=1.0, theta=0.0
% INFO    : Bus 5618	: V=0.9896641, theta=-68.303063 -> V=1.0, theta=0.0
% INFO    : Bus 5619	: V=0.9949955, theta=-66.589788 -> V=1.0, theta=0.0
% INFO    : Bus 5620	: V=0.9831142, theta=-68.514193 -> V=1.0, theta=0.0
% INFO    : Bus 5621	: V=0.9822424, theta=-68.534645 -> V=1.0, theta=0.0
% INFO    : Bus 5622	: V=0.9836877, theta=-68.026957 -> V=1.0, theta=0.0
% INFO    : Bus 5623	: V=0.9803287, theta=-68.537505 -> V=1.0, theta=0.0
% INFO    : Bus 5624	: V=0.991643, theta=-66.988088 -> V=1.0, theta=0.0
% INFO    : Bus 5625	: V=0.9902289, theta=-67.130059 -> V=1.0, theta=0.0
% INFO    : Bus 5626	: V=0.9853414, theta=-68.280849 -> V=1.0, theta=0.0
% INFO    : Bus 5627	: V=0.9832679, theta=-68.496257 -> V=1.0, theta=0.0
% INFO    : Bus 5628	: V=0.9888259, theta=-67.249334 -> V=1.0, theta=0.0
% INFO    : Bus 5629	: V=0.9820722, theta=-68.60372 -> V=1.0, theta=0.0
% INFO    : Bus 5630	: V=0.9786685, theta=-68.813691 -> V=1.0, theta=0.0
% INFO    : Bus 5631	: V=0.9796138, theta=-68.787538 -> V=1.0, theta=0.0
% INFO    : Bus 5632	: V=0.9768388, theta=-68.865147 -> V=1.0, theta=0.0
% INFO    : Bus 5633	: V=0.9759187, theta=-68.890313 -> V=1.0, theta=0.0
% INFO    : Bus 5634	: V=0.9808152, theta=-68.67636 -> V=1.0, theta=0.0
% INFO    : Bus 5635	: V=0.9745401, theta=-69.551355 -> V=1.0, theta=0.0
% INFO    : Bus 5636	: V=0.9737143, theta=-69.487045 -> V=1.0, theta=0.0
% INFO    : Bus 5637	: V=0.9855413, theta=-69.126884 -> V=1.0, theta=0.0
% INFO    : Bus 5638	: V=0.9834232, theta=-69.291981 -> V=1.0, theta=0.0
% INFO    : Bus 5639	: V=0.9842257, theta=-69.270159 -> V=1.0, theta=0.0
% INFO    : Bus 5640	: V=0.9824058, theta=-69.210934 -> V=1.0, theta=0.0
% INFO    : Bus 5641	: V=0.9832642, theta=-69.187576 -> V=1.0, theta=0.0
% INFO    : Bus 5642	: V=0.9859318, theta=-68.678363 -> V=1.0, theta=0.0
% INFO    : Bus 5643	: V=0.981802, theta=-69.223692 -> V=1.0, theta=0.0
% INFO    : Bus 5644	: V=0.9827219, theta=-68.635983 -> V=1.0, theta=0.0
% INFO    : Bus 5645	: V=0.9891572, theta=-67.862875 -> V=1.0, theta=0.0
% INFO    : Bus 5646	: V=0.9925308, theta=-63.806234 -> V=1.0, theta=0.0
% INFO    : Bus 5647	: V=0.9805947, theta=-68.680277 -> V=1.0, theta=0.0
% INFO    : Bus 5648	: V=0.9884975, theta=-67.467521 -> V=1.0, theta=0.0
% INFO    : Bus 5649	: V=0.9818017, theta=-69.077554 -> V=1.0, theta=0.0
% INFO    : Bus 5650	: V=0.9797156, theta=-69.123887 -> V=1.0, theta=0.0
% INFO    : Bus 5651	: V=0.9758243, theta=-69.647433 -> V=1.0, theta=0.0
% INFO    : Bus 5652	: V=0.9921124, theta=-69.721542 -> V=1.0, theta=0.0
% INFO    : Bus 5653	: V=0.9840677, theta=-70.111792 -> V=1.0, theta=0.0
% INFO    : Bus 5654	: V=0.9755642, theta=-70.52834 -> V=1.0, theta=0.0
% INFO    : Bus 5655	: V=0.9872896, theta=-70.21402 -> V=1.0, theta=0.0
% INFO    : Bus 5656	: V=0.9808369, theta=-70.369478 -> V=1.0, theta=0.0
% INFO    : Bus 5657	: V=0.9849678, theta=-70.179982 -> V=1.0, theta=0.0
% INFO    : Bus 5658	: V=0.9840688, theta=-70.20438 -> V=1.0, theta=0.0
% INFO    : Bus 5659	: V=0.993321, theta=-69.800114 -> V=1.0, theta=0.0
% INFO    : Bus 5660	: V=0.9856001, theta=-70.069796 -> V=1.0, theta=0.0
% INFO    : Bus 5661	: V=0.9907226, theta=-69.984409 -> V=1.0, theta=0.0
% INFO    : Bus 5662	: V=0.9947107, theta=-69.615853 -> V=1.0, theta=0.0
% INFO    : Bus 5663	: V=0.993873, theta=-69.692372 -> V=1.0, theta=0.0
% INFO    : Bus 5664	: V=0.9953942, theta=-69.679933 -> V=1.0, theta=0.0
% INFO    : Bus 5665	: V=0.9962518, theta=-69.659438 -> V=1.0, theta=0.0
% INFO    : Bus 5666	: V=0.9956854, theta=-69.763873 -> V=1.0, theta=0.0
% INFO    : Bus 5667	: V=0.9897201, theta=-70.197013 -> V=1.0, theta=0.0
% INFO    : Bus 5668	: V=0.9907255, theta=-70.173169 -> V=1.0, theta=0.0
% INFO    : Bus 5669	: V=0.9951565, theta=-69.776636 -> V=1.0, theta=0.0
% INFO    : Bus 5670	: V=0.9933578, theta=-70.007006 -> V=1.0, theta=0.0
% INFO    : Bus 5671	: V=0.984774, theta=-70.231527 -> V=1.0, theta=0.0
% INFO    : Bus 5672	: V=0.9832961, theta=-70.241516 -> V=1.0, theta=0.0
% INFO    : Bus 5673	: V=0.9880675, theta=-68.771894 -> V=1.0, theta=0.0
% INFO    : Bus 5674	: V=0.9820551, theta=-70.212627 -> V=1.0, theta=0.0
% INFO    : Bus 5675	: V=0.9821087, theta=-70.191913 -> V=1.0, theta=0.0
% INFO    : Bus 5676	: V=0.983509, theta=-70.15475 -> V=1.0, theta=0.0
% INFO    : Bus 5677	: V=0.9913231, theta=-68.474368 -> V=1.0, theta=0.0
% INFO    : Bus 5678	: V=0.9822367, theta=-70.095817 -> V=1.0, theta=0.0
% INFO    : Bus 5679	: V=0.9791922, theta=-70.089577 -> V=1.0, theta=0.0
% INFO    : Bus 5680	: V=0.9783213, theta=-70.12215 -> V=1.0, theta=0.0
% INFO    : Bus 5681	: V=0.9779639, theta=-70.118649 -> V=1.0, theta=0.0
% INFO    : Bus 5682	: V=0.9805466, theta=-70.010665 -> V=1.0, theta=0.0
% INFO    : Bus 5683	: V=0.9872923, theta=-68.962703 -> V=1.0, theta=0.0
% INFO    : Bus 5684	: V=0.9877594, theta=-68.548565 -> V=1.0, theta=0.0
% INFO    : Bus 5685	: V=0.9760299, theta=-70.15955 -> V=1.0, theta=0.0
% INFO    : Bus 5686	: V=0.9719294, theta=-70.662316 -> V=1.0, theta=0.0
% INFO    : Bus 5687	: V=0.9685848, theta=-70.849439 -> V=1.0, theta=0.0
% INFO    : Bus 5688	: V=0.9698394, theta=-70.813833 -> V=1.0, theta=0.0
% INFO    : Bus 5689	: V=0.9778453, theta=-71.096662 -> V=1.0, theta=0.0
% INFO    : Bus 5690	: V=0.9738119, theta=-71.439137 -> V=1.0, theta=0.0
% INFO    : Bus 5691	: V=0.9805991, theta=-70.126949 -> V=1.0, theta=0.0
% INFO    : Bus 5692	: V=0.9759258, theta=-71.143822 -> V=1.0, theta=0.0
% INFO    : Bus 5693	: V=0.9888436, theta=-69.165598 -> V=1.0, theta=0.0
% INFO    : Bus 5694	: V=0.9702719, theta=-71.094705 -> V=1.0, theta=0.0
% INFO    : Bus 5695	: V=0.9718209, theta=-71.250418 -> V=1.0, theta=0.0
% INFO    : Bus 5696	: V=0.963048, theta=-72.365843 -> V=1.0, theta=0.0
% INFO    : Bus 5697	: V=0.9655687, theta=-72.239421 -> V=1.0, theta=0.0
% INFO    : Bus 5698	: V=0.9651502, theta=-72.242485 -> V=1.0, theta=0.0
% INFO    : Bus 5699	: V=0.9652447, theta=-72.225039 -> V=1.0, theta=0.0
% INFO    : Bus 5700	: V=0.9658101, theta=-72.106733 -> V=1.0, theta=0.0
% INFO    : Bus 5701	: V=0.9820773, theta=-69.989265 -> V=1.0, theta=0.0
% INFO    : Bus 5702	: V=0.9965354, theta=-66.861334 -> V=1.0, theta=0.0
% INFO    : Bus 5703	: V=0.9473706, theta=-72.445254 -> V=1.0, theta=0.0
% INFO    : Bus 5704	: V=0.9541149, theta=-71.838284 -> V=1.0, theta=0.0
% INFO    : Bus 5705	: V=0.9545261, theta=-71.801649 -> V=1.0, theta=0.0
% INFO    : Bus 5706	: V=0.9612827, theta=-70.273011 -> V=1.0, theta=0.0
% INFO    : Bus 5707	: V=0.9530838, theta=-71.941571 -> V=1.0, theta=0.0
% INFO    : Bus 5708	: V=0.9509843, theta=-72.107224 -> V=1.0, theta=0.0
% INFO    : Bus 5709	: V=0.9488685, theta=-72.357632 -> V=1.0, theta=0.0
% INFO    : Bus 5710	: V=0.9480613, theta=-72.425118 -> V=1.0, theta=0.0
% INFO    : Bus 5711	: V=0.9513692, theta=-72.096037 -> V=1.0, theta=0.0
% INFO    : Bus 5712	: V=0.9552059, theta=-71.482593 -> V=1.0, theta=0.0
% INFO    : Bus 5713	: V=0.9630016, theta=-69.882672 -> V=1.0, theta=0.0
% INFO    : Bus 5714	: V=0.9698976, theta=-69.006556 -> V=1.0, theta=0.0
% INFO    : Bus 5715	: V=0.9654722, theta=-67.40512 -> V=1.0, theta=0.0
% INFO    : Bus 5716	: V=0.9668873, theta=-67.233479 -> V=1.0, theta=0.0
% INFO    : Bus 5717	: V=0.9569646, theta=-70.586663 -> V=1.0, theta=0.0
% INFO    : Bus 5718	: V=0.9554067, theta=-71.062644 -> V=1.0, theta=0.0
% INFO    : Bus 5719	: V=0.9893545, theta=-64.850575 -> V=1.0, theta=0.0
% INFO    : Bus 5720	: V=0.9886597, theta=-64.92483 -> V=1.0, theta=0.0
% INFO    : Bus 5721	: V=0.9880775, theta=-64.984274 -> V=1.0, theta=0.0
% INFO    : Bus 5722	: V=0.9858594, theta=-65.185421 -> V=1.0, theta=0.0
% INFO    : Bus 5723	: V=0.9800714, theta=-66.47987 -> V=1.0, theta=0.0
% INFO    : Bus 5724	: V=0.987557, theta=-65.03707 -> V=1.0, theta=0.0
% INFO    : Bus 5725	: V=0.9865653, theta=-65.099808 -> V=1.0, theta=0.0
% INFO    : Bus 5726	: V=0.9768091, theta=-66.634654 -> V=1.0, theta=0.0
% INFO    : Bus 5727	: V=1.0002395, theta=-64.196161 -> V=1.0, theta=0.0
% INFO    : Bus 5728	: V=0.9920126, theta=-64.608673 -> V=1.0, theta=0.0
% INFO    : Bus 5729	: V=0.9932036, theta=-64.475291 -> V=1.0, theta=0.0
% INFO    : Bus 5730	: V=0.9953726, theta=-64.318954 -> V=1.0, theta=0.0
% INFO    : Bus 5731	: V=0.9905359, theta=-64.835594 -> V=1.0, theta=0.0
% INFO    : Bus 5732	: V=1.0053489, theta=-63.803223 -> V=1.0, theta=0.0
% INFO    : Bus 5733	: V=1.0033019, theta=-63.880555 -> V=1.0, theta=0.0
% INFO    : Bus 5734	: V=1.0040838, theta=-63.86978 -> V=1.0, theta=0.0
% INFO    : Bus 5735	: V=1.0036823, theta=-63.873621 -> V=1.0, theta=0.0
% INFO    : Bus 5736	: V=0.9904151, theta=-64.803315 -> V=1.0, theta=0.0
% INFO    : Bus 5737	: V=1.0033154, theta=-63.877026 -> V=1.0, theta=0.0
% INFO    : Bus 5738	: V=0.9978678, theta=-64.130491 -> V=1.0, theta=0.0
% INFO    : Bus 5739	: V=0.9871866, theta=-66.07336 -> V=1.0, theta=0.0
% INFO    : Bus 5740	: V=0.9903015, theta=-65.231107 -> V=1.0, theta=0.0
% INFO    : Bus 5741	: V=0.996301, theta=-64.174388 -> V=1.0, theta=0.0
% INFO    : Bus 5742	: V=0.9826315, theta=-66.011932 -> V=1.0, theta=0.0
% INFO    : Bus 5743	: V=0.9945181, theta=-64.219056 -> V=1.0, theta=0.0
% INFO    : Bus 5744	: V=0.995106, theta=-64.176835 -> V=1.0, theta=0.0
% INFO    : Bus 5745	: V=0.994355, theta=-63.970016 -> V=1.0, theta=0.0
% INFO    : Bus 5746	: V=0.9820153, theta=-65.402327 -> V=1.0, theta=0.0
% INFO    : Bus 5747	: V=0.9772774, theta=-66.572265 -> V=1.0, theta=0.0
% INFO    : Bus 5748	: V=0.9785669, theta=-66.415667 -> V=1.0, theta=0.0
% INFO    : Bus 5749	: V=0.9857375, theta=-65.054399 -> V=1.0, theta=0.0
% INFO    : Bus 5750	: V=0.984242, theta=-65.190093 -> V=1.0, theta=0.0
% INFO    : Bus 5751	: V=0.9784852, theta=-66.423084 -> V=1.0, theta=0.0
% INFO    : Bus 5752	: V=0.9804652, theta=-66.202772 -> V=1.0, theta=0.0
% INFO    : Bus 5753	: V=0.9807721, theta=-66.172385 -> V=1.0, theta=0.0
% INFO    : Bus 5754	: V=0.9801719, theta=-66.175393 -> V=1.0, theta=0.0
% INFO    : Bus 5755	: V=0.9819842, theta=-66.02289 -> V=1.0, theta=0.0
% INFO    : Bus 5756	: V=0.9816588, theta=-66.032135 -> V=1.0, theta=0.0
% INFO    : Bus 5757	: V=0.9895447, theta=-65.477552 -> V=1.0, theta=0.0
% INFO    : Bus 5758	: V=0.9811171, theta=-66.123555 -> V=1.0, theta=0.0
% INFO    : Bus 5759	: V=0.9896677, theta=-64.53093 -> V=1.0, theta=0.0
% INFO    : Bus 5760	: V=0.9952515, theta=-64.024351 -> V=1.0, theta=0.0
% INFO    : Bus 5761	: V=0.9960859, theta=-63.874246 -> V=1.0, theta=0.0
% INFO    : Bus 5762	: V=0.991269, theta=-64.039366 -> V=1.0, theta=0.0
% INFO    : Bus 5763	: V=0.993466, theta=-63.83562 -> V=1.0, theta=0.0
% INFO    : Bus 5764	: V=0.9937297, theta=-63.829037 -> V=1.0, theta=0.0
% INFO    : Bus 5765	: V=0.9920346, theta=-64.019076 -> V=1.0, theta=0.0
% INFO    : Bus 5766	: V=0.9902056, theta=-64.194373 -> V=1.0, theta=0.0
% INFO    : Bus 5767	: V=0.9898853, theta=-64.201927 -> V=1.0, theta=0.0
% INFO    : Bus 5768	: V=0.9897498, theta=-64.205166 -> V=1.0, theta=0.0
% INFO    : Bus 5769	: V=0.9755861, theta=-66.79958 -> V=1.0, theta=0.0
% INFO    : Bus 5770	: V=0.9789554, theta=-66.048704 -> V=1.0, theta=0.0
% INFO    : Bus 5771	: V=0.9823868, theta=-65.361914 -> V=1.0, theta=0.0
% INFO    : Bus 5772	: V=0.9795366, theta=-66.032897 -> V=1.0, theta=0.0
% INFO    : Bus 5773	: V=0.9831806, theta=-65.286345 -> V=1.0, theta=0.0
% INFO    : Bus 5774	: V=0.9794955, theta=-66.014529 -> V=1.0, theta=0.0
% INFO    : Bus 5775	: V=0.9806757, theta=-65.544438 -> V=1.0, theta=0.0
% INFO    : Bus 5776	: V=0.98102, theta=-65.500388 -> V=1.0, theta=0.0
% INFO    : Bus 5777	: V=0.9818614, theta=-65.400773 -> V=1.0, theta=0.0
% INFO    : Bus 5778	: V=0.9775137, theta=-66.586285 -> V=1.0, theta=0.0
% INFO    : Bus 5779	: V=0.982655, theta=-65.290726 -> V=1.0, theta=0.0
% INFO    : Bus 5780	: V=0.9797565, theta=-66.213112 -> V=1.0, theta=0.0
% INFO    : Bus 5781	: V=0.9803454, theta=-66.200224 -> V=1.0, theta=0.0
% INFO    : Bus 5782	: V=0.9832507, theta=-65.211891 -> V=1.0, theta=0.0
% INFO    : Bus 5783	: V=0.9878792, theta=-64.485427 -> V=1.0, theta=0.0
% INFO    : Bus 5784	: V=0.9873659, theta=-64.539148 -> V=1.0, theta=0.0
% INFO    : Bus 5785	: V=0.9870267, theta=-64.575146 -> V=1.0, theta=0.0
% INFO    : Bus 5786	: V=0.9810079, theta=-66.154381 -> V=1.0, theta=0.0
% INFO    : Bus 5787	: V=0.9810387, theta=-66.167921 -> V=1.0, theta=0.0
% INFO    : Bus 5788	: V=0.9859578, theta=-64.866087 -> V=1.0, theta=0.0
% INFO    : Bus 5789	: V=0.9827887, theta=-66.026986 -> V=1.0, theta=0.0
% INFO    : Bus 5790	: V=0.9894011, theta=-64.334214 -> V=1.0, theta=0.0
% INFO    : Bus 5791	: V=0.9834732, theta=-65.978136 -> V=1.0, theta=0.0
% INFO    : Bus 5792	: V=0.9842681, theta=-66.080299 -> V=1.0, theta=0.0
% INFO    : Bus 5793	: V=0.9784005, theta=-66.18406 -> V=1.0, theta=0.0
% INFO    : Bus 5794	: V=0.9810732, theta=-66.015954 -> V=1.0, theta=0.0
% INFO    : Bus 5795	: V=0.9823025, theta=-65.890116 -> V=1.0, theta=0.0
% INFO    : Bus 5796	: V=0.9858603, theta=-65.611163 -> V=1.0, theta=0.0
% INFO    : Bus 5797	: V=0.9837742, theta=-65.814852 -> V=1.0, theta=0.0
% INFO    : Bus 5798	: V=0.990239, theta=-64.248744 -> V=1.0, theta=0.0
% INFO    : Bus 5799	: V=0.9908461, theta=-64.189431 -> V=1.0, theta=0.0
% INFO    : Bus 5800	: V=0.9910287, theta=-64.165715 -> V=1.0, theta=0.0
% INFO    : Bus 5801	: V=0.9913504, theta=-64.12432 -> V=1.0, theta=0.0
% INFO    : Bus 5802	: V=0.9838022, theta=-65.74119 -> V=1.0, theta=0.0
% INFO    : Bus 5803	: V=0.9841068, theta=-65.659138 -> V=1.0, theta=0.0
% INFO    : Bus 5804	: V=0.9845439, theta=-65.56773 -> V=1.0, theta=0.0
% INFO    : Bus 5805	: V=0.9859475, theta=-65.103727 -> V=1.0, theta=0.0
% INFO    : Bus 5806	: V=0.9857297, theta=-65.109555 -> V=1.0, theta=0.0
% INFO    : Bus 5807	: V=0.9865897, theta=-65.228024 -> V=1.0, theta=0.0
% INFO    : Bus 5808	: V=1.0032043, theta=-62.310114 -> V=1.0, theta=0.0
% INFO    : Bus 5809	: V=0.9924434, theta=-64.023701 -> V=1.0, theta=0.0
% INFO    : Bus 5810	: V=0.9869198, theta=-65.219147 -> V=1.0, theta=0.0
% INFO    : Bus 5811	: V=0.9867765, theta=-63.824274 -> V=1.0, theta=0.0
% INFO    : Bus 5812	: V=0.9850381, theta=-65.476975 -> V=1.0, theta=0.0
% INFO    : Bus 5813	: V=0.986418, theta=-63.895823 -> V=1.0, theta=0.0
% INFO    : Bus 5814	: V=0.9901941, theta=-64.212693 -> V=1.0, theta=0.0
% INFO    : Bus 5815	: V=0.9931782, theta=-63.822912 -> V=1.0, theta=0.0
% INFO    : Bus 5816	: V=0.9928238, theta=-63.625403 -> V=1.0, theta=0.0
% INFO    : Bus 5817	: V=0.9929157, theta=-63.694535 -> V=1.0, theta=0.0
% INFO    : Bus 5818	: V=0.9870295, theta=-63.779428 -> V=1.0, theta=0.0
% INFO    : Bus 5819	: V=0.9873992, theta=-63.7125 -> V=1.0, theta=0.0
% INFO    : Bus 5820	: V=0.9824026, theta=-65.091629 -> V=1.0, theta=0.0
% INFO    : Bus 5821	: V=0.9879707, theta=-63.616883 -> V=1.0, theta=0.0
% INFO    : Bus 5822	: V=0.9836578, theta=-64.793879 -> V=1.0, theta=0.0
% INFO    : Bus 5823	: V=0.9817194, theta=-65.272173 -> V=1.0, theta=0.0
% INFO    : Bus 5824	: V=0.9816661, theta=-65.110894 -> V=1.0, theta=0.0
% INFO    : Bus 5825	: V=0.9877174, theta=-64.576947 -> V=1.0, theta=0.0
% INFO    : Bus 5826	: V=0.9855313, theta=-64.548536 -> V=1.0, theta=0.0
% INFO    : Bus 5827	: V=0.9888791, theta=-64.191187 -> V=1.0, theta=0.0
% INFO    : Bus 5828	: V=0.9852092, theta=-64.615149 -> V=1.0, theta=0.0
% INFO    : Bus 5829	: V=0.9874914, theta=-64.406443 -> V=1.0, theta=0.0
% INFO    : Bus 5830	: V=0.9847806, theta=-64.680747 -> V=1.0, theta=0.0
% INFO    : Bus 5831	: V=0.9861919, theta=-64.552153 -> V=1.0, theta=0.0
% INFO    : Bus 5832	: V=0.9848149, theta=-64.763068 -> V=1.0, theta=0.0
% INFO    : Bus 5833	: V=0.9845603, theta=-64.755591 -> V=1.0, theta=0.0
% INFO    : Bus 5834	: V=0.9846301, theta=-64.73275 -> V=1.0, theta=0.0
% INFO    : Bus 5835	: V=0.9832352, theta=-65.001371 -> V=1.0, theta=0.0
% INFO    : Bus 5836	: V=0.9908424, theta=-63.309882 -> V=1.0, theta=0.0
% INFO    : Bus 5837	: V=0.9768175, theta=-66.729553 -> V=1.0, theta=0.0
% INFO    : Bus 5838	: V=0.976308, theta=-66.784644 -> V=1.0, theta=0.0
% INFO    : Bus 5839	: V=0.979658, theta=-66.591069 -> V=1.0, theta=0.0
% INFO    : Bus 5840	: V=0.9821061, theta=-66.422136 -> V=1.0, theta=0.0
% INFO    : Bus 5841	: V=0.9826038, theta=-66.39683 -> V=1.0, theta=0.0
% INFO    : Bus 5842	: V=0.9765049, theta=-66.814196 -> V=1.0, theta=0.0
% INFO    : Bus 5843	: V=0.9770595, theta=-66.806197 -> V=1.0, theta=0.0
% INFO    : Bus 5844	: V=0.9784334, theta=-66.742209 -> V=1.0, theta=0.0
% INFO    : Bus 5845	: V=0.978709, theta=-66.700576 -> V=1.0, theta=0.0
% INFO    : Bus 5846	: V=0.9896856, theta=-65.396147 -> V=1.0, theta=0.0
% INFO    : Bus 5847	: V=0.9892413, theta=-65.408276 -> V=1.0, theta=0.0
% INFO    : Bus 5848	: V=0.98761, theta=-65.539834 -> V=1.0, theta=0.0
% INFO    : Bus 5849	: V=0.987395, theta=-65.731828 -> V=1.0, theta=0.0
% INFO    : Bus 5850	: V=0.9904664, theta=-65.889783 -> V=1.0, theta=0.0
% INFO    : Bus 5851	: V=0.9863189, theta=-65.816561 -> V=1.0, theta=0.0
% INFO    : Bus 5852	: V=0.9764263, theta=-67.215053 -> V=1.0, theta=0.0
% INFO    : Bus 5853	: V=0.9790404, theta=-66.757754 -> V=1.0, theta=0.0
% INFO    : Bus 5854	: V=0.9798483, theta=-66.731272 -> V=1.0, theta=0.0
% INFO    : Bus 5855	: V=0.9835252, theta=-66.387364 -> V=1.0, theta=0.0
% INFO    : Bus 5856	: V=0.9765339, theta=-67.225987 -> V=1.0, theta=0.0
% INFO    : Bus 5857	: V=0.9919846, theta=-65.18699 -> V=1.0, theta=0.0
% INFO    : Bus 5858	: V=0.9839332, theta=-66.311078 -> V=1.0, theta=0.0
% INFO    : Bus 5859	: V=0.9894114, theta=-65.621573 -> V=1.0, theta=0.0
% INFO    : Bus 5860	: V=0.9912954, theta=-65.27395 -> V=1.0, theta=0.0
% INFO    : Bus 5861	: V=0.9864385, theta=-66.164476 -> V=1.0, theta=0.0
% INFO    : Bus 5862	: V=0.9933963, theta=-65.114688 -> V=1.0, theta=0.0
% INFO    : Bus 5863	: V=0.9850425, theta=-66.304869 -> V=1.0, theta=0.0
% INFO    : Bus 5864	: V=0.9857785, theta=-66.16802 -> V=1.0, theta=0.0
% INFO    : Bus 5865	: V=0.9955272, theta=-64.86768 -> V=1.0, theta=0.0
% INFO    : Bus 5866	: V=0.9924989, theta=-65.188164 -> V=1.0, theta=0.0
% INFO    : Bus 5867	: V=0.9854987, theta=-66.118548 -> V=1.0, theta=0.0
% INFO    : Bus 5868	: V=0.9880224, theta=-65.34085 -> V=1.0, theta=0.0
% INFO    : Bus 5869	: V=0.9921319, theta=-65.103814 -> V=1.0, theta=0.0
% INFO    : Bus 5870	: V=0.9883386, theta=-65.33238 -> V=1.0, theta=0.0
% INFO    : Bus 5871	: V=0.9863451, theta=-65.323377 -> V=1.0, theta=0.0
% INFO    : Bus 5872	: V=0.9856832, theta=-66.216999 -> V=1.0, theta=0.0
% INFO    : Bus 5873	: V=0.9963277, theta=-64.881354 -> V=1.0, theta=0.0
% INFO    : Bus 5874	: V=0.9900938, theta=-65.175275 -> V=1.0, theta=0.0
% INFO    : Bus 5875	: V=0.9988568, theta=-64.679049 -> V=1.0, theta=0.0
% INFO    : Bus 5876	: V=0.9961392, theta=-64.775122 -> V=1.0, theta=0.0
% INFO    : Bus 5877	: V=1.0168137, theta=-62.073386 -> V=1.0, theta=0.0
% INFO    : Bus 5878	: V=0.9894659, theta=-65.255695 -> V=1.0, theta=0.0
% INFO    : Bus 5879	: V=0.9900711, theta=-65.156237 -> V=1.0, theta=0.0
% INFO    : Bus 5880	: V=0.9909948, theta=-65.123335 -> V=1.0, theta=0.0
% INFO    : Bus 5881	: V=0.9953759, theta=-64.760246 -> V=1.0, theta=0.0
% INFO    : Bus 5882	: V=0.9946077, theta=-64.793288 -> V=1.0, theta=0.0
% INFO    : Bus 5883	: V=0.9871893, theta=-65.306106 -> V=1.0, theta=0.0
% INFO    : Bus 5884	: V=0.9867475, theta=-65.286064 -> V=1.0, theta=0.0
% INFO    : Bus 5885	: V=0.9823489, theta=-65.439374 -> V=1.0, theta=0.0
% INFO    : Bus 5886	: V=0.9867382, theta=-65.312589 -> V=1.0, theta=0.0
% INFO    : Bus 5887	: V=0.9867034, theta=-65.282788 -> V=1.0, theta=0.0
% INFO    : Bus 5888	: V=0.9863623, theta=-65.322655 -> V=1.0, theta=0.0
% INFO    : Bus 5889	: V=0.9882652, theta=-65.213266 -> V=1.0, theta=0.0
% INFO    : Bus 5890	: V=0.9889942, theta=-65.160839 -> V=1.0, theta=0.0
% INFO    : Bus 5891	: V=0.9906836, theta=-65.058684 -> V=1.0, theta=0.0
% INFO    : Bus 5892	: V=0.9919512, theta=-64.970676 -> V=1.0, theta=0.0
% INFO    : Bus 5893	: V=0.9941916, theta=-64.806202 -> V=1.0, theta=0.0
% INFO    : Bus 5894	: V=0.993851, theta=-64.798285 -> V=1.0, theta=0.0
% INFO    : Bus 5895	: V=0.9811332, theta=-65.386148 -> V=1.0, theta=0.0
% INFO    : Bus 5896	: V=0.9801163, theta=-65.427688 -> V=1.0, theta=0.0
% INFO    : Bus 5897	: V=0.9792969, theta=-65.452573 -> V=1.0, theta=0.0
% INFO    : Bus 5898	: V=0.9786163, theta=-65.490284 -> V=1.0, theta=0.0
% INFO    : Bus 5899	: V=0.9805947, theta=-65.528236 -> V=1.0, theta=0.0
% INFO    : Bus 5900	: V=0.9785633, theta=-65.726597 -> V=1.0, theta=0.0
% INFO    : Bus 5901	: V=0.9864815, theta=-65.233116 -> V=1.0, theta=0.0
% INFO    : Bus 5902	: V=0.9793799, theta=-65.575022 -> V=1.0, theta=0.0
% INFO    : Bus 5903	: V=0.9784339, theta=-65.691649 -> V=1.0, theta=0.0
% INFO    : Bus 5904	: V=0.9784476, theta=-65.576493 -> V=1.0, theta=0.0
% INFO    : Bus 5905	: V=0.9779048, theta=-65.655909 -> V=1.0, theta=0.0
% INFO    : Bus 5906	: V=0.9775932, theta=-65.638948 -> V=1.0, theta=0.0
% INFO    : Bus 5907	: V=0.9817896, theta=-64.989433 -> V=1.0, theta=0.0
% INFO    : Bus 5908	: V=0.9801964, theta=-65.430113 -> V=1.0, theta=0.0
% INFO    : Bus 5909	: V=0.9775923, theta=-65.574523 -> V=1.0, theta=0.0
% INFO    : Bus 5910	: V=0.9803777, theta=-65.281304 -> V=1.0, theta=0.0
% INFO    : Bus 5911	: V=0.9778634, theta=-65.471891 -> V=1.0, theta=0.0
% INFO    : Bus 5912	: V=0.9771087, theta=-65.550966 -> V=1.0, theta=0.0
% INFO    : Bus 5913	: V=0.9839104, theta=-66.376934 -> V=1.0, theta=0.0
% INFO    : Bus 5914	: V=1.0066282, theta=-63.703564 -> V=1.0, theta=0.0
% INFO    : Bus 5915	: V=0.9924052, theta=-65.281815 -> V=1.0, theta=0.0
% INFO    : Bus 5916	: V=0.9952918, theta=-64.994837 -> V=1.0, theta=0.0
% INFO    : Bus 5917	: V=0.9930748, theta=-65.392144 -> V=1.0, theta=0.0
% INFO    : Bus 5918	: V=0.9982674, theta=-64.700902 -> V=1.0, theta=0.0
% INFO    : Bus 5919	: V=0.9967783, theta=-64.5101 -> V=1.0, theta=0.0
% INFO    : Bus 5920	: V=0.9987249, theta=-64.340723 -> V=1.0, theta=0.0
% INFO    : Bus 5921	: V=0.9984188, theta=-64.347835 -> V=1.0, theta=0.0
% INFO    : Bus 5922	: V=1.0014736, theta=-64.128099 -> V=1.0, theta=0.0
% INFO    : Bus 5923	: V=1.0002514, theta=-64.231155 -> V=1.0, theta=0.0
% INFO    : Bus 5924	: V=1.0046106, theta=-63.851302 -> V=1.0, theta=0.0
% INFO    : Bus 5925	: V=0.980762, theta=-64.887057 -> V=1.0, theta=0.0
% INFO    : Bus 5926	: V=0.9850488, theta=-64.733625 -> V=1.0, theta=0.0
% INFO    : Bus 5927	: V=0.9812367, theta=-64.874109 -> V=1.0, theta=0.0
% INFO    : Bus 5928	: V=0.9860876, theta=-64.053138 -> V=1.0, theta=0.0
% INFO    : Bus 5929	: V=0.9838431, theta=-64.763476 -> V=1.0, theta=0.0
% INFO    : Bus 5930	: V=0.9827384, theta=-64.79062 -> V=1.0, theta=0.0
% INFO    : Bus 5931	: V=0.987885, theta=-64.580468 -> V=1.0, theta=0.0
% INFO    : Bus 5932	: V=0.9998076, theta=-63.998532 -> V=1.0, theta=0.0
% INFO    : Bus 5933	: V=0.9874388, theta=-64.60729 -> V=1.0, theta=0.0
% INFO    : Bus 5934	: V=0.9908725, theta=-63.498087 -> V=1.0, theta=0.0
% INFO    : Bus 5935	: V=0.9912465, theta=-63.60265 -> V=1.0, theta=0.0
% INFO    : Bus 5936	: V=0.9813245, theta=-64.749275 -> V=1.0, theta=0.0
% INFO    : Bus 5937	: V=0.9818443, theta=-64.72831 -> V=1.0, theta=0.0
% INFO    : Bus 5938	: V=0.9800292, theta=-64.781827 -> V=1.0, theta=0.0
% INFO    : Bus 5939	: V=0.9819198, theta=-62.341761 -> V=1.0, theta=0.0
% INFO    : Bus 5940	: V=0.9914536, theta=-63.279842 -> V=1.0, theta=0.0
% INFO    : Bus 5941	: V=0.983362, theta=-64.42036 -> V=1.0, theta=0.0
% INFO    : Bus 5942	: V=0.9923451, theta=-62.890094 -> V=1.0, theta=0.0
% INFO    : Bus 5943	: V=0.9904665, theta=-62.278921 -> V=1.0, theta=0.0
% INFO    : Bus 5944	: V=0.9909893, theta=-62.331603 -> V=1.0, theta=0.0
% INFO    : Bus 5945	: V=0.9824172, theta=-63.83741 -> V=1.0, theta=0.0
% INFO    : Bus 5946	: V=0.9830273, theta=-63.592648 -> V=1.0, theta=0.0
% INFO    : Bus 5947	: V=0.9871105, theta=-64.409188 -> V=1.0, theta=0.0
% INFO    : Bus 5948	: V=0.9838737, theta=-64.570549 -> V=1.0, theta=0.0
% INFO    : Bus 5949	: V=0.9843554, theta=-64.560572 -> V=1.0, theta=0.0
% INFO    : Bus 5950	: V=0.9825589, theta=-64.656932 -> V=1.0, theta=0.0
% INFO    : Bus 5951	: V=0.9818503, theta=-64.674043 -> V=1.0, theta=0.0
% INFO    : Bus 5952	: V=0.9861858, theta=-64.383099 -> V=1.0, theta=0.0
% INFO    : Bus 5953	: V=0.9929318, theta=-63.416857 -> V=1.0, theta=0.0
% INFO    : Bus 5954	: V=0.9861205, theta=-64.532855 -> V=1.0, theta=0.0
% INFO    : Bus 5955	: V=0.9935227, theta=-63.13652 -> V=1.0, theta=0.0
% INFO    : Bus 5956	: V=0.9883852, theta=-62.8298 -> V=1.0, theta=0.0
% INFO    : Bus 5957	: V=0.9874601, theta=-64.125705 -> V=1.0, theta=0.0
% INFO    : Bus 5958	: V=0.9834434, theta=-63.7104 -> V=1.0, theta=0.0
% INFO    : Bus 5959	: V=0.9889512, theta=-62.718482 -> V=1.0, theta=0.0
% INFO    : Bus 5960	: V=0.9894456, theta=-62.65583 -> V=1.0, theta=0.0
% INFO    : Bus 5961	: V=0.9918307, theta=-62.366352 -> V=1.0, theta=0.0
% INFO    : Bus 5962	: V=0.9844334, theta=-63.161876 -> V=1.0, theta=0.0
% INFO    : Bus 5963	: V=0.9903247, theta=-62.542632 -> V=1.0, theta=0.0
% INFO    : Bus 5964	: V=0.9858543, theta=-63.812538 -> V=1.0, theta=0.0
% INFO    : Bus 5965	: V=0.9857286, theta=-63.861184 -> V=1.0, theta=0.0
% INFO    : Bus 5966	: V=0.985348, theta=-63.825974 -> V=1.0, theta=0.0
% INFO    : Bus 5967	: V=0.9937498, theta=-62.911855 -> V=1.0, theta=0.0
% INFO    : Bus 5968	: V=0.993162, theta=-62.860847 -> V=1.0, theta=0.0
% INFO    : Bus 5969	: V=0.993767, theta=-62.569792 -> V=1.0, theta=0.0
% INFO    : Bus 5970	: V=0.9846709, theta=-64.671497 -> V=1.0, theta=0.0
% INFO    : Bus 5971	: V=0.9917131, theta=-63.019864 -> V=1.0, theta=0.0
% INFO    : Bus 5972	: V=0.9845425, theta=-64.092272 -> V=1.0, theta=0.0
% INFO    : Bus 5973	: V=0.9839505, theta=-64.162995 -> V=1.0, theta=0.0
% INFO    : Bus 5974	: V=0.9832712, theta=-64.181304 -> V=1.0, theta=0.0
% INFO    : Bus 5975	: V=0.9830139, theta=-64.322582 -> V=1.0, theta=0.0
% INFO    : Bus 5976	: V=0.9827867, theta=-64.389534 -> V=1.0, theta=0.0
% INFO    : Bus 5977	: V=0.9840618, theta=-64.778168 -> V=1.0, theta=0.0
% INFO    : Bus 5978	: V=0.983342, theta=-64.857229 -> V=1.0, theta=0.0
% INFO    : Bus 5979	: V=0.9821081, theta=-64.980883 -> V=1.0, theta=0.0
% INFO    : Bus 5980	: V=0.9812667, theta=-65.01332 -> V=1.0, theta=0.0
% INFO    : Bus 5981	: V=0.9815259, theta=-64.996758 -> V=1.0, theta=0.0
% INFO    : Bus 5982	: V=0.979035, theta=-65.24999 -> V=1.0, theta=0.0
% INFO    : Bus 5983	: V=0.9784528, theta=-65.264421 -> V=1.0, theta=0.0
% INFO    : Bus 5984	: V=0.9766985, theta=-65.540649 -> V=1.0, theta=0.0
% INFO    : Bus 5985	: V=0.9766461, theta=-65.4954 -> V=1.0, theta=0.0
% INFO    : Bus 5986	: V=0.9794667, theta=-64.69213 -> V=1.0, theta=0.0
% INFO    : Bus 5987	: V=0.9790478, theta=-64.704827 -> V=1.0, theta=0.0
% INFO    : Bus 5988	: V=0.9795796, theta=-64.690159 -> V=1.0, theta=0.0
% INFO    : Bus 5989	: V=0.9769656, theta=-65.422378 -> V=1.0, theta=0.0
% INFO    : Bus 5990	: V=0.9799094, theta=-64.681192 -> V=1.0, theta=0.0
% INFO    : Bus 5991	: V=0.9781316, theta=-65.200767 -> V=1.0, theta=0.0
% INFO    : Bus 5992	: V=0.9729373, theta=-65.576278 -> V=1.0, theta=0.0
% INFO    : Bus 5993	: V=0.9836065, theta=-63.763535 -> V=1.0, theta=0.0
% INFO    : Bus 5994	: V=0.9791111, theta=-65.336894 -> V=1.0, theta=0.0
% INFO    : Bus 5995	: V=0.9816017, theta=-65.956625 -> V=1.0, theta=0.0
% INFO    : Bus 5996	: V=0.990763, theta=-64.237376 -> V=1.0, theta=0.0
% INFO    : Bus 5997	: V=0.9909959, theta=-63.639452 -> V=1.0, theta=0.0
% INFO    : Bus 5998	: V=0.9902205, theta=-63.529003 -> V=1.0, theta=0.0
% INFO    : Bus 5999	: V=0.9927369, theta=-64.186046 -> V=1.0, theta=0.0
% INFO    : Bus 6000	: V=0.9975778, theta=-63.16551 -> V=1.0, theta=0.0
% INFO    : Bus 6001	: V=1.00166, theta=-63.095372 -> V=1.0, theta=0.0
% INFO    : Bus 6002	: V=0.990014, theta=-63.947691 -> V=1.0, theta=0.0
% INFO    : Bus 6003	: V=1.0011807, theta=-63.110981 -> V=1.0, theta=0.0
% INFO    : Bus 6004	: V=0.9898017, theta=-63.926874 -> V=1.0, theta=0.0
% INFO    : Bus 6005	: V=0.9918689, theta=-64.381951 -> V=1.0, theta=0.0
% INFO    : Bus 6006	: V=0.9952629, theta=-64.007114 -> V=1.0, theta=0.0
% INFO    : Bus 6007	: V=1.0014075, theta=-63.076731 -> V=1.0, theta=0.0
% INFO    : Bus 6008	: V=0.9887154, theta=-64.120189 -> V=1.0, theta=0.0
% INFO    : Bus 6009	: V=0.9931186, theta=-64.161911 -> V=1.0, theta=0.0
% INFO    : Bus 6010	: V=0.9938541, theta=-64.117716 -> V=1.0, theta=0.0
% INFO    : Bus 6011	: V=1.0006743, theta=-63.131071 -> V=1.0, theta=0.0
% INFO    : Bus 6012	: V=0.9902764, theta=-63.946985 -> V=1.0, theta=0.0
% INFO    : Bus 6013	: V=0.9916136, theta=-64.259448 -> V=1.0, theta=0.0
% INFO    : Bus 6014	: V=0.9911937, theta=-64.293003 -> V=1.0, theta=0.0
% INFO    : Bus 6015	: V=0.9958726, theta=-63.953302 -> V=1.0, theta=0.0
% INFO    : Bus 6016	: V=0.9916438, theta=-63.882648 -> V=1.0, theta=0.0
% INFO    : Bus 6017	: V=1.0019838, theta=-63.057957 -> V=1.0, theta=0.0
% INFO    : Bus 6018	: V=1.0024609, theta=-63.043161 -> V=1.0, theta=0.0
% INFO    : Bus 6019	: V=0.996403, theta=-63.896275 -> V=1.0, theta=0.0
% INFO    : Bus 6020	: V=0.9904639, theta=-64.391737 -> V=1.0, theta=0.0
% INFO    : Bus 6021	: V=1.0028318, theta=-63.030836 -> V=1.0, theta=0.0
% INFO    : Bus 6022	: V=1.0033209, theta=-63.011219 -> V=1.0, theta=0.0
% INFO    : Bus 6023	: V=0.9900453, theta=-64.445811 -> V=1.0, theta=0.0
% INFO    : Bus 6024	: V=1.004022, theta=-62.981534 -> V=1.0, theta=0.0
% INFO    : Bus 6025	: V=0.989647, theta=-64.478019 -> V=1.0, theta=0.0
% INFO    : Bus 6026	: V=0.9937631, theta=-64.131697 -> V=1.0, theta=0.0
% INFO    : Bus 6027	: V=0.9937761, theta=-64.136551 -> V=1.0, theta=0.0
% INFO    : Bus 6028	: V=0.9887195, theta=-64.547428 -> V=1.0, theta=0.0
% INFO    : Bus 6029	: V=0.9939448, theta=-64.130704 -> V=1.0, theta=0.0
% INFO    : Bus 6030	: V=0.9889612, theta=-64.533302 -> V=1.0, theta=0.0
% INFO    : Bus 6031	: V=0.9942121, theta=-64.107081 -> V=1.0, theta=0.0
% INFO    : Bus 6032	: V=0.9906702, theta=-64.363232 -> V=1.0, theta=0.0
% INFO    : Bus 6033	: V=0.990251, theta=-64.398581 -> V=1.0, theta=0.0
% INFO    : Bus 6034	: V=0.9920289, theta=-63.861046 -> V=1.0, theta=0.0
% INFO    : Bus 6035	: V=0.9897966, theta=-64.440481 -> V=1.0, theta=0.0
% INFO    : Bus 6036	: V=0.9918069, theta=-63.87511 -> V=1.0, theta=0.0
% INFO    : Bus 6037	: V=0.9972903, theta=-63.307104 -> V=1.0, theta=0.0
% INFO    : Bus 6038	: V=0.9902215, theta=-64.395649 -> V=1.0, theta=0.0
% INFO    : Bus 6039	: V=0.9938193, theta=-64.118503 -> V=1.0, theta=0.0
% INFO    : Bus 6040	: V=0.9905106, theta=-64.377541 -> V=1.0, theta=0.0
% INFO    : Bus 6041	: V=1.0035292, theta=-63.008869 -> V=1.0, theta=0.0
% INFO    : Bus 6042	: V=0.9901483, theta=-64.397125 -> V=1.0, theta=0.0
% INFO    : Bus 6043	: V=0.9901206, theta=-64.386122 -> V=1.0, theta=0.0
% INFO    : Bus 6044	: V=0.9974052, theta=-63.294675 -> V=1.0, theta=0.0
% INFO    : Bus 6045	: V=0.9903263, theta=-64.381977 -> V=1.0, theta=0.0
% INFO    : Bus 6046	: V=0.9953556, theta=-63.34928 -> V=1.0, theta=0.0
% INFO    : Bus 6047	: V=0.9951818, theta=-63.373245 -> V=1.0, theta=0.0
% INFO    : Bus 6048	: V=0.9892476, theta=-64.600919 -> V=1.0, theta=0.0
% INFO    : Bus 6049	: V=0.9945157, theta=-63.45066 -> V=1.0, theta=0.0
% INFO    : Bus 6050	: V=0.9891204, theta=-64.497456 -> V=1.0, theta=0.0
% INFO    : Bus 6051	: V=0.9944484, theta=-63.562513 -> V=1.0, theta=0.0
% INFO    : Bus 6052	: V=0.9893321, theta=-64.491819 -> V=1.0, theta=0.0
% INFO    : Bus 6053	: V=0.9941828, theta=-63.590211 -> V=1.0, theta=0.0
% INFO    : Bus 6054	: V=0.9948356, theta=-63.4157 -> V=1.0, theta=0.0
% INFO    : Bus 6055	: V=1.0025334, theta=-63.049309 -> V=1.0, theta=0.0
% INFO    : Bus 6056	: V=0.9949729, theta=-63.400849 -> V=1.0, theta=0.0
% INFO    : Bus 6057	: V=1.0011909, theta=-63.100149 -> V=1.0, theta=0.0
% INFO    : Bus 6058	: V=0.9890752, theta=-64.546693 -> V=1.0, theta=0.0
% INFO    : Bus 6059	: V=0.9976041, theta=-63.274338 -> V=1.0, theta=0.0
% INFO    : Bus 6060	: V=0.9946299, theta=-63.438812 -> V=1.0, theta=0.0
% INFO    : Bus 6061	: V=0.9979168, theta=-63.249462 -> V=1.0, theta=0.0
% INFO    : Bus 6062	: V=0.9890555, theta=-64.543022 -> V=1.0, theta=0.0
% INFO    : Bus 6063	: V=1.001185, theta=-62.100692 -> V=1.0, theta=0.0
% INFO    : Bus 6064	: V=0.9923416, theta=-63.838456 -> V=1.0, theta=0.0
% INFO    : Bus 6065	: V=0.9982936, theta=-63.217764 -> V=1.0, theta=0.0
% INFO    : Bus 6066	: V=0.9888728, theta=-64.576158 -> V=1.0, theta=0.0
% INFO    : Bus 6067	: V=1.0056438, theta=-61.369695 -> V=1.0, theta=0.0
% INFO    : Bus 6068	: V=0.9928559, theta=-63.800409 -> V=1.0, theta=0.0
% INFO    : Bus 6069	: V=0.9966077, theta=-63.5778 -> V=1.0, theta=0.0
% INFO    : Bus 6070	: V=0.9889487, theta=-64.540502 -> V=1.0, theta=0.0
% INFO    : Bus 6071	: V=0.9872397, theta=-64.940449 -> V=1.0, theta=0.0
% INFO    : Bus 6072	: V=0.9881847, theta=-64.648578 -> V=1.0, theta=0.0
% INFO    : Bus 6073	: V=0.9923215, theta=-64.274353 -> V=1.0, theta=0.0
% INFO    : Bus 6074	: V=0.9877676, theta=-64.676687 -> V=1.0, theta=0.0
% INFO    : Bus 6075	: V=0.9926266, theta=-64.239031 -> V=1.0, theta=0.0
% INFO    : Bus 6076	: V=0.9935257, theta=-63.733243 -> V=1.0, theta=0.0
% INFO    : Bus 6077	: V=1.0054785, theta=-61.403257 -> V=1.0, theta=0.0
% INFO    : Bus 6078	: V=0.9839348, theta=-65.298067 -> V=1.0, theta=0.0
% INFO    : Bus 6079	: V=0.9929517, theta=-64.213733 -> V=1.0, theta=0.0
% INFO    : Bus 6080	: V=0.9919568, theta=-64.286196 -> V=1.0, theta=0.0
% INFO    : Bus 6081	: V=0.9921144, theta=-63.873978 -> V=1.0, theta=0.0
% INFO    : Bus 6082	: V=0.9939073, theta=-63.694475 -> V=1.0, theta=0.0
% INFO    : Bus 6083	: V=0.9923872, theta=-64.259012 -> V=1.0, theta=0.0
% INFO    : Bus 6084	: V=0.9841174, theta=-65.286815 -> V=1.0, theta=0.0
% INFO    : Bus 6085	: V=0.9866841, theta=-64.905081 -> V=1.0, theta=0.0
% INFO    : Bus 6086	: V=0.994344, theta=-63.647722 -> V=1.0, theta=0.0
% INFO    : Bus 6087	: V=0.9867582, theta=-64.897226 -> V=1.0, theta=0.0
% INFO    : Bus 6088	: V=0.9844269, theta=-65.260928 -> V=1.0, theta=0.0
% INFO    : Bus 6089	: V=0.9868946, theta=-64.879871 -> V=1.0, theta=0.0
% INFO    : Bus 6090	: V=0.9939023, theta=-63.689612 -> V=1.0, theta=0.0
% INFO    : Bus 6091	: V=1.0053851, theta=-61.425028 -> V=1.0, theta=0.0
% INFO    : Bus 6092	: V=0.9845107, theta=-65.236466 -> V=1.0, theta=0.0
% INFO    : Bus 6093	: V=0.9922376, theta=-63.853551 -> V=1.0, theta=0.0
% INFO    : Bus 6094	: V=0.9837149, theta=-65.310983 -> V=1.0, theta=0.0
% INFO    : Bus 6095	: V=0.9861608, theta=-64.983184 -> V=1.0, theta=0.0
% INFO    : Bus 6096	: V=0.9935735, theta=-63.716103 -> V=1.0, theta=0.0
% INFO    : Bus 6097	: V=0.9861583, theta=-64.973817 -> V=1.0, theta=0.0
% INFO    : Bus 6098	: V=0.9846449, theta=-65.206332 -> V=1.0, theta=0.0
% INFO    : Bus 6099	: V=0.9863449, theta=-64.962822 -> V=1.0, theta=0.0
% INFO    : Bus 6100	: V=0.9920174, theta=-63.891518 -> V=1.0, theta=0.0
% INFO    : Bus 6101	: V=0.9919509, theta=-63.915065 -> V=1.0, theta=0.0
% INFO    : Bus 6102	: V=0.9921239, theta=-63.872076 -> V=1.0, theta=0.0
% INFO    : Bus 6103	: V=0.9932953, theta=-63.734906 -> V=1.0, theta=0.0
% INFO    : Bus 6104	: V=0.985814, theta=-65.020518 -> V=1.0, theta=0.0
% INFO    : Bus 6105	: V=0.9848365, theta=-65.167308 -> V=1.0, theta=0.0
% INFO    : Bus 6106	: V=0.9859628, theta=-65.001669 -> V=1.0, theta=0.0
% INFO    : Bus 6107	: V=0.985771, theta=-65.006795 -> V=1.0, theta=0.0
% INFO    : Bus 6108	: V=0.9858659, theta=-65.004954 -> V=1.0, theta=0.0
% INFO    : Bus 6109	: V=0.9931055, theta=-63.745274 -> V=1.0, theta=0.0
% INFO    : Bus 6110	: V=0.9857511, theta=-65.018375 -> V=1.0, theta=0.0
% INFO    : Bus 6111	: V=0.9856695, theta=-65.011767 -> V=1.0, theta=0.0
% INFO    : Bus 6112	: V=0.9850474, theta=-65.130783 -> V=1.0, theta=0.0
% INFO    : Bus 6113	: V=0.9876114, theta=-64.794991 -> V=1.0, theta=0.0
% INFO    : Bus 6114	: V=0.9859963, theta=-64.826685 -> V=1.0, theta=0.0
% INFO    : Bus 6115	: V=0.9913798, theta=-64.028053 -> V=1.0, theta=0.0
% INFO    : Bus 6116	: V=0.9862654, theta=-64.990013 -> V=1.0, theta=0.0
% INFO    : Bus 6117	: V=0.9856633, theta=-65.028635 -> V=1.0, theta=0.0
% INFO    : Bus 6118	: V=0.9845759, theta=-65.157774 -> V=1.0, theta=0.0
% INFO    : Bus 6119	: V=0.985662, theta=-65.018964 -> V=1.0, theta=0.0
% INFO    : Bus 6120	: V=0.991856, theta=-63.990521 -> V=1.0, theta=0.0
% INFO    : Bus 6121	: V=0.9928127, theta=-63.732233 -> V=1.0, theta=0.0
% INFO    : Bus 6122	: V=0.991548, theta=-64.013551 -> V=1.0, theta=0.0
% INFO    : Bus 6123	: V=0.9843278, theta=-65.173238 -> V=1.0, theta=0.0
% INFO    : Bus 6124	: V=0.9851781, theta=-65.027636 -> V=1.0, theta=0.0
% INFO    : Bus 6125	: V=0.9863212, theta=-64.799618 -> V=1.0, theta=0.0
% INFO    : Bus 6126	: V=0.9856894, theta=-65.002438 -> V=1.0, theta=0.0
% INFO    : Bus 6127	: V=0.9845528, theta=-65.158436 -> V=1.0, theta=0.0
% INFO    : Bus 6128	: V=0.9921299, theta=-63.967439 -> V=1.0, theta=0.0
% INFO    : Bus 6129	: V=0.9841498, theta=-65.176011 -> V=1.0, theta=0.0
% INFO    : Bus 6130	: V=0.9916454, theta=-64.006865 -> V=1.0, theta=0.0
% INFO    : Bus 6131	: V=0.9852009, theta=-65.011655 -> V=1.0, theta=0.0
% INFO    : Bus 6132	: V=1.005329, theta=-61.511897 -> V=1.0, theta=0.0
% INFO    : Bus 6133	: V=0.9850782, theta=-65.077627 -> V=1.0, theta=0.0
% INFO    : Bus 6134	: V=0.9986313, theta=-62.570022 -> V=1.0, theta=0.0
% INFO    : Bus 6135	: V=0.9841322, theta=-65.157426 -> V=1.0, theta=0.0
% INFO    : Bus 6136	: V=0.9915871, theta=-64.014904 -> V=1.0, theta=0.0
% INFO    : Bus 6137	: V=0.9914709, theta=-64.025966 -> V=1.0, theta=0.0
% INFO    : Bus 6138	: V=0.9855627, theta=-64.811086 -> V=1.0, theta=0.0
% INFO    : Bus 6139	: V=0.9870078, theta=-64.917519 -> V=1.0, theta=0.0
% INFO    : Bus 6140	: V=0.9919863, theta=-63.980814 -> V=1.0, theta=0.0
% INFO    : Bus 6141	: V=0.9841454, theta=-65.142487 -> V=1.0, theta=0.0
% INFO    : Bus 6142	: V=0.9873011, theta=-64.87095 -> V=1.0, theta=0.0
% INFO    : Bus 6143	: V=0.9869539, theta=-64.912962 -> V=1.0, theta=0.0
% INFO    : Bus 6144	: V=0.9845783, theta=-65.089758 -> V=1.0, theta=0.0
% INFO    : Bus 6145	: V=0.9859206, theta=-64.77877 -> V=1.0, theta=0.0
% INFO    : Bus 6146	: V=0.9860334, theta=-64.763308 -> V=1.0, theta=0.0
% INFO    : Bus 6147	: V=0.9864929, theta=-64.583022 -> V=1.0, theta=0.0
% INFO    : Bus 6148	: V=0.9857721, theta=-64.793103 -> V=1.0, theta=0.0
% INFO    : Bus 6149	: V=0.9856391, theta=-64.805147 -> V=1.0, theta=0.0
% INFO    : Bus 6150	: V=0.9843768, theta=-65.07626 -> V=1.0, theta=0.0
% INFO    : Bus 6151	: V=0.9846005, theta=-65.430979 -> V=1.0, theta=0.0
% INFO    : Bus 6152	: V=0.9865327, theta=-64.579479 -> V=1.0, theta=0.0
% INFO    : Bus 6153	: V=0.9866001, theta=-64.951225 -> V=1.0, theta=0.0
% INFO    : Bus 6154	: V=0.9841019, theta=-65.105961 -> V=1.0, theta=0.0
% INFO    : Bus 6155	: V=0.9864179, theta=-64.95983 -> V=1.0, theta=0.0
% INFO    : Bus 6156	: V=0.9863717, theta=-64.96106 -> V=1.0, theta=0.0
% INFO    : Bus 6157	: V=0.986622, theta=-64.569494 -> V=1.0, theta=0.0
% INFO    : Bus 6158	: V=0.9861552, theta=-64.740654 -> V=1.0, theta=0.0
% INFO    : Bus 6159	: V=0.9864026, theta=-64.709075 -> V=1.0, theta=0.0
% INFO    : Bus 6160	: V=0.9872875, theta=-64.474169 -> V=1.0, theta=0.0
% INFO    : Bus 6161	: V=0.9798386, theta=-66.017634 -> V=1.0, theta=0.0
% INFO    : Bus 6162	: V=0.979814, theta=-66.019388 -> V=1.0, theta=0.0
% INFO    : Bus 6163	: V=0.9867989, theta=-64.553777 -> V=1.0, theta=0.0
% INFO    : Bus 6164	: V=0.9839741, theta=-65.466612 -> V=1.0, theta=0.0
% INFO    : Bus 6165	: V=0.9873437, theta=-64.469496 -> V=1.0, theta=0.0
% INFO    : Bus 6166	: V=0.9842949, theta=-65.141187 -> V=1.0, theta=0.0
% INFO    : Bus 6167	: V=0.9866607, theta=-64.569617 -> V=1.0, theta=0.0
% INFO    : Bus 6168	: V=0.9867499, theta=-64.666563 -> V=1.0, theta=0.0
% INFO    : Bus 6169	: V=0.9870723, theta=-64.507715 -> V=1.0, theta=0.0
% INFO    : Bus 6170	: V=0.9821382, theta=-65.59764 -> V=1.0, theta=0.0
% INFO    : Bus 6171	: V=0.9865779, theta=-64.579259 -> V=1.0, theta=0.0
% INFO    : Bus 6172	: V=0.9873948, theta=-64.584369 -> V=1.0, theta=0.0
% INFO    : Bus 6173	: V=0.9832145, theta=-65.211388 -> V=1.0, theta=0.0
% INFO    : Bus 6174	: V=0.987923, theta=-64.517618 -> V=1.0, theta=0.0
% INFO    : Bus 6175	: V=0.9865431, theta=-64.584356 -> V=1.0, theta=0.0
% INFO    : Bus 6176	: V=0.9847336, theta=-65.159024 -> V=1.0, theta=0.0
% INFO    : Bus 6177	: V=0.9847091, theta=-65.160488 -> V=1.0, theta=0.0
% INFO    : Bus 6178	: V=0.9867136, theta=-64.554022 -> V=1.0, theta=0.0
% INFO    : Bus 6179	: V=0.9865545, theta=-64.584259 -> V=1.0, theta=0.0
% INFO    : Bus 6180	: V=0.9904692, theta=-64.152569 -> V=1.0, theta=0.0
% INFO    : Bus 6181	: V=0.9829174, theta=-65.255216 -> V=1.0, theta=0.0
% INFO    : Bus 6182	: V=0.9885896, theta=-64.426641 -> V=1.0, theta=0.0
% INFO    : Bus 6183	: V=0.9866249, theta=-64.577532 -> V=1.0, theta=0.0
% INFO    : Bus 6184	: V=0.9885957, theta=-64.407359 -> V=1.0, theta=0.0
% INFO    : Bus 6185	: V=0.9822902, theta=-65.310812 -> V=1.0, theta=0.0
% INFO    : Bus 6186	: V=0.9881535, theta=-64.4516 -> V=1.0, theta=0.0
% INFO    : Bus 6187	: V=0.9826428, theta=-65.283296 -> V=1.0, theta=0.0
% INFO    : Bus 6188	: V=0.9878126, theta=-64.480081 -> V=1.0, theta=0.0
% INFO    : Bus 6189	: V=0.9864095, theta=-64.593168 -> V=1.0, theta=0.0
% INFO    : Bus 6190	: V=0.9891915, theta=-64.347885 -> V=1.0, theta=0.0
% INFO    : Bus 6191	: V=0.9869612, theta=-64.548467 -> V=1.0, theta=0.0
% INFO    : Bus 6192	: V=0.9879085, theta=-64.471886 -> V=1.0, theta=0.0
% INFO    : Bus 6193	: V=0.9863492, theta=-64.60212 -> V=1.0, theta=0.0
% INFO    : Bus 6194	: V=0.9889266, theta=-64.365137 -> V=1.0, theta=0.0
% INFO    : Bus 6195	: V=0.9871047, theta=-64.537381 -> V=1.0, theta=0.0
% INFO    : Bus 6196	: V=0.9890596, theta=-64.356639 -> V=1.0, theta=0.0
% INFO    : Bus 6197	: V=0.9827618, theta=-65.420395 -> V=1.0, theta=0.0
% INFO    : Bus 6198	: V=0.9875962, theta=-64.494201 -> V=1.0, theta=0.0
% INFO    : Bus 6199	: V=0.9800918, theta=-65.700652 -> V=1.0, theta=0.0
% INFO    : Bus 6200	: V=0.987289, theta=-64.522968 -> V=1.0, theta=0.0
% INFO    : Bus 6201	: V=0.9872964, theta=-64.521098 -> V=1.0, theta=0.0
% INFO    : Bus 6202	: V=0.9865664, theta=-64.767633 -> V=1.0, theta=0.0
% INFO    : Bus 6203	: V=0.9832572, theta=-65.31196 -> V=1.0, theta=0.0
% INFO    : Bus 6204	: V=0.979857, theta=-65.708554 -> V=1.0, theta=0.0
% INFO    : Bus 6205	: V=0.9805352, theta=-65.686118 -> V=1.0, theta=0.0
% INFO    : Bus 6206	: V=0.9864705, theta=-64.598242 -> V=1.0, theta=0.0
% INFO    : Bus 6207	: V=0.9867045, theta=-64.755301 -> V=1.0, theta=0.0
% INFO    : Bus 6208	: V=0.9817926, theta=-65.627497 -> V=1.0, theta=0.0
% INFO    : Bus 6209	: V=0.9864946, theta=-64.599789 -> V=1.0, theta=0.0
% INFO    : Bus 6210	: V=0.9819006, theta=-65.622942 -> V=1.0, theta=0.0
% INFO    : Bus 6211	: V=0.9865629, theta=-64.599635 -> V=1.0, theta=0.0
% INFO    : Bus 6212	: V=0.9821257, theta=-65.59183 -> V=1.0, theta=0.0
% INFO    : Bus 6213	: V=0.9869526, theta=-64.731936 -> V=1.0, theta=0.0
% INFO    : Bus 6214	: V=0.9872114, theta=-64.562669 -> V=1.0, theta=0.0
% INFO    : Bus 6215	: V=0.9866462, theta=-64.597702 -> V=1.0, theta=0.0
% INFO    : Bus 6216	: V=0.9820901, theta=-65.585566 -> V=1.0, theta=0.0
% INFO    : Bus 6217	: V=0.9867662, theta=-64.5915 -> V=1.0, theta=0.0
% INFO    : Bus 6218	: V=0.9874724, theta=-64.508134 -> V=1.0, theta=0.0
% INFO    : Bus 6219	: V=0.9837188, theta=-65.47593 -> V=1.0, theta=0.0
% INFO    : Bus 6220	: V=0.9876052, theta=-64.496955 -> V=1.0, theta=0.0
% INFO    : Bus 6221	: V=0.9872802, theta=-64.699475 -> V=1.0, theta=0.0
% INFO    : Bus 6222	: V=0.986823, theta=-64.565597 -> V=1.0, theta=0.0
% INFO    : Bus 6223	: V=0.9827507, theta=-65.523444 -> V=1.0, theta=0.0
% INFO    : Bus 6224	: V=0.9814938, theta=-65.648846 -> V=1.0, theta=0.0
% INFO    : Bus 6225	: V=0.9877326, theta=-64.650089 -> V=1.0, theta=0.0
% INFO    : Bus 6226	: V=0.9875319, theta=-64.67218 -> V=1.0, theta=0.0
% INFO    : Bus 6227	: V=0.9815512, theta=-65.642381 -> V=1.0, theta=0.0
% INFO    : Bus 6228	: V=0.9880177, theta=-64.614186 -> V=1.0, theta=0.0
% INFO    : Bus 6229	: V=0.9869477, theta=-64.580265 -> V=1.0, theta=0.0
% INFO    : Bus 6230	: V=0.9796561, theta=-65.890647 -> V=1.0, theta=0.0
% INFO    : Bus 6231	: V=0.9838836, theta=-65.175909 -> V=1.0, theta=0.0
% INFO    : Bus 6232	: V=0.987715, theta=-64.641379 -> V=1.0, theta=0.0
% INFO    : Bus 6233	: V=0.9861357, theta=-64.802835 -> V=1.0, theta=0.0
% INFO    : Bus 6234	: V=0.9861313, theta=-64.789227 -> V=1.0, theta=0.0
% INFO    : Bus 6235	: V=0.98604, theta=-64.806887 -> V=1.0, theta=0.0
% INFO    : Bus 6236	: V=0.987421, theta=-64.665335 -> V=1.0, theta=0.0
% INFO    : Bus 6237	: V=0.9799312, theta=-65.869524 -> V=1.0, theta=0.0
% INFO    : Bus 6238	: V=0.9862221, theta=-64.774333 -> V=1.0, theta=0.0
% INFO    : Bus 6239	: V=0.9837723, theta=-65.273427 -> V=1.0, theta=0.0
% INFO    : Bus 6240	: V=0.9798411, theta=-65.881178 -> V=1.0, theta=0.0
% INFO    : Bus 6241	: V=0.9870685, theta=-64.692462 -> V=1.0, theta=0.0
% INFO    : Bus 6242	: V=0.986329, theta=-64.756727 -> V=1.0, theta=0.0
% INFO    : Bus 6243	: V=0.9943646, theta=-63.539681 -> V=1.0, theta=0.0
% INFO    : Bus 6244	: V=0.9868139, theta=-64.710236 -> V=1.0, theta=0.0
% INFO    : Bus 6245	: V=0.9881098, theta=-64.450544 -> V=1.0, theta=0.0
% INFO    : Bus 6246	: V=0.9799791, theta=-66.050062 -> V=1.0, theta=0.0
% INFO    : Bus 6247	: V=0.9796594, theta=-66.075176 -> V=1.0, theta=0.0
% INFO    : Bus 6248	: V=0.9864786, theta=-64.733029 -> V=1.0, theta=0.0
% INFO    : Bus 6249	: V=0.9866812, theta=-64.712181 -> V=1.0, theta=0.0
% INFO    : Bus 6250	: V=0.9815021, theta=-65.749146 -> V=1.0, theta=0.0
% INFO    : Bus 6251	: V=0.9998796, theta=-62.119358 -> V=1.0, theta=0.0
% INFO    : Bus 6252	: V=0.9862393, theta=-64.737496 -> V=1.0, theta=0.0
% INFO    : Bus 6253	: V=0.9810791, theta=-65.768577 -> V=1.0, theta=0.0
% INFO    : Bus 6254	: V=0.9866612, theta=-64.58035 -> V=1.0, theta=0.0
% INFO    : Bus 6255	: V=0.9799086, theta=-65.883785 -> V=1.0, theta=0.0
% INFO    : Bus 6256	: V=0.9756804, theta=-66.817936 -> V=1.0, theta=0.0
% INFO    : Bus 6257	: V=0.9858442, theta=-64.770958 -> V=1.0, theta=0.0
% INFO    : Bus 6258	: V=0.9757373, theta=-66.79866 -> V=1.0, theta=0.0
% INFO    : Bus 6259	: V=0.9750051, theta=-66.872117 -> V=1.0, theta=0.0
% INFO    : Bus 6260	: V=0.9750816, theta=-66.870031 -> V=1.0, theta=0.0
% INFO    : Bus 6261	: V=0.9748824, theta=-66.883914 -> V=1.0, theta=0.0
% INFO    : Bus 6262	: V=0.9840639, theta=-65.011686 -> V=1.0, theta=0.0
% INFO    : Bus 6263	: V=0.9839133, theta=-65.015513 -> V=1.0, theta=0.0
% INFO    : Bus 6264	: V=0.9917132, theta=-63.478338 -> V=1.0, theta=0.0
% INFO    : Bus 6265	: V=0.9845785, theta=-64.971822 -> V=1.0, theta=0.0
% INFO    : Bus 6266	: V=0.9843615, theta=-64.976259 -> V=1.0, theta=0.0
% INFO    : Bus 6267	: V=0.9847953, theta=-64.922329 -> V=1.0, theta=0.0
% INFO    : Bus 6268	: V=0.9845256, theta=-64.941748 -> V=1.0, theta=0.0
% INFO    : Bus 6269	: V=0.9841514, theta=-64.951667 -> V=1.0, theta=0.0
% INFO    : Bus 6270	: V=0.9845415, theta=-64.92096 -> V=1.0, theta=0.0
% INFO    : Bus 6271	: V=0.9843935, theta=-64.937021 -> V=1.0, theta=0.0
% INFO    : Bus 6272	: V=0.9777525, theta=-66.278111 -> V=1.0, theta=0.0
% INFO    : Bus 6273	: V=0.977558, theta=-66.283396 -> V=1.0, theta=0.0
% INFO    : Bus 6274	: V=0.9791026, theta=-65.905717 -> V=1.0, theta=0.0
% INFO    : Bus 6275	: V=0.9842559, theta=-64.947061 -> V=1.0, theta=0.0
% INFO    : Bus 6276	: V=0.9840896, theta=-64.96582 -> V=1.0, theta=0.0
% INFO    : Bus 6277	: V=0.9836724, theta=-65.011102 -> V=1.0, theta=0.0
% INFO    : Bus 6278	: V=0.9756054, theta=-66.820004 -> V=1.0, theta=0.0
% INFO    : Bus 6279	: V=0.9882623, theta=-64.176263 -> V=1.0, theta=0.0
% INFO    : Bus 6280	: V=0.9888932, theta=-64.093266 -> V=1.0, theta=0.0
% INFO    : Bus 6281	: V=0.9898544, theta=-63.873528 -> V=1.0, theta=0.0
% INFO    : Bus 6282	: V=1.0153612, theta=-73.338564 -> V=1.0, theta=0.0
% INFO    : Bus 6283	: V=1.0158071, theta=-71.705637 -> V=1.0, theta=0.0
% INFO    : Bus 6284	: V=1.0151485, theta=-71.669275 -> V=1.0, theta=0.0
% INFO    : Bus 6285	: V=1.01521, theta=-73.436404 -> V=1.0, theta=0.0
% INFO    : Bus 6286	: V=1.0160947, theta=-73.511546 -> V=1.0, theta=0.0
% INFO    : Bus 6287	: V=1.015129, theta=-73.440032 -> V=1.0, theta=0.0
% INFO    : Bus 6288	: V=1.0147204, theta=-73.538304 -> V=1.0, theta=0.0
% INFO    : Bus 6289	: V=1.0158649, theta=-73.520005 -> V=1.0, theta=0.0
% INFO    : Bus 6290	: V=1.0157383, theta=-74.81838 -> V=1.0, theta=0.0
% INFO    : Bus 6291	: V=1.0163939, theta=-73.628773 -> V=1.0, theta=0.0
% INFO    : Bus 6292	: V=1.0165763, theta=-73.686546 -> V=1.0, theta=0.0
% INFO    : Bus 6293	: V=1.0140866, theta=-73.641979 -> V=1.0, theta=0.0
% INFO    : Bus 6294	: V=1.0155682, theta=-74.861642 -> V=1.0, theta=0.0
% INFO    : Bus 6295	: V=1.0154271, theta=-74.908592 -> V=1.0, theta=0.0
% INFO    : Bus 6296	: V=1.0194917, theta=-74.680697 -> V=1.0, theta=0.0
% INFO    : Bus 6297	: V=1.0095092, theta=-74.17387 -> V=1.0, theta=0.0
% INFO    : Bus 6298	: V=1.0091858, theta=-74.111798 -> V=1.0, theta=0.0
% INFO    : Bus 6299	: V=1.0093146, theta=-74.124085 -> V=1.0, theta=0.0
% INFO    : Bus 6300	: V=1.0091624, theta=-74.047716 -> V=1.0, theta=0.0
% INFO    : Bus 6301	: V=1.0090652, theta=-73.991898 -> V=1.0, theta=0.0
% INFO    : Bus 6302	: V=1.0142166, theta=-73.099648 -> V=1.0, theta=0.0
% INFO    : Bus 6303	: V=1.0098855, theta=-73.798624 -> V=1.0, theta=0.0
% INFO    : Bus 6304	: V=1.0061245, theta=-70.575762 -> V=1.0, theta=0.0
% INFO    : Bus 6305	: V=1.0065503, theta=-73.104019 -> V=1.0, theta=0.0
% INFO    : Bus 6306	: V=1.0082625, theta=-74.021189 -> V=1.0, theta=0.0
% INFO    : Bus 6307	: V=1.009516, theta=-73.246852 -> V=1.0, theta=0.0
% INFO    : Bus 6308	: V=1.0088969, theta=-73.105837 -> V=1.0, theta=0.0
% INFO    : Bus 6309	: V=1.0082479, theta=-72.818921 -> V=1.0, theta=0.0
% INFO    : Bus 6310	: V=1.0094143, theta=-73.665597 -> V=1.0, theta=0.0
% INFO    : Bus 6311	: V=1.0083121, theta=-73.866837 -> V=1.0, theta=0.0
% INFO    : Bus 6312	: V=1.0076754, theta=-73.912061 -> V=1.0, theta=0.0
% INFO    : Bus 6313	: V=1.0072124, theta=-73.946798 -> V=1.0, theta=0.0
% INFO    : Bus 6314	: V=1.0075484, theta=-72.815971 -> V=1.0, theta=0.0
% INFO    : Bus 6315	: V=1.0020898, theta=-70.64139 -> V=1.0, theta=0.0
% INFO    : Bus 6316	: V=0.9912349, theta=-71.12864 -> V=1.0, theta=0.0
% INFO    : Bus 6317	: V=0.9904457, theta=-71.414619 -> V=1.0, theta=0.0
% INFO    : Bus 6318	: V=0.9914314, theta=-71.330138 -> V=1.0, theta=0.0
% INFO    : Bus 6319	: V=0.9944437, theta=-70.1493 -> V=1.0, theta=0.0
% INFO    : Bus 6320	: V=0.9945505, theta=-70.221877 -> V=1.0, theta=0.0
% INFO    : Bus 6321	: V=0.9941248, theta=-71.103966 -> V=1.0, theta=0.0
% INFO    : Bus 6322	: V=0.969822, theta=-72.541394 -> V=1.0, theta=0.0
% INFO    : Bus 6323	: V=0.9949282, theta=-71.088751 -> V=1.0, theta=0.0
% INFO    : Bus 6324	: V=0.9689617, theta=-72.547002 -> V=1.0, theta=0.0
% INFO    : Bus 6325	: V=0.9742537, theta=-71.700093 -> V=1.0, theta=0.0
% INFO    : Bus 6326	: V=0.9869089, theta=-70.79987 -> V=1.0, theta=0.0
% INFO    : Bus 6327	: V=0.9952299, theta=-69.915504 -> V=1.0, theta=0.0
% INFO    : Bus 6328	: V=1.0042381, theta=-68.908218 -> V=1.0, theta=0.0
% INFO    : Bus 6329	: V=0.9994763, theta=-69.591925 -> V=1.0, theta=0.0
% INFO    : Bus 6330	: V=0.9847553, theta=-70.733141 -> V=1.0, theta=0.0
% INFO    : Bus 6331	: V=0.9779582, theta=-70.85214 -> V=1.0, theta=0.0
% INFO    : Bus 6332	: V=0.9792363, theta=-70.829552 -> V=1.0, theta=0.0
% INFO    : Bus 6333	: V=0.9940783, theta=-71.14795 -> V=1.0, theta=0.0
% INFO    : Bus 6334	: V=1.0158704, theta=-72.901226 -> V=1.0, theta=0.0
% INFO    : Bus 6335	: V=1.0151742, theta=-72.932509 -> V=1.0, theta=0.0
% INFO    : Bus 6336	: V=1.0036118, theta=-73.128317 -> V=1.0, theta=0.0
% INFO    : Bus 6337	: V=1.0107345, theta=-73.373281 -> V=1.0, theta=0.0
% INFO    : Bus 6338	: V=0.9967118, theta=-72.216204 -> V=1.0, theta=0.0
% INFO    : Bus 6339	: V=0.9941671, theta=-71.352939 -> V=1.0, theta=0.0
% INFO    : Bus 6340	: V=1.0095104, theta=-73.443927 -> V=1.0, theta=0.0
% INFO    : Bus 6341	: V=1.0072601, theta=-73.271482 -> V=1.0, theta=0.0
% INFO    : Bus 6342	: V=0.9663129, theta=-65.742695 -> V=1.0, theta=0.0
% INFO    : Bus 6343	: V=0.9694393, theta=-65.172475 -> V=1.0, theta=0.0
% INFO    : Bus 6344	: V=0.9672022, theta=-65.488605 -> V=1.0, theta=0.0
% INFO    : Bus 6345	: V=0.9689074, theta=-65.301358 -> V=1.0, theta=0.0
% INFO    : Bus 6346	: V=0.96911, theta=-65.267257 -> V=1.0, theta=0.0
% INFO    : Bus 6347	: V=0.9697224, theta=-65.093444 -> V=1.0, theta=0.0
% INFO    : Bus 6348	: V=0.969246, theta=-65.228936 -> V=1.0, theta=0.0
% INFO    : Bus 6349	: V=0.9667142, theta=-65.731441 -> V=1.0, theta=0.0
% INFO    : Bus 6350	: V=0.9700271, theta=-64.989968 -> V=1.0, theta=0.0
% INFO    : Bus 6351	: V=0.9669626, theta=-65.515229 -> V=1.0, theta=0.0
% INFO    : Bus 6352	: V=0.9694508, theta=-65.142914 -> V=1.0, theta=0.0
% INFO    : Bus 6353	: V=0.9682334, theta=-65.363879 -> V=1.0, theta=0.0
% INFO    : Bus 6354	: V=0.9647036, theta=-66.456171 -> V=1.0, theta=0.0
% INFO    : Bus 6355	: V=0.9691988, theta=-65.212102 -> V=1.0, theta=0.0
% INFO    : Bus 6356	: V=0.9683299, theta=-65.3791 -> V=1.0, theta=0.0
% INFO    : Bus 6357	: V=0.9673108, theta=-65.459131 -> V=1.0, theta=0.0
% INFO    : Bus 6358	: V=0.9676373, theta=-65.430046 -> V=1.0, theta=0.0
% INFO    : Bus 6359	: V=0.969619, theta=-65.096658 -> V=1.0, theta=0.0
% INFO    : Bus 6360	: V=0.9683215, theta=-65.509398 -> V=1.0, theta=0.0
% INFO    : Bus 6361	: V=0.9648689, theta=-66.417262 -> V=1.0, theta=0.0
% INFO    : Bus 6362	: V=0.9658355, theta=-65.615346 -> V=1.0, theta=0.0
% INFO    : Bus 6363	: V=0.9710365, theta=-64.589752 -> V=1.0, theta=0.0
% INFO    : Bus 6364	: V=0.9710371, theta=-64.156749 -> V=1.0, theta=0.0
% INFO    : Bus 6365	: V=0.9752469, theta=-63.219558 -> V=1.0, theta=0.0
% INFO    : Bus 6366	: V=0.9724111, theta=-63.775009 -> V=1.0, theta=0.0
% INFO    : Bus 6367	: V=0.9713634, theta=-64.141672 -> V=1.0, theta=0.0
% INFO    : Bus 6368	: V=0.9714825, theta=-64.130879 -> V=1.0, theta=0.0
% INFO    : Bus 6369	: V=0.9749352, theta=-63.460789 -> V=1.0, theta=0.0
% INFO    : Bus 6370	: V=0.9707362, theta=-64.159137 -> V=1.0, theta=0.0
% INFO    : Bus 6371	: V=0.9762868, theta=-62.914466 -> V=1.0, theta=0.0
% INFO    : Bus 6372	: V=0.9704281, theta=-64.1986 -> V=1.0, theta=0.0
% INFO    : Bus 6373	: V=0.9672326, theta=-64.654157 -> V=1.0, theta=0.0
% INFO    : Bus 6374	: V=0.966731, theta=-65.408704 -> V=1.0, theta=0.0
% INFO    : Bus 6375	: V=0.9678314, theta=-65.398982 -> V=1.0, theta=0.0
% INFO    : Bus 6376	: V=0.9803968, theta=-62.258789 -> V=1.0, theta=0.0
% INFO    : Bus 6377	: V=0.9715663, theta=-64.47487 -> V=1.0, theta=0.0
% INFO    : Bus 6378	: V=0.9714976, theta=-64.390017 -> V=1.0, theta=0.0
% INFO    : Bus 6379	: V=0.9773974, theta=-65.081086 -> V=1.0, theta=0.0
% INFO    : Bus 6380	: V=0.9644749, theta=-66.426031 -> V=1.0, theta=0.0
% INFO    : Bus 6381	: V=0.9645961, theta=-65.940649 -> V=1.0, theta=0.0
% INFO    : Bus 6382	: V=0.9844109, theta=-65.802393 -> V=1.0, theta=0.0
% INFO    : Bus 6383	: V=0.96304, theta=-64.48281 -> V=1.0, theta=0.0
% INFO    : Bus 6384	: V=0.9840387, theta=-66.04873 -> V=1.0, theta=0.0
% INFO    : Bus 6385	: V=0.9655625, theta=-64.401489 -> V=1.0, theta=0.0
% INFO    : Bus 6386	: V=0.9775831, theta=-62.548854 -> V=1.0, theta=0.0
% INFO    : Bus 6387	: V=0.9797361, theta=-61.974574 -> V=1.0, theta=0.0
% INFO    : Bus 6388	: V=0.968776, theta=-64.271217 -> V=1.0, theta=0.0
% INFO    : Bus 6389	: V=0.9851819, theta=-60.694597 -> V=1.0, theta=0.0
% INFO    : Bus 6390	: V=0.9766661, theta=-61.457033 -> V=1.0, theta=0.0
% INFO    : Bus 6391	: V=0.9667165, theta=-65.445862 -> V=1.0, theta=0.0
% INFO    : Bus 6392	: V=0.9676606, theta=-65.271137 -> V=1.0, theta=0.0
% INFO    : Bus 6393	: V=0.9691995, theta=-65.033403 -> V=1.0, theta=0.0
% INFO    : Bus 6394	: V=0.965696, theta=-65.565668 -> V=1.0, theta=0.0
% INFO    : Bus 6395	: V=0.9644057, theta=-65.617843 -> V=1.0, theta=0.0
% INFO    : Bus 6396	: V=0.9662378, theta=-65.565561 -> V=1.0, theta=0.0
% INFO    : Bus 6397	: V=0.9627936, theta=-65.700901 -> V=1.0, theta=0.0
% INFO    : Bus 6398	: V=0.9597812, theta=-65.976205 -> V=1.0, theta=0.0
% INFO    : Bus 6399	: V=0.9730778, theta=-64.168248 -> V=1.0, theta=0.0
% INFO    : Bus 6400	: V=0.970404, theta=-64.686185 -> V=1.0, theta=0.0
% INFO    : Bus 6401	: V=0.9684512, theta=-65.074436 -> V=1.0, theta=0.0
% INFO    : Bus 6402	: V=0.9705774, theta=-64.197516 -> V=1.0, theta=0.0
% INFO    : Bus 6403	: V=0.9718301, theta=-64.202255 -> V=1.0, theta=0.0
% INFO    : Bus 6404	: V=0.9561651, theta=-66.485061 -> V=1.0, theta=0.0
% INFO    : Bus 6405	: V=0.9748831, theta=-63.358075 -> V=1.0, theta=0.0
% INFO    : Bus 6406	: V=0.9697712, theta=-65.05616 -> V=1.0, theta=0.0
% INFO    : Bus 6407	: V=0.9676904, theta=-65.428467 -> V=1.0, theta=0.0
% INFO    : Bus 6408	: V=0.9578842, theta=-66.395332 -> V=1.0, theta=0.0
% INFO    : Bus 6409	: V=0.9834314, theta=-60.646581 -> V=1.0, theta=0.0
% INFO    : Bus 6410	: V=0.9818613, theta=-62.617392 -> V=1.0, theta=0.0
% INFO    : Bus 6411	: V=0.9817115, theta=-61.969492 -> V=1.0, theta=0.0
% INFO    : Bus 6412	: V=0.978547, theta=-63.24513 -> V=1.0, theta=0.0
% INFO    : Bus 6413	: V=0.968857, theta=-65.343289 -> V=1.0, theta=0.0
% INFO    : Bus 6414	: V=0.9672035, theta=-65.488702 -> V=1.0, theta=0.0
% INFO    : Bus 6415	: V=0.9755492, theta=-63.520672 -> V=1.0, theta=0.0
% INFO    : Bus 6416	: V=0.9714683, theta=-62.144676 -> V=1.0, theta=0.0
% INFO    : Bus 6417	: V=0.9723283, theta=-61.893431 -> V=1.0, theta=0.0
% INFO    : Bus 6418	: V=0.972087, theta=-61.899284 -> V=1.0, theta=0.0
% INFO    : Bus 6419	: V=0.9799965, theta=-60.787898 -> V=1.0, theta=0.0
% INFO    : Bus 6420	: V=0.9723545, theta=-61.992012 -> V=1.0, theta=0.0
% INFO    : Bus 6421	: V=0.9724862, theta=-61.927418 -> V=1.0, theta=0.0
% INFO    : Bus 6422	: V=0.9732351, theta=-61.899582 -> V=1.0, theta=0.0
% INFO    : Bus 6423	: V=0.9794889, theta=-60.928786 -> V=1.0, theta=0.0
% INFO    : Bus 6424	: V=0.975285, theta=-61.219429 -> V=1.0, theta=0.0
% INFO    : Bus 6425	: V=0.9840673, theta=-60.576388 -> V=1.0, theta=0.0
% INFO    : Bus 6426	: V=0.9733789, theta=-61.961134 -> V=1.0, theta=0.0
% INFO    : Bus 6427	: V=0.9792049, theta=-61.023495 -> V=1.0, theta=0.0
% INFO    : Bus 6428	: V=0.9790748, theta=-61.07863 -> V=1.0, theta=0.0
% INFO    : Bus 6429	: V=0.981603, theta=-60.886678 -> V=1.0, theta=0.0
% INFO    : Bus 6430	: V=0.9827659, theta=-60.809924 -> V=1.0, theta=0.0
% INFO    : Bus 6431	: V=0.9819514, theta=-60.876287 -> V=1.0, theta=0.0
% INFO    : Bus 6432	: V=0.9857883, theta=-60.426981 -> V=1.0, theta=0.0
% INFO    : Bus 6433	: V=0.9700616, theta=-62.184139 -> V=1.0, theta=0.0
% INFO    : Bus 6434	: V=0.9719381, theta=-62.286548 -> V=1.0, theta=0.0
% INFO    : Bus 6435	: V=0.9729097, theta=-61.97526 -> V=1.0, theta=0.0
% INFO    : Bus 6436	: V=0.9789697, theta=-61.124122 -> V=1.0, theta=0.0
% INFO    : Bus 6437	: V=0.9698347, theta=-62.190517 -> V=1.0, theta=0.0
% INFO    : Bus 6438	: V=0.979373, theta=-61.569608 -> V=1.0, theta=0.0
% INFO    : Bus 6439	: V=0.9715841, theta=-62.346397 -> V=1.0, theta=0.0
% INFO    : Bus 6440	: V=0.9708557, theta=-62.38188 -> V=1.0, theta=0.0
% INFO    : Bus 6441	: V=0.9788608, theta=-61.189093 -> V=1.0, theta=0.0
% INFO    : Bus 6442	: V=0.9817447, theta=-61.04635 -> V=1.0, theta=0.0
% INFO    : Bus 6443	: V=0.9762196, theta=-61.516256 -> V=1.0, theta=0.0
% INFO    : Bus 6444	: V=0.9792812, theta=-61.310533 -> V=1.0, theta=0.0
% INFO    : Bus 6445	: V=0.9732332, theta=-62.277069 -> V=1.0, theta=0.0
% INFO    : Bus 6446	: V=0.9722474, theta=-62.354014 -> V=1.0, theta=0.0
% INFO    : Bus 6447	: V=0.9714705, theta=-62.348825 -> V=1.0, theta=0.0
% INFO    : Bus 6448	: V=0.978943, theta=-61.373111 -> V=1.0, theta=0.0
% INFO    : Bus 6449	: V=0.9749472, theta=-61.621808 -> V=1.0, theta=0.0
% INFO    : Bus 6450	: V=0.9788767, theta=-61.279893 -> V=1.0, theta=0.0
% INFO    : Bus 6451	: V=0.9754982, theta=-61.621909 -> V=1.0, theta=0.0
% INFO    : Bus 6452	: V=0.9810355, theta=-61.239613 -> V=1.0, theta=0.0
% INFO    : Bus 6453	: V=0.9768808, theta=-61.456911 -> V=1.0, theta=0.0
% INFO    : Bus 6454	: V=0.9722386, theta=-62.269353 -> V=1.0, theta=0.0
% INFO    : Bus 6455	: V=0.9733078, theta=-62.300254 -> V=1.0, theta=0.0
% INFO    : Bus 6456	: V=0.9733879, theta=-62.312601 -> V=1.0, theta=0.0
% INFO    : Bus 6457	: V=0.9783889, theta=-61.730892 -> V=1.0, theta=0.0
% INFO    : Bus 6458	: V=0.972054, theta=-62.359394 -> V=1.0, theta=0.0
% INFO    : Bus 6459	: V=0.97206, theta=-62.489299 -> V=1.0, theta=0.0
% INFO    : Bus 6460	: V=0.9717843, theta=-62.495449 -> V=1.0, theta=0.0
% INFO    : Bus 6461	: V=0.9784145, theta=-61.63219 -> V=1.0, theta=0.0
% INFO    : Bus 6462	: V=0.9805069, theta=-61.407929 -> V=1.0, theta=0.0
% INFO    : Bus 6463	: V=0.9801771, theta=-61.51241 -> V=1.0, theta=0.0
% INFO    : Bus 6464	: V=0.9731336, theta=-62.380443 -> V=1.0, theta=0.0
% INFO    : Bus 6465	: V=0.9783163, theta=-61.756252 -> V=1.0, theta=0.0
% INFO    : Bus 6466	: V=0.9782657, theta=-61.777413 -> V=1.0, theta=0.0
% INFO    : Bus 6467	: V=0.9780955, theta=-61.980747 -> V=1.0, theta=0.0
% INFO    : Bus 6468	: V=0.9782156, theta=-61.809461 -> V=1.0, theta=0.0
% INFO    : Bus 6469	: V=0.972995, theta=-62.434612 -> V=1.0, theta=0.0
% INFO    : Bus 6470	: V=0.9727209, theta=-62.440755 -> V=1.0, theta=0.0
% INFO    : Bus 6471	: V=0.9686636, theta=-61.770288 -> V=1.0, theta=0.0
% INFO    : Bus 6472	: V=0.9747982, theta=-60.397033 -> V=1.0, theta=0.0
% INFO    : Bus 6473	: V=0.9726863, theta=-60.969673 -> V=1.0, theta=0.0
% INFO    : Bus 6474	: V=0.9696344, theta=-60.995285 -> V=1.0, theta=0.0
% INFO    : Bus 6475	: V=0.9701456, theta=-60.990419 -> V=1.0, theta=0.0
% INFO    : Bus 6476	: V=0.9706349, theta=-61.724952 -> V=1.0, theta=0.0
% INFO    : Bus 6477	: V=0.9753831, theta=-61.304472 -> V=1.0, theta=0.0
% INFO    : Bus 6478	: V=0.9766334, theta=-61.292877 -> V=1.0, theta=0.0
% INFO    : Bus 6479	: V=0.9760347, theta=-61.300254 -> V=1.0, theta=0.0
% INFO    : Bus 6480	: V=0.9716722, theta=-61.649028 -> V=1.0, theta=0.0
% INFO    : Bus 6481	: V=0.9723902, theta=-61.60553 -> V=1.0, theta=0.0
% INFO    : Bus 6482	: V=0.9712326, theta=-61.671275 -> V=1.0, theta=0.0
% INFO    : Bus 6483	: V=0.9706294, theta=-61.684143 -> V=1.0, theta=0.0
% INFO    : Bus 6484	: V=0.9729802, theta=-61.434763 -> V=1.0, theta=0.0
% INFO    : Bus 6485	: V=0.9725821, theta=-61.536893 -> V=1.0, theta=0.0
% INFO    : Bus 6486	: V=0.9781311, theta=-60.303639 -> V=1.0, theta=0.0
% INFO    : Bus 6487	: V=0.9779305, theta=-60.433516 -> V=1.0, theta=0.0
% INFO    : Bus 6488	: V=0.9770211, theta=-60.296043 -> V=1.0, theta=0.0
% INFO    : Bus 6489	: V=0.9796265, theta=-59.711075 -> V=1.0, theta=0.0
% INFO    : Bus 6490	: V=0.9784542, theta=-60.157712 -> V=1.0, theta=0.0
% INFO    : Bus 6491	: V=0.9788649, theta=-60.00289 -> V=1.0, theta=0.0
% INFO    : Bus 6492	: V=0.9738887, theta=-61.286263 -> V=1.0, theta=0.0
% INFO    : Bus 6493	: V=0.9707443, theta=-60.98932 -> V=1.0, theta=0.0
% INFO    : Bus 6494	: V=0.9818856, theta=-59.10985 -> V=1.0, theta=0.0
% INFO    : Bus 6495	: V=0.9842037, theta=-58.859733 -> V=1.0, theta=0.0
% INFO    : Bus 6496	: V=0.9861914, theta=-58.260671 -> V=1.0, theta=0.0
% INFO    : Bus 6497	: V=0.9764195, theta=-60.426286 -> V=1.0, theta=0.0
% INFO    : Bus 6498	: V=0.982948, theta=-59.368011 -> V=1.0, theta=0.0
% INFO    : Bus 6499	: V=0.9825453, theta=-59.648371 -> V=1.0, theta=0.0
% INFO    : Bus 6500	: V=0.9819405, theta=-60.180707 -> V=1.0, theta=0.0
% INFO    : Bus 6501	: V=0.9804171, theta=-60.369088 -> V=1.0, theta=0.0
% INFO    : Bus 6502	: V=0.9762477, theta=-61.73915 -> V=1.0, theta=0.0
% INFO    : Bus 6503	: V=0.9720031, theta=-62.669258 -> V=1.0, theta=0.0
% INFO    : Bus 6504	: V=0.972192, theta=-62.655665 -> V=1.0, theta=0.0
% INFO    : Bus 6505	: V=0.9726107, theta=-62.644033 -> V=1.0, theta=0.0
% INFO    : Bus 6506	: V=0.97496, theta=-62.586777 -> V=1.0, theta=0.0
% INFO    : Bus 6507	: V=0.9727695, theta=-62.426543 -> V=1.0, theta=0.0
% INFO    : Bus 6508	: V=0.9733036, theta=-62.412989 -> V=1.0, theta=0.0
% INFO    : Bus 6509	: V=0.9794647, theta=-61.940681 -> V=1.0, theta=0.0
% INFO    : Bus 6510	: V=0.9821038, theta=-60.818026 -> V=1.0, theta=0.0
% INFO    : Bus 6511	: V=0.9823362, theta=-61.185712 -> V=1.0, theta=0.0
% INFO    : Bus 6512	: V=0.981475, theta=-61.297814 -> V=1.0, theta=0.0
% INFO    : Bus 6513	: V=0.9755919, theta=-62.160794 -> V=1.0, theta=0.0
% INFO    : Bus 6514	: V=0.9803788, theta=-61.438523 -> V=1.0, theta=0.0
% INFO    : Bus 6515	: V=0.9684885, theta=-62.009236 -> V=1.0, theta=0.0
% INFO    : Bus 6516	: V=0.9718112, theta=-60.860148 -> V=1.0, theta=0.0
% INFO    : Bus 6517	: V=0.9699286, theta=-61.966485 -> V=1.0, theta=0.0
% INFO    : Bus 6518	: V=0.968886, theta=-62.000644 -> V=1.0, theta=0.0
% INFO    : Bus 6519	: V=0.9786706, theta=-60.745159 -> V=1.0, theta=0.0
% INFO    : Bus 6520	: V=0.9712514, theta=-61.637148 -> V=1.0, theta=0.0
% INFO    : Bus 6521	: V=0.9777739, theta=-61.235777 -> V=1.0, theta=0.0
% INFO    : Bus 6522	: V=0.9767987, theta=-61.243569 -> V=1.0, theta=0.0
% INFO    : Bus 6523	: V=0.981073, theta=-60.660407 -> V=1.0, theta=0.0
% INFO    : Bus 6524	: V=0.9788263, theta=-61.317862 -> V=1.0, theta=0.0
% INFO    : Bus 6525	: V=0.992539, theta=-56.846813 -> V=1.0, theta=0.0
% INFO    : Bus 6526	: V=0.9852274, theta=-59.97783 -> V=1.0, theta=0.0
% INFO    : Bus 6527	: V=0.9850625, theta=-60.59311 -> V=1.0, theta=0.0
% INFO    : Bus 6528	: V=0.9753261, theta=-61.583952 -> V=1.0, theta=0.0
% INFO    : Bus 6529	: V=0.9725233, theta=-61.635863 -> V=1.0, theta=0.0
% INFO    : Bus 6530	: V=0.9737088, theta=-61.605194 -> V=1.0, theta=0.0
% INFO    : Bus 6531	: V=0.9851216, theta=-60.330936 -> V=1.0, theta=0.0
% INFO    : Bus 6532	: V=0.9843133, theta=-60.572706 -> V=1.0, theta=0.0
% INFO    : Bus 6533	: V=0.9838568, theta=-60.743032 -> V=1.0, theta=0.0
% INFO    : Bus 6534	: V=0.9700932, theta=-62.167982 -> V=1.0, theta=0.0
% INFO    : Bus 6535	: V=0.971413, theta=-62.130835 -> V=1.0, theta=0.0
% INFO    : Bus 6536	: V=0.9915862, theta=-57.462933 -> V=1.0, theta=0.0
% INFO    : Bus 6537	: V=0.9863679, theta=-59.937895 -> V=1.0, theta=0.0
% INFO    : Bus 6538	: V=0.9824008, theta=-60.01756 -> V=1.0, theta=0.0
% INFO    : Bus 6539	: V=0.983531, theta=-61.15421 -> V=1.0, theta=0.0
% INFO    : Bus 6540	: V=0.9757247, theta=-63.704735 -> V=1.0, theta=0.0
% INFO    : Bus 6541	: V=0.9646634, theta=-63.022441 -> V=1.0, theta=0.0
% INFO    : Bus 6542	: V=0.9721968, theta=-62.437503 -> V=1.0, theta=0.0
% INFO    : Bus 6543	: V=0.9782079, theta=-62.522283 -> V=1.0, theta=0.0
% INFO    : Bus 6544	: V=0.9781878, theta=-62.290571 -> V=1.0, theta=0.0
% INFO    : Bus 6545	: V=0.9668944, theta=-62.96323 -> V=1.0, theta=0.0
% INFO    : Bus 6546	: V=0.9717541, theta=-62.45609 -> V=1.0, theta=0.0
% INFO    : Bus 6547	: V=0.9680445, theta=-62.900493 -> V=1.0, theta=0.0
% INFO    : Bus 6548	: V=0.9698118, theta=-62.848729 -> V=1.0, theta=0.0
% INFO    : Bus 6549	: V=0.9738224, theta=-62.949442 -> V=1.0, theta=0.0
% INFO    : Bus 6550	: V=0.9726026, theta=-64.254861 -> V=1.0, theta=0.0
% INFO    : Bus 6551	: V=0.9720393, theta=-65.16421 -> V=1.0, theta=0.0
% INFO    : Bus 6552	: V=0.973673, theta=-64.467693 -> V=1.0, theta=0.0
% INFO    : Bus 6553	: V=0.96578, theta=-64.973635 -> V=1.0, theta=0.0
% INFO    : Bus 6554	: V=0.9839351, theta=-61.601592 -> V=1.0, theta=0.0
% INFO    : Bus 6555	: V=0.9806784, theta=-62.846875 -> V=1.0, theta=0.0
% INFO    : Bus 6556	: V=0.9755477, theta=-69.150884 -> V=1.0, theta=0.0
% INFO    : Bus 6557	: V=0.9738792, theta=-68.798409 -> V=1.0, theta=0.0
% INFO    : Bus 6558	: V=0.9808154, theta=-65.907574 -> V=1.0, theta=0.0
% INFO    : Bus 6559	: V=0.9777884, theta=-66.340998 -> V=1.0, theta=0.0
% INFO    : Bus 6560	: V=0.9800433, theta=-65.569993 -> V=1.0, theta=0.0
% INFO    : Bus 6561	: V=0.9761786, theta=-66.345455 -> V=1.0, theta=0.0
% INFO    : Bus 6562	: V=0.9722231, theta=-67.433889 -> V=1.0, theta=0.0
% INFO    : Bus 6563	: V=0.9710927, theta=-70.596966 -> V=1.0, theta=0.0
% INFO    : Bus 6564	: V=0.964916, theta=-69.963776 -> V=1.0, theta=0.0
% INFO    : Bus 6565	: V=0.9667272, theta=-69.241056 -> V=1.0, theta=0.0
% INFO    : Bus 6566	: V=0.9651121, theta=-69.47929 -> V=1.0, theta=0.0
% INFO    : Bus 6567	: V=0.9645469, theta=-69.495079 -> V=1.0, theta=0.0
% INFO    : Bus 6568	: V=0.9643553, theta=-69.469576 -> V=1.0, theta=0.0
% INFO    : Bus 6569	: V=0.9645065, theta=-69.41222 -> V=1.0, theta=0.0
% INFO    : Bus 6570	: V=0.9644098, theta=-68.832692 -> V=1.0, theta=0.0
% INFO    : Bus 6571	: V=0.9628265, theta=-69.11414 -> V=1.0, theta=0.0
% INFO    : Bus 6572	: V=0.9628251, theta=-68.629819 -> V=1.0, theta=0.0
% INFO    : Bus 6573	: V=0.9645838, theta=-67.756407 -> V=1.0, theta=0.0
% INFO    : Bus 6574	: V=0.9668689, theta=-67.695446 -> V=1.0, theta=0.0
% INFO    : Bus 6575	: V=0.9744108, theta=-66.25741 -> V=1.0, theta=0.0
% INFO    : Bus 6576	: V=0.9678694, theta=-67.667577 -> V=1.0, theta=0.0
% INFO    : Bus 6577	: V=0.9662488, theta=-67.713111 -> V=1.0, theta=0.0
% INFO    : Bus 6578	: V=0.9641345, theta=-72.345067 -> V=1.0, theta=0.0
% INFO    : Bus 6579	: V=0.9720163, theta=-71.790191 -> V=1.0, theta=0.0
% INFO    : Bus 6580	: V=0.9722912, theta=-72.701842 -> V=1.0, theta=0.0
% INFO    : Bus 6581	: V=0.9769795, theta=-63.917649 -> V=1.0, theta=0.0
% INFO    : Bus 6582	: V=0.9772218, theta=-63.912637 -> V=1.0, theta=0.0
% INFO    : Bus 6583	: V=0.9842989, theta=-63.198435 -> V=1.0, theta=0.0
% INFO    : Bus 6584	: V=0.9841139, theta=-63.194085 -> V=1.0, theta=0.0
% INFO    : Bus 6585	: V=0.9841092, theta=-63.183102 -> V=1.0, theta=0.0
% INFO    : Bus 6586	: V=0.9841559, theta=-63.173894 -> V=1.0, theta=0.0
% INFO    : Bus 6587	: V=0.983063, theta=-63.311841 -> V=1.0, theta=0.0
% INFO    : Bus 6588	: V=0.9695244, theta=-65.3088 -> V=1.0, theta=0.0
% INFO    : Bus 6589	: V=0.9723076, theta=-65.042327 -> V=1.0, theta=0.0
% INFO    : Bus 6590	: V=0.9727053, theta=-65.006068 -> V=1.0, theta=0.0
% INFO    : Bus 6591	: V=0.9855083, theta=-63.470551 -> V=1.0, theta=0.0
% INFO    : Bus 6592	: V=0.9796186, theta=-64.509296 -> V=1.0, theta=0.0
% INFO    : Bus 6593	: V=0.9616795, theta=-67.37976 -> V=1.0, theta=0.0
% INFO    : Bus 6594	: V=0.9620652, theta=-67.371683 -> V=1.0, theta=0.0
% INFO    : Bus 6595	: V=0.9651368, theta=-67.241561 -> V=1.0, theta=0.0
% INFO    : Bus 6596	: V=0.9692516, theta=-64.560421 -> V=1.0, theta=0.0
% INFO    : Bus 6597	: V=0.9827933, theta=-63.683926 -> V=1.0, theta=0.0
% INFO    : Bus 6598	: V=0.9909967, theta=-62.680932 -> V=1.0, theta=0.0
% INFO    : Bus 6599	: V=0.9692863, theta=-64.597916 -> V=1.0, theta=0.0
% INFO    : Bus 6600	: V=0.9747649, theta=-64.065 -> V=1.0, theta=0.0
% INFO    : Bus 6601	: V=0.9671711, theta=-64.634589 -> V=1.0, theta=0.0
% INFO    : Bus 6602	: V=0.9560261, theta=-65.8689 -> V=1.0, theta=0.0
% INFO    : Bus 6603	: V=0.9573308, theta=-65.776556 -> V=1.0, theta=0.0
% INFO    : Bus 6604	: V=0.9743068, theta=-64.323992 -> V=1.0, theta=0.0
% INFO    : Bus 6605	: V=0.9546157, theta=-65.909661 -> V=1.0, theta=0.0
% INFO    : Bus 6606	: V=0.9646145, theta=-65.717121 -> V=1.0, theta=0.0
% INFO    : Bus 6607	: V=0.9666432, theta=-65.511215 -> V=1.0, theta=0.0
% INFO    : Bus 6608	: V=0.9747259, theta=-64.506367 -> V=1.0, theta=0.0
% INFO    : Bus 6609	: V=0.9718488, theta=-65.091481 -> V=1.0, theta=0.0
% INFO    : Bus 6610	: V=0.9701783, theta=-65.131983 -> V=1.0, theta=0.0
% INFO    : Bus 6611	: V=0.9754168, theta=-64.8636 -> V=1.0, theta=0.0
% INFO    : Bus 6612	: V=0.9724495, theta=-65.042151 -> V=1.0, theta=0.0
% INFO    : Bus 6613	: V=0.9833433, theta=-63.730879 -> V=1.0, theta=0.0
% INFO    : Bus 6614	: V=0.9689654, theta=-65.779931 -> V=1.0, theta=0.0
% INFO    : Bus 6615	: V=0.965967, theta=-67.219436 -> V=1.0, theta=0.0
% INFO    : Bus 6616	: V=0.966771, theta=-67.131062 -> V=1.0, theta=0.0
% INFO    : Bus 6617	: V=0.9663459, theta=-67.077921 -> V=1.0, theta=0.0
% INFO    : Bus 6618	: V=0.9674833, theta=-66.591868 -> V=1.0, theta=0.0
% INFO    : Bus 6619	: V=0.9726891, theta=-65.470432 -> V=1.0, theta=0.0
% INFO    : Bus 6620	: V=0.9708945, theta=-65.486924 -> V=1.0, theta=0.0
% INFO    : Bus 6621	: V=1.0001783, theta=-61.471895 -> V=1.0, theta=0.0
% INFO    : Bus 6622	: V=0.9731225, theta=-64.483327 -> V=1.0, theta=0.0
% INFO    : Bus 6623	: V=0.9716654, theta=-64.505046 -> V=1.0, theta=0.0
% INFO    : Bus 6624	: V=0.9593594, theta=-65.502125 -> V=1.0, theta=0.0
% INFO    : Bus 6625	: V=0.9808683, theta=-63.525015 -> V=1.0, theta=0.0
% INFO    : Bus 6626	: V=0.976409, theta=-64.072636 -> V=1.0, theta=0.0
% INFO    : Bus 6627	: V=0.9846901, theta=-63.113878 -> V=1.0, theta=0.0
% INFO    : Bus 6628	: V=0.9856145, theta=-63.024047 -> V=1.0, theta=0.0
% INFO    : Bus 6629	: V=0.9776946, theta=-63.961117 -> V=1.0, theta=0.0
% INFO    : Bus 6630	: V=0.9883845, theta=-62.793947 -> V=1.0, theta=0.0
% INFO    : Bus 6631	: V=0.9920539, theta=-62.514401 -> V=1.0, theta=0.0
% INFO    : Bus 6632	: V=0.9705527, theta=-64.502333 -> V=1.0, theta=0.0
% INFO    : Bus 6633	: V=0.9712682, theta=-64.459321 -> V=1.0, theta=0.0
% INFO    : Bus 6634	: V=0.9734554, theta=-64.297765 -> V=1.0, theta=0.0
% INFO    : Bus 6635	: V=0.9744098, theta=-64.174727 -> V=1.0, theta=0.0
% INFO    : Bus 6636	: V=0.9756992, theta=-64.136795 -> V=1.0, theta=0.0
% INFO    : Bus 6637	: V=0.9988621, theta=-61.884745 -> V=1.0, theta=0.0
% INFO    : Bus 6638	: V=0.9982797, theta=-61.967937 -> V=1.0, theta=0.0
% INFO    : Bus 6639	: V=0.9790844, theta=-63.769351 -> V=1.0, theta=0.0
% INFO    : Bus 6640	: V=0.9808411, theta=-63.225371 -> V=1.0, theta=0.0
% INFO    : Bus 6641	: V=0.9795842, theta=-63.645812 -> V=1.0, theta=0.0
% INFO    : Bus 6642	: V=1.0083016, theta=-60.47832 -> V=1.0, theta=0.0
% INFO    : Bus 6643	: V=0.9784075, theta=-63.656831 -> V=1.0, theta=0.0
% INFO    : Bus 6644	: V=0.9818219, theta=-63.11556 -> V=1.0, theta=0.0
% INFO    : Bus 6645	: V=0.981866, theta=-63.536584 -> V=1.0, theta=0.0
% INFO    : Bus 6646	: V=0.9694327, theta=-64.520396 -> V=1.0, theta=0.0
% INFO    : Bus 6647	: V=0.9705047, theta=-64.644242 -> V=1.0, theta=0.0
% INFO    : Bus 6648	: V=0.9607925, theta=-66.785261 -> V=1.0, theta=0.0
% INFO    : Bus 6649	: V=0.9697684, theta=-64.693742 -> V=1.0, theta=0.0
% INFO    : Bus 6650	: V=0.9806873, theta=-63.65963 -> V=1.0, theta=0.0
% INFO    : Bus 6651	: V=0.9691553, theta=-64.682556 -> V=1.0, theta=0.0
% INFO    : Bus 6652	: V=0.9813279, theta=-63.606135 -> V=1.0, theta=0.0
% INFO    : Bus 6653	: V=0.9832374, theta=-63.088662 -> V=1.0, theta=0.0
% INFO    : Bus 6654	: V=0.9773853, theta=-63.831443 -> V=1.0, theta=0.0
% INFO    : Bus 6655	: V=0.9776592, theta=-63.828926 -> V=1.0, theta=0.0
% INFO    : Bus 6656	: V=0.9761387, theta=-63.952608 -> V=1.0, theta=0.0
% INFO    : Bus 6657	: V=0.976582, theta=-63.946634 -> V=1.0, theta=0.0
% INFO    : Bus 6658	: V=0.9842811, theta=-63.599275 -> V=1.0, theta=0.0
% INFO    : Bus 6659	: V=0.9671965, theta=-64.707934 -> V=1.0, theta=0.0
% INFO    : Bus 6660	: V=0.977894, theta=-71.335789 -> V=1.0, theta=0.0
% INFO    : Bus 6661	: V=0.9791018, theta=-71.488381 -> V=1.0, theta=0.0
% INFO    : Bus 6662	: V=0.9815112, theta=-71.285563 -> V=1.0, theta=0.0
% INFO    : Bus 6663	: V=0.9820632, theta=-71.259313 -> V=1.0, theta=0.0
% INFO    : Bus 6664	: V=0.9794395, theta=-71.687284 -> V=1.0, theta=0.0
% INFO    : Bus 6665	: V=0.9839956, theta=-70.805304 -> V=1.0, theta=0.0
% INFO    : Bus 6666	: V=0.984956, theta=-70.226906 -> V=1.0, theta=0.0
% INFO    : Bus 6667	: V=0.9698791, theta=-71.895014 -> V=1.0, theta=0.0
% INFO    : Bus 6668	: V=0.9917295, theta=-69.948996 -> V=1.0, theta=0.0
% INFO    : Bus 6669	: V=0.9759296, theta=-71.324452 -> V=1.0, theta=0.0
% INFO    : Bus 6670	: V=0.9953833, theta=-58.344169 -> V=1.0, theta=0.0
% INFO    : Bus 6671	: V=0.9834574, theta=-59.957897 -> V=1.0, theta=0.0
% INFO    : Bus 6672	: V=0.9877432, theta=-58.88899 -> V=1.0, theta=0.0
% INFO    : Bus 6673	: V=0.9952564, theta=-56.399453 -> V=1.0, theta=0.0
% INFO    : Bus 6674	: V=1.0020291, theta=-55.465151 -> V=1.0, theta=0.0
% INFO    : Bus 6675	: V=1.0004188, theta=-57.01284 -> V=1.0, theta=0.0
% INFO    : Bus 6676	: V=0.9877641, theta=-58.984149 -> V=1.0, theta=0.0
% INFO    : Bus 6677	: V=0.9803479, theta=-58.953652 -> V=1.0, theta=0.0
% INFO    : Bus 6678	: V=0.9796294, theta=-59.468564 -> V=1.0, theta=0.0
% INFO    : Bus 6679	: V=0.9938734, theta=-57.247502 -> V=1.0, theta=0.0
% INFO    : Bus 6680	: V=0.9926227, theta=-56.651358 -> V=1.0, theta=0.0
% INFO    : Bus 6681	: V=0.9809327, theta=-58.856189 -> V=1.0, theta=0.0
% INFO    : Bus 6682	: V=0.9863653, theta=-58.042231 -> V=1.0, theta=0.0
% INFO    : Bus 6683	: V=0.9947006, theta=-56.285376 -> V=1.0, theta=0.0
% INFO    : Bus 6684	: V=0.9915287, theta=-56.619475 -> V=1.0, theta=0.0
% INFO    : Bus 6685	: V=0.9912241, theta=-56.694591 -> V=1.0, theta=0.0
% INFO    : Bus 6686	: V=0.9907357, theta=-56.700335 -> V=1.0, theta=0.0
% INFO    : Bus 6687	: V=0.9970258, theta=-55.414056 -> V=1.0, theta=0.0
% INFO    : Bus 6688	: V=0.9942789, theta=-56.063812 -> V=1.0, theta=0.0
% INFO    : Bus 6689	: V=0.9994352, theta=-56.116498 -> V=1.0, theta=0.0
% INFO    : Bus 6690	: V=1.0141566, theta=-51.958547 -> V=1.0, theta=0.0
% INFO    : Bus 6691	: V=1.0075306, theta=-52.927763 -> V=1.0, theta=0.0
% INFO    : Bus 6692	: V=1.0126718, theta=-51.177627 -> V=1.0, theta=0.0
% INFO    : Bus 6693	: V=1.0078093, theta=-51.877013 -> V=1.0, theta=0.0
% INFO    : Bus 6694	: V=1.0197732, theta=-49.841096 -> V=1.0, theta=0.0
% INFO    : Bus 6695	: V=1.0163415, theta=-51.20312 -> V=1.0, theta=0.0
% INFO    : Bus 6696	: V=1.0131591, theta=-51.810064 -> V=1.0, theta=0.0
% INFO    : Bus 6697	: V=1.0146164, theta=-51.60569 -> V=1.0, theta=0.0
% INFO    : Bus 6698	: V=1.0196902, theta=-49.683894 -> V=1.0, theta=0.0
% INFO    : Bus 6699	: V=0.9672641, theta=-65.886233 -> V=1.0, theta=0.0
% INFO    : Bus 6700	: V=0.9651881, theta=-66.285707 -> V=1.0, theta=0.0
% INFO    : Bus 6701	: V=0.9659849, theta=-65.916619 -> V=1.0, theta=0.0
% INFO    : Bus 6702	: V=0.9548739, theta=-67.057637 -> V=1.0, theta=0.0
% INFO    : Bus 6703	: V=0.9688671, theta=-65.403832 -> V=1.0, theta=0.0
% INFO    : Bus 6704	: V=0.959482, theta=-66.725857 -> V=1.0, theta=0.0
% INFO    : Bus 6705	: V=0.9687936, theta=-65.787141 -> V=1.0, theta=0.0
% INFO    : Bus 6706	: V=0.961646, theta=-66.755534 -> V=1.0, theta=0.0
% INFO    : Bus 6707	: V=0.9556862, theta=-67.469604 -> V=1.0, theta=0.0
% INFO    : Bus 6708	: V=0.9507713, theta=-68.138359 -> V=1.0, theta=0.0
% INFO    : Bus 6709	: V=0.9515459, theta=-68.115769 -> V=1.0, theta=0.0
% INFO    : Bus 6710	: V=0.9551427, theta=-67.528904 -> V=1.0, theta=0.0
% INFO    : Bus 6711	: V=0.9527294, theta=-68.008889 -> V=1.0, theta=0.0
% INFO    : Bus 6712	: V=0.951459, theta=-68.117964 -> V=1.0, theta=0.0
% INFO    : Bus 6713	: V=0.9591234, theta=-66.830867 -> V=1.0, theta=0.0
% INFO    : Bus 6714	: V=0.9664967, theta=-65.952983 -> V=1.0, theta=0.0
% INFO    : Bus 6715	: V=0.9778651, theta=-64.013122 -> V=1.0, theta=0.0
% INFO    : Bus 6716	: V=0.9621061, theta=-67.061859 -> V=1.0, theta=0.0
% INFO    : Bus 6717	: V=0.9643734, theta=-66.924956 -> V=1.0, theta=0.0
% INFO    : Bus 6718	: V=0.9631274, theta=-65.64967 -> V=1.0, theta=0.0
% INFO    : Bus 6719	: V=0.9625031, theta=-65.665145 -> V=1.0, theta=0.0
% INFO    : Bus 6720	: V=0.9750057, theta=-64.738048 -> V=1.0, theta=0.0
% INFO    : Bus 6721	: V=0.9959659, theta=-62.156243 -> V=1.0, theta=0.0
% INFO    : Bus 6722	: V=0.996673, theta=-62.092938 -> V=1.0, theta=0.0
% INFO    : Bus 6723	: V=0.9995959, theta=-61.873857 -> V=1.0, theta=0.0
% INFO    : Bus 6724	: V=0.9991971, theta=-61.84882 -> V=1.0, theta=0.0
% INFO    : Bus 6725	: V=0.9976731, theta=-61.990729 -> V=1.0, theta=0.0
% INFO    : Bus 6726	: V=0.9703139, theta=-65.212197 -> V=1.0, theta=0.0
% INFO    : Bus 6727	: V=0.9678719, theta=-65.419271 -> V=1.0, theta=0.0
% INFO    : Bus 6728	: V=0.9625775, theta=-65.982025 -> V=1.0, theta=0.0
% INFO    : Bus 6729	: V=0.9690126, theta=-65.350381 -> V=1.0, theta=0.0
% INFO    : Bus 6730	: V=0.9535397, theta=-68.735401 -> V=1.0, theta=0.0
% INFO    : Bus 6731	: V=0.9655408, theta=-66.572077 -> V=1.0, theta=0.0
% INFO    : Bus 6732	: V=0.9693791, theta=-66.46452 -> V=1.0, theta=0.0
% INFO    : Bus 6733	: V=0.9647135, theta=-66.897066 -> V=1.0, theta=0.0
% INFO    : Bus 6734	: V=0.9661596, theta=-66.754163 -> V=1.0, theta=0.0
% INFO    : Bus 6735	: V=0.9885178, theta=-64.469931 -> V=1.0, theta=0.0
% INFO    : Bus 6736	: V=0.9760546, theta=-66.561703 -> V=1.0, theta=0.0
% INFO    : Bus 6737	: V=0.9786402, theta=-65.861732 -> V=1.0, theta=0.0
% INFO    : Bus 6738	: V=0.9763263, theta=-66.324993 -> V=1.0, theta=0.0
% INFO    : Bus 6739	: V=0.9891428, theta=-64.355851 -> V=1.0, theta=0.0
% INFO    : Bus 6740	: V=0.9747873, theta=-66.673392 -> V=1.0, theta=0.0
% INFO    : Bus 6741	: V=0.9785596, theta=-65.866974 -> V=1.0, theta=0.0
% INFO    : Bus 6742	: V=0.9786883, theta=-65.856174 -> V=1.0, theta=0.0
% INFO    : Bus 6743	: V=0.9760282, theta=-66.561787 -> V=1.0, theta=0.0
% INFO    : Bus 6744	: V=0.975791, theta=-66.600629 -> V=1.0, theta=0.0
% INFO    : Bus 6745	: V=0.9759006, theta=-66.598349 -> V=1.0, theta=0.0
% INFO    : Bus 6746	: V=0.9897662, theta=-64.24366 -> V=1.0, theta=0.0
% INFO    : Bus 6747	: V=0.9758629, theta=-66.60651 -> V=1.0, theta=0.0
% INFO    : Bus 6748	: V=0.9764594, theta=-66.535107 -> V=1.0, theta=0.0
% INFO    : Bus 6749	: V=0.9765058, theta=-66.536343 -> V=1.0, theta=0.0
% INFO    : Bus 6750	: V=0.9913059, theta=-64.023103 -> V=1.0, theta=0.0
% INFO    : Bus 6751	: V=0.9764465, theta=-66.559907 -> V=1.0, theta=0.0
% INFO    : Bus 6752	: V=0.9758183, theta=-66.618212 -> V=1.0, theta=0.0
% INFO    : Bus 6753	: V=0.9758396, theta=-66.611887 -> V=1.0, theta=0.0
% INFO    : Bus 6754	: V=0.9896111, theta=-64.370699 -> V=1.0, theta=0.0
% INFO    : Bus 6755	: V=0.975176, theta=-66.675044 -> V=1.0, theta=0.0
% INFO    : Bus 6756	: V=0.987178, theta=-64.753422 -> V=1.0, theta=0.0
% INFO    : Bus 6757	: V=0.9745272, theta=-66.704997 -> V=1.0, theta=0.0
% INFO    : Bus 6758	: V=0.974562, theta=-66.704149 -> V=1.0, theta=0.0
% INFO    : Bus 6759	: V=0.9905083, theta=-64.276367 -> V=1.0, theta=0.0
% INFO    : Bus 6760	: V=0.9748098, theta=-66.713973 -> V=1.0, theta=0.0
% INFO    : Bus 6761	: V=0.9900378, theta=-64.341559 -> V=1.0, theta=0.0
% INFO    : Bus 6762	: V=0.9745951, theta=-66.730875 -> V=1.0, theta=0.0
% INFO    : Bus 6763	: V=0.9745498, theta=-66.738878 -> V=1.0, theta=0.0
% INFO    : Bus 6764	: V=0.9744345, theta=-66.718589 -> V=1.0, theta=0.0
% INFO    : Bus 6765	: V=0.9898955, theta=-64.355734 -> V=1.0, theta=0.0
% INFO    : Bus 6766	: V=0.9742284, theta=-66.733513 -> V=1.0, theta=0.0
% INFO    : Bus 6767	: V=0.9900523, theta=-64.335855 -> V=1.0, theta=0.0
% INFO    : Bus 6768	: V=0.9897744, theta=-64.365754 -> V=1.0, theta=0.0
% INFO    : Bus 6769	: V=0.9742498, theta=-66.742759 -> V=1.0, theta=0.0
% INFO    : Bus 6770	: V=0.9909892, theta=-64.11414 -> V=1.0, theta=0.0
% INFO    : Bus 6771	: V=0.9743516, theta=-66.720863 -> V=1.0, theta=0.0
% INFO    : Bus 6772	: V=0.9912328, theta=-64.087857 -> V=1.0, theta=0.0
% INFO    : Bus 6773	: V=0.9742745, theta=-66.754604 -> V=1.0, theta=0.0
% INFO    : Bus 6774	: V=0.9905819, theta=-64.178148 -> V=1.0, theta=0.0
% INFO    : Bus 6775	: V=0.9910807, theta=-64.107493 -> V=1.0, theta=0.0
% INFO    : Bus 6776	: V=0.9741855, theta=-66.788673 -> V=1.0, theta=0.0
% INFO    : Bus 6777	: V=0.9911728, theta=-64.101759 -> V=1.0, theta=0.0
% INFO    : Bus 6778	: V=0.9912777, theta=-64.095122 -> V=1.0, theta=0.0
% INFO    : Bus 6779	: V=0.9759979, theta=-66.405742 -> V=1.0, theta=0.0
% INFO    : Bus 6780	: V=0.9738799, theta=-66.752767 -> V=1.0, theta=0.0
% INFO    : Bus 6781	: V=0.9914167, theta=-64.084231 -> V=1.0, theta=0.0
% INFO    : Bus 6782	: V=0.9916462, theta=-64.066039 -> V=1.0, theta=0.0
% INFO    : Bus 6783	: V=0.9928466, theta=-63.84826 -> V=1.0, theta=0.0
% INFO    : Bus 6784	: V=0.9920276, theta=-64.011122 -> V=1.0, theta=0.0
% INFO    : Bus 6785	: V=0.9918288, theta=-64.029188 -> V=1.0, theta=0.0
% INFO    : Bus 6786	: V=0.9916466, theta=-64.046451 -> V=1.0, theta=0.0
% INFO    : Bus 6787	: V=0.9914725, theta=-64.06352 -> V=1.0, theta=0.0
% INFO    : Bus 6788	: V=0.9899839, theta=-64.337683 -> V=1.0, theta=0.0
% INFO    : Bus 6789	: V=0.98963, theta=-64.350463 -> V=1.0, theta=0.0
% INFO    : Bus 6790	: V=0.9895484, theta=-64.352539 -> V=1.0, theta=0.0
% INFO    : Bus 6791	: V=0.9897007, theta=-64.350854 -> V=1.0, theta=0.0
% INFO    : Bus 6792	: V=0.990091, theta=-64.340485 -> V=1.0, theta=0.0
% INFO    : Bus 6793	: V=0.9742198, theta=-66.806636 -> V=1.0, theta=0.0
% INFO    : Bus 6794	: V=0.9921497, theta=-63.980952 -> V=1.0, theta=0.0
% INFO    : Bus 6795	: V=0.9763572, theta=-66.402857 -> V=1.0, theta=0.0
% INFO    : Bus 6796	: V=0.9922055, theta=-63.978945 -> V=1.0, theta=0.0
% INFO    : Bus 6797	: V=0.9742885, theta=-66.816106 -> V=1.0, theta=0.0
% INFO    : Bus 6798	: V=0.9910387, theta=-64.272514 -> V=1.0, theta=0.0
% INFO    : Bus 6799	: V=0.9743683, theta=-66.830497 -> V=1.0, theta=0.0
% INFO    : Bus 6800	: V=0.9925157, theta=-63.964384 -> V=1.0, theta=0.0
% INFO    : Bus 6801	: V=0.9745199, theta=-66.812881 -> V=1.0, theta=0.0
% INFO    : Bus 6802	: V=0.9923716, theta=-63.971394 -> V=1.0, theta=0.0
% INFO    : Bus 6803	: V=0.9745287, theta=-66.826093 -> V=1.0, theta=0.0
% INFO    : Bus 6804	: V=0.9927154, theta=-63.939744 -> V=1.0, theta=0.0
% INFO    : Bus 6805	: V=0.977183, theta=-66.384478 -> V=1.0, theta=0.0
% INFO    : Bus 6806	: V=1.0008004, theta=-62.543644 -> V=1.0, theta=0.0
% INFO    : Bus 6807	: V=0.9745638, theta=-66.827776 -> V=1.0, theta=0.0
% INFO    : Bus 6808	: V=0.9954249, theta=-63.45738 -> V=1.0, theta=0.0
% INFO    : Bus 6809	: V=0.9746525, theta=-66.826828 -> V=1.0, theta=0.0
% INFO    : Bus 6810	: V=0.9927974, theta=-63.920022 -> V=1.0, theta=0.0
% INFO    : Bus 6811	: V=0.9744144, theta=-66.815514 -> V=1.0, theta=0.0
% INFO    : Bus 6812	: V=0.974563, theta=-66.790043 -> V=1.0, theta=0.0
% INFO    : Bus 6813	: V=0.9895263, theta=-64.531816 -> V=1.0, theta=0.0
% INFO    : Bus 6814	: V=0.974562, theta=-66.743106 -> V=1.0, theta=0.0
% INFO    : Bus 6815	: V=0.9920967, theta=-64.03063 -> V=1.0, theta=0.0
% INFO    : Bus 6816	: V=0.9746941, theta=-66.738308 -> V=1.0, theta=0.0
% INFO    : Bus 6817	: V=0.9920125, theta=-64.033742 -> V=1.0, theta=0.0
% INFO    : Bus 6818	: V=0.9746257, theta=-66.765637 -> V=1.0, theta=0.0
% INFO    : Bus 6819	: V=1.0001457, theta=-62.545008 -> V=1.0, theta=0.0
% INFO    : Bus 6820	: V=0.9759176, theta=-66.616407 -> V=1.0, theta=0.0
% INFO    : Bus 6821	: V=0.9920071, theta=-64.026602 -> V=1.0, theta=0.0
% INFO    : Bus 6822	: V=0.9754085, theta=-66.765138 -> V=1.0, theta=0.0
% INFO    : Bus 6823	: V=0.9917457, theta=-64.069681 -> V=1.0, theta=0.0
% INFO    : Bus 6824	: V=0.9794593, theta=-65.862682 -> V=1.0, theta=0.0
% INFO    : Bus 6825	: V=0.9914771, theta=-64.130616 -> V=1.0, theta=0.0
% INFO    : Bus 6826	: V=0.9761039, theta=-66.611296 -> V=1.0, theta=0.0
% INFO    : Bus 6827	: V=0.9918095, theta=-64.051499 -> V=1.0, theta=0.0
% INFO    : Bus 6828	: V=0.975821, theta=-66.628507 -> V=1.0, theta=0.0
% INFO    : Bus 6829	: V=0.9757385, theta=-66.630776 -> V=1.0, theta=0.0
% INFO    : Bus 6830	: V=0.976417, theta=-66.577936 -> V=1.0, theta=0.0
% INFO    : Bus 6831	: V=0.9766199, theta=-66.572748 -> V=1.0, theta=0.0
% INFO    : Bus 6832	: V=0.9768196, theta=-66.567552 -> V=1.0, theta=0.0
% INFO    : Bus 6833	: V=0.9772404, theta=-66.550941 -> V=1.0, theta=0.0
% INFO    : Bus 6834	: V=0.991217, theta=-64.163004 -> V=1.0, theta=0.0
% INFO    : Bus 6835	: V=0.9768398, theta=-66.616356 -> V=1.0, theta=0.0
% INFO    : Bus 6836	: V=0.9922604, theta=-63.985448 -> V=1.0, theta=0.0
% INFO    : Bus 6837	: V=0.9769097, theta=-66.62002 -> V=1.0, theta=0.0
% INFO    : Bus 6838	: V=0.9766142, theta=-66.639181 -> V=1.0, theta=0.0
% INFO    : Bus 6839	: V=0.9925046, theta=-63.945407 -> V=1.0, theta=0.0
% INFO    : Bus 6840	: V=0.976299, theta=-66.670923 -> V=1.0, theta=0.0
% INFO    : Bus 6841	: V=0.9797132, theta=-65.833559 -> V=1.0, theta=0.0
% INFO    : Bus 6842	: V=0.9992254, theta=-62.636262 -> V=1.0, theta=0.0
% INFO    : Bus 6843	: V=0.9758577, theta=-66.625162 -> V=1.0, theta=0.0
% INFO    : Bus 6844	: V=0.9927897, theta=-63.89912 -> V=1.0, theta=0.0
% INFO    : Bus 6845	: V=0.9988015, theta=-62.674753 -> V=1.0, theta=0.0
% INFO    : Bus 6846	: V=0.9755581, theta=-66.761984 -> V=1.0, theta=0.0
% INFO    : Bus 6847	: V=0.9932688, theta=-63.83434 -> V=1.0, theta=0.0
% INFO    : Bus 6848	: V=0.9755484, theta=-66.7663 -> V=1.0, theta=0.0
% INFO    : Bus 6849	: V=0.9930523, theta=-63.85275 -> V=1.0, theta=0.0
% INFO    : Bus 6850	: V=0.9755647, theta=-66.777852 -> V=1.0, theta=0.0
% INFO    : Bus 6851	: V=0.9884633, theta=-64.697314 -> V=1.0, theta=0.0
% INFO    : Bus 6852	: V=0.9753001, theta=-66.787439 -> V=1.0, theta=0.0
% INFO    : Bus 6853	: V=0.9902868, theta=-64.400225 -> V=1.0, theta=0.0
% INFO    : Bus 6854	: V=0.9751317, theta=-66.801147 -> V=1.0, theta=0.0
% INFO    : Bus 6855	: V=0.9876863, theta=-64.717549 -> V=1.0, theta=0.0
% INFO    : Bus 6856	: V=0.9752326, theta=-66.791131 -> V=1.0, theta=0.0
% INFO    : Bus 6857	: V=0.974852, theta=-66.820082 -> V=1.0, theta=0.0
% INFO    : Bus 6858	: V=0.987849, theta=-64.713177 -> V=1.0, theta=0.0
% INFO    : Bus 6859	: V=0.9877726, theta=-64.715237 -> V=1.0, theta=0.0
% INFO    : Bus 6860	: V=0.9981087, theta=-62.772363 -> V=1.0, theta=0.0
% INFO    : Bus 6861	: V=0.9747281, theta=-66.823282 -> V=1.0, theta=0.0
% INFO    : Bus 6862	: V=0.9744777, theta=-66.821226 -> V=1.0, theta=0.0
% INFO    : Bus 6863	: V=0.9743801, theta=-66.823903 -> V=1.0, theta=0.0
% INFO    : Bus 6864	: V=0.9874624, theta=-64.660455 -> V=1.0, theta=0.0
% INFO    : Bus 6865	: V=0.9747791, theta=-66.86075 -> V=1.0, theta=0.0
% INFO    : Bus 6866	: V=0.9897176, theta=-64.336969 -> V=1.0, theta=0.0
% INFO    : Bus 6867	: V=0.9747887, theta=-66.870445 -> V=1.0, theta=0.0
% INFO    : Bus 6868	: V=0.9747276, theta=-66.872112 -> V=1.0, theta=0.0
% INFO    : Bus 6869	: V=0.9748893, theta=-66.878381 -> V=1.0, theta=0.0
% INFO    : Bus 6870	: V=0.9749606, theta=-66.880057 -> V=1.0, theta=0.0
% INFO    : Bus 6871	: V=0.988631, theta=-64.474573 -> V=1.0, theta=0.0
% INFO    : Bus 6872	: V=0.9750781, theta=-66.880796 -> V=1.0, theta=0.0
% INFO    : Bus 6873	: V=0.9842591, theta=-65.234913 -> V=1.0, theta=0.0
% INFO    : Bus 6874	: V=0.9843516, theta=-65.232451 -> V=1.0, theta=0.0
% INFO    : Bus 6875	: V=0.9752268, theta=-66.913574 -> V=1.0, theta=0.0
% INFO    : Bus 6876	: V=0.9844206, theta=-65.223254 -> V=1.0, theta=0.0
% INFO    : Bus 6877	: V=0.9747118, theta=-66.982645 -> V=1.0, theta=0.0
% INFO    : Bus 6878	: V=0.9750985, theta=-66.916803 -> V=1.0, theta=0.0
% INFO    : Bus 6879	: V=0.9874118, theta=-64.637956 -> V=1.0, theta=0.0
% INFO    : Bus 6880	: V=0.9871759, theta=-64.668749 -> V=1.0, theta=0.0
% INFO    : Bus 6881	: V=0.9751708, theta=-66.913972 -> V=1.0, theta=0.0
% INFO    : Bus 6882	: V=0.9848604, theta=-65.124116 -> V=1.0, theta=0.0
% INFO    : Bus 6883	: V=0.9751638, theta=-66.913261 -> V=1.0, theta=0.0
% INFO    : Bus 6884	: V=0.9879629, theta=-64.566347 -> V=1.0, theta=0.0
% INFO    : Bus 6885	: V=0.9751603, theta=-66.929431 -> V=1.0, theta=0.0
% INFO    : Bus 6886	: V=0.9751672, theta=-66.911507 -> V=1.0, theta=0.0
% INFO    : Bus 6887	: V=0.9752006, theta=-66.907805 -> V=1.0, theta=0.0
% INFO    : Bus 6888	: V=0.9753012, theta=-66.895698 -> V=1.0, theta=0.0
% INFO    : Bus 6889	: V=0.9754567, theta=-66.833119 -> V=1.0, theta=0.0
% INFO    : Bus 6890	: V=0.9861801, theta=-64.77612 -> V=1.0, theta=0.0
% INFO    : Bus 6891	: V=0.975153, theta=-66.792825 -> V=1.0, theta=0.0
% INFO    : Bus 6892	: V=0.9755788, theta=-66.829756 -> V=1.0, theta=0.0
% INFO    : Bus 6893	: V=0.9815486, theta=-65.624946 -> V=1.0, theta=0.0
% INFO    : Bus 6894	: V=0.975608, theta=-66.781627 -> V=1.0, theta=0.0
% INFO    : Bus 6895	: V=0.9758493, theta=-66.770824 -> V=1.0, theta=0.0
% INFO    : Bus 6896	: V=0.9763793, theta=-66.725502 -> V=1.0, theta=0.0
% INFO    : Bus 6897	: V=0.9802796, theta=-65.775547 -> V=1.0, theta=0.0
% INFO    : Bus 6898	: V=0.9808194, theta=-65.732615 -> V=1.0, theta=0.0
% INFO    : Bus 6899	: V=0.9844221, theta=-65.017714 -> V=1.0, theta=0.0
% INFO    : Bus 6900	: V=0.9813043, theta=-65.680069 -> V=1.0, theta=0.0
% INFO    : Bus 6901	: V=0.9826403, theta=-65.667436 -> V=1.0, theta=0.0
% INFO    : Bus 6902	: V=0.9847048, theta=-65.129957 -> V=1.0, theta=0.0
% INFO    : Bus 6903	: V=0.9792609, theta=-66.317419 -> V=1.0, theta=0.0
% INFO    : Bus 6904	: V=0.9824187, theta=-65.708733 -> V=1.0, theta=0.0
% INFO    : Bus 6905	: V=0.986731, theta=-64.72978 -> V=1.0, theta=0.0
% INFO    : Bus 6906	: V=0.9758432, theta=-66.803349 -> V=1.0, theta=0.0
% INFO    : Bus 6907	: V=0.9822164, theta=-65.746528 -> V=1.0, theta=0.0
% INFO    : Bus 6908	: V=0.9767156, theta=-66.673916 -> V=1.0, theta=0.0
% INFO    : Bus 6909	: V=0.9860793, theta=-64.854912 -> V=1.0, theta=0.0
% INFO    : Bus 6910	: V=0.9864326, theta=-64.805813 -> V=1.0, theta=0.0
% INFO    : Bus 6911	: V=0.9752879, theta=-66.911179 -> V=1.0, theta=0.0
% INFO    : Bus 6912	: V=0.9854729, theta=-65.124982 -> V=1.0, theta=0.0
% INFO    : Bus 6913	: V=0.9868201, theta=-64.750989 -> V=1.0, theta=0.0
% INFO    : Bus 6914	: V=0.9873588, theta=-64.676014 -> V=1.0, theta=0.0
% INFO    : Bus 6915	: V=0.9871306, theta=-64.691695 -> V=1.0, theta=0.0
% INFO    : Bus 6916	: V=0.9848267, theta=-65.188261 -> V=1.0, theta=0.0
% INFO    : Bus 6917	: V=0.9752254, theta=-66.928253 -> V=1.0, theta=0.0
% INFO    : Bus 6918	: V=0.9977106, theta=-62.827366 -> V=1.0, theta=0.0
% INFO    : Bus 6919	: V=0.9879482, theta=-64.613154 -> V=1.0, theta=0.0
% INFO    : Bus 6920	: V=0.9754714, theta=-66.911632 -> V=1.0, theta=0.0
% INFO    : Bus 6921	: V=0.9878248, theta=-64.63334 -> V=1.0, theta=0.0
% INFO    : Bus 6922	: V=0.9750519, theta=-66.943257 -> V=1.0, theta=0.0
% INFO    : Bus 6923	: V=0.9876671, theta=-64.659626 -> V=1.0, theta=0.0
% INFO    : Bus 6924	: V=0.9749958, theta=-66.94898 -> V=1.0, theta=0.0
% INFO    : Bus 6925	: V=0.9874394, theta=-64.691781 -> V=1.0, theta=0.0
% INFO    : Bus 6926	: V=0.9753731, theta=-66.914081 -> V=1.0, theta=0.0
% INFO    : Bus 6927	: V=0.9872202, theta=-64.718686 -> V=1.0, theta=0.0
% INFO    : Bus 6928	: V=0.9758079, theta=-66.894518 -> V=1.0, theta=0.0
% INFO    : Bus 6929	: V=0.9868323, theta=-64.802966 -> V=1.0, theta=0.0
% INFO    : Bus 6930	: V=0.9865695, theta=-64.874675 -> V=1.0, theta=0.0
% INFO    : Bus 6931	: V=0.9832396, theta=-65.564191 -> V=1.0, theta=0.0
% INFO    : Bus 6932	: V=0.9749555, theta=-66.953301 -> V=1.0, theta=0.0
% INFO    : Bus 6933	: V=0.9860677, theta=-64.938497 -> V=1.0, theta=0.0
% INFO    : Bus 6934	: V=0.9750871, theta=-66.948716 -> V=1.0, theta=0.0
% INFO    : Bus 6935	: V=0.9828778, theta=-65.628122 -> V=1.0, theta=0.0
% INFO    : Bus 6936	: V=0.9750337, theta=-66.951197 -> V=1.0, theta=0.0
% INFO    : Bus 6937	: V=0.9827957, theta=-65.62769 -> V=1.0, theta=0.0
% INFO    : Bus 6938	: V=0.9748142, theta=-66.968898 -> V=1.0, theta=0.0
% INFO    : Bus 6939	: V=0.9868775, theta=-64.777109 -> V=1.0, theta=0.0
% INFO    : Bus 6940	: V=0.9747396, theta=-66.977492 -> V=1.0, theta=0.0
% INFO    : Bus 6941	: V=0.9851746, theta=-65.148554 -> V=1.0, theta=0.0
% INFO    : Bus 6942	: V=0.9746832, theta=-66.978953 -> V=1.0, theta=0.0
% INFO    : Bus 6943	: V=0.9869966, theta=-64.763897 -> V=1.0, theta=0.0
% INFO    : Bus 6944	: V=0.9745984, theta=-66.986658 -> V=1.0, theta=0.0
% INFO    : Bus 6945	: V=0.9873522, theta=-64.749618 -> V=1.0, theta=0.0
% INFO    : Bus 6946	: V=0.9746807, theta=-66.984398 -> V=1.0, theta=0.0
% INFO    : Bus 6947	: V=0.9854126, theta=-65.133451 -> V=1.0, theta=0.0
% INFO    : Bus 6948	: V=0.9872463, theta=-64.7366 -> V=1.0, theta=0.0
% INFO    : Bus 6949	: V=0.9750476, theta=-66.975596 -> V=1.0, theta=0.0
% INFO    : Bus 6950	: V=0.9855319, theta=-65.124502 -> V=1.0, theta=0.0
% INFO    : Bus 6951	: V=0.9880394, theta=-64.61883 -> V=1.0, theta=0.0
% INFO    : Bus 6952	: V=0.9853387, theta=-65.129425 -> V=1.0, theta=0.0
% INFO    : Bus 6953	: V=0.9814868, theta=-66.020287 -> V=1.0, theta=0.0
% INFO    : Bus 6954	: V=0.9915041, theta=-64.14561 -> V=1.0, theta=0.0
% INFO    : Bus 6955	: V=0.9888585, theta=-64.519417 -> V=1.0, theta=0.0
% INFO    : Bus 6956	: V=0.9751528, theta=-66.965593 -> V=1.0, theta=0.0
% INFO    : Bus 6957	: V=0.9897923, theta=-64.361942 -> V=1.0, theta=0.0
% INFO    : Bus 6958	: V=0.9885812, theta=-64.549406 -> V=1.0, theta=0.0
% INFO    : Bus 6959	: V=0.9897484, theta=-64.394295 -> V=1.0, theta=0.0
% INFO    : Bus 6960	: V=0.9906605, theta=-64.252728 -> V=1.0, theta=0.0
% INFO    : Bus 6961	: V=0.9766759, theta=-67.045033 -> V=1.0, theta=0.0
% INFO    : Bus 6962	: V=0.9885319, theta=-64.528468 -> V=1.0, theta=0.0
% INFO    : Bus 6963	: V=0.9835835, theta=-65.861873 -> V=1.0, theta=0.0
% INFO    : Bus 6964	: V=0.9889517, theta=-64.515916 -> V=1.0, theta=0.0
% INFO    : Bus 6965	: V=0.977024, theta=-67.023825 -> V=1.0, theta=0.0
% INFO    : Bus 6966	: V=0.9897506, theta=-64.430026 -> V=1.0, theta=0.0
% INFO    : Bus 6967	: V=0.9775335, theta=-66.910466 -> V=1.0, theta=0.0
% INFO    : Bus 6968	: V=0.9818573, theta=-65.990458 -> V=1.0, theta=0.0
% INFO    : Bus 6969	: V=0.9882738, theta=-64.56282 -> V=1.0, theta=0.0
% INFO    : Bus 6970	: V=0.9880392, theta=-64.587682 -> V=1.0, theta=0.0
% INFO    : Bus 6971	: V=0.9884955, theta=-64.606277 -> V=1.0, theta=0.0
% INFO    : Bus 6972	: V=0.9881011, theta=-64.644487 -> V=1.0, theta=0.0
% INFO    : Bus 6973	: V=0.9832315, theta=-65.878926 -> V=1.0, theta=0.0
% INFO    : Bus 6974	: V=0.9877288, theta=-64.618436 -> V=1.0, theta=0.0
% INFO    : Bus 6975	: V=0.9878422, theta=-64.698945 -> V=1.0, theta=0.0
% INFO    : Bus 6976	: V=0.9778649, theta=-67.007161 -> V=1.0, theta=0.0
% INFO    : Bus 6977	: V=0.9856163, theta=-65.106962 -> V=1.0, theta=0.0
% INFO    : Bus 6978	: V=0.9874175, theta=-64.752056 -> V=1.0, theta=0.0
% INFO    : Bus 6979	: V=0.9854609, theta=-65.111425 -> V=1.0, theta=0.0
% INFO    : Bus 6980	: V=0.9829204, theta=-65.891915 -> V=1.0, theta=0.0
% INFO    : Bus 6981	: V=0.987221, theta=-64.787733 -> V=1.0, theta=0.0
% INFO    : Bus 6982	: V=0.9771445, theta=-66.788374 -> V=1.0, theta=0.0
% INFO    : Bus 6983	: V=0.9868677, theta=-64.836161 -> V=1.0, theta=0.0
% INFO    : Bus 6984	: V=0.9862849, theta=-64.917402 -> V=1.0, theta=0.0
% INFO    : Bus 6985	: V=0.9864687, theta=-64.897613 -> V=1.0, theta=0.0
% INFO    : Bus 6986	: V=0.9767302, theta=-66.837724 -> V=1.0, theta=0.0
% INFO    : Bus 6987	: V=0.9869497, theta=-64.82449 -> V=1.0, theta=0.0
% INFO    : Bus 6988	: V=0.9870028, theta=-64.705868 -> V=1.0, theta=0.0
% INFO    : Bus 6989	: V=0.9858734, theta=-64.981659 -> V=1.0, theta=0.0
% INFO    : Bus 6990	: V=0.9860479, theta=-65.043135 -> V=1.0, theta=0.0
% INFO    : Bus 6991	: V=0.978894, theta=-66.447504 -> V=1.0, theta=0.0
% INFO    : Bus 6992	: V=0.9755887, theta=-66.885541 -> V=1.0, theta=0.0
% INFO    : Bus 6993	: V=0.9771134, theta=-66.788813 -> V=1.0, theta=0.0
% INFO    : Bus 6994	: V=0.9756114, theta=-66.903377 -> V=1.0, theta=0.0
% INFO    : Bus 6995	: V=0.9828839, theta=-65.615558 -> V=1.0, theta=0.0
% INFO    : Bus 6996	: V=0.9753391, theta=-66.916299 -> V=1.0, theta=0.0
% INFO    : Bus 6997	: V=0.9853961, theta=-65.05591 -> V=1.0, theta=0.0
% INFO    : Bus 6998	: V=0.9753855, theta=-66.912371 -> V=1.0, theta=0.0
% INFO    : Bus 6999	: V=0.9823962, theta=-65.656432 -> V=1.0, theta=0.0
% INFO    : Bus 7000	: V=0.9755467, theta=-66.900373 -> V=1.0, theta=0.0
% INFO    : Bus 7001	: V=0.982517, theta=-65.653171 -> V=1.0, theta=0.0
% INFO    : Bus 7002	: V=0.9827194, theta=-65.639371 -> V=1.0, theta=0.0
% INFO    : Bus 7003	: V=0.9862288, theta=-64.932304 -> V=1.0, theta=0.0
% INFO    : Bus 7004	: V=0.9856659, theta=-65.014926 -> V=1.0, theta=0.0
% INFO    : Bus 7005	: V=0.9840008, theta=-65.330274 -> V=1.0, theta=0.0
% INFO    : Bus 7006	: V=0.9757544, theta=-66.895831 -> V=1.0, theta=0.0
% INFO    : Bus 7007	: V=0.9849723, theta=-65.1182 -> V=1.0, theta=0.0
% INFO    : Bus 7008	: V=0.9756476, theta=-66.902819 -> V=1.0, theta=0.0
% INFO    : Bus 7009	: V=0.9765749, theta=-66.841845 -> V=1.0, theta=0.0
% INFO    : Bus 7010	: V=0.9846669, theta=-65.164638 -> V=1.0, theta=0.0
% INFO    : Bus 7011	: V=0.9760915, theta=-66.879415 -> V=1.0, theta=0.0
% INFO    : Bus 7012	: V=0.9758615, theta=-66.890468 -> V=1.0, theta=0.0
% INFO    : Bus 7013	: V=0.984169, theta=-65.233851 -> V=1.0, theta=0.0
% INFO    : Bus 7014	: V=0.9814869, theta=-65.785672 -> V=1.0, theta=0.0
% INFO    : Bus 7015	: V=0.9844864, theta=-65.189618 -> V=1.0, theta=0.0
% INFO    : Bus 7016	: V=0.975778, theta=-66.891307 -> V=1.0, theta=0.0
% INFO    : Bus 7017	: V=0.9839398, theta=-65.334515 -> V=1.0, theta=0.0
% INFO    : Bus 7018	: V=0.9853198, theta=-65.063759 -> V=1.0, theta=0.0
% INFO    : Bus 7019	: V=0.9822786, theta=-65.798202 -> V=1.0, theta=0.0
% INFO    : Bus 7020	: V=0.9753663, theta=-66.889593 -> V=1.0, theta=0.0
% INFO    : Bus 7021	: V=0.9755407, theta=-66.856767 -> V=1.0, theta=0.0
% INFO    : Bus 7022	: V=0.975661, theta=-66.828554 -> V=1.0, theta=0.0
% INFO    : Bus 7023	: V=0.9791974, theta=-66.319141 -> V=1.0, theta=0.0
% INFO    : Bus 7024	: V=0.975585, theta=-66.845135 -> V=1.0, theta=0.0
% INFO    : Bus 7025	: V=0.9754892, theta=-66.854861 -> V=1.0, theta=0.0
% INFO    : Bus 7026	: V=0.9850365, theta=-65.103612 -> V=1.0, theta=0.0
% INFO    : Bus 7027	: V=0.9757764, theta=-66.818429 -> V=1.0, theta=0.0
% INFO    : Bus 7028	: V=0.9821008, theta=-65.709062 -> V=1.0, theta=0.0
% INFO    : Bus 7029	: V=0.9752914, theta=-66.884252 -> V=1.0, theta=0.0
% INFO    : Bus 7030	: V=0.9822935, theta=-65.684781 -> V=1.0, theta=0.0
% INFO    : Bus 7031	: V=0.9755535, theta=-66.864604 -> V=1.0, theta=0.0
% INFO    : Bus 7032	: V=0.9824118, theta=-65.673483 -> V=1.0, theta=0.0
% INFO    : Bus 7033	: V=0.9755929, theta=-66.874752 -> V=1.0, theta=0.0
% INFO    : Bus 7034	: V=0.9825795, theta=-65.658739 -> V=1.0, theta=0.0
% INFO    : Bus 7035	: V=0.9751319, theta=-66.903271 -> V=1.0, theta=0.0
% INFO    : Bus 7036	: V=0.9826966, theta=-65.646643 -> V=1.0, theta=0.0
% INFO    : Bus 7037	: V=0.9751895, theta=-66.901896 -> V=1.0, theta=0.0
% INFO    : Bus 7038	: V=0.9828668, theta=-65.624593 -> V=1.0, theta=0.0
% INFO    : Bus 7039	: V=0.9752328, theta=-66.90403 -> V=1.0, theta=0.0
% INFO    : Bus 7040	: V=0.98307, theta=-65.601728 -> V=1.0, theta=0.0
% INFO    : Bus 7041	: V=0.9749463, theta=-66.927589 -> V=1.0, theta=0.0
% INFO    : Bus 7042	: V=0.9855818, theta=-65.018711 -> V=1.0, theta=0.0
% INFO    : Bus 7043	: V=0.9748392, theta=-66.936568 -> V=1.0, theta=0.0
% INFO    : Bus 7044	: V=0.9822431, theta=-65.681149 -> V=1.0, theta=0.0
% INFO    : Bus 7045	: V=0.9849259, theta=-65.125858 -> V=1.0, theta=0.0
% INFO    : Bus 7046	: V=0.9742839, theta=-66.972926 -> V=1.0, theta=0.0
% INFO    : Bus 7047	: V=0.9743536, theta=-66.971045 -> V=1.0, theta=0.0
% INFO    : Bus 7048	: V=0.9846704, theta=-65.12899 -> V=1.0, theta=0.0
% INFO    : Bus 7049	: V=0.9747323, theta=-66.943618 -> V=1.0, theta=0.0
% INFO    : Bus 7050	: V=0.9857201, theta=-64.978361 -> V=1.0, theta=0.0
% INFO    : Bus 7051	: V=0.9741969, theta=-66.975401 -> V=1.0, theta=0.0
% INFO    : Bus 7052	: V=0.9870024, theta=-64.743415 -> V=1.0, theta=0.0
% INFO    : Bus 7053	: V=0.9739736, theta=-66.981383 -> V=1.0, theta=0.0
% INFO    : Bus 7054	: V=0.9853327, theta=-65.031333 -> V=1.0, theta=0.0
% INFO    : Bus 7055	: V=0.9865878, theta=-64.81521 -> V=1.0, theta=0.0
% INFO    : Bus 7056	: V=0.9743173, theta=-66.96296 -> V=1.0, theta=0.0
% INFO    : Bus 7057	: V=0.9849089, theta=-65.125672 -> V=1.0, theta=0.0
% INFO    : Bus 7058	: V=0.9855248, theta=-64.940004 -> V=1.0, theta=0.0
% INFO    : Bus 7059	: V=0.983173, theta=-65.420462 -> V=1.0, theta=0.0
% INFO    : Bus 7060	: V=0.9744111, theta=-66.942569 -> V=1.0, theta=0.0
% INFO    : Bus 7061	: V=0.9865051, theta=-64.822965 -> V=1.0, theta=0.0
% INFO    : Bus 7062	: V=0.9839705, theta=-65.220818 -> V=1.0, theta=0.0
% INFO    : Bus 7063	: V=0.9746078, theta=-66.959043 -> V=1.0, theta=0.0
% INFO    : Bus 7064	: V=0.9745433, theta=-66.96081 -> V=1.0, theta=0.0
% INFO    : Bus 7065	: V=0.9747431, theta=-66.947791 -> V=1.0, theta=0.0
% INFO    : Bus 7066	: V=0.9752218, theta=-66.917749 -> V=1.0, theta=0.0
% INFO    : Bus 7067	: V=0.9835336, theta=-65.382755 -> V=1.0, theta=0.0
% INFO    : Bus 7068	: V=0.9749285, theta=-66.932308 -> V=1.0, theta=0.0
% INFO    : Bus 7069	: V=0.9843661, theta=-65.158994 -> V=1.0, theta=0.0
% INFO    : Bus 7070	: V=0.9750925, theta=-66.918908 -> V=1.0, theta=0.0
% INFO    : Bus 7071	: V=0.9751752, theta=-66.909508 -> V=1.0, theta=0.0
% INFO    : Bus 7072	: V=0.9850671, theta=-64.977815 -> V=1.0, theta=0.0
% INFO    : Bus 7073	: V=0.9752624, theta=-66.898896 -> V=1.0, theta=0.0
% INFO    : Bus 7074	: V=0.9849017, theta=-65.125183 -> V=1.0, theta=0.0
% INFO    : Bus 7075	: V=0.9855425, theta=-64.92925 -> V=1.0, theta=0.0
% INFO    : Bus 7076	: V=0.9755005, theta=-66.889144 -> V=1.0, theta=0.0
% INFO    : Bus 7077	: V=0.9847397, theta=-65.010375 -> V=1.0, theta=0.0
% INFO    : Bus 7078	: V=0.9752551, theta=-66.907324 -> V=1.0, theta=0.0
% INFO    : Bus 7079	: V=0.9751858, theta=-66.912541 -> V=1.0, theta=0.0
% INFO    : Bus 7080	: V=0.9842795, theta=-65.056556 -> V=1.0, theta=0.0
% INFO    : Bus 7081	: V=0.9751498, theta=-66.913431 -> V=1.0, theta=0.0
% INFO    : Bus 7082	: V=0.9750785, theta=-66.934315 -> V=1.0, theta=0.0
% INFO    : Bus 7083	: V=0.9827201, theta=-65.343195 -> V=1.0, theta=0.0
% INFO    : Bus 7084	: V=0.975732, theta=-66.883336 -> V=1.0, theta=0.0
% INFO    : Bus 7085	: V=0.975794, theta=-66.881776 -> V=1.0, theta=0.0
% INFO    : Bus 7086	: V=0.9757117, theta=-66.882169 -> V=1.0, theta=0.0
% INFO    : Bus 7087	: V=0.984325, theta=-65.042302 -> V=1.0, theta=0.0
% INFO    : Bus 7088	: V=0.9753596, theta=-66.900378 -> V=1.0, theta=0.0
% INFO    : Bus 7089	: V=0.9758098, theta=-66.85434 -> V=1.0, theta=0.0
% INFO    : Bus 7090	: V=0.9832286, theta=-65.237051 -> V=1.0, theta=0.0
% INFO    : Bus 7091	: V=0.9754923, theta=-66.869226 -> V=1.0, theta=0.0
% INFO    : Bus 7092	: V=0.9756266, theta=-66.851568 -> V=1.0, theta=0.0
% INFO    : Bus 7093	: V=0.9808279, theta=-65.724229 -> V=1.0, theta=0.0
% INFO    : Bus 7094	: V=0.9750166, theta=-66.906897 -> V=1.0, theta=0.0
% INFO    : Bus 7095	: V=0.9744917, theta=-66.939067 -> V=1.0, theta=0.0
% INFO    : Bus 7096	: V=0.9819227, theta=-65.413809 -> V=1.0, theta=0.0
% INFO    : Bus 7097	: V=0.9814151, theta=-65.502792 -> V=1.0, theta=0.0
% INFO    : Bus 7098	: V=0.9744017, theta=-66.940282 -> V=1.0, theta=0.0
% INFO    : Bus 7099	: V=0.981097, theta=-65.554854 -> V=1.0, theta=0.0
% INFO    : Bus 7100	: V=0.9802548, theta=-65.689415 -> V=1.0, theta=0.0
% INFO    : Bus 7101	: V=0.9750183, theta=-66.911885 -> V=1.0, theta=0.0
% INFO    : Bus 7102	: V=0.9805244, theta=-65.650114 -> V=1.0, theta=0.0
% INFO    : Bus 7103	: V=0.9753518, theta=-66.834114 -> V=1.0, theta=0.0
% INFO    : Bus 7104	: V=0.9802225, theta=-65.759339 -> V=1.0, theta=0.0
% INFO    : Bus 7105	: V=0.9751, theta=-66.840493 -> V=1.0, theta=0.0
% INFO    : Bus 7106	: V=0.9796045, theta=-65.765187 -> V=1.0, theta=0.0
% INFO    : Bus 7107	: V=0.9749609, theta=-66.844362 -> V=1.0, theta=0.0
% INFO    : Bus 7108	: V=0.9790096, theta=-65.837435 -> V=1.0, theta=0.0
% INFO    : Bus 7109	: V=0.9753494, theta=-66.843061 -> V=1.0, theta=0.0
% INFO    : Bus 7110	: V=0.9758094, theta=-66.516783 -> V=1.0, theta=0.0
% INFO    : Bus 7111	: V=0.9753053, theta=-66.844175 -> V=1.0, theta=0.0
% INFO    : Bus 7112	: V=0.9750235, theta=-66.851083 -> V=1.0, theta=0.0
% INFO    : Bus 7113	: V=0.9760123, theta=-66.511089 -> V=1.0, theta=0.0
% INFO    : Bus 7114	: V=0.9748991, theta=-66.846048 -> V=1.0, theta=0.0
% INFO    : Bus 7115	: V=0.975814, theta=-66.51662 -> V=1.0, theta=0.0
% INFO    : Bus 7116	: V=0.9751054, theta=-66.893055 -> V=1.0, theta=0.0
% INFO    : Bus 7117	: V=0.978828, theta=-65.922911 -> V=1.0, theta=0.0
% INFO    : Bus 7118	: V=0.979034, theta=-65.916085 -> V=1.0, theta=0.0
% INFO    : Bus 7119	: V=0.9800437, theta=-65.621349 -> V=1.0, theta=0.0
% INFO    : Bus 7120	: V=0.9790699, theta=-65.913393 -> V=1.0, theta=0.0
% INFO    : Bus 7121	: V=0.9797988, theta=-65.651244 -> V=1.0, theta=0.0
% INFO    : Bus 7122	: V=0.9791762, theta=-65.904148 -> V=1.0, theta=0.0
% INFO    : Bus 7123	: V=0.9793184, theta=-65.891392 -> V=1.0, theta=0.0
% INFO    : Bus 7124	: V=0.9794999, theta=-65.854106 -> V=1.0, theta=0.0
% INFO    : Bus 7125	: V=0.9801313, theta=-65.781655 -> V=1.0, theta=0.0
% INFO    : Bus 7126	: V=0.9757591, theta=-66.825103 -> V=1.0, theta=0.0
% INFO    : Bus 7127	: V=0.9823819, theta=-65.346187 -> V=1.0, theta=0.0
% INFO    : Bus 7128	: V=0.9803334, theta=-65.588662 -> V=1.0, theta=0.0
% INFO    : Bus 7129	: V=0.9797604, theta=-65.848708 -> V=1.0, theta=0.0
% INFO    : Bus 7130	: V=0.9764432, theta=-66.766483 -> V=1.0, theta=0.0
% INFO    : Bus 7131	: V=0.9831949, theta=-65.227871 -> V=1.0, theta=0.0
% INFO    : Bus 7132	: V=0.9759939, theta=-66.830911 -> V=1.0, theta=0.0
% INFO    : Bus 7133	: V=0.9758126, theta=-66.854106 -> V=1.0, theta=0.0
% INFO    : Bus 7134	: V=0.9839364, theta=-65.105747 -> V=1.0, theta=0.0
% INFO    : Bus 7135	: V=0.9762379, theta=-66.799097 -> V=1.0, theta=0.0
% INFO    : Bus 7136	: V=0.9837499, theta=-65.132687 -> V=1.0, theta=0.0
% INFO    : Bus 7137	: V=0.9840111, theta=-65.104051 -> V=1.0, theta=0.0
% INFO    : Bus 7138	: V=0.9761821, theta=-66.800656 -> V=1.0, theta=0.0
% INFO    : Bus 7139	: V=0.9844832, theta=-65.051266 -> V=1.0, theta=0.0
% INFO    : Bus 7140	: V=0.975764, theta=-66.839716 -> V=1.0, theta=0.0
% INFO    : Bus 7141	: V=0.9757119, theta=-66.841143 -> V=1.0, theta=0.0
% INFO    : Bus 7142	: V=0.9763368, theta=-66.793504 -> V=1.0, theta=0.0
% INFO    : Bus 7143	: V=0.9805992, theta=-65.651468 -> V=1.0, theta=0.0
% INFO    : Bus 7144	: V=0.9812577, theta=-65.579253 -> V=1.0, theta=0.0
% INFO    : Bus 7145	: V=0.9766333, theta=-66.796407 -> V=1.0, theta=0.0
% INFO    : Bus 7146	: V=0.9768122, theta=-66.797315 -> V=1.0, theta=0.0
% INFO    : Bus 7147	: V=0.9770478, theta=-66.79446 -> V=1.0, theta=0.0
% INFO    : Bus 7148	: V=0.9771449, theta=-66.793384 -> V=1.0, theta=0.0
% INFO    : Bus 7149	: V=0.9813831, theta=-65.577902 -> V=1.0, theta=0.0
% INFO    : Bus 7150	: V=0.9770769, theta=-66.795246 -> V=1.0, theta=0.0
% INFO    : Bus 7151	: V=0.9781556, theta=-66.215137 -> V=1.0, theta=0.0
% INFO    : Bus 7152	: V=0.9764588, theta=-66.789996 -> V=1.0, theta=0.0
% INFO    : Bus 7153	: V=0.977854, theta=-66.211776 -> V=1.0, theta=0.0
% INFO    : Bus 7154	: V=0.976337, theta=-66.793524 -> V=1.0, theta=0.0
% INFO    : Bus 7155	: V=0.9789076, theta=-65.920759 -> V=1.0, theta=0.0
% INFO    : Bus 7156	: V=0.9768981, theta=-66.824092 -> V=1.0, theta=0.0
% INFO    : Bus 7157	: V=0.979959, theta=-65.716683 -> V=1.0, theta=0.0
% INFO    : Bus 7158	: V=0.9796733, theta=-65.748932 -> V=1.0, theta=0.0
% INFO    : Bus 7159	: V=0.9770309, theta=-66.811881 -> V=1.0, theta=0.0
% INFO    : Bus 7160	: V=0.9772327, theta=-66.790466 -> V=1.0, theta=0.0
% INFO    : Bus 7161	: V=0.9778023, theta=-66.212849 -> V=1.0, theta=0.0
% INFO    : Bus 7162	: V=0.9780306, theta=-66.231834 -> V=1.0, theta=0.0
% INFO    : Bus 7163	: V=0.9779644, theta=-66.239969 -> V=1.0, theta=0.0
% INFO    : Bus 7164	: V=0.9800074, theta=-65.72401 -> V=1.0, theta=0.0
% INFO    : Bus 7165	: V=0.9775368, theta=-66.793519 -> V=1.0, theta=0.0
% INFO    : Bus 7166	: V=0.9773034, theta=-66.366758 -> V=1.0, theta=0.0
% INFO    : Bus 7167	: V=0.976709, theta=-66.493872 -> V=1.0, theta=0.0
% INFO    : Bus 7168	: V=0.9770109, theta=-66.425978 -> V=1.0, theta=0.0
% INFO    : Bus 7169	: V=0.9810471, theta=-65.629838 -> V=1.0, theta=0.0
% INFO    : Bus 7170	: V=0.977748, theta=-66.756334 -> V=1.0, theta=0.0
% INFO    : Bus 7171	: V=0.9782842, theta=-66.720741 -> V=1.0, theta=0.0
% INFO    : Bus 7172	: V=0.9849591, theta=-65.760535 -> V=1.0, theta=0.0
% INFO    : Bus 7173	: V=0.9815893, theta=-65.629616 -> V=1.0, theta=0.0
% INFO    : Bus 7174	: V=0.9784852, theta=-66.779754 -> V=1.0, theta=0.0
% INFO    : Bus 7175	: V=0.9816321, theta=-65.538187 -> V=1.0, theta=0.0
% INFO    : Bus 7176	: V=0.9817907, theta=-65.528684 -> V=1.0, theta=0.0
% INFO    : Bus 7177	: V=0.9818375, theta=-65.516339 -> V=1.0, theta=0.0
% INFO    : Bus 7178	: V=0.9783631, theta=-66.782731 -> V=1.0, theta=0.0
% INFO    : Bus 7179	: V=0.982025, theta=-65.496601 -> V=1.0, theta=0.0
% INFO    : Bus 7180	: V=0.9824895, theta=-65.44496 -> V=1.0, theta=0.0
% INFO    : Bus 7181	: V=0.9763383, theta=-67.175919 -> V=1.0, theta=0.0
% INFO    : Bus 7182	: V=0.982321, theta=-65.531631 -> V=1.0, theta=0.0
% INFO    : Bus 7183	: V=0.9849335, theta=-65.004534 -> V=1.0, theta=0.0
% INFO    : Bus 7184	: V=0.9842411, theta=-65.162327 -> V=1.0, theta=0.0
% INFO    : Bus 7185	: V=0.9829236, theta=-65.378132 -> V=1.0, theta=0.0
% INFO    : Bus 7186	: V=0.9821434, theta=-65.486682 -> V=1.0, theta=0.0
% INFO    : Bus 7187	: V=0.9809281, theta=-65.850985 -> V=1.0, theta=0.0
% INFO    : Bus 7188	: V=0.9776964, theta=-66.994869 -> V=1.0, theta=0.0
% INFO    : Bus 7189	: V=0.9839454, theta=-65.838692 -> V=1.0, theta=0.0
% INFO    : Bus 7190	: V=0.9818877, theta=-65.736471 -> V=1.0, theta=0.0
% INFO    : Bus 7191	: V=0.9844265, theta=-65.210018 -> V=1.0, theta=0.0
% INFO    : Bus 7192	: V=0.9769546, theta=-67.050066 -> V=1.0, theta=0.0
% INFO    : Bus 7193	: V=0.9840662, theta=-65.266694 -> V=1.0, theta=0.0
% INFO    : Bus 7194	: V=0.9766551, theta=-67.114131 -> V=1.0, theta=0.0
% INFO    : Bus 7195	: V=0.9810739, theta=-65.847589 -> V=1.0, theta=0.0
% INFO    : Bus 7196	: V=0.983859, theta=-65.300402 -> V=1.0, theta=0.0
% INFO    : Bus 7197	: V=0.9783009, theta=-66.352954 -> V=1.0, theta=0.0
% INFO    : Bus 7198	: V=0.9814526, theta=-65.660329 -> V=1.0, theta=0.0
% INFO    : Bus 7199	: V=0.9813958, theta=-65.671645 -> V=1.0, theta=0.0
% INFO    : Bus 7200	: V=0.9824505, theta=-65.473141 -> V=1.0, theta=0.0
% INFO    : Bus 7201	: V=0.9828925, theta=-65.416936 -> V=1.0, theta=0.0
% INFO    : Bus 7202	: V=0.9834968, theta=-65.334964 -> V=1.0, theta=0.0
% INFO    : Bus 7203	: V=0.9842266, theta=-65.251826 -> V=1.0, theta=0.0
% INFO    : Bus 7204	: V=0.9831906, theta=-65.376149 -> V=1.0, theta=0.0
% INFO    : Bus 7205	: V=0.9836614, theta=-65.331384 -> V=1.0, theta=0.0
% INFO    : Bus 7206	: V=0.9810976, theta=-66.153288 -> V=1.0, theta=0.0
% INFO    : Bus 7207	: V=0.9845766, theta=-65.187692 -> V=1.0, theta=0.0
% INFO    : Bus 7208	: V=0.9814613, theta=-65.776851 -> V=1.0, theta=0.0
% INFO    : Bus 7209	: V=0.9814261, theta=-65.794111 -> V=1.0, theta=0.0
% INFO    : Bus 7210	: V=0.9813623, theta=-65.802399 -> V=1.0, theta=0.0
% INFO    : Bus 7211	: V=0.9812519, theta=-65.696038 -> V=1.0, theta=0.0
% INFO    : Bus 7212	: V=0.9815429, theta=-65.581042 -> V=1.0, theta=0.0
% INFO    : Bus 7213	: V=0.9785405, theta=-66.345673 -> V=1.0, theta=0.0
% INFO    : Bus 7214	: V=0.9829209, theta=-65.450909 -> V=1.0, theta=0.0
% INFO    : Bus 7215	: V=0.9784671, theta=-66.417665 -> V=1.0, theta=0.0
% INFO    : Bus 7216	: V=0.9835939, theta=-65.318491 -> V=1.0, theta=0.0
% INFO    : Bus 7217	: V=0.9837488, theta=-65.294415 -> V=1.0, theta=0.0
% INFO    : Bus 7218	: V=0.9839714, theta=-65.261171 -> V=1.0, theta=0.0
% INFO    : Bus 7219	: V=0.9813213, theta=-65.800935 -> V=1.0, theta=0.0
% INFO    : Bus 7220	: V=0.9782845, theta=-66.395098 -> V=1.0, theta=0.0
% INFO    : Bus 7221	: V=0.9826148, theta=-65.506534 -> V=1.0, theta=0.0
% INFO    : Bus 7222	: V=0.978349, theta=-66.43711 -> V=1.0, theta=0.0
% INFO    : Bus 7223	: V=0.9783633, theta=-66.384883 -> V=1.0, theta=0.0
% INFO    : Bus 7224	: V=0.9782988, theta=-66.393789 -> V=1.0, theta=0.0
% INFO    : Bus 7225	: V=0.9805583, theta=-65.770834 -> V=1.0, theta=0.0
% INFO    : Bus 7226	: V=0.9806233, theta=-65.762943 -> V=1.0, theta=0.0
% INFO    : Bus 7227	: V=0.9824667, theta=-65.540896 -> V=1.0, theta=0.0
% INFO    : Bus 7228	: V=0.9818174, theta=-65.618415 -> V=1.0, theta=0.0
% INFO    : Bus 7229	: V=0.9831272, theta=-65.585363 -> V=1.0, theta=0.0
% INFO    : Bus 7230	: V=0.9767575, theta=-66.721472 -> V=1.0, theta=0.0
% INFO    : Bus 7231	: V=0.9772457, theta=-66.642354 -> V=1.0, theta=0.0
% INFO    : Bus 7232	: V=0.9775434, theta=-66.576473 -> V=1.0, theta=0.0
% INFO    : Bus 7233	: V=0.9771179, theta=-66.649969 -> V=1.0, theta=0.0
% INFO    : Bus 7234	: V=0.9754337, theta=-66.944043 -> V=1.0, theta=0.0
% INFO    : Bus 7235	: V=0.9752602, theta=-66.926286 -> V=1.0, theta=0.0
% INFO    : Bus 7236	: V=0.9753062, theta=-66.934534 -> V=1.0, theta=0.0
% INFO    : Bus 7237	: V=0.9879413, theta=-64.691668 -> V=1.0, theta=0.0
% INFO    : Bus 7238	: V=0.9854458, theta=-65.173707 -> V=1.0, theta=0.0
% INFO    : Bus 7239	: V=0.9855601, theta=-65.157463 -> V=1.0, theta=0.0
% INFO    : Bus 7240	: V=0.996028, theta=-63.312825 -> V=1.0, theta=0.0
% INFO    : Bus 7241	: V=0.9882688, theta=-64.683792 -> V=1.0, theta=0.0
% INFO    : Bus 7242	: V=0.987941, theta=-64.691643 -> V=1.0, theta=0.0
% INFO    : Bus 7243	: V=0.983648, theta=-65.413442 -> V=1.0, theta=0.0
% INFO    : Bus 7244	: V=0.9785933, theta=-66.308114 -> V=1.0, theta=0.0
% INFO    : Bus 7245	: V=0.9751895, theta=-66.883623 -> V=1.0, theta=0.0
% INFO    : Bus 7246	: V=0.9880357, theta=-64.687538 -> V=1.0, theta=0.0
% INFO    : Bus 7247	: V=0.9747381, theta=-66.8366 -> V=1.0, theta=0.0
% INFO    : Bus 7248	: V=0.9776372, theta=-66.36385 -> V=1.0, theta=0.0
% INFO    : Bus 7249	: V=0.977262, theta=-66.676853 -> V=1.0, theta=0.0
% INFO    : Bus 7250	: V=0.9746371, theta=-66.839081 -> V=1.0, theta=0.0
% INFO    : Bus 7251	: V=0.9744739, theta=-66.843855 -> V=1.0, theta=0.0
% INFO    : Bus 7252	: V=0.9855468, theta=-65.141117 -> V=1.0, theta=0.0
% INFO    : Bus 7253	: V=0.9780269, theta=-66.569279 -> V=1.0, theta=0.0
% INFO    : Bus 7254	: V=0.977421, theta=-66.6306 -> V=1.0, theta=0.0
% INFO    : Bus 7255	: V=0.9776088, theta=-66.608402 -> V=1.0, theta=0.0
% INFO    : Bus 7256	: V=0.9774069, theta=-66.641702 -> V=1.0, theta=0.0
% INFO    : Bus 7257	: V=0.9771732, theta=-66.668825 -> V=1.0, theta=0.0
% INFO    : Bus 7258	: V=0.977029, theta=-66.662444 -> V=1.0, theta=0.0
% INFO    : Bus 7259	: V=0.976683, theta=-66.396755 -> V=1.0, theta=0.0
% INFO    : Bus 7260	: V=0.9754559, theta=-66.830491 -> V=1.0, theta=0.0
% INFO    : Bus 7261	: V=0.985296, theta=-65.141941 -> V=1.0, theta=0.0
% INFO    : Bus 7262	: V=0.978619, theta=-66.492022 -> V=1.0, theta=0.0
% INFO    : Bus 7263	: V=0.969449, theta=-67.201601 -> V=1.0, theta=0.0
% INFO    : Bus 7264	: V=0.9750139, theta=-66.925983 -> V=1.0, theta=0.0
% INFO    : Bus 7265	: V=0.9756147, theta=-66.393163 -> V=1.0, theta=0.0
% INFO    : Bus 7266	: V=0.9850751, theta=-65.139435 -> V=1.0, theta=0.0
% INFO    : Bus 7267	: V=0.9676616, theta=-66.840418 -> V=1.0, theta=0.0
% INFO    : Bus 7268	: V=0.9786046, theta=-66.315925 -> V=1.0, theta=0.0
% INFO    : Bus 7269	: V=0.9850139, theta=-65.122652 -> V=1.0, theta=0.0
% INFO    : Bus 7270	: V=0.9792382, theta=-66.1912 -> V=1.0, theta=0.0
% INFO    : Bus 7271	: V=0.9849828, theta=-65.100933 -> V=1.0, theta=0.0
% INFO    : Bus 7272	: V=0.9798352, theta=-66.172783 -> V=1.0, theta=0.0
% INFO    : Bus 7273	: V=0.9849216, theta=-65.289852 -> V=1.0, theta=0.0
% INFO    : Bus 7274	: V=0.9804212, theta=-66.15288 -> V=1.0, theta=0.0
% INFO    : Bus 7275	: V=0.980883, theta=-66.13454 -> V=1.0, theta=0.0
% INFO    : Bus 7276	: V=0.9817676, theta=-66.095332 -> V=1.0, theta=0.0
% INFO    : Bus 7277	: V=0.9819638, theta=-65.644981 -> V=1.0, theta=0.0
% INFO    : Bus 7278	: V=0.9855714, theta=-66.15246 -> V=1.0, theta=0.0
% INFO    : Bus 7279	: V=0.9838234, theta=-65.991043 -> V=1.0, theta=0.0
% INFO    : Bus 7280	: V=0.9832587, theta=-66.023627 -> V=1.0, theta=0.0
% INFO    : Bus 7281	: V=0.9857777, theta=-64.992973 -> V=1.0, theta=0.0
% INFO    : Bus 7282	: V=0.9849823, theta=-65.086172 -> V=1.0, theta=0.0
% INFO    : Bus 7283	: V=0.9847237, theta=-65.935716 -> V=1.0, theta=0.0
% INFO    : Bus 7284	: V=0.9854218, theta=-65.889686 -> V=1.0, theta=0.0
% INFO    : Bus 7285	: V=0.9829073, theta=-66.550066 -> V=1.0, theta=0.0
% INFO    : Bus 7286	: V=0.9867405, theta=-65.81479 -> V=1.0, theta=0.0
% INFO    : Bus 7287	: V=0.9865459, theta=-65.817924 -> V=1.0, theta=0.0
% INFO    : Bus 7288	: V=0.9778024, theta=-66.500706 -> V=1.0, theta=0.0
% INFO    : Bus 7289	: V=0.977566, theta=-66.527928 -> V=1.0, theta=0.0
% INFO    : Bus 7290	: V=0.9779216, theta=-66.156082 -> V=1.0, theta=0.0
% INFO    : Bus 7291	: V=0.9768432, theta=-66.626883 -> V=1.0, theta=0.0
% INFO    : Bus 7292	: V=0.9825423, theta=-66.656871 -> V=1.0, theta=0.0
% INFO    : Bus 7293	: V=0.9772015, theta=-66.253315 -> V=1.0, theta=0.0
% INFO    : Bus 7294	: V=0.9756604, theta=-66.806016 -> V=1.0, theta=0.0
% INFO    : Bus 7295	: V=0.9756441, theta=-66.811473 -> V=1.0, theta=0.0
% INFO    : Bus 7296	: V=0.9762285, theta=-66.721952 -> V=1.0, theta=0.0
% INFO    : Bus 7297	: V=0.9888896, theta=-65.623119 -> V=1.0, theta=0.0
% INFO    : Bus 7298	: V=0.9922526, theta=-65.760011 -> V=1.0, theta=0.0
% INFO    : Bus 7299	: V=0.9758919, theta=-66.773432 -> V=1.0, theta=0.0
% INFO    : Bus 7300	: V=0.99468, theta=-65.613629 -> V=1.0, theta=0.0
% INFO    : Bus 7301	: V=0.9872274, theta=-65.798915 -> V=1.0, theta=0.0
% INFO    : Bus 7302	: V=0.9896137, theta=-65.55032 -> V=1.0, theta=0.0
% INFO    : Bus 7303	: V=0.9903693, theta=-65.474813 -> V=1.0, theta=0.0
% INFO    : Bus 7304	: V=0.9773862, theta=-66.226935 -> V=1.0, theta=0.0
% INFO    : Bus 7305	: V=0.9770099, theta=-66.59975 -> V=1.0, theta=0.0
% INFO    : Bus 7306	: V=0.9940232, theta=-65.691611 -> V=1.0, theta=0.0
% INFO    : Bus 7307	: V=0.9929849, theta=-65.76169 -> V=1.0, theta=0.0
% INFO    : Bus 7308	: V=0.9768814, theta=-66.619733 -> V=1.0, theta=0.0
% INFO    : Bus 7309	: V=0.9774709, theta=-66.551959 -> V=1.0, theta=0.0
% INFO    : Bus 7310	: V=0.9745072, theta=-66.965677 -> V=1.0, theta=0.0
% INFO    : Bus 7311	: V=0.976562, theta=-66.68778 -> V=1.0, theta=0.0
% INFO    : Bus 7312	: V=0.9818477, theta=-66.379682 -> V=1.0, theta=0.0
% INFO    : Bus 7313	: V=0.9770294, theta=-66.279666 -> V=1.0, theta=0.0
% INFO    : Bus 7314	: V=0.9759145, theta=-66.790023 -> V=1.0, theta=0.0
% INFO    : Bus 7315	: V=0.9762861, theta=-66.759036 -> V=1.0, theta=0.0
% INFO    : Bus 7316	: V=0.9761981, theta=-66.766944 -> V=1.0, theta=0.0
% INFO    : Bus 7317	: V=0.9824826, theta=-65.48059 -> V=1.0, theta=0.0
% INFO    : Bus 7318	: V=0.9767117, theta=-66.691143 -> V=1.0, theta=0.0
% INFO    : Bus 7319	: V=0.976163, theta=-66.762392 -> V=1.0, theta=0.0
% INFO    : Bus 7320	: V=0.9760325, theta=-66.771068 -> V=1.0, theta=0.0
% INFO    : Bus 7321	: V=0.9763732, theta=-66.733784 -> V=1.0, theta=0.0
% INFO    : Bus 7322	: V=0.9762416, theta=-66.760989 -> V=1.0, theta=0.0
% INFO    : Bus 7323	: V=0.9764963, theta=-66.727259 -> V=1.0, theta=0.0
% INFO    : Bus 7324	: V=0.9762275, theta=-66.759157 -> V=1.0, theta=0.0
% INFO    : Bus 7325	: V=0.976229, theta=-66.757149 -> V=1.0, theta=0.0
% INFO    : Bus 7326	: V=0.9760503, theta=-66.774327 -> V=1.0, theta=0.0
% INFO    : Bus 7327	: V=0.9758545, theta=-66.800836 -> V=1.0, theta=0.0
% INFO    : Bus 7328	: V=0.9757802, theta=-66.819012 -> V=1.0, theta=0.0
% INFO    : Bus 7329	: V=0.9846839, theta=-65.207246 -> V=1.0, theta=0.0
% INFO    : Bus 7330	: V=0.9767883, theta=-66.667934 -> V=1.0, theta=0.0
% INFO    : Bus 7331	: V=0.9766022, theta=-66.724298 -> V=1.0, theta=0.0
% INFO    : Bus 7332	: V=0.9769121, theta=-66.304533 -> V=1.0, theta=0.0
% INFO    : Bus 7333	: V=0.9763353, theta=-66.73622 -> V=1.0, theta=0.0
% INFO    : Bus 7334	: V=0.9765706, theta=-66.72344 -> V=1.0, theta=0.0
% INFO    : Bus 7335	: V=0.9767169, theta=-66.669903 -> V=1.0, theta=0.0
% INFO    : Bus 7336	: V=0.9769103, theta=-66.69483 -> V=1.0, theta=0.0
% INFO    : Bus 7337	: V=0.9766957, theta=-66.713281 -> V=1.0, theta=0.0
% INFO    : Bus 7338	: V=0.9764782, theta=-66.728605 -> V=1.0, theta=0.0
% INFO    : Bus 7339	: V=0.9764441, theta=-66.729414 -> V=1.0, theta=0.0
% INFO    : Bus 7340	: V=0.9769389, theta=-66.700527 -> V=1.0, theta=0.0
% INFO    : Bus 7341	: V=0.9769949, theta=-66.699151 -> V=1.0, theta=0.0
% INFO    : Bus 7342	: V=0.9769089, theta=-66.716845 -> V=1.0, theta=0.0
% INFO    : Bus 7343	: V=0.9770999, theta=-66.696339 -> V=1.0, theta=0.0
% INFO    : Bus 7344	: V=0.9763809, theta=-66.709423 -> V=1.0, theta=0.0
% INFO    : Bus 7345	: V=0.9765239, theta=-66.756691 -> V=1.0, theta=0.0
% INFO    : Bus 7346	: V=0.9761555, theta=-66.804197 -> V=1.0, theta=0.0
% INFO    : Bus 7347	: V=0.97595, theta=-66.833601 -> V=1.0, theta=0.0
% INFO    : Bus 7348	: V=0.9840389, theta=-65.429324 -> V=1.0, theta=0.0
% INFO    : Bus 7349	: V=0.9755954, theta=-66.872057 -> V=1.0, theta=0.0
% INFO    : Bus 7350	: V=0.9754299, theta=-66.888066 -> V=1.0, theta=0.0
% INFO    : Bus 7351	: V=0.9766316, theta=-66.734719 -> V=1.0, theta=0.0
% INFO    : Bus 7352	: V=0.9761899, theta=-66.783713 -> V=1.0, theta=0.0
% INFO    : Bus 7353	: V=0.9758451, theta=-66.816712 -> V=1.0, theta=0.0
% INFO    : Bus 7354	: V=0.9751622, theta=-66.909285 -> V=1.0, theta=0.0
% INFO    : Bus 7355	: V=0.9751609, theta=-66.922177 -> V=1.0, theta=0.0
% INFO    : Bus 7356	: V=0.9750088, theta=-66.922244 -> V=1.0, theta=0.0
% INFO    : Bus 7357	: V=0.9750841, theta=-66.925616 -> V=1.0, theta=0.0
% INFO    : Bus 7358	: V=0.9755275, theta=-66.844662 -> V=1.0, theta=0.0
% INFO    : Bus 7359	: V=0.9815964, theta=-65.415899 -> V=1.0, theta=0.0
% INFO    : Bus 7360	: V=0.9746677, theta=-66.9217 -> V=1.0, theta=0.0
% INFO    : Bus 7361	: V=0.9752789, theta=-66.901921 -> V=1.0, theta=0.0
% INFO    : Bus 7362	: V=0.9754251, theta=-66.901263 -> V=1.0, theta=0.0
% INFO    : Bus 7363	: V=0.9753795, theta=-66.891181 -> V=1.0, theta=0.0
% INFO    : Bus 7364	: V=0.9755619, theta=-66.839905 -> V=1.0, theta=0.0
% INFO    : Bus 7365	: V=0.9759032, theta=-66.756078 -> V=1.0, theta=0.0
% INFO    : Bus 7366	: V=0.9762907, theta=-66.719974 -> V=1.0, theta=0.0
% INFO    : Bus 7367	: V=0.9758989, theta=-66.756231 -> V=1.0, theta=0.0
% INFO    : Bus 7368	: V=0.9757633, theta=-66.823125 -> V=1.0, theta=0.0
% INFO    : Bus 7369	: V=0.9760228, theta=-66.795209 -> V=1.0, theta=0.0
% INFO    : Bus 7370	: V=0.975936, theta=-66.808295 -> V=1.0, theta=0.0
% INFO    : Bus 7371	: V=0.9758318, theta=-66.82439 -> V=1.0, theta=0.0
% INFO    : Bus 7372	: V=0.9760354, theta=-66.80875 -> V=1.0, theta=0.0
% INFO    : Bus 7373	: V=0.9759483, theta=-66.806163 -> V=1.0, theta=0.0
% INFO    : Bus 7374	: V=0.9763142, theta=-66.75315 -> V=1.0, theta=0.0
% INFO    : Bus 7375	: V=0.9814045, theta=-65.542817 -> V=1.0, theta=0.0
% INFO    : Bus 7376	: V=0.9764778, theta=-66.710958 -> V=1.0, theta=0.0
% INFO    : Bus 7377	: V=0.9763349, theta=-66.733652 -> V=1.0, theta=0.0
% INFO    : Bus 7378	: V=0.9763541, theta=-66.728229 -> V=1.0, theta=0.0
% INFO    : Bus 7379	: V=0.9761168, theta=-66.780276 -> V=1.0, theta=0.0
% INFO    : Bus 7380	: V=0.976378, theta=-66.730119 -> V=1.0, theta=0.0
% INFO    : Bus 7381	: V=0.9765317, theta=-66.706609 -> V=1.0, theta=0.0
% INFO    : Bus 7382	: V=0.9819146, theta=-65.513786 -> V=1.0, theta=0.0
% INFO    : Bus 7383	: V=0.9770757, theta=-66.701143 -> V=1.0, theta=0.0
% INFO    : Bus 7384	: V=0.9839614, theta=-65.351882 -> V=1.0, theta=0.0
% INFO    : Bus 7385	: V=0.9766656, theta=-66.721702 -> V=1.0, theta=0.0
% INFO    : Bus 7386	: V=0.9769571, theta=-66.71366 -> V=1.0, theta=0.0
% INFO    : Bus 7387	: V=0.9752452, theta=-66.827616 -> V=1.0, theta=0.0
% INFO    : Bus 7388	: V=0.9761296, theta=-66.777217 -> V=1.0, theta=0.0
% INFO    : Bus 7389	: V=0.9749808, theta=-66.824407 -> V=1.0, theta=0.0
% INFO    : Bus 7390	: V=0.9754131, theta=-66.809808 -> V=1.0, theta=0.0
% INFO    : Bus 7391	: V=0.9753958, theta=-66.841122 -> V=1.0, theta=0.0
% INFO    : Bus 7392	: V=0.9751678, theta=-66.846718 -> V=1.0, theta=0.0
% INFO    : Bus 7393	: V=0.9754027, theta=-66.829877 -> V=1.0, theta=0.0
% INFO    : Bus 7394	: V=0.976554, theta=-66.674875 -> V=1.0, theta=0.0
% INFO    : Bus 7395	: V=0.9746337, theta=-66.861392 -> V=1.0, theta=0.0
% INFO    : Bus 7396	: V=0.9767363, theta=-66.658963 -> V=1.0, theta=0.0
% INFO    : Bus 7397	: V=0.9759362, theta=-66.789988 -> V=1.0, theta=0.0
% INFO    : Bus 7398	: V=0.975605, theta=-66.835978 -> V=1.0, theta=0.0
% INFO    : Bus 7399	: V=0.9632722, theta=-72.097326 -> V=1.0, theta=0.0
% INFO    : Bus 7400	: V=0.9636801, theta=-72.075904 -> V=1.0, theta=0.0
% INFO    : Bus 7401	: V=0.963674, theta=-72.051106 -> V=1.0, theta=0.0
% INFO    : Bus 7402	: V=0.9628789, theta=-71.98644 -> V=1.0, theta=0.0
% INFO    : Bus 7403	: V=0.9629145, theta=-72.009989 -> V=1.0, theta=0.0
% INFO    : Bus 7404	: V=0.9626421, theta=-71.944682 -> V=1.0, theta=0.0
% INFO    : Bus 7405	: V=0.9627274, theta=-71.918893 -> V=1.0, theta=0.0
% INFO    : Bus 7406	: V=0.9630411, theta=-71.874435 -> V=1.0, theta=0.0
% INFO    : Bus 7407	: V=0.9648125, theta=-71.735379 -> V=1.0, theta=0.0
% INFO    : Bus 7408	: V=0.9677273, theta=-71.373669 -> V=1.0, theta=0.0
% INFO    : Bus 7409	: V=0.9656916, theta=-71.791827 -> V=1.0, theta=0.0
% INFO    : Bus 7410	: V=0.9640148, theta=-71.873547 -> V=1.0, theta=0.0
% INFO    : Bus 7411	: V=0.962833, theta=-71.940238 -> V=1.0, theta=0.0
% INFO    : Bus 7412	: V=0.9631455, theta=-72.062575 -> V=1.0, theta=0.0
% INFO    : Bus 7413	: V=1.0174416, theta=-65.029022 -> V=1.0, theta=0.0
% INFO    : Bus 7414	: V=0.9796432, theta=-68.561089 -> V=1.0, theta=0.0
% INFO    : Bus 7415	: V=0.9690836, theta=-72.846296 -> V=1.0, theta=0.0
% INFO    : Bus 7416	: V=0.9793163, theta=-71.659816 -> V=1.0, theta=0.0
% INFO    : Bus 7417	: V=0.9556764, theta=-72.179149 -> V=1.0, theta=0.0
% INFO    : Bus 7418	: V=0.9614542, theta=-72.009761 -> V=1.0, theta=0.0
% INFO    : Bus 7419	: V=0.9618354, theta=-72.127961 -> V=1.0, theta=0.0
% INFO    : Bus 7420	: V=0.9572704, theta=-72.295819 -> V=1.0, theta=0.0
% INFO    : Bus 7421	: V=0.9606653, theta=-72.189104 -> V=1.0, theta=0.0
% INFO    : Bus 7422	: V=0.9626929, theta=-71.9767 -> V=1.0, theta=0.0
% INFO    : Bus 7423	: V=0.9553012, theta=-72.356752 -> V=1.0, theta=0.0
% INFO    : Bus 7424	: V=0.9664458, theta=-72.912847 -> V=1.0, theta=0.0
% INFO    : Bus 7425	: V=0.9651897, theta=-72.609918 -> V=1.0, theta=0.0
% INFO    : Bus 7426	: V=0.9651222, theta=-72.13533 -> V=1.0, theta=0.0
% INFO    : Bus 7427	: V=0.961034, theta=-72.252912 -> V=1.0, theta=0.0
% INFO    : Bus 7428	: V=0.9762708, theta=-69.39591 -> V=1.0, theta=0.0
% INFO    : Bus 7429	: V=0.9727852, theta=-70.736228 -> V=1.0, theta=0.0
% INFO    : Bus 7430	: V=0.9675673, theta=-71.633561 -> V=1.0, theta=0.0
% INFO    : Bus 7431	: V=0.9679181, theta=-71.623121 -> V=1.0, theta=0.0
% INFO    : Bus 7432	: V=0.9779294, theta=-69.385224 -> V=1.0, theta=0.0
% INFO    : Bus 7433	: V=0.9951845, theta=-66.898375 -> V=1.0, theta=0.0
% INFO    : Bus 7434	: V=0.9966845, theta=-66.622877 -> V=1.0, theta=0.0
% INFO    : Bus 7435	: V=0.9972375, theta=-66.365214 -> V=1.0, theta=0.0
% INFO    : Bus 7436	: V=0.9687265, theta=-68.98923 -> V=1.0, theta=0.0
% INFO    : Bus 7437	: V=0.9924106, theta=-66.940031 -> V=1.0, theta=0.0
% INFO    : Bus 7438	: V=0.9634341, theta=-69.275698 -> V=1.0, theta=0.0
% INFO    : Bus 7439	: V=0.9672045, theta=-69.006533 -> V=1.0, theta=0.0
% INFO    : Bus 7440	: V=0.9590709, theta=-69.408855 -> V=1.0, theta=0.0
% INFO    : Bus 7441	: V=0.9882281, theta=-63.045933 -> V=1.0, theta=0.0
% INFO    : Bus 7442	: V=0.9892466, theta=-62.742086 -> V=1.0, theta=0.0
% INFO    : Bus 7443	: V=0.9884116, theta=-63.038611 -> V=1.0, theta=0.0
% INFO    : Bus 7444	: V=0.9878535, theta=-63.022732 -> V=1.0, theta=0.0
% INFO    : Bus 7445	: V=0.9887012, theta=-63.020214 -> V=1.0, theta=0.0
% INFO    : Bus 7446	: V=0.9887229, theta=-62.97137 -> V=1.0, theta=0.0
% INFO    : Bus 7447	: V=0.9886202, theta=-62.972034 -> V=1.0, theta=0.0
% INFO    : Bus 7448	: V=0.9864856, theta=-62.751264 -> V=1.0, theta=0.0
% INFO    : Bus 7449	: V=0.986402, theta=-62.843643 -> V=1.0, theta=0.0
% INFO    : Bus 7450	: V=0.9864523, theta=-62.814967 -> V=1.0, theta=0.0
% INFO    : Bus 7451	: V=0.9916005, theta=-62.363499 -> V=1.0, theta=0.0
% INFO    : Bus 7452	: V=0.990688, theta=-62.5089 -> V=1.0, theta=0.0
% INFO    : Bus 7453	: V=0.9894726, theta=-62.758309 -> V=1.0, theta=0.0
% INFO    : Bus 7454	: V=0.9882121, theta=-62.927795 -> V=1.0, theta=0.0
% INFO    : Bus 7455	: V=0.987717, theta=-62.60743 -> V=1.0, theta=0.0
% INFO    : Bus 7456	: V=0.9888406, theta=-62.248397 -> V=1.0, theta=0.0
% INFO    : Bus 7457	: V=0.9887836, theta=-62.859729 -> V=1.0, theta=0.0
% INFO    : Bus 7458	: V=0.9907603, theta=-62.497226 -> V=1.0, theta=0.0
% INFO    : Bus 7459	: V=0.9881887, theta=-62.56031 -> V=1.0, theta=0.0
% INFO    : Bus 7460	: V=0.9946269, theta=-61.721682 -> V=1.0, theta=0.0
% INFO    : Bus 7461	: V=0.9882704, theta=-62.546325 -> V=1.0, theta=0.0
% INFO    : Bus 7462	: V=0.9893158, theta=-62.78619 -> V=1.0, theta=0.0
% INFO    : Bus 7463	: V=0.9869788, theta=-62.646402 -> V=1.0, theta=0.0
% INFO    : Bus 7464	: V=0.9865699, theta=-62.750452 -> V=1.0, theta=0.0
% INFO    : Bus 7465	: V=0.9941332, theta=-61.794627 -> V=1.0, theta=0.0
% INFO    : Bus 7466	: V=0.9890029, theta=-62.910621 -> V=1.0, theta=0.0
% INFO    : Bus 7467	: V=0.9887701, theta=-62.979135 -> V=1.0, theta=0.0
% INFO    : Bus 7468	: V=0.9934216, theta=-61.610904 -> V=1.0, theta=0.0
% INFO    : Bus 7469	: V=0.9937494, theta=-61.568066 -> V=1.0, theta=0.0
% INFO    : Bus 7470	: V=0.9955179, theta=-61.736719 -> V=1.0, theta=0.0
% INFO    : Bus 7471	: V=0.9955389, theta=-61.624426 -> V=1.0, theta=0.0
% INFO    : Bus 7472	: V=0.9875682, theta=-62.54744 -> V=1.0, theta=0.0
% INFO    : Bus 7473	: V=0.9869032, theta=-62.544845 -> V=1.0, theta=0.0
% INFO    : Bus 7474	: V=0.9940095, theta=-61.535889 -> V=1.0, theta=0.0
% INFO    : Bus 7475	: V=0.9943334, theta=-61.497544 -> V=1.0, theta=0.0
% INFO    : Bus 7476	: V=0.9881668, theta=-62.527519 -> V=1.0, theta=0.0
% INFO    : Bus 7477	: V=0.9947708, theta=-61.44948 -> V=1.0, theta=0.0
% INFO    : Bus 7478	: V=0.9871196, theta=-62.415871 -> V=1.0, theta=0.0
% INFO    : Bus 7479	: V=0.9868016, theta=-62.514207 -> V=1.0, theta=0.0
% INFO    : Bus 7480	: V=0.9858069, theta=-62.545735 -> V=1.0, theta=0.0
% INFO    : Bus 7481	: V=0.9861199, theta=-62.543339 -> V=1.0, theta=0.0
% INFO    : Bus 7482	: V=0.9917057, theta=-61.717135 -> V=1.0, theta=0.0
% INFO    : Bus 7483	: V=0.9881351, theta=-61.851489 -> V=1.0, theta=0.0
% INFO    : Bus 7484	: V=0.9910784, theta=-61.751413 -> V=1.0, theta=0.0
% INFO    : Bus 7485	: V=0.987783, theta=-62.402939 -> V=1.0, theta=0.0
% INFO    : Bus 7486	: V=0.9958996, theta=-61.601368 -> V=1.0, theta=0.0
% INFO    : Bus 7487	: V=0.9949924, theta=-61.409814 -> V=1.0, theta=0.0
% INFO    : Bus 7488	: V=0.9957914, theta=-61.283228 -> V=1.0, theta=0.0
% INFO    : Bus 7489	: V=0.9873579, theta=-62.413697 -> V=1.0, theta=0.0
% INFO    : Bus 7490	: V=0.9858291, theta=-62.036435 -> V=1.0, theta=0.0
% INFO    : Bus 7491	: V=0.9891443, theta=-61.845692 -> V=1.0, theta=0.0
% INFO    : Bus 7492	: V=0.9960618, theta=-61.266897 -> V=1.0, theta=0.0
% INFO    : Bus 7493	: V=0.9876819, theta=-61.932283 -> V=1.0, theta=0.0
% INFO    : Bus 7494	: V=0.9883721, theta=-61.890114 -> V=1.0, theta=0.0
% INFO    : Bus 7495	: V=0.9954724, theta=-61.608566 -> V=1.0, theta=0.0
% INFO    : Bus 7496	: V=0.9959201, theta=-61.526686 -> V=1.0, theta=0.0
% INFO    : Bus 7497	: V=0.9847425, theta=-62.091165 -> V=1.0, theta=0.0
% INFO    : Bus 7498	: V=0.9842585, theta=-62.095242 -> V=1.0, theta=0.0
% INFO    : Bus 7499	: V=0.9840355, theta=-62.101686 -> V=1.0, theta=0.0
% INFO    : Bus 7500	: V=0.9902777, theta=-62.130526 -> V=1.0, theta=0.0
% INFO    : Bus 7501	: V=0.9863601, theta=-61.979906 -> V=1.0, theta=0.0
% INFO    : Bus 7502	: V=0.9874053, theta=-61.92894 -> V=1.0, theta=0.0
% INFO    : Bus 7503	: V=0.9870846, theta=-61.962063 -> V=1.0, theta=0.0
% INFO    : Bus 7504	: V=0.9873334, theta=-61.905989 -> V=1.0, theta=0.0
% INFO    : Bus 7505	: V=1.0015872, theta=-60.573606 -> V=1.0, theta=0.0
% INFO    : Bus 7506	: V=0.9849365, theta=-62.045026 -> V=1.0, theta=0.0
% INFO    : Bus 7507	: V=0.9869793, theta=-61.974341 -> V=1.0, theta=0.0
% INFO    : Bus 7508	: V=0.9941384, theta=-61.842281 -> V=1.0, theta=0.0
% INFO    : Bus 7509	: V=0.9856786, theta=-61.987162 -> V=1.0, theta=0.0
% INFO    : Bus 7510	: V=0.9926026, theta=-62.130358 -> V=1.0, theta=0.0
% INFO    : Bus 7511	: V=0.9850009, theta=-62.463608 -> V=1.0, theta=0.0
% INFO    : Bus 7512	: V=0.9914673, theta=-61.916324 -> V=1.0, theta=0.0
% INFO    : Bus 7513	: V=0.9950063, theta=-61.68298 -> V=1.0, theta=0.0
% INFO    : Bus 7514	: V=0.9966086, theta=-61.424961 -> V=1.0, theta=0.0
% INFO    : Bus 7515	: V=0.9970348, theta=-61.346171 -> V=1.0, theta=0.0
% INFO    : Bus 7516	: V=0.9937537, theta=-61.763255 -> V=1.0, theta=0.0
% INFO    : Bus 7517	: V=0.986533, theta=-61.810342 -> V=1.0, theta=0.0
% INFO    : Bus 7518	: V=0.9936766, theta=-61.775492 -> V=1.0, theta=0.0
% INFO    : Bus 7519	: V=0.9965873, theta=-61.471487 -> V=1.0, theta=0.0
% INFO    : Bus 7520	: V=0.9868554, theta=-61.918297 -> V=1.0, theta=0.0
% INFO    : Bus 7521	: V=0.9889075, theta=-61.752242 -> V=1.0, theta=0.0
% INFO    : Bus 7522	: V=0.9881437, theta=-61.821975 -> V=1.0, theta=0.0
% INFO    : Bus 7523	: V=0.9966969, theta=-61.43963 -> V=1.0, theta=0.0
% INFO    : Bus 7524	: V=0.9927044, theta=-61.717329 -> V=1.0, theta=0.0
% INFO    : Bus 7525	: V=0.9975666, theta=-60.961233 -> V=1.0, theta=0.0
% INFO    : Bus 7526	: V=1.0040263, theta=-60.427183 -> V=1.0, theta=0.0
% INFO    : Bus 7527	: V=0.99735, theta=-61.304102 -> V=1.0, theta=0.0
% INFO    : Bus 7528	: V=0.997095, theta=-61.351923 -> V=1.0, theta=0.0
% INFO    : Bus 7529	: V=0.9862984, theta=-61.811634 -> V=1.0, theta=0.0
% INFO    : Bus 7530	: V=0.9859178, theta=-61.815767 -> V=1.0, theta=0.0
% INFO    : Bus 7531	: V=0.9968634, theta=-61.401062 -> V=1.0, theta=0.0
% INFO    : Bus 7532	: V=0.9868796, theta=-61.793877 -> V=1.0, theta=0.0
% INFO    : Bus 7533	: V=0.9938787, theta=-61.748102 -> V=1.0, theta=0.0
% INFO    : Bus 7534	: V=0.9978258, theta=-61.209961 -> V=1.0, theta=0.0
% INFO    : Bus 7535	: V=0.9913284, theta=-61.830542 -> V=1.0, theta=0.0
% INFO    : Bus 7536	: V=0.9995948, theta=-60.948264 -> V=1.0, theta=0.0
% INFO    : Bus 7537	: V=0.9911319, theta=-61.871593 -> V=1.0, theta=0.0
% INFO    : Bus 7538	: V=0.9914067, theta=-61.86965 -> V=1.0, theta=0.0
% INFO    : Bus 7539	: V=0.9915161, theta=-61.865186 -> V=1.0, theta=0.0
% INFO    : Bus 7540	: V=0.9901863, theta=-61.901109 -> V=1.0, theta=0.0
% INFO    : Bus 7541	: V=1.0149169, theta=-59.249492 -> V=1.0, theta=0.0
% INFO    : Bus 7542	: V=0.9994597, theta=-60.996511 -> V=1.0, theta=0.0
% INFO    : Bus 7543	: V=0.9987466, theta=-61.108707 -> V=1.0, theta=0.0
% INFO    : Bus 7544	: V=0.9917399, theta=-61.79825 -> V=1.0, theta=0.0
% INFO    : Bus 7545	: V=0.9978656, theta=-61.228755 -> V=1.0, theta=0.0
% INFO    : Bus 7546	: V=0.9926831, theta=-61.705147 -> V=1.0, theta=0.0
% INFO    : Bus 7547	: V=0.9919342, theta=-61.749607 -> V=1.0, theta=0.0
% INFO    : Bus 7548	: V=1.0001157, theta=-60.865855 -> V=1.0, theta=0.0
% INFO    : Bus 7549	: V=1.0162889, theta=-59.575843 -> V=1.0, theta=0.0
% INFO    : Bus 7550	: V=1.0157004, theta=-59.675058 -> V=1.0, theta=0.0
% INFO    : Bus 7551	: V=1.0042533, theta=-61.365788 -> V=1.0, theta=0.0
% INFO    : Bus 7552	: V=1.0003385, theta=-61.669645 -> V=1.0, theta=0.0
% INFO    : Bus 7553	: V=0.9951893, theta=-62.197936 -> V=1.0, theta=0.0
% INFO    : Bus 7554	: V=0.9900194, theta=-62.479693 -> V=1.0, theta=0.0
% INFO    : Bus 7555	: V=1.0011414, theta=-61.64874 -> V=1.0, theta=0.0
% INFO    : Bus 7556	: V=1.0027299, theta=-61.597113 -> V=1.0, theta=0.0
% INFO    : Bus 7557	: V=1.0035587, theta=-61.658662 -> V=1.0, theta=0.0
% INFO    : Bus 7558	: V=0.9954595, theta=-62.532466 -> V=1.0, theta=0.0
% INFO    : Bus 7559	: V=0.9949178, theta=-62.555465 -> V=1.0, theta=0.0
% INFO    : Bus 7560	: V=0.9909003, theta=-62.941773 -> V=1.0, theta=0.0
% INFO    : Bus 7561	: V=1.0018459, theta=-61.833135 -> V=1.0, theta=0.0
% INFO    : Bus 7562	: V=0.9949965, theta=-62.545023 -> V=1.0, theta=0.0
% INFO    : Bus 7563	: V=0.9998876, theta=-62.085711 -> V=1.0, theta=0.0
% INFO    : Bus 7564	: V=1.00087, theta=-61.939652 -> V=1.0, theta=0.0
% INFO    : Bus 7565	: V=1.000293, theta=-62.000494 -> V=1.0, theta=0.0
% INFO    : Bus 7566	: V=0.9988807, theta=-62.230091 -> V=1.0, theta=0.0
% INFO    : Bus 7567	: V=0.9988251, theta=-62.228252 -> V=1.0, theta=0.0
% INFO    : Bus 7568	: V=1.0069781, theta=-61.043726 -> V=1.0, theta=0.0
% INFO    : Bus 7569	: V=0.9967965, theta=-62.466132 -> V=1.0, theta=0.0
% INFO    : Bus 7570	: V=0.9869407, theta=-63.038809 -> V=1.0, theta=0.0
% INFO    : Bus 7571	: V=0.986509, theta=-63.14872 -> V=1.0, theta=0.0
% INFO    : Bus 7572	: V=0.9799462, theta=-63.787734 -> V=1.0, theta=0.0
% INFO    : Bus 7573	: V=0.98429, theta=-63.499295 -> V=1.0, theta=0.0
% INFO    : Bus 7574	: V=0.9984965, theta=-62.256326 -> V=1.0, theta=0.0
% INFO    : Bus 7575	: V=0.98018, theta=-63.802132 -> V=1.0, theta=0.0
% INFO    : Bus 7576	: V=0.981902, theta=-63.698047 -> V=1.0, theta=0.0
% INFO    : Bus 7577	: V=0.9877117, theta=-62.93332 -> V=1.0, theta=0.0
% INFO    : Bus 7578	: V=0.9868393, theta=-63.020164 -> V=1.0, theta=0.0
% INFO    : Bus 7579	: V=0.9861099, theta=-63.088421 -> V=1.0, theta=0.0
% INFO    : Bus 7580	: V=0.9863665, theta=-63.301327 -> V=1.0, theta=0.0
% INFO    : Bus 7581	: V=0.9864211, theta=-63.064694 -> V=1.0, theta=0.0
% INFO    : Bus 7582	: V=0.9834091, theta=-63.548761 -> V=1.0, theta=0.0
% INFO    : Bus 7583	: V=0.979664, theta=-64.019904 -> V=1.0, theta=0.0
% INFO    : Bus 7584	: V=0.9795942, theta=-64.029266 -> V=1.0, theta=0.0
% INFO    : Bus 7585	: V=0.9826104, theta=-63.579087 -> V=1.0, theta=0.0
% INFO    : Bus 7586	: V=0.9954166, theta=-62.288079 -> V=1.0, theta=0.0
% INFO    : Bus 7587	: V=0.9710406, theta=-65.7899 -> V=1.0, theta=0.0
% INFO    : Bus 7588	: V=0.980364, theta=-64.006831 -> V=1.0, theta=0.0
% INFO    : Bus 7589	: V=0.9705821, theta=-65.802172 -> V=1.0, theta=0.0
% INFO    : Bus 7590	: V=0.9747038, theta=-64.269317 -> V=1.0, theta=0.0
% INFO    : Bus 7591	: V=0.9745761, theta=-64.217336 -> V=1.0, theta=0.0
% INFO    : Bus 7592	: V=0.9745191, theta=-64.258496 -> V=1.0, theta=0.0
% INFO    : Bus 7593	: V=0.9740108, theta=-64.24104 -> V=1.0, theta=0.0
% INFO    : Bus 7594	: V=0.9739129, theta=-64.244497 -> V=1.0, theta=0.0
% INFO    : Bus 7595	: V=0.9758194, theta=-64.105435 -> V=1.0, theta=0.0
% INFO    : Bus 7596	: V=0.9748258, theta=-64.118568 -> V=1.0, theta=0.0
% INFO    : Bus 7597	: V=0.97505, theta=-64.115866 -> V=1.0, theta=0.0
% INFO    : Bus 7598	: V=0.9753961, theta=-64.125986 -> V=1.0, theta=0.0
% INFO    : Bus 7599	: V=0.9736632, theta=-64.250257 -> V=1.0, theta=0.0
% INFO    : Bus 7600	: V=0.9744921, theta=-64.13383 -> V=1.0, theta=0.0
% INFO    : Bus 7601	: V=0.9736808, theta=-64.315106 -> V=1.0, theta=0.0
% INFO    : Bus 7602	: V=0.977604, theta=-64.037972 -> V=1.0, theta=0.0
% INFO    : Bus 7603	: V=0.9866437, theta=-63.253163 -> V=1.0, theta=0.0
% INFO    : Bus 7604	: V=0.987009, theta=-63.306921 -> V=1.0, theta=0.0
% INFO    : Bus 7605	: V=0.9888929, theta=-63.17829 -> V=1.0, theta=0.0
% INFO    : Bus 7606	: V=0.9905671, theta=-63.06308 -> V=1.0, theta=0.0
% INFO    : Bus 7607	: V=0.9921881, theta=-62.912066 -> V=1.0, theta=0.0
% INFO    : Bus 7608	: V=1.0025801, theta=-61.652092 -> V=1.0, theta=0.0
% INFO    : Bus 7609	: V=1.0052441, theta=-61.291691 -> V=1.0, theta=0.0
% INFO    : Bus 7610	: V=1.0043659, theta=-61.410876 -> V=1.0, theta=0.0
% INFO    : Bus 7611	: V=1.0009466, theta=-61.884096 -> V=1.0, theta=0.0
% INFO    : Bus 7612	: V=0.9917881, theta=-63.045631 -> V=1.0, theta=0.0
% INFO    : Bus 7613	: V=0.9996106, theta=-62.072999 -> V=1.0, theta=0.0
% INFO    : Bus 7614	: V=1.0216401, theta=-65.105543 -> V=1.0, theta=0.0
% INFO    : Bus 7615	: V=1.0132875, theta=-65.5474 -> V=1.0, theta=0.0
% INFO    : Bus 7616	: V=1.0045027, theta=-66.575755 -> V=1.0, theta=0.0
% INFO    : Bus 7617	: V=1.0101591, theta=-65.579759 -> V=1.0, theta=0.0
% INFO    : Bus 7618	: V=0.9981803, theta=-67.994805 -> V=1.0, theta=0.0
% INFO    : Bus 7619	: V=1.0150479, theta=-65.402584 -> V=1.0, theta=0.0
% INFO    : Bus 7620	: V=0.9972398, theta=-67.734402 -> V=1.0, theta=0.0
% INFO    : Bus 7621	: V=0.996052, theta=-69.59633 -> V=1.0, theta=0.0
% INFO    : Bus 7622	: V=1.0023086, theta=-69.291515 -> V=1.0, theta=0.0
% INFO    : Bus 7623	: V=1.0091092, theta=-70.12148 -> V=1.0, theta=0.0
% INFO    : Bus 7624	: V=1.0006754, theta=-69.586745 -> V=1.0, theta=0.0
% INFO    : Bus 7625	: V=0.9999385, theta=-69.477886 -> V=1.0, theta=0.0
% INFO    : Bus 7626	: V=0.993991, theta=-68.098657 -> V=1.0, theta=0.0
% INFO    : Bus 7627	: V=0.996917, theta=-67.964638 -> V=1.0, theta=0.0
% INFO    : Bus 7628	: V=0.976166, theta=-70.28235 -> V=1.0, theta=0.0
% INFO    : Bus 7629	: V=0.9744458, theta=-70.358694 -> V=1.0, theta=0.0
% INFO    : Bus 7630	: V=0.9669528, theta=-70.609543 -> V=1.0, theta=0.0
% INFO    : Bus 7631	: V=0.9692503, theta=-70.351366 -> V=1.0, theta=0.0
% INFO    : Bus 7632	: V=0.9869398, theta=-69.420324 -> V=1.0, theta=0.0
% INFO    : Bus 7633	: V=0.997563, theta=-67.77156 -> V=1.0, theta=0.0
% INFO    : Bus 7634	: V=0.9833721, theta=-69.454144 -> V=1.0, theta=0.0
% INFO    : Bus 7635	: V=1.0185286, theta=-64.636151 -> V=1.0, theta=0.0
% INFO    : Bus 7636	: V=1.0074222, theta=-65.497617 -> V=1.0, theta=0.0
% INFO    : Bus 7637	: V=0.9962282, theta=-65.566293 -> V=1.0, theta=0.0
% INFO    : Bus 7638	: V=1.0166706, theta=-61.838471 -> V=1.0, theta=0.0
% INFO    : Bus 7639	: V=0.9684056, theta=-70.254181 -> V=1.0, theta=0.0
% INFO    : Bus 7640	: V=0.9623566, theta=-70.758012 -> V=1.0, theta=0.0
% INFO    : Bus 7641	: V=0.9622245, theta=-70.428686 -> V=1.0, theta=0.0
% INFO    : Bus 7642	: V=1.0051567, theta=-70.063036 -> V=1.0, theta=0.0
% INFO    : Bus 7643	: V=0.9867336, theta=-69.889091 -> V=1.0, theta=0.0
% INFO    : Bus 7644	: V=0.9890831, theta=-69.768215 -> V=1.0, theta=0.0
% INFO    : Bus 7645	: V=1.0110856, theta=-69.438546 -> V=1.0, theta=0.0
% INFO    : Bus 7646	: V=1.0150255, theta=-69.145611 -> V=1.0, theta=0.0
% INFO    : Bus 7647	: V=1.0051612, theta=-69.947012 -> V=1.0, theta=0.0
% INFO    : Bus 7648	: V=0.9918969, theta=-70.388985 -> V=1.0, theta=0.0
% INFO    : Bus 7649	: V=0.9773394, theta=-70.770471 -> V=1.0, theta=0.0
% INFO    : Bus 7650	: V=0.9830735, theta=-71.098871 -> V=1.0, theta=0.0
% INFO    : Bus 7651	: V=0.9806768, theta=-70.586528 -> V=1.0, theta=0.0
% INFO    : Bus 7652	: V=0.9940054, theta=-70.415714 -> V=1.0, theta=0.0
% INFO    : Bus 7653	: V=0.9910597, theta=-70.430572 -> V=1.0, theta=0.0
% INFO    : Bus 7654	: V=0.9796109, theta=-71.589742 -> V=1.0, theta=0.0
% INFO    : Bus 7655	: V=0.9698909, theta=-71.801443 -> V=1.0, theta=0.0
% INFO    : Bus 7656	: V=0.9733131, theta=-71.753577 -> V=1.0, theta=0.0
% INFO    : Bus 7657	: V=0.9875105, theta=-70.371472 -> V=1.0, theta=0.0
% INFO    : Bus 7658	: V=0.9798975, theta=-71.130443 -> V=1.0, theta=0.0
% INFO    : Bus 7659	: V=0.9873677, theta=-70.347416 -> V=1.0, theta=0.0
% INFO    : Bus 7660	: V=0.9787237, theta=-71.13924 -> V=1.0, theta=0.0
% INFO    : Bus 7661	: V=0.9874108, theta=-70.200221 -> V=1.0, theta=0.0
% INFO    : Bus 7662	: V=0.988774, theta=-70.394797 -> V=1.0, theta=0.0
% INFO    : Bus 7663	: V=0.9645212, theta=-72.181617 -> V=1.0, theta=0.0
% INFO    : Bus 7664	: V=0.9725855, theta=-71.157757 -> V=1.0, theta=0.0
% INFO    : Bus 7665	: V=0.9735049, theta=-71.678398 -> V=1.0, theta=0.0
% INFO    : Bus 7666	: V=0.9730405, theta=-70.791945 -> V=1.0, theta=0.0
% INFO    : Bus 7667	: V=0.9621515, theta=-71.631653 -> V=1.0, theta=0.0
% INFO    : Bus 7668	: V=0.9695576, theta=-71.410824 -> V=1.0, theta=0.0
% INFO    : Bus 7669	: V=0.9670826, theta=-71.41891 -> V=1.0, theta=0.0
% INFO    : Bus 7670	: V=0.9835226, theta=-70.385708 -> V=1.0, theta=0.0
% INFO    : Bus 7671	: V=0.9697537, theta=-71.231735 -> V=1.0, theta=0.0
% INFO    : Bus 7672	: V=0.9805043, theta=-69.721361 -> V=1.0, theta=0.0
% INFO    : Bus 7673	: V=0.9675427, theta=-71.559806 -> V=1.0, theta=0.0
% INFO    : Bus 7674	: V=0.9664949, theta=-71.571138 -> V=1.0, theta=0.0
% INFO    : Bus 7675	: V=0.9633976, theta=-70.671969 -> V=1.0, theta=0.0
% INFO    : Bus 7676	: V=0.9632536, theta=-70.676039 -> V=1.0, theta=0.0
% INFO    : Bus 7677	: V=0.9677259, theta=-70.731503 -> V=1.0, theta=0.0
% INFO    : Bus 7678	: V=0.9641525, theta=-70.851556 -> V=1.0, theta=0.0
% INFO    : Bus 7679	: V=0.9667274, theta=-70.701369 -> V=1.0, theta=0.0
% INFO    : Bus 7680	: V=0.9681884, theta=-70.355818 -> V=1.0, theta=0.0
% INFO    : Bus 7681	: V=0.9796467, theta=-69.315781 -> V=1.0, theta=0.0
% INFO    : Bus 7682	: V=0.9720098, theta=-69.956073 -> V=1.0, theta=0.0
% INFO    : Bus 7683	: V=0.9663073, theta=-70.561749 -> V=1.0, theta=0.0
% INFO    : Bus 7684	: V=0.9699147, theta=-70.648866 -> V=1.0, theta=0.0
% INFO    : Bus 7685	: V=0.9718537, theta=-70.232286 -> V=1.0, theta=0.0
% INFO    : Bus 7686	: V=0.9695973, theta=-70.319589 -> V=1.0, theta=0.0
% INFO    : Bus 7687	: V=0.977959, theta=-69.421742 -> V=1.0, theta=0.0
% INFO    : Bus 7688	: V=0.972594, theta=-69.649693 -> V=1.0, theta=0.0
% INFO    : Bus 7689	: V=0.9740686, theta=-69.637423 -> V=1.0, theta=0.0
% INFO    : Bus 7690	: V=0.9642818, theta=-72.060655 -> V=1.0, theta=0.0
% INFO    : Bus 7691	: V=0.9634868, theta=-72.089882 -> V=1.0, theta=0.0
% INFO    : Bus 7692	: V=0.9740882, theta=-69.294419 -> V=1.0, theta=0.0
% INFO    : Bus 7693	: V=0.9738304, theta=-69.296044 -> V=1.0, theta=0.0
% INFO    : Bus 7694	: V=0.9641578, theta=-70.784022 -> V=1.0, theta=0.0
% INFO    : Bus 7695	: V=0.9657393, theta=-70.636674 -> V=1.0, theta=0.0
% INFO    : Bus 7696	: V=0.9686116, theta=-69.313054 -> V=1.0, theta=0.0
% INFO    : Bus 7697	: V=0.9793874, theta=-68.207017 -> V=1.0, theta=0.0
% INFO    : Bus 7698	: V=0.9686438, theta=-69.318557 -> V=1.0, theta=0.0
% INFO    : Bus 7699	: V=0.9660645, theta=-70.60964 -> V=1.0, theta=0.0
% INFO    : Bus 7700	: V=0.9656043, theta=-70.622584 -> V=1.0, theta=0.0
% INFO    : Bus 7701	: V=0.9652049, theta=-70.658677 -> V=1.0, theta=0.0
% INFO    : Bus 7702	: V=0.9649418, theta=-70.665668 -> V=1.0, theta=0.0
% INFO    : Bus 7703	: V=0.9664396, theta=-70.325715 -> V=1.0, theta=0.0
% INFO    : Bus 7704	: V=0.9688416, theta=-70.117821 -> V=1.0, theta=0.0
% INFO    : Bus 7705	: V=0.969147, theta=-70.109396 -> V=1.0, theta=0.0
% INFO    : Bus 7706	: V=0.977855, theta=-68.335011 -> V=1.0, theta=0.0
% INFO    : Bus 7707	: V=0.978475, theta=-68.281835 -> V=1.0, theta=0.0
% INFO    : Bus 7708	: V=0.9705569, theta=-69.985019 -> V=1.0, theta=0.0
% INFO    : Bus 7709	: V=0.9678237, theta=-70.184954 -> V=1.0, theta=0.0
% INFO    : Bus 7710	: V=0.9749878, theta=-69.287914 -> V=1.0, theta=0.0
% INFO    : Bus 7711	: V=1.0067938, theta=-63.917054 -> V=1.0, theta=0.0
% INFO    : Bus 7712	: V=0.9672968, theta=-70.199902 -> V=1.0, theta=0.0
% INFO    : Bus 7713	: V=0.9621227, theta=-70.930049 -> V=1.0, theta=0.0
% INFO    : Bus 7714	: V=0.9616196, theta=-70.944195 -> V=1.0, theta=0.0
% INFO    : Bus 7715	: V=0.9654016, theta=-71.020565 -> V=1.0, theta=0.0
% INFO    : Bus 7716	: V=0.9618176, theta=-71.030709 -> V=1.0, theta=0.0
% INFO    : Bus 7717	: V=0.9600662, theta=-71.113346 -> V=1.0, theta=0.0
% INFO    : Bus 7718	: V=0.9641287, theta=-71.311859 -> V=1.0, theta=0.0
% INFO    : Bus 7719	: V=0.9651817, theta=-71.283712 -> V=1.0, theta=0.0
% INFO    : Bus 7720	: V=0.960436, theta=-71.678443 -> V=1.0, theta=0.0
% INFO    : Bus 7721	: V=0.9625086, theta=-70.215071 -> V=1.0, theta=0.0
% INFO    : Bus 7722	: V=0.9733244, theta=-68.784315 -> V=1.0, theta=0.0
% INFO    : Bus 7723	: V=0.9634504, theta=-70.201088 -> V=1.0, theta=0.0
% INFO    : Bus 7724	: V=0.9696037, theta=-70.037319 -> V=1.0, theta=0.0
% INFO    : Bus 7725	: V=0.9693429, theta=-70.051348 -> V=1.0, theta=0.0
% INFO    : Bus 7726	: V=0.9640289, theta=-70.183977 -> V=1.0, theta=0.0
% INFO    : Bus 7727	: V=0.9684327, theta=-70.07676 -> V=1.0, theta=0.0
% INFO    : Bus 7728	: V=0.9644626, theta=-70.172531 -> V=1.0, theta=0.0
% INFO    : Bus 7729	: V=0.9619449, theta=-70.929628 -> V=1.0, theta=0.0
% INFO    : Bus 7730	: V=0.9570025, theta=-71.166775 -> V=1.0, theta=0.0
% INFO    : Bus 7731	: V=0.9679595, theta=-70.090198 -> V=1.0, theta=0.0
% INFO    : Bus 7732	: V=0.9682622, theta=-70.081792 -> V=1.0, theta=0.0
% INFO    : Bus 7733	: V=0.9791646, theta=-68.303581 -> V=1.0, theta=0.0
% INFO    : Bus 7734	: V=0.9671093, theta=-70.306849 -> V=1.0, theta=0.0
% INFO    : Bus 7735	: V=0.9646416, theta=-66.414441 -> V=1.0, theta=0.0
% INFO    : Bus 7736	: V=0.975652, theta=-65.499415 -> V=1.0, theta=0.0
% INFO    : Bus 7737	: V=0.9725275, theta=-65.658676 -> V=1.0, theta=0.0
% INFO    : Bus 7738	: V=0.9699829, theta=-66.823056 -> V=1.0, theta=0.0
% INFO    : Bus 7739	: V=0.9723333, theta=-65.389954 -> V=1.0, theta=0.0
% INFO    : Bus 7740	: V=0.9831518, theta=-63.750801 -> V=1.0, theta=0.0
% INFO    : Bus 7741	: V=0.9607157, theta=-66.711893 -> V=1.0, theta=0.0
% INFO    : Bus 7742	: V=0.9910887, theta=-63.045671 -> V=1.0, theta=0.0
% INFO    : Bus 7743	: V=1.0025006, theta=-70.017957 -> V=1.0, theta=0.0
% INFO    : Bus 7744	: V=0.9907748, theta=-70.873736 -> V=1.0, theta=0.0
% INFO    : Bus 7745	: V=0.9800723, theta=-72.180895 -> V=1.0, theta=0.0
% INFO    : Bus 7746	: V=0.9802166, theta=-72.113577 -> V=1.0, theta=0.0
% INFO    : Bus 7747	: V=0.9657511, theta=-73.525079 -> V=1.0, theta=0.0
% INFO    : Bus 7748	: V=0.9812116, theta=-64.688047 -> V=1.0, theta=0.0
% INFO    : Bus 7749	: V=0.9727883, theta=-66.096187 -> V=1.0, theta=0.0
% INFO    : Bus 7750	: V=0.9709794, theta=-66.03254 -> V=1.0, theta=0.0
% INFO    : Bus 7751	: V=0.9823769, theta=-66.183833 -> V=1.0, theta=0.0
% INFO    : Bus 7752	: V=0.9797023, theta=-65.742236 -> V=1.0, theta=0.0
% INFO    : Bus 7753	: V=0.9668082, theta=-66.451297 -> V=1.0, theta=0.0
% INFO    : Bus 7754	: V=0.9884097, theta=-66.833247 -> V=1.0, theta=0.0
% INFO    : Bus 7755	: V=0.9982345, theta=-67.747791 -> V=1.0, theta=0.0
% INFO    : Bus 7756	: V=1.0066356, theta=-69.095691 -> V=1.0, theta=0.0
% INFO    : Bus 7757	: V=1.0089731, theta=-69.056148 -> V=1.0, theta=0.0
% INFO    : Bus 7758	: V=0.9965153, theta=-70.430585 -> V=1.0, theta=0.0
% INFO    : Bus 7759	: V=1.0037981, theta=-71.736458 -> V=1.0, theta=0.0
% INFO    : Bus 7760	: V=1.0093942, theta=-71.599763 -> V=1.0, theta=0.0
% INFO    : Bus 7761	: V=0.9961432, theta=-72.276107 -> V=1.0, theta=0.0
% INFO    : Bus 7762	: V=0.9921808, theta=-72.389134 -> V=1.0, theta=0.0
% INFO    : Bus 7763	: V=0.992702, theta=-72.031444 -> V=1.0, theta=0.0
% INFO    : Bus 7764	: V=0.9933942, theta=-71.96627 -> V=1.0, theta=0.0
% INFO    : Bus 7765	: V=0.9900043, theta=-72.948126 -> V=1.0, theta=0.0
% INFO    : Bus 7766	: V=0.9894896, theta=-72.9617 -> V=1.0, theta=0.0
% INFO    : Bus 7767	: V=0.9967325, theta=-72.672299 -> V=1.0, theta=0.0
% INFO    : Bus 7768	: V=0.990399, theta=-73.00056 -> V=1.0, theta=0.0
% INFO    : Bus 7769	: V=0.9898045, theta=-71.474103 -> V=1.0, theta=0.0
% INFO    : Bus 7770	: V=0.9852124, theta=-72.638392 -> V=1.0, theta=0.0
% INFO    : Bus 7771	: V=0.9922575, theta=-71.059545 -> V=1.0, theta=0.0
% INFO    : Bus 7772	: V=0.9783732, theta=-72.229418 -> V=1.0, theta=0.0
% INFO    : Bus 7773	: V=0.9703027, theta=-74.480987 -> V=1.0, theta=0.0
% INFO    : Bus 7774	: V=0.9683732, theta=-75.433982 -> V=1.0, theta=0.0
% INFO    : Bus 7775	: V=0.9800947, theta=-74.33217 -> V=1.0, theta=0.0
% INFO    : Bus 7776	: V=0.9885434, theta=-72.906498 -> V=1.0, theta=0.0
% INFO    : Bus 7777	: V=0.9624559, theta=-75.554705 -> V=1.0, theta=0.0
% INFO    : Bus 7778	: V=0.9605046, theta=-76.986054 -> V=1.0, theta=0.0
% INFO    : Bus 7779	: V=0.974327, theta=-75.221518 -> V=1.0, theta=0.0
% INFO    : Bus 7780	: V=0.9821951, theta=-73.890424 -> V=1.0, theta=0.0
% INFO    : Bus 7781	: V=0.965596, theta=-76.299789 -> V=1.0, theta=0.0
% INFO    : Bus 7782	: V=0.9646027, theta=-76.39609 -> V=1.0, theta=0.0
% INFO    : Bus 7783	: V=0.9646585, theta=-76.368101 -> V=1.0, theta=0.0
% INFO    : Bus 7784	: V=0.9634741, theta=-76.461519 -> V=1.0, theta=0.0
% INFO    : Bus 7785	: V=0.9609589, theta=-76.57646 -> V=1.0, theta=0.0
% INFO    : Bus 7786	: V=0.9624388, theta=-76.511199 -> V=1.0, theta=0.0
% INFO    : Bus 7787	: V=0.9587528, theta=-76.694774 -> V=1.0, theta=0.0
% INFO    : Bus 7788	: V=0.9842784, theta=-62.318315 -> V=1.0, theta=0.0
% INFO    : Bus 7789	: V=0.9936224, theta=-62.455328 -> V=1.0, theta=0.0
% INFO    : Bus 7790	: V=0.9948784, theta=-62.118811 -> V=1.0, theta=0.0
% INFO    : Bus 7791	: V=0.9879611, theta=-62.107334 -> V=1.0, theta=0.0
% INFO    : Bus 7792	: V=0.9897927, theta=-61.943334 -> V=1.0, theta=0.0
% INFO    : Bus 7793	: V=0.9915749, theta=-61.76373 -> V=1.0, theta=0.0
% INFO    : Bus 7794	: V=0.9968749, theta=-60.945245 -> V=1.0, theta=0.0
% INFO    : Bus 7795	: V=0.9954349, theta=-61.095217 -> V=1.0, theta=0.0
% INFO    : Bus 7796	: V=1.0098545, theta=-58.926137 -> V=1.0, theta=0.0
% INFO    : Bus 7797	: V=0.9978793, theta=-61.459036 -> V=1.0, theta=0.0
% INFO    : Bus 7798	: V=0.9906293, theta=-61.39028 -> V=1.0, theta=0.0
% INFO    : Bus 7799	: V=0.9922813, theta=-61.627004 -> V=1.0, theta=0.0
% INFO    : Bus 7800	: V=0.9916577, theta=-61.769071 -> V=1.0, theta=0.0
% INFO    : Bus 7801	: V=0.9928824, theta=-61.505289 -> V=1.0, theta=0.0
% INFO    : Bus 7802	: V=0.9832722, theta=-62.473001 -> V=1.0, theta=0.0
% INFO    : Bus 7803	: V=0.9909758, theta=-61.937802 -> V=1.0, theta=0.0
% INFO    : Bus 7804	: V=0.9852965, theta=-62.477774 -> V=1.0, theta=0.0
% INFO    : Bus 7805	: V=0.9856012, theta=-62.528529 -> V=1.0, theta=0.0
% INFO    : Bus 7806	: V=0.9942031, theta=-61.249636 -> V=1.0, theta=0.0
% INFO    : Bus 7807	: V=0.9850705, theta=-62.36708 -> V=1.0, theta=0.0
% INFO    : Bus 7808	: V=0.992365, theta=-61.378638 -> V=1.0, theta=0.0
% INFO    : Bus 7809	: V=0.9892617, theta=-61.669188 -> V=1.0, theta=0.0
% INFO    : Bus 7810	: V=0.989026, theta=-61.669979 -> V=1.0, theta=0.0
% INFO    : Bus 7811	: V=0.9837728, theta=-62.341357 -> V=1.0, theta=0.0
% INFO    : Bus 7812	: V=0.9825287, theta=-62.25749 -> V=1.0, theta=0.0
% INFO    : Bus 7813	: V=0.9923842, theta=-61.450163 -> V=1.0, theta=0.0
% INFO    : Bus 7814	: V=0.9896853, theta=-61.585551 -> V=1.0, theta=0.0
% INFO    : Bus 7815	: V=0.988539, theta=-61.704827 -> V=1.0, theta=0.0
% INFO    : Bus 7816	: V=0.9851308, theta=-61.795393 -> V=1.0, theta=0.0
% INFO    : Bus 7817	: V=0.984731, theta=-61.799635 -> V=1.0, theta=0.0
% INFO    : Bus 7818	: V=0.9769678, theta=-62.465214 -> V=1.0, theta=0.0
% INFO    : Bus 7819	: V=0.98277, theta=-61.96227 -> V=1.0, theta=0.0
% INFO    : Bus 7820	: V=0.9811661, theta=-62.09599 -> V=1.0, theta=0.0
% INFO    : Bus 7821	: V=0.9797299, theta=-62.215723 -> V=1.0, theta=0.0
% INFO    : Bus 7822	: V=0.990605, theta=-62.113768 -> V=1.0, theta=0.0
% INFO    : Bus 7823	: V=0.9867909, theta=-62.595678 -> V=1.0, theta=0.0
% INFO    : Bus 7824	: V=0.984854, theta=-62.433478 -> V=1.0, theta=0.0
% INFO    : Bus 7825	: V=0.9788836, theta=-62.386799 -> V=1.0, theta=0.0
% INFO    : Bus 7826	: V=0.9779509, theta=-62.395693 -> V=1.0, theta=0.0
% INFO    : Bus 7827	: V=0.9794712, theta=-62.37963 -> V=1.0, theta=0.0
% INFO    : Bus 7828	: V=0.9877178, theta=-62.569929 -> V=1.0, theta=0.0
% INFO    : Bus 7829	: V=1.0102469, theta=-59.501456 -> V=1.0, theta=0.0
% INFO    : Bus 7830	: V=0.998252, theta=-60.976442 -> V=1.0, theta=0.0
% INFO    : Bus 7831	: V=0.9783934, theta=-62.425666 -> V=1.0, theta=0.0
% INFO    : Bus 7832	: V=0.986032, theta=-62.429777 -> V=1.0, theta=0.0
% INFO    : Bus 7833	: V=0.9877588, theta=-62.384862 -> V=1.0, theta=0.0
% INFO    : Bus 7834	: V=0.9905095, theta=-62.376105 -> V=1.0, theta=0.0
% INFO    : Bus 7835	: V=0.9908805, theta=-62.817805 -> V=1.0, theta=0.0
% INFO    : Bus 7836	: V=0.9901255, theta=-62.686218 -> V=1.0, theta=0.0
% INFO    : Bus 7837	: V=0.9928218, theta=-62.982186 -> V=1.0, theta=0.0
% INFO    : Bus 7838	: V=0.9924561, theta=-61.979373 -> V=1.0, theta=0.0
% INFO    : Bus 7839	: V=0.9912006, theta=-62.669558 -> V=1.0, theta=0.0
% INFO    : Bus 7840	: V=0.9916547, theta=-61.98992 -> V=1.0, theta=0.0
% INFO    : Bus 7841	: V=0.9901039, theta=-62.695715 -> V=1.0, theta=0.0
% INFO    : Bus 7842	: V=0.9911254, theta=-61.950319 -> V=1.0, theta=0.0
% INFO    : Bus 7843	: V=0.9883755, theta=-62.06972 -> V=1.0, theta=0.0
% INFO    : Bus 7844	: V=0.9873631, theta=-62.128352 -> V=1.0, theta=0.0
% INFO    : Bus 7845	: V=0.9923876, theta=-61.963596 -> V=1.0, theta=0.0
% INFO    : Bus 7846	: V=0.9896875, theta=-61.93027 -> V=1.0, theta=0.0
% INFO    : Bus 7847	: V=0.9919603, theta=-61.624899 -> V=1.0, theta=0.0
% INFO    : Bus 7848	: V=1.0028205, theta=-60.420535 -> V=1.0, theta=0.0
% INFO    : Bus 7849	: V=0.9910126, theta=-61.899321 -> V=1.0, theta=0.0
% INFO    : Bus 7850	: V=0.989946, theta=-62.001384 -> V=1.0, theta=0.0
% INFO    : Bus 7851	: V=0.9860695, theta=-62.690071 -> V=1.0, theta=0.0
% INFO    : Bus 7852	: V=0.985235, theta=-62.64214 -> V=1.0, theta=0.0
% INFO    : Bus 7853	: V=0.9879216, theta=-62.709556 -> V=1.0, theta=0.0
% INFO    : Bus 7854	: V=0.9855081, theta=-62.442708 -> V=1.0, theta=0.0
% INFO    : Bus 7855	: V=0.9808028, theta=-63.721377 -> V=1.0, theta=0.0
% INFO    : Bus 7856	: V=0.9812737, theta=-63.709717 -> V=1.0, theta=0.0
% INFO    : Bus 7857	: V=0.9880419, theta=-63.223406 -> V=1.0, theta=0.0
% INFO    : Bus 7858	: V=0.9872564, theta=-63.368939 -> V=1.0, theta=0.0
% INFO    : Bus 7859	: V=0.9809473, theta=-64.592846 -> V=1.0, theta=0.0
% INFO    : Bus 7860	: V=0.9861429, theta=-63.498911 -> V=1.0, theta=0.0
% INFO    : Bus 7861	: V=0.9876512, theta=-63.350438 -> V=1.0, theta=0.0
% INFO    : Bus 7862	: V=0.988182, theta=-63.350855 -> V=1.0, theta=0.0
% INFO    : Bus 7863	: V=0.9841989, theta=-63.705642 -> V=1.0, theta=0.0
% INFO    : Bus 7864	: V=0.9819854, theta=-64.278237 -> V=1.0, theta=0.0
% INFO    : Bus 7865	: V=0.9853515, theta=-63.588743 -> V=1.0, theta=0.0
% INFO    : Bus 7866	: V=0.9823046, theta=-64.099825 -> V=1.0, theta=0.0
% INFO    : Bus 7867	: V=0.9826448, theta=-64.064661 -> V=1.0, theta=0.0
% INFO    : Bus 7868	: V=0.9836721, theta=-63.985625 -> V=1.0, theta=0.0
% INFO    : Bus 7869	: V=0.9850244, theta=-63.77998 -> V=1.0, theta=0.0
% INFO    : Bus 7870	: V=0.9871755, theta=-63.707899 -> V=1.0, theta=0.0
% INFO    : Bus 7871	: V=0.9876012, theta=-63.697543 -> V=1.0, theta=0.0
% INFO    : Bus 7872	: V=0.9847432, theta=-63.865341 -> V=1.0, theta=0.0
% INFO    : Bus 7873	: V=0.9847719, theta=-63.903433 -> V=1.0, theta=0.0
% INFO    : Bus 7874	: V=0.9841709, theta=-63.925329 -> V=1.0, theta=0.0
% INFO    : Bus 7875	: V=0.9875437, theta=-63.711369 -> V=1.0, theta=0.0
% INFO    : Bus 7876	: V=0.987384, theta=-63.713942 -> V=1.0, theta=0.0
% INFO    : Bus 7877	: V=0.9690573, theta=-64.452867 -> V=1.0, theta=0.0
% INFO    : Bus 7878	: V=0.9833986, theta=-63.747371 -> V=1.0, theta=0.0
% INFO    : Bus 7879	: V=0.987072, theta=-63.722219 -> V=1.0, theta=0.0
% INFO    : Bus 7880	: V=0.9850274, theta=-63.743371 -> V=1.0, theta=0.0
% INFO    : Bus 7881	: V=0.9824806, theta=-61.821963 -> V=1.0, theta=0.0
% INFO    : Bus 7882	: V=0.9859547, theta=-61.642819 -> V=1.0, theta=0.0
% INFO    : Bus 7883	: V=0.98312, theta=-61.797046 -> V=1.0, theta=0.0
% INFO    : Bus 7884	: V=0.9772344, theta=-62.087573 -> V=1.0, theta=0.0
% INFO    : Bus 7885	: V=0.9783202, theta=-62.112494 -> V=1.0, theta=0.0
% INFO    : Bus 7886	: V=0.9789935, theta=-62.024635 -> V=1.0, theta=0.0
% INFO    : Bus 7887	: V=0.9811136, theta=-61.904845 -> V=1.0, theta=0.0
% INFO    : Bus 7888	: V=0.9818712, theta=-61.86435 -> V=1.0, theta=0.0
% INFO    : Bus 7889	: V=0.9991954, theta=-60.158397 -> V=1.0, theta=0.0
% INFO    : Bus 7890	: V=1.0001324, theta=-60.093692 -> V=1.0, theta=0.0
% INFO    : Bus 7891	: V=0.975963, theta=-62.100101 -> V=1.0, theta=0.0
% INFO    : Bus 7892	: V=0.9865773, theta=-61.097219 -> V=1.0, theta=0.0
% INFO    : Bus 7893	: V=0.9825672, theta=-61.932594 -> V=1.0, theta=0.0
% INFO    : Bus 7894	: V=0.9827222, theta=-61.90203 -> V=1.0, theta=0.0
% INFO    : Bus 7895	: V=0.9847265, theta=-61.836401 -> V=1.0, theta=0.0
% INFO    : Bus 7896	: V=0.9827453, theta=-61.887323 -> V=1.0, theta=0.0
% INFO    : Bus 7897	: V=0.9777042, theta=-62.466049 -> V=1.0, theta=0.0
% INFO    : Bus 7898	: V=0.9900214, theta=-61.59249 -> V=1.0, theta=0.0
% INFO    : Bus 7899	: V=0.9945096, theta=-61.262298 -> V=1.0, theta=0.0
% INFO    : Bus 7900	: V=0.9791298, theta=-62.42267 -> V=1.0, theta=0.0
% INFO    : Bus 7901	: V=1.009322, theta=-59.288794 -> V=1.0, theta=0.0
% INFO    : Bus 7902	: V=0.9786991, theta=-62.108757 -> V=1.0, theta=0.0
% INFO    : Bus 7903	: V=0.9804644, theta=-62.032274 -> V=1.0, theta=0.0
% INFO    : Bus 7904	: V=0.984471, theta=-61.999446 -> V=1.0, theta=0.0
% INFO    : Bus 7905	: V=0.9979062, theta=-60.241162 -> V=1.0, theta=0.0
% INFO    : Bus 7906	: V=0.9769172, theta=-61.790496 -> V=1.0, theta=0.0
% INFO    : Bus 7907	: V=0.9782799, theta=-61.774601 -> V=1.0, theta=0.0
% INFO    : Bus 7908	: V=0.9922618, theta=-61.774323 -> V=1.0, theta=0.0
% INFO    : Bus 7909	: V=0.9993486, theta=-60.850354 -> V=1.0, theta=0.0
% INFO    : Bus 7910	: V=0.9923408, theta=-61.782197 -> V=1.0, theta=0.0
% INFO    : Bus 7911	: V=0.9886331, theta=-61.983835 -> V=1.0, theta=0.0
% INFO    : Bus 7912	: V=1.0074407, theta=-60.206628 -> V=1.0, theta=0.0
% INFO    : Bus 7913	: V=0.9868771, theta=-62.06189 -> V=1.0, theta=0.0
% INFO    : Bus 7914	: V=0.9923876, theta=-61.728533 -> V=1.0, theta=0.0
% INFO    : Bus 7915	: V=0.9868026, theta=-62.214891 -> V=1.0, theta=0.0
% INFO    : Bus 7916	: V=0.9843098, theta=-62.158336 -> V=1.0, theta=0.0
% INFO    : Bus 7917	: V=0.9825804, theta=-62.354467 -> V=1.0, theta=0.0
% INFO    : Bus 7918	: V=0.9790877, theta=-61.788855 -> V=1.0, theta=0.0
% INFO    : Bus 7919	: V=0.9785383, theta=-61.793745 -> V=1.0, theta=0.0
% INFO    : Bus 7920	: V=0.9776432, theta=-61.810462 -> V=1.0, theta=0.0
% INFO    : Bus 7921	: V=0.9852614, theta=-62.226949 -> V=1.0, theta=0.0
% INFO    : Bus 7922	: V=0.985661, theta=-62.197516 -> V=1.0, theta=0.0
% INFO    : Bus 7923	: V=0.9809508, theta=-62.678372 -> V=1.0, theta=0.0
% INFO    : Bus 7924	: V=0.9907555, theta=-61.559622 -> V=1.0, theta=0.0
% INFO    : Bus 7925	: V=0.9861816, theta=-62.156532 -> V=1.0, theta=0.0
% INFO    : Bus 7926	: V=0.9739042, theta=-63.70252 -> V=1.0, theta=0.0
% INFO    : Bus 7927	: V=0.9871388, theta=-62.091679 -> V=1.0, theta=0.0
% INFO    : Bus 7928	: V=0.9754884, theta=-63.435978 -> V=1.0, theta=0.0
% INFO    : Bus 7929	: V=0.9892961, theta=-61.927678 -> V=1.0, theta=0.0
% INFO    : Bus 7930	: V=0.9885134, theta=-61.986983 -> V=1.0, theta=0.0
% INFO    : Bus 7931	: V=0.9876082, theta=-61.741349 -> V=1.0, theta=0.0
% INFO    : Bus 7932	: V=0.981928, theta=-62.275258 -> V=1.0, theta=0.0
% INFO    : Bus 7933	: V=0.9826981, theta=-62.269371 -> V=1.0, theta=0.0
% INFO    : Bus 7934	: V=0.9872716, theta=-61.735702 -> V=1.0, theta=0.0
% INFO    : Bus 7935	: V=0.9752564, theta=-63.402483 -> V=1.0, theta=0.0
% INFO    : Bus 7936	: V=0.9763531, theta=-63.286431 -> V=1.0, theta=0.0
% INFO    : Bus 7937	: V=0.9812436, theta=-62.291587 -> V=1.0, theta=0.0
% INFO    : Bus 7938	: V=0.9806967, theta=-62.855115 -> V=1.0, theta=0.0
% INFO    : Bus 7939	: V=0.9843199, theta=-62.472506 -> V=1.0, theta=0.0
% INFO    : Bus 7940	: V=0.983036, theta=-62.605611 -> V=1.0, theta=0.0
% INFO    : Bus 7941	: V=0.9783228, theta=-63.101921 -> V=1.0, theta=0.0
% INFO    : Bus 7942	: V=0.9753488, theta=-61.404638 -> V=1.0, theta=0.0
% INFO    : Bus 7943	: V=0.9781295, theta=-61.265983 -> V=1.0, theta=0.0
% INFO    : Bus 7944	: V=0.9923892, theta=-60.206827 -> V=1.0, theta=0.0
% INFO    : Bus 7945	: V=0.9953131, theta=-59.890666 -> V=1.0, theta=0.0
% INFO    : Bus 7946	: V=0.981528, theta=-60.90702 -> V=1.0, theta=0.0
% INFO    : Bus 7947	: V=0.9927948, theta=-59.692332 -> V=1.0, theta=0.0
% INFO    : Bus 7948	: V=0.9908257, theta=-59.762442 -> V=1.0, theta=0.0
% INFO    : Bus 7949	: V=0.9916258, theta=-59.752848 -> V=1.0, theta=0.0
% INFO    : Bus 7950	: V=1.0016223, theta=-59.188094 -> V=1.0, theta=0.0
% INFO    : Bus 7951	: V=0.9915257, theta=-59.670187 -> V=1.0, theta=0.0
% INFO    : Bus 7952	: V=0.9821246, theta=-62.777931 -> V=1.0, theta=0.0
% INFO    : Bus 7953	: V=0.9815659, theta=-62.760526 -> V=1.0, theta=0.0
% INFO    : Bus 7954	: V=0.9790457, theta=-63.861517 -> V=1.0, theta=0.0
% INFO    : Bus 7955	: V=0.9811999, theta=-62.738752 -> V=1.0, theta=0.0
% INFO    : Bus 7956	: V=0.9766833, theta=-63.990327 -> V=1.0, theta=0.0
% INFO    : Bus 7957	: V=0.9740296, theta=-64.12122 -> V=1.0, theta=0.0
% INFO    : Bus 7958	: V=0.9729501, theta=-64.212097 -> V=1.0, theta=0.0
% INFO    : Bus 7959	: V=0.9695793, theta=-64.038417 -> V=1.0, theta=0.0
% INFO    : Bus 7960	: V=0.9700441, theta=-64.025447 -> V=1.0, theta=0.0
% INFO    : Bus 7961	: V=0.9689226, theta=-64.057397 -> V=1.0, theta=0.0
% INFO    : Bus 7962	: V=0.9708637, theta=-63.966248 -> V=1.0, theta=0.0
% INFO    : Bus 7963	: V=0.9719393, theta=-63.887485 -> V=1.0, theta=0.0
% INFO    : Bus 7964	: V=0.9723288, theta=-63.776504 -> V=1.0, theta=0.0
% INFO    : Bus 7965	: V=0.9736976, theta=-63.545939 -> V=1.0, theta=0.0
% INFO    : Bus 7966	: V=0.9725007, theta=-63.578991 -> V=1.0, theta=0.0
% INFO    : Bus 7967	: V=0.9694263, theta=-63.881989 -> V=1.0, theta=0.0
% INFO    : Bus 7968	: V=0.9702889, theta=-63.821159 -> V=1.0, theta=0.0
% INFO    : Bus 7969	: V=0.9761339, theta=-62.88347 -> V=1.0, theta=0.0
% INFO    : Bus 7970	: V=0.9763969, theta=-62.877747 -> V=1.0, theta=0.0
% INFO    : Bus 7971	: V=0.9776186, theta=-62.843808 -> V=1.0, theta=0.0
% INFO    : Bus 7972	: V=0.9834387, theta=-60.538187 -> V=1.0, theta=0.0
% INFO    : Bus 7973	: V=0.9820561, theta=-60.587552 -> V=1.0, theta=0.0
% INFO    : Bus 7974	: V=0.9842854, theta=-60.129398 -> V=1.0, theta=0.0
% INFO    : Bus 7975	: V=0.9847649, theta=-60.324756 -> V=1.0, theta=0.0
% INFO    : Bus 7976	: V=0.9949791, theta=-58.797412 -> V=1.0, theta=0.0
% INFO    : Bus 7977	: V=0.9961662, theta=-58.718422 -> V=1.0, theta=0.0
% INFO    : Bus 7978	: V=0.9910046, theta=-59.508685 -> V=1.0, theta=0.0
% INFO    : Bus 7979	: V=1.0083932, theta=-59.54747 -> V=1.0, theta=0.0
% INFO    : Bus 7980	: V=1.0066636, theta=-59.680692 -> V=1.0, theta=0.0
% INFO    : Bus 7981	: V=1.0021705, theta=-59.950591 -> V=1.0, theta=0.0
% INFO    : Bus 7982	: V=1.0048862, theta=-59.777585 -> V=1.0, theta=0.0
% INFO    : Bus 7983	: V=0.9868731, theta=-61.095904 -> V=1.0, theta=0.0
% INFO    : Bus 7984	: V=0.9923499, theta=-60.763184 -> V=1.0, theta=0.0
% INFO    : Bus 7985	: V=1.0054791, theta=-59.659512 -> V=1.0, theta=0.0
% INFO    : Bus 7986	: V=0.9871091, theta=-60.836971 -> V=1.0, theta=0.0
% INFO    : Bus 7987	: V=0.9804249, theta=-61.203887 -> V=1.0, theta=0.0
% INFO    : Bus 7988	: V=0.9815989, theta=-61.189325 -> V=1.0, theta=0.0
% INFO    : Bus 7989	: V=0.9830028, theta=-61.395582 -> V=1.0, theta=0.0
% INFO    : Bus 7990	: V=0.9861643, theta=-61.100025 -> V=1.0, theta=0.0
% INFO    : Bus 7991	: V=0.9828854, theta=-61.101403 -> V=1.0, theta=0.0
% INFO    : Bus 7992	: V=0.9822736, theta=-61.108294 -> V=1.0, theta=0.0
% INFO    : Bus 7993	: V=0.98114, theta=-61.053448 -> V=1.0, theta=0.0
% INFO    : Bus 7994	: V=0.9892004, theta=-60.891617 -> V=1.0, theta=0.0
% INFO    : Bus 7995	: V=0.9871611, theta=-60.950942 -> V=1.0, theta=0.0
% INFO    : Bus 7996	: V=0.9867677, theta=-60.342338 -> V=1.0, theta=0.0
% INFO    : Bus 7997	: V=1.0081269, theta=-59.434105 -> V=1.0, theta=0.0
% INFO    : Bus 7998	: V=1.0123146, theta=-59.24574 -> V=1.0, theta=0.0
% INFO    : Bus 7999	: V=1.0062696, theta=-59.473948 -> V=1.0, theta=0.0
% INFO    : Bus 8000	: V=1.0097303, theta=-59.394056 -> V=1.0, theta=0.0
% INFO    : Bus 8001	: V=1.0095192, theta=-59.368494 -> V=1.0, theta=0.0
% INFO    : Bus 8002	: V=1.0035188, theta=-59.560137 -> V=1.0, theta=0.0
% INFO    : Bus 8003	: V=0.9980703, theta=-59.672043 -> V=1.0, theta=0.0
% INFO    : Bus 8004	: V=0.9960042, theta=-60.154856 -> V=1.0, theta=0.0
% INFO    : Bus 8005	: V=0.9907398, theta=-60.114945 -> V=1.0, theta=0.0
% INFO    : Bus 8006	: V=0.9933947, theta=-59.84518 -> V=1.0, theta=0.0
% INFO    : Bus 8007	: V=0.9911386, theta=-60.190634 -> V=1.0, theta=0.0
% INFO    : Bus 8008	: V=1.0036199, theta=-59.35154 -> V=1.0, theta=0.0
% INFO    : Bus 8009	: V=1.0046365, theta=-59.34468 -> V=1.0, theta=0.0
% INFO    : Bus 8010	: V=0.9940835, theta=-60.217033 -> V=1.0, theta=0.0
% INFO    : Bus 8011	: V=0.9920826, theta=-60.242906 -> V=1.0, theta=0.0
% INFO    : Bus 8012	: V=0.9871841, theta=-60.336303 -> V=1.0, theta=0.0
% INFO    : Bus 8013	: V=1.0001483, theta=-59.64041 -> V=1.0, theta=0.0
% INFO    : Bus 8014	: V=1.0006293, theta=-59.636511 -> V=1.0, theta=0.0
% INFO    : Bus 8015	: V=1.0042005, theta=-59.238205 -> V=1.0, theta=0.0
% INFO    : Bus 8016	: V=1.0199264, theta=-58.059696 -> V=1.0, theta=0.0
% INFO    : Bus 8017	: V=0.9973532, theta=-59.627215 -> V=1.0, theta=0.0
% INFO    : Bus 8018	: V=1.0092907, theta=-59.051392 -> V=1.0, theta=0.0
% INFO    : Bus 8019	: V=1.0078293, theta=-59.110147 -> V=1.0, theta=0.0
% INFO    : Bus 8020	: V=1.0167818, theta=-58.367994 -> V=1.0, theta=0.0
% INFO    : Bus 8021	: V=1.0063006, theta=-59.159344 -> V=1.0, theta=0.0
% INFO    : Bus 8022	: V=1.0082408, theta=-59.062268 -> V=1.0, theta=0.0
% INFO    : Bus 8023	: V=0.9809632, theta=-61.634365 -> V=1.0, theta=0.0
% INFO    : Bus 8024	: V=0.98145, theta=-61.524504 -> V=1.0, theta=0.0
% INFO    : Bus 8025	: V=0.9810965, theta=-61.527742 -> V=1.0, theta=0.0
% INFO    : Bus 8026	: V=0.9820409, theta=-61.240733 -> V=1.0, theta=0.0
% INFO    : Bus 8027	: V=0.9833939, theta=-61.295401 -> V=1.0, theta=0.0
% INFO    : Bus 8028	: V=0.979896, theta=-61.080072 -> V=1.0, theta=0.0
% INFO    : Bus 8029	: V=0.9924656, theta=-59.697716 -> V=1.0, theta=0.0
% INFO    : Bus 8030	: V=0.9792443, theta=-61.657066 -> V=1.0, theta=0.0
% INFO    : Bus 8031	: V=0.9803887, theta=-61.639437 -> V=1.0, theta=0.0
% INFO    : Bus 8032	: V=0.9837388, theta=-61.535534 -> V=1.0, theta=0.0
% INFO    : Bus 8033	: V=1.0177657, theta=-58.549494 -> V=1.0, theta=0.0
% INFO    : Bus 8034	: V=0.9944097, theta=-59.679621 -> V=1.0, theta=0.0
% INFO    : Bus 8035	: V=0.9943041, theta=-59.671454 -> V=1.0, theta=0.0
% INFO    : Bus 8036	: V=0.9806974, theta=-61.707745 -> V=1.0, theta=0.0
% INFO    : Bus 8037	: V=0.9819647, theta=-61.648956 -> V=1.0, theta=0.0
% INFO    : Bus 8038	: V=0.9849656, theta=-60.477388 -> V=1.0, theta=0.0
% INFO    : Bus 8039	: V=0.9931181, theta=-59.65837 -> V=1.0, theta=0.0
% INFO    : Bus 8040	: V=0.9996609, theta=-59.134032 -> V=1.0, theta=0.0
% INFO    : Bus 8041	: V=0.9944347, theta=-59.641324 -> V=1.0, theta=0.0
% INFO    : Bus 8042	: V=0.9983406, theta=-59.266921 -> V=1.0, theta=0.0
% INFO    : Bus 8043	: V=1.009057, theta=-58.717497 -> V=1.0, theta=0.0
% INFO    : Bus 8044	: V=0.9890899, theta=-59.958172 -> V=1.0, theta=0.0
% INFO    : Bus 8045	: V=0.9906422, theta=-59.94753 -> V=1.0, theta=0.0
% INFO    : Bus 8046	: V=0.9887591, theta=-59.752838 -> V=1.0, theta=0.0
% INFO    : Bus 8047	: V=0.9933846, theta=-59.667863 -> V=1.0, theta=0.0
% INFO    : Bus 8048	: V=0.9884967, theta=-59.811545 -> V=1.0, theta=0.0
% INFO    : Bus 8049	: V=0.9990292, theta=-58.514736 -> V=1.0, theta=0.0
% INFO    : Bus 8050	: V=0.9891564, theta=-59.747046 -> V=1.0, theta=0.0
% INFO    : Bus 8051	: V=1.0035419, theta=-58.12607 -> V=1.0, theta=0.0
% INFO    : Bus 8052	: V=0.9951151, theta=-59.484618 -> V=1.0, theta=0.0
% INFO    : Bus 8053	: V=0.9939279, theta=-59.419536 -> V=1.0, theta=0.0
% INFO    : Bus 8054	: V=1.0084337, theta=-57.773061 -> V=1.0, theta=0.0
% INFO    : Bus 8055	: V=0.9928493, theta=-59.475324 -> V=1.0, theta=0.0
% INFO    : Bus 8056	: V=1.007557, theta=-57.804889 -> V=1.0, theta=0.0
% INFO    : Bus 8057	: V=0.9930067, theta=-59.382684 -> V=1.0, theta=0.0
% INFO    : Bus 8058	: V=0.9928466, theta=-59.379301 -> V=1.0, theta=0.0
% INFO    : Bus 8059	: V=0.9921371, theta=-59.625347 -> V=1.0, theta=0.0
% INFO    : Bus 8060	: V=0.9906933, theta=-59.643408 -> V=1.0, theta=0.0
% INFO    : Bus 8061	: V=0.9884628, theta=-59.794099 -> V=1.0, theta=0.0
% INFO    : Bus 8062	: V=0.9800329, theta=-60.63839 -> V=1.0, theta=0.0
% INFO    : Bus 8063	: V=0.9969718, theta=-59.426229 -> V=1.0, theta=0.0
% INFO    : Bus 8064	: V=0.9921123, theta=-59.565434 -> V=1.0, theta=0.0
% INFO    : Bus 8065	: V=0.9876625, theta=-60.394967 -> V=1.0, theta=0.0
% INFO    : Bus 8066	: V=0.9954932, theta=-59.444013 -> V=1.0, theta=0.0
% INFO    : Bus 8067	: V=0.9991211, theta=-59.249791 -> V=1.0, theta=0.0
% INFO    : Bus 8068	: V=0.9874653, theta=-59.88817 -> V=1.0, theta=0.0
% INFO    : Bus 8069	: V=0.986085, theta=-59.97331 -> V=1.0, theta=0.0
% INFO    : Bus 8070	: V=0.9837782, theta=-59.997681 -> V=1.0, theta=0.0
% INFO    : Bus 8071	: V=0.9852167, theta=-59.984838 -> V=1.0, theta=0.0
% INFO    : Bus 8072	: V=0.9906623, theta=-59.64567 -> V=1.0, theta=0.0
% INFO    : Bus 8073	: V=0.9870843, theta=-59.888092 -> V=1.0, theta=0.0
% INFO    : Bus 8074	: V=0.9866511, theta=-59.891819 -> V=1.0, theta=0.0
% INFO    : Bus 8075	: V=0.9807356, theta=-60.471045 -> V=1.0, theta=0.0
% INFO    : Bus 8076	: V=0.9772861, theta=-60.810796 -> V=1.0, theta=0.0
% INFO    : Bus 8077	: V=1.0136922, theta=-58.364015 -> V=1.0, theta=0.0
% INFO    : Bus 8078	: V=0.9941532, theta=-60.15639 -> V=1.0, theta=0.0
% INFO    : Bus 8079	: V=1.006992, theta=-58.991817 -> V=1.0, theta=0.0
% INFO    : Bus 8080	: V=1.0046569, theta=-59.156725 -> V=1.0, theta=0.0
% INFO    : Bus 8081	: V=0.9914474, theta=-60.368338 -> V=1.0, theta=0.0
% INFO    : Bus 8082	: V=0.9883001, theta=-60.660691 -> V=1.0, theta=0.0
% INFO    : Bus 8083	: V=0.9875881, theta=-60.891264 -> V=1.0, theta=0.0
% INFO    : Bus 8084	: V=0.9906054, theta=-60.771902 -> V=1.0, theta=0.0
% INFO    : Bus 8085	: V=1.0036174, theta=-60.028029 -> V=1.0, theta=0.0
% INFO    : Bus 8086	: V=0.9963459, theta=-60.445715 -> V=1.0, theta=0.0
% INFO    : Bus 8087	: V=1.0010761, theta=-60.134735 -> V=1.0, theta=0.0
% INFO    : Bus 8088	: V=1.0024483, theta=-60.192681 -> V=1.0, theta=0.0
% INFO    : Bus 8089	: V=0.9894732, theta=-60.573096 -> V=1.0, theta=0.0
% INFO    : Bus 8090	: V=0.9699266, theta=-61.310656 -> V=1.0, theta=0.0
% INFO    : Bus 8091	: V=0.9823281, theta=-60.959147 -> V=1.0, theta=0.0
% INFO    : Bus 8092	: V=0.9729473, theta=-61.171666 -> V=1.0, theta=0.0
% INFO    : Bus 8093	: V=0.9745744, theta=-61.003833 -> V=1.0, theta=0.0
% INFO    : Bus 8094	: V=0.9736934, theta=-61.08758 -> V=1.0, theta=0.0
% INFO    : Bus 8095	: V=0.9696274, theta=-61.200459 -> V=1.0, theta=0.0
% INFO    : Bus 8096	: V=0.9848825, theta=-60.925009 -> V=1.0, theta=0.0
% INFO    : Bus 8097	: V=0.9825014, theta=-60.957928 -> V=1.0, theta=0.0
% INFO    : Bus 8098	: V=0.9929268, theta=-60.6553 -> V=1.0, theta=0.0
% INFO    : Bus 8099	: V=0.9840961, theta=-61.069076 -> V=1.0, theta=0.0
% INFO    : Bus 8100	: V=0.986236, theta=-60.984591 -> V=1.0, theta=0.0
% INFO    : Bus 8101	: V=0.9896474, theta=-60.680473 -> V=1.0, theta=0.0
% INFO    : Bus 8102	: V=1.0025269, theta=-60.307865 -> V=1.0, theta=0.0
% INFO    : Bus 8103	: V=0.9824771, theta=-61.156477 -> V=1.0, theta=0.0
% INFO    : Bus 8104	: V=1.0054925, theta=-60.400246 -> V=1.0, theta=0.0
% INFO    : Bus 8105	: V=1.0041141, theta=-60.404428 -> V=1.0, theta=0.0
% INFO    : Bus 8106	: V=0.9905229, theta=-60.955289 -> V=1.0, theta=0.0
% INFO    : Bus 8107	: V=0.9957379, theta=-60.915058 -> V=1.0, theta=0.0
% INFO    : Bus 8108	: V=0.9823194, theta=-61.137402 -> V=1.0, theta=0.0
% INFO    : Bus 8109	: V=0.988048, theta=-62.064825 -> V=1.0, theta=0.0
% INFO    : Bus 8110	: V=0.9850784, theta=-63.973359 -> V=1.0, theta=0.0
% INFO    : Bus 8111	: V=0.991832, theta=-64.402856 -> V=1.0, theta=0.0
% INFO    : Bus 8112	: V=0.9762869, theta=-66.441655 -> V=1.0, theta=0.0
% INFO    : Bus 8113	: V=0.9744407, theta=-66.289793 -> V=1.0, theta=0.0
% INFO    : Bus 8114	: V=0.9905368, theta=-64.174717 -> V=1.0, theta=0.0
% INFO    : Bus 8115	: V=0.9745487, theta=-66.12529 -> V=1.0, theta=0.0
% INFO    : Bus 8116	: V=0.974544, theta=-65.990573 -> V=1.0, theta=0.0
% INFO    : Bus 8117	: V=0.9901022, theta=-63.911585 -> V=1.0, theta=0.0
% INFO    : Bus 8118	: V=0.9785903, theta=-65.098078 -> V=1.0, theta=0.0
% INFO    : Bus 8119	: V=0.9825513, theta=-64.434193 -> V=1.0, theta=0.0
% INFO    : Bus 8120	: V=0.9905933, theta=-63.586032 -> V=1.0, theta=0.0
% INFO    : Bus 8121	: V=0.9783467, theta=-64.302849 -> V=1.0, theta=0.0
% INFO    : Bus 8122	: V=0.9807736, theta=-64.154544 -> V=1.0, theta=0.0
% INFO    : Bus 8123	: V=0.9769695, theta=-65.212915 -> V=1.0, theta=0.0
% INFO    : Bus 8124	: V=0.9739931, theta=-65.619487 -> V=1.0, theta=0.0
% INFO    : Bus 8125	: V=0.9676421, theta=-65.442013 -> V=1.0, theta=0.0
% INFO    : Bus 8126	: V=0.9751642, theta=-65.350166 -> V=1.0, theta=0.0
% INFO    : Bus 8127	: V=0.973664, theta=-65.901669 -> V=1.0, theta=0.0
% INFO    : Bus 8128	: V=0.973314, theta=-66.09613 -> V=1.0, theta=0.0
% INFO    : Bus 8129	: V=0.9770862, theta=-66.102177 -> V=1.0, theta=0.0
% INFO    : Bus 8130	: V=0.9750678, theta=-66.263501 -> V=1.0, theta=0.0
% INFO    : Bus 8131	: V=0.9727069, theta=-66.474392 -> V=1.0, theta=0.0
% INFO    : Bus 8132	: V=0.9708114, theta=-66.634897 -> V=1.0, theta=0.0
% INFO    : Bus 8133	: V=0.9691211, theta=-66.842507 -> V=1.0, theta=0.0
% INFO    : Bus 8134	: V=0.962177, theta=-71.755971 -> V=1.0, theta=0.0
% INFO    : Bus 8135	: V=0.9654948, theta=-72.49347 -> V=1.0, theta=0.0
% INFO    : Bus 8136	: V=0.9557451, theta=-73.676357 -> V=1.0, theta=0.0
% INFO    : Bus 8137	: V=0.9404468, theta=-76.703202 -> V=1.0, theta=0.0
% INFO    : Bus 8138	: V=0.943436, theta=-76.460494 -> V=1.0, theta=0.0
% INFO    : Bus 8139	: V=0.9500107, theta=-77.037461 -> V=1.0, theta=0.0
% INFO    : Bus 8140	: V=0.9467149, theta=-78.272721 -> V=1.0, theta=0.0
% INFO    : Bus 8141	: V=0.9612467, theta=-73.344864 -> V=1.0, theta=0.0
% INFO    : Bus 8142	: V=0.9451706, theta=-78.666273 -> V=1.0, theta=0.0
% INFO    : Bus 8143	: V=0.9467109, theta=-78.545658 -> V=1.0, theta=0.0
% INFO    : Bus 8144	: V=0.997153, theta=-71.214101 -> V=1.0, theta=0.0
% INFO    : Bus 8145	: V=0.9973498, theta=-71.212576 -> V=1.0, theta=0.0
% INFO    : Bus 8146	: V=0.9962334, theta=-71.246605 -> V=1.0, theta=0.0
% INFO    : Bus 8147	: V=0.9945638, theta=-71.201267 -> V=1.0, theta=0.0
% INFO    : Bus 8148	: V=0.9935051, theta=-71.129058 -> V=1.0, theta=0.0
% INFO    : Bus 8149	: V=0.9918774, theta=-71.168498 -> V=1.0, theta=0.0
% INFO    : Bus 8150	: V=0.9964094, theta=-71.192868 -> V=1.0, theta=0.0
% INFO    : Bus 8151	: V=0.9973112, theta=-71.190825 -> V=1.0, theta=0.0
% INFO    : Bus 8152	: V=1.0005224, theta=-70.916021 -> V=1.0, theta=0.0
% INFO    : Bus 8153	: V=0.9901164, theta=-71.727249 -> V=1.0, theta=0.0
% INFO    : Bus 8154	: V=0.9934735, theta=-71.537512 -> V=1.0, theta=0.0
% INFO    : Bus 8155	: V=0.9961549, theta=-71.236957 -> V=1.0, theta=0.0
% INFO    : Bus 8156	: V=0.9931591, theta=-71.16916 -> V=1.0, theta=0.0
% INFO    : Bus 8157	: V=0.9832125, theta=-70.569761 -> V=1.0, theta=0.0
% INFO    : Bus 8158	: V=0.9917077, theta=-70.031978 -> V=1.0, theta=0.0
% INFO    : Bus 8159	: V=1.0156464, theta=-69.197532 -> V=1.0, theta=0.0
% INFO    : Bus 8160	: V=0.998756, theta=-70.395334 -> V=1.0, theta=0.0
% INFO    : Bus 8161	: V=0.9903959, theta=-70.583972 -> V=1.0, theta=0.0
% INFO    : Bus 8162	: V=0.9754287, theta=-71.399011 -> V=1.0, theta=0.0
% INFO    : Bus 8163	: V=0.9809814, theta=-70.142061 -> V=1.0, theta=0.0
% INFO    : Bus 8164	: V=0.9804546, theta=-69.790216 -> V=1.0, theta=0.0
% INFO    : Bus 8165	: V=0.9773343, theta=-68.995785 -> V=1.0, theta=0.0
% INFO    : Bus 8166	: V=1.0030893, theta=-69.030684 -> V=1.0, theta=0.0
% INFO    : Bus 8167	: V=0.9842897, theta=-64.956886 -> V=1.0, theta=0.0
% INFO    : Bus 8168	: V=0.9788219, theta=-65.335698 -> V=1.0, theta=0.0
% INFO    : Bus 8169	: V=0.9770106, theta=-65.437378 -> V=1.0, theta=0.0
% INFO    : Bus 8170	: V=0.9718368, theta=-65.536924 -> V=1.0, theta=0.0
% INFO    : Bus 8171	: V=0.9652754, theta=-66.308023 -> V=1.0, theta=0.0
% INFO    : Bus 8172	: V=0.9610981, theta=-66.427309 -> V=1.0, theta=0.0
% INFO    : Bus 8173	: V=0.9806782, theta=-64.282021 -> V=1.0, theta=0.0
% INFO    : Bus 8174	: V=0.9746108, theta=-64.736431 -> V=1.0, theta=0.0
% INFO    : Bus 8175	: V=0.9639501, theta=-66.32828 -> V=1.0, theta=0.0
% INFO    : Bus 8176	: V=0.9614036, theta=-66.830873 -> V=1.0, theta=0.0
% INFO    : Bus 8177	: V=0.9735081, theta=-65.638892 -> V=1.0, theta=0.0
% INFO    : Bus 8178	: V=0.9720568, theta=-65.709783 -> V=1.0, theta=0.0
% INFO    : Bus 8179	: V=0.963214, theta=-66.692842 -> V=1.0, theta=0.0
% INFO    : Bus 8180	: V=0.9630536, theta=-66.835351 -> V=1.0, theta=0.0
% INFO    : Bus 8181	: V=0.9703314, theta=-65.846612 -> V=1.0, theta=0.0
% INFO    : Bus 8182	: V=0.9641741, theta=-66.793778 -> V=1.0, theta=0.0
% INFO    : Bus 8183	: V=0.9645041, theta=-66.784452 -> V=1.0, theta=0.0
% INFO    : Bus 8184	: V=0.9641869, theta=-66.792712 -> V=1.0, theta=0.0
% INFO    : Bus 8185	: V=0.9637413, theta=-66.817747 -> V=1.0, theta=0.0
% INFO    : Bus 8186	: V=0.9634726, theta=-66.823381 -> V=1.0, theta=0.0
% INFO    : Bus 8187	: V=0.9641826, theta=-66.752895 -> V=1.0, theta=0.0
% INFO    : Bus 8188	: V=0.9643564, theta=-66.748024 -> V=1.0, theta=0.0
% INFO    : Bus 8189	: V=0.9636791, theta=-66.771725 -> V=1.0, theta=0.0
% INFO    : Bus 8190	: V=0.9698541, theta=-65.537887 -> V=1.0, theta=0.0
% INFO    : Bus 8191	: V=0.9606057, theta=-66.899163 -> V=1.0, theta=0.0
% INFO    : Bus 8192	: V=0.959431, theta=-66.870073 -> V=1.0, theta=0.0
% INFO    : Bus 8193	: V=0.9670775, theta=-66.237175 -> V=1.0, theta=0.0
% INFO    : Bus 8194	: V=0.9661642, theta=-65.576577 -> V=1.0, theta=0.0
% INFO    : Bus 8195	: V=0.9637748, theta=-65.701441 -> V=1.0, theta=0.0
% INFO    : Bus 8196	: V=0.9604057, theta=-65.772695 -> V=1.0, theta=0.0
% INFO    : Bus 8197	: V=0.9630604, theta=-65.697873 -> V=1.0, theta=0.0
% INFO    : Bus 8198	: V=0.9650646, theta=-65.924645 -> V=1.0, theta=0.0
% INFO    : Bus 8199	: V=0.9634385, theta=-65.878091 -> V=1.0, theta=0.0
% INFO    : Bus 8200	: V=0.9732211, theta=-64.450209 -> V=1.0, theta=0.0
% INFO    : Bus 8201	: V=0.9684677, theta=-64.714456 -> V=1.0, theta=0.0
% INFO    : Bus 8202	: V=0.9622104, theta=-65.222068 -> V=1.0, theta=0.0
% INFO    : Bus 8203	: V=0.9645018, theta=-65.014352 -> V=1.0, theta=0.0
% INFO    : Bus 8204	: V=0.9633874, theta=-65.495171 -> V=1.0, theta=0.0
% INFO    : Bus 8205	: V=0.9648291, theta=-65.751992 -> V=1.0, theta=0.0
% INFO    : Bus 8206	: V=0.9745446, theta=-64.857753 -> V=1.0, theta=0.0
% INFO    : Bus 8207	: V=0.967938, theta=-65.388403 -> V=1.0, theta=0.0
% INFO    : Bus 8208	: V=0.9801326, theta=-64.469472 -> V=1.0, theta=0.0
% INFO    : Bus 8209	: V=0.9761524, theta=-64.7674 -> V=1.0, theta=0.0
% INFO    : Bus 8210	: V=0.975549, theta=-65.527744 -> V=1.0, theta=0.0
% INFO    : Bus 8211	: V=0.9737042, theta=-64.876816 -> V=1.0, theta=0.0
% INFO    : Bus 8212	: V=0.9781271, theta=-64.209318 -> V=1.0, theta=0.0
% INFO    : Bus 8213	: V=0.9623029, theta=-65.323876 -> V=1.0, theta=0.0
% INFO    : Bus 8214	: V=0.9903871, theta=-69.725403 -> V=1.0, theta=0.0
% INFO    : Bus 8215	: V=0.991877, theta=-69.645275 -> V=1.0, theta=0.0
% INFO    : Bus 8216	: V=0.996307, theta=-68.391746 -> V=1.0, theta=0.0
% INFO    : Bus 8217	: V=0.9969696, theta=-68.253703 -> V=1.0, theta=0.0
% INFO    : Bus 8218	: V=1.0119707, theta=-65.182929 -> V=1.0, theta=0.0
% INFO    : Bus 8219	: V=0.991372, theta=-69.770308 -> V=1.0, theta=0.0
% INFO    : Bus 8220	: V=0.9857643, theta=-70.301176 -> V=1.0, theta=0.0
% INFO    : Bus 8221	: V=0.9958251, theta=-68.494027 -> V=1.0, theta=0.0
% INFO    : Bus 8222	: V=0.9965192, theta=-69.682885 -> V=1.0, theta=0.0
% INFO    : Bus 8223	: V=0.9931669, theta=-69.738057 -> V=1.0, theta=0.0
% INFO    : Bus 8224	: V=0.9989161, theta=-69.655957 -> V=1.0, theta=0.0
% INFO    : Bus 8225	: V=1.0037678, theta=-69.592889 -> V=1.0, theta=0.0
% INFO    : Bus 8226	: V=0.9867997, theta=-70.286709 -> V=1.0, theta=0.0
% INFO    : Bus 8227	: V=0.9854105, theta=-70.56068 -> V=1.0, theta=0.0
% INFO    : Bus 8228	: V=0.9904968, theta=-70.225314 -> V=1.0, theta=0.0
% INFO    : Bus 8229	: V=0.9596766, theta=-71.99622 -> V=1.0, theta=0.0
% INFO    : Bus 8230	: V=0.9681415, theta=-71.656422 -> V=1.0, theta=0.0
% INFO    : Bus 8231	: V=0.9715831, theta=-70.877031 -> V=1.0, theta=0.0
% INFO    : Bus 8232	: V=0.9688209, theta=-71.335586 -> V=1.0, theta=0.0
% INFO    : Bus 8233	: V=0.9860194, theta=-70.056837 -> V=1.0, theta=0.0
% INFO    : Bus 8234	: V=0.98541, theta=-70.060727 -> V=1.0, theta=0.0
% INFO    : Bus 8235	: V=0.9791995, theta=-70.433067 -> V=1.0, theta=0.0
% INFO    : Bus 8236	: V=0.9682458, theta=-70.956357 -> V=1.0, theta=0.0
% INFO    : Bus 8237	: V=0.9639199, theta=-72.300314 -> V=1.0, theta=0.0
% INFO    : Bus 8238	: V=0.9725564, theta=-71.543095 -> V=1.0, theta=0.0
% INFO    : Bus 8239	: V=0.9613749, theta=-72.310511 -> V=1.0, theta=0.0
% INFO    : Bus 8240	: V=0.9717099, theta=-70.562023 -> V=1.0, theta=0.0
% INFO    : Bus 8241	: V=0.9693319, theta=-70.578354 -> V=1.0, theta=0.0
% INFO    : Bus 8242	: V=0.9771011, theta=-70.403525 -> V=1.0, theta=0.0
% INFO    : Bus 8243	: V=0.9889655, theta=-69.279388 -> V=1.0, theta=0.0
% INFO    : Bus 8244	: V=0.9715656, theta=-71.270834 -> V=1.0, theta=0.0
% INFO    : Bus 8245	: V=0.962089, theta=-71.430151 -> V=1.0, theta=0.0
% INFO    : Bus 8246	: V=0.9682683, theta=-71.589434 -> V=1.0, theta=0.0
% INFO    : Bus 8247	: V=0.9623287, theta=-73.050839 -> V=1.0, theta=0.0
% INFO    : Bus 8248	: V=0.9655181, theta=-71.880044 -> V=1.0, theta=0.0
% INFO    : Bus 8249	: V=0.9652009, theta=-71.88759 -> V=1.0, theta=0.0
% INFO    : Bus 8250	: V=1.0088788, theta=-64.260984 -> V=1.0, theta=0.0
% INFO    : Bus 8251	: V=1.0050102, theta=-64.428155 -> V=1.0, theta=0.0
% INFO    : Bus 8252	: V=1.0004521, theta=-64.597114 -> V=1.0, theta=0.0
% INFO    : Bus 8253	: V=0.9977948, theta=-64.629684 -> V=1.0, theta=0.0
% INFO    : Bus 8254	: V=0.9829992, theta=-67.799208 -> V=1.0, theta=0.0
% INFO    : Bus 8255	: V=0.9859781, theta=-65.441021 -> V=1.0, theta=0.0
% INFO    : Bus 8256	: V=0.9997278, theta=-63.740521 -> V=1.0, theta=0.0
% INFO    : Bus 8257	: V=1.0017652, theta=-63.228602 -> V=1.0, theta=0.0
% INFO    : Bus 8258	: V=1.0026637, theta=-63.806132 -> V=1.0, theta=0.0
% INFO    : Bus 8259	: V=0.9925393, theta=-64.776727 -> V=1.0, theta=0.0
% INFO    : Bus 8260	: V=0.9813344, theta=-66.150621 -> V=1.0, theta=0.0
% INFO    : Bus 8261	: V=0.9987515, theta=-61.850752 -> V=1.0, theta=0.0
% INFO    : Bus 8262	: V=0.9985658, theta=-62.571398 -> V=1.0, theta=0.0
% INFO    : Bus 8263	: V=0.9770557, theta=-65.918543 -> V=1.0, theta=0.0
% INFO    : Bus 8264	: V=0.9798438, theta=-65.209164 -> V=1.0, theta=0.0
% INFO    : Bus 8265	: V=0.9800152, theta=-65.076393 -> V=1.0, theta=0.0
% INFO    : Bus 8266	: V=0.9811619, theta=-64.213703 -> V=1.0, theta=0.0
% INFO    : Bus 8267	: V=0.9964447, theta=-60.409142 -> V=1.0, theta=0.0
% INFO    : Bus 8268	: V=0.9950288, theta=-59.203966 -> V=1.0, theta=0.0
% INFO    : Bus 8269	: V=0.9884252, theta=-61.377075 -> V=1.0, theta=0.0
% INFO    : Bus 8270	: V=0.9840202, theta=-63.155318 -> V=1.0, theta=0.0
% INFO    : Bus 8271	: V=0.9833755, theta=-62.762682 -> V=1.0, theta=0.0
% INFO    : Bus 8272	: V=0.9886459, theta=-64.131861 -> V=1.0, theta=0.0
% INFO    : Bus 8273	: V=0.9886712, theta=-64.131814 -> V=1.0, theta=0.0
% INFO    : Bus 8274	: V=0.9885173, theta=-64.135874 -> V=1.0, theta=0.0
% INFO    : Bus 8275	: V=0.9910366, theta=-63.564901 -> V=1.0, theta=0.0
% INFO    : Bus 8276	: V=0.9878552, theta=-64.231825 -> V=1.0, theta=0.0
% INFO    : Bus 8277	: V=0.9868526, theta=-64.483074 -> V=1.0, theta=0.0
% INFO    : Bus 8278	: V=0.9916238, theta=-63.458414 -> V=1.0, theta=0.0
% INFO    : Bus 8279	: V=0.9889618, theta=-64.111393 -> V=1.0, theta=0.0
% INFO    : Bus 8280	: V=0.9891772, theta=-64.08171 -> V=1.0, theta=0.0
% INFO    : Bus 8281	: V=0.989271, theta=-64.060967 -> V=1.0, theta=0.0
% INFO    : Bus 8282	: V=0.9893676, theta=-64.045279 -> V=1.0, theta=0.0
% INFO    : Bus 8283	: V=0.9880354, theta=-64.286076 -> V=1.0, theta=0.0
% INFO    : Bus 8284	: V=0.9901189, theta=-63.898945 -> V=1.0, theta=0.0
% INFO    : Bus 8285	: V=0.9899563, theta=-63.925457 -> V=1.0, theta=0.0
% INFO    : Bus 8286	: V=0.9966027, theta=-62.522431 -> V=1.0, theta=0.0
% INFO    : Bus 8287	: V=0.9896458, theta=-63.990891 -> V=1.0, theta=0.0
% INFO    : Bus 8288	: V=0.9966224, theta=-62.526424 -> V=1.0, theta=0.0
% INFO    : Bus 8289	: V=0.9892364, theta=-64.068831 -> V=1.0, theta=0.0
% INFO    : Bus 8290	: V=0.9836672, theta=-65.05531 -> V=1.0, theta=0.0
% INFO    : Bus 8291	: V=0.9892047, theta=-64.077979 -> V=1.0, theta=0.0
% INFO    : Bus 8292	: V=0.9885693, theta=-64.128312 -> V=1.0, theta=0.0
% INFO    : Bus 8293	: V=0.9828428, theta=-65.096904 -> V=1.0, theta=0.0
% INFO    : Bus 8294	: V=0.986667, theta=-64.511679 -> V=1.0, theta=0.0
% INFO    : Bus 8295	: V=0.9868696, theta=-64.479265 -> V=1.0, theta=0.0
% INFO    : Bus 8296	: V=0.9834933, theta=-65.079257 -> V=1.0, theta=0.0
% INFO    : Bus 8297	: V=0.9813813, theta=-65.395501 -> V=1.0, theta=0.0
% INFO    : Bus 8298	: V=0.9821879, theta=-65.348797 -> V=1.0, theta=0.0
% INFO    : Bus 8299	: V=0.9818375, theta=-65.366318 -> V=1.0, theta=0.0
% INFO    : Bus 8300	: V=0.9816199, theta=-65.38955 -> V=1.0, theta=0.0
% INFO    : Bus 8301	: V=0.9810923, theta=-65.405666 -> V=1.0, theta=0.0
% INFO    : Bus 8302	: V=0.9812462, theta=-65.403923 -> V=1.0, theta=0.0
% INFO    : Bus 8303	: V=0.9895808, theta=-64.002527 -> V=1.0, theta=0.0
% INFO    : Bus 8304	: V=0.9879673, theta=-64.268109 -> V=1.0, theta=0.0
% INFO    : Bus 8305	: V=0.996819, theta=-62.48548 -> V=1.0, theta=0.0
% INFO    : Bus 8306	: V=0.9967886, theta=-62.478184 -> V=1.0, theta=0.0
% INFO    : Bus 8307	: V=0.9898426, theta=-63.706253 -> V=1.0, theta=0.0
% INFO    : Bus 8308	: V=0.9876559, theta=-64.022236 -> V=1.0, theta=0.0
% INFO    : Bus 8309	: V=0.9833142, theta=-64.913997 -> V=1.0, theta=0.0
% INFO    : Bus 8310	: V=0.9874229, theta=-64.133824 -> V=1.0, theta=0.0
% INFO    : Bus 8311	: V=0.9828171, theta=-64.98757 -> V=1.0, theta=0.0
% INFO    : Bus 8312	: V=0.9874462, theta=-64.074261 -> V=1.0, theta=0.0
% INFO    : Bus 8313	: V=0.9834986, theta=-64.90942 -> V=1.0, theta=0.0
% INFO    : Bus 8314	: V=0.9867513, theta=-64.312757 -> V=1.0, theta=0.0
% INFO    : Bus 8315	: V=0.9865636, theta=-64.391788 -> V=1.0, theta=0.0
% INFO    : Bus 8316	: V=0.983979, theta=-64.890113 -> V=1.0, theta=0.0
% INFO    : Bus 8317	: V=0.9818574, theta=-65.246229 -> V=1.0, theta=0.0
% INFO    : Bus 8318	: V=0.9868567, theta=-64.448536 -> V=1.0, theta=0.0
% INFO    : Bus 8319	: V=0.9814481, theta=-65.255808 -> V=1.0, theta=0.0
% INFO    : Bus 8320	: V=0.9833816, theta=-65.073708 -> V=1.0, theta=0.0
% INFO    : Bus 8321	: V=0.9848708, theta=-64.772449 -> V=1.0, theta=0.0
% INFO    : Bus 8322	: V=0.985254, theta=-64.728834 -> V=1.0, theta=0.0
% INFO    : Bus 8323	: V=0.9857798, theta=-64.639347 -> V=1.0, theta=0.0
% INFO    : Bus 8324	: V=0.9976581, theta=-62.419501 -> V=1.0, theta=0.0
% INFO    : Bus 8325	: V=0.9812468, theta=-65.415083 -> V=1.0, theta=0.0
% INFO    : Bus 8326	: V=0.9813089, theta=-65.42973 -> V=1.0, theta=0.0
% INFO    : Bus 8327	: V=0.9838833, theta=-64.907242 -> V=1.0, theta=0.0
% INFO    : Bus 8328	: V=0.9841699, theta=-64.864682 -> V=1.0, theta=0.0
% INFO    : Bus 8329	: V=0.9808067, theta=-65.42641 -> V=1.0, theta=0.0
% INFO    : Bus 8330	: V=0.9806949, theta=-65.429441 -> V=1.0, theta=0.0
% INFO    : Bus 8331	: V=0.9844903, theta=-64.725321 -> V=1.0, theta=0.0
% INFO    : Bus 8332	: V=0.9783559, theta=-65.917279 -> V=1.0, theta=0.0
% INFO    : Bus 8333	: V=0.9844502, theta=-64.82274 -> V=1.0, theta=0.0
% INFO    : Bus 8334	: V=0.9815796, theta=-65.367562 -> V=1.0, theta=0.0
% INFO    : Bus 8335	: V=0.9818564, theta=-65.346767 -> V=1.0, theta=0.0
% INFO    : Bus 8336	: V=0.9853157, theta=-64.606775 -> V=1.0, theta=0.0
% INFO    : Bus 8337	: V=0.9832232, theta=-65.071663 -> V=1.0, theta=0.0
% INFO    : Bus 8338	: V=0.9848082, theta=-64.676126 -> V=1.0, theta=0.0
% INFO    : Bus 8339	: V=0.9848394, theta=-64.673205 -> V=1.0, theta=0.0
% INFO    : Bus 8340	: V=0.9851565, theta=-64.624873 -> V=1.0, theta=0.0
% INFO    : Bus 8341	: V=0.9784798, theta=-65.689755 -> V=1.0, theta=0.0
% INFO    : Bus 8342	: V=0.9854768, theta=-64.575665 -> V=1.0, theta=0.0
% INFO    : Bus 8343	: V=0.9857558, theta=-64.547913 -> V=1.0, theta=0.0
% INFO    : Bus 8344	: V=0.9864938, theta=-64.448333 -> V=1.0, theta=0.0
% INFO    : Bus 8345	: V=0.9860057, theta=-64.507153 -> V=1.0, theta=0.0
% INFO    : Bus 8346	: V=0.9827598, theta=-65.154049 -> V=1.0, theta=0.0
% INFO    : Bus 8347	: V=0.9822383, theta=-65.042063 -> V=1.0, theta=0.0
% INFO    : Bus 8348	: V=0.9843457, theta=-64.614161 -> V=1.0, theta=0.0
% INFO    : Bus 8349	: V=0.9846829, theta=-64.588414 -> V=1.0, theta=0.0
% INFO    : Bus 8350	: V=0.985302, theta=-64.536008 -> V=1.0, theta=0.0
% INFO    : Bus 8351	: V=0.9848187, theta=-64.606507 -> V=1.0, theta=0.0
% INFO    : Bus 8352	: V=0.9840371, theta=-64.73138 -> V=1.0, theta=0.0
% INFO    : Bus 8353	: V=0.9779545, theta=-65.928232 -> V=1.0, theta=0.0
% INFO    : Bus 8354	: V=0.9789751, theta=-65.657202 -> V=1.0, theta=0.0
% INFO    : Bus 8355	: V=0.9774443, theta=-65.815157 -> V=1.0, theta=0.0
% INFO    : Bus 8356	: V=0.9763771, theta=-65.920799 -> V=1.0, theta=0.0
% INFO    : Bus 8357	: V=0.9769867, theta=-65.860926 -> V=1.0, theta=0.0
% INFO    : Bus 8358	: V=0.976803, theta=-65.651613 -> V=1.0, theta=0.0
% INFO    : Bus 8359	: V=0.9768767, theta=-65.637451 -> V=1.0, theta=0.0
% INFO    : Bus 8360	: V=0.9752821, theta=-66.025702 -> V=1.0, theta=0.0
% INFO    : Bus 8361	: V=0.9767935, theta=-65.662739 -> V=1.0, theta=0.0
% INFO    : Bus 8362	: V=0.9775789, theta=-65.822827 -> V=1.0, theta=0.0
% INFO    : Bus 8363	: V=0.976811, theta=-65.876757 -> V=1.0, theta=0.0
% INFO    : Bus 8364	: V=0.9780002, theta=-65.775282 -> V=1.0, theta=0.0
% INFO    : Bus 8365	: V=0.9749501, theta=-66.052215 -> V=1.0, theta=0.0
% INFO    : Bus 8366	: V=0.9843768, theta=-64.671726 -> V=1.0, theta=0.0
% INFO    : Bus 8367	: V=0.9800672, theta=-65.371608 -> V=1.0, theta=0.0
% INFO    : Bus 8368	: V=0.9808528, theta=-65.12318 -> V=1.0, theta=0.0
% INFO    : Bus 8369	: V=0.9808766, theta=-65.349707 -> V=1.0, theta=0.0
% INFO    : Bus 8370	: V=0.979314, theta=-65.355036 -> V=1.0, theta=0.0
% INFO    : Bus 8371	: V=0.9779891, theta=-65.500695 -> V=1.0, theta=0.0
% INFO    : Bus 8372	: V=0.9774327, theta=-65.559942 -> V=1.0, theta=0.0
% INFO    : Bus 8373	: V=0.9771864, theta=-65.784321 -> V=1.0, theta=0.0
% INFO    : Bus 8374	: V=0.9847565, theta=-64.890727 -> V=1.0, theta=0.0
% INFO    : Bus 8375	: V=0.9786027, theta=-65.637918 -> V=1.0, theta=0.0
% INFO    : Bus 8376	: V=0.9776153, theta=-65.667232 -> V=1.0, theta=0.0
% INFO    : Bus 8377	: V=0.9780421, theta=-65.994857 -> V=1.0, theta=0.0
% INFO    : Bus 8378	: V=0.9754567, theta=-65.926373 -> V=1.0, theta=0.0
% INFO    : Bus 8379	: V=0.9765185, theta=-65.903983 -> V=1.0, theta=0.0
% INFO    : Bus 8380	: V=0.9804721, theta=-64.951049 -> V=1.0, theta=0.0
% INFO    : Bus 8381	: V=0.9802515, theta=-64.979691 -> V=1.0, theta=0.0
% INFO    : Bus 8382	: V=0.9802002, theta=-64.988822 -> V=1.0, theta=0.0
% INFO    : Bus 8383	: V=0.9772441, theta=-65.443286 -> V=1.0, theta=0.0
% INFO    : Bus 8384	: V=0.976609, theta=-65.473899 -> V=1.0, theta=0.0
% INFO    : Bus 8385	: V=0.9779039, theta=-65.4412 -> V=1.0, theta=0.0
% INFO    : Bus 8386	: V=0.980688, theta=-64.942461 -> V=1.0, theta=0.0
% INFO    : Bus 8387	: V=0.9836421, theta=-64.861176 -> V=1.0, theta=0.0
% INFO    : Bus 8388	: V=0.9784499, theta=-65.984598 -> V=1.0, theta=0.0
% INFO    : Bus 8389	: V=0.9839297, theta=-64.8914 -> V=1.0, theta=0.0
% INFO    : Bus 8390	: V=0.978584, theta=-65.385581 -> V=1.0, theta=0.0
% INFO    : Bus 8391	: V=0.9818121, theta=-64.796677 -> V=1.0, theta=0.0
% INFO    : Bus 8392	: V=0.982651, theta=-64.678441 -> V=1.0, theta=0.0
% INFO    : Bus 8393	: V=0.9827288, theta=-64.69942 -> V=1.0, theta=0.0
% INFO    : Bus 8394	: V=0.9831098, theta=-64.644417 -> V=1.0, theta=0.0
% INFO    : Bus 8395	: V=0.9832517, theta=-64.55371 -> V=1.0, theta=0.0
% INFO    : Bus 8396	: V=0.9832561, theta=-64.61629 -> V=1.0, theta=0.0
% INFO    : Bus 8397	: V=0.9814847, theta=-65.103433 -> V=1.0, theta=0.0
% INFO    : Bus 8398	: V=0.9830769, theta=-64.722354 -> V=1.0, theta=0.0
% INFO    : Bus 8399	: V=0.9828941, theta=-64.716818 -> V=1.0, theta=0.0
% INFO    : Bus 8400	: V=0.9828376, theta=-64.704865 -> V=1.0, theta=0.0
% INFO    : Bus 8401	: V=0.977407, theta=-65.714795 -> V=1.0, theta=0.0
% INFO    : Bus 8402	: V=0.9822783, theta=-64.848241 -> V=1.0, theta=0.0
% INFO    : Bus 8403	: V=0.9815671, theta=-64.96473 -> V=1.0, theta=0.0
% INFO    : Bus 8404	: V=0.9829707, theta=-64.714016 -> V=1.0, theta=0.0
% INFO    : Bus 8405	: V=0.9831497, theta=-64.78481 -> V=1.0, theta=0.0
% INFO    : Bus 8406	: V=0.980327, theta=-65.161365 -> V=1.0, theta=0.0
% INFO    : Bus 8407	: V=0.9800099, theta=-65.328352 -> V=1.0, theta=0.0
% INFO    : Bus 8408	: V=0.9834888, theta=-64.677612 -> V=1.0, theta=0.0
% INFO    : Bus 8409	: V=0.9841553, theta=-64.626226 -> V=1.0, theta=0.0
% INFO    : Bus 8410	: V=0.9973325, theta=-62.419988 -> V=1.0, theta=0.0
% INFO    : Bus 8411	: V=0.9912629, theta=-63.735856 -> V=1.0, theta=0.0
% INFO    : Bus 8412	: V=0.9903315, theta=-63.412858 -> V=1.0, theta=0.0
% INFO    : Bus 8413	: V=0.9897396, theta=-63.558051 -> V=1.0, theta=0.0
% INFO    : Bus 8414	: V=0.9846189, theta=-64.608525 -> V=1.0, theta=0.0
% INFO    : Bus 8415	: V=0.9883227, theta=-63.86115 -> V=1.0, theta=0.0
% INFO    : Bus 8416	: V=0.9838573, theta=-64.637776 -> V=1.0, theta=0.0
% INFO    : Bus 8417	: V=0.984315, theta=-64.581976 -> V=1.0, theta=0.0
% INFO    : Bus 8418	: V=0.9847989, theta=-64.52307 -> V=1.0, theta=0.0
% INFO    : Bus 8419	: V=0.983208, theta=-64.708572 -> V=1.0, theta=0.0
% INFO    : Bus 8420	: V=0.9841252, theta=-64.468045 -> V=1.0, theta=0.0
% INFO    : Bus 8421	: V=0.983661, theta=-64.549377 -> V=1.0, theta=0.0
% INFO    : Bus 8422	: V=0.9851139, theta=-64.466759 -> V=1.0, theta=0.0
% INFO    : Bus 8423	: V=0.9848612, theta=-64.343974 -> V=1.0, theta=0.0
% INFO    : Bus 8424	: V=0.992965, theta=-63.046055 -> V=1.0, theta=0.0
% INFO    : Bus 8425	: V=0.9855634, theta=-63.761774 -> V=1.0, theta=0.0
% INFO    : Bus 8426	: V=0.9918019, theta=-63.306452 -> V=1.0, theta=0.0
% INFO    : Bus 8427	: V=0.9912374, theta=-63.25178 -> V=1.0, theta=0.0
% INFO    : Bus 8428	: V=0.9922366, theta=-63.256812 -> V=1.0, theta=0.0
% INFO    : Bus 8429	: V=0.9952148, theta=-62.767147 -> V=1.0, theta=0.0
% INFO    : Bus 8430	: V=0.9956334, theta=-62.697074 -> V=1.0, theta=0.0
% INFO    : Bus 8431	: V=0.9898058, theta=-63.207472 -> V=1.0, theta=0.0
% INFO    : Bus 8432	: V=0.988086, theta=-63.387264 -> V=1.0, theta=0.0
% INFO    : Bus 8433	: V=0.9851937, theta=-64.156371 -> V=1.0, theta=0.0
% INFO    : Bus 8434	: V=0.9865295, theta=-63.823222 -> V=1.0, theta=0.0
% INFO    : Bus 8435	: V=0.9799599, theta=-64.972329 -> V=1.0, theta=0.0
% INFO    : Bus 8436	: V=0.9865177, theta=-63.793167 -> V=1.0, theta=0.0
% INFO    : Bus 8437	: V=0.9868899, theta=-63.724439 -> V=1.0, theta=0.0
% INFO    : Bus 8438	: V=0.9840019, theta=-64.397949 -> V=1.0, theta=0.0
% INFO    : Bus 8439	: V=0.9841737, theta=-64.139933 -> V=1.0, theta=0.0
% INFO    : Bus 8440	: V=0.9684432, theta=-66.68374 -> V=1.0, theta=0.0
% INFO    : Bus 8441	: V=0.9737109, theta=-65.821241 -> V=1.0, theta=0.0
% INFO    : Bus 8442	: V=0.9744006, theta=-65.557883 -> V=1.0, theta=0.0
% INFO    : Bus 8443	: V=0.9788125, theta=-65.581697 -> V=1.0, theta=0.0
% INFO    : Bus 8444	: V=0.9709589, theta=-65.851208 -> V=1.0, theta=0.0
% INFO    : Bus 8445	: V=0.9804355, theta=-65.063814 -> V=1.0, theta=0.0
% INFO    : Bus 8446	: V=0.9708376, theta=-66.616299 -> V=1.0, theta=0.0
% INFO    : Bus 8447	: V=0.9828378, theta=-64.600433 -> V=1.0, theta=0.0
% INFO    : Bus 8448	: V=0.9715436, theta=-65.906489 -> V=1.0, theta=0.0
% INFO    : Bus 8449	: V=0.9818968, theta=-64.587612 -> V=1.0, theta=0.0
% INFO    : Bus 8450	: V=0.9827803, theta=-64.382787 -> V=1.0, theta=0.0
% INFO    : Bus 8451	: V=0.9779979, theta=-63.892128 -> V=1.0, theta=0.0
% INFO    : Bus 8452	: V=0.9709396, theta=-65.86908 -> V=1.0, theta=0.0
% INFO    : Bus 8453	: V=0.9892232, theta=-63.22074 -> V=1.0, theta=0.0
% INFO    : Bus 8454	: V=0.9899447, theta=-63.121097 -> V=1.0, theta=0.0
% INFO    : Bus 8455	: V=0.9915902, theta=-62.910372 -> V=1.0, theta=0.0
% INFO    : Bus 8456	: V=0.9905711, theta=-63.041392 -> V=1.0, theta=0.0
% INFO    : Bus 8457	: V=0.9914163, theta=-62.889028 -> V=1.0, theta=0.0
% INFO    : Bus 8458	: V=0.9913731, theta=-62.857267 -> V=1.0, theta=0.0
% INFO    : Bus 8459	: V=0.9932917, theta=-62.673083 -> V=1.0, theta=0.0
% INFO    : Bus 8460	: V=0.9914167, theta=-62.835935 -> V=1.0, theta=0.0
% INFO    : Bus 8461	: V=0.9877124, theta=-63.083417 -> V=1.0, theta=0.0
% INFO    : Bus 8462	: V=0.9992349, theta=-61.891717 -> V=1.0, theta=0.0
% INFO    : Bus 8463	: V=1.0076262, theta=-61.083564 -> V=1.0, theta=0.0
% INFO    : Bus 8464	: V=1.0066144, theta=-61.282832 -> V=1.0, theta=0.0
% INFO    : Bus 8465	: V=0.992869, theta=-62.464462 -> V=1.0, theta=0.0
% INFO    : Bus 8466	: V=0.9941159, theta=-62.452425 -> V=1.0, theta=0.0
% INFO    : Bus 8467	: V=1.0033955, theta=-61.515062 -> V=1.0, theta=0.0
% INFO    : Bus 8468	: V=1.0045268, theta=-61.429743 -> V=1.0, theta=0.0
% INFO    : Bus 8469	: V=1.0058808, theta=-61.304509 -> V=1.0, theta=0.0
% INFO    : Bus 8470	: V=1.0036848, theta=-61.456001 -> V=1.0, theta=0.0
% INFO    : Bus 8471	: V=0.9911005, theta=-62.417929 -> V=1.0, theta=0.0
% INFO    : Bus 8472	: V=0.9927079, theta=-62.442816 -> V=1.0, theta=0.0
% INFO    : Bus 8473	: V=1.0012663, theta=-61.756253 -> V=1.0, theta=0.0
% INFO    : Bus 8474	: V=1.0015343, theta=-61.655104 -> V=1.0, theta=0.0
% INFO    : Bus 8475	: V=0.9918532, theta=-62.445856 -> V=1.0, theta=0.0
% INFO    : Bus 8476	: V=0.9710171, theta=-65.073579 -> V=1.0, theta=0.0
% INFO    : Bus 8477	: V=0.9924625, theta=-62.617813 -> V=1.0, theta=0.0
% INFO    : Bus 8478	: V=0.967238, theta=-65.472457 -> V=1.0, theta=0.0
% INFO    : Bus 8479	: V=0.9651405, theta=-65.495591 -> V=1.0, theta=0.0
% INFO    : Bus 8480	: V=0.9947636, theta=-62.363019 -> V=1.0, theta=0.0
% INFO    : Bus 8481	: V=0.9669067, theta=-65.476627 -> V=1.0, theta=0.0
% INFO    : Bus 8482	: V=0.9656207, theta=-65.517389 -> V=1.0, theta=0.0
% INFO    : Bus 8483	: V=0.9735202, theta=-64.021841 -> V=1.0, theta=0.0
% INFO    : Bus 8484	: V=0.959229, theta=-66.139598 -> V=1.0, theta=0.0
% INFO    : Bus 8485	: V=0.9608562, theta=-66.098225 -> V=1.0, theta=0.0
% INFO    : Bus 8486	: V=0.9646397, theta=-65.528023 -> V=1.0, theta=0.0
% INFO    : Bus 8487	: V=0.9585699, theta=-66.156816 -> V=1.0, theta=0.0
% INFO    : Bus 8488	: V=0.9737882, theta=-66.046706 -> V=1.0, theta=0.0
% INFO    : Bus 8489	: V=0.9856437, theta=-64.215843 -> V=1.0, theta=0.0
% INFO    : Bus 8490	: V=0.983133, theta=-63.750061 -> V=1.0, theta=0.0
% INFO    : Bus 8491	: V=0.9814879, theta=-64.849162 -> V=1.0, theta=0.0
% INFO    : Bus 8492	: V=0.9989834, theta=-62.04699 -> V=1.0, theta=0.0
% INFO    : Bus 8493	: V=0.9811688, theta=-64.883464 -> V=1.0, theta=0.0
% INFO    : Bus 8494	: V=0.9938103, theta=-69.74247 -> V=1.0, theta=0.0
% INFO    : Bus 8495	: V=0.9974403, theta=-67.409789 -> V=1.0, theta=0.0
% INFO    : Bus 8496	: V=1.0064674, theta=-70.59419 -> V=1.0, theta=0.0
% INFO    : Bus 8497	: V=1.007267, theta=-69.749737 -> V=1.0, theta=0.0
% INFO    : Bus 8498	: V=1.0042506, theta=-69.060521 -> V=1.0, theta=0.0
% INFO    : Bus 8499	: V=0.9986752, theta=-69.309305 -> V=1.0, theta=0.0
% INFO    : Bus 8500	: V=1.0057437, theta=-69.220741 -> V=1.0, theta=0.0
% INFO    : Bus 8501	: V=1.0099912, theta=-68.822816 -> V=1.0, theta=0.0
% INFO    : Bus 8502	: V=1.0010535, theta=-69.842396 -> V=1.0, theta=0.0
% INFO    : Bus 8503	: V=1.0125647, theta=-67.399566 -> V=1.0, theta=0.0
% INFO    : Bus 8504	: V=1.0097999, theta=-69.300509 -> V=1.0, theta=0.0
% INFO    : Bus 8505	: V=1.0022859, theta=-69.394478 -> V=1.0, theta=0.0
% INFO    : Bus 8506	: V=1.0059305, theta=-69.152679 -> V=1.0, theta=0.0
% INFO    : Bus 8507	: V=0.99049, theta=-70.710034 -> V=1.0, theta=0.0
% INFO    : Bus 8508	: V=1.0003676, theta=-69.918636 -> V=1.0, theta=0.0
% INFO    : Bus 8509	: V=0.9970376, theta=-69.581337 -> V=1.0, theta=0.0
% INFO    : Bus 8510	: V=1.02, theta=-53.792558 -> V=1.0, theta=0.0
% INFO    : Bus 8511	: V=1.02, theta=-52.353496 -> V=1.0, theta=0.0
% INFO    : Bus 8512	: V=1.02, theta=-53.906264 -> V=1.0, theta=0.0
% INFO    : Bus 8513	: V=1.0111885, theta=-60.568877 -> V=1.0, theta=0.0
% INFO    : Bus 8514	: V=1.0199238, theta=-58.68393 -> V=1.0, theta=0.0
% INFO    : Bus 8515	: V=1.02, theta=-55.437207 -> V=1.0, theta=0.0
% INFO    : Bus 8516	: V=1.0194607, theta=-56.480845 -> V=1.0, theta=0.0
% INFO    : Bus 8517	: V=1.0145321, theta=-56.344843 -> V=1.0, theta=0.0
% INFO    : Bus 8518	: V=1.02, theta=-58.045177 -> V=1.0, theta=0.0
% INFO    : Bus 8519	: V=1.02, theta=-57.833808 -> V=1.0, theta=0.0
% INFO    : Bus 8520	: V=1.0197664, theta=-57.855829 -> V=1.0, theta=0.0
% INFO    : Bus 8521	: V=1.02, theta=-51.656783 -> V=1.0, theta=0.0
% INFO    : Bus 8522	: V=1.0061242, theta=-54.698647 -> V=1.0, theta=0.0
% INFO    : Bus 8523	: V=1.0148751, theta=-61.574399 -> V=1.0, theta=0.0
% INFO    : Bus 8524	: V=1.0166049, theta=-59.024206 -> V=1.0, theta=0.0
% INFO    : Bus 8525	: V=1.0178397, theta=-53.593939 -> V=1.0, theta=0.0
% INFO    : Bus 8526	: V=1.014815, theta=-59.312837 -> V=1.0, theta=0.0
% INFO    : Bus 8527	: V=1.0186243, theta=-56.4545 -> V=1.0, theta=0.0
% INFO    : Bus 8528	: V=1.0027576, theta=-59.335566 -> V=1.0, theta=0.0
% INFO    : Bus 8529	: V=1.0145661, theta=-56.331595 -> V=1.0, theta=0.0
% INFO    : Bus 8530	: V=1.0197526, theta=-55.522295 -> V=1.0, theta=0.0
% INFO    : Bus 8531	: V=1.0064542, theta=-60.34124 -> V=1.0, theta=0.0
% INFO    : Bus 8532	: V=1.0076374, theta=-60.838047 -> V=1.0, theta=0.0
% INFO    : Bus 8533	: V=0.9938188, theta=-63.789118 -> V=1.0, theta=0.0
% INFO    : Bus 8534	: V=1.003316, theta=-53.07959 -> V=1.0, theta=0.0
% INFO    : Bus 8535	: V=1.02, theta=-58.143813 -> V=1.0, theta=0.0
% INFO    : Bus 8536	: V=1.0113564, theta=-59.080381 -> V=1.0, theta=0.0
% INFO    : Bus 8537	: V=1.0175746, theta=-58.413536 -> V=1.0, theta=0.0
% INFO    : Bus 8538	: V=1.0119018, theta=-58.787752 -> V=1.0, theta=0.0
% INFO    : Bus 8539	: V=0.9962501, theta=-60.636178 -> V=1.0, theta=0.0
% INFO    : Bus 8540	: V=0.9991764, theta=-61.169157 -> V=1.0, theta=0.0
% INFO    : Bus 8541	: V=1.0072725, theta=-54.816656 -> V=1.0, theta=0.0
% INFO    : Bus 8542	: V=1.0039256, theta=-59.332456 -> V=1.0, theta=0.0
% INFO    : Bus 8543	: V=1.0080822, theta=-60.489529 -> V=1.0, theta=0.0
% INFO    : Bus 8544	: V=1.0197545, theta=-53.948663 -> V=1.0, theta=0.0
% INFO    : Bus 8545	: V=0.9979863, theta=-59.64754 -> V=1.0, theta=0.0
% INFO    : Bus 8546	: V=0.9979887, theta=-61.337257 -> V=1.0, theta=0.0
% INFO    : Bus 8547	: V=1.0060342, theta=-58.650211 -> V=1.0, theta=0.0
% INFO    : Bus 8548	: V=0.9908431, theta=-61.331668 -> V=1.0, theta=0.0
% INFO    : Bus 8549	: V=0.9980595, theta=-55.454334 -> V=1.0, theta=0.0
% INFO    : Bus 8550	: V=1.0097339, theta=-59.006742 -> V=1.0, theta=0.0
% INFO    : Bus 8551	: V=1.0076805, theta=-53.831347 -> V=1.0, theta=0.0
% INFO    : Bus 8552	: V=1.0029452, theta=-59.857645 -> V=1.0, theta=0.0
% INFO    : Bus 8553	: V=1.02, theta=-55.096965 -> V=1.0, theta=0.0
% INFO    : Bus 8554	: V=1.02, theta=-57.834796 -> V=1.0, theta=0.0
% INFO    : Bus 8555	: V=1.0086785, theta=-58.240708 -> V=1.0, theta=0.0
% INFO    : Bus 8556	: V=1.02, theta=-55.071943 -> V=1.0, theta=0.0
% INFO    : Bus 8557	: V=1.02, theta=-56.735088 -> V=1.0, theta=0.0
% INFO    : Bus 8558	: V=1.02, theta=-55.027809 -> V=1.0, theta=0.0
% INFO    : Bus 8559	: V=1.0199649, theta=-55.12855 -> V=1.0, theta=0.0
% INFO    : Bus 8560	: V=1.02, theta=-55.234469 -> V=1.0, theta=0.0
% INFO    : Bus 8561	: V=1.0068485, theta=-59.753718 -> V=1.0, theta=0.0
% INFO    : Bus 8562	: V=1.02, theta=-56.856343 -> V=1.0, theta=0.0
% INFO    : Bus 8563	: V=1.02, theta=-51.467402 -> V=1.0, theta=0.0
% INFO    : Bus 8564	: V=1.0023648, theta=-58.835286 -> V=1.0, theta=0.0
% INFO    : Bus 8565	: V=1.02, theta=-60.754964 -> V=1.0, theta=0.0
% INFO    : Bus 8566	: V=1.02, theta=-58.020154 -> V=1.0, theta=0.0
% INFO    : Bus 8567	: V=1.02, theta=-60.261525 -> V=1.0, theta=0.0
% INFO    : Bus 8568	: V=0.999881, theta=-60.856047 -> V=1.0, theta=0.0
% INFO    : Bus 8569	: V=1.0130691, theta=-60.402488 -> V=1.0, theta=0.0
% INFO    : Bus 8570	: V=1.02, theta=-58.082994 -> V=1.0, theta=0.0
% INFO    : Bus 8571	: V=1.02, theta=-58.025008 -> V=1.0, theta=0.0
% INFO    : Bus 8572	: V=1.02, theta=-56.498665 -> V=1.0, theta=0.0
% INFO    : Bus 8573	: V=1.0168487, theta=-57.49108 -> V=1.0, theta=0.0
% INFO    : Bus 8574	: V=1.012331, theta=-58.514089 -> V=1.0, theta=0.0
% INFO    : Bus 8575	: V=1.02, theta=-55.950463 -> V=1.0, theta=0.0
% INFO    : Bus 8576	: V=1.02, theta=-57.433987 -> V=1.0, theta=0.0
% INFO    : Bus 8577	: V=1.02, theta=-53.067706 -> V=1.0, theta=0.0
% INFO    : Bus 8578	: V=1.02, theta=-64.179821 -> V=1.0, theta=0.0
% INFO    : Bus 8579	: V=0.9997825, theta=-60.868265 -> V=1.0, theta=0.0
% INFO    : Bus 8580	: V=1.0111105, theta=-61.388274 -> V=1.0, theta=0.0
% INFO    : Bus 8581	: V=1.02, theta=-54.19999 -> V=1.0, theta=0.0
% INFO    : Bus 8582	: V=1.02, theta=-58.479075 -> V=1.0, theta=0.0
% INFO    : Bus 8583	: V=1.02, theta=-61.524899 -> V=1.0, theta=0.0
% INFO    : Bus 8584	: V=1.0071702, theta=-60.605632 -> V=1.0, theta=0.0
% INFO    : Bus 8585	: V=0.9999424, theta=-57.998968 -> V=1.0, theta=0.0
% INFO    : Bus 8586	: V=1.02, theta=-58.541481 -> V=1.0, theta=0.0
% INFO    : Bus 8587	: V=0.9706773, theta=-77.649872 -> V=1.0, theta=0.0
% INFO    : Bus 8588	: V=1.0092956, theta=-57.180211 -> V=1.0, theta=0.0
% INFO    : Bus 8589	: V=1.0082484, theta=-60.930144 -> V=1.0, theta=0.0
% INFO    : Bus 8590	: V=1.0170084, theta=-67.248942 -> V=1.0, theta=0.0
% INFO    : Bus 8591	: V=1.0044842, theta=-59.956724 -> V=1.0, theta=0.0
% INFO    : Bus 8592	: V=1.0149288, theta=-57.849795 -> V=1.0, theta=0.0
% INFO    : Bus 8593	: V=1.0122786, theta=-61.954754 -> V=1.0, theta=0.0
% INFO    : Bus 8594	: V=1.003894, theta=-61.140001 -> V=1.0, theta=0.0
% INFO    : Bus 8595	: V=1.0180074, theta=-57.70067 -> V=1.0, theta=0.0
% INFO    : Bus 8596	: V=0.993074, theta=-61.710064 -> V=1.0, theta=0.0
% INFO    : Bus 8597	: V=0.9963525, theta=-60.244064 -> V=1.0, theta=0.0
% INFO    : Bus 8598	: V=1.0021738, theta=-59.979051 -> V=1.0, theta=0.0
% INFO    : Bus 8599	: V=0.9990013, theta=-61.78188 -> V=1.0, theta=0.0
% INFO    : Bus 8600	: V=1.010957, theta=-59.511158 -> V=1.0, theta=0.0
% INFO    : Bus 8601	: V=1.0150004, theta=-58.055789 -> V=1.0, theta=0.0
% INFO    : Bus 8602	: V=1.0024761, theta=-57.857434 -> V=1.0, theta=0.0
% INFO    : Bus 8603	: V=0.9958488, theta=-62.305236 -> V=1.0, theta=0.0
% INFO    : Bus 8604	: V=0.9781456, theta=-63.565919 -> V=1.0, theta=0.0
% INFO    : Bus 8605	: V=1.0024776, theta=-59.966453 -> V=1.0, theta=0.0
% INFO    : Bus 8606	: V=1.0114724, theta=-58.777954 -> V=1.0, theta=0.0
% INFO    : Bus 8607	: V=1.02, theta=-67.227825 -> V=1.0, theta=0.0
% INFO    : Bus 8608	: V=1.0089988, theta=-60.699404 -> V=1.0, theta=0.0
% INFO    : Bus 8609	: V=1.015346, theta=-57.815086 -> V=1.0, theta=0.0
% INFO    : Bus 8610	: V=0.9724485, theta=-71.805433 -> V=1.0, theta=0.0
% INFO    : Bus 8611	: V=0.9782059, theta=-70.803914 -> V=1.0, theta=0.0
% INFO    : Bus 8612	: V=1.0045523, theta=-60.358297 -> V=1.0, theta=0.0
% INFO    : Bus 8613	: V=1.012002, theta=-71.00342 -> V=1.0, theta=0.0
% INFO    : Bus 8614	: V=1.0071734, theta=-67.703955 -> V=1.0, theta=0.0
% INFO    : Bus 8615	: V=1.0019125, theta=-59.694233 -> V=1.0, theta=0.0
% INFO    : Bus 8616	: V=0.9865878, theta=-61.52276 -> V=1.0, theta=0.0
% INFO    : Bus 8617	: V=1.02, theta=-55.083755 -> V=1.0, theta=0.0
% INFO    : Bus 8618	: V=1.0094484, theta=-58.52129 -> V=1.0, theta=0.0
% INFO    : Bus 8619	: V=0.9873764, theta=-63.178069 -> V=1.0, theta=0.0
% INFO    : Bus 8620	: V=1.0112117, theta=-62.056897 -> V=1.0, theta=0.0
% INFO    : Bus 8621	: V=0.963379, theta=-69.420996 -> V=1.0, theta=0.0
% INFO    : Bus 8622	: V=0.9870768, theta=-63.193285 -> V=1.0, theta=0.0
% INFO    : Bus 8623	: V=0.9978076, theta=-60.881619 -> V=1.0, theta=0.0
% INFO    : Bus 8624	: V=1.0172599, theta=-55.435852 -> V=1.0, theta=0.0
% INFO    : Bus 8625	: V=0.996169, theta=-59.009524 -> V=1.0, theta=0.0
% INFO    : Bus 8626	: V=1.004151, theta=-57.707841 -> V=1.0, theta=0.0
% INFO    : Bus 8627	: V=0.9845612, theta=-65.617573 -> V=1.0, theta=0.0
% INFO    : Bus 8628	: V=0.991645, theta=-61.799455 -> V=1.0, theta=0.0
% INFO    : Bus 8629	: V=0.9865399, theta=-61.457884 -> V=1.0, theta=0.0
% INFO    : Bus 8630	: V=1.0052741, theta=-62.85653 -> V=1.0, theta=0.0
% INFO    : Bus 8631	: V=0.9843435, theta=-61.927189 -> V=1.0, theta=0.0
% INFO    : Bus 8632	: V=1.0018137, theta=-58.636091 -> V=1.0, theta=0.0
% INFO    : Bus 8633	: V=1.0034099, theta=-58.46015 -> V=1.0, theta=0.0
% INFO    : Bus 8634	: V=1.019067, theta=-56.481106 -> V=1.0, theta=0.0
% INFO    : Bus 8635	: V=0.9934704, theta=-63.808396 -> V=1.0, theta=0.0
% INFO    : Bus 8636	: V=1.005692, theta=-61.378463 -> V=1.0, theta=0.0
% INFO    : Bus 8637	: V=0.9801986, theta=-63.184003 -> V=1.0, theta=0.0
% INFO    : Bus 8638	: V=1.0196083, theta=-57.117824 -> V=1.0, theta=0.0
% INFO    : Bus 8639	: V=0.9687975, theta=-66.651074 -> V=1.0, theta=0.0
% INFO    : Bus 8640	: V=0.9740094, theta=-70.494172 -> V=1.0, theta=0.0
% INFO    : Bus 8641	: V=1.0163501, theta=-57.041907 -> V=1.0, theta=0.0
% INFO    : Bus 8642	: V=0.9994738, theta=-67.188185 -> V=1.0, theta=0.0
% INFO    : Bus 8643	: V=1.0053958, theta=-59.381344 -> V=1.0, theta=0.0
% INFO    : Bus 8644	: V=1.0078267, theta=-57.478226 -> V=1.0, theta=0.0
% INFO    : Bus 8645	: V=1.001834, theta=-59.754428 -> V=1.0, theta=0.0
% INFO    : Bus 8646	: V=1.02, theta=-70.812003 -> V=1.0, theta=0.0
% INFO    : Bus 8647	: V=1.0000614, theta=-61.349114 -> V=1.0, theta=0.0
% INFO    : Bus 8648	: V=1.0013384, theta=-58.713842 -> V=1.0, theta=0.0
% INFO    : Bus 8649	: V=0.994935, theta=-59.244131 -> V=1.0, theta=0.0
% INFO    : Bus 8650	: V=1.0136666, theta=-59.219148 -> V=1.0, theta=0.0
% INFO    : Bus 8651	: V=0.9668435, theta=-64.256789 -> V=1.0, theta=0.0
% INFO    : Bus 8652	: V=1.0096614, theta=-59.233726 -> V=1.0, theta=0.0
% INFO    : Bus 8653	: V=0.9763135, theta=-63.90404 -> V=1.0, theta=0.0
% INFO    : Bus 8654	: V=0.9880582, theta=-61.147242 -> V=1.0, theta=0.0
% INFO    : Bus 8655	: V=0.9725575, theta=-65.496925 -> V=1.0, theta=0.0
% INFO    : Bus 8656	: V=0.9696666, theta=-69.148769 -> V=1.0, theta=0.0
% INFO    : Bus 8657	: V=1.02, theta=-57.509182 -> V=1.0, theta=0.0
% INFO    : Bus 8658	: V=0.9887794, theta=-63.252425 -> V=1.0, theta=0.0
% INFO    : Bus 8659	: V=0.9973129, theta=-61.069381 -> V=1.0, theta=0.0
% INFO    : Bus 8660	: V=1.0002419, theta=-62.820345 -> V=1.0, theta=0.0
% INFO    : Bus 8661	: V=0.9855774, theta=-60.572707 -> V=1.0, theta=0.0
% INFO    : Bus 8662	: V=1.0054547, theta=-58.21944 -> V=1.0, theta=0.0
% INFO    : Bus 8663	: V=0.995087, theta=-53.608803 -> V=1.0, theta=0.0
% INFO    : Bus 8664	: V=0.9954897, theta=-53.623622 -> V=1.0, theta=0.0
% INFO    : Bus 8665	: V=0.9956358, theta=-53.610766 -> V=1.0, theta=0.0
% INFO    : Bus 8666	: V=0.9958208, theta=-53.597271 -> V=1.0, theta=0.0
% INFO    : Bus 8667	: V=1.0028418, theta=-53.09746 -> V=1.0, theta=0.0
% INFO    : Bus 8668	: V=1.0020436, theta=-53.352908 -> V=1.0, theta=0.0
% INFO    : Bus 8669	: V=1.0041464, theta=-53.232171 -> V=1.0, theta=0.0
% INFO    : Bus 8670	: V=1.0022642, theta=-53.355451 -> V=1.0, theta=0.0
% INFO    : Bus 8671	: V=0.9983287, theta=-53.61455 -> V=1.0, theta=0.0
% INFO    : Bus 8672	: V=0.998943, theta=-53.496894 -> V=1.0, theta=0.0
% INFO    : Bus 8673	: V=0.9977645, theta=-53.470714 -> V=1.0, theta=0.0
% INFO    : Bus 8674	: V=1.0025922, theta=-53.106849 -> V=1.0, theta=0.0
% INFO    : Bus 8675	: V=1.0039093, theta=-53.044544 -> V=1.0, theta=0.0
% INFO    : Bus 8676	: V=1.0033333, theta=-53.0849 -> V=1.0, theta=0.0
% INFO    : Bus 8677	: V=0.9969378, theta=-53.965118 -> V=1.0, theta=0.0
% INFO    : Bus 8678	: V=0.9977891, theta=-53.73969 -> V=1.0, theta=0.0
% INFO    : Bus 8679	: V=1.0021119, theta=-53.169241 -> V=1.0, theta=0.0
% INFO    : Bus 8680	: V=1.0025001, theta=-53.141877 -> V=1.0, theta=0.0
% INFO    : Bus 8681	: V=0.9925272, theta=-54.012997 -> V=1.0, theta=0.0
% INFO    : Bus 8682	: V=0.9944489, theta=-53.87001 -> V=1.0, theta=0.0
% INFO    : Bus 8683	: V=0.9629353, theta=-55.786581 -> V=1.0, theta=0.0
% INFO    : Bus 8684	: V=0.9825179, theta=-54.837758 -> V=1.0, theta=0.0
% INFO    : Bus 8685	: V=0.9961665, theta=-54.047648 -> V=1.0, theta=0.0
% INFO    : Bus 8686	: V=0.9793645, theta=-54.930625 -> V=1.0, theta=0.0
% INFO    : Bus 8687	: V=0.9853587, theta=-54.280796 -> V=1.0, theta=0.0
% INFO    : Bus 8688	: V=0.9883456, theta=-54.270139 -> V=1.0, theta=0.0
% INFO    : Bus 8689	: V=0.9573757, theta=-56.399312 -> V=1.0, theta=0.0
% INFO    : Bus 8690	: V=0.9587013, theta=-57.906435 -> V=1.0, theta=0.0
% INFO    : Bus 8691	: V=0.9594152, theta=-58.742319 -> V=1.0, theta=0.0
% INFO    : Bus 8692	: V=0.9602987, theta=-58.483227 -> V=1.0, theta=0.0
% INFO    : Bus 8693	: V=0.9759951, theta=-56.884739 -> V=1.0, theta=0.0
% INFO    : Bus 8694	: V=0.9639281, theta=-57.692513 -> V=1.0, theta=0.0
% INFO    : Bus 8695	: V=0.9699259, theta=-57.213269 -> V=1.0, theta=0.0
% INFO    : Bus 8696	: V=0.9931051, theta=-55.37886 -> V=1.0, theta=0.0
% INFO    : Bus 8697	: V=0.9792118, theta=-56.384053 -> V=1.0, theta=0.0
% INFO    : Bus 8698	: V=0.9765857, theta=-55.884399 -> V=1.0, theta=0.0
% INFO    : Bus 8699	: V=0.9798761, theta=-55.4248 -> V=1.0, theta=0.0
% INFO    : Bus 8700	: V=0.9736988, theta=-54.656406 -> V=1.0, theta=0.0
% INFO    : Bus 8701	: V=0.9755391, theta=-55.477358 -> V=1.0, theta=0.0
% INFO    : Bus 8702	: V=0.9814771, theta=-54.555621 -> V=1.0, theta=0.0
% INFO    : Bus 8703	: V=1.0014668, theta=-53.375783 -> V=1.0, theta=0.0
% INFO    : Bus 8704	: V=0.9994134, theta=-53.630817 -> V=1.0, theta=0.0
% INFO    : Bus 8705	: V=1.0050753, theta=-52.98179 -> V=1.0, theta=0.0
% INFO    : Bus 8706	: V=1.0100046, theta=-52.427887 -> V=1.0, theta=0.0
% INFO    : Bus 8707	: V=1.0141696, theta=-52.128203 -> V=1.0, theta=0.0
% INFO    : Bus 8708	: V=0.9950372, theta=-53.936534 -> V=1.0, theta=0.0
% INFO    : Bus 8709	: V=1.0044599, theta=-52.826807 -> V=1.0, theta=0.0
% INFO    : Bus 8710	: V=0.9980195, theta=-53.619067 -> V=1.0, theta=0.0
% INFO    : Bus 8711	: V=0.9972643, theta=-53.656476 -> V=1.0, theta=0.0
% INFO    : Bus 8712	: V=1.0054792, theta=-52.768025 -> V=1.0, theta=0.0
% INFO    : Bus 8713	: V=0.9974743, theta=-53.61668 -> V=1.0, theta=0.0
% INFO    : Bus 8714	: V=0.9969045, theta=-53.68461 -> V=1.0, theta=0.0
% INFO    : Bus 8715	: V=1.0083473, theta=-52.549048 -> V=1.0, theta=0.0
% INFO    : Bus 8716	: V=1.0097481, theta=-52.444691 -> V=1.0, theta=0.0
% INFO    : Bus 8717	: V=1.011463, theta=-52.307422 -> V=1.0, theta=0.0
% INFO    : Bus 8718	: V=1.0091132, theta=-52.466456 -> V=1.0, theta=0.0
% INFO    : Bus 8719	: V=1.0135018, theta=-52.154112 -> V=1.0, theta=0.0
% INFO    : Bus 8720	: V=1.0040878, theta=-52.802528 -> V=1.0, theta=0.0
% INFO    : Bus 8721	: V=1.0127118, theta=-52.195661 -> V=1.0, theta=0.0
% INFO    : Bus 8722	: V=1.0032008, theta=-52.806175 -> V=1.0, theta=0.0
% INFO    : Bus 8723	: V=0.9968735, theta=-53.558684 -> V=1.0, theta=0.0
% INFO    : Bus 8724	: V=0.997329, theta=-53.529233 -> V=1.0, theta=0.0
% INFO    : Bus 8725	: V=0.9980321, theta=-53.477394 -> V=1.0, theta=0.0
% INFO    : Bus 8726	: V=0.9950141, theta=-53.62603 -> V=1.0, theta=0.0
% INFO    : Bus 8727	: V=0.9957482, theta=-53.613387 -> V=1.0, theta=0.0
% INFO    : Bus 8728	: V=0.9962704, theta=-53.585506 -> V=1.0, theta=0.0
% INFO    : Bus 8729	: V=0.9955516, theta=-53.614221 -> V=1.0, theta=0.0
% INFO    : Bus 8730	: V=1.000917, theta=-53.268918 -> V=1.0, theta=0.0
% INFO    : Bus 8731	: V=0.9759574, theta=-55.061393 -> V=1.0, theta=0.0
% INFO    : Bus 8732	: V=0.9811787, theta=-64.731409 -> V=1.0, theta=0.0
% INFO    : Bus 8733	: V=0.9847353, theta=-64.827397 -> V=1.0, theta=0.0
% INFO    : Bus 8734	: V=0.9824492, theta=-64.995418 -> V=1.0, theta=0.0
% INFO    : Bus 8735	: V=0.9832904, theta=-64.9497 -> V=1.0, theta=0.0
% INFO    : Bus 8736	: V=0.9923107, theta=-63.898492 -> V=1.0, theta=0.0
% INFO    : Bus 8737	: V=0.9923559, theta=-63.898158 -> V=1.0, theta=0.0
% INFO    : Bus 8738	: V=0.9926196, theta=-63.878287 -> V=1.0, theta=0.0
% INFO    : Bus 8739	: V=0.9931566, theta=-63.832846 -> V=1.0, theta=0.0
% INFO    : Bus 8740	: V=0.9914849, theta=-64.260766 -> V=1.0, theta=0.0
% INFO    : Bus 8741	: V=0.9927538, theta=-63.857978 -> V=1.0, theta=0.0
% INFO    : Bus 8742	: V=0.9919897, theta=-64.421151 -> V=1.0, theta=0.0
% INFO    : Bus 8743	: V=0.9972048, theta=-63.444444 -> V=1.0, theta=0.0
% INFO    : Bus 8744	: V=0.9908201, theta=-62.673308 -> V=1.0, theta=0.0
% INFO    : Bus 8745	: V=0.9944136, theta=-64.097304 -> V=1.0, theta=0.0
% INFO    : Bus 8746	: V=0.993999, theta=-64.108809 -> V=1.0, theta=0.0
% INFO    : Bus 8747	: V=0.9944031, theta=-64.106397 -> V=1.0, theta=0.0
% INFO    : Bus 8748	: V=0.9938054, theta=-63.877284 -> V=1.0, theta=0.0
% INFO    : Bus 8749	: V=0.9852519, theta=-64.859077 -> V=1.0, theta=0.0
% INFO    : Bus 8750	: V=0.9895148, theta=-64.046529 -> V=1.0, theta=0.0
% INFO    : Bus 8751	: V=0.9913088, theta=-63.94681 -> V=1.0, theta=0.0
% INFO    : Bus 8752	: V=0.9865471, theta=-64.729433 -> V=1.0, theta=0.0
% INFO    : Bus 8753	: V=0.9861464, theta=-64.759095 -> V=1.0, theta=0.0
% INFO    : Bus 8754	: V=0.9878396, theta=-64.680387 -> V=1.0, theta=0.0
% INFO    : Bus 8755	: V=0.9872964, theta=-64.65984 -> V=1.0, theta=0.0
% INFO    : Bus 8756	: V=0.9867834, theta=-64.675477 -> V=1.0, theta=0.0
% INFO    : Bus 8757	: V=0.9921514, theta=-63.923212 -> V=1.0, theta=0.0
% INFO    : Bus 8758	: V=0.993119, theta=-63.848022 -> V=1.0, theta=0.0
% INFO    : Bus 8759	: V=0.9922448, theta=-63.837856 -> V=1.0, theta=0.0
% INFO    : Bus 8760	: V=0.9929628, theta=-63.918136 -> V=1.0, theta=0.0
% INFO    : Bus 8761	: V=0.9900104, theta=-62.64077 -> V=1.0, theta=0.0
% INFO    : Bus 8762	: V=0.9882252, theta=-62.833682 -> V=1.0, theta=0.0
% INFO    : Bus 8763	: V=0.993257, theta=-64.000281 -> V=1.0, theta=0.0
% INFO    : Bus 8764	: V=0.9946883, theta=-64.096108 -> V=1.0, theta=0.0
% INFO    : Bus 8765	: V=0.9885056, theta=-64.167723 -> V=1.0, theta=0.0
% INFO    : Bus 8766	: V=0.9900696, theta=-64.515191 -> V=1.0, theta=0.0
% INFO    : Bus 8767	: V=0.9933953, theta=-63.793988 -> V=1.0, theta=0.0
% INFO    : Bus 8768	: V=0.9900009, theta=-64.521963 -> V=1.0, theta=0.0
% INFO    : Bus 8769	: V=0.9952852, theta=-63.693436 -> V=1.0, theta=0.0
% INFO    : Bus 8770	: V=0.9896943, theta=-64.519304 -> V=1.0, theta=0.0
% INFO    : Bus 8771	: V=0.9890959, theta=-64.624908 -> V=1.0, theta=0.0
% INFO    : Bus 8772	: V=0.9885353, theta=-64.232334 -> V=1.0, theta=0.0
% INFO    : Bus 8773	: V=0.9981982, theta=-61.785524 -> V=1.0, theta=0.0
% INFO    : Bus 8774	: V=0.9906027, theta=-64.023818 -> V=1.0, theta=0.0
% INFO    : Bus 8775	: V=0.9882746, theta=-64.29164 -> V=1.0, theta=0.0
% INFO    : Bus 8776	: V=0.9882722, theta=-64.31928 -> V=1.0, theta=0.0
% INFO    : Bus 8777	: V=0.9946734, theta=-63.767441 -> V=1.0, theta=0.0
% INFO    : Bus 8778	: V=0.9959236, theta=-63.626432 -> V=1.0, theta=0.0
% INFO    : Bus 8779	: V=0.9943022, theta=-64.008509 -> V=1.0, theta=0.0
% INFO    : Bus 8780	: V=0.9948444, theta=-63.95367 -> V=1.0, theta=0.0
% INFO    : Bus 8781	: V=0.9947853, theta=-63.969407 -> V=1.0, theta=0.0
% INFO    : Bus 8782	: V=0.9944163, theta=-63.989348 -> V=1.0, theta=0.0
% INFO    : Bus 8783	: V=0.9990585, theta=-63.374217 -> V=1.0, theta=0.0
% INFO    : Bus 8784	: V=0.9946973, theta=-63.987965 -> V=1.0, theta=0.0
% INFO    : Bus 8785	: V=0.999401, theta=-63.350335 -> V=1.0, theta=0.0
% INFO    : Bus 8786	: V=0.9941042, theta=-64.105451 -> V=1.0, theta=0.0
% INFO    : Bus 8787	: V=0.9950978, theta=-64.062449 -> V=1.0, theta=0.0
% INFO    : Bus 8788	: V=0.9945159, theta=-64.104612 -> V=1.0, theta=0.0
% INFO    : Bus 8789	: V=0.9834014, theta=-64.14074 -> V=1.0, theta=0.0
% INFO    : Bus 8790	: V=0.9811802, theta=-64.86589 -> V=1.0, theta=0.0
% INFO    : Bus 8791	: V=0.9902223, theta=-63.858927 -> V=1.0, theta=0.0
% INFO    : Bus 8792	: V=0.9907745, theta=-63.83758 -> V=1.0, theta=0.0
% INFO    : Bus 8793	: V=0.9944996, theta=-63.46805 -> V=1.0, theta=0.0
% INFO    : Bus 8794	: V=0.9949302, theta=-63.461239 -> V=1.0, theta=0.0
% INFO    : Bus 8795	: V=0.9894075, theta=-63.808346 -> V=1.0, theta=0.0
% INFO    : Bus 8796	: V=0.9940822, theta=-63.471192 -> V=1.0, theta=0.0
% INFO    : Bus 8797	: V=0.9875091, theta=-64.254677 -> V=1.0, theta=0.0
% INFO    : Bus 8798	: V=0.9881285, theta=-64.232461 -> V=1.0, theta=0.0
% INFO    : Bus 8799	: V=0.994443, theta=-63.674588 -> V=1.0, theta=0.0
% INFO    : Bus 8800	: V=0.9941264, theta=-63.695653 -> V=1.0, theta=0.0
% INFO    : Bus 8801	: V=0.9896998, theta=-64.316683 -> V=1.0, theta=0.0
% INFO    : Bus 8802	: V=0.9944674, theta=-63.620497 -> V=1.0, theta=0.0
% INFO    : Bus 8803	: V=0.9936989, theta=-63.823669 -> V=1.0, theta=0.0
% INFO    : Bus 8804	: V=0.9962332, theta=-63.444518 -> V=1.0, theta=0.0
% INFO    : Bus 8805	: V=0.994709, theta=-63.602232 -> V=1.0, theta=0.0
% INFO    : Bus 8806	: V=0.9949417, theta=-63.578857 -> V=1.0, theta=0.0
% INFO    : Bus 8807	: V=0.9966086, theta=-63.47465 -> V=1.0, theta=0.0
% INFO    : Bus 8808	: V=0.995718, theta=-63.532173 -> V=1.0, theta=0.0
% INFO    : Bus 8809	: V=0.981788, theta=-65.161664 -> V=1.0, theta=0.0
% INFO    : Bus 8810	: V=0.9843729, theta=-64.938133 -> V=1.0, theta=0.0
% INFO    : Bus 8811	: V=0.9975045, theta=-63.361428 -> V=1.0, theta=0.0
% INFO    : Bus 8812	: V=0.9968337, theta=-63.395343 -> V=1.0, theta=0.0
% INFO    : Bus 8813	: V=0.9826022, theta=-65.053008 -> V=1.0, theta=0.0
% INFO    : Bus 8814	: V=0.9868307, theta=-64.264212 -> V=1.0, theta=0.0
% INFO    : Bus 8815	: V=0.9809485, theta=-64.84133 -> V=1.0, theta=0.0
% INFO    : Bus 8816	: V=0.9954438, theta=-63.862029 -> V=1.0, theta=0.0
% INFO    : Bus 8817	: V=0.995077, theta=-63.871629 -> V=1.0, theta=0.0
% INFO    : Bus 8818	: V=0.9981496, theta=-63.490517 -> V=1.0, theta=0.0
% INFO    : Bus 8819	: V=1.0003692, theta=-63.196353 -> V=1.0, theta=0.0
% INFO    : Bus 8820	: V=0.995416, theta=-63.517835 -> V=1.0, theta=0.0
% INFO    : Bus 8821	: V=0.9953632, theta=-63.451518 -> V=1.0, theta=0.0
% INFO    : Bus 8822	: V=0.9956765, theta=-63.441071 -> V=1.0, theta=0.0
% INFO    : Bus 8823	: V=0.996139, theta=-63.425922 -> V=1.0, theta=0.0
% INFO    : Bus 8824	: V=0.99151, theta=-62.259792 -> V=1.0, theta=0.0
% INFO    : Bus 8825	: V=0.9864582, theta=-63.030061 -> V=1.0, theta=0.0
% INFO    : Bus 8826	: V=0.9858776, theta=-63.055533 -> V=1.0, theta=0.0
% INFO    : Bus 8827	: V=0.9853363, theta=-63.089472 -> V=1.0, theta=0.0
% INFO    : Bus 8828	: V=0.9832683, theta=-64.126072 -> V=1.0, theta=0.0
% INFO    : Bus 8829	: V=0.9773807, theta=-65.17921 -> V=1.0, theta=0.0
% INFO    : Bus 8830	: V=0.975563, theta=-65.33428 -> V=1.0, theta=0.0
% INFO    : Bus 8831	: V=0.9779113, theta=-65.069534 -> V=1.0, theta=0.0
% INFO    : Bus 8832	: V=0.9771278, theta=-65.182099 -> V=1.0, theta=0.0
% INFO    : Bus 8833	: V=0.9890106, theta=-64.371691 -> V=1.0, theta=0.0
% INFO    : Bus 8834	: V=0.9941609, theta=-63.641091 -> V=1.0, theta=0.0
% INFO    : Bus 8835	: V=0.9943082, theta=-63.631578 -> V=1.0, theta=0.0
% INFO    : Bus 8836	: V=0.983433, theta=-64.554872 -> V=1.0, theta=0.0
% INFO    : Bus 8837	: V=0.9786911, theta=-65.592342 -> V=1.0, theta=0.0
% INFO    : Bus 8838	: V=0.9801411, theta=-65.484591 -> V=1.0, theta=0.0
% INFO    : Bus 8839	: V=1.0085033, theta=-61.975513 -> V=1.0, theta=0.0
% INFO    : Bus 8840	: V=0.9993916, theta=-63.244453 -> V=1.0, theta=0.0
% INFO    : Bus 8841	: V=0.9870375, theta=-64.641624 -> V=1.0, theta=0.0
% INFO    : Bus 8842	: V=0.9906125, theta=-64.288788 -> V=1.0, theta=0.0
% INFO    : Bus 8843	: V=0.9912104, theta=-64.272876 -> V=1.0, theta=0.0
% INFO    : Bus 8844	: V=0.981482, theta=-62.799169 -> V=1.0, theta=0.0
% INFO    : Bus 8845	: V=0.9815604, theta=-62.735947 -> V=1.0, theta=0.0
% INFO    : Bus 8846	: V=0.9815514, theta=-62.72646 -> V=1.0, theta=0.0
% INFO    : Bus 8847	: V=0.9826059, theta=-64.289416 -> V=1.0, theta=0.0
% INFO    : Bus 8848	: V=0.977927, theta=-65.01245 -> V=1.0, theta=0.0
% INFO    : Bus 8849	: V=0.9837969, theta=-64.129061 -> V=1.0, theta=0.0
% INFO    : Bus 8850	: V=0.9889998, theta=-64.135705 -> V=1.0, theta=0.0
% INFO    : Bus 8851	: V=0.9894579, theta=-64.103709 -> V=1.0, theta=0.0
% INFO    : Bus 8852	: V=1.0020949, theta=-62.950733 -> V=1.0, theta=0.0
% INFO    : Bus 8853	: V=1.0014998, theta=-62.9693 -> V=1.0, theta=0.0
% INFO    : Bus 8854	: V=1.001322, theta=-62.959835 -> V=1.0, theta=0.0
% INFO    : Bus 8855	: V=1.0011617, theta=-62.971404 -> V=1.0, theta=0.0
% INFO    : Bus 8856	: V=0.9903672, theta=-64.02472 -> V=1.0, theta=0.0
% INFO    : Bus 8857	: V=0.9821753, theta=-65.172226 -> V=1.0, theta=0.0
% INFO    : Bus 8858	: V=0.9882595, theta=-64.036973 -> V=1.0, theta=0.0
% INFO    : Bus 8859	: V=0.9881859, theta=-64.242173 -> V=1.0, theta=0.0
% INFO    : Bus 8860	: V=0.9881592, theta=-64.413733 -> V=1.0, theta=0.0
% INFO    : Bus 8861	: V=0.978066, theta=-65.605521 -> V=1.0, theta=0.0
% INFO    : Bus 8862	: V=0.9800091, theta=-65.457249 -> V=1.0, theta=0.0
% INFO    : Bus 8863	: V=0.9832263, theta=-64.098751 -> V=1.0, theta=0.0
% INFO    : Bus 8864	: V=0.9832978, theta=-64.055357 -> V=1.0, theta=0.0
% INFO    : Bus 8865	: V=0.9826403, theta=-64.114699 -> V=1.0, theta=0.0
% INFO    : Bus 8866	: V=0.9951391, theta=-64.031952 -> V=1.0, theta=0.0
% INFO    : Bus 8867	: V=0.9996624, theta=-63.293263 -> V=1.0, theta=0.0
% INFO    : Bus 8868	: V=0.9970552, theta=-63.57896 -> V=1.0, theta=0.0
% INFO    : Bus 8869	: V=0.9975198, theta=-63.408453 -> V=1.0, theta=0.0
% INFO    : Bus 8870	: V=0.9989757, theta=-63.30429 -> V=1.0, theta=0.0
% INFO    : Bus 8871	: V=0.9818156, theta=-64.767511 -> V=1.0, theta=0.0
% INFO    : Bus 8872	: V=0.9825444, theta=-64.578644 -> V=1.0, theta=0.0
% INFO    : Bus 8873	: V=0.982578, theta=-64.580075 -> V=1.0, theta=0.0
% INFO    : Bus 8874	: V=0.9877802, theta=-63.732229 -> V=1.0, theta=0.0
% INFO    : Bus 8875	: V=0.9870092, theta=-64.298605 -> V=1.0, theta=0.0
% INFO    : Bus 8876	: V=0.992141, theta=-63.908645 -> V=1.0, theta=0.0
% INFO    : Bus 8877	: V=0.991564, theta=-63.948252 -> V=1.0, theta=0.0
% INFO    : Bus 8878	: V=0.9790902, theta=-65.482387 -> V=1.0, theta=0.0
% INFO    : Bus 8879	: V=0.9837498, theta=-65.012111 -> V=1.0, theta=0.0
% INFO    : Bus 8880	: V=0.9939956, theta=-63.643478 -> V=1.0, theta=0.0
% INFO    : Bus 8881	: V=0.9883656, theta=-62.801524 -> V=1.0, theta=0.0
% INFO    : Bus 8882	: V=0.9868029, theta=-63.010152 -> V=1.0, theta=0.0
% INFO    : Bus 8883	: V=0.9888651, theta=-62.753129 -> V=1.0, theta=0.0
% INFO    : Bus 8884	: V=0.9905238, theta=-62.492344 -> V=1.0, theta=0.0
% INFO    : Bus 8885	: V=0.9884046, theta=-64.352634 -> V=1.0, theta=0.0
% INFO    : Bus 8886	: V=0.9942212, theta=-63.604679 -> V=1.0, theta=0.0
% INFO    : Bus 8887	: V=0.9793792, theta=-64.917955 -> V=1.0, theta=0.0
% INFO    : Bus 8888	: V=0.9795115, theta=-64.809935 -> V=1.0, theta=0.0
% INFO    : Bus 8889	: V=0.9906826, theta=-64.458031 -> V=1.0, theta=0.0
% INFO    : Bus 8890	: V=0.9908619, theta=-64.410848 -> V=1.0, theta=0.0
% INFO    : Bus 8891	: V=0.9937208, theta=-63.76468 -> V=1.0, theta=0.0
% INFO    : Bus 8892	: V=0.9946535, theta=-63.643879 -> V=1.0, theta=0.0
% INFO    : Bus 8893	: V=0.9947818, theta=-63.618423 -> V=1.0, theta=0.0
% INFO    : Bus 8894	: V=0.9959102, theta=-63.534511 -> V=1.0, theta=0.0
% INFO    : Bus 8895	: V=0.9871715, theta=-64.870555 -> V=1.0, theta=0.0
% INFO    : Bus 8896	: V=0.9880471, theta=-64.608519 -> V=1.0, theta=0.0
% INFO    : Bus 8897	: V=0.9801469, theta=-64.896927 -> V=1.0, theta=0.0
% INFO    : Bus 8898	: V=0.9824828, theta=-64.611634 -> V=1.0, theta=0.0
% INFO    : Bus 8899	: V=0.9878995, theta=-63.780397 -> V=1.0, theta=0.0
% INFO    : Bus 8900	: V=0.988168, theta=-62.84438 -> V=1.0, theta=0.0
% INFO    : Bus 8901	: V=0.9886774, theta=-63.697453 -> V=1.0, theta=0.0
% INFO    : Bus 8902	: V=0.9857269, theta=-64.536316 -> V=1.0, theta=0.0
% INFO    : Bus 8903	: V=0.9878144, theta=-64.170428 -> V=1.0, theta=0.0
% INFO    : Bus 8904	: V=0.9881957, theta=-64.178573 -> V=1.0, theta=0.0
% INFO    : Bus 8905	: V=0.9862883, theta=-64.53379 -> V=1.0, theta=0.0
% INFO    : Bus 8906	: V=0.9933846, theta=-64.070612 -> V=1.0, theta=0.0
% INFO    : Bus 8907	: V=0.9785378, theta=-65.027132 -> V=1.0, theta=0.0
% INFO    : Bus 8908	: V=0.979456, theta=-65.001959 -> V=1.0, theta=0.0
% INFO    : Bus 8909	: V=0.9879056, theta=-63.712654 -> V=1.0, theta=0.0
% INFO    : Bus 8910	: V=0.9876242, theta=-63.749484 -> V=1.0, theta=0.0
% INFO    : Bus 8911	: V=0.9816786, theta=-62.071876 -> V=1.0, theta=0.0
% INFO    : Bus 8912	: V=0.9733253, theta=-62.644426 -> V=1.0, theta=0.0
% INFO    : Bus 8913	: V=0.9736926, theta=-62.642114 -> V=1.0, theta=0.0
% INFO    : Bus 8914	: V=0.9753279, theta=-62.599325 -> V=1.0, theta=0.0
% INFO    : Bus 8915	: V=0.9787167, theta=-62.671959 -> V=1.0, theta=0.0
% INFO    : Bus 8916	: V=0.9744071, theta=-62.630623 -> V=1.0, theta=0.0
% INFO    : Bus 8917	: V=0.9724214, theta=-62.697553 -> V=1.0, theta=0.0
% INFO    : Bus 8918	: V=0.9770138, theta=-62.48403 -> V=1.0, theta=0.0
% INFO    : Bus 8919	: V=0.9766246, theta=-62.484316 -> V=1.0, theta=0.0
% INFO    : Bus 8920	: V=0.9689614, theta=-62.748036 -> V=1.0, theta=0.0
% INFO    : Bus 8921	: V=0.9703582, theta=-62.707179 -> V=1.0, theta=0.0
% INFO    : Bus 8922	: V=0.9677401, theta=-62.755695 -> V=1.0, theta=0.0
% INFO    : Bus 8923	: V=0.9671342, theta=-62.748618 -> V=1.0, theta=0.0
% INFO    : Bus 8924	: V=0.966499, theta=-62.730977 -> V=1.0, theta=0.0
% INFO    : Bus 8925	: V=0.9658537, theta=-62.529776 -> V=1.0, theta=0.0
% INFO    : Bus 8926	: V=0.9657925, theta=-62.772431 -> V=1.0, theta=0.0
% INFO    : Bus 8927	: V=0.9707912, theta=-62.757143 -> V=1.0, theta=0.0
% INFO    : Bus 8928	: V=0.9715074, theta=-62.742512 -> V=1.0, theta=0.0
% INFO    : Bus 8929	: V=0.9727777, theta=-62.681794 -> V=1.0, theta=0.0
% INFO    : Bus 8930	: V=0.9763871, theta=-62.474531 -> V=1.0, theta=0.0
% INFO    : Bus 8931	: V=0.9933284, theta=-61.127715 -> V=1.0, theta=0.0
% INFO    : Bus 8932	: V=0.9790383, theta=-62.370624 -> V=1.0, theta=0.0
% INFO    : Bus 8933	: V=0.9780954, theta=-62.409731 -> V=1.0, theta=0.0
% INFO    : Bus 8934	: V=0.9793941, theta=-62.35097 -> V=1.0, theta=0.0
% INFO    : Bus 8935	: V=0.979951, theta=-62.316179 -> V=1.0, theta=0.0
% INFO    : Bus 8936	: V=0.9804265, theta=-62.287757 -> V=1.0, theta=0.0
% INFO    : Bus 8937	: V=0.9976693, theta=-60.851253 -> V=1.0, theta=0.0
% INFO    : Bus 8938	: V=0.9875312, theta=-62.493548 -> V=1.0, theta=0.0
% INFO    : Bus 8939	: V=0.9995778, theta=-60.743268 -> V=1.0, theta=0.0
% INFO    : Bus 8940	: V=0.9926028, theta=-61.901029 -> V=1.0, theta=0.0
% INFO    : Bus 8941	: V=0.9842918, theta=-61.689224 -> V=1.0, theta=0.0
% INFO    : Bus 8942	: V=1.0050541, theta=-60.257945 -> V=1.0, theta=0.0
% INFO    : Bus 8943	: V=1.0097396, theta=-59.643044 -> V=1.0, theta=0.0
% INFO    : Bus 8944	: V=0.9862583, theta=-61.63336 -> V=1.0, theta=0.0
% INFO    : Bus 8945	: V=0.9994394, theta=-60.71705 -> V=1.0, theta=0.0
% INFO    : Bus 8946	: V=1.0054454, theta=-60.299298 -> V=1.0, theta=0.0
% INFO    : Bus 8947	: V=1.0057298, theta=-60.319172 -> V=1.0, theta=0.0
% INFO    : Bus 8948	: V=0.996767, theta=-61.122672 -> V=1.0, theta=0.0
% INFO    : Bus 8949	: V=1.0012982, theta=-60.531024 -> V=1.0, theta=0.0
% INFO    : Bus 8950	: V=1.0056744, theta=-60.029155 -> V=1.0, theta=0.0
% INFO    : Bus 8951	: V=1.0031655, theta=-60.335569 -> V=1.0, theta=0.0
% INFO    : Bus 8952	: V=0.9866553, theta=-61.080681 -> V=1.0, theta=0.0
% INFO    : Bus 8953	: V=1.000843, theta=-60.430741 -> V=1.0, theta=0.0
% INFO    : Bus 8954	: V=1.0053203, theta=-59.819269 -> V=1.0, theta=0.0
% INFO    : Bus 8955	: V=1.0053174, theta=-59.8945 -> V=1.0, theta=0.0
% INFO    : Bus 8956	: V=0.9798025, theta=-61.018529 -> V=1.0, theta=0.0
% INFO    : Bus 8957	: V=0.9691474, theta=-61.645064 -> V=1.0, theta=0.0
% INFO    : Bus 8958	: V=0.9717571, theta=-61.671813 -> V=1.0, theta=0.0
% INFO    : Bus 8959	: V=0.9761562, theta=-60.90782 -> V=1.0, theta=0.0
% INFO    : Bus 8960	: V=0.972222, theta=-61.420082 -> V=1.0, theta=0.0
% INFO    : Bus 8961	: V=0.9754532, theta=-61.011311 -> V=1.0, theta=0.0
% INFO    : Bus 8962	: V=0.9748848, theta=-61.116082 -> V=1.0, theta=0.0
% INFO    : Bus 8963	: V=0.974142, theta=-61.277704 -> V=1.0, theta=0.0
% INFO    : Bus 8964	: V=0.9709742, theta=-61.670839 -> V=1.0, theta=0.0
% INFO    : Bus 8965	: V=0.9840011, theta=-61.343106 -> V=1.0, theta=0.0
% INFO    : Bus 8966	: V=0.9658322, theta=-62.484904 -> V=1.0, theta=0.0
% INFO    : Bus 8967	: V=0.9671928, theta=-62.410404 -> V=1.0, theta=0.0
% INFO    : Bus 8968	: V=0.9677587, theta=-62.394996 -> V=1.0, theta=0.0
% INFO    : Bus 8969	: V=0.9867212, theta=-61.731681 -> V=1.0, theta=0.0
% INFO    : Bus 8970	: V=0.9858318, theta=-61.684338 -> V=1.0, theta=0.0
% INFO    : Bus 8971	: V=0.9856779, theta=-61.716061 -> V=1.0, theta=0.0
% INFO    : Bus 8972	: V=0.981762, theta=-61.852242 -> V=1.0, theta=0.0
% INFO    : Bus 8973	: V=0.9807584, theta=-61.91179 -> V=1.0, theta=0.0
% INFO    : Bus 8974	: V=0.9827399, theta=-61.845808 -> V=1.0, theta=0.0
% INFO    : Bus 8975	: V=0.9857369, theta=-61.742555 -> V=1.0, theta=0.0
% INFO    : Bus 8976	: V=0.9984393, theta=-60.833011 -> V=1.0, theta=0.0
% INFO    : Bus 8977	: V=0.9960853, theta=-60.968275 -> V=1.0, theta=0.0
% INFO    : Bus 8978	: V=0.9846659, theta=-61.827209 -> V=1.0, theta=0.0
% INFO    : Bus 8979	: V=0.99473, theta=-61.046182 -> V=1.0, theta=0.0
% INFO    : Bus 8980	: V=0.978324, theta=-61.979135 -> V=1.0, theta=0.0
% INFO    : Bus 8981	: V=0.9644772, theta=-62.52903 -> V=1.0, theta=0.0
% INFO    : Bus 8982	: V=0.9654593, theta=-62.502422 -> V=1.0, theta=0.0
% INFO    : Bus 8983	: V=0.9634308, theta=-62.534855 -> V=1.0, theta=0.0
% INFO    : Bus 8984	: V=0.9638744, theta=-62.573327 -> V=1.0, theta=0.0
% INFO    : Bus 8985	: V=0.964366, theta=-62.753159 -> V=1.0, theta=0.0
% INFO    : Bus 8986	: V=0.9648066, theta=-62.609914 -> V=1.0, theta=0.0
% INFO    : Bus 8987	: V=0.9694552, theta=-62.410143 -> V=1.0, theta=0.0
% INFO    : Bus 8988	: V=0.9727379, theta=-62.24786 -> V=1.0, theta=0.0
% INFO    : Bus 8989	: V=0.9663517, theta=-62.558675 -> V=1.0, theta=0.0
% INFO    : Bus 8990	: V=0.9659958, theta=-62.571172 -> V=1.0, theta=0.0
% INFO    : Bus 8991	: V=0.9659293, theta=-62.562813 -> V=1.0, theta=0.0
% INFO    : Bus 8992	: V=0.9653241, theta=-62.582592 -> V=1.0, theta=0.0
% INFO    : Bus 8993	: V=0.9627392, theta=-62.594358 -> V=1.0, theta=0.0
% INFO    : Bus 8994	: V=0.9634125, theta=-62.541529 -> V=1.0, theta=0.0
% INFO    : Bus 8995	: V=0.9650335, theta=-62.52053 -> V=1.0, theta=0.0
% INFO    : Bus 8996	: V=0.9660492, theta=-61.803191 -> V=1.0, theta=0.0
% INFO    : Bus 8997	: V=0.9622171, theta=-61.48223 -> V=1.0, theta=0.0
% INFO    : Bus 8998	: V=0.9646478, theta=-61.812009 -> V=1.0, theta=0.0
% INFO    : Bus 8999	: V=0.962179, theta=-58.200237 -> V=1.0, theta=0.0
% INFO    : Bus 9000	: V=0.9515089, theta=-62.013808 -> V=1.0, theta=0.0
% INFO    : Bus 9001	: V=0.9621412, theta=-61.360406 -> V=1.0, theta=0.0
% INFO    : Bus 9002	: V=0.9611821, theta=-62.612802 -> V=1.0, theta=0.0
% INFO    : Bus 9003	: V=0.9580785, theta=-62.11696 -> V=1.0, theta=0.0
% INFO    : Bus 9004	: V=0.9639008, theta=-60.961129 -> V=1.0, theta=0.0
% INFO    : Bus 9005	: V=0.9626164, theta=-61.236975 -> V=1.0, theta=0.0
% INFO    : Bus 9006	: V=0.9612978, theta=-62.431216 -> V=1.0, theta=0.0
% INFO    : Bus 9007	: V=0.9618408, theta=-62.390355 -> V=1.0, theta=0.0
% INFO    : Bus 9008	: V=0.9598085, theta=-62.138687 -> V=1.0, theta=0.0
% INFO    : Bus 9009	: V=0.9595758, theta=-62.221266 -> V=1.0, theta=0.0
% INFO    : Bus 9010	: V=0.9578243, theta=-62.101093 -> V=1.0, theta=0.0
% INFO    : Bus 9011	: V=0.9583053, theta=-62.205997 -> V=1.0, theta=0.0
% INFO    : Bus 9012	: V=0.9598414, theta=-61.425022 -> V=1.0, theta=0.0
% INFO    : Bus 9013	: V=0.9549806, theta=-62.124638 -> V=1.0, theta=0.0
% INFO    : Bus 9014	: V=0.9596955, theta=-62.457112 -> V=1.0, theta=0.0
% INFO    : Bus 9015	: V=0.9586069, theta=-62.510932 -> V=1.0, theta=0.0
% INFO    : Bus 9016	: V=1.0036831, theta=-60.005949 -> V=1.0, theta=0.0
% INFO    : Bus 9017	: V=0.9998506, theta=-60.082193 -> V=1.0, theta=0.0
% INFO    : Bus 9018	: V=0.9804003, theta=-61.092487 -> V=1.0, theta=0.0
% INFO    : Bus 9019	: V=0.9898615, theta=-61.100979 -> V=1.0, theta=0.0
% INFO    : Bus 9020	: V=0.9720741, theta=-57.383779 -> V=1.0, theta=0.0
% INFO    : Bus 9021	: V=0.9778068, theta=-60.965994 -> V=1.0, theta=0.0
% INFO    : Bus 9022	: V=0.9869709, theta=-60.727579 -> V=1.0, theta=0.0
% INFO    : Bus 9023	: V=0.9963109, theta=-60.404373 -> V=1.0, theta=0.0
% INFO    : Bus 9024	: V=0.9859723, theta=-60.74591 -> V=1.0, theta=0.0
% INFO    : Bus 9025	: V=0.981686, theta=-61.547382 -> V=1.0, theta=0.0
% INFO    : Bus 9026	: V=0.9837526, theta=-61.122587 -> V=1.0, theta=0.0
% INFO    : Bus 9027	: V=0.9805154, theta=-61.434079 -> V=1.0, theta=0.0
% INFO    : Bus 9028	: V=0.9809298, theta=-61.43169 -> V=1.0, theta=0.0
% INFO    : Bus 9029	: V=0.9890107, theta=-61.378007 -> V=1.0, theta=0.0
% INFO    : Bus 9030	: V=0.9873588, theta=-61.481855 -> V=1.0, theta=0.0
% INFO    : Bus 9031	: V=0.979808, theta=-61.682547 -> V=1.0, theta=0.0
% INFO    : Bus 9032	: V=0.9859488, theta=-61.569743 -> V=1.0, theta=0.0
% INFO    : Bus 9033	: V=0.985201, theta=-61.57559 -> V=1.0, theta=0.0
% INFO    : Bus 9034	: V=0.9805808, theta=-61.681055 -> V=1.0, theta=0.0
% INFO    : Bus 9035	: V=0.9832486, theta=-61.053839 -> V=1.0, theta=0.0
% INFO    : Bus 9036	: V=0.9908878, theta=-60.716234 -> V=1.0, theta=0.0
% INFO    : Bus 9037	: V=0.9843831, theta=-61.119353 -> V=1.0, theta=0.0
% INFO    : Bus 9038	: V=0.9853368, theta=-61.034879 -> V=1.0, theta=0.0
% INFO    : Bus 9039	: V=0.9936573, theta=-60.474502 -> V=1.0, theta=0.0
% INFO    : Bus 9040	: V=0.9973727, theta=-59.680414 -> V=1.0, theta=0.0
% INFO    : Bus 9041	: V=0.9903043, theta=-60.291361 -> V=1.0, theta=0.0
% INFO    : Bus 9042	: V=0.9793073, theta=-61.7666 -> V=1.0, theta=0.0
% INFO    : Bus 9043	: V=0.9841252, theta=-61.57736 -> V=1.0, theta=0.0
% INFO    : Bus 9044	: V=0.9845874, theta=-61.577468 -> V=1.0, theta=0.0
% INFO    : Bus 9045	: V=0.9813742, theta=-61.900752 -> V=1.0, theta=0.0
% INFO    : Bus 9046	: V=0.9819757, theta=-61.871009 -> V=1.0, theta=0.0
% INFO    : Bus 9047	: V=0.9802094, theta=-62.059458 -> V=1.0, theta=0.0
% INFO    : Bus 9048	: V=0.9853251, theta=-61.653295 -> V=1.0, theta=0.0
% INFO    : Bus 9049	: V=0.983008, theta=-61.815317 -> V=1.0, theta=0.0
% INFO    : Bus 9050	: V=0.9835332, theta=-61.56683 -> V=1.0, theta=0.0
% INFO    : Bus 9051	: V=0.9824286, theta=-61.617154 -> V=1.0, theta=0.0
% INFO    : Bus 9052	: V=0.9668378, theta=-62.522392 -> V=1.0, theta=0.0
% INFO    : Bus 9053	: V=0.9681239, theta=-62.47985 -> V=1.0, theta=0.0
% INFO    : Bus 9054	: V=0.9784157, theta=-61.095781 -> V=1.0, theta=0.0
% INFO    : Bus 9055	: V=0.9789012, theta=-61.683264 -> V=1.0, theta=0.0
% INFO    : Bus 9056	: V=0.9689566, theta=-60.972645 -> V=1.0, theta=0.0
% INFO    : Bus 9057	: V=0.9643082, theta=-61.352441 -> V=1.0, theta=0.0
% INFO    : Bus 9058	: V=0.9699648, theta=-60.884484 -> V=1.0, theta=0.0
% INFO    : Bus 9059	: V=0.9610585, theta=-62.021853 -> V=1.0, theta=0.0
% INFO    : Bus 9060	: V=0.9680501, theta=-61.057665 -> V=1.0, theta=0.0
% INFO    : Bus 9061	: V=0.9811552, theta=-60.894461 -> V=1.0, theta=0.0
% INFO    : Bus 9062	: V=0.9800749, theta=-60.972414 -> V=1.0, theta=0.0
% INFO    : Bus 9063	: V=0.9793442, theta=-61.025152 -> V=1.0, theta=0.0
% INFO    : Bus 9064	: V=0.9727631, theta=-61.510127 -> V=1.0, theta=0.0
% INFO    : Bus 9065	: V=0.9851837, theta=-61.34982 -> V=1.0, theta=0.0
% INFO    : Bus 9066	: V=0.9845495, theta=-60.669403 -> V=1.0, theta=0.0
% INFO    : Bus 9067	: V=0.979045, theta=-61.143962 -> V=1.0, theta=0.0
% INFO    : Bus 9068	: V=0.9841533, theta=-61.027045 -> V=1.0, theta=0.0
% INFO    : Bus 9069	: V=0.9795872, theta=-61.663542 -> V=1.0, theta=0.0
% INFO    : Bus 9070	: V=0.9861961, theta=-61.215243 -> V=1.0, theta=0.0
% INFO    : Bus 9071	: V=0.9870508, theta=-61.106936 -> V=1.0, theta=0.0
% INFO    : Bus 9072	: V=0.9810558, theta=-61.105464 -> V=1.0, theta=0.0
% INFO    : Bus 9073	: V=0.987302, theta=-60.357681 -> V=1.0, theta=0.0
% INFO    : Bus 9074	: V=0.991897, theta=-60.113676 -> V=1.0, theta=0.0
% INFO    : Bus 9075	: V=0.9909414, theta=-60.145831 -> V=1.0, theta=0.0
% INFO    : Bus 9076	: V=0.9872513, theta=-60.120321 -> V=1.0, theta=0.0
% INFO    : Bus 9077	: V=0.9879512, theta=-60.351385 -> V=1.0, theta=0.0
% INFO    : Bus 9078	: V=0.9800967, theta=-61.082019 -> V=1.0, theta=0.0
% INFO    : Bus 9079	: V=0.9771747, theta=-61.181168 -> V=1.0, theta=0.0
% INFO    : Bus 9080	: V=0.9784539, theta=-61.136927 -> V=1.0, theta=0.0
% INFO    : Bus 9081	: V=0.9770126, theta=-61.160525 -> V=1.0, theta=0.0
% INFO    : Bus 9082	: V=0.9753849, theta=-61.214416 -> V=1.0, theta=0.0
% INFO    : Bus 9083	: V=0.983463, theta=-60.73885 -> V=1.0, theta=0.0
% INFO    : Bus 9084	: V=0.9735218, theta=-61.509641 -> V=1.0, theta=0.0
% INFO    : Bus 9085	: V=0.9820911, theta=-60.829852 -> V=1.0, theta=0.0
% INFO    : Bus 9086	: V=0.9761708, theta=-61.250126 -> V=1.0, theta=0.0
% INFO    : Bus 9087	: V=0.9712305, theta=-60.780248 -> V=1.0, theta=0.0
% INFO    : Bus 9088	: V=0.97237, theta=-61.282739 -> V=1.0, theta=0.0
% INFO    : Bus 9089	: V=0.9720427, theta=-61.202469 -> V=1.0, theta=0.0
% INFO    : Bus 9090	: V=0.9775514, theta=-61.143673 -> V=1.0, theta=0.0
% INFO    : Bus 9091	: V=0.9903069, theta=-60.132584 -> V=1.0, theta=0.0
% INFO    : Bus 9092	: V=0.9774159, theta=-61.114417 -> V=1.0, theta=0.0
% INFO    : Bus 9093	: V=0.9731761, theta=-61.188042 -> V=1.0, theta=0.0
% INFO    : Bus 9094	: V=0.9678246, theta=-61.345903 -> V=1.0, theta=0.0
% INFO    : Bus 9095	: V=0.9723997, theta=-60.495558 -> V=1.0, theta=0.0
% INFO    : Bus 9096	: V=0.9671164, theta=-61.390687 -> V=1.0, theta=0.0
% INFO    : Bus 9097	: V=0.964104, theta=-61.642427 -> V=1.0, theta=0.0
% INFO    : Bus 9098	: V=0.9608413, theta=-61.992051 -> V=1.0, theta=0.0
% INFO    : Bus 9099	: V=0.9604834, theta=-61.677896 -> V=1.0, theta=0.0
% INFO    : Bus 9100	: V=0.9605486, theta=-61.595412 -> V=1.0, theta=0.0
% INFO    : Bus 9101	: V=0.9652674, theta=-61.539905 -> V=1.0, theta=0.0
% INFO    : Bus 9102	: V=0.966381, theta=-61.45146 -> V=1.0, theta=0.0
% INFO    : Bus 9103	: V=0.9610318, theta=-61.485014 -> V=1.0, theta=0.0
% INFO    : Bus 9104	: V=0.9615022, theta=-61.273901 -> V=1.0, theta=0.0
% INFO    : Bus 9105	: V=0.9703351, theta=-60.551219 -> V=1.0, theta=0.0
% INFO    : Bus 9106	: V=0.959803, theta=-61.220633 -> V=1.0, theta=0.0
% INFO    : Bus 9107	: V=0.9649903, theta=-60.9727 -> V=1.0, theta=0.0
% INFO    : Bus 9108	: V=0.9662942, theta=-60.90357 -> V=1.0, theta=0.0
% INFO    : Bus 9109	: V=0.9711898, theta=-60.505148 -> V=1.0, theta=0.0
% INFO    : Bus 9110	: V=0.9733682, theta=-60.394717 -> V=1.0, theta=0.0
% INFO    : Bus 9111	: V=0.9727979, theta=-60.455606 -> V=1.0, theta=0.0
% INFO    : Bus 9112	: V=0.9716312, theta=-61.090544 -> V=1.0, theta=0.0
% INFO    : Bus 9113	: V=0.9677189, theta=-60.812248 -> V=1.0, theta=0.0
% INFO    : Bus 9114	: V=0.9633914, theta=-61.1619 -> V=1.0, theta=0.0
% INFO    : Bus 9115	: V=0.961619, theta=-61.189191 -> V=1.0, theta=0.0
% INFO    : Bus 9116	: V=0.9666715, theta=-61.017771 -> V=1.0, theta=0.0
% INFO    : Bus 9117	: V=0.9762017, theta=-60.156292 -> V=1.0, theta=0.0
% INFO    : Bus 9118	: V=0.9751441, theta=-60.240303 -> V=1.0, theta=0.0
% INFO    : Bus 9119	: V=0.9609052, theta=-61.020921 -> V=1.0, theta=0.0
% INFO    : Bus 9120	: V=0.9610672, theta=-60.980306 -> V=1.0, theta=0.0
% INFO    : Bus 9121	: V=0.9606285, theta=-60.499675 -> V=1.0, theta=0.0
% INFO    : Bus 9122	: V=0.9619461, theta=-60.901909 -> V=1.0, theta=0.0
% INFO    : Bus 9123	: V=0.9625994, theta=-61.104538 -> V=1.0, theta=0.0
% INFO    : Bus 9124	: V=0.9616978, theta=-61.101359 -> V=1.0, theta=0.0
% INFO    : Bus 9125	: V=0.9616737, theta=-61.207676 -> V=1.0, theta=0.0
% INFO    : Bus 9126	: V=0.9681304, theta=-60.234957 -> V=1.0, theta=0.0
% INFO    : Bus 9127	: V=0.9669383, theta=-60.420587 -> V=1.0, theta=0.0
% INFO    : Bus 9128	: V=0.9545007, theta=-60.322178 -> V=1.0, theta=0.0
% INFO    : Bus 9129	: V=0.9530998, theta=-60.363678 -> V=1.0, theta=0.0
% INFO    : Bus 9130	: V=0.9577357, theta=-59.044377 -> V=1.0, theta=0.0
% INFO    : Bus 9131	: V=0.9575728, theta=-59.655005 -> V=1.0, theta=0.0
% INFO    : Bus 9132	: V=0.9563288, theta=-60.15787 -> V=1.0, theta=0.0
% INFO    : Bus 9133	: V=0.9624894, theta=-59.535292 -> V=1.0, theta=0.0
% INFO    : Bus 9134	: V=0.9712466, theta=-59.323687 -> V=1.0, theta=0.0
% INFO    : Bus 9135	: V=0.969907, theta=-59.715281 -> V=1.0, theta=0.0
% INFO    : Bus 9136	: V=0.9635641, theta=-59.939978 -> V=1.0, theta=0.0
% INFO    : Bus 9137	: V=0.9717783, theta=-58.443112 -> V=1.0, theta=0.0
% INFO    : Bus 9138	: V=0.9925669, theta=-61.154036 -> V=1.0, theta=0.0
% INFO    : Bus 9139	: V=0.9915709, theta=-61.212418 -> V=1.0, theta=0.0
% INFO    : Bus 9140	: V=0.9948085, theta=-60.647336 -> V=1.0, theta=0.0
% INFO    : Bus 9141	: V=0.978639, theta=-61.805031 -> V=1.0, theta=0.0
% INFO    : Bus 9142	: V=0.9824736, theta=-62.026669 -> V=1.0, theta=0.0
% INFO    : Bus 9143	: V=0.9896994, theta=-60.217588 -> V=1.0, theta=0.0
% INFO    : Bus 9144	: V=0.9930607, theta=-60.074142 -> V=1.0, theta=0.0
% INFO    : Bus 9145	: V=0.9893455, theta=-60.180373 -> V=1.0, theta=0.0
% INFO    : Bus 9146	: V=0.9720797, theta=-60.458742 -> V=1.0, theta=0.0
% INFO    : Bus 9147	: V=0.9745701, theta=-60.176229 -> V=1.0, theta=0.0
% INFO    : Bus 9148	: V=0.9591144, theta=-61.061802 -> V=1.0, theta=0.0
% INFO    : Bus 9149	: V=0.9600036, theta=-59.039048 -> V=1.0, theta=0.0
% INFO    : Bus 9150	: V=0.988394, theta=-60.943372 -> V=1.0, theta=0.0
% INFO    : Bus 9151	: V=0.9901052, theta=-60.191918 -> V=1.0, theta=0.0
% INFO    : Bus 9152	: V=1.0076351, theta=-52.429081 -> V=1.0, theta=0.0
% INFO    : Bus 9153	: V=1.0061722, theta=-52.477034 -> V=1.0, theta=0.0
% INFO    : Bus 9154	: V=1.0074444, theta=-52.429192 -> V=1.0, theta=0.0
% INFO    : Bus 9155	: V=1.0049326, theta=-52.503728 -> V=1.0, theta=0.0
% INFO    : Bus 9156	: V=1.0032315, theta=-52.50914 -> V=1.0, theta=0.0
% INFO    : Bus 9157	: V=1.003694, theta=-52.508293 -> V=1.0, theta=0.0
% INFO    : Bus 9158	: V=1.0182671, theta=-51.748665 -> V=1.0, theta=0.0
% INFO    : Bus 9159	: V=0.9949908, theta=-54.001599 -> V=1.0, theta=0.0
% INFO    : Bus 9160	: V=0.9827803, theta=-55.008672 -> V=1.0, theta=0.0
% INFO    : Bus 9161	: V=0.9868763, theta=-54.938408 -> V=1.0, theta=0.0
% INFO    : Bus 9162	: V=0.9864731, theta=-55.04626 -> V=1.0, theta=0.0
% INFO    : Bus 9163	: V=0.9858209, theta=-54.757606 -> V=1.0, theta=0.0
% INFO    : Bus 9164	: V=0.9873424, theta=-54.564216 -> V=1.0, theta=0.0
% INFO    : Bus 9165	: V=0.9807002, theta=-54.989052 -> V=1.0, theta=0.0
% INFO    : Bus 9166	: V=0.9847858, theta=-54.743162 -> V=1.0, theta=0.0
% INFO    : Bus 9167	: V=0.9849974, theta=-54.716451 -> V=1.0, theta=0.0
% INFO    : Bus 9168	: V=0.9970428, theta=-54.079507 -> V=1.0, theta=0.0
% INFO    : Bus 9169	: V=0.9904283, theta=-54.601132 -> V=1.0, theta=0.0
% INFO    : Bus 9170	: V=0.9821694, theta=-54.987336 -> V=1.0, theta=0.0
% INFO    : Bus 9171	: V=0.9823415, theta=-55.004488 -> V=1.0, theta=0.0
% INFO    : Bus 9172	: V=0.9831672, theta=-54.99636 -> V=1.0, theta=0.0
% INFO    : Bus 9173	: V=0.981613, theta=-55.007501 -> V=1.0, theta=0.0
% INFO    : Bus 9174	: V=0.9919975, theta=-54.381264 -> V=1.0, theta=0.0
% INFO    : Bus 9175	: V=0.9919609, theta=-54.451652 -> V=1.0, theta=0.0
% INFO    : Bus 9176	: V=0.9988265, theta=-54.172114 -> V=1.0, theta=0.0
% INFO    : Bus 9177	: V=1.0000725, theta=-54.16658 -> V=1.0, theta=0.0
% INFO    : Bus 9178	: V=0.9938055, theta=-54.325588 -> V=1.0, theta=0.0
% INFO    : Bus 9179	: V=0.9925867, theta=-54.326888 -> V=1.0, theta=0.0
% INFO    : Bus 9180	: V=0.9921556, theta=-54.491627 -> V=1.0, theta=0.0
% INFO    : Bus 9181	: V=1.0030689, theta=-54.006728 -> V=1.0, theta=0.0
% INFO    : Bus 9182	: V=1.0080407, theta=-53.798404 -> V=1.0, theta=0.0
% INFO    : Bus 9183	: V=1.007266, theta=-53.841142 -> V=1.0, theta=0.0
% INFO    : Bus 9184	: V=1.0009991, theta=-54.473281 -> V=1.0, theta=0.0
% INFO    : Bus 9185	: V=0.9870131, theta=-55.203794 -> V=1.0, theta=0.0
% INFO    : Bus 9186	: V=0.9898932, theta=-55.261569 -> V=1.0, theta=0.0
% INFO    : Bus 9187	: V=0.99359, theta=-55.327253 -> V=1.0, theta=0.0
% INFO    : Bus 9188	: V=0.9906991, theta=-55.328954 -> V=1.0, theta=0.0
% INFO    : Bus 9189	: V=1.0080626, theta=-54.607676 -> V=1.0, theta=0.0
% INFO    : Bus 9190	: V=1.0000903, theta=-54.966474 -> V=1.0, theta=0.0
% INFO    : Bus 9191	: V=1.0102954, theta=-54.435903 -> V=1.0, theta=0.0
% INFO    : Bus 9192	: V=1.0080225, theta=-54.649902 -> V=1.0, theta=0.0
% INFO    : Bus 9193	: V=1.0032177, theta=-55.295967 -> V=1.0, theta=0.0
% INFO    : Bus 9194	: V=1.0049622, theta=-54.934549 -> V=1.0, theta=0.0
% INFO    : Bus 9195	: V=1.0071153, theta=-54.758522 -> V=1.0, theta=0.0
% INFO    : Bus 9196	: V=1.0070691, theta=-54.759109 -> V=1.0, theta=0.0
% INFO    : Bus 9197	: V=1.00702, theta=-54.780162 -> V=1.0, theta=0.0
% INFO    : Bus 9198	: V=1.007015, theta=-54.797054 -> V=1.0, theta=0.0
% INFO    : Bus 9199	: V=1.0074452, theta=-54.72523 -> V=1.0, theta=0.0
% INFO    : Bus 9200	: V=1.0073664, theta=-54.726097 -> V=1.0, theta=0.0
% INFO    : Bus 9201	: V=0.9991837, theta=-55.080604 -> V=1.0, theta=0.0
% INFO    : Bus 9202	: V=1.0109831, theta=-54.119196 -> V=1.0, theta=0.0
% INFO    : Bus 9203	: V=1.0111917, theta=-54.086995 -> V=1.0, theta=0.0
% INFO    : Bus 9204	: V=0.9978989, theta=-55.215095 -> V=1.0, theta=0.0
% INFO    : Bus 9205	: V=0.9973286, theta=-55.178926 -> V=1.0, theta=0.0
% INFO    : Bus 9206	: V=1.0135438, theta=-53.918748 -> V=1.0, theta=0.0
% INFO    : Bus 9207	: V=0.9870713, theta=-56.056855 -> V=1.0, theta=0.0
% INFO    : Bus 9208	: V=0.9944805, theta=-55.739009 -> V=1.0, theta=0.0
% INFO    : Bus 9209	: V=1.0006148, theta=-55.218341 -> V=1.0, theta=0.0
% INFO    : Bus 9210	: V=0.9874814, theta=-55.992994 -> V=1.0, theta=0.0
% INFO    : Bus 9211	: V=0.9991939, theta=-55.155491 -> V=1.0, theta=0.0
% INFO    : Bus 9212	: V=0.9900885, theta=-55.822374 -> V=1.0, theta=0.0
% INFO    : Bus 9213	: V=0.9981275, theta=-55.24817 -> V=1.0, theta=0.0
% INFO    : Bus 9214	: V=0.991508, theta=-56.004543 -> V=1.0, theta=0.0
% INFO    : Bus 9215	: V=1.0062425, theta=-54.538209 -> V=1.0, theta=0.0
% INFO    : Bus 9216	: V=0.9968994, theta=-55.54906 -> V=1.0, theta=0.0
% INFO    : Bus 9217	: V=0.9823488, theta=-62.421041 -> V=1.0, theta=0.0
% INFO    : Bus 9218	: V=0.9888943, theta=-61.922275 -> V=1.0, theta=0.0
% INFO    : Bus 9219	: V=0.9883624, theta=-61.94866 -> V=1.0, theta=0.0
% INFO    : Bus 9220	: V=0.9827767, theta=-62.393809 -> V=1.0, theta=0.0
% INFO    : Bus 9221	: V=0.9831326, theta=-62.331754 -> V=1.0, theta=0.0
% INFO    : Bus 9222	: V=0.9832539, theta=-62.331414 -> V=1.0, theta=0.0
% INFO    : Bus 9223	: V=0.9888072, theta=-61.683411 -> V=1.0, theta=0.0
% INFO    : Bus 9224	: V=0.9840414, theta=-62.24058 -> V=1.0, theta=0.0
% INFO    : Bus 9225	: V=0.9895854, theta=-61.648228 -> V=1.0, theta=0.0
% INFO    : Bus 9226	: V=0.9909189, theta=-61.581421 -> V=1.0, theta=0.0
% INFO    : Bus 9227	: V=0.991066, theta=-61.571464 -> V=1.0, theta=0.0
% INFO    : Bus 9228	: V=0.9879554, theta=-61.781318 -> V=1.0, theta=0.0
% INFO    : Bus 9229	: V=0.9880596, theta=-61.777515 -> V=1.0, theta=0.0
% INFO    : Bus 9230	: V=0.9845165, theta=-62.169757 -> V=1.0, theta=0.0
% INFO    : Bus 9231	: V=0.9852763, theta=-62.008385 -> V=1.0, theta=0.0
% INFO    : Bus 9232	: V=0.9842509, theta=-62.171022 -> V=1.0, theta=0.0
% INFO    : Bus 9233	: V=0.9881267, theta=-61.772527 -> V=1.0, theta=0.0
% INFO    : Bus 9234	: V=0.9889913, theta=-61.652879 -> V=1.0, theta=0.0
% INFO    : Bus 9235	: V=0.9867787, theta=-61.793328 -> V=1.0, theta=0.0
% INFO    : Bus 9236	: V=0.9869724, theta=-61.763298 -> V=1.0, theta=0.0
% INFO    : Bus 9237	: V=0.9870929, theta=-61.782541 -> V=1.0, theta=0.0
% INFO    : Bus 9238	: V=0.987667, theta=-61.739436 -> V=1.0, theta=0.0
% INFO    : Bus 9239	: V=0.9871501, theta=-61.737117 -> V=1.0, theta=0.0
% INFO    : Bus 9240	: V=0.982826, theta=-62.243766 -> V=1.0, theta=0.0
% INFO    : Bus 9241	: V=0.9826543, theta=-62.260037 -> V=1.0, theta=0.0
% INFO    : Bus 9242	: V=0.9898938, theta=-61.595949 -> V=1.0, theta=0.0
% INFO    : Bus 9243	: V=0.9878551, theta=-61.780116 -> V=1.0, theta=0.0
% INFO    : Bus 9244	: V=0.9914923, theta=-61.532845 -> V=1.0, theta=0.0
% INFO    : Bus 9245	: V=0.9871358, theta=-61.814814 -> V=1.0, theta=0.0
% INFO    : Bus 9246	: V=0.9908008, theta=-61.528336 -> V=1.0, theta=0.0
% INFO    : Bus 9247	: V=0.9909431, theta=-61.553983 -> V=1.0, theta=0.0
% INFO    : Bus 9248	: V=0.9880658, theta=-61.774234 -> V=1.0, theta=0.0
% INFO    : Bus 9249	: V=0.9913851, theta=-61.496743 -> V=1.0, theta=0.0
% INFO    : Bus 9250	: V=0.9879128, theta=-61.641827 -> V=1.0, theta=0.0
% INFO    : Bus 9251	: V=0.9870357, theta=-61.724933 -> V=1.0, theta=0.0
% INFO    : Bus 9252	: V=0.9866893, theta=-61.743744 -> V=1.0, theta=0.0
% INFO    : Bus 9253	: V=0.9863268, theta=-61.766248 -> V=1.0, theta=0.0
% INFO    : Bus 9254	: V=0.9923739, theta=-61.471386 -> V=1.0, theta=0.0
% INFO    : Bus 9255	: V=0.9933126, theta=-61.29885 -> V=1.0, theta=0.0
% INFO    : Bus 9256	: V=0.9930663, theta=-61.363456 -> V=1.0, theta=0.0
% INFO    : Bus 9257	: V=0.9944808, theta=-61.222138 -> V=1.0, theta=0.0
% INFO    : Bus 9258	: V=0.9931454, theta=-61.339243 -> V=1.0, theta=0.0
% INFO    : Bus 9259	: V=0.9930051, theta=-61.39345 -> V=1.0, theta=0.0
% INFO    : Bus 9260	: V=0.9898905, theta=-61.622258 -> V=1.0, theta=0.0
% INFO    : Bus 9261	: V=0.9873822, theta=-61.697177 -> V=1.0, theta=0.0
% INFO    : Bus 9262	: V=0.9876864, theta=-61.67369 -> V=1.0, theta=0.0
% INFO    : Bus 9263	: V=0.9882679, theta=-61.634152 -> V=1.0, theta=0.0
% INFO    : Bus 9264	: V=0.9937743, theta=-61.393409 -> V=1.0, theta=0.0
% INFO    : Bus 9265	: V=0.9920484, theta=-61.511137 -> V=1.0, theta=0.0
% INFO    : Bus 9266	: V=0.991388, theta=-61.544644 -> V=1.0, theta=0.0
% INFO    : Bus 9267	: V=0.9887414, theta=-61.83989 -> V=1.0, theta=0.0
% INFO    : Bus 9268	: V=0.9934426, theta=-61.439202 -> V=1.0, theta=0.0
% INFO    : Bus 9269	: V=1.006379, theta=-60.326292 -> V=1.0, theta=0.0
% INFO    : Bus 9270	: V=0.9944515, theta=-61.445455 -> V=1.0, theta=0.0
% INFO    : Bus 9271	: V=0.9966444, theta=-61.319047 -> V=1.0, theta=0.0
% INFO    : Bus 9272	: V=0.9967104, theta=-61.315655 -> V=1.0, theta=0.0
% INFO    : Bus 9273	: V=0.9966689, theta=-61.322774 -> V=1.0, theta=0.0
% INFO    : Bus 9274	: V=0.9966566, theta=-61.328774 -> V=1.0, theta=0.0
% INFO    : Bus 9275	: V=0.9988983, theta=-61.165434 -> V=1.0, theta=0.0
% INFO    : Bus 9276	: V=0.9971513, theta=-61.397153 -> V=1.0, theta=0.0
% INFO    : Bus 9277	: V=0.9990365, theta=-61.22708 -> V=1.0, theta=0.0
% INFO    : Bus 9278	: V=0.9877548, theta=-61.943146 -> V=1.0, theta=0.0
% INFO    : Bus 9279	: V=0.9932621, theta=-61.542189 -> V=1.0, theta=0.0
% INFO    : Bus 9280	: V=0.9942536, theta=-61.457902 -> V=1.0, theta=0.0
% INFO    : Bus 9281	: V=0.9926214, theta=-61.5928 -> V=1.0, theta=0.0
% INFO    : Bus 9282	: V=0.9917915, theta=-61.63958 -> V=1.0, theta=0.0
% INFO    : Bus 9283	: V=0.9931676, theta=-61.493282 -> V=1.0, theta=0.0
% INFO    : Bus 9284	: V=0.9910244, theta=-61.563319 -> V=1.0, theta=0.0
% INFO    : Bus 9285	: V=0.9848196, theta=-62.206594 -> V=1.0, theta=0.0
% INFO    : Bus 9286	: V=0.9847076, theta=-62.206923 -> V=1.0, theta=0.0
% INFO    : Bus 9287	: V=0.9846474, theta=-62.204866 -> V=1.0, theta=0.0
% INFO    : Bus 9288	: V=0.9848647, theta=-62.180613 -> V=1.0, theta=0.0
% INFO    : Bus 9289	: V=0.9842591, theta=-62.227624 -> V=1.0, theta=0.0
% INFO    : Bus 9290	: V=0.9908645, theta=-61.82682 -> V=1.0, theta=0.0
% INFO    : Bus 9291	: V=0.9900782, theta=-61.863829 -> V=1.0, theta=0.0
% INFO    : Bus 9292	: V=0.9894544, theta=-61.894501 -> V=1.0, theta=0.0
% INFO    : Bus 9293	: V=0.9830228, theta=-62.404137 -> V=1.0, theta=0.0
% INFO    : Bus 9294	: V=0.9904699, theta=-62.015781 -> V=1.0, theta=0.0
% INFO    : Bus 9295	: V=0.9900421, theta=-62.076854 -> V=1.0, theta=0.0
% INFO    : Bus 9296	: V=0.9777523, theta=-62.581782 -> V=1.0, theta=0.0
% INFO    : Bus 9297	: V=0.977849, theta=-62.571125 -> V=1.0, theta=0.0
% INFO    : Bus 9298	: V=0.9781912, theta=-62.545119 -> V=1.0, theta=0.0
% INFO    : Bus 9299	: V=0.9814933, theta=-62.439397 -> V=1.0, theta=0.0
% INFO    : Bus 9300	: V=0.9884117, theta=-61.706328 -> V=1.0, theta=0.0
% INFO    : Bus 9301	: V=0.9787952, theta=-62.509277 -> V=1.0, theta=0.0
% INFO    : Bus 9302	: V=0.9797551, theta=-62.463886 -> V=1.0, theta=0.0
% INFO    : Bus 9303	: V=0.980728, theta=-62.411918 -> V=1.0, theta=0.0
% INFO    : Bus 9304	: V=0.98109, theta=-62.410763 -> V=1.0, theta=0.0
% INFO    : Bus 9305	: V=0.9840739, theta=-62.221967 -> V=1.0, theta=0.0
% INFO    : Bus 9306	: V=0.9811148, theta=-62.352252 -> V=1.0, theta=0.0
% INFO    : Bus 9307	: V=0.9883643, theta=-61.70071 -> V=1.0, theta=0.0
% INFO    : Bus 9308	: V=0.980749, theta=-62.389193 -> V=1.0, theta=0.0
% INFO    : Bus 9309	: V=0.9801104, theta=-62.429317 -> V=1.0, theta=0.0
% INFO    : Bus 9310	: V=0.9866211, theta=-61.826583 -> V=1.0, theta=0.0
% INFO    : Bus 9311	: V=0.9801604, theta=-62.407706 -> V=1.0, theta=0.0
% INFO    : Bus 9312	: V=0.9806357, theta=-62.380356 -> V=1.0, theta=0.0
% INFO    : Bus 9313	: V=0.9811668, theta=-62.352615 -> V=1.0, theta=0.0
% INFO    : Bus 9314	: V=0.9819023, theta=-62.31282 -> V=1.0, theta=0.0
% INFO    : Bus 9315	: V=0.9863279, theta=-61.7437 -> V=1.0, theta=0.0
% INFO    : Bus 9316	: V=0.9887073, theta=-61.541407 -> V=1.0, theta=0.0
% INFO    : Bus 9317	: V=0.9882041, theta=-61.594675 -> V=1.0, theta=0.0
% INFO    : Bus 9318	: V=0.9878799, theta=-61.633042 -> V=1.0, theta=0.0
% INFO    : Bus 9319	: V=0.9874909, theta=-61.687709 -> V=1.0, theta=0.0
% INFO    : Bus 9320	: V=0.9909266, theta=-61.445149 -> V=1.0, theta=0.0
% INFO    : Bus 9321	: V=0.9890059, theta=-61.639 -> V=1.0, theta=0.0
% INFO    : Bus 9322	: V=0.989585, theta=-61.595594 -> V=1.0, theta=0.0
% INFO    : Bus 9323	: V=0.9811397, theta=-62.152554 -> V=1.0, theta=0.0
% INFO    : Bus 9324	: V=0.9910419, theta=-61.441031 -> V=1.0, theta=0.0
% INFO    : Bus 9325	: V=0.9865679, theta=-61.742708 -> V=1.0, theta=0.0
% INFO    : Bus 9326	: V=0.9865228, theta=-61.839722 -> V=1.0, theta=0.0
% INFO    : Bus 9327	: V=0.9903328, theta=-61.513389 -> V=1.0, theta=0.0
% INFO    : Bus 9328	: V=0.9898112, theta=-61.583632 -> V=1.0, theta=0.0
% INFO    : Bus 9329	: V=0.9895826, theta=-61.608597 -> V=1.0, theta=0.0
% INFO    : Bus 9330	: V=0.9879568, theta=-62.597491 -> V=1.0, theta=0.0
% INFO    : Bus 9331	: V=0.9880449, theta=-62.538361 -> V=1.0, theta=0.0
% INFO    : Bus 9332	: V=0.9881989, theta=-62.484265 -> V=1.0, theta=0.0
% INFO    : Bus 9333	: V=0.9824975, theta=-62.910431 -> V=1.0, theta=0.0
% INFO    : Bus 9334	: V=0.9879391, theta=-62.543121 -> V=1.0, theta=0.0
% INFO    : Bus 9335	: V=0.9879697, theta=-62.47488 -> V=1.0, theta=0.0
% INFO    : Bus 9336	: V=0.9822977, theta=-62.876714 -> V=1.0, theta=0.0
% INFO    : Bus 9337	: V=0.9885641, theta=-62.339554 -> V=1.0, theta=0.0
% INFO    : Bus 9338	: V=0.9828998, theta=-62.875438 -> V=1.0, theta=0.0
% INFO    : Bus 9339	: V=0.98906, theta=-62.323421 -> V=1.0, theta=0.0
% INFO    : Bus 9340	: V=0.989648, theta=-62.29851 -> V=1.0, theta=0.0
% INFO    : Bus 9341	: V=0.9893234, theta=-62.183488 -> V=1.0, theta=0.0
% INFO    : Bus 9342	: V=0.9889834, theta=-62.241783 -> V=1.0, theta=0.0
% INFO    : Bus 9343	: V=0.9879434, theta=-61.972107 -> V=1.0, theta=0.0
% INFO    : Bus 9344	: V=0.987578, theta=-63.22285 -> V=1.0, theta=0.0
% INFO    : Bus 9345	: V=0.9878282, theta=-63.278133 -> V=1.0, theta=0.0
% INFO    : Bus 9346	: V=0.9838055, theta=-62.950982 -> V=1.0, theta=0.0
% INFO    : Bus 9347	: V=0.9837311, theta=-62.935692 -> V=1.0, theta=0.0
% INFO    : Bus 9348	: V=0.9816296, theta=-62.879984 -> V=1.0, theta=0.0
% INFO    : Bus 9349	: V=0.9819073, theta=-62.883823 -> V=1.0, theta=0.0
% INFO    : Bus 9350	: V=0.9813701, theta=-62.85998 -> V=1.0, theta=0.0
% INFO    : Bus 9351	: V=0.9810056, theta=-62.779037 -> V=1.0, theta=0.0
% INFO    : Bus 9352	: V=0.9805389, theta=-62.608904 -> V=1.0, theta=0.0
% INFO    : Bus 9353	: V=0.9811852, theta=-62.606074 -> V=1.0, theta=0.0
% INFO    : Bus 9354	: V=0.9810955, theta=-62.703281 -> V=1.0, theta=0.0
% INFO    : Bus 9355	: V=0.9815814, theta=-62.464273 -> V=1.0, theta=0.0
% INFO    : Bus 9356	: V=0.9814986, theta=-62.884347 -> V=1.0, theta=0.0
% INFO    : Bus 9357	: V=0.9887237, theta=-62.598093 -> V=1.0, theta=0.0
% INFO    : Bus 9358	: V=0.9892325, theta=-63.237764 -> V=1.0, theta=0.0
% INFO    : Bus 9359	: V=0.986798, theta=-63.131606 -> V=1.0, theta=0.0
% INFO    : Bus 9360	: V=0.9878721, theta=-62.489809 -> V=1.0, theta=0.0
% INFO    : Bus 9361	: V=0.9842189, theta=-62.96789 -> V=1.0, theta=0.0
% INFO    : Bus 9362	: V=0.9821317, theta=-62.890435 -> V=1.0, theta=0.0
% INFO    : Bus 9363	: V=0.9820228, theta=-62.897619 -> V=1.0, theta=0.0
% INFO    : Bus 9364	: V=0.982604, theta=-62.888869 -> V=1.0, theta=0.0
% INFO    : Bus 9365	: V=0.98197, theta=-62.906085 -> V=1.0, theta=0.0
% INFO    : Bus 9366	: V=0.9801226, theta=-62.768971 -> V=1.0, theta=0.0
% INFO    : Bus 9367	: V=0.9816364, theta=-62.88866 -> V=1.0, theta=0.0
% INFO    : Bus 9368	: V=0.9800702, theta=-62.761963 -> V=1.0, theta=0.0
% INFO    : Bus 9369	: V=0.9796083, theta=-62.727671 -> V=1.0, theta=0.0
% INFO    : Bus 9370	: V=0.9781183, theta=-62.543435 -> V=1.0, theta=0.0
% INFO    : Bus 9371	: V=0.9785857, theta=-62.732599 -> V=1.0, theta=0.0
% INFO    : Bus 9372	: V=0.9784837, theta=-62.697735 -> V=1.0, theta=0.0
% INFO    : Bus 9373	: V=0.9834408, theta=-62.017409 -> V=1.0, theta=0.0
% INFO    : Bus 9374	: V=0.9837331, theta=-61.999404 -> V=1.0, theta=0.0
% INFO    : Bus 9375	: V=0.9780295, theta=-62.51635 -> V=1.0, theta=0.0
% INFO    : Bus 9376	: V=0.9784557, theta=-62.465309 -> V=1.0, theta=0.0
% INFO    : Bus 9377	: V=0.9782372, theta=-62.517178 -> V=1.0, theta=0.0
% INFO    : Bus 9378	: V=0.9777658, theta=-62.591604 -> V=1.0, theta=0.0
% INFO    : Bus 9379	: V=0.9779405, theta=-62.565111 -> V=1.0, theta=0.0
% INFO    : Bus 9380	: V=0.9781318, theta=-62.546077 -> V=1.0, theta=0.0
% INFO    : Bus 9381	: V=0.9800174, theta=-62.424728 -> V=1.0, theta=0.0
% INFO    : Bus 9382	: V=0.9847117, theta=-61.944667 -> V=1.0, theta=0.0
% INFO    : Bus 9383	: V=0.9853778, theta=-61.902341 -> V=1.0, theta=0.0
% INFO    : Bus 9384	: V=0.9793733, theta=-62.442948 -> V=1.0, theta=0.0
% INFO    : Bus 9385	: V=0.9790053, theta=-62.464476 -> V=1.0, theta=0.0
% INFO    : Bus 9386	: V=0.9789009, theta=-62.425636 -> V=1.0, theta=0.0
% INFO    : Bus 9387	: V=0.9793771, theta=-62.438984 -> V=1.0, theta=0.0
% INFO    : Bus 9388	: V=0.986445, theta=-61.833473 -> V=1.0, theta=0.0
% INFO    : Bus 9389	: V=0.9791843, theta=-62.4256 -> V=1.0, theta=0.0
% INFO    : Bus 9390	: V=0.9792406, theta=-62.347268 -> V=1.0, theta=0.0
% INFO    : Bus 9391	: V=0.9769502, theta=-62.546894 -> V=1.0, theta=0.0
% INFO    : Bus 9392	: V=0.9769248, theta=-62.550082 -> V=1.0, theta=0.0
% INFO    : Bus 9393	: V=0.9776695, theta=-62.511183 -> V=1.0, theta=0.0
% INFO    : Bus 9394	: V=0.9804549, theta=-62.115889 -> V=1.0, theta=0.0
% INFO    : Bus 9395	: V=0.9799469, theta=-62.226487 -> V=1.0, theta=0.0
% INFO    : Bus 9396	: V=0.983359, theta=-61.94995 -> V=1.0, theta=0.0
% INFO    : Bus 9397	: V=0.984569, theta=-61.987882 -> V=1.0, theta=0.0
% INFO    : Bus 9398	: V=0.9808545, theta=-62.135851 -> V=1.0, theta=0.0
% INFO    : Bus 9399	: V=0.9795931, theta=-62.106879 -> V=1.0, theta=0.0
% INFO    : Bus 9400	: V=0.9852349, theta=-62.267517 -> V=1.0, theta=0.0
% INFO    : Bus 9401	: V=0.9785504, theta=-62.803047 -> V=1.0, theta=0.0
% INFO    : Bus 9402	: V=0.9846931, theta=-62.14577 -> V=1.0, theta=0.0
% INFO    : Bus 9403	: V=0.9781308, theta=-62.600277 -> V=1.0, theta=0.0
% INFO    : Bus 9404	: V=0.9846112, theta=-62.218343 -> V=1.0, theta=0.0
% INFO    : Bus 9405	: V=0.9823597, theta=-62.645131 -> V=1.0, theta=0.0
% INFO    : Bus 9406	: V=0.9872138, theta=-62.216888 -> V=1.0, theta=0.0
% INFO    : Bus 9407	: V=0.9882667, theta=-62.420107 -> V=1.0, theta=0.0
% INFO    : Bus 9408	: V=0.9879758, theta=-62.460879 -> V=1.0, theta=0.0
% INFO    : Bus 9409	: V=0.9828254, theta=-62.872825 -> V=1.0, theta=0.0
% INFO    : Bus 9410	: V=0.9892257, theta=-62.46418 -> V=1.0, theta=0.0
% INFO    : Bus 9411	: V=0.9888725, theta=-62.547304 -> V=1.0, theta=0.0
% INFO    : Bus 9412	: V=1.0132944, theta=-59.012129 -> V=1.0, theta=0.0
% INFO    : Bus 9413	: V=0.9895872, theta=-62.37893 -> V=1.0, theta=0.0
% INFO    : Bus 9414	: V=0.9888168, theta=-62.348374 -> V=1.0, theta=0.0
% INFO    : Bus 9415	: V=0.9890726, theta=-62.318898 -> V=1.0, theta=0.0
% INFO    : Bus 9416	: V=0.9877575, theta=-62.409176 -> V=1.0, theta=0.0
% INFO    : Bus 9417	: V=1.0011573, theta=-61.014742 -> V=1.0, theta=0.0
% INFO    : Bus 9418	: V=0.9817744, theta=-62.884081 -> V=1.0, theta=0.0
% INFO    : Bus 9419	: V=0.989011, theta=-61.815863 -> V=1.0, theta=0.0
% INFO    : Bus 9420	: V=0.9917073, theta=-61.528759 -> V=1.0, theta=0.0
% INFO    : Bus 9421	: V=0.9927482, theta=-61.664204 -> V=1.0, theta=0.0
% INFO    : Bus 9422	: V=0.9876376, theta=-61.781666 -> V=1.0, theta=0.0
% INFO    : Bus 9423	: V=0.9903434, theta=-61.578343 -> V=1.0, theta=0.0
% INFO    : Bus 9424	: V=0.9929767, theta=-61.415409 -> V=1.0, theta=0.0
% INFO    : Bus 9425	: V=0.9947473, theta=-61.417336 -> V=1.0, theta=0.0
% INFO    : Bus 9426	: V=1.0164291, theta=-58.543878 -> V=1.0, theta=0.0
% INFO    : Bus 9427	: V=0.9908953, theta=-60.057432 -> V=1.0, theta=0.0
% INFO    : Bus 9428	: V=1.0015296, theta=-59.385596 -> V=1.0, theta=0.0
% INFO    : Bus 9429	: V=0.9985025, theta=-59.531373 -> V=1.0, theta=0.0
% INFO    : Bus 9430	: V=0.9893562, theta=-59.84357 -> V=1.0, theta=0.0
% INFO    : Bus 9431	: V=1.0001553, theta=-58.97826 -> V=1.0, theta=0.0
% INFO    : Bus 9432	: V=1.0031706, theta=-59.153491 -> V=1.0, theta=0.0
% INFO    : Bus 9433	: V=1.0027672, theta=-59.282623 -> V=1.0, theta=0.0
% INFO    : Bus 9434	: V=1.0040789, theta=-58.949686 -> V=1.0, theta=0.0
% INFO    : Bus 9435	: V=1.0079005, theta=-58.370387 -> V=1.0, theta=0.0
% INFO    : Bus 9436	: V=0.9933003, theta=-59.410028 -> V=1.0, theta=0.0
% INFO    : Bus 9437	: V=0.9874534, theta=-59.671526 -> V=1.0, theta=0.0
% INFO    : Bus 9438	: V=0.9836644, theta=-59.831618 -> V=1.0, theta=0.0
% INFO    : Bus 9439	: V=0.9863702, theta=-58.415772 -> V=1.0, theta=0.0
% INFO    : Bus 9440	: V=0.9852976, theta=-59.928605 -> V=1.0, theta=0.0
% INFO    : Bus 9441	: V=0.982217, theta=-60.199968 -> V=1.0, theta=0.0
% INFO    : Bus 9442	: V=0.9858956, theta=-60.395105 -> V=1.0, theta=0.0
% INFO    : Bus 9443	: V=0.9836704, theta=-60.198845 -> V=1.0, theta=0.0
% INFO    : Bus 9444	: V=0.9958027, theta=-59.654141 -> V=1.0, theta=0.0
% INFO    : Bus 9445	: V=0.9936084, theta=-59.827858 -> V=1.0, theta=0.0
% INFO    : Bus 9446	: V=0.9922843, theta=-59.937465 -> V=1.0, theta=0.0
% INFO    : Bus 9447	: V=0.9915304, theta=-59.356751 -> V=1.0, theta=0.0
% INFO    : Bus 9448	: V=0.9790154, theta=-60.186768 -> V=1.0, theta=0.0
% INFO    : Bus 9449	: V=0.9811706, theta=-60.205838 -> V=1.0, theta=0.0
% INFO    : Bus 9450	: V=0.9807781, theta=-59.944512 -> V=1.0, theta=0.0
% INFO    : Bus 9451	: V=0.9869554, theta=-59.90845 -> V=1.0, theta=0.0
% INFO    : Bus 9452	: V=0.9676925, theta=-60.402579 -> V=1.0, theta=0.0
% INFO    : Bus 9453	: V=0.9686588, theta=-60.238387 -> V=1.0, theta=0.0
% INFO    : Bus 9454	: V=0.9743864, theta=-59.17527 -> V=1.0, theta=0.0
% INFO    : Bus 9455	: V=0.9638658, theta=-60.756471 -> V=1.0, theta=0.0
% INFO    : Bus 9456	: V=0.9630225, theta=-60.421533 -> V=1.0, theta=0.0
% INFO    : Bus 9457	: V=0.9739204, theta=-59.203703 -> V=1.0, theta=0.0
% INFO    : Bus 9458	: V=0.9783637, theta=-59.200366 -> V=1.0, theta=0.0
% INFO    : Bus 9459	: V=0.9778683, theta=-59.616847 -> V=1.0, theta=0.0
% INFO    : Bus 9460	: V=0.9765972, theta=-59.107682 -> V=1.0, theta=0.0
% INFO    : Bus 9461	: V=0.9757679, theta=-59.055566 -> V=1.0, theta=0.0
% INFO    : Bus 9462	: V=0.9760527, theta=-58.876034 -> V=1.0, theta=0.0
% INFO    : Bus 9463	: V=0.9800133, theta=-59.026171 -> V=1.0, theta=0.0
% INFO    : Bus 9464	: V=0.9812106, theta=-58.910671 -> V=1.0, theta=0.0
% INFO    : Bus 9465	: V=0.9730598, theta=-59.98955 -> V=1.0, theta=0.0
% INFO    : Bus 9466	: V=0.973039, theta=-58.85608 -> V=1.0, theta=0.0
% INFO    : Bus 9467	: V=0.9695196, theta=-59.423427 -> V=1.0, theta=0.0
% INFO    : Bus 9468	: V=0.9711251, theta=-59.411464 -> V=1.0, theta=0.0
% INFO    : Bus 9469	: V=0.9708067, theta=-59.300629 -> V=1.0, theta=0.0
% INFO    : Bus 9470	: V=0.9713798, theta=-59.299428 -> V=1.0, theta=0.0
% INFO    : Bus 9471	: V=0.9782482, theta=-58.207446 -> V=1.0, theta=0.0
% INFO    : Bus 9472	: V=0.9728914, theta=-58.970623 -> V=1.0, theta=0.0
% INFO    : Bus 9473	: V=0.9743356, theta=-58.673323 -> V=1.0, theta=0.0
% INFO    : Bus 9474	: V=0.9740394, theta=-58.365711 -> V=1.0, theta=0.0
% INFO    : Bus 9475	: V=0.9767877, theta=-58.255127 -> V=1.0, theta=0.0
% INFO    : Bus 9476	: V=0.9638997, theta=-59.531751 -> V=1.0, theta=0.0
% INFO    : Bus 9477	: V=0.9766764, theta=-58.521877 -> V=1.0, theta=0.0
% INFO    : Bus 9478	: V=0.980577, theta=-57.539649 -> V=1.0, theta=0.0
% INFO    : Bus 9479	: V=0.9829814, theta=-56.749519 -> V=1.0, theta=0.0
% INFO    : Bus 9480	: V=0.9872453, theta=-56.52708 -> V=1.0, theta=0.0
% INFO    : Bus 9481	: V=0.9777616, theta=-58.000254 -> V=1.0, theta=0.0
% INFO    : Bus 9482	: V=0.9883206, theta=-56.383227 -> V=1.0, theta=0.0
% INFO    : Bus 9483	: V=0.9826027, theta=-57.657277 -> V=1.0, theta=0.0
% INFO    : Bus 9484	: V=0.9939035, theta=-57.69494 -> V=1.0, theta=0.0
% INFO    : Bus 9485	: V=0.9713634, theta=-60.133733 -> V=1.0, theta=0.0
% INFO    : Bus 9486	: V=0.9962808, theta=-57.264774 -> V=1.0, theta=0.0
% INFO    : Bus 9487	: V=1.0036748, theta=-57.378374 -> V=1.0, theta=0.0
% INFO    : Bus 9488	: V=1.0000898, theta=-57.702592 -> V=1.0, theta=0.0
% INFO    : Bus 9489	: V=1.0109865, theta=-57.723783 -> V=1.0, theta=0.0
% INFO    : Bus 9490	: V=0.9918008, theta=-63.579954 -> V=1.0, theta=0.0
% INFO    : Bus 9491	: V=0.9957836, theta=-62.814782 -> V=1.0, theta=0.0
% INFO    : Bus 9492	: V=0.9959865, theta=-62.694839 -> V=1.0, theta=0.0
% INFO    : Bus 9493	: V=0.9967096, theta=-62.675934 -> V=1.0, theta=0.0
% INFO    : Bus 9494	: V=0.9960543, theta=-62.773629 -> V=1.0, theta=0.0
% INFO    : Bus 9495	: V=0.9962923, theta=-62.73722 -> V=1.0, theta=0.0
% INFO    : Bus 9496	: V=0.9963651, theta=-62.571283 -> V=1.0, theta=0.0
% INFO    : Bus 9497	: V=0.9915931, theta=-62.73633 -> V=1.0, theta=0.0
% INFO    : Bus 9498	: V=0.9985978, theta=-61.997907 -> V=1.0, theta=0.0
% INFO    : Bus 9499	: V=0.9951991, theta=-62.155721 -> V=1.0, theta=0.0
% INFO    : Bus 9500	: V=0.9943446, theta=-62.25404 -> V=1.0, theta=0.0
% INFO    : Bus 9501	: V=0.9937308, theta=-62.313411 -> V=1.0, theta=0.0
% INFO    : Bus 9502	: V=0.9930311, theta=-62.370992 -> V=1.0, theta=0.0
% INFO    : Bus 9503	: V=0.9929015, theta=-62.463587 -> V=1.0, theta=0.0
% INFO    : Bus 9504	: V=0.9929434, theta=-62.412957 -> V=1.0, theta=0.0
% INFO    : Bus 9505	: V=1.0105131, theta=-60.60348 -> V=1.0, theta=0.0
% INFO    : Bus 9506	: V=0.999201, theta=-61.731085 -> V=1.0, theta=0.0
% INFO    : Bus 9507	: V=0.9969115, theta=-61.822037 -> V=1.0, theta=0.0
% INFO    : Bus 9508	: V=0.9983419, theta=-61.781755 -> V=1.0, theta=0.0
% INFO    : Bus 9509	: V=0.9919812, theta=-62.531556 -> V=1.0, theta=0.0
% INFO    : Bus 9510	: V=0.9916351, theta=-62.584073 -> V=1.0, theta=0.0
% INFO    : Bus 9511	: V=0.9911837, theta=-62.649076 -> V=1.0, theta=0.0
% INFO    : Bus 9512	: V=1.0060803, theta=-61.075655 -> V=1.0, theta=0.0
% INFO    : Bus 9513	: V=0.9986109, theta=-61.655412 -> V=1.0, theta=0.0
% INFO    : Bus 9514	: V=0.9978087, theta=-61.813253 -> V=1.0, theta=0.0
% INFO    : Bus 9515	: V=0.9973404, theta=-61.835458 -> V=1.0, theta=0.0
% INFO    : Bus 9516	: V=0.997069, theta=-61.848759 -> V=1.0, theta=0.0
% INFO    : Bus 9517	: V=0.9906926, theta=-63.06782 -> V=1.0, theta=0.0
% INFO    : Bus 9518	: V=0.9992205, theta=-61.775582 -> V=1.0, theta=0.0
% INFO    : Bus 9519	: V=0.9980762, theta=-61.684179 -> V=1.0, theta=0.0
% INFO    : Bus 9520	: V=0.9922855, theta=-62.275357 -> V=1.0, theta=0.0
% INFO    : Bus 9521	: V=0.9977212, theta=-61.700231 -> V=1.0, theta=0.0
% INFO    : Bus 9522	: V=0.9919546, theta=-62.267171 -> V=1.0, theta=0.0
% INFO    : Bus 9523	: V=0.9916181, theta=-62.252122 -> V=1.0, theta=0.0
% INFO    : Bus 9524	: V=0.9906655, theta=-62.26099 -> V=1.0, theta=0.0
% INFO    : Bus 9525	: V=0.990124, theta=-62.274576 -> V=1.0, theta=0.0
% INFO    : Bus 9526	: V=0.9897747, theta=-62.275194 -> V=1.0, theta=0.0
% INFO    : Bus 9527	: V=0.9967408, theta=-61.866505 -> V=1.0, theta=0.0
% INFO    : Bus 9528	: V=0.9973717, theta=-61.714685 -> V=1.0, theta=0.0
% INFO    : Bus 9529	: V=0.9971709, theta=-61.721571 -> V=1.0, theta=0.0
% INFO    : Bus 9530	: V=0.9919934, theta=-62.176201 -> V=1.0, theta=0.0
% INFO    : Bus 9531	: V=0.9965628, theta=-61.871628 -> V=1.0, theta=0.0
% INFO    : Bus 9532	: V=0.9970384, theta=-61.725257 -> V=1.0, theta=0.0
% INFO    : Bus 9533	: V=0.9907287, theta=-62.168201 -> V=1.0, theta=0.0
% INFO    : Bus 9534	: V=0.9969382, theta=-61.727551 -> V=1.0, theta=0.0
% INFO    : Bus 9535	: V=0.9969806, theta=-61.713466 -> V=1.0, theta=0.0
% INFO    : Bus 9536	: V=0.99753, theta=-61.649639 -> V=1.0, theta=0.0
% INFO    : Bus 9537	: V=0.9971353, theta=-61.655531 -> V=1.0, theta=0.0
% INFO    : Bus 9538	: V=0.9969116, theta=-61.645079 -> V=1.0, theta=0.0
% INFO    : Bus 9539	: V=0.9969763, theta=-61.652547 -> V=1.0, theta=0.0
% INFO    : Bus 9540	: V=0.9877464, theta=-62.370903 -> V=1.0, theta=0.0
% INFO    : Bus 9541	: V=0.9904037, theta=-63.069962 -> V=1.0, theta=0.0
% INFO    : Bus 9542	: V=0.9965369, theta=-61.87635 -> V=1.0, theta=0.0
% INFO    : Bus 9543	: V=0.9926755, theta=-62.372153 -> V=1.0, theta=0.0
% INFO    : Bus 9544	: V=0.9925693, theta=-62.274874 -> V=1.0, theta=0.0
% INFO    : Bus 9545	: V=0.9914114, theta=-62.234972 -> V=1.0, theta=0.0
% INFO    : Bus 9546	: V=1.0036912, theta=-61.497912 -> V=1.0, theta=0.0
% INFO    : Bus 9547	: V=0.9913838, theta=-62.584778 -> V=1.0, theta=0.0
% INFO    : Bus 9548	: V=0.9981532, theta=-61.794786 -> V=1.0, theta=0.0
% INFO    : Bus 9549	: V=0.9909811, theta=-62.650315 -> V=1.0, theta=0.0
% INFO    : Bus 9550	: V=0.9906772, theta=-63.2294 -> V=1.0, theta=0.0
% INFO    : Bus 9551	: V=0.9897316, theta=-63.04817 -> V=1.0, theta=0.0
% INFO    : Bus 9552	: V=0.9899309, theta=-63.067849 -> V=1.0, theta=0.0
% INFO    : Bus 9553	: V=0.98971, theta=-62.981999 -> V=1.0, theta=0.0
% INFO    : Bus 9554	: V=0.9970636, theta=-62.135866 -> V=1.0, theta=0.0
% INFO    : Bus 9555	: V=0.9906864, theta=-62.747328 -> V=1.0, theta=0.0
% INFO    : Bus 9556	: V=0.997014, theta=-61.626327 -> V=1.0, theta=0.0
% INFO    : Bus 9557	: V=0.992536, theta=-62.009598 -> V=1.0, theta=0.0
% INFO    : Bus 9558	: V=0.9916408, theta=-62.046178 -> V=1.0, theta=0.0
% INFO    : Bus 9559	: V=0.9977625, theta=-61.55309 -> V=1.0, theta=0.0
% INFO    : Bus 9560	: V=0.9928693, theta=-61.963316 -> V=1.0, theta=0.0
% INFO    : Bus 9561	: V=0.997908, theta=-61.416288 -> V=1.0, theta=0.0
% INFO    : Bus 9562	: V=0.9930749, theta=-61.925983 -> V=1.0, theta=0.0
% INFO    : Bus 9563	: V=1.0085292, theta=-60.507018 -> V=1.0, theta=0.0
% INFO    : Bus 9564	: V=0.9919216, theta=-61.773175 -> V=1.0, theta=0.0
% INFO    : Bus 9565	: V=0.997939, theta=-61.362849 -> V=1.0, theta=0.0
% INFO    : Bus 9566	: V=0.9979219, theta=-61.376859 -> V=1.0, theta=0.0
% INFO    : Bus 9567	: V=0.9980384, theta=-61.322835 -> V=1.0, theta=0.0
% INFO    : Bus 9568	: V=0.9943918, theta=-61.673216 -> V=1.0, theta=0.0
% INFO    : Bus 9569	: V=0.9943522, theta=-61.702795 -> V=1.0, theta=0.0
% INFO    : Bus 9570	: V=0.9944988, theta=-61.701369 -> V=1.0, theta=0.0
% INFO    : Bus 9571	: V=0.9943086, theta=-61.703659 -> V=1.0, theta=0.0
% INFO    : Bus 9572	: V=0.982125, theta=-62.61401 -> V=1.0, theta=0.0
% INFO    : Bus 9573	: V=0.9817184, theta=-62.699124 -> V=1.0, theta=0.0
% INFO    : Bus 9574	: V=0.9858851, theta=-62.273451 -> V=1.0, theta=0.0
% INFO    : Bus 9575	: V=0.9827004, theta=-62.52854 -> V=1.0, theta=0.0
% INFO    : Bus 9576	: V=1.0073553, theta=-60.68286 -> V=1.0, theta=0.0
% INFO    : Bus 9577	: V=0.9939726, theta=-61.553446 -> V=1.0, theta=0.0
% INFO    : Bus 9578	: V=0.9935113, theta=-61.573062 -> V=1.0, theta=0.0
% INFO    : Bus 9579	: V=0.9933579, theta=-61.579662 -> V=1.0, theta=0.0
% INFO    : Bus 9580	: V=0.9932119, theta=-61.587364 -> V=1.0, theta=0.0
% INFO    : Bus 9581	: V=0.9858058, theta=-62.163117 -> V=1.0, theta=0.0
% INFO    : Bus 9582	: V=0.9854692, theta=-62.180786 -> V=1.0, theta=0.0
% INFO    : Bus 9583	: V=0.9923853, theta=-61.762034 -> V=1.0, theta=0.0
% INFO    : Bus 9584	: V=0.9905641, theta=-61.912848 -> V=1.0, theta=0.0
% INFO    : Bus 9585	: V=0.9905679, theta=-61.91105 -> V=1.0, theta=0.0
% INFO    : Bus 9586	: V=0.9924985, theta=-61.730089 -> V=1.0, theta=0.0
% INFO    : Bus 9587	: V=0.9920055, theta=-61.672204 -> V=1.0, theta=0.0
% INFO    : Bus 9588	: V=0.9956877, theta=-61.484055 -> V=1.0, theta=0.0
% INFO    : Bus 9589	: V=0.9949418, theta=-63.598493 -> V=1.0, theta=0.0
% INFO    : Bus 9590	: V=0.9910139, theta=-64.218635 -> V=1.0, theta=0.0
% INFO    : Bus 9591	: V=0.9945684, theta=-63.574893 -> V=1.0, theta=0.0
% INFO    : Bus 9592	: V=0.9942055, theta=-63.541509 -> V=1.0, theta=0.0
% INFO    : Bus 9593	: V=0.9905513, theta=-63.857853 -> V=1.0, theta=0.0
% INFO    : Bus 9594	: V=0.9905565, theta=-63.857598 -> V=1.0, theta=0.0
% INFO    : Bus 9595	: V=0.9911589, theta=-63.760508 -> V=1.0, theta=0.0
% INFO    : Bus 9596	: V=0.9912205, theta=-63.755645 -> V=1.0, theta=0.0
% INFO    : Bus 9597	: V=0.991133, theta=-63.761314 -> V=1.0, theta=0.0
% INFO    : Bus 9598	: V=0.9935804, theta=-63.364533 -> V=1.0, theta=0.0
% INFO    : Bus 9599	: V=1.0010829, theta=-61.945905 -> V=1.0, theta=0.0
% INFO    : Bus 9600	: V=0.9915528, theta=-63.586493 -> V=1.0, theta=0.0
% INFO    : Bus 9601	: V=0.9915745, theta=-63.951328 -> V=1.0, theta=0.0
% INFO    : Bus 9602	: V=0.9916671, theta=-63.951666 -> V=1.0, theta=0.0
% INFO    : Bus 9603	: V=0.9905889, theta=-63.8532 -> V=1.0, theta=0.0
% INFO    : Bus 9604	: V=0.9906449, theta=-63.835649 -> V=1.0, theta=0.0
% INFO    : Bus 9605	: V=0.9938735, theta=-63.487928 -> V=1.0, theta=0.0
% INFO    : Bus 9606	: V=0.9939324, theta=-63.506156 -> V=1.0, theta=0.0
% INFO    : Bus 9607	: V=0.9912963, theta=-63.748975 -> V=1.0, theta=0.0
% INFO    : Bus 9608	: V=0.9908606, theta=-63.819986 -> V=1.0, theta=0.0
% INFO    : Bus 9609	: V=0.9907491, theta=-63.824274 -> V=1.0, theta=0.0
% INFO    : Bus 9610	: V=0.9908519, theta=-63.781913 -> V=1.0, theta=0.0
% INFO    : Bus 9611	: V=0.9936452, theta=-63.43829 -> V=1.0, theta=0.0
% INFO    : Bus 9612	: V=0.9911794, theta=-63.757762 -> V=1.0, theta=0.0
% INFO    : Bus 9613	: V=0.9919774, theta=-63.650368 -> V=1.0, theta=0.0
% INFO    : Bus 9614	: V=0.9938006, theta=-63.391846 -> V=1.0, theta=0.0
% INFO    : Bus 9615	: V=0.9937024, theta=-63.382952 -> V=1.0, theta=0.0
% INFO    : Bus 9616	: V=0.9939266, theta=-63.352506 -> V=1.0, theta=0.0
% INFO    : Bus 9617	: V=0.9940863, theta=-63.299803 -> V=1.0, theta=0.0
% INFO    : Bus 9618	: V=0.9942611, theta=-63.237642 -> V=1.0, theta=0.0
% INFO    : Bus 9619	: V=0.9908199, theta=-64.125987 -> V=1.0, theta=0.0
% INFO    : Bus 9620	: V=0.9913187, theta=-64.022873 -> V=1.0, theta=0.0
% INFO    : Bus 9621	: V=0.99449, theta=-63.168932 -> V=1.0, theta=0.0
% INFO    : Bus 9622	: V=0.9947166, theta=-63.100771 -> V=1.0, theta=0.0
% INFO    : Bus 9623	: V=0.9949481, theta=-63.019769 -> V=1.0, theta=0.0
% INFO    : Bus 9624	: V=0.9951137, theta=-63.000258 -> V=1.0, theta=0.0
% INFO    : Bus 9625	: V=0.9949518, theta=-63.029319 -> V=1.0, theta=0.0
% INFO    : Bus 9626	: V=0.9937202, theta=-63.243867 -> V=1.0, theta=0.0
% INFO    : Bus 9627	: V=0.9951642, theta=-62.966444 -> V=1.0, theta=0.0
% INFO    : Bus 9628	: V=0.9952931, theta=-62.919223 -> V=1.0, theta=0.0
% INFO    : Bus 9629	: V=0.9946734, theta=-63.046439 -> V=1.0, theta=0.0
% INFO    : Bus 9630	: V=0.9955109, theta=-62.862011 -> V=1.0, theta=0.0
% INFO    : Bus 9631	: V=0.9914375, theta=-62.772766 -> V=1.0, theta=0.0
% INFO    : Bus 9632	: V=0.9894073, theta=-64.339877 -> V=1.0, theta=0.0
% INFO    : Bus 9633	: V=0.9917647, theta=-63.831717 -> V=1.0, theta=0.0
% INFO    : Bus 9634	: V=0.9891041, theta=-64.34747 -> V=1.0, theta=0.0
% INFO    : Bus 9635	: V=0.9904802, theta=-63.97219 -> V=1.0, theta=0.0
% INFO    : Bus 9636	: V=0.9912422, theta=-62.846549 -> V=1.0, theta=0.0
% INFO    : Bus 9637	: V=0.9907967, theta=-63.959896 -> V=1.0, theta=0.0
% INFO    : Bus 9638	: V=0.9956149, theta=-62.69018 -> V=1.0, theta=0.0
% INFO    : Bus 9639	: V=0.991352, theta=-62.716195 -> V=1.0, theta=0.0
% INFO    : Bus 9640	: V=0.9906715, theta=-62.889382 -> V=1.0, theta=0.0
% INFO    : Bus 9641	: V=0.9909144, theta=-62.872963 -> V=1.0, theta=0.0
% INFO    : Bus 9642	: V=0.9904528, theta=-62.895176 -> V=1.0, theta=0.0
% INFO    : Bus 9643	: V=0.9911756, theta=-62.848606 -> V=1.0, theta=0.0
% INFO    : Bus 9644	: V=0.9914393, theta=-62.645274 -> V=1.0, theta=0.0
% INFO    : Bus 9645	: V=0.9916494, theta=-62.642643 -> V=1.0, theta=0.0
% INFO    : Bus 9646	: V=0.9919081, theta=-62.606544 -> V=1.0, theta=0.0
% INFO    : Bus 9647	: V=0.9922181, theta=-62.559252 -> V=1.0, theta=0.0
% INFO    : Bus 9648	: V=0.9967705, theta=-62.156719 -> V=1.0, theta=0.0
% INFO    : Bus 9649	: V=0.9913503, theta=-62.841856 -> V=1.0, theta=0.0
% INFO    : Bus 9650	: V=0.9950923, theta=-62.370471 -> V=1.0, theta=0.0
% INFO    : Bus 9651	: V=0.9960209, theta=-62.253822 -> V=1.0, theta=0.0
% INFO    : Bus 9652	: V=0.9955757, theta=-62.305261 -> V=1.0, theta=0.0
% INFO    : Bus 9653	: V=0.9971227, theta=-62.045951 -> V=1.0, theta=0.0
% INFO    : Bus 9654	: V=0.9906265, theta=-63.84852 -> V=1.0, theta=0.0
% INFO    : Bus 9655	: V=0.9890675, theta=-62.303478 -> V=1.0, theta=0.0
% INFO    : Bus 9656	: V=0.9911607, theta=-60.885409 -> V=1.0, theta=0.0
% INFO    : Bus 9657	: V=0.9984476, theta=-60.214357 -> V=1.0, theta=0.0
% INFO    : Bus 9658	: V=1.0044146, theta=-59.79361 -> V=1.0, theta=0.0
% INFO    : Bus 9659	: V=0.9942055, theta=-60.812299 -> V=1.0, theta=0.0
% INFO    : Bus 9660	: V=1.0033329, theta=-60.26191 -> V=1.0, theta=0.0
% INFO    : Bus 9661	: V=0.9971266, theta=-60.678733 -> V=1.0, theta=0.0
% INFO    : Bus 9662	: V=0.9953626, theta=-60.700264 -> V=1.0, theta=0.0
% INFO    : Bus 9663	: V=0.9900093, theta=-61.1528 -> V=1.0, theta=0.0
% INFO    : Bus 9664	: V=0.9927532, theta=-60.884928 -> V=1.0, theta=0.0
% INFO    : Bus 9665	: V=0.9891448, theta=-61.141433 -> V=1.0, theta=0.0
% INFO    : Bus 9666	: V=0.9967628, theta=-60.270079 -> V=1.0, theta=0.0
% INFO    : Bus 9667	: V=0.9966215, theta=-60.39826 -> V=1.0, theta=0.0
% INFO    : Bus 9668	: V=0.9846565, theta=-61.188525 -> V=1.0, theta=0.0
% INFO    : Bus 9669	: V=0.9845591, theta=-61.489416 -> V=1.0, theta=0.0
% INFO    : Bus 9670	: V=0.9771401, theta=-61.562277 -> V=1.0, theta=0.0
% INFO    : Bus 9671	: V=0.9743937, theta=-61.79533 -> V=1.0, theta=0.0
% INFO    : Bus 9672	: V=0.9855556, theta=-61.44659 -> V=1.0, theta=0.0
% INFO    : Bus 9673	: V=0.9768644, theta=-62.300468 -> V=1.0, theta=0.0
% INFO    : Bus 9674	: V=0.9749024, theta=-61.988327 -> V=1.0, theta=0.0
% INFO    : Bus 9675	: V=0.9731507, theta=-62.054412 -> V=1.0, theta=0.0
% INFO    : Bus 9676	: V=0.9841626, theta=-61.497989 -> V=1.0, theta=0.0
% INFO    : Bus 9677	: V=0.9923269, theta=-61.100699 -> V=1.0, theta=0.0
% INFO    : Bus 9678	: V=0.9856122, theta=-61.69806 -> V=1.0, theta=0.0
% INFO    : Bus 9679	: V=0.9742056, theta=-62.055285 -> V=1.0, theta=0.0
% INFO    : Bus 9680	: V=0.9768139, theta=-62.515172 -> V=1.0, theta=0.0
% INFO    : Bus 9681	: V=0.9807365, theta=-62.28295 -> V=1.0, theta=0.0
% INFO    : Bus 9682	: V=1.0030937, theta=-60.147065 -> V=1.0, theta=0.0
% INFO    : Bus 9683	: V=1.0018038, theta=-60.264748 -> V=1.0, theta=0.0
% INFO    : Bus 9684	: V=0.9951043, theta=-60.723234 -> V=1.0, theta=0.0
% INFO    : Bus 9685	: V=0.9991727, theta=-60.581326 -> V=1.0, theta=0.0
% INFO    : Bus 9686	: V=0.9965652, theta=-60.70655 -> V=1.0, theta=0.0
% INFO    : Bus 9687	: V=1.0008435, theta=-60.277667 -> V=1.0, theta=0.0
% INFO    : Bus 9688	: V=0.9963277, theta=-60.708019 -> V=1.0, theta=0.0
% INFO    : Bus 9689	: V=0.9999782, theta=-60.40221 -> V=1.0, theta=0.0
% INFO    : Bus 9690	: V=0.997884, theta=-60.574098 -> V=1.0, theta=0.0
% INFO    : Bus 9691	: V=0.9988294, theta=-60.492052 -> V=1.0, theta=0.0
% INFO    : Bus 9692	: V=0.9899069, theta=-61.430793 -> V=1.0, theta=0.0
% INFO    : Bus 9693	: V=0.9895037, theta=-61.430308 -> V=1.0, theta=0.0
% INFO    : Bus 9694	: V=0.9918208, theta=-61.295978 -> V=1.0, theta=0.0
% INFO    : Bus 9695	: V=0.9916395, theta=-61.286492 -> V=1.0, theta=0.0
% INFO    : Bus 9696	: V=0.9948932, theta=-60.770649 -> V=1.0, theta=0.0
% INFO    : Bus 9697	: V=0.9904026, theta=-61.37271 -> V=1.0, theta=0.0
% INFO    : Bus 9698	: V=0.9961562, theta=-60.686448 -> V=1.0, theta=0.0
% INFO    : Bus 9699	: V=0.989897, theta=-61.415628 -> V=1.0, theta=0.0
% INFO    : Bus 9700	: V=0.9954016, theta=-60.745056 -> V=1.0, theta=0.0
% INFO    : Bus 9701	: V=0.9962237, theta=-60.661815 -> V=1.0, theta=0.0
% INFO    : Bus 9702	: V=0.9963758, theta=-60.667432 -> V=1.0, theta=0.0
% INFO    : Bus 9703	: V=0.9966384, theta=-60.668771 -> V=1.0, theta=0.0
% INFO    : Bus 9704	: V=0.9996309, theta=-60.358477 -> V=1.0, theta=0.0
% INFO    : Bus 9705	: V=0.9987161, theta=-60.417957 -> V=1.0, theta=0.0
% INFO    : Bus 9706	: V=1.0005394, theta=-60.359872 -> V=1.0, theta=0.0
% INFO    : Bus 9707	: V=1.0051719, theta=-59.990471 -> V=1.0, theta=0.0
% INFO    : Bus 9708	: V=1.0025628, theta=-60.162404 -> V=1.0, theta=0.0
% INFO    : Bus 9709	: V=0.9847955, theta=-61.521618 -> V=1.0, theta=0.0
% INFO    : Bus 9710	: V=1.0025147, theta=-60.131012 -> V=1.0, theta=0.0
% INFO    : Bus 9711	: V=1.0026007, theta=-60.080234 -> V=1.0, theta=0.0
% INFO    : Bus 9712	: V=0.9929296, theta=-60.852715 -> V=1.0, theta=0.0
% INFO    : Bus 9713	: V=0.9969244, theta=-60.573371 -> V=1.0, theta=0.0
% INFO    : Bus 9714	: V=0.9916017, theta=-60.871384 -> V=1.0, theta=0.0
% INFO    : Bus 9715	: V=0.9945607, theta=-60.583888 -> V=1.0, theta=0.0
% INFO    : Bus 9716	: V=1.0029012, theta=-59.685538 -> V=1.0, theta=0.0
% INFO    : Bus 9717	: V=1.0008936, theta=-60.066535 -> V=1.0, theta=0.0
% INFO    : Bus 9718	: V=1.0179184, theta=-58.23212 -> V=1.0, theta=0.0
% INFO    : Bus 9719	: V=1.0049383, theta=-59.750292 -> V=1.0, theta=0.0
% INFO    : Bus 9720	: V=0.9970483, theta=-60.399632 -> V=1.0, theta=0.0
% INFO    : Bus 9721	: V=0.9921879, theta=-60.805883 -> V=1.0, theta=0.0
% INFO    : Bus 9722	: V=0.9995669, theta=-60.215792 -> V=1.0, theta=0.0
% INFO    : Bus 9723	: V=1.0020705, theta=-60.036367 -> V=1.0, theta=0.0
% INFO    : Bus 9724	: V=0.9962235, theta=-60.641282 -> V=1.0, theta=0.0
% INFO    : Bus 9725	: V=0.9876492, theta=-61.29632 -> V=1.0, theta=0.0
% INFO    : Bus 9726	: V=0.9919691, theta=-60.962171 -> V=1.0, theta=0.0
% INFO    : Bus 9727	: V=0.9881683, theta=-61.25135 -> V=1.0, theta=0.0
% INFO    : Bus 9728	: V=0.9860863, theta=-61.414102 -> V=1.0, theta=0.0
% INFO    : Bus 9729	: V=0.9939768, theta=-60.837155 -> V=1.0, theta=0.0
% INFO    : Bus 9730	: V=0.9913886, theta=-61.075856 -> V=1.0, theta=0.0
% INFO    : Bus 9731	: V=0.9908281, theta=-61.296538 -> V=1.0, theta=0.0
% INFO    : Bus 9732	: V=0.9902547, theta=-61.299256 -> V=1.0, theta=0.0
% INFO    : Bus 9733	: V=0.9896154, theta=-61.257585 -> V=1.0, theta=0.0
% INFO    : Bus 9734	: V=0.9821489, theta=-62.083124 -> V=1.0, theta=0.0
% INFO    : Bus 9735	: V=0.9833959, theta=-62.044916 -> V=1.0, theta=0.0
% INFO    : Bus 9736	: V=0.9804937, theta=-62.541817 -> V=1.0, theta=0.0
% INFO    : Bus 9737	: V=0.9768147, theta=-62.521051 -> V=1.0, theta=0.0
% INFO    : Bus 9738	: V=0.9824916, theta=-61.654737 -> V=1.0, theta=0.0
% INFO    : Bus 9739	: V=0.9772493, theta=-62.259419 -> V=1.0, theta=0.0
% INFO    : Bus 9740	: V=0.978879, theta=-62.245219 -> V=1.0, theta=0.0
% INFO    : Bus 9741	: V=0.9829598, theta=-61.630988 -> V=1.0, theta=0.0
% INFO    : Bus 9742	: V=0.9832664, theta=-61.492668 -> V=1.0, theta=0.0
% INFO    : Bus 9743	: V=0.9823052, theta=-61.565238 -> V=1.0, theta=0.0
% INFO    : Bus 9744	: V=0.9761038, theta=-62.104045 -> V=1.0, theta=0.0
% INFO    : Bus 9745	: V=0.9839271, theta=-61.496117 -> V=1.0, theta=0.0
% INFO    : Bus 9746	: V=0.9856214, theta=-61.274905 -> V=1.0, theta=0.0
% INFO    : Bus 9747	: V=0.9953941, theta=-60.326313 -> V=1.0, theta=0.0
% INFO    : Bus 9748	: V=0.9911085, theta=-60.845862 -> V=1.0, theta=0.0
% INFO    : Bus 9749	: V=0.9876017, theta=-61.113664 -> V=1.0, theta=0.0
% INFO    : Bus 9750	: V=0.9980361, theta=-60.138253 -> V=1.0, theta=0.0
% INFO    : Bus 9751	: V=0.9992147, theta=-60.095493 -> V=1.0, theta=0.0
% INFO    : Bus 9752	: V=0.9909063, theta=-60.393873 -> V=1.0, theta=0.0
% INFO    : Bus 9753	: V=0.990016, theta=-60.413743 -> V=1.0, theta=0.0
% INFO    : Bus 9754	: V=0.9967705, theta=-60.165275 -> V=1.0, theta=0.0
% INFO    : Bus 9755	: V=0.9957995, theta=-59.971041 -> V=1.0, theta=0.0
% INFO    : Bus 9756	: V=0.994353, theta=-60.136064 -> V=1.0, theta=0.0
% INFO    : Bus 9757	: V=0.9833999, theta=-61.49692 -> V=1.0, theta=0.0
% INFO    : Bus 9758	: V=0.9775558, theta=-62.005687 -> V=1.0, theta=0.0
% INFO    : Bus 9759	: V=0.9829845, theta=-61.461114 -> V=1.0, theta=0.0
% INFO    : Bus 9760	: V=0.9809088, theta=-61.597139 -> V=1.0, theta=0.0
% INFO    : Bus 9761	: V=0.9811769, theta=-61.513588 -> V=1.0, theta=0.0
% INFO    : Bus 9762	: V=0.9849831, theta=-61.129129 -> V=1.0, theta=0.0
% INFO    : Bus 9763	: V=0.9836476, theta=-61.136023 -> V=1.0, theta=0.0
% INFO    : Bus 9764	: V=0.9862948, theta=-61.041527 -> V=1.0, theta=0.0
% INFO    : Bus 9765	: V=0.9822661, theta=-61.39731 -> V=1.0, theta=0.0
% INFO    : Bus 9766	: V=0.9907413, theta=-60.691945 -> V=1.0, theta=0.0
% INFO    : Bus 9767	: V=1.0127782, theta=-59.154401 -> V=1.0, theta=0.0
% INFO    : Bus 9768	: V=0.9884548, theta=-60.707163 -> V=1.0, theta=0.0
% INFO    : Bus 9769	: V=0.9878845, theta=-60.767741 -> V=1.0, theta=0.0
% INFO    : Bus 9770	: V=0.9734626, theta=-61.766683 -> V=1.0, theta=0.0
% INFO    : Bus 9771	: V=0.9907264, theta=-60.728027 -> V=1.0, theta=0.0
% INFO    : Bus 9772	: V=0.9822859, theta=-61.39547 -> V=1.0, theta=0.0
% INFO    : Bus 9773	: V=0.9827536, theta=-61.3393 -> V=1.0, theta=0.0
% INFO    : Bus 9774	: V=0.9833667, theta=-61.281848 -> V=1.0, theta=0.0
% INFO    : Bus 9775	: V=0.9843349, theta=-61.210314 -> V=1.0, theta=0.0
% INFO    : Bus 9776	: V=0.986037, theta=-61.120163 -> V=1.0, theta=0.0
% INFO    : Bus 9777	: V=0.9910814, theta=-60.608531 -> V=1.0, theta=0.0
% INFO    : Bus 9778	: V=0.9996411, theta=-59.572774 -> V=1.0, theta=0.0
% INFO    : Bus 9779	: V=0.9995933, theta=-59.602207 -> V=1.0, theta=0.0
% INFO    : Bus 9780	: V=0.9915662, theta=-60.249237 -> V=1.0, theta=0.0
% INFO    : Bus 9781	: V=0.9938542, theta=-60.451605 -> V=1.0, theta=0.0
% INFO    : Bus 9782	: V=0.9926926, theta=-60.584519 -> V=1.0, theta=0.0
% INFO    : Bus 9783	: V=0.9920949, theta=-60.650959 -> V=1.0, theta=0.0
% INFO    : Bus 9784	: V=0.9867306, theta=-60.991879 -> V=1.0, theta=0.0
% INFO    : Bus 9785	: V=0.9875477, theta=-60.989102 -> V=1.0, theta=0.0
% INFO    : Bus 9786	: V=0.9891929, theta=-60.513919 -> V=1.0, theta=0.0
% INFO    : Bus 9787	: V=0.9910814, theta=-60.384483 -> V=1.0, theta=0.0
% INFO    : Bus 9788	: V=0.9954361, theta=-60.281275 -> V=1.0, theta=0.0
% INFO    : Bus 9789	: V=0.9962898, theta=-60.175834 -> V=1.0, theta=0.0
% INFO    : Bus 9790	: V=1.0004345, theta=-59.642279 -> V=1.0, theta=0.0
% INFO    : Bus 9791	: V=0.9904767, theta=-60.49283 -> V=1.0, theta=0.0
% INFO    : Bus 9792	: V=0.9903915, theta=-60.403386 -> V=1.0, theta=0.0
% INFO    : Bus 9793	: V=0.9988463, theta=-59.724158 -> V=1.0, theta=0.0
% INFO    : Bus 9794	: V=1.0017362, theta=-59.464438 -> V=1.0, theta=0.0
% INFO    : Bus 9795	: V=1.0015221, theta=-59.628225 -> V=1.0, theta=0.0
% INFO    : Bus 9796	: V=0.9919133, theta=-60.232984 -> V=1.0, theta=0.0
% INFO    : Bus 9797	: V=1.0030027, theta=-59.402257 -> V=1.0, theta=0.0
% INFO    : Bus 9798	: V=1.0025918, theta=-59.493148 -> V=1.0, theta=0.0
% INFO    : Bus 9799	: V=1.0040228, theta=-59.569416 -> V=1.0, theta=0.0
% INFO    : Bus 9800	: V=1.0022586, theta=-59.760323 -> V=1.0, theta=0.0
% INFO    : Bus 9801	: V=0.9995726, theta=-60.035821 -> V=1.0, theta=0.0
% INFO    : Bus 9802	: V=1.0028639, theta=-59.695704 -> V=1.0, theta=0.0
% INFO    : Bus 9803	: V=0.9975674, theta=-60.004203 -> V=1.0, theta=0.0
% INFO    : Bus 9804	: V=0.9978382, theta=-59.991859 -> V=1.0, theta=0.0
% INFO    : Bus 9805	: V=0.9922655, theta=-60.378864 -> V=1.0, theta=0.0
% INFO    : Bus 9806	: V=0.9997791, theta=-59.783208 -> V=1.0, theta=0.0
% INFO    : Bus 9807	: V=0.9919152, theta=-60.68849 -> V=1.0, theta=0.0
% INFO    : Bus 9808	: V=0.9937928, theta=-60.552108 -> V=1.0, theta=0.0
% INFO    : Bus 9809	: V=0.9935261, theta=-60.601225 -> V=1.0, theta=0.0
% INFO    : Bus 9810	: V=0.9951223, theta=-60.422144 -> V=1.0, theta=0.0
% INFO    : Bus 9811	: V=0.9952933, theta=-60.299426 -> V=1.0, theta=0.0
% INFO    : Bus 9812	: V=1.0012317, theta=-59.894146 -> V=1.0, theta=0.0
% INFO    : Bus 9813	: V=1.0003956, theta=-60.002539 -> V=1.0, theta=0.0
% INFO    : Bus 9814	: V=0.9994963, theta=-60.13072 -> V=1.0, theta=0.0
% INFO    : Bus 9815	: V=0.9990427, theta=-60.202424 -> V=1.0, theta=0.0
% INFO    : Bus 9816	: V=0.9964286, theta=-60.405798 -> V=1.0, theta=0.0
% INFO    : Bus 9817	: V=0.997669, theta=-60.329224 -> V=1.0, theta=0.0
% INFO    : Bus 9818	: V=0.9992445, theta=-60.247128 -> V=1.0, theta=0.0
% INFO    : Bus 9819	: V=0.9985619, theta=-60.261597 -> V=1.0, theta=0.0
% INFO    : Bus 9820	: V=0.9978276, theta=-60.297966 -> V=1.0, theta=0.0
% INFO    : Bus 9821	: V=1.0025017, theta=-59.773228 -> V=1.0, theta=0.0
% INFO    : Bus 9822	: V=1.0016403, theta=-59.839416 -> V=1.0, theta=0.0
% INFO    : Bus 9823	: V=0.9983016, theta=-60.182084 -> V=1.0, theta=0.0
% INFO    : Bus 9824	: V=0.9993363, theta=-60.061252 -> V=1.0, theta=0.0
% INFO    : Bus 9825	: V=1.0007831, theta=-59.970711 -> V=1.0, theta=0.0
% INFO    : Bus 9826	: V=1.0052182, theta=-59.508874 -> V=1.0, theta=0.0
% INFO    : Bus 9827	: V=1.0118038, theta=-59.277885 -> V=1.0, theta=0.0
% INFO    : Bus 9828	: V=0.9964653, theta=-60.519393 -> V=1.0, theta=0.0
% INFO    : Bus 9829	: V=1.0013433, theta=-60.456088 -> V=1.0, theta=0.0
% INFO    : Bus 9830	: V=1.0015638, theta=-60.399688 -> V=1.0, theta=0.0
% INFO    : Bus 9831	: V=1.012481, theta=-59.470124 -> V=1.0, theta=0.0
% INFO    : Bus 9832	: V=1.0043453, theta=-59.770536 -> V=1.0, theta=0.0
% INFO    : Bus 9833	: V=1.0064623, theta=-59.428993 -> V=1.0, theta=0.0
% INFO    : Bus 9834	: V=1.0059618, theta=-59.517565 -> V=1.0, theta=0.0
% INFO    : Bus 9835	: V=1.0092244, theta=-59.364281 -> V=1.0, theta=0.0
% INFO    : Bus 9836	: V=1.0094356, theta=-59.319234 -> V=1.0, theta=0.0
% INFO    : Bus 9837	: V=1.0118163, theta=-59.164118 -> V=1.0, theta=0.0
% INFO    : Bus 9838	: V=1.0097478, theta=-59.278558 -> V=1.0, theta=0.0
% INFO    : Bus 9839	: V=1.0077148, theta=-59.350054 -> V=1.0, theta=0.0
% INFO    : Bus 9840	: V=1.008804, theta=-59.268913 -> V=1.0, theta=0.0
% INFO    : Bus 9841	: V=1.0100653, theta=-59.232936 -> V=1.0, theta=0.0
% INFO    : Bus 9842	: V=1.0105158, theta=-59.178844 -> V=1.0, theta=0.0
% INFO    : Bus 9843	: V=0.9959401, theta=-59.897103 -> V=1.0, theta=0.0
% INFO    : Bus 9844	: V=0.9955321, theta=-59.919645 -> V=1.0, theta=0.0
% INFO    : Bus 9845	: V=0.9953646, theta=-59.929779 -> V=1.0, theta=0.0
% INFO    : Bus 9846	: V=0.9918924, theta=-60.253212 -> V=1.0, theta=0.0
% INFO    : Bus 9847	: V=0.9870638, theta=-60.697499 -> V=1.0, theta=0.0
% INFO    : Bus 9848	: V=0.9952358, theta=-59.937997 -> V=1.0, theta=0.0
% INFO    : Bus 9849	: V=0.985287, theta=-60.802065 -> V=1.0, theta=0.0
% INFO    : Bus 9850	: V=0.9962708, theta=-59.867543 -> V=1.0, theta=0.0
% INFO    : Bus 9851	: V=1.0018989, theta=-59.486476 -> V=1.0, theta=0.0
% INFO    : Bus 9852	: V=0.9983078, theta=-59.718422 -> V=1.0, theta=0.0
% INFO    : Bus 9853	: V=0.9858721, theta=-60.784808 -> V=1.0, theta=0.0
% INFO    : Bus 9854	: V=0.9874295, theta=-60.676107 -> V=1.0, theta=0.0
% INFO    : Bus 9855	: V=0.9874342, theta=-60.69452 -> V=1.0, theta=0.0
% INFO    : Bus 9856	: V=0.9879112, theta=-60.702011 -> V=1.0, theta=0.0
% INFO    : Bus 9857	: V=0.9885012, theta=-60.670192 -> V=1.0, theta=0.0
% INFO    : Bus 9858	: V=0.9889391, theta=-60.605804 -> V=1.0, theta=0.0
% INFO    : Bus 9859	: V=0.9862873, theta=-60.739803 -> V=1.0, theta=0.0
% INFO    : Bus 9860	: V=0.987462, theta=-60.672911 -> V=1.0, theta=0.0
% INFO    : Bus 9861	: V=0.9788118, theta=-61.210676 -> V=1.0, theta=0.0
% INFO    : Bus 9862	: V=1.0041261, theta=-59.316117 -> V=1.0, theta=0.0
% INFO    : Bus 9863	: V=0.9837962, theta=-60.933384 -> V=1.0, theta=0.0
% INFO    : Bus 9864	: V=0.9834336, theta=-61.03946 -> V=1.0, theta=0.0
% INFO    : Bus 9865	: V=0.9904401, theta=-60.394697 -> V=1.0, theta=0.0
% INFO    : Bus 9866	: V=0.9894311, theta=-60.483409 -> V=1.0, theta=0.0
% INFO    : Bus 9867	: V=0.9885838, theta=-60.55884 -> V=1.0, theta=0.0
% INFO    : Bus 9868	: V=0.9892507, theta=-60.46186 -> V=1.0, theta=0.0
% INFO    : Bus 9869	: V=0.9862296, theta=-60.73981 -> V=1.0, theta=0.0
% INFO    : Bus 9870	: V=1.005784, theta=-59.216724 -> V=1.0, theta=0.0
% INFO    : Bus 9871	: V=0.9970661, theta=-59.948633 -> V=1.0, theta=0.0
% INFO    : Bus 9872	: V=1.0057263, theta=-59.230431 -> V=1.0, theta=0.0
% INFO    : Bus 9873	: V=1.0065977, theta=-59.183622 -> V=1.0, theta=0.0
% INFO    : Bus 9874	: V=1.0077998, theta=-59.120108 -> V=1.0, theta=0.0
% INFO    : Bus 9875	: V=1.0029568, theta=-59.52782 -> V=1.0, theta=0.0
% INFO    : Bus 9876	: V=1.0112124, theta=-58.853952 -> V=1.0, theta=0.0
% INFO    : Bus 9877	: V=1.006433, theta=-59.192563 -> V=1.0, theta=0.0
% INFO    : Bus 9878	: V=1.0110709, theta=-58.868965 -> V=1.0, theta=0.0
% INFO    : Bus 9879	: V=1.0105449, theta=-58.979986 -> V=1.0, theta=0.0
% INFO    : Bus 9880	: V=1.0005297, theta=-59.628969 -> V=1.0, theta=0.0
% INFO    : Bus 9881	: V=1.0009032, theta=-59.63818 -> V=1.0, theta=0.0
% INFO    : Bus 9882	: V=0.999084, theta=-59.719802 -> V=1.0, theta=0.0
% INFO    : Bus 9883	: V=0.999865, theta=-59.691077 -> V=1.0, theta=0.0
% INFO    : Bus 9884	: V=1.0111508, theta=-59.060129 -> V=1.0, theta=0.0
% INFO    : Bus 9885	: V=1.0013618, theta=-59.62969 -> V=1.0, theta=0.0
% INFO    : Bus 9886	: V=0.9860607, theta=-60.481177 -> V=1.0, theta=0.0
% INFO    : Bus 9887	: V=0.9900635, theta=-60.318159 -> V=1.0, theta=0.0
% INFO    : Bus 9888	: V=0.9909589, theta=-60.233597 -> V=1.0, theta=0.0
% INFO    : Bus 9889	: V=1.0124759, theta=-58.558495 -> V=1.0, theta=0.0
% INFO    : Bus 9890	: V=0.9927076, theta=-60.077493 -> V=1.0, theta=0.0
% INFO    : Bus 9891	: V=0.9920638, theta=-60.075222 -> V=1.0, theta=0.0
% INFO    : Bus 9892	: V=0.9918042, theta=-60.079052 -> V=1.0, theta=0.0
% INFO    : Bus 9893	: V=0.9991807, theta=-59.695243 -> V=1.0, theta=0.0
% INFO    : Bus 9894	: V=0.9965581, theta=-59.737584 -> V=1.0, theta=0.0
% INFO    : Bus 9895	: V=0.9977033, theta=-59.742056 -> V=1.0, theta=0.0
% INFO    : Bus 9896	: V=0.9983206, theta=-59.731554 -> V=1.0, theta=0.0
% INFO    : Bus 9897	: V=0.9955407, theta=-59.672622 -> V=1.0, theta=0.0
% INFO    : Bus 9898	: V=0.9964186, theta=-59.77297 -> V=1.0, theta=0.0
% INFO    : Bus 9899	: V=0.9943185, theta=-59.713956 -> V=1.0, theta=0.0
% INFO    : Bus 9900	: V=0.9891492, theta=-60.122889 -> V=1.0, theta=0.0
% INFO    : Bus 9901	: V=0.9919535, theta=-59.99965 -> V=1.0, theta=0.0
% INFO    : Bus 9902	: V=0.9889819, theta=-60.427893 -> V=1.0, theta=0.0
% INFO    : Bus 9903	: V=0.9889989, theta=-60.445256 -> V=1.0, theta=0.0
% INFO    : Bus 9904	: V=0.9913012, theta=-60.313812 -> V=1.0, theta=0.0
% INFO    : Bus 9905	: V=0.9948985, theta=-59.934973 -> V=1.0, theta=0.0
% INFO    : Bus 9906	: V=0.9890549, theta=-60.351336 -> V=1.0, theta=0.0
% INFO    : Bus 9907	: V=0.9972349, theta=-59.813968 -> V=1.0, theta=0.0
% INFO    : Bus 9908	: V=0.9829264, theta=-60.854885 -> V=1.0, theta=0.0
% INFO    : Bus 9909	: V=0.9952558, theta=-59.987004 -> V=1.0, theta=0.0
% INFO    : Bus 9910	: V=0.9926282, theta=-60.189036 -> V=1.0, theta=0.0
% INFO    : Bus 9911	: V=0.9874677, theta=-60.432645 -> V=1.0, theta=0.0
% INFO    : Bus 9912	: V=0.9935143, theta=-60.119468 -> V=1.0, theta=0.0
% INFO    : Bus 9913	: V=0.9876567, theta=-60.864297 -> V=1.0, theta=0.0
% INFO    : Bus 9914	: V=0.9877908, theta=-60.810008 -> V=1.0, theta=0.0
% INFO    : Bus 9915	: V=0.9879552, theta=-60.764545 -> V=1.0, theta=0.0
% INFO    : Bus 9916	: V=0.9882879, theta=-60.706288 -> V=1.0, theta=0.0
% INFO    : Bus 9917	: V=0.9844392, theta=-61.014635 -> V=1.0, theta=0.0
% INFO    : Bus 9918	: V=0.9881235, theta=-60.795698 -> V=1.0, theta=0.0
% INFO    : Bus 9919	: V=0.9840913, theta=-61.006059 -> V=1.0, theta=0.0
% INFO    : Bus 9920	: V=0.9878503, theta=-60.908017 -> V=1.0, theta=0.0
% INFO    : Bus 9921	: V=0.986842, theta=-61.062725 -> V=1.0, theta=0.0
% INFO    : Bus 9922	: V=0.9899345, theta=-60.744822 -> V=1.0, theta=0.0
% INFO    : Bus 9923	: V=0.9918735, theta=-60.596141 -> V=1.0, theta=0.0
% INFO    : Bus 9924	: V=0.9874254, theta=-60.946743 -> V=1.0, theta=0.0
% INFO    : Bus 9925	: V=0.987292, theta=-60.954447 -> V=1.0, theta=0.0
% INFO    : Bus 9926	: V=1.016657, theta=-58.367953 -> V=1.0, theta=0.0
% INFO    : Bus 9927	: V=0.9979382, theta=-59.667865 -> V=1.0, theta=0.0
% INFO    : Bus 9928	: V=1.0171159, theta=-58.459879 -> V=1.0, theta=0.0
% INFO    : Bus 9929	: V=1.0023198, theta=-60.020116 -> V=1.0, theta=0.0
% INFO    : Bus 9930	: V=1.0163657, theta=-59.071958 -> V=1.0, theta=0.0
% INFO    : Bus 9931	: V=1.0097326, theta=-59.008236 -> V=1.0, theta=0.0
% INFO    : Bus 9932	: V=0.9904582, theta=-60.261785 -> V=1.0, theta=0.0
% INFO    : Bus 9933	: V=0.980512, theta=-61.162035 -> V=1.0, theta=0.0
% INFO    : Bus 9934	: V=0.9628342, theta=-60.90323 -> V=1.0, theta=0.0
% INFO    : Bus 9935	: V=0.9660344, theta=-60.888589 -> V=1.0, theta=0.0
% INFO    : Bus 9936	: V=0.9693786, theta=-60.695175 -> V=1.0, theta=0.0
% INFO    : Bus 9937	: V=0.9701929, theta=-60.793151 -> V=1.0, theta=0.0
% INFO    : Bus 9938	: V=0.9715509, theta=-60.787265 -> V=1.0, theta=0.0
% INFO    : Bus 9939	: V=0.9723987, theta=-60.755328 -> V=1.0, theta=0.0
% INFO    : Bus 9940	: V=0.9857955, theta=-59.764627 -> V=1.0, theta=0.0
% INFO    : Bus 9941	: V=0.9716829, theta=-60.690457 -> V=1.0, theta=0.0
% INFO    : Bus 9942	: V=0.9709562, theta=-60.689192 -> V=1.0, theta=0.0
% INFO    : Bus 9943	: V=0.9706021, theta=-60.583396 -> V=1.0, theta=0.0
% INFO    : Bus 9944	: V=0.9719456, theta=-60.609656 -> V=1.0, theta=0.0
% INFO    : Bus 9945	: V=0.9698611, theta=-60.702393 -> V=1.0, theta=0.0
% INFO    : Bus 9946	: V=0.9863093, theta=-59.686322 -> V=1.0, theta=0.0
% INFO    : Bus 9947	: V=0.9862559, theta=-59.634168 -> V=1.0, theta=0.0
% INFO    : Bus 9948	: V=0.9740946, theta=-60.475114 -> V=1.0, theta=0.0
% INFO    : Bus 9949	: V=0.9709931, theta=-60.060124 -> V=1.0, theta=0.0
% INFO    : Bus 9950	: V=0.9719714, theta=-60.776342 -> V=1.0, theta=0.0
% INFO    : Bus 9951	: V=0.9712083, theta=-60.776065 -> V=1.0, theta=0.0
% INFO    : Bus 9952	: V=0.9759045, theta=-60.628534 -> V=1.0, theta=0.0
% INFO    : Bus 9953	: V=0.9836277, theta=-60.365898 -> V=1.0, theta=0.0
% INFO    : Bus 9954	: V=0.9932431, theta=-59.570365 -> V=1.0, theta=0.0
% INFO    : Bus 9955	: V=0.9756905, theta=-60.732926 -> V=1.0, theta=0.0
% INFO    : Bus 9956	: V=0.9710675, theta=-60.778357 -> V=1.0, theta=0.0
% INFO    : Bus 9957	: V=0.989661, theta=-59.676133 -> V=1.0, theta=0.0
% INFO    : Bus 9958	: V=0.9811235, theta=-60.447416 -> V=1.0, theta=0.0
% INFO    : Bus 9959	: V=0.9866592, theta=-60.219931 -> V=1.0, theta=0.0
% INFO    : Bus 9960	: V=0.9873259, theta=-60.217136 -> V=1.0, theta=0.0
% INFO    : Bus 9961	: V=0.9921472, theta=-59.793511 -> V=1.0, theta=0.0
% INFO    : Bus 9962	: V=0.9842172, theta=-60.221544 -> V=1.0, theta=0.0
% INFO    : Bus 9963	: V=0.9931966, theta=-59.754002 -> V=1.0, theta=0.0
% INFO    : Bus 9964	: V=0.9924701, theta=-59.779464 -> V=1.0, theta=0.0
% INFO    : Bus 9965	: V=0.9864186, theta=-60.229338 -> V=1.0, theta=0.0
% INFO    : Bus 9966	: V=0.9876204, theta=-59.73108 -> V=1.0, theta=0.0
% INFO    : Bus 9967	: V=0.9834462, theta=-60.26389 -> V=1.0, theta=0.0
% INFO    : Bus 9968	: V=0.9867267, theta=-59.75798 -> V=1.0, theta=0.0
% INFO    : Bus 9969	: V=0.9864121, theta=-59.582249 -> V=1.0, theta=0.0
% INFO    : Bus 9970	: V=0.9756282, theta=-60.377294 -> V=1.0, theta=0.0
% INFO    : Bus 9971	: V=0.9853924, theta=-59.655511 -> V=1.0, theta=0.0
% INFO    : Bus 9972	: V=0.9732406, theta=-60.541024 -> V=1.0, theta=0.0
% INFO    : Bus 9973	: V=0.9733299, theta=-60.340557 -> V=1.0, theta=0.0
% INFO    : Bus 9974	: V=0.970248, theta=-60.5686 -> V=1.0, theta=0.0
% INFO    : Bus 9975	: V=0.9660619, theta=-60.303281 -> V=1.0, theta=0.0
% INFO    : Bus 9976	: V=0.9748301, theta=-60.335568 -> V=1.0, theta=0.0
% INFO    : Bus 9977	: V=0.9752647, theta=-60.315867 -> V=1.0, theta=0.0
% INFO    : Bus 9978	: V=0.9789038, theta=-59.702607 -> V=1.0, theta=0.0
% INFO    : Bus 9979	: V=0.9789502, theta=-59.619412 -> V=1.0, theta=0.0
% INFO    : Bus 9980	: V=0.9909859, theta=-58.630691 -> V=1.0, theta=0.0
% INFO    : Bus 9981	: V=0.9790611, theta=-59.619061 -> V=1.0, theta=0.0
% INFO    : Bus 9982	: V=0.97979, theta=-59.573091 -> V=1.0, theta=0.0
% INFO    : Bus 9983	: V=0.9802661, theta=-59.500691 -> V=1.0, theta=0.0
% INFO    : Bus 9984	: V=0.9668621, theta=-60.302086 -> V=1.0, theta=0.0
% INFO    : Bus 9985	: V=0.9676292, theta=-60.263288 -> V=1.0, theta=0.0
% INFO    : Bus 9986	: V=0.9676853, theta=-60.273695 -> V=1.0, theta=0.0
% INFO    : Bus 9987	: V=0.9664202, theta=-60.399432 -> V=1.0, theta=0.0
% INFO    : Bus 9988	: V=0.9686714, theta=-60.220929 -> V=1.0, theta=0.0
% INFO    : Bus 9989	: V=0.9731023, theta=-59.855369 -> V=1.0, theta=0.0
% INFO    : Bus 9990	: V=0.972946, theta=-59.862861 -> V=1.0, theta=0.0
% INFO    : Bus 9991	: V=0.9760316, theta=-59.495765 -> V=1.0, theta=0.0
% INFO    : Bus 9992	: V=0.9740239, theta=-59.805028 -> V=1.0, theta=0.0
% INFO    : Bus 9993	: V=0.9737437, theta=-59.822816 -> V=1.0, theta=0.0
% INFO    : Bus 9994	: V=0.9851444, theta=-58.884699 -> V=1.0, theta=0.0
% INFO    : Bus 9995	: V=0.9763429, theta=-59.461435 -> V=1.0, theta=0.0
% INFO    : Bus 9996	: V=0.9868644, theta=-58.911476 -> V=1.0, theta=0.0
% INFO    : Bus 9997	: V=0.9873821, theta=-58.861726 -> V=1.0, theta=0.0
% INFO    : Bus 9998	: V=0.9882567, theta=-58.787996 -> V=1.0, theta=0.0
% INFO    : Bus 9999	: V=0.9869897, theta=-58.797434 -> V=1.0, theta=0.0
% INFO    : Bus 10000	: V=0.9862523, theta=-58.834905 -> V=1.0, theta=0.0
% INFO    : Bus 10001	: V=0.981824, theta=-58.566574 -> V=1.0, theta=0.0
% INFO    : Bus 10002	: V=0.9777626, theta=-59.071758 -> V=1.0, theta=0.0
% INFO    : Bus 10003	: V=0.9773291, theta=-59.072236 -> V=1.0, theta=0.0
% INFO    : Bus 10004	: V=0.977885, theta=-59.110774 -> V=1.0, theta=0.0
% INFO    : Bus 10005	: V=0.977861, theta=-59.12472 -> V=1.0, theta=0.0
% INFO    : Bus 10006	: V=0.9820362, theta=-58.547771 -> V=1.0, theta=0.0
% INFO    : Bus 10007	: V=0.9803167, theta=-58.866617 -> V=1.0, theta=0.0
% INFO    : Bus 10008	: V=0.9779928, theta=-59.130719 -> V=1.0, theta=0.0
% INFO    : Bus 10009	: V=0.9886233, theta=-58.598706 -> V=1.0, theta=0.0
% INFO    : Bus 10010	: V=0.9895783, theta=-58.676524 -> V=1.0, theta=0.0
% INFO    : Bus 10011	: V=0.9906219, theta=-58.590061 -> V=1.0, theta=0.0
% INFO    : Bus 10012	: V=0.991118, theta=-58.333375 -> V=1.0, theta=0.0
% INFO    : Bus 10013	: V=0.9826213, theta=-59.218871 -> V=1.0, theta=0.0
% INFO    : Bus 10014	: V=0.9900746, theta=-58.436933 -> V=1.0, theta=0.0
% INFO    : Bus 10015	: V=0.9823464, theta=-58.521458 -> V=1.0, theta=0.0
% INFO    : Bus 10016	: V=0.9827778, theta=-58.481593 -> V=1.0, theta=0.0
% INFO    : Bus 10017	: V=0.9830537, theta=-58.457032 -> V=1.0, theta=0.0
% INFO    : Bus 10018	: V=0.9836263, theta=-58.409002 -> V=1.0, theta=0.0
% INFO    : Bus 10019	: V=0.9936611, theta=-58.089319 -> V=1.0, theta=0.0
% INFO    : Bus 10020	: V=0.9940952, theta=-58.192877 -> V=1.0, theta=0.0
% INFO    : Bus 10021	: V=0.997482, theta=-57.757943 -> V=1.0, theta=0.0
% INFO    : Bus 10022	: V=1.0017963, theta=-57.37923 -> V=1.0, theta=0.0
% INFO    : Bus 10023	: V=0.9876922, theta=-58.052699 -> V=1.0, theta=0.0
% INFO    : Bus 10024	: V=0.9859742, theta=-58.203094 -> V=1.0, theta=0.0
% INFO    : Bus 10025	: V=0.9840044, theta=-58.376284 -> V=1.0, theta=0.0
% INFO    : Bus 10026	: V=0.9851274, theta=-58.277522 -> V=1.0, theta=0.0
% INFO    : Bus 10027	: V=0.9863005, theta=-58.143485 -> V=1.0, theta=0.0
% INFO    : Bus 10028	: V=0.9885816, theta=-57.972401 -> V=1.0, theta=0.0
% INFO    : Bus 10029	: V=0.9869201, theta=-58.142617 -> V=1.0, theta=0.0
% INFO    : Bus 10030	: V=0.9875524, theta=-58.107363 -> V=1.0, theta=0.0
% INFO    : Bus 10031	: V=0.9893682, theta=-59.758108 -> V=1.0, theta=0.0
% INFO    : Bus 10032	: V=0.984634, theta=-60.348674 -> V=1.0, theta=0.0
% INFO    : Bus 10033	: V=0.9837825, theta=-60.411169 -> V=1.0, theta=0.0
% INFO    : Bus 10034	: V=0.9808346, theta=-60.287445 -> V=1.0, theta=0.0
% INFO    : Bus 10035	: V=0.9798826, theta=-60.478964 -> V=1.0, theta=0.0
% INFO    : Bus 10036	: V=0.9798344, theta=-60.403686 -> V=1.0, theta=0.0
% INFO    : Bus 10037	: V=0.9793704, theta=-60.0873 -> V=1.0, theta=0.0
% INFO    : Bus 10038	: V=0.9803517, theta=-59.738617 -> V=1.0, theta=0.0
% INFO    : Bus 10039	: V=0.9879065, theta=-58.634689 -> V=1.0, theta=0.0
% INFO    : Bus 10040	: V=0.989745, theta=-60.152569 -> V=1.0, theta=0.0
% INFO    : Bus 10041	: V=0.9840551, theta=-60.429273 -> V=1.0, theta=0.0
% INFO    : Bus 10042	: V=0.9844997, theta=-60.435309 -> V=1.0, theta=0.0
% INFO    : Bus 10043	: V=0.9821126, theta=-60.499462 -> V=1.0, theta=0.0
% INFO    : Bus 10044	: V=0.9802615, theta=-60.501795 -> V=1.0, theta=0.0
% INFO    : Bus 10045	: V=0.9876152, theta=-60.226824 -> V=1.0, theta=0.0
% INFO    : Bus 10046	: V=0.9890062, theta=-60.188065 -> V=1.0, theta=0.0
% INFO    : Bus 10047	: V=0.9903808, theta=-60.127124 -> V=1.0, theta=0.0
% INFO    : Bus 10048	: V=0.9791969, theta=-60.458973 -> V=1.0, theta=0.0
% INFO    : Bus 10049	: V=0.9869587, theta=-59.809336 -> V=1.0, theta=0.0
% INFO    : Bus 10050	: V=0.9878049, theta=-59.767325 -> V=1.0, theta=0.0
% INFO    : Bus 10051	: V=0.9788726, theta=-60.437001 -> V=1.0, theta=0.0
% INFO    : Bus 10052	: V=0.9796973, theta=-60.493033 -> V=1.0, theta=0.0
% INFO    : Bus 10053	: V=0.9790333, theta=-60.514003 -> V=1.0, theta=0.0
% INFO    : Bus 10054	: V=0.9785722, theta=-60.402017 -> V=1.0, theta=0.0
% INFO    : Bus 10055	: V=0.978559, theta=-60.362566 -> V=1.0, theta=0.0
% INFO    : Bus 10056	: V=0.9777032, theta=-60.394262 -> V=1.0, theta=0.0
% INFO    : Bus 10057	: V=0.9769681, theta=-60.398874 -> V=1.0, theta=0.0
% INFO    : Bus 10058	: V=0.9815703, theta=-60.035946 -> V=1.0, theta=0.0
% INFO    : Bus 10059	: V=0.9901763, theta=-58.443062 -> V=1.0, theta=0.0
% INFO    : Bus 10060	: V=0.9837287, theta=-59.499678 -> V=1.0, theta=0.0
% INFO    : Bus 10061	: V=0.9838649, theta=-59.739672 -> V=1.0, theta=0.0
% INFO    : Bus 10062	: V=0.9859136, theta=-59.623009 -> V=1.0, theta=0.0
% INFO    : Bus 10063	: V=0.9864002, theta=-59.576311 -> V=1.0, theta=0.0
% INFO    : Bus 10064	: V=0.9861993, theta=-59.638472 -> V=1.0, theta=0.0
% INFO    : Bus 10065	: V=0.9860412, theta=-59.634861 -> V=1.0, theta=0.0
% INFO    : Bus 10066	: V=1.004076, theta=-57.24534 -> V=1.0, theta=0.0
% INFO    : Bus 10067	: V=0.9982948, theta=-57.731834 -> V=1.0, theta=0.0
% INFO    : Bus 10068	: V=0.9937704, theta=-58.108344 -> V=1.0, theta=0.0
% INFO    : Bus 10069	: V=0.9970284, theta=-59.935662 -> V=1.0, theta=0.0
% INFO    : Bus 10070	: V=0.9904322, theta=-60.456987 -> V=1.0, theta=0.0
% INFO    : Bus 10071	: V=0.9658829, theta=-60.333133 -> V=1.0, theta=0.0
% INFO    : Bus 10072	: V=0.9979752, theta=-58.099412 -> V=1.0, theta=0.0
% INFO    : Bus 10073	: V=0.9859339, theta=-59.410513 -> V=1.0, theta=0.0
% INFO    : Bus 10074	: V=0.9769334, theta=-59.451311 -> V=1.0, theta=0.0
% INFO    : Bus 10075	: V=0.990002, theta=-60.167492 -> V=1.0, theta=0.0
% INFO    : Bus 10076	: V=0.9923714, theta=-60.101318 -> V=1.0, theta=0.0
% INFO    : Bus 10077	: V=0.9824431, theta=-63.794187 -> V=1.0, theta=0.0
% INFO    : Bus 10078	: V=0.9882275, theta=-62.904571 -> V=1.0, theta=0.0
% INFO    : Bus 10079	: V=0.985731, theta=-63.561493 -> V=1.0, theta=0.0
% INFO    : Bus 10080	: V=0.9811925, theta=-64.12766 -> V=1.0, theta=0.0
% INFO    : Bus 10081	: V=0.9775004, theta=-65.137848 -> V=1.0, theta=0.0
% INFO    : Bus 10082	: V=0.9761013, theta=-65.259924 -> V=1.0, theta=0.0
% INFO    : Bus 10083	: V=0.9755622, theta=-65.29009 -> V=1.0, theta=0.0
% INFO    : Bus 10084	: V=0.9804083, theta=-64.08189 -> V=1.0, theta=0.0
% INFO    : Bus 10085	: V=0.9782767, theta=-64.141416 -> V=1.0, theta=0.0
% INFO    : Bus 10086	: V=0.9812921, theta=-63.871969 -> V=1.0, theta=0.0
% INFO    : Bus 10087	: V=0.9868972, theta=-62.591478 -> V=1.0, theta=0.0
% INFO    : Bus 10088	: V=0.9803418, theta=-63.656133 -> V=1.0, theta=0.0
% INFO    : Bus 10089	: V=0.9868347, theta=-62.756908 -> V=1.0, theta=0.0
% INFO    : Bus 10090	: V=0.9766533, theta=-63.817505 -> V=1.0, theta=0.0
% INFO    : Bus 10091	: V=0.9788028, theta=-63.677137 -> V=1.0, theta=0.0
% INFO    : Bus 10092	: V=0.9782469, theta=-63.688894 -> V=1.0, theta=0.0
% INFO    : Bus 10093	: V=0.975083, theta=-62.888463 -> V=1.0, theta=0.0
% INFO    : Bus 10094	: V=0.9811913, theta=-62.471847 -> V=1.0, theta=0.0
% INFO    : Bus 10095	: V=0.9810065, theta=-62.422397 -> V=1.0, theta=0.0
% INFO    : Bus 10096	: V=0.9826585, theta=-62.296771 -> V=1.0, theta=0.0
% INFO    : Bus 10097	: V=0.9822575, theta=-62.385305 -> V=1.0, theta=0.0
% INFO    : Bus 10098	: V=0.9820598, theta=-62.503806 -> V=1.0, theta=0.0
% INFO    : Bus 10099	: V=0.9792586, theta=-63.527294 -> V=1.0, theta=0.0
% INFO    : Bus 10100	: V=0.977001, theta=-62.809011 -> V=1.0, theta=0.0
% INFO    : Bus 10101	: V=0.9802344, theta=-63.429442 -> V=1.0, theta=0.0
% INFO    : Bus 10102	: V=0.985705, theta=-62.592968 -> V=1.0, theta=0.0
% INFO    : Bus 10103	: V=0.981061, theta=-63.192562 -> V=1.0, theta=0.0
% INFO    : Bus 10104	: V=0.9852837, theta=-62.546919 -> V=1.0, theta=0.0
% INFO    : Bus 10105	: V=0.979656, theta=-63.483564 -> V=1.0, theta=0.0
% INFO    : Bus 10106	: V=0.9794784, theta=-63.505764 -> V=1.0, theta=0.0
% INFO    : Bus 10107	: V=0.9769584, theta=-62.79391 -> V=1.0, theta=0.0
% INFO    : Bus 10108	: V=0.9848699, theta=-62.475627 -> V=1.0, theta=0.0
% INFO    : Bus 10109	: V=0.9863037, theta=-62.295438 -> V=1.0, theta=0.0
% INFO    : Bus 10110	: V=0.9854761, theta=-62.329035 -> V=1.0, theta=0.0
% INFO    : Bus 10111	: V=0.9835605, theta=-62.431697 -> V=1.0, theta=0.0
% INFO    : Bus 10112	: V=0.9829752, theta=-62.361163 -> V=1.0, theta=0.0
% INFO    : Bus 10113	: V=0.9828174, theta=-62.354898 -> V=1.0, theta=0.0
% INFO    : Bus 10114	: V=0.983344, theta=-62.296721 -> V=1.0, theta=0.0
% INFO    : Bus 10115	: V=0.9821873, theta=-62.445208 -> V=1.0, theta=0.0
% INFO    : Bus 10116	: V=0.9842293, theta=-62.229258 -> V=1.0, theta=0.0
% INFO    : Bus 10117	: V=0.9865751, theta=-61.706977 -> V=1.0, theta=0.0
% INFO    : Bus 10118	: V=0.9771174, theta=-62.395093 -> V=1.0, theta=0.0
% INFO    : Bus 10119	: V=0.9769453, theta=-62.356033 -> V=1.0, theta=0.0
% INFO    : Bus 10120	: V=0.9805775, theta=-62.276012 -> V=1.0, theta=0.0
% INFO    : Bus 10121	: V=0.9783376, theta=-62.389111 -> V=1.0, theta=0.0
% INFO    : Bus 10122	: V=0.9774197, theta=-62.391438 -> V=1.0, theta=0.0
% INFO    : Bus 10123	: V=0.9794833, theta=-62.367785 -> V=1.0, theta=0.0
% INFO    : Bus 10124	: V=0.9715108, theta=-62.943958 -> V=1.0, theta=0.0
% INFO    : Bus 10125	: V=0.981918, theta=-62.211332 -> V=1.0, theta=0.0
% INFO    : Bus 10126	: V=0.9812309, theta=-62.201457 -> V=1.0, theta=0.0
% INFO    : Bus 10127	: V=0.9836239, theta=-62.23338 -> V=1.0, theta=0.0
% INFO    : Bus 10128	: V=0.9828653, theta=-62.052703 -> V=1.0, theta=0.0
% INFO    : Bus 10129	: V=0.9748098, theta=-62.814516 -> V=1.0, theta=0.0
% INFO    : Bus 10130	: V=0.98219, theta=-62.189993 -> V=1.0, theta=0.0
% INFO    : Bus 10131	: V=0.9770908, theta=-62.652466 -> V=1.0, theta=0.0
% INFO    : Bus 10132	: V=0.9753674, theta=-62.779737 -> V=1.0, theta=0.0
% INFO    : Bus 10133	: V=0.9756531, theta=-62.362924 -> V=1.0, theta=0.0
% INFO    : Bus 10134	: V=0.9739051, theta=-62.326714 -> V=1.0, theta=0.0
% INFO    : Bus 10135	: V=0.9808282, theta=-61.856812 -> V=1.0, theta=0.0
% INFO    : Bus 10136	: V=0.9811941, theta=-61.823232 -> V=1.0, theta=0.0
% INFO    : Bus 10137	: V=0.9807932, theta=-62.128852 -> V=1.0, theta=0.0
% INFO    : Bus 10138	: V=0.9812557, theta=-62.357592 -> V=1.0, theta=0.0
% INFO    : Bus 10139	: V=0.9804435, theta=-63.265189 -> V=1.0, theta=0.0
% INFO    : Bus 10140	: V=0.9731069, theta=-62.858219 -> V=1.0, theta=0.0
% INFO    : Bus 10141	: V=0.9748602, theta=-62.749496 -> V=1.0, theta=0.0
% INFO    : Bus 10142	: V=0.9778132, theta=-62.600261 -> V=1.0, theta=0.0
% INFO    : Bus 10143	: V=0.9779075, theta=-62.497859 -> V=1.0, theta=0.0
% INFO    : Bus 10144	: V=0.9734829, theta=-64.356791 -> V=1.0, theta=0.0
% INFO    : Bus 10145	: V=0.9787147, theta=-63.536243 -> V=1.0, theta=0.0
% INFO    : Bus 10146	: V=0.979284, theta=-63.25687 -> V=1.0, theta=0.0
% INFO    : Bus 10147	: V=0.976447, theta=-63.071696 -> V=1.0, theta=0.0
% INFO    : Bus 10148	: V=0.9825948, theta=-62.20431 -> V=1.0, theta=0.0
% INFO    : Bus 10149	: V=0.9779732, theta=-62.477156 -> V=1.0, theta=0.0
% INFO    : Bus 10150	: V=0.9847925, theta=-61.927958 -> V=1.0, theta=0.0
% INFO    : Bus 10151	: V=0.9847756, theta=-61.9335 -> V=1.0, theta=0.0
% INFO    : Bus 10152	: V=0.9784114, theta=-62.607775 -> V=1.0, theta=0.0
% INFO    : Bus 10153	: V=0.986821, theta=-61.782804 -> V=1.0, theta=0.0
% INFO    : Bus 10154	: V=0.9807442, theta=-62.476657 -> V=1.0, theta=0.0
% INFO    : Bus 10155	: V=0.9896269, theta=-61.484121 -> V=1.0, theta=0.0
% INFO    : Bus 10156	: V=0.9787628, theta=-62.338581 -> V=1.0, theta=0.0
% INFO    : Bus 10157	: V=0.990429, theta=-61.400125 -> V=1.0, theta=0.0
% INFO    : Bus 10158	: V=0.983747, theta=-62.13151 -> V=1.0, theta=0.0
% INFO    : Bus 10159	: V=0.9843204, theta=-62.068879 -> V=1.0, theta=0.0
% INFO    : Bus 10160	: V=0.986781, theta=-61.831244 -> V=1.0, theta=0.0
% INFO    : Bus 10161	: V=0.9849507, theta=-62.051248 -> V=1.0, theta=0.0
% INFO    : Bus 10162	: V=0.9791017, theta=-62.467144 -> V=1.0, theta=0.0
% INFO    : Bus 10163	: V=0.9841154, theta=-61.832507 -> V=1.0, theta=0.0
% INFO    : Bus 10164	: V=0.9917138, theta=-60.85859 -> V=1.0, theta=0.0
% INFO    : Bus 10165	: V=0.9912262, theta=-60.906225 -> V=1.0, theta=0.0
% INFO    : Bus 10166	: V=0.9932531, theta=-61.110872 -> V=1.0, theta=0.0
% INFO    : Bus 10167	: V=0.9903775, theta=-61.434849 -> V=1.0, theta=0.0
% INFO    : Bus 10168	: V=0.9922613, theta=-61.24792 -> V=1.0, theta=0.0
% INFO    : Bus 10169	: V=0.9965261, theta=-60.786021 -> V=1.0, theta=0.0
% INFO    : Bus 10170	: V=1.0035388, theta=-59.937883 -> V=1.0, theta=0.0
% INFO    : Bus 10171	: V=1.0000022, theta=-60.153329 -> V=1.0, theta=0.0
% INFO    : Bus 10172	: V=0.9909973, theta=-60.771323 -> V=1.0, theta=0.0
% INFO    : Bus 10173	: V=0.998733, theta=-60.206876 -> V=1.0, theta=0.0
% INFO    : Bus 10174	: V=0.9951161, theta=-60.536382 -> V=1.0, theta=0.0
% INFO    : Bus 10175	: V=0.9847645, theta=-62.022375 -> V=1.0, theta=0.0
% INFO    : Bus 10176	: V=0.9852354, theta=-61.659806 -> V=1.0, theta=0.0
% INFO    : Bus 10177	: V=0.9919155, theta=-57.683223 -> V=1.0, theta=0.0
% INFO    : Bus 10178	: V=0.9933796, theta=-57.561928 -> V=1.0, theta=0.0
% INFO    : Bus 10179	: V=0.9898483, theta=-57.982841 -> V=1.0, theta=0.0
% INFO    : Bus 10180	: V=0.9947241, theta=-57.454128 -> V=1.0, theta=0.0
% INFO    : Bus 10181	: V=0.9959546, theta=-57.34221 -> V=1.0, theta=0.0
% INFO    : Bus 10182	: V=0.9958398, theta=-57.332832 -> V=1.0, theta=0.0
% INFO    : Bus 10183	: V=0.9906684, theta=-57.972204 -> V=1.0, theta=0.0
% INFO    : Bus 10184	: V=0.9915686, theta=-57.946952 -> V=1.0, theta=0.0
% INFO    : Bus 10185	: V=1.003591, theta=-57.219624 -> V=1.0, theta=0.0
% INFO    : Bus 10186	: V=0.992265, theta=-57.92618 -> V=1.0, theta=0.0
% INFO    : Bus 10187	: V=1.0059666, theta=-57.014005 -> V=1.0, theta=0.0
% INFO    : Bus 10188	: V=1.0083812, theta=-56.815478 -> V=1.0, theta=0.0
% INFO    : Bus 10189	: V=1.0078111, theta=-56.909709 -> V=1.0, theta=0.0
% INFO    : Bus 10190	: V=1.0114367, theta=-56.578052 -> V=1.0, theta=0.0
% INFO    : Bus 10191	: V=0.9980872, theta=-57.236617 -> V=1.0, theta=0.0
% INFO    : Bus 10192	: V=0.9973103, theta=-57.237282 -> V=1.0, theta=0.0
% INFO    : Bus 10193	: V=0.9976039, theta=-57.192905 -> V=1.0, theta=0.0
% INFO    : Bus 10194	: V=0.9989538, theta=-57.069414 -> V=1.0, theta=0.0
% INFO    : Bus 10195	: V=1.0021781, theta=-56.810316 -> V=1.0, theta=0.0
% INFO    : Bus 10196	: V=1.0025373, theta=-56.891934 -> V=1.0, theta=0.0
% INFO    : Bus 10197	: V=1.0054706, theta=-56.609383 -> V=1.0, theta=0.0
% INFO    : Bus 10198	: V=1.0025441, theta=-56.778578 -> V=1.0, theta=0.0
% INFO    : Bus 10199	: V=1.0029389, theta=-56.658807 -> V=1.0, theta=0.0
% INFO    : Bus 10200	: V=1.003233, theta=-56.586089 -> V=1.0, theta=0.0
% INFO    : Bus 10201	: V=1.0076902, theta=-56.850259 -> V=1.0, theta=0.0
% INFO    : Bus 10202	: V=1.005395, theta=-56.948594 -> V=1.0, theta=0.0
% INFO    : Bus 10203	: V=1.0047491, theta=-56.991336 -> V=1.0, theta=0.0
% INFO    : Bus 10204	: V=1.0048628, theta=-56.94404 -> V=1.0, theta=0.0
% INFO    : Bus 10205	: V=0.9922815, theta=-57.719458 -> V=1.0, theta=0.0
% INFO    : Bus 10206	: V=1.0045284, theta=-56.930006 -> V=1.0, theta=0.0
% INFO    : Bus 10207	: V=1.0041979, theta=-56.90429 -> V=1.0, theta=0.0
% INFO    : Bus 10208	: V=0.9830884, theta=-58.666423 -> V=1.0, theta=0.0
% INFO    : Bus 10209	: V=1.004199, theta=-56.821635 -> V=1.0, theta=0.0
% INFO    : Bus 10210	: V=1.0093414, theta=-56.559711 -> V=1.0, theta=0.0
% INFO    : Bus 10211	: V=1.0027361, theta=-56.853131 -> V=1.0, theta=0.0
% INFO    : Bus 10212	: V=1.0032479, theta=-56.850335 -> V=1.0, theta=0.0
% INFO    : Bus 10213	: V=1.0034155, theta=-56.883292 -> V=1.0, theta=0.0
% INFO    : Bus 10214	: V=0.9895947, theta=-59.00357 -> V=1.0, theta=0.0
% INFO    : Bus 10215	: V=0.997567, theta=-57.437047 -> V=1.0, theta=0.0
% INFO    : Bus 10216	: V=0.9804128, theta=-60.197297 -> V=1.0, theta=0.0
% INFO    : Bus 10217	: V=0.978156, theta=-60.197393 -> V=1.0, theta=0.0
% INFO    : Bus 10218	: V=0.9878414, theta=-60.185799 -> V=1.0, theta=0.0
% INFO    : Bus 10219	: V=0.9893024, theta=-60.121086 -> V=1.0, theta=0.0
% INFO    : Bus 10220	: V=0.9884681, theta=-58.976783 -> V=1.0, theta=0.0
% INFO    : Bus 10221	: V=0.9988238, theta=-57.315601 -> V=1.0, theta=0.0
% INFO    : Bus 10222	: V=1.0008258, theta=-57.147901 -> V=1.0, theta=0.0
% INFO    : Bus 10223	: V=0.9916447, theta=-60.187108 -> V=1.0, theta=0.0
% INFO    : Bus 10224	: V=0.9922403, theta=-56.595191 -> V=1.0, theta=0.0
% INFO    : Bus 10225	: V=1.0000744, theta=-56.771257 -> V=1.0, theta=0.0
% INFO    : Bus 10226	: V=0.9884373, theta=-58.119998 -> V=1.0, theta=0.0
% INFO    : Bus 10227	: V=0.9893897, theta=-58.11446 -> V=1.0, theta=0.0
% INFO    : Bus 10228	: V=1.0021801, theta=-56.717451 -> V=1.0, theta=0.0
% INFO    : Bus 10229	: V=0.9842888, theta=-58.162394 -> V=1.0, theta=0.0
% INFO    : Bus 10230	: V=0.9836098, theta=-58.170779 -> V=1.0, theta=0.0
% INFO    : Bus 10231	: V=1.0012794, theta=-56.821318 -> V=1.0, theta=0.0
% INFO    : Bus 10232	: V=1.0018932, theta=-56.82829 -> V=1.0, theta=0.0
% INFO    : Bus 10233	: V=1.000731, theta=-56.807456 -> V=1.0, theta=0.0
% INFO    : Bus 10234	: V=1.0031485, theta=-56.828886 -> V=1.0, theta=0.0
% INFO    : Bus 10235	: V=1.0055882, theta=-56.585312 -> V=1.0, theta=0.0
% INFO    : Bus 10236	: V=1.0022309, theta=-56.794082 -> V=1.0, theta=0.0
% INFO    : Bus 10237	: V=1.0028128, theta=-56.87882 -> V=1.0, theta=0.0
% INFO    : Bus 10238	: V=1.004395, theta=-56.502596 -> V=1.0, theta=0.0
% INFO    : Bus 10239	: V=1.0014907, theta=-56.879481 -> V=1.0, theta=0.0
% INFO    : Bus 10240	: V=1.0012835, theta=-56.869857 -> V=1.0, theta=0.0
% INFO    : Bus 10241	: V=1.0037105, theta=-56.472615 -> V=1.0, theta=0.0
% INFO    : Bus 10242	: V=1.0014221, theta=-56.816155 -> V=1.0, theta=0.0
% INFO    : Bus 10243	: V=1.0040948, theta=-56.456431 -> V=1.0, theta=0.0
% INFO    : Bus 10244	: V=1.0040423, theta=-56.412447 -> V=1.0, theta=0.0
% INFO    : Bus 10245	: V=0.9957673, theta=-56.843198 -> V=1.0, theta=0.0
% INFO    : Bus 10246	: V=0.9921206, theta=-57.158219 -> V=1.0, theta=0.0
% INFO    : Bus 10247	: V=1.0045073, theta=-56.396989 -> V=1.0, theta=0.0
% INFO    : Bus 10248	: V=1.0043208, theta=-56.246197 -> V=1.0, theta=0.0
% INFO    : Bus 10249	: V=1.00415, theta=-56.330351 -> V=1.0, theta=0.0
% INFO    : Bus 10250	: V=1.0046791, theta=-56.197822 -> V=1.0, theta=0.0
% INFO    : Bus 10251	: V=0.994516, theta=-56.85076 -> V=1.0, theta=0.0
% INFO    : Bus 10252	: V=1.0009913, theta=-56.38155 -> V=1.0, theta=0.0
% INFO    : Bus 10253	: V=0.996349, theta=-56.814631 -> V=1.0, theta=0.0
% INFO    : Bus 10254	: V=1.0050999, theta=-56.110065 -> V=1.0, theta=0.0
% INFO    : Bus 10255	: V=1.0057132, theta=-56.017583 -> V=1.0, theta=0.0
% INFO    : Bus 10256	: V=1.0061808, theta=-55.951729 -> V=1.0, theta=0.0
% INFO    : Bus 10257	: V=1.0001552, theta=-56.353574 -> V=1.0, theta=0.0
% INFO    : Bus 10258	: V=1.0054833, theta=-56.071513 -> V=1.0, theta=0.0
% INFO    : Bus 10259	: V=1.0042509, theta=-56.355008 -> V=1.0, theta=0.0
% INFO    : Bus 10260	: V=1.004634, theta=-56.274084 -> V=1.0, theta=0.0
% INFO    : Bus 10261	: V=1.0051061, theta=-56.187708 -> V=1.0, theta=0.0
% INFO    : Bus 10262	: V=0.9993503, theta=-56.226755 -> V=1.0, theta=0.0
% INFO    : Bus 10263	: V=1.0033251, theta=-56.16042 -> V=1.0, theta=0.0
% INFO    : Bus 10264	: V=0.9996912, theta=-56.225124 -> V=1.0, theta=0.0
% INFO    : Bus 10265	: V=1.008941, theta=-55.583328 -> V=1.0, theta=0.0
% INFO    : Bus 10266	: V=1.0065697, theta=-55.915608 -> V=1.0, theta=0.0
% INFO    : Bus 10267	: V=1.0079669, theta=-55.725098 -> V=1.0, theta=0.0
% INFO    : Bus 10268	: V=1.0011601, theta=-56.183763 -> V=1.0, theta=0.0
% INFO    : Bus 10269	: V=0.995753, theta=-57.711987 -> V=1.0, theta=0.0
% INFO    : Bus 10270	: V=1.0044423, theta=-56.342651 -> V=1.0, theta=0.0
% INFO    : Bus 10271	: V=0.9931656, theta=-57.875115 -> V=1.0, theta=0.0
% INFO    : Bus 10272	: V=1.0053936, theta=-56.170851 -> V=1.0, theta=0.0
% INFO    : Bus 10273	: V=0.9992518, theta=-56.531304 -> V=1.0, theta=0.0
% INFO    : Bus 10274	: V=0.9927243, theta=-57.132293 -> V=1.0, theta=0.0
% INFO    : Bus 10275	: V=1.0075834, theta=-55.829168 -> V=1.0, theta=0.0
% INFO    : Bus 10276	: V=1.0139637, theta=-54.768079 -> V=1.0, theta=0.0
% INFO    : Bus 10277	: V=1.0159432, theta=-54.581544 -> V=1.0, theta=0.0
% INFO    : Bus 10278	: V=1.0149168, theta=-54.51328 -> V=1.0, theta=0.0
% INFO    : Bus 10279	: V=1.018061, theta=-54.211664 -> V=1.0, theta=0.0
% INFO    : Bus 10280	: V=1.0048932, theta=-55.002161 -> V=1.0, theta=0.0
% INFO    : Bus 10281	: V=0.9893395, theta=-56.13027 -> V=1.0, theta=0.0
% INFO    : Bus 10282	: V=1.0033792, theta=-54.972244 -> V=1.0, theta=0.0
% INFO    : Bus 10283	: V=1.0013399, theta=-55.01709 -> V=1.0, theta=0.0
% INFO    : Bus 10284	: V=0.9985848, theta=-55.097771 -> V=1.0, theta=0.0
% INFO    : Bus 10285	: V=0.9969319, theta=-55.085536 -> V=1.0, theta=0.0
% INFO    : Bus 10286	: V=0.9945859, theta=-55.137329 -> V=1.0, theta=0.0
% INFO    : Bus 10287	: V=0.9944227, theta=-55.163553 -> V=1.0, theta=0.0
% INFO    : Bus 10288	: V=0.9960533, theta=-55.158876 -> V=1.0, theta=0.0
% INFO    : Bus 10289	: V=0.9945048, theta=-54.9672 -> V=1.0, theta=0.0
% INFO    : Bus 10290	: V=0.9942872, theta=-55.065075 -> V=1.0, theta=0.0
% INFO    : Bus 10291	: V=0.9944886, theta=-54.332367 -> V=1.0, theta=0.0
% INFO    : Bus 10292	: V=0.9922113, theta=-54.674378 -> V=1.0, theta=0.0
% INFO    : Bus 10293	: V=0.989971, theta=-54.679883 -> V=1.0, theta=0.0
% INFO    : Bus 10294	: V=0.9919513, theta=-54.775065 -> V=1.0, theta=0.0
% INFO    : Bus 10295	: V=0.9926292, theta=-55.080194 -> V=1.0, theta=0.0
% INFO    : Bus 10296	: V=0.9919549, theta=-54.975988 -> V=1.0, theta=0.0
% INFO    : Bus 10297	: V=1.0131843, theta=-54.51626 -> V=1.0, theta=0.0
% INFO    : Bus 10298	: V=0.9909347, theta=-55.187495 -> V=1.0, theta=0.0
% INFO    : Bus 10299	: V=0.9808572, theta=-60.024946 -> V=1.0, theta=0.0
% INFO    : Bus 10300	: V=1.0131936, theta=-54.516921 -> V=1.0, theta=0.0
% INFO    : Bus 10301	: V=0.9936141, theta=-54.471091 -> V=1.0, theta=0.0
% INFO    : Bus 10302	: V=0.9748607, theta=-65.475687 -> V=1.0, theta=0.0
% INFO    : Bus 10303	: V=0.9939285, theta=-63.30046 -> V=1.0, theta=0.0
% INFO    : Bus 10304	: V=0.988532, theta=-62.746681 -> V=1.0, theta=0.0
% INFO    : Bus 10305	: V=0.9891978, theta=-63.349886 -> V=1.0, theta=0.0
% INFO    : Bus 10306	: V=0.9885204, theta=-62.794475 -> V=1.0, theta=0.0
% INFO    : Bus 10307	: V=0.9882953, theta=-63.426392 -> V=1.0, theta=0.0
% INFO    : Bus 10308	: V=0.9888918, theta=-63.422136 -> V=1.0, theta=0.0
% INFO    : Bus 10309	: V=0.9883786, theta=-63.512493 -> V=1.0, theta=0.0
% INFO    : Bus 10310	: V=0.987982, theta=-62.731269 -> V=1.0, theta=0.0
% INFO    : Bus 10311	: V=0.993219, theta=-63.393424 -> V=1.0, theta=0.0
% INFO    : Bus 10312	: V=0.9935364, theta=-63.361442 -> V=1.0, theta=0.0
% INFO    : Bus 10313	: V=0.9933393, theta=-63.391483 -> V=1.0, theta=0.0
% INFO    : Bus 10314	: V=0.9899924, theta=-63.849487 -> V=1.0, theta=0.0
% INFO    : Bus 10315	: V=0.9900464, theta=-63.821455 -> V=1.0, theta=0.0
% INFO    : Bus 10316	: V=0.9931173, theta=-63.426519 -> V=1.0, theta=0.0
% INFO    : Bus 10317	: V=0.990198, theta=-63.771609 -> V=1.0, theta=0.0
% INFO    : Bus 10318	: V=0.98987, theta=-63.755155 -> V=1.0, theta=0.0
% INFO    : Bus 10319	: V=0.9884846, theta=-64.087152 -> V=1.0, theta=0.0
% INFO    : Bus 10320	: V=0.9885302, theta=-64.051252 -> V=1.0, theta=0.0
% INFO    : Bus 10321	: V=0.9856617, theta=-64.367665 -> V=1.0, theta=0.0
% INFO    : Bus 10322	: V=0.9867896, theta=-64.289591 -> V=1.0, theta=0.0
% INFO    : Bus 10323	: V=0.9894525, theta=-63.575636 -> V=1.0, theta=0.0
% INFO    : Bus 10324	: V=0.988747, theta=-62.633991 -> V=1.0, theta=0.0
% INFO    : Bus 10325	: V=0.9893829, theta=-63.824002 -> V=1.0, theta=0.0
% INFO    : Bus 10326	: V=0.9884093, theta=-63.643194 -> V=1.0, theta=0.0
% INFO    : Bus 10327	: V=0.9898826, theta=-63.755363 -> V=1.0, theta=0.0
% INFO    : Bus 10328	: V=0.9899924, theta=-63.75039 -> V=1.0, theta=0.0
% INFO    : Bus 10329	: V=0.993588, theta=-63.469926 -> V=1.0, theta=0.0
% INFO    : Bus 10330	: V=0.9901092, theta=-63.713758 -> V=1.0, theta=0.0
% INFO    : Bus 10331	: V=0.9892878, theta=-63.700621 -> V=1.0, theta=0.0
% INFO    : Bus 10332	: V=0.9931726, theta=-63.431369 -> V=1.0, theta=0.0
% INFO    : Bus 10333	: V=0.9885573, theta=-63.568042 -> V=1.0, theta=0.0
% INFO    : Bus 10334	: V=0.9889538, theta=-63.688054 -> V=1.0, theta=0.0
% INFO    : Bus 10335	: V=0.9881581, theta=-62.796576 -> V=1.0, theta=0.0
% INFO    : Bus 10336	: V=0.9888771, theta=-63.65152 -> V=1.0, theta=0.0
% INFO    : Bus 10337	: V=0.9880448, theta=-62.81878 -> V=1.0, theta=0.0
% INFO    : Bus 10338	: V=0.9889637, theta=-63.712326 -> V=1.0, theta=0.0
% INFO    : Bus 10339	: V=0.9895929, theta=-63.660217 -> V=1.0, theta=0.0
% INFO    : Bus 10340	: V=0.9887791, theta=-63.712248 -> V=1.0, theta=0.0
% INFO    : Bus 10341	: V=0.9908094, theta=-63.63629 -> V=1.0, theta=0.0
% INFO    : Bus 10342	: V=0.9884128, theta=-64.156648 -> V=1.0, theta=0.0
% INFO    : Bus 10343	: V=0.9915164, theta=-63.60576 -> V=1.0, theta=0.0
% INFO    : Bus 10344	: V=0.9885541, theta=-64.114764 -> V=1.0, theta=0.0
% INFO    : Bus 10345	: V=0.9884808, theta=-64.154782 -> V=1.0, theta=0.0
% INFO    : Bus 10346	: V=0.9879217, theta=-64.245467 -> V=1.0, theta=0.0
% INFO    : Bus 10347	: V=0.9919409, theta=-63.662498 -> V=1.0, theta=0.0
% INFO    : Bus 10348	: V=0.9880932, theta=-64.235389 -> V=1.0, theta=0.0
% INFO    : Bus 10349	: V=0.9885923, theta=-64.194176 -> V=1.0, theta=0.0
% INFO    : Bus 10350	: V=0.9887192, theta=-64.19398 -> V=1.0, theta=0.0
% INFO    : Bus 10351	: V=0.9889717, theta=-64.174419 -> V=1.0, theta=0.0
% INFO    : Bus 10352	: V=0.9892456, theta=-64.145701 -> V=1.0, theta=0.0
% INFO    : Bus 10353	: V=0.9885779, theta=-64.145599 -> V=1.0, theta=0.0
% INFO    : Bus 10354	: V=0.9887919, theta=-64.140112 -> V=1.0, theta=0.0
% INFO    : Bus 10355	: V=0.9888576, theta=-64.129129 -> V=1.0, theta=0.0
% INFO    : Bus 10356	: V=0.9884778, theta=-64.162938 -> V=1.0, theta=0.0
% INFO    : Bus 10357	: V=0.9917315, theta=-63.584508 -> V=1.0, theta=0.0
% INFO    : Bus 10358	: V=0.9915769, theta=-63.608682 -> V=1.0, theta=0.0
% INFO    : Bus 10359	: V=0.9905347, theta=-63.739794 -> V=1.0, theta=0.0
% INFO    : Bus 10360	: V=0.9914708, theta=-63.623779 -> V=1.0, theta=0.0
% INFO    : Bus 10361	: V=0.9913723, theta=-63.637134 -> V=1.0, theta=0.0
% INFO    : Bus 10362	: V=0.9913098, theta=-63.645175 -> V=1.0, theta=0.0
% INFO    : Bus 10363	: V=0.9903159, theta=-64.043965 -> V=1.0, theta=0.0
% INFO    : Bus 10364	: V=0.9893293, theta=-63.909839 -> V=1.0, theta=0.0
% INFO    : Bus 10365	: V=0.9919526, theta=-63.899703 -> V=1.0, theta=0.0
% INFO    : Bus 10366	: V=0.9902737, theta=-63.837329 -> V=1.0, theta=0.0
% INFO    : Bus 10367	: V=0.9904002, theta=-63.745492 -> V=1.0, theta=0.0
% INFO    : Bus 10368	: V=0.9907247, theta=-63.735448 -> V=1.0, theta=0.0
% INFO    : Bus 10369	: V=0.99085, theta=-63.822206 -> V=1.0, theta=0.0
% INFO    : Bus 10370	: V=0.9911086, theta=-63.870068 -> V=1.0, theta=0.0
% INFO    : Bus 10371	: V=0.9905895, theta=-63.836654 -> V=1.0, theta=0.0
% INFO    : Bus 10372	: V=0.9923103, theta=-63.63009 -> V=1.0, theta=0.0
% INFO    : Bus 10373	: V=0.9846245, theta=-63.812912 -> V=1.0, theta=0.0
% INFO    : Bus 10374	: V=0.98391, theta=-63.983001 -> V=1.0, theta=0.0
% INFO    : Bus 10375	: V=0.9876604, theta=-64.255647 -> V=1.0, theta=0.0
% INFO    : Bus 10376	: V=0.9717784, theta=-65.726703 -> V=1.0, theta=0.0
% INFO    : Bus 10377	: V=0.979432, theta=-64.870531 -> V=1.0, theta=0.0
% INFO    : Bus 10378	: V=0.9913991, theta=-63.604247 -> V=1.0, theta=0.0
% INFO    : Bus 10379	: V=0.9997842, theta=-61.438486 -> V=1.0, theta=0.0
% INFO    : Bus 10380	: V=0.9906496, theta=-63.732836 -> V=1.0, theta=0.0
% INFO    : Bus 10381	: V=0.9788789, theta=-65.025655 -> V=1.0, theta=0.0
% INFO    : Bus 10382	: V=0.9760401, theta=-65.358661 -> V=1.0, theta=0.0
% INFO    : Bus 10383	: V=0.9874527, theta=-63.80051 -> V=1.0, theta=0.0
% INFO    : Bus 10384	: V=0.9817613, theta=-64.258516 -> V=1.0, theta=0.0
% INFO    : Bus 10385	: V=0.981336, theta=-64.170973 -> V=1.0, theta=0.0
% INFO    : Bus 10386	: V=0.9881175, theta=-63.51608 -> V=1.0, theta=0.0
% INFO    : Bus 10387	: V=0.9882524, theta=-63.90146 -> V=1.0, theta=0.0
% INFO    : Bus 10388	: V=0.9878946, theta=-63.415997 -> V=1.0, theta=0.0
% INFO    : Bus 10389	: V=0.9897873, theta=-63.754649 -> V=1.0, theta=0.0
% INFO    : Bus 10390	: V=0.9825571, theta=-64.094714 -> V=1.0, theta=0.0
% INFO    : Bus 10391	: V=0.9878659, theta=-63.319361 -> V=1.0, theta=0.0
% INFO    : Bus 10392	: V=0.9880622, theta=-63.166784 -> V=1.0, theta=0.0
% INFO    : Bus 10393	: V=0.9882863, theta=-63.053117 -> V=1.0, theta=0.0
% INFO    : Bus 10394	: V=0.9747497, theta=-65.889552 -> V=1.0, theta=0.0
% INFO    : Bus 10395	: V=0.9767546, theta=-65.364437 -> V=1.0, theta=0.0
% INFO    : Bus 10396	: V=0.9756669, theta=-65.543066 -> V=1.0, theta=0.0
% INFO    : Bus 10397	: V=0.9738606, theta=-65.671848 -> V=1.0, theta=0.0
% INFO    : Bus 10398	: V=0.9706779, theta=-65.933435 -> V=1.0, theta=0.0
% INFO    : Bus 10399	: V=0.9918323, theta=-63.526484 -> V=1.0, theta=0.0
% INFO    : Bus 10400	: V=0.9995042, theta=-62.447478 -> V=1.0, theta=0.0
% INFO    : Bus 10401	: V=0.9888634, theta=-64.147036 -> V=1.0, theta=0.0
% INFO    : Bus 10402	: V=1.0111358, theta=-56.77135 -> V=1.0, theta=0.0
% INFO    : Bus 10403	: V=1.0041954, theta=-57.132798 -> V=1.0, theta=0.0
% INFO    : Bus 10404	: V=1.0044811, theta=-57.131837 -> V=1.0, theta=0.0
% INFO    : Bus 10405	: V=1.0036836, theta=-57.134508 -> V=1.0, theta=0.0
% INFO    : Bus 10406	: V=1.0036687, theta=-57.137455 -> V=1.0, theta=0.0
% INFO    : Bus 10407	: V=1.0074685, theta=-56.53609 -> V=1.0, theta=0.0
% INFO    : Bus 10408	: V=0.9992833, theta=-56.760551 -> V=1.0, theta=0.0
% INFO    : Bus 10409	: V=1.0011038, theta=-56.421397 -> V=1.0, theta=0.0
% INFO    : Bus 10410	: V=0.9885, theta=-56.948921 -> V=1.0, theta=0.0
% INFO    : Bus 10411	: V=0.9914029, theta=-56.586419 -> V=1.0, theta=0.0
% INFO    : Bus 10412	: V=0.9943073, theta=-56.251556 -> V=1.0, theta=0.0
% INFO    : Bus 10413	: V=0.9877059, theta=-56.260363 -> V=1.0, theta=0.0
% INFO    : Bus 10414	: V=1.0070449, theta=-55.123994 -> V=1.0, theta=0.0
% INFO    : Bus 10415	: V=1.0104469, theta=-54.711114 -> V=1.0, theta=0.0
% INFO    : Bus 10416	: V=1.0059684, theta=-55.573826 -> V=1.0, theta=0.0
% INFO    : Bus 10417	: V=1.0169946, theta=-55.553667 -> V=1.0, theta=0.0
% INFO    : Bus 10418	: V=1.0191017, theta=-55.534102 -> V=1.0, theta=0.0
% INFO    : Bus 10419	: V=1.0112055, theta=-55.580313 -> V=1.0, theta=0.0
% INFO    : Bus 10420	: V=1.0134117, theta=-55.5738 -> V=1.0, theta=0.0
% INFO    : Bus 10421	: V=1.0091441, theta=-55.069176 -> V=1.0, theta=0.0
% INFO    : Bus 10422	: V=1.0097721, theta=-54.970587 -> V=1.0, theta=0.0
% INFO    : Bus 10423	: V=1.0087653, theta=-55.190375 -> V=1.0, theta=0.0
% INFO    : Bus 10424	: V=1.0139622, theta=-54.05746 -> V=1.0, theta=0.0
% INFO    : Bus 10425	: V=1.0120414, theta=-54.632769 -> V=1.0, theta=0.0
% INFO    : Bus 10426	: V=0.9758918, theta=-62.094621 -> V=1.0, theta=0.0
% INFO    : Bus 10427	: V=0.9706358, theta=-62.470395 -> V=1.0, theta=0.0
% INFO    : Bus 10428	: V=0.9710793, theta=-62.462507 -> V=1.0, theta=0.0
% INFO    : Bus 10429	: V=0.9702267, theta=-62.502507 -> V=1.0, theta=0.0
% INFO    : Bus 10430	: V=0.9763132, theta=-62.067373 -> V=1.0, theta=0.0
% INFO    : Bus 10431	: V=0.9768405, theta=-62.031285 -> V=1.0, theta=0.0
% INFO    : Bus 10432	: V=0.9717303, theta=-62.440408 -> V=1.0, theta=0.0
% INFO    : Bus 10433	: V=0.969716, theta=-62.507825 -> V=1.0, theta=0.0
% INFO    : Bus 10434	: V=0.9781526, theta=-61.936625 -> V=1.0, theta=0.0
% INFO    : Bus 10435	: V=0.9813985, theta=-61.747316 -> V=1.0, theta=0.0
% INFO    : Bus 10436	: V=0.9810505, theta=-61.7811 -> V=1.0, theta=0.0
% INFO    : Bus 10437	: V=0.972488, theta=-62.345003 -> V=1.0, theta=0.0
% INFO    : Bus 10438	: V=0.9722715, theta=-62.208791 -> V=1.0, theta=0.0
% INFO    : Bus 10439	: V=0.9685768, theta=-62.458257 -> V=1.0, theta=0.0
% INFO    : Bus 10440	: V=0.9787968, theta=-61.807529 -> V=1.0, theta=0.0
% INFO    : Bus 10441	: V=0.973428, theta=-62.257728 -> V=1.0, theta=0.0
% INFO    : Bus 10442	: V=0.9808864, theta=-61.631047 -> V=1.0, theta=0.0
% INFO    : Bus 10443	: V=0.9729437, theta=-62.260365 -> V=1.0, theta=0.0
% INFO    : Bus 10444	: V=0.9779097, theta=-61.891587 -> V=1.0, theta=0.0
% INFO    : Bus 10445	: V=0.9777888, theta=-61.904416 -> V=1.0, theta=0.0
% INFO    : Bus 10446	: V=0.9781974, theta=-61.86341 -> V=1.0, theta=0.0
% INFO    : Bus 10447	: V=0.9800565, theta=-61.569294 -> V=1.0, theta=0.0
% INFO    : Bus 10448	: V=0.9803936, theta=-61.548276 -> V=1.0, theta=0.0
% INFO    : Bus 10449	: V=0.9809039, theta=-61.484912 -> V=1.0, theta=0.0
% INFO    : Bus 10450	: V=0.9809738, theta=-61.526328 -> V=1.0, theta=0.0
% INFO    : Bus 10451	: V=0.9799198, theta=-61.581722 -> V=1.0, theta=0.0
% INFO    : Bus 10452	: V=0.988208, theta=-60.905234 -> V=1.0, theta=0.0
% INFO    : Bus 10453	: V=0.9770762, theta=-62.008995 -> V=1.0, theta=0.0
% INFO    : Bus 10454	: V=0.9747792, theta=-61.905426 -> V=1.0, theta=0.0
% INFO    : Bus 10455	: V=0.9716705, theta=-62.076277 -> V=1.0, theta=0.0
% INFO    : Bus 10456	: V=0.9781438, theta=-61.770107 -> V=1.0, theta=0.0
% INFO    : Bus 10457	: V=0.9805977, theta=-62.002415 -> V=1.0, theta=0.0
% INFO    : Bus 10458	: V=0.9815879, theta=-61.773189 -> V=1.0, theta=0.0
% INFO    : Bus 10459	: V=0.9808039, theta=-61.863892 -> V=1.0, theta=0.0
% INFO    : Bus 10460	: V=0.9777874, theta=-62.032917 -> V=1.0, theta=0.0
% INFO    : Bus 10461	: V=0.9885189, theta=-61.185934 -> V=1.0, theta=0.0
% INFO    : Bus 10462	: V=0.9802768, theta=-61.87776 -> V=1.0, theta=0.0
% INFO    : Bus 10463	: V=0.9834086, theta=-61.599505 -> V=1.0, theta=0.0
% INFO    : Bus 10464	: V=0.9858536, theta=-61.371498 -> V=1.0, theta=0.0
% INFO    : Bus 10465	: V=0.9725424, theta=-62.273406 -> V=1.0, theta=0.0
% INFO    : Bus 10466	: V=0.9847481, theta=-60.966128 -> V=1.0, theta=0.0
% INFO    : Bus 10467	: V=0.9804313, theta=-61.298435 -> V=1.0, theta=0.0
% INFO    : Bus 10468	: V=0.9777152, theta=-61.497819 -> V=1.0, theta=0.0
% INFO    : Bus 10469	: V=0.9834914, theta=-61.049832 -> V=1.0, theta=0.0
% INFO    : Bus 10470	: V=0.9913884, theta=-60.285401 -> V=1.0, theta=0.0
% INFO    : Bus 10471	: V=0.9769223, theta=-61.674932 -> V=1.0, theta=0.0
% INFO    : Bus 10472	: V=0.9815867, theta=-61.079444 -> V=1.0, theta=0.0
% INFO    : Bus 10473	: V=0.9749944, theta=-61.697658 -> V=1.0, theta=0.0
% INFO    : Bus 10474	: V=0.9796366, theta=-61.734706 -> V=1.0, theta=0.0
% INFO    : Bus 10475	: V=0.9795754, theta=-61.849061 -> V=1.0, theta=0.0
% INFO    : Bus 10476	: V=0.9794764, theta=-61.848442 -> V=1.0, theta=0.0
% INFO    : Bus 10477	: V=0.9821988, theta=-61.666782 -> V=1.0, theta=0.0
% INFO    : Bus 10478	: V=0.9742645, theta=-62.248581 -> V=1.0, theta=0.0
% INFO    : Bus 10479	: V=0.9744308, theta=-62.240331 -> V=1.0, theta=0.0
% INFO    : Bus 10480	: V=0.9776481, theta=-61.962358 -> V=1.0, theta=0.0
% INFO    : Bus 10481	: V=0.9770825, theta=-61.986603 -> V=1.0, theta=0.0
% INFO    : Bus 10482	: V=0.9662064, theta=-62.755299 -> V=1.0, theta=0.0
% INFO    : Bus 10483	: V=0.9792482, theta=-61.775726 -> V=1.0, theta=0.0
% INFO    : Bus 10484	: V=0.9789959, theta=-61.801521 -> V=1.0, theta=0.0
% INFO    : Bus 10485	: V=0.9771067, theta=-61.971567 -> V=1.0, theta=0.0
% INFO    : Bus 10486	: V=0.978043, theta=-61.881025 -> V=1.0, theta=0.0
% INFO    : Bus 10487	: V=0.9813749, theta=-61.636302 -> V=1.0, theta=0.0
% INFO    : Bus 10488	: V=0.9801759, theta=-61.726941 -> V=1.0, theta=0.0
% INFO    : Bus 10489	: V=0.9795903, theta=-61.771065 -> V=1.0, theta=0.0
% INFO    : Bus 10490	: V=0.9808476, theta=-61.868507 -> V=1.0, theta=0.0
% INFO    : Bus 10491	: V=0.975969, theta=-62.114158 -> V=1.0, theta=0.0
% INFO    : Bus 10492	: V=0.9802848, theta=-61.762545 -> V=1.0, theta=0.0
% INFO    : Bus 10493	: V=0.9755275, theta=-61.63039 -> V=1.0, theta=0.0
% INFO    : Bus 10494	: V=0.9677242, theta=-67.833773 -> V=1.0, theta=0.0
% INFO    : Bus 10495	: V=0.9695934, theta=-67.229105 -> V=1.0, theta=0.0
% INFO    : Bus 10496	: V=0.9717299, theta=-66.58454 -> V=1.0, theta=0.0
% INFO    : Bus 10497	: V=0.9654599, theta=-67.60999 -> V=1.0, theta=0.0
% INFO    : Bus 10498	: V=0.9721864, theta=-66.531899 -> V=1.0, theta=0.0
% INFO    : Bus 10499	: V=0.9736151, theta=-66.118761 -> V=1.0, theta=0.0
% INFO    : Bus 10500	: V=0.9735753, theta=-66.188456 -> V=1.0, theta=0.0
% INFO    : Bus 10501	: V=0.9728087, theta=-66.284474 -> V=1.0, theta=0.0
% INFO    : Bus 10502	: V=0.9723562, theta=-66.406583 -> V=1.0, theta=0.0
% INFO    : Bus 10503	: V=0.9714071, theta=-66.675049 -> V=1.0, theta=0.0
% INFO    : Bus 10504	: V=0.9676114, theta=-67.455414 -> V=1.0, theta=0.0
% INFO    : Bus 10505	: V=0.9676675, theta=-66.591335 -> V=1.0, theta=0.0
% INFO    : Bus 10506	: V=0.9695695, theta=-66.150604 -> V=1.0, theta=0.0
% INFO    : Bus 10507	: V=0.9666767, theta=-67.015528 -> V=1.0, theta=0.0
% INFO    : Bus 10508	: V=0.969436, theta=-66.903127 -> V=1.0, theta=0.0
% INFO    : Bus 10509	: V=0.9679416, theta=-65.38244 -> V=1.0, theta=0.0
% INFO    : Bus 10510	: V=0.9724086, theta=-66.238053 -> V=1.0, theta=0.0
% INFO    : Bus 10511	: V=0.9663685, theta=-66.475389 -> V=1.0, theta=0.0
% INFO    : Bus 10512	: V=0.9692241, theta=-66.394385 -> V=1.0, theta=0.0
% INFO    : Bus 10513	: V=0.9711865, theta=-66.004972 -> V=1.0, theta=0.0
% INFO    : Bus 10514	: V=0.9705225, theta=-66.02317 -> V=1.0, theta=0.0
% INFO    : Bus 10515	: V=0.9726285, theta=-65.695338 -> V=1.0, theta=0.0
% INFO    : Bus 10516	: V=0.972151, theta=-64.501116 -> V=1.0, theta=0.0
% INFO    : Bus 10517	: V=0.9780031, theta=-63.635323 -> V=1.0, theta=0.0
% INFO    : Bus 10518	: V=0.9775632, theta=-63.601949 -> V=1.0, theta=0.0
% INFO    : Bus 10519	: V=0.976913, theta=-63.742167 -> V=1.0, theta=0.0
% INFO    : Bus 10520	: V=0.9750912, theta=-64.148982 -> V=1.0, theta=0.0
% INFO    : Bus 10521	: V=0.9692591, theta=-65.249625 -> V=1.0, theta=0.0
% INFO    : Bus 10522	: V=0.9737461, theta=-64.533945 -> V=1.0, theta=0.0
% INFO    : Bus 10523	: V=0.9739198, theta=-64.469943 -> V=1.0, theta=0.0
% INFO    : Bus 10524	: V=0.9660323, theta=-66.962263 -> V=1.0, theta=0.0
% INFO    : Bus 10525	: V=0.9736519, theta=-65.053778 -> V=1.0, theta=0.0
% INFO    : Bus 10526	: V=0.9808644, theta=-64.220083 -> V=1.0, theta=0.0
% INFO    : Bus 10527	: V=0.9889494, theta=-61.962408 -> V=1.0, theta=0.0
% INFO    : Bus 10528	: V=0.9868043, theta=-62.187794 -> V=1.0, theta=0.0
% INFO    : Bus 10529	: V=0.9829559, theta=-62.645541 -> V=1.0, theta=0.0
% INFO    : Bus 10530	: V=0.9812098, theta=-62.930248 -> V=1.0, theta=0.0
% INFO    : Bus 10531	: V=0.9922036, theta=-61.216639 -> V=1.0, theta=0.0
% INFO    : Bus 10532	: V=0.9828651, theta=-62.67876 -> V=1.0, theta=0.0
% INFO    : Bus 10533	: V=0.9907972, theta=-61.362085 -> V=1.0, theta=0.0
% INFO    : Bus 10534	: V=0.9838686, theta=-62.548283 -> V=1.0, theta=0.0
% INFO    : Bus 10535	: V=1.000751, theta=-60.80814 -> V=1.0, theta=0.0
% INFO    : Bus 10536	: V=0.9948048, theta=-61.297022 -> V=1.0, theta=0.0
% INFO    : Bus 10537	: V=0.9983601, theta=-60.921843 -> V=1.0, theta=0.0
% INFO    : Bus 10538	: V=1.0025924, theta=-60.537467 -> V=1.0, theta=0.0
% INFO    : Bus 10539	: V=0.9922587, theta=-61.202478 -> V=1.0, theta=0.0
% INFO    : Bus 10540	: V=0.9972492, theta=-60.929345 -> V=1.0, theta=0.0
% INFO    : Bus 10541	: V=0.9998712, theta=-60.765828 -> V=1.0, theta=0.0
% INFO    : Bus 10542	: V=1.0017647, theta=-60.655767 -> V=1.0, theta=0.0
% INFO    : Bus 10543	: V=1.0012022, theta=-60.738727 -> V=1.0, theta=0.0
% INFO    : Bus 10544	: V=0.9987244, theta=-60.860245 -> V=1.0, theta=0.0
% INFO    : Bus 10545	: V=0.9977419, theta=-60.945275 -> V=1.0, theta=0.0
% INFO    : Bus 10546	: V=0.9967145, theta=-61.010703 -> V=1.0, theta=0.0
% INFO    : Bus 10547	: V=0.9914504, theta=-61.390121 -> V=1.0, theta=0.0
% INFO    : Bus 10548	: V=0.9960752, theta=-61.057321 -> V=1.0, theta=0.0
% INFO    : Bus 10549	: V=0.9960408, theta=-61.051591 -> V=1.0, theta=0.0
% INFO    : Bus 10550	: V=0.9956206, theta=-61.09328 -> V=1.0, theta=0.0
% INFO    : Bus 10551	: V=0.9913655, theta=-61.400582 -> V=1.0, theta=0.0
% INFO    : Bus 10552	: V=0.991899, theta=-61.334255 -> V=1.0, theta=0.0
% INFO    : Bus 10553	: V=0.9916283, theta=-61.362788 -> V=1.0, theta=0.0
% INFO    : Bus 10554	: V=0.9974732, theta=-60.913381 -> V=1.0, theta=0.0
% INFO    : Bus 10555	: V=0.9920973, theta=-61.317215 -> V=1.0, theta=0.0
% INFO    : Bus 10556	: V=0.9953808, theta=-61.049432 -> V=1.0, theta=0.0
% INFO    : Bus 10557	: V=0.9929278, theta=-61.199756 -> V=1.0, theta=0.0
% INFO    : Bus 10558	: V=0.9943306, theta=-61.117664 -> V=1.0, theta=0.0
% INFO    : Bus 10559	: V=0.9860606, theta=-61.786678 -> V=1.0, theta=0.0
% INFO    : Bus 10560	: V=0.9925747, theta=-61.307678 -> V=1.0, theta=0.0
% INFO    : Bus 10561	: V=0.9928908, theta=-61.263721 -> V=1.0, theta=0.0
% INFO    : Bus 10562	: V=0.9949385, theta=-61.131868 -> V=1.0, theta=0.0
% INFO    : Bus 10563	: V=0.9894399, theta=-61.460211 -> V=1.0, theta=0.0
% INFO    : Bus 10564	: V=0.9890751, theta=-61.472398 -> V=1.0, theta=0.0
% INFO    : Bus 10565	: V=0.9885255, theta=-61.500651 -> V=1.0, theta=0.0
% INFO    : Bus 10566	: V=0.9808674, theta=-62.086498 -> V=1.0, theta=0.0
% INFO    : Bus 10567	: V=0.9811173, theta=-62.033333 -> V=1.0, theta=0.0
% INFO    : Bus 10568	: V=0.9886852, theta=-61.431487 -> V=1.0, theta=0.0
% INFO    : Bus 10569	: V=0.9892866, theta=-61.497453 -> V=1.0, theta=0.0
% INFO    : Bus 10570	: V=0.9914377, theta=-61.323681 -> V=1.0, theta=0.0
% INFO    : Bus 10571	: V=0.9921988, theta=-61.268312 -> V=1.0, theta=0.0
% INFO    : Bus 10572	: V=0.9849505, theta=-62.839142 -> V=1.0, theta=0.0
% INFO    : Bus 10573	: V=0.9937272, theta=-61.187306 -> V=1.0, theta=0.0
% INFO    : Bus 10574	: V=0.9883326, theta=-61.428401 -> V=1.0, theta=0.0
% INFO    : Bus 10575	: V=0.9884745, theta=-61.424553 -> V=1.0, theta=0.0
% INFO    : Bus 10576	: V=0.9872724, theta=-61.445611 -> V=1.0, theta=0.0
% INFO    : Bus 10577	: V=0.9877338, theta=-61.439588 -> V=1.0, theta=0.0
% INFO    : Bus 10578	: V=0.9957997, theta=-60.609361 -> V=1.0, theta=0.0
% INFO    : Bus 10579	: V=0.9945912, theta=-61.001131 -> V=1.0, theta=0.0
% INFO    : Bus 10580	: V=0.9960492, theta=-60.592865 -> V=1.0, theta=0.0
% INFO    : Bus 10581	: V=0.9964943, theta=-60.564328 -> V=1.0, theta=0.0
% INFO    : Bus 10582	: V=0.9956288, theta=-60.915768 -> V=1.0, theta=0.0
% INFO    : Bus 10583	: V=0.9937979, theta=-61.068228 -> V=1.0, theta=0.0
% INFO    : Bus 10584	: V=0.9962704, theta=-60.836214 -> V=1.0, theta=0.0
% INFO    : Bus 10585	: V=0.9967225, theta=-60.787743 -> V=1.0, theta=0.0
% INFO    : Bus 10586	: V=0.9968971, theta=-60.531326 -> V=1.0, theta=0.0
% INFO    : Bus 10587	: V=0.9977789, theta=-60.477277 -> V=1.0, theta=0.0
% INFO    : Bus 10588	: V=0.9984259, theta=-60.447448 -> V=1.0, theta=0.0
% INFO    : Bus 10589	: V=0.9982495, theta=-60.737299 -> V=1.0, theta=0.0
% INFO    : Bus 10590	: V=0.9985327, theta=-60.846997 -> V=1.0, theta=0.0
% INFO    : Bus 10591	: V=0.9964148, theta=-60.646255 -> V=1.0, theta=0.0
% INFO    : Bus 10592	: V=1.0118225, theta=-59.553081 -> V=1.0, theta=0.0
% INFO    : Bus 10593	: V=0.998047, theta=-60.425441 -> V=1.0, theta=0.0
% INFO    : Bus 10594	: V=0.9944382, theta=-60.564551 -> V=1.0, theta=0.0
% INFO    : Bus 10595	: V=0.9951441, theta=-60.532765 -> V=1.0, theta=0.0
% INFO    : Bus 10596	: V=0.9985359, theta=-60.300692 -> V=1.0, theta=0.0
% INFO    : Bus 10597	: V=0.9983011, theta=-60.351774 -> V=1.0, theta=0.0
% INFO    : Bus 10598	: V=0.99616, theta=-60.64503 -> V=1.0, theta=0.0
% INFO    : Bus 10599	: V=0.9890667, theta=-61.162529 -> V=1.0, theta=0.0
% INFO    : Bus 10600	: V=0.9891042, theta=-61.141702 -> V=1.0, theta=0.0
% INFO    : Bus 10601	: V=0.9878109, theta=-61.22724 -> V=1.0, theta=0.0
% INFO    : Bus 10602	: V=0.991406, theta=-60.691405 -> V=1.0, theta=0.0
% INFO    : Bus 10603	: V=0.9834227, theta=-61.643492 -> V=1.0, theta=0.0
% INFO    : Bus 10604	: V=0.9853745, theta=-61.502249 -> V=1.0, theta=0.0
% INFO    : Bus 10605	: V=0.9871506, theta=-61.368705 -> V=1.0, theta=0.0
% INFO    : Bus 10606	: V=0.9851596, theta=-61.454318 -> V=1.0, theta=0.0
% INFO    : Bus 10607	: V=0.9868795, theta=-61.291023 -> V=1.0, theta=0.0
% INFO    : Bus 10608	: V=0.9840888, theta=-61.597441 -> V=1.0, theta=0.0
% INFO    : Bus 10609	: V=0.9877829, theta=-61.431578 -> V=1.0, theta=0.0
% INFO    : Bus 10610	: V=0.987312, theta=-61.424306 -> V=1.0, theta=0.0
% INFO    : Bus 10611	: V=0.9851187, theta=-61.62318 -> V=1.0, theta=0.0
% INFO    : Bus 10612	: V=0.9849304, theta=-61.572292 -> V=1.0, theta=0.0
% INFO    : Bus 10613	: V=0.9853022, theta=-61.515905 -> V=1.0, theta=0.0
% INFO    : Bus 10614	: V=0.9795423, theta=-62.102973 -> V=1.0, theta=0.0
% INFO    : Bus 10615	: V=0.986284, theta=-61.537401 -> V=1.0, theta=0.0
% INFO    : Bus 10616	: V=0.9812151, theta=-61.951209 -> V=1.0, theta=0.0
% INFO    : Bus 10617	: V=0.9827299, theta=-61.911306 -> V=1.0, theta=0.0
% INFO    : Bus 10618	: V=0.9824883, theta=-61.877224 -> V=1.0, theta=0.0
% INFO    : Bus 10619	: V=0.9783687, theta=-62.181397 -> V=1.0, theta=0.0
% INFO    : Bus 10620	: V=0.9786644, theta=-62.175056 -> V=1.0, theta=0.0
% INFO    : Bus 10621	: V=0.9757051, theta=-62.264565 -> V=1.0, theta=0.0
% INFO    : Bus 10622	: V=0.9832275, theta=-61.738068 -> V=1.0, theta=0.0
% INFO    : Bus 10623	: V=0.9816368, theta=-61.83409 -> V=1.0, theta=0.0
% INFO    : Bus 10624	: V=0.9817744, theta=-61.773753 -> V=1.0, theta=0.0
% INFO    : Bus 10625	: V=0.9855325, theta=-61.541193 -> V=1.0, theta=0.0
% INFO    : Bus 10626	: V=0.983331, theta=-61.609373 -> V=1.0, theta=0.0
% INFO    : Bus 10627	: V=0.9853807, theta=-61.477904 -> V=1.0, theta=0.0
% INFO    : Bus 10628	: V=0.98974, theta=-60.912324 -> V=1.0, theta=0.0
% INFO    : Bus 10629	: V=0.9889597, theta=-61.033707 -> V=1.0, theta=0.0
% INFO    : Bus 10630	: V=0.9854959, theta=-61.443719 -> V=1.0, theta=0.0
% INFO    : Bus 10631	: V=0.9861184, theta=-61.368493 -> V=1.0, theta=0.0
% INFO    : Bus 10632	: V=0.9819111, theta=-61.486365 -> V=1.0, theta=0.0
% INFO    : Bus 10633	: V=0.9868207, theta=-61.291484 -> V=1.0, theta=0.0
% INFO    : Bus 10634	: V=0.9820489, theta=-61.65104 -> V=1.0, theta=0.0
% INFO    : Bus 10635	: V=0.9872512, theta=-61.25245 -> V=1.0, theta=0.0
% INFO    : Bus 10636	: V=0.9840391, theta=-61.356024 -> V=1.0, theta=0.0
% INFO    : Bus 10637	: V=0.9814446, theta=-61.483259 -> V=1.0, theta=0.0
% INFO    : Bus 10638	: V=0.9893937, theta=-60.777922 -> V=1.0, theta=0.0
% INFO    : Bus 10639	: V=0.9829355, theta=-61.404291 -> V=1.0, theta=0.0
% INFO    : Bus 10640	: V=0.9987065, theta=-60.192271 -> V=1.0, theta=0.0
% INFO    : Bus 10641	: V=0.9990999, theta=-61.065258 -> V=1.0, theta=0.0
% INFO    : Bus 10642	: V=0.9917726, theta=-61.348635 -> V=1.0, theta=0.0
% INFO    : Bus 10643	: V=1.0035111, theta=-60.521227 -> V=1.0, theta=0.0
% INFO    : Bus 10644	: V=1.0034901, theta=-60.546482 -> V=1.0, theta=0.0
% INFO    : Bus 10645	: V=0.9989135, theta=-61.099327 -> V=1.0, theta=0.0
% INFO    : Bus 10646	: V=0.9984604, theta=-61.194967 -> V=1.0, theta=0.0
% INFO    : Bus 10647	: V=0.9743921, theta=-64.659105 -> V=1.0, theta=0.0
% INFO    : Bus 10648	: V=0.9663621, theta=-65.56473 -> V=1.0, theta=0.0
% INFO    : Bus 10649	: V=1.0064355, theta=-59.864716 -> V=1.0, theta=0.0
% INFO    : Bus 10650	: V=0.9988363, theta=-60.756862 -> V=1.0, theta=0.0
% INFO    : Bus 10651	: V=0.9936789, theta=-61.453543 -> V=1.0, theta=0.0
% INFO    : Bus 10652	: V=1.0050966, theta=-59.848735 -> V=1.0, theta=0.0
% INFO    : Bus 10653	: V=1.0057606, theta=-59.746334 -> V=1.0, theta=0.0
% INFO    : Bus 10654	: V=1.0098628, theta=-59.265478 -> V=1.0, theta=0.0
% INFO    : Bus 10655	: V=1.0169105, theta=-58.437159 -> V=1.0, theta=0.0
% INFO    : Bus 10656	: V=1.0140908, theta=-58.775455 -> V=1.0, theta=0.0
% INFO    : Bus 10657	: V=1.0148409, theta=-58.829243 -> V=1.0, theta=0.0
% INFO    : Bus 10658	: V=1.015962, theta=-58.607433 -> V=1.0, theta=0.0
% INFO    : Bus 10659	: V=1.0087549, theta=-59.334177 -> V=1.0, theta=0.0
% INFO    : Bus 10660	: V=1.0148562, theta=-58.691743 -> V=1.0, theta=0.0
% INFO    : Bus 10661	: V=1.003513, theta=-60.124623 -> V=1.0, theta=0.0
% INFO    : Bus 10662	: V=1.0038838, theta=-60.303121 -> V=1.0, theta=0.0
% INFO    : Bus 10663	: V=1.0043521, theta=-60.364263 -> V=1.0, theta=0.0
% INFO    : Bus 10664	: V=1.003888, theta=-60.381052 -> V=1.0, theta=0.0
% INFO    : Bus 10665	: V=0.9985239, theta=-61.079208 -> V=1.0, theta=0.0
% INFO    : Bus 10666	: V=0.9931365, theta=-59.96238 -> V=1.0, theta=0.0
% INFO    : Bus 10667	: V=0.9834279, theta=-60.659081 -> V=1.0, theta=0.0
% INFO    : Bus 10668	: V=0.9964147, theta=-59.669645 -> V=1.0, theta=0.0
% INFO    : Bus 10669	: V=0.9995804, theta=-59.107736 -> V=1.0, theta=0.0
% INFO    : Bus 10670	: V=0.9993035, theta=-58.975034 -> V=1.0, theta=0.0
% INFO    : Bus 10671	: V=1.0020084, theta=-58.724404 -> V=1.0, theta=0.0
% INFO    : Bus 10672	: V=1.006261, theta=-58.116112 -> V=1.0, theta=0.0
% INFO    : Bus 10673	: V=0.9989264, theta=-58.951944 -> V=1.0, theta=0.0
% INFO    : Bus 10674	: V=0.9971879, theta=-59.642585 -> V=1.0, theta=0.0
% INFO    : Bus 10675	: V=0.9931717, theta=-59.565579 -> V=1.0, theta=0.0
% INFO    : Bus 10676	: V=0.9895568, theta=-59.8842 -> V=1.0, theta=0.0
% INFO    : Bus 10677	: V=0.9872978, theta=-59.981011 -> V=1.0, theta=0.0
% INFO    : Bus 10678	: V=0.986983, theta=-59.872779 -> V=1.0, theta=0.0
% INFO    : Bus 10679	: V=0.9889, theta=-59.07086 -> V=1.0, theta=0.0
% INFO    : Bus 10680	: V=0.986684, theta=-59.316178 -> V=1.0, theta=0.0
% INFO    : Bus 10681	: V=0.9765652, theta=-60.294596 -> V=1.0, theta=0.0
% INFO    : Bus 10682	: V=0.9869007, theta=-59.386374 -> V=1.0, theta=0.0
% INFO    : Bus 10683	: V=1.0009917, theta=-58.591121 -> V=1.0, theta=0.0
% INFO    : Bus 10684	: V=0.9875118, theta=-59.132303 -> V=1.0, theta=0.0
% INFO    : Bus 10685	: V=1.0012025, theta=-58.516343 -> V=1.0, theta=0.0
% INFO    : Bus 10686	: V=1.0013895, theta=-58.471506 -> V=1.0, theta=0.0
% INFO    : Bus 10687	: V=0.9862874, theta=-59.148792 -> V=1.0, theta=0.0
% INFO    : Bus 10688	: V=0.9876777, theta=-59.272482 -> V=1.0, theta=0.0
% INFO    : Bus 10689	: V=0.9882297, theta=-60.176174 -> V=1.0, theta=0.0
% INFO    : Bus 10690	: V=1.0014917, theta=-57.828919 -> V=1.0, theta=0.0
% INFO    : Bus 10691	: V=0.9755489, theta=-62.144128 -> V=1.0, theta=0.0
% INFO    : Bus 10692	: V=0.965636, theta=-63.761744 -> V=1.0, theta=0.0
% INFO    : Bus 10693	: V=0.9665186, theta=-63.683777 -> V=1.0, theta=0.0
% INFO    : Bus 10694	: V=0.9654122, theta=-63.813121 -> V=1.0, theta=0.0
% INFO    : Bus 10695	: V=0.9750298, theta=-62.229562 -> V=1.0, theta=0.0
% INFO    : Bus 10696	: V=0.9738297, theta=-62.336293 -> V=1.0, theta=0.0
% INFO    : Bus 10697	: V=0.974641, theta=-62.250459 -> V=1.0, theta=0.0
% INFO    : Bus 10698	: V=0.9662285, theta=-63.702595 -> V=1.0, theta=0.0
% INFO    : Bus 10699	: V=0.9661704, theta=-63.693266 -> V=1.0, theta=0.0
% INFO    : Bus 10700	: V=0.9662483, theta=-63.703572 -> V=1.0, theta=0.0
% INFO    : Bus 10701	: V=0.9744101, theta=-62.235153 -> V=1.0, theta=0.0
% INFO    : Bus 10702	: V=0.9658827, theta=-63.735191 -> V=1.0, theta=0.0
% INFO    : Bus 10703	: V=0.9769328, theta=-62.0314 -> V=1.0, theta=0.0
% INFO    : Bus 10704	: V=0.9673334, theta=-63.62231 -> V=1.0, theta=0.0
% INFO    : Bus 10705	: V=0.9636643, theta=-63.986603 -> V=1.0, theta=0.0
% INFO    : Bus 10706	: V=0.9623268, theta=-64.105514 -> V=1.0, theta=0.0
% INFO    : Bus 10707	: V=0.9621252, theta=-64.108316 -> V=1.0, theta=0.0
% INFO    : Bus 10708	: V=0.9601546, theta=-64.251804 -> V=1.0, theta=0.0
% INFO    : Bus 10709	: V=0.9737772, theta=-62.335147 -> V=1.0, theta=0.0
% INFO    : Bus 10710	: V=0.9672154, theta=-63.599116 -> V=1.0, theta=0.0
% INFO    : Bus 10711	: V=0.9656399, theta=-63.733728 -> V=1.0, theta=0.0
% INFO    : Bus 10712	: V=0.9677233, theta=-63.534544 -> V=1.0, theta=0.0
% INFO    : Bus 10713	: V=0.9680839, theta=-63.515936 -> V=1.0, theta=0.0
% INFO    : Bus 10714	: V=0.9679138, theta=-63.531917 -> V=1.0, theta=0.0
% INFO    : Bus 10715	: V=0.9774026, theta=-62.014033 -> V=1.0, theta=0.0
% INFO    : Bus 10716	: V=0.9676982, theta=-63.603382 -> V=1.0, theta=0.0
% INFO    : Bus 10717	: V=0.976727, theta=-62.054104 -> V=1.0, theta=0.0
% INFO    : Bus 10718	: V=0.9662934, theta=-63.628647 -> V=1.0, theta=0.0
% INFO    : Bus 10719	: V=0.9666134, theta=-63.634187 -> V=1.0, theta=0.0
% INFO    : Bus 10720	: V=0.9649532, theta=-63.687698 -> V=1.0, theta=0.0
% INFO    : Bus 10721	: V=0.9667574, theta=-63.589257 -> V=1.0, theta=0.0
% INFO    : Bus 10722	: V=0.9671803, theta=-63.566728 -> V=1.0, theta=0.0
% INFO    : Bus 10723	: V=0.9656146, theta=-63.651352 -> V=1.0, theta=0.0
% INFO    : Bus 10724	: V=0.9775065, theta=-62.10898 -> V=1.0, theta=0.0
% INFO    : Bus 10725	: V=0.9687447, theta=-63.44079 -> V=1.0, theta=0.0
% INFO    : Bus 10726	: V=0.9761585, theta=-62.18871 -> V=1.0, theta=0.0
% INFO    : Bus 10727	: V=0.9683359, theta=-63.496721 -> V=1.0, theta=0.0
% INFO    : Bus 10728	: V=0.975118, theta=-62.241345 -> V=1.0, theta=0.0
% INFO    : Bus 10729	: V=0.9768245, theta=-62.693416 -> V=1.0, theta=0.0
% INFO    : Bus 10730	: V=0.9591591, theta=-64.37067 -> V=1.0, theta=0.0
% INFO    : Bus 10731	: V=0.958355, theta=-64.430207 -> V=1.0, theta=0.0
% INFO    : Bus 10732	: V=0.9592498, theta=-64.369452 -> V=1.0, theta=0.0
% INFO    : Bus 10733	: V=0.9570502, theta=-64.458619 -> V=1.0, theta=0.0
% INFO    : Bus 10734	: V=0.9571957, theta=-64.456272 -> V=1.0, theta=0.0
% INFO    : Bus 10735	: V=0.9603309, theta=-64.509258 -> V=1.0, theta=0.0
% INFO    : Bus 10736	: V=0.9593224, theta=-64.665403 -> V=1.0, theta=0.0
% INFO    : Bus 10737	: V=0.9577276, theta=-64.796459 -> V=1.0, theta=0.0
% INFO    : Bus 10738	: V=0.9633198, theta=-63.905268 -> V=1.0, theta=0.0
% INFO    : Bus 10739	: V=0.9632427, theta=-63.992613 -> V=1.0, theta=0.0
% INFO    : Bus 10740	: V=0.9602229, theta=-64.21019 -> V=1.0, theta=0.0
% INFO    : Bus 10741	: V=0.9599115, theta=-64.247519 -> V=1.0, theta=0.0
% INFO    : Bus 10742	: V=0.9732721, theta=-62.424009 -> V=1.0, theta=0.0
% INFO    : Bus 10743	: V=0.9602334, theta=-64.509779 -> V=1.0, theta=0.0
% INFO    : Bus 10744	: V=0.9611195, theta=-64.336042 -> V=1.0, theta=0.0
% INFO    : Bus 10745	: V=0.9593163, theta=-64.578925 -> V=1.0, theta=0.0
% INFO    : Bus 10746	: V=0.961396, theta=-64.377889 -> V=1.0, theta=0.0
% INFO    : Bus 10747	: V=0.9628976, theta=-64.110531 -> V=1.0, theta=0.0
% INFO    : Bus 10748	: V=0.9693053, theta=-62.772703 -> V=1.0, theta=0.0
% INFO    : Bus 10749	: V=0.9713865, theta=-62.581839 -> V=1.0, theta=0.0
% INFO    : Bus 10750	: V=0.9701029, theta=-62.702374 -> V=1.0, theta=0.0
% INFO    : Bus 10751	: V=0.9650861, theta=-63.827917 -> V=1.0, theta=0.0
% INFO    : Bus 10752	: V=0.9659005, theta=-63.803044 -> V=1.0, theta=0.0
% INFO    : Bus 10753	: V=0.9779536, theta=-61.80801 -> V=1.0, theta=0.0
% INFO    : Bus 10754	: V=0.9635318, theta=-63.731134 -> V=1.0, theta=0.0
% INFO    : Bus 10755	: V=0.9630227, theta=-63.741723 -> V=1.0, theta=0.0
% INFO    : Bus 10756	: V=0.9737365, theta=-62.340816 -> V=1.0, theta=0.0
% INFO    : Bus 10757	: V=0.9803943, theta=-61.42452 -> V=1.0, theta=0.0
% INFO    : Bus 10758	: V=0.972687, theta=-62.435882 -> V=1.0, theta=0.0
% INFO    : Bus 10759	: V=0.9740606, theta=-62.335192 -> V=1.0, theta=0.0
% INFO    : Bus 10760	: V=0.9790075, theta=-61.525159 -> V=1.0, theta=0.0
% INFO    : Bus 10761	: V=0.9635622, theta=-63.550204 -> V=1.0, theta=0.0
% INFO    : Bus 10762	: V=0.9618301, theta=-63.666694 -> V=1.0, theta=0.0
% INFO    : Bus 10763	: V=0.9606338, theta=-63.662948 -> V=1.0, theta=0.0
% INFO    : Bus 10764	: V=0.9596777, theta=-63.687374 -> V=1.0, theta=0.0
% INFO    : Bus 10765	: V=0.9593395, theta=-63.767778 -> V=1.0, theta=0.0
% INFO    : Bus 10766	: V=0.9794898, theta=-61.36736 -> V=1.0, theta=0.0
% INFO    : Bus 10767	: V=0.9596623, theta=-63.729637 -> V=1.0, theta=0.0
% INFO    : Bus 10768	: V=0.9804451, theta=-61.413013 -> V=1.0, theta=0.0
% INFO    : Bus 10769	: V=0.9746016, theta=-62.379225 -> V=1.0, theta=0.0
% INFO    : Bus 10770	: V=0.976379, theta=-62.071248 -> V=1.0, theta=0.0
% INFO    : Bus 10771	: V=0.9767924, theta=-62.018406 -> V=1.0, theta=0.0
% INFO    : Bus 10772	: V=0.9745397, theta=-62.380113 -> V=1.0, theta=0.0
% INFO    : Bus 10773	: V=0.9769268, theta=-62.061676 -> V=1.0, theta=0.0
% INFO    : Bus 10774	: V=0.9766761, theta=-62.05493 -> V=1.0, theta=0.0
% INFO    : Bus 10775	: V=0.9787904, theta=-61.722473 -> V=1.0, theta=0.0
% INFO    : Bus 10776	: V=0.9768934, theta=-62.020931 -> V=1.0, theta=0.0
% INFO    : Bus 10777	: V=0.9767024, theta=-62.027014 -> V=1.0, theta=0.0
% INFO    : Bus 10778	: V=0.9783991, theta=-61.787644 -> V=1.0, theta=0.0
% INFO    : Bus 10779	: V=0.9785057, theta=-61.751197 -> V=1.0, theta=0.0
% INFO    : Bus 10780	: V=0.9791678, theta=-61.658324 -> V=1.0, theta=0.0
% INFO    : Bus 10781	: V=0.9774472, theta=-61.92201 -> V=1.0, theta=0.0
% INFO    : Bus 10782	: V=0.9801351, theta=-61.485508 -> V=1.0, theta=0.0
% INFO    : Bus 10783	: V=0.9799571, theta=-61.537135 -> V=1.0, theta=0.0
% INFO    : Bus 10784	: V=0.9770569, theta=-62.006951 -> V=1.0, theta=0.0
% INFO    : Bus 10785	: V=0.979469, theta=-61.616775 -> V=1.0, theta=0.0
% INFO    : Bus 10786	: V=0.9802219, theta=-61.512451 -> V=1.0, theta=0.0
% INFO    : Bus 10787	: V=0.9660014, theta=-63.165506 -> V=1.0, theta=0.0
% INFO    : Bus 10788	: V=0.9658014, theta=-63.169491 -> V=1.0, theta=0.0
% INFO    : Bus 10789	: V=0.9599921, theta=-63.694016 -> V=1.0, theta=0.0
% INFO    : Bus 10790	: V=0.960588, theta=-63.684394 -> V=1.0, theta=0.0
% INFO    : Bus 10791	: V=0.9626439, theta=-63.497578 -> V=1.0, theta=0.0
% INFO    : Bus 10792	: V=0.9609663, theta=-63.724072 -> V=1.0, theta=0.0
% INFO    : Bus 10793	: V=0.9761326, theta=-61.628655 -> V=1.0, theta=0.0
% INFO    : Bus 10794	: V=0.975242, theta=-61.707991 -> V=1.0, theta=0.0
% INFO    : Bus 10795	: V=0.9626705, theta=-63.51212 -> V=1.0, theta=0.0
% INFO    : Bus 10796	: V=0.9601267, theta=-63.687948 -> V=1.0, theta=0.0
% INFO    : Bus 10797	: V=0.9629044, theta=-63.510834 -> V=1.0, theta=0.0
% INFO    : Bus 10798	: V=0.9938078, theta=-61.067271 -> V=1.0, theta=0.0
% INFO    : Bus 10799	: V=0.9929149, theta=-61.214207 -> V=1.0, theta=0.0
% INFO    : Bus 10800	: V=0.9819336, theta=-62.703793 -> V=1.0, theta=0.0
% INFO    : Bus 10801	: V=0.9928068, theta=-61.244391 -> V=1.0, theta=0.0
% INFO    : Bus 10802	: V=0.9932092, theta=-61.233853 -> V=1.0, theta=0.0
% INFO    : Bus 10803	: V=0.9900541, theta=-61.891951 -> V=1.0, theta=0.0
% INFO    : Bus 10804	: V=0.9861533, theta=-61.980538 -> V=1.0, theta=0.0
% INFO    : Bus 10805	: V=0.9800164, theta=-62.734804 -> V=1.0, theta=0.0
% INFO    : Bus 10806	: V=0.9591824, theta=-64.828449 -> V=1.0, theta=0.0
% INFO    : Bus 10807	: V=0.964138, theta=-64.486018 -> V=1.0, theta=0.0
% INFO    : Bus 10808	: V=0.9799887, theta=-61.481707 -> V=1.0, theta=0.0
% INFO    : Bus 10809	: V=0.9672825, theta=-63.909582 -> V=1.0, theta=0.0
% INFO    : Bus 10810	: V=0.9840338, theta=-61.046203 -> V=1.0, theta=0.0
% INFO    : Bus 10811	: V=0.9846328, theta=-60.978252 -> V=1.0, theta=0.0
% INFO    : Bus 10812	: V=0.9850591, theta=-60.928432 -> V=1.0, theta=0.0
% INFO    : Bus 10813	: V=0.9831292, theta=-61.037466 -> V=1.0, theta=0.0
% INFO    : Bus 10814	: V=0.982316, theta=-61.075831 -> V=1.0, theta=0.0
% INFO    : Bus 10815	: V=0.9733788, theta=-62.239065 -> V=1.0, theta=0.0
% INFO    : Bus 10816	: V=0.9686153, theta=-63.05552 -> V=1.0, theta=0.0
% INFO    : Bus 10817	: V=0.96769, theta=-63.068676 -> V=1.0, theta=0.0
% INFO    : Bus 10818	: V=0.9792131, theta=-61.358199 -> V=1.0, theta=0.0
% INFO    : Bus 10819	: V=0.969579, theta=-63.101797 -> V=1.0, theta=0.0
% INFO    : Bus 10820	: V=0.9716596, theta=-62.405319 -> V=1.0, theta=0.0
% INFO    : Bus 10821	: V=0.9646354, theta=-64.238583 -> V=1.0, theta=0.0
% INFO    : Bus 10822	: V=0.9638442, theta=-64.143326 -> V=1.0, theta=0.0
% INFO    : Bus 10823	: V=0.9633214, theta=-64.349595 -> V=1.0, theta=0.0
% INFO    : Bus 10824	: V=0.9839418, theta=-61.90144 -> V=1.0, theta=0.0
% INFO    : Bus 10825	: V=0.9739975, theta=-62.954047 -> V=1.0, theta=0.0
% INFO    : Bus 10826	: V=0.9985682, theta=-60.739319 -> V=1.0, theta=0.0
% INFO    : Bus 10827	: V=0.9969004, theta=-60.943411 -> V=1.0, theta=0.0
% INFO    : Bus 10828	: V=1.0113486, theta=-58.551848 -> V=1.0, theta=0.0
% INFO    : Bus 10829	: V=0.9995789, theta=-60.580196 -> V=1.0, theta=0.0
% INFO    : Bus 10830	: V=0.9895165, theta=-61.514442 -> V=1.0, theta=0.0
% INFO    : Bus 10831	: V=0.9786854, theta=-62.551349 -> V=1.0, theta=0.0
% INFO    : Bus 10832	: V=0.996498, theta=-60.317555 -> V=1.0, theta=0.0
% INFO    : Bus 10833	: V=0.9785051, theta=-62.33662 -> V=1.0, theta=0.0
% INFO    : Bus 10834	: V=0.9780087, theta=-62.717987 -> V=1.0, theta=0.0
% INFO    : Bus 10835	: V=0.9802862, theta=-62.386236 -> V=1.0, theta=0.0
% INFO    : Bus 10836	: V=0.9920915, theta=-60.289484 -> V=1.0, theta=0.0
% INFO    : Bus 10837	: V=0.9651186, theta=-63.695655 -> V=1.0, theta=0.0
% INFO    : Bus 10838	: V=0.9694449, theta=-63.168928 -> V=1.0, theta=0.0
% INFO    : Bus 10839	: V=0.9758339, theta=-61.947574 -> V=1.0, theta=0.0
% INFO    : Bus 10840	: V=0.9758153, theta=-61.963919 -> V=1.0, theta=0.0
% INFO    : Bus 10841	: V=0.9702591, theta=-63.14204 -> V=1.0, theta=0.0
% INFO    : Bus 10842	: V=0.9772967, theta=-61.988542 -> V=1.0, theta=0.0
% INFO    : Bus 10843	: V=0.9764504, theta=-61.87831 -> V=1.0, theta=0.0
% INFO    : Bus 10844	: V=0.9693758, theta=-63.385236 -> V=1.0, theta=0.0
% INFO    : Bus 10845	: V=0.972819, theta=-62.959187 -> V=1.0, theta=0.0
% INFO    : Bus 10846	: V=0.9777649, theta=-61.886355 -> V=1.0, theta=0.0
% INFO    : Bus 10847	: V=0.9628177, theta=-64.177058 -> V=1.0, theta=0.0
% INFO    : Bus 10848	: V=0.970408, theta=-62.918722 -> V=1.0, theta=0.0
% INFO    : Bus 10849	: V=0.9772828, theta=-61.783942 -> V=1.0, theta=0.0
% INFO    : Bus 10850	: V=0.9659085, theta=-63.429859 -> V=1.0, theta=0.0
% INFO    : Bus 10851	: V=0.9791947, theta=-61.559355 -> V=1.0, theta=0.0
% INFO    : Bus 10852	: V=0.9791932, theta=-61.579895 -> V=1.0, theta=0.0
% INFO    : Bus 10853	: V=0.9806193, theta=-61.345925 -> V=1.0, theta=0.0
% INFO    : Bus 10854	: V=0.9673051, theta=-63.4589 -> V=1.0, theta=0.0
% INFO    : Bus 10855	: V=0.9711921, theta=-62.760951 -> V=1.0, theta=0.0
% INFO    : Bus 10856	: V=0.9798007, theta=-61.463243 -> V=1.0, theta=0.0
% INFO    : Bus 10857	: V=0.9803663, theta=-61.424814 -> V=1.0, theta=0.0
% INFO    : Bus 10858	: V=0.9813857, theta=-61.219878 -> V=1.0, theta=0.0
% INFO    : Bus 10859	: V=0.9805732, theta=-61.374763 -> V=1.0, theta=0.0
% INFO    : Bus 10860	: V=0.9822801, theta=-61.077947 -> V=1.0, theta=0.0
% INFO    : Bus 10861	: V=0.9799283, theta=-61.41232 -> V=1.0, theta=0.0
% INFO    : Bus 10862	: V=0.9833782, theta=-60.91131 -> V=1.0, theta=0.0
% INFO    : Bus 10863	: V=0.9839947, theta=-60.820968 -> V=1.0, theta=0.0
% INFO    : Bus 10864	: V=0.9819987, theta=-61.083917 -> V=1.0, theta=0.0
% INFO    : Bus 10865	: V=0.9811352, theta=-60.468533 -> V=1.0, theta=0.0
% INFO    : Bus 10866	: V=0.9892128, theta=-59.948066 -> V=1.0, theta=0.0
% INFO    : Bus 10867	: V=0.9908199, theta=-59.665617 -> V=1.0, theta=0.0
% INFO    : Bus 10868	: V=0.9938591, theta=-59.269681 -> V=1.0, theta=0.0
% INFO    : Bus 10869	: V=0.9926261, theta=-59.408177 -> V=1.0, theta=0.0
% INFO    : Bus 10870	: V=0.983067, theta=-61.144626 -> V=1.0, theta=0.0
% INFO    : Bus 10871	: V=0.9772257, theta=-61.938677 -> V=1.0, theta=0.0
% INFO    : Bus 10872	: V=0.9874291, theta=-60.252894 -> V=1.0, theta=0.0
% INFO    : Bus 10873	: V=0.9941504, theta=-59.065743 -> V=1.0, theta=0.0
% INFO    : Bus 10874	: V=0.9931661, theta=-59.199922 -> V=1.0, theta=0.0
% INFO    : Bus 10875	: V=0.9934861, theta=-59.24215 -> V=1.0, theta=0.0
% INFO    : Bus 10876	: V=0.9795055, theta=-61.301828 -> V=1.0, theta=0.0
% INFO    : Bus 10877	: V=0.9806907, theta=-60.885863 -> V=1.0, theta=0.0
% INFO    : Bus 10878	: V=0.9851042, theta=-59.932348 -> V=1.0, theta=0.0
% INFO    : Bus 10879	: V=0.9745998, theta=-61.425755 -> V=1.0, theta=0.0
% INFO    : Bus 10880	: V=0.9764314, theta=-61.29545 -> V=1.0, theta=0.0
% INFO    : Bus 10881	: V=0.962412, theta=-62.728619 -> V=1.0, theta=0.0
% INFO    : Bus 10882	: V=0.9615073, theta=-62.359987 -> V=1.0, theta=0.0
% INFO    : Bus 10883	: V=0.9628137, theta=-62.034067 -> V=1.0, theta=0.0
% INFO    : Bus 10884	: V=0.9627138, theta=-62.427601 -> V=1.0, theta=0.0
% INFO    : Bus 10885	: V=0.958287, theta=-63.079659 -> V=1.0, theta=0.0
% INFO    : Bus 10886	: V=0.9591544, theta=-63.056875 -> V=1.0, theta=0.0
% INFO    : Bus 10887	: V=0.9744763, theta=-61.310484 -> V=1.0, theta=0.0
% INFO    : Bus 10888	: V=0.9811713, theta=-60.900106 -> V=1.0, theta=0.0
% INFO    : Bus 10889	: V=0.9821325, theta=-61.059161 -> V=1.0, theta=0.0
% INFO    : Bus 10890	: V=0.9784421, theta=-61.314823 -> V=1.0, theta=0.0
% INFO    : Bus 10891	: V=0.962361, theta=-63.3015 -> V=1.0, theta=0.0
% INFO    : Bus 10892	: V=0.9816986, theta=-60.932929 -> V=1.0, theta=0.0
% INFO    : Bus 10893	: V=0.9807493, theta=-61.232399 -> V=1.0, theta=0.0
% INFO    : Bus 10894	: V=1.0152956, theta=-55.255135 -> V=1.0, theta=0.0
% INFO    : Bus 10895	: V=0.9815878, theta=-61.217084 -> V=1.0, theta=0.0
% INFO    : Bus 10896	: V=0.9813813, theta=-61.241894 -> V=1.0, theta=0.0
% INFO    : Bus 10897	: V=0.9813667, theta=-61.249586 -> V=1.0, theta=0.0
% INFO    : Bus 10898	: V=0.9782961, theta=-61.44696 -> V=1.0, theta=0.0
% INFO    : Bus 10899	: V=0.9815592, theta=-61.242859 -> V=1.0, theta=0.0
% INFO    : Bus 10900	: V=0.9776147, theta=-61.490326 -> V=1.0, theta=0.0
% INFO    : Bus 10901	: V=0.9631248, theta=-63.286267 -> V=1.0, theta=0.0
% INFO    : Bus 10902	: V=0.9589124, theta=-63.442828 -> V=1.0, theta=0.0
% INFO    : Bus 10903	: V=0.9585685, theta=-63.441419 -> V=1.0, theta=0.0
% INFO    : Bus 10904	: V=0.9590231, theta=-63.585932 -> V=1.0, theta=0.0
% INFO    : Bus 10905	: V=0.975221, theta=-61.779438 -> V=1.0, theta=0.0
% INFO    : Bus 10906	: V=0.9573798, theta=-63.475081 -> V=1.0, theta=0.0
% INFO    : Bus 10907	: V=0.9582898, theta=-63.349218 -> V=1.0, theta=0.0
% INFO    : Bus 10908	: V=0.9569045, theta=-63.752404 -> V=1.0, theta=0.0
% INFO    : Bus 10909	: V=0.9559826, theta=-63.774925 -> V=1.0, theta=0.0
% INFO    : Bus 10910	: V=0.9576603, theta=-63.57033 -> V=1.0, theta=0.0
% INFO    : Bus 10911	: V=0.9562375, theta=-63.667384 -> V=1.0, theta=0.0
% INFO    : Bus 10912	: V=0.9585298, theta=-63.810151 -> V=1.0, theta=0.0
% INFO    : Bus 10913	: V=0.9580165, theta=-63.821828 -> V=1.0, theta=0.0
% INFO    : Bus 10914	: V=0.9574196, theta=-63.832838 -> V=1.0, theta=0.0
% INFO    : Bus 10915	: V=0.9568017, theta=-63.846152 -> V=1.0, theta=0.0
% INFO    : Bus 10916	: V=0.9563127, theta=-63.811791 -> V=1.0, theta=0.0
% INFO    : Bus 10917	: V=0.9559811, theta=-63.843068 -> V=1.0, theta=0.0
% INFO    : Bus 10918	: V=0.9710636, theta=-62.080981 -> V=1.0, theta=0.0
% INFO    : Bus 10919	: V=0.956617, theta=-63.860944 -> V=1.0, theta=0.0
% INFO    : Bus 10920	: V=0.960081, theta=-63.396793 -> V=1.0, theta=0.0
% INFO    : Bus 10921	: V=0.9585324, theta=-63.432315 -> V=1.0, theta=0.0
% INFO    : Bus 10922	: V=0.9564966, theta=-63.572794 -> V=1.0, theta=0.0
% INFO    : Bus 10923	: V=0.9574955, theta=-63.473197 -> V=1.0, theta=0.0
% INFO    : Bus 10924	: V=0.9590832, theta=-63.340394 -> V=1.0, theta=0.0
% INFO    : Bus 10925	: V=0.9611929, theta=-63.318458 -> V=1.0, theta=0.0
% INFO    : Bus 10926	: V=0.96131, theta=-62.798491 -> V=1.0, theta=0.0
% INFO    : Bus 10927	: V=0.9760877, theta=-60.615664 -> V=1.0, theta=0.0
% INFO    : Bus 10928	: V=0.9778474, theta=-60.49104 -> V=1.0, theta=0.0
% INFO    : Bus 10929	: V=0.9732821, theta=-61.892561 -> V=1.0, theta=0.0
% INFO    : Bus 10930	: V=0.9737622, theta=-61.861236 -> V=1.0, theta=0.0
% INFO    : Bus 10931	: V=0.974006, theta=-61.789595 -> V=1.0, theta=0.0
% INFO    : Bus 10932	: V=0.9751701, theta=-61.7113 -> V=1.0, theta=0.0
% INFO    : Bus 10933	: V=0.9680759, theta=-62.152554 -> V=1.0, theta=0.0
% INFO    : Bus 10934	: V=0.969129, theta=-62.133019 -> V=1.0, theta=0.0
% INFO    : Bus 10935	: V=0.9694132, theta=-62.840646 -> V=1.0, theta=0.0
% INFO    : Bus 10936	: V=0.9777621, theta=-61.429534 -> V=1.0, theta=0.0
% INFO    : Bus 10937	: V=0.9718401, theta=-62.030917 -> V=1.0, theta=0.0
% INFO    : Bus 10938	: V=0.9714272, theta=-62.065982 -> V=1.0, theta=0.0
% INFO    : Bus 10939	: V=0.9655639, theta=-63.191075 -> V=1.0, theta=0.0
% INFO    : Bus 10940	: V=0.9650076, theta=-63.232131 -> V=1.0, theta=0.0
% INFO    : Bus 10941	: V=0.9659892, theta=-63.15309 -> V=1.0, theta=0.0
% INFO    : Bus 10942	: V=0.9658334, theta=-63.194324 -> V=1.0, theta=0.0
% INFO    : Bus 10943	: V=0.9666766, theta=-63.088746 -> V=1.0, theta=0.0
% INFO    : Bus 10944	: V=0.9634867, theta=-63.498823 -> V=1.0, theta=0.0
% INFO    : Bus 10945	: V=0.981451, theta=-60.453149 -> V=1.0, theta=0.0
% INFO    : Bus 10946	: V=0.9671214, theta=-63.067238 -> V=1.0, theta=0.0
% INFO    : Bus 10947	: V=0.9650327, theta=-63.168213 -> V=1.0, theta=0.0
% INFO    : Bus 10948	: V=0.9595526, theta=-63.704628 -> V=1.0, theta=0.0
% INFO    : Bus 10949	: V=0.9649655, theta=-63.119069 -> V=1.0, theta=0.0
% INFO    : Bus 10950	: V=0.9605025, theta=-63.732376 -> V=1.0, theta=0.0
% INFO    : Bus 10951	: V=0.9648956, theta=-63.989214 -> V=1.0, theta=0.0
% INFO    : Bus 10952	: V=0.9629432, theta=-64.239029 -> V=1.0, theta=0.0
% INFO    : Bus 10953	: V=0.9627737, theta=-64.307096 -> V=1.0, theta=0.0
% INFO    : Bus 10954	: V=0.974982, theta=-61.794255 -> V=1.0, theta=0.0
% INFO    : Bus 10955	: V=0.9652314, theta=-64.034203 -> V=1.0, theta=0.0
% INFO    : Bus 10956	: V=0.9624858, theta=-64.389463 -> V=1.0, theta=0.0
% INFO    : Bus 10957	: V=0.9647686, theta=-64.243496 -> V=1.0, theta=0.0
% INFO    : Bus 10958	: V=0.9618437, theta=-64.309236 -> V=1.0, theta=0.0
% INFO    : Bus 10959	: V=0.9633308, theta=-64.17174 -> V=1.0, theta=0.0
% INFO    : Bus 10960	: V=0.9657919, theta=-63.864361 -> V=1.0, theta=0.0
% INFO    : Bus 10961	: V=0.9668066, theta=-63.995026 -> V=1.0, theta=0.0
% INFO    : Bus 10962	: V=0.9666019, theta=-64.129058 -> V=1.0, theta=0.0
% INFO    : Bus 10963	: V=0.9658076, theta=-63.915525 -> V=1.0, theta=0.0
% INFO    : Bus 10964	: V=0.9611198, theta=-64.192225 -> V=1.0, theta=0.0
% INFO    : Bus 10965	: V=0.9885032, theta=-59.756574 -> V=1.0, theta=0.0
% INFO    : Bus 10966	: V=0.9690424, theta=-63.247553 -> V=1.0, theta=0.0
% INFO    : Bus 10967	: V=0.9807131, theta=-60.941875 -> V=1.0, theta=0.0
% INFO    : Bus 10968	: V=0.9681904, theta=-63.034744 -> V=1.0, theta=0.0
% INFO    : Bus 10969	: V=0.9739463, theta=-62.007388 -> V=1.0, theta=0.0
% INFO    : Bus 10970	: V=0.9722669, theta=-62.058524 -> V=1.0, theta=0.0
% INFO    : Bus 10971	: V=0.9878831, theta=-60.505813 -> V=1.0, theta=0.0
% INFO    : Bus 10972	: V=0.985303, theta=-60.428765 -> V=1.0, theta=0.0
% INFO    : Bus 10973	: V=0.9761141, theta=-61.663055 -> V=1.0, theta=0.0
% INFO    : Bus 10974	: V=0.9864725, theta=-60.465525 -> V=1.0, theta=0.0
% INFO    : Bus 10975	: V=0.9877817, theta=-60.309499 -> V=1.0, theta=0.0
% INFO    : Bus 10976	: V=0.989053, theta=-60.150033 -> V=1.0, theta=0.0
% INFO    : Bus 10977	: V=0.9914379, theta=-59.844541 -> V=1.0, theta=0.0
% INFO    : Bus 10978	: V=1.0089569, theta=-56.975162 -> V=1.0, theta=0.0
% INFO    : Bus 10979	: V=0.9751925, theta=-61.30705 -> V=1.0, theta=0.0
% INFO    : Bus 10980	: V=0.9793359, theta=-60.75168 -> V=1.0, theta=0.0
% INFO    : Bus 10981	: V=0.9716905, theta=-61.755581 -> V=1.0, theta=0.0
% INFO    : Bus 10982	: V=0.9765226, theta=-61.645578 -> V=1.0, theta=0.0
% INFO    : Bus 10983	: V=0.9708677, theta=-63.239431 -> V=1.0, theta=0.0
% INFO    : Bus 10984	: V=0.9696699, theta=-63.2102 -> V=1.0, theta=0.0
% INFO    : Bus 10985	: V=0.9843952, theta=-60.646401 -> V=1.0, theta=0.0
% INFO    : Bus 10986	: V=0.9669319, theta=-63.683623 -> V=1.0, theta=0.0
% INFO    : Bus 10987	: V=0.9698427, theta=-63.256464 -> V=1.0, theta=0.0
% INFO    : Bus 10988	: V=0.9621077, theta=-63.816777 -> V=1.0, theta=0.0
% INFO    : Bus 10989	: V=0.9603927, theta=-64.53285 -> V=1.0, theta=0.0
% INFO    : Bus 10990	: V=0.9595983, theta=-64.657045 -> V=1.0, theta=0.0
% INFO    : Bus 10991	: V=0.9599625, theta=-64.626775 -> V=1.0, theta=0.0
% INFO    : Bus 10992	: V=0.9617319, theta=-64.615008 -> V=1.0, theta=0.0
% INFO    : Bus 10993	: V=0.9648554, theta=-64.412237 -> V=1.0, theta=0.0
% INFO    : Bus 10994	: V=0.9637506, theta=-64.489319 -> V=1.0, theta=0.0
% INFO    : Bus 10995	: V=0.9659252, theta=-64.277368 -> V=1.0, theta=0.0
% INFO    : Bus 10996	: V=0.9617369, theta=-64.53471 -> V=1.0, theta=0.0
% INFO    : Bus 10997	: V=0.9622493, theta=-64.50426 -> V=1.0, theta=0.0
% INFO    : Bus 10998	: V=0.9589328, theta=-64.688599 -> V=1.0, theta=0.0
% INFO    : Bus 10999	: V=0.9597443, theta=-64.656862 -> V=1.0, theta=0.0
% INFO    : Bus 11000	: V=0.9588759, theta=-64.706595 -> V=1.0, theta=0.0
% INFO    : Bus 11001	: V=0.9606434, theta=-64.512427 -> V=1.0, theta=0.0
% INFO    : Bus 11002	: V=0.9588954, theta=-64.593138 -> V=1.0, theta=0.0
% INFO    : Bus 11003	: V=0.9589708, theta=-64.593586 -> V=1.0, theta=0.0
% INFO    : Bus 11004	: V=0.9582757, theta=-64.74888 -> V=1.0, theta=0.0
% INFO    : Bus 11005	: V=0.9612308, theta=-64.564017 -> V=1.0, theta=0.0
% INFO    : Bus 11006	: V=0.9621963, theta=-64.509788 -> V=1.0, theta=0.0
% INFO    : Bus 11007	: V=0.9640963, theta=-64.396111 -> V=1.0, theta=0.0
% INFO    : Bus 11008	: V=0.9777432, theta=-62.627234 -> V=1.0, theta=0.0
% INFO    : Bus 11009	: V=0.961494, theta=-64.616885 -> V=1.0, theta=0.0
% INFO    : Bus 11010	: V=0.9698146, theta=-63.879651 -> V=1.0, theta=0.0
% INFO    : Bus 11011	: V=0.9651064, theta=-64.380509 -> V=1.0, theta=0.0
% INFO    : Bus 11012	: V=0.9758138, theta=-62.806744 -> V=1.0, theta=0.0
% INFO    : Bus 11013	: V=0.9770503, theta=-62.725785 -> V=1.0, theta=0.0
% INFO    : Bus 11014	: V=0.9666586, theta=-64.014261 -> V=1.0, theta=0.0
% INFO    : Bus 11015	: V=0.9651101, theta=-64.117589 -> V=1.0, theta=0.0
% INFO    : Bus 11016	: V=0.9770274, theta=-62.780877 -> V=1.0, theta=0.0
% INFO    : Bus 11017	: V=0.965146, theta=-64.296489 -> V=1.0, theta=0.0
% INFO    : Bus 11018	: V=0.9780321, theta=-62.600866 -> V=1.0, theta=0.0
% INFO    : Bus 11019	: V=0.9588505, theta=-64.803423 -> V=1.0, theta=0.0
% INFO    : Bus 11020	: V=0.9837676, theta=-62.00949 -> V=1.0, theta=0.0
% INFO    : Bus 11021	: V=0.9683203, theta=-64.124274 -> V=1.0, theta=0.0
% INFO    : Bus 11022	: V=0.9821938, theta=-62.338102 -> V=1.0, theta=0.0
% INFO    : Bus 11023	: V=0.9723532, theta=-63.742376 -> V=1.0, theta=0.0
% INFO    : Bus 11024	: V=0.9797464, theta=-62.498689 -> V=1.0, theta=0.0
% INFO    : Bus 11025	: V=0.9766294, theta=-63.067242 -> V=1.0, theta=0.0
% INFO    : Bus 11026	: V=0.9853444, theta=-62.126275 -> V=1.0, theta=0.0
% INFO    : Bus 11027	: V=0.9770562, theta=-62.569404 -> V=1.0, theta=0.0
% INFO    : Bus 11028	: V=0.9784566, theta=-63.029712 -> V=1.0, theta=0.0
% INFO    : Bus 11029	: V=0.9805316, theta=-62.878491 -> V=1.0, theta=0.0
% INFO    : Bus 11030	: V=0.9872722, theta=-61.776006 -> V=1.0, theta=0.0
% INFO    : Bus 11031	: V=0.9876566, theta=-61.723536 -> V=1.0, theta=0.0
% INFO    : Bus 11032	: V=0.9923756, theta=-61.597659 -> V=1.0, theta=0.0
% INFO    : Bus 11033	: V=0.9753766, theta=-63.711973 -> V=1.0, theta=0.0
% INFO    : Bus 11034	: V=0.9867897, theta=-62.072677 -> V=1.0, theta=0.0
% INFO    : Bus 11035	: V=0.9723937, theta=-63.837673 -> V=1.0, theta=0.0
% INFO    : Bus 11036	: V=0.9827234, theta=-62.383029 -> V=1.0, theta=0.0
% INFO    : Bus 11037	: V=0.9793363, theta=-62.629448 -> V=1.0, theta=0.0
% INFO    : Bus 11038	: V=0.9638137, theta=-63.978318 -> V=1.0, theta=0.0
% INFO    : Bus 11039	: V=0.9635927, theta=-63.819731 -> V=1.0, theta=0.0
% INFO    : Bus 11040	: V=0.9645453, theta=-63.651788 -> V=1.0, theta=0.0
% INFO    : Bus 11041	: V=0.9630841, theta=-64.118147 -> V=1.0, theta=0.0
% INFO    : Bus 11042	: V=0.9647507, theta=-63.805268 -> V=1.0, theta=0.0
% INFO    : Bus 11043	: V=0.9651498, theta=-63.843724 -> V=1.0, theta=0.0
% INFO    : Bus 11044	: V=0.9659109, theta=-63.811037 -> V=1.0, theta=0.0
% INFO    : Bus 11045	: V=0.9642097, theta=-63.89861 -> V=1.0, theta=0.0
% INFO    : Bus 11046	: V=0.9813934, theta=-60.973664 -> V=1.0, theta=0.0
% INFO    : Bus 11047	: V=0.9589103, theta=-64.672728 -> V=1.0, theta=0.0
% INFO    : Bus 11048	: V=0.958764, theta=-64.656655 -> V=1.0, theta=0.0
% INFO    : Bus 11049	: V=0.9583186, theta=-64.728614 -> V=1.0, theta=0.0
% INFO    : Bus 11050	: V=0.9579452, theta=-64.77105 -> V=1.0, theta=0.0
% INFO    : Bus 11051	: V=0.9581348, theta=-64.760798 -> V=1.0, theta=0.0
% INFO    : Bus 11052	: V=0.9585508, theta=-64.728029 -> V=1.0, theta=0.0
% INFO    : Bus 11053	: V=0.9575933, theta=-64.813495 -> V=1.0, theta=0.0
% INFO    : Bus 11054	: V=0.9573291, theta=-64.781368 -> V=1.0, theta=0.0
% INFO    : Bus 11055	: V=0.9646593, theta=-63.836982 -> V=1.0, theta=0.0
% INFO    : Bus 11056	: V=0.9602055, theta=-63.739795 -> V=1.0, theta=0.0
% INFO    : Bus 11057	: V=0.9770553, theta=-62.68981 -> V=1.0, theta=0.0
% INFO    : Bus 11058	: V=0.965877, theta=-63.722709 -> V=1.0, theta=0.0
% INFO    : Bus 11059	: V=0.9639764, theta=-64.101324 -> V=1.0, theta=0.0
% INFO    : Bus 11060	: V=0.9617577, theta=-63.689414 -> V=1.0, theta=0.0
% INFO    : Bus 11061	: V=0.9803791, theta=-61.320386 -> V=1.0, theta=0.0
% INFO    : Bus 11062	: V=0.9783552, theta=-61.565549 -> V=1.0, theta=0.0
% INFO    : Bus 11063	: V=0.9806953, theta=-61.393502 -> V=1.0, theta=0.0
% INFO    : Bus 11064	: V=0.961768, theta=-63.384819 -> V=1.0, theta=0.0
% INFO    : Bus 11065	: V=0.9644524, theta=-64.001312 -> V=1.0, theta=0.0
% INFO    : Bus 11066	: V=0.9798954, theta=-61.325272 -> V=1.0, theta=0.0
% INFO    : Bus 11067	: V=0.9769187, theta=-61.659427 -> V=1.0, theta=0.0
% INFO    : Bus 11068	: V=0.981143, theta=-61.358719 -> V=1.0, theta=0.0
% INFO    : Bus 11069	: V=0.9837053, theta=-60.644297 -> V=1.0, theta=0.0
% INFO    : Bus 11070	: V=0.9814713, theta=-60.901622 -> V=1.0, theta=0.0
% INFO    : Bus 11071	: V=0.9603911, theta=-64.642952 -> V=1.0, theta=0.0
% INFO    : Bus 11072	: V=0.9620127, theta=-62.427085 -> V=1.0, theta=0.0
% INFO    : Bus 11073	: V=0.9625102, theta=-63.299001 -> V=1.0, theta=0.0
% INFO    : Bus 11074	: V=0.9591382, theta=-63.882035 -> V=1.0, theta=0.0
% INFO    : Bus 11075	: V=0.9595343, theta=-64.665964 -> V=1.0, theta=0.0
% INFO    : Bus 11076	: V=1.007211, theta=-57.382323 -> V=1.0, theta=0.0
% INFO    : Bus 11077	: V=0.9799301, theta=-62.496944 -> V=1.0, theta=0.0
% INFO    : Bus 11078	: V=0.9649495, theta=-63.687843 -> V=1.0, theta=0.0
% INFO    : Bus 11079	: V=0.960065, theta=-64.481188 -> V=1.0, theta=0.0
% INFO    : Bus 11080	: V=0.9771416, theta=-62.010184 -> V=1.0, theta=0.0
% INFO    : Bus 11081	: V=0.9726799, theta=-62.455806 -> V=1.0, theta=0.0
% INFO    : Bus 11082	: V=0.9763369, theta=-62.08356 -> V=1.0, theta=0.0
% INFO    : Bus 11083	: V=0.9748084, theta=-62.319227 -> V=1.0, theta=0.0
% INFO    : Bus 11084	: V=0.9753948, theta=-62.160708 -> V=1.0, theta=0.0
% INFO    : Bus 11085	: V=0.9818458, theta=-61.251522 -> V=1.0, theta=0.0
% INFO    : Bus 11086	: V=0.9669537, theta=-63.622911 -> V=1.0, theta=0.0
% INFO    : Bus 11087	: V=0.9601334, theta=-64.512589 -> V=1.0, theta=0.0
% INFO    : Bus 11088	: V=0.9785139, theta=-62.590905 -> V=1.0, theta=0.0
% INFO    : Bus 11089	: V=0.9661765, theta=-63.757448 -> V=1.0, theta=0.0
% INFO    : Bus 11090	: V=1.0096805, theta=-64.960017 -> V=1.0, theta=0.0
% INFO    : Bus 11091	: V=1.0168274, theta=-64.582042 -> V=1.0, theta=0.0
% INFO    : Bus 11092	: V=0.9874459, theta=-66.671715 -> V=1.0, theta=0.0
% INFO    : Bus 11093	: V=0.9954681, theta=-64.116687 -> V=1.0, theta=0.0
% INFO    : Bus 11094	: V=1.0071038, theta=-63.621342 -> V=1.0, theta=0.0
% INFO    : Bus 11095	: V=1.013916, theta=-63.673607 -> V=1.0, theta=0.0
% INFO    : Bus 11096	: V=0.9978055, theta=-58.944316 -> V=1.0, theta=0.0
% INFO    : Bus 11097	: V=1.007335, theta=-59.040434 -> V=1.0, theta=0.0
% INFO    : Bus 11098	: V=1.0035099, theta=-61.50418 -> V=1.0, theta=0.0
% INFO    : Bus 11099	: V=1.0077701, theta=-60.240369 -> V=1.0, theta=0.0
% INFO    : Bus 11100	: V=1.0086029, theta=-63.059202 -> V=1.0, theta=0.0
% INFO    : Bus 11101	: V=0.9962455, theta=-62.291571 -> V=1.0, theta=0.0
% INFO    : Bus 11102	: V=0.9993586, theta=-60.199234 -> V=1.0, theta=0.0
% INFO    : Bus 11103	: V=0.9989402, theta=-60.231862 -> V=1.0, theta=0.0
% INFO    : Bus 11104	: V=1.0023702, theta=-60.095791 -> V=1.0, theta=0.0
% INFO    : Bus 11105	: V=1.0151494, theta=-58.102236 -> V=1.0, theta=0.0
% INFO    : Bus 11106	: V=1.0183269, theta=-57.475309 -> V=1.0, theta=0.0
% INFO    : Bus 11107	: V=1.0018988, theta=-59.917248 -> V=1.0, theta=0.0
% INFO    : Bus 11108	: V=0.9953341, theta=-60.858343 -> V=1.0, theta=0.0
% INFO    : Bus 11109	: V=0.9847475, theta=-59.703996 -> V=1.0, theta=0.0
% INFO    : Bus 11110	: V=0.9909306, theta=-58.958707 -> V=1.0, theta=0.0
% INFO    : Bus 11111	: V=0.9885266, theta=-60.151405 -> V=1.0, theta=0.0
% INFO    : Bus 11112	: V=0.9895482, theta=-60.114594 -> V=1.0, theta=0.0
% INFO    : Bus 11113	: V=0.9853713, theta=-60.669645 -> V=1.0, theta=0.0
% INFO    : Bus 11114	: V=0.9882312, theta=-60.273675 -> V=1.0, theta=0.0
% INFO    : Bus 11115	: V=0.9811107, theta=-61.549843 -> V=1.0, theta=0.0
% INFO    : Bus 11116	: V=0.9820579, theta=-61.118422 -> V=1.0, theta=0.0
% INFO    : Bus 11117	: V=0.9903251, theta=-60.056473 -> V=1.0, theta=0.0
% INFO    : Bus 11118	: V=0.9810646, theta=-61.138833 -> V=1.0, theta=0.0
% INFO    : Bus 11119	: V=0.9864558, theta=-60.607903 -> V=1.0, theta=0.0
% INFO    : Bus 11120	: V=0.9921493, theta=-59.945381 -> V=1.0, theta=0.0
% INFO    : Bus 11121	: V=0.9934139, theta=-59.781952 -> V=1.0, theta=0.0
% INFO    : Bus 11122	: V=0.9941543, theta=-59.687339 -> V=1.0, theta=0.0
% INFO    : Bus 11123	: V=0.9955206, theta=-59.517023 -> V=1.0, theta=0.0
% INFO    : Bus 11124	: V=0.9955058, theta=-59.233414 -> V=1.0, theta=0.0
% INFO    : Bus 11125	: V=0.9938957, theta=-59.600067 -> V=1.0, theta=0.0
% INFO    : Bus 11126	: V=1.006132, theta=-56.867573 -> V=1.0, theta=0.0
% INFO    : Bus 11127	: V=0.9984378, theta=-58.102959 -> V=1.0, theta=0.0
% INFO    : Bus 11128	: V=1.0040869, theta=-57.511064 -> V=1.0, theta=0.0
% INFO    : Bus 11129	: V=1.0016078, theta=-57.638126 -> V=1.0, theta=0.0
% INFO    : Bus 11130	: V=1.0043227, theta=-57.27627 -> V=1.0, theta=0.0
% INFO    : Bus 11131	: V=1.0003495, theta=-58.066573 -> V=1.0, theta=0.0
% INFO    : Bus 11132	: V=0.9919815, theta=-59.905128 -> V=1.0, theta=0.0
% INFO    : Bus 11133	: V=1.0005583, theta=-58.364631 -> V=1.0, theta=0.0
% INFO    : Bus 11134	: V=0.9913811, theta=-59.981099 -> V=1.0, theta=0.0
% INFO    : Bus 11135	: V=0.9904408, theta=-60.019653 -> V=1.0, theta=0.0
% INFO    : Bus 11136	: V=0.9932236, theta=-59.435622 -> V=1.0, theta=0.0
% INFO    : Bus 11137	: V=0.990929, theta=-59.768574 -> V=1.0, theta=0.0
% INFO    : Bus 11138	: V=0.9876339, theta=-60.307635 -> V=1.0, theta=0.0
% INFO    : Bus 11139	: V=0.9833363, theta=-60.423575 -> V=1.0, theta=0.0
% INFO    : Bus 11140	: V=0.9948657, theta=-59.125139 -> V=1.0, theta=0.0
% INFO    : Bus 11141	: V=0.9819121, theta=-61.081941 -> V=1.0, theta=0.0
% INFO    : Bus 11142	: V=0.9940661, theta=-59.226922 -> V=1.0, theta=0.0
% INFO    : Bus 11143	: V=0.9823499, theta=-61.07455 -> V=1.0, theta=0.0
% INFO    : Bus 11144	: V=0.996636, theta=-58.90453 -> V=1.0, theta=0.0
% INFO    : Bus 11145	: V=0.9988063, theta=-58.378299 -> V=1.0, theta=0.0
% INFO    : Bus 11146	: V=0.9966767, theta=-58.799693 -> V=1.0, theta=0.0
% INFO    : Bus 11147	: V=0.9950063, theta=-59.075681 -> V=1.0, theta=0.0
% INFO    : Bus 11148	: V=0.9956969, theta=-58.812302 -> V=1.0, theta=0.0
% INFO    : Bus 11149	: V=0.9943259, theta=-59.110444 -> V=1.0, theta=0.0
% INFO    : Bus 11150	: V=0.9944658, theta=-58.904262 -> V=1.0, theta=0.0
% INFO    : Bus 11151	: V=0.994494, theta=-57.75952 -> V=1.0, theta=0.0
% INFO    : Bus 11152	: V=0.9769944, theta=-62.644271 -> V=1.0, theta=0.0
% INFO    : Bus 11153	: V=0.9758534, theta=-62.014189 -> V=1.0, theta=0.0
% INFO    : Bus 11154	: V=0.9801548, theta=-61.088078 -> V=1.0, theta=0.0
% INFO    : Bus 11155	: V=0.9919497, theta=-59.89109 -> V=1.0, theta=0.0
% INFO    : Bus 11156	: V=1.0080199, theta=-56.392865 -> V=1.0, theta=0.0
% INFO    : Bus 11157	: V=0.9911165, theta=-60.072883 -> V=1.0, theta=0.0
% INFO    : Bus 11158	: V=0.9983293, theta=-58.477412 -> V=1.0, theta=0.0
% INFO    : Bus 11159	: V=0.9807774, theta=-61.550826 -> V=1.0, theta=0.0
% INFO    : Bus 11160	: V=0.9911835, theta=-60.921644 -> V=1.0, theta=0.0
% INFO    : Bus 11161	: V=0.9979291, theta=-60.391717 -> V=1.0, theta=0.0
% INFO    : Bus 11162	: V=0.9945561, theta=-60.461859 -> V=1.0, theta=0.0
% INFO    : Bus 11163	: V=0.9931027, theta=-60.79542 -> V=1.0, theta=0.0
% INFO    : Bus 11164	: V=0.9894094, theta=-60.829307 -> V=1.0, theta=0.0
% INFO    : Bus 11165	: V=0.9893574, theta=-60.661129 -> V=1.0, theta=0.0
% INFO    : Bus 11166	: V=0.9908044, theta=-60.550222 -> V=1.0, theta=0.0
% INFO    : Bus 11167	: V=0.9900703, theta=-60.581112 -> V=1.0, theta=0.0
% INFO    : Bus 11168	: V=0.9957396, theta=-60.197134 -> V=1.0, theta=0.0
% INFO    : Bus 11169	: V=0.9948262, theta=-58.842405 -> V=1.0, theta=0.0
% INFO    : Bus 11170	: V=1.0003123, theta=-57.480005 -> V=1.0, theta=0.0
% INFO    : Bus 11171	: V=0.9973291, theta=-63.143755 -> V=1.0, theta=0.0
% INFO    : Bus 11172	: V=0.9898212, theta=-64.159754 -> V=1.0, theta=0.0
% INFO    : Bus 11173	: V=0.9899428, theta=-64.121527 -> V=1.0, theta=0.0
% INFO    : Bus 11174	: V=0.9908765, theta=-64.033377 -> V=1.0, theta=0.0
% INFO    : Bus 11175	: V=0.9983512, theta=-62.999973 -> V=1.0, theta=0.0
% INFO    : Bus 11176	: V=0.9918748, theta=-63.842431 -> V=1.0, theta=0.0
% INFO    : Bus 11177	: V=0.9917293, theta=-63.920747 -> V=1.0, theta=0.0
% INFO    : Bus 11178	: V=0.9912189, theta=-63.927807 -> V=1.0, theta=0.0
% INFO    : Bus 11179	: V=0.9909473, theta=-64.033087 -> V=1.0, theta=0.0
% INFO    : Bus 11180	: V=0.9907576, theta=-64.070145 -> V=1.0, theta=0.0
% INFO    : Bus 11181	: V=0.9906953, theta=-64.106268 -> V=1.0, theta=0.0
% INFO    : Bus 11182	: V=0.9929623, theta=-63.837367 -> V=1.0, theta=0.0
% INFO    : Bus 11183	: V=0.9914855, theta=-63.97946 -> V=1.0, theta=0.0
% INFO    : Bus 11184	: V=0.9916646, theta=-63.94067 -> V=1.0, theta=0.0
% INFO    : Bus 11185	: V=0.9916489, theta=-63.935836 -> V=1.0, theta=0.0
% INFO    : Bus 11186	: V=0.9917244, theta=-63.933805 -> V=1.0, theta=0.0
% INFO    : Bus 11187	: V=0.9919436, theta=-63.924125 -> V=1.0, theta=0.0
% INFO    : Bus 11188	: V=0.9941398, theta=-63.782943 -> V=1.0, theta=0.0
% INFO    : Bus 11189	: V=0.9931333, theta=-63.860303 -> V=1.0, theta=0.0
% INFO    : Bus 11190	: V=0.9947851, theta=-63.771825 -> V=1.0, theta=0.0
% INFO    : Bus 11191	: V=0.9939142, theta=-63.813525 -> V=1.0, theta=0.0
% INFO    : Bus 11192	: V=0.9933042, theta=-63.828553 -> V=1.0, theta=0.0
% INFO    : Bus 11193	: V=0.9931258, theta=-63.84976 -> V=1.0, theta=0.0
% INFO    : Bus 11194	: V=0.997283, theta=-63.152841 -> V=1.0, theta=0.0
% INFO    : Bus 11195	: V=0.9974948, theta=-63.130864 -> V=1.0, theta=0.0
% INFO    : Bus 11196	: V=0.9976407, theta=-63.112679 -> V=1.0, theta=0.0
% INFO    : Bus 11197	: V=1.0030391, theta=-62.976097 -> V=1.0, theta=0.0
% INFO    : Bus 11198	: V=0.9843348, theta=-64.998609 -> V=1.0, theta=0.0
% INFO    : Bus 11199	: V=1.0006257, theta=-62.620237 -> V=1.0, theta=0.0
% INFO    : Bus 11200	: V=0.9969816, theta=-62.919961 -> V=1.0, theta=0.0
% INFO    : Bus 11201	: V=0.9999463, theta=-62.981361 -> V=1.0, theta=0.0
% INFO    : Bus 11202	: V=1.0039159, theta=-62.355468 -> V=1.0, theta=0.0
% INFO    : Bus 11203	: V=1.0008991, theta=-62.788195 -> V=1.0, theta=0.0
% INFO    : Bus 11204	: V=0.9991518, theta=-63.180801 -> V=1.0, theta=0.0
% INFO    : Bus 11205	: V=0.9855125, theta=-65.043019 -> V=1.0, theta=0.0
% INFO    : Bus 11206	: V=0.9853891, theta=-64.492637 -> V=1.0, theta=0.0
% INFO    : Bus 11207	: V=0.9895301, theta=-64.247033 -> V=1.0, theta=0.0
% INFO    : Bus 11208	: V=0.9954131, theta=-63.196092 -> V=1.0, theta=0.0
% INFO    : Bus 11209	: V=1.0066233, theta=-61.559725 -> V=1.0, theta=0.0
% INFO    : Bus 11210	: V=0.9987524, theta=-62.914678 -> V=1.0, theta=0.0
% INFO    : Bus 11211	: V=0.9890079, theta=-64.319191 -> V=1.0, theta=0.0
% INFO    : Bus 11212	: V=0.9891251, theta=-64.293769 -> V=1.0, theta=0.0
% INFO    : Bus 11213	: V=0.9986633, theta=-62.981204 -> V=1.0, theta=0.0
% INFO    : Bus 11214	: V=0.9909434, theta=-64.120154 -> V=1.0, theta=0.0
% INFO    : Bus 11215	: V=0.9900661, theta=-64.185361 -> V=1.0, theta=0.0
% INFO    : Bus 11216	: V=0.9980385, theta=-63.059087 -> V=1.0, theta=0.0
% INFO    : Bus 11217	: V=0.9914051, theta=-64.085964 -> V=1.0, theta=0.0
% INFO    : Bus 11218	: V=1.0019976, theta=-63.005275 -> V=1.0, theta=0.0
% INFO    : Bus 11219	: V=1.0006264, theta=-63.02067 -> V=1.0, theta=0.0
% INFO    : Bus 11220	: V=0.9845746, theta=-64.759606 -> V=1.0, theta=0.0
% INFO    : Bus 11221	: V=1.0011867, theta=-63.020418 -> V=1.0, theta=0.0
% INFO    : Bus 11222	: V=0.9858251, theta=-64.734745 -> V=1.0, theta=0.0
% INFO    : Bus 11223	: V=1.0029483, theta=-63.047128 -> V=1.0, theta=0.0
% INFO    : Bus 11224	: V=0.9739605, theta=-67.290359 -> V=1.0, theta=0.0
% INFO    : Bus 11225	: V=0.9814391, theta=-65.026567 -> V=1.0, theta=0.0
% INFO    : Bus 11226	: V=0.9679607, theta=-64.272908 -> V=1.0, theta=0.0
% INFO    : Bus 11227	: V=0.9932298, theta=-63.67686 -> V=1.0, theta=0.0
% INFO    : Bus 11228	: V=0.9912871, theta=-63.476349 -> V=1.0, theta=0.0
% INFO    : Bus 11229	: V=0.9920273, theta=-63.824943 -> V=1.0, theta=0.0
% INFO    : Bus 11230	: V=0.9983122, theta=-63.209548 -> V=1.0, theta=0.0
% INFO    : Bus 11231	: V=1.0003553, theta=-63.177721 -> V=1.0, theta=0.0
% INFO    : Bus 11232	: V=1.0012086, theta=-63.18489 -> V=1.0, theta=0.0
% INFO    : Bus 11233	: V=0.9984755, theta=-63.366046 -> V=1.0, theta=0.0
% INFO    : Bus 11234	: V=0.994719, theta=-63.636548 -> V=1.0, theta=0.0
% INFO    : Bus 11235	: V=0.9968715, theta=-63.475087 -> V=1.0, theta=0.0
% INFO    : Bus 11236	: V=0.9795543, theta=-65.904771 -> V=1.0, theta=0.0
% INFO    : Bus 11237	: V=0.9949309, theta=-63.75999 -> V=1.0, theta=0.0
% INFO    : Bus 11238	: V=0.9928491, theta=-63.813232 -> V=1.0, theta=0.0
% INFO    : Bus 11239	: V=1.0016801, theta=-62.601489 -> V=1.0, theta=0.0
% INFO    : Bus 11240	: V=1.0037197, theta=-62.419977 -> V=1.0, theta=0.0
% INFO    : Bus 11241	: V=0.9900066, theta=-64.158929 -> V=1.0, theta=0.0
% INFO    : Bus 11242	: V=0.9994041, theta=-63.104652 -> V=1.0, theta=0.0
% INFO    : Bus 11243	: V=1.0011164, theta=-62.647553 -> V=1.0, theta=0.0
% INFO    : Bus 11244	: V=0.9981158, theta=-62.87905 -> V=1.0, theta=0.0
% INFO    : Bus 11245	: V=0.9897656, theta=-63.949702 -> V=1.0, theta=0.0
% INFO    : Bus 11246	: V=0.9878636, theta=-64.004688 -> V=1.0, theta=0.0
% INFO    : Bus 11247	: V=0.9883512, theta=-63.975998 -> V=1.0, theta=0.0
% INFO    : Bus 11248	: V=0.9839041, theta=-64.26703 -> V=1.0, theta=0.0
% INFO    : Bus 11249	: V=0.9823452, theta=-64.62483 -> V=1.0, theta=0.0
% INFO    : Bus 11250	: V=0.978907, theta=-64.931094 -> V=1.0, theta=0.0
% INFO    : Bus 11251	: V=0.9950445, theta=-62.981911 -> V=1.0, theta=0.0
% INFO    : Bus 11252	: V=1.0164039, theta=-60.380373 -> V=1.0, theta=0.0
% INFO    : Bus 11253	: V=0.9826973, theta=-64.717849 -> V=1.0, theta=0.0
% INFO    : Bus 11254	: V=1.0008456, theta=-62.328966 -> V=1.0, theta=0.0
% INFO    : Bus 11255	: V=0.9985988, theta=-62.732462 -> V=1.0, theta=0.0
% INFO    : Bus 11256	: V=0.995755, theta=-62.967521 -> V=1.0, theta=0.0
% INFO    : Bus 11257	: V=0.9824441, theta=-64.770597 -> V=1.0, theta=0.0
% INFO    : Bus 11258	: V=0.9984874, theta=-62.396526 -> V=1.0, theta=0.0
% INFO    : Bus 11259	: V=0.998083, theta=-62.34891 -> V=1.0, theta=0.0
% INFO    : Bus 11260	: V=0.9953216, theta=-62.767653 -> V=1.0, theta=0.0
% INFO    : Bus 11261	: V=0.9622896, theta=-67.831958 -> V=1.0, theta=0.0
% INFO    : Bus 11262	: V=0.9759129, theta=-65.562538 -> V=1.0, theta=0.0
% INFO    : Bus 11263	: V=0.9757865, theta=-65.625676 -> V=1.0, theta=0.0
% INFO    : Bus 11264	: V=0.9810653, theta=-64.522405 -> V=1.0, theta=0.0
% INFO    : Bus 11265	: V=0.9796332, theta=-64.790481 -> V=1.0, theta=0.0
% INFO    : Bus 11266	: V=0.988919, theta=-63.194296 -> V=1.0, theta=0.0
% INFO    : Bus 11267	: V=0.9796435, theta=-64.714021 -> V=1.0, theta=0.0
% INFO    : Bus 11268	: V=0.9842601, theta=-63.905795 -> V=1.0, theta=0.0
% INFO    : Bus 11269	: V=0.9965213, theta=-61.256156 -> V=1.0, theta=0.0
% INFO    : Bus 11270	: V=0.9981051, theta=-61.106141 -> V=1.0, theta=0.0
% INFO    : Bus 11271	: V=0.9969937, theta=-61.980192 -> V=1.0, theta=0.0
% INFO    : Bus 11272	: V=0.9917374, theta=-62.709941 -> V=1.0, theta=0.0
% INFO    : Bus 11273	: V=0.9781934, theta=-64.810166 -> V=1.0, theta=0.0
% INFO    : Bus 11274	: V=0.9783783, theta=-64.852337 -> V=1.0, theta=0.0
% INFO    : Bus 11275	: V=0.9934792, theta=-62.000269 -> V=1.0, theta=0.0
% INFO    : Bus 11276	: V=0.9954081, theta=-61.941228 -> V=1.0, theta=0.0
% INFO    : Bus 11277	: V=0.9952616, theta=-61.970865 -> V=1.0, theta=0.0
% INFO    : Bus 11278	: V=0.9979886, theta=-61.717233 -> V=1.0, theta=0.0
% INFO    : Bus 11279	: V=0.9877842, theta=-63.366832 -> V=1.0, theta=0.0
% INFO    : Bus 11280	: V=0.9793255, theta=-64.61739 -> V=1.0, theta=0.0
% INFO    : Bus 11281	: V=0.9788221, theta=-64.626474 -> V=1.0, theta=0.0
% INFO    : Bus 11282	: V=0.9755542, theta=-64.915467 -> V=1.0, theta=0.0
% INFO    : Bus 11283	: V=0.9775469, theta=-64.9041 -> V=1.0, theta=0.0
% INFO    : Bus 11284	: V=0.9780717, theta=-64.896038 -> V=1.0, theta=0.0
% INFO    : Bus 11285	: V=0.9771734, theta=-64.910887 -> V=1.0, theta=0.0
% INFO    : Bus 11286	: V=0.9849941, theta=-63.795549 -> V=1.0, theta=0.0
% INFO    : Bus 11287	: V=0.9889165, theta=-63.141805 -> V=1.0, theta=0.0
% INFO    : Bus 11288	: V=0.9875594, theta=-63.342172 -> V=1.0, theta=0.0
% INFO    : Bus 11289	: V=0.9866199, theta=-63.483891 -> V=1.0, theta=0.0
% INFO    : Bus 11290	: V=0.978411, theta=-64.604922 -> V=1.0, theta=0.0
% INFO    : Bus 11291	: V=0.9858693, theta=-63.608293 -> V=1.0, theta=0.0
% INFO    : Bus 11292	: V=0.9855037, theta=-63.678572 -> V=1.0, theta=0.0
% INFO    : Bus 11293	: V=0.9778532, theta=-64.922007 -> V=1.0, theta=0.0
% INFO    : Bus 11294	: V=0.9762194, theta=-64.907429 -> V=1.0, theta=0.0
% INFO    : Bus 11295	: V=0.9425628, theta=-76.592263 -> V=1.0, theta=0.0
% INFO    : Bus 11296	: V=0.9537577, theta=-75.659488 -> V=1.0, theta=0.0
% INFO    : Bus 11297	: V=0.9440211, theta=-78.249587 -> V=1.0, theta=0.0
% INFO    : Bus 11298	: V=0.9486762, theta=-77.437332 -> V=1.0, theta=0.0
% INFO    : Bus 11299	: V=0.958259, theta=-77.761624 -> V=1.0, theta=0.0
% INFO    : Bus 11300	: V=0.94625, theta=-79.652489 -> V=1.0, theta=0.0
% INFO    : Bus 11301	: V=0.9683382, theta=-77.788846 -> V=1.0, theta=0.0
% INFO    : Bus 11302	: V=0.9623472, theta=-77.838024 -> V=1.0, theta=0.0
% INFO    : Bus 11303	: V=1.0167154, theta=-64.661594 -> V=1.0, theta=0.0
% INFO    : Bus 11304	: V=0.9740245, theta=-72.174102 -> V=1.0, theta=0.0
% INFO    : Bus 11305	: V=0.9727392, theta=-71.385922 -> V=1.0, theta=0.0
% INFO    : Bus 11306	: V=0.9716304, theta=-70.655141 -> V=1.0, theta=0.0
% INFO    : Bus 11307	: V=0.9668115, theta=-75.4802 -> V=1.0, theta=0.0
% INFO    : Bus 11308	: V=0.9665666, theta=-77.637601 -> V=1.0, theta=0.0
% INFO    : Bus 11309	: V=0.982184, theta=-63.146618 -> V=1.0, theta=0.0
% INFO    : Bus 11310	: V=0.9744857, theta=-63.956012 -> V=1.0, theta=0.0
% INFO    : Bus 11311	: V=0.9914244, theta=-61.833129 -> V=1.0, theta=0.0
% INFO    : Bus 11312	: V=0.9809997, theta=-63.196367 -> V=1.0, theta=0.0
% INFO    : Bus 11313	: V=0.966829, theta=-64.766304 -> V=1.0, theta=0.0
% INFO    : Bus 11314	: V=0.974181, theta=-63.975159 -> V=1.0, theta=0.0
% INFO    : Bus 11315	: V=0.977834, theta=-63.662924 -> V=1.0, theta=0.0
% INFO    : Bus 11316	: V=0.9756283, theta=-63.911555 -> V=1.0, theta=0.0
% INFO    : Bus 11317	: V=0.9949827, theta=-61.456844 -> V=1.0, theta=0.0
% INFO    : Bus 11318	: V=0.9831011, theta=-63.131316 -> V=1.0, theta=0.0
% INFO    : Bus 11319	: V=0.9748205, theta=-63.855318 -> V=1.0, theta=0.0
% INFO    : Bus 11320	: V=0.9812789, theta=-63.068701 -> V=1.0, theta=0.0
% INFO    : Bus 11321	: V=1.0091518, theta=-59.671318 -> V=1.0, theta=0.0
% INFO    : Bus 11322	: V=1.0013753, theta=-60.793114 -> V=1.0, theta=0.0
% INFO    : Bus 11323	: V=0.9986597, theta=-60.926544 -> V=1.0, theta=0.0
% INFO    : Bus 11324	: V=0.9998912, theta=-60.850367 -> V=1.0, theta=0.0
% INFO    : Bus 11325	: V=1.001061, theta=-60.77716 -> V=1.0, theta=0.0
% INFO    : Bus 11326	: V=0.9963496, theta=-61.122229 -> V=1.0, theta=0.0
% INFO    : Bus 11327	: V=0.9919295, theta=-62.006222 -> V=1.0, theta=0.0
% INFO    : Bus 11328	: V=1.0090159, theta=-59.681932 -> V=1.0, theta=0.0
% INFO    : Bus 11329	: V=1.0096757, theta=-59.602736 -> V=1.0, theta=0.0
% INFO    : Bus 11330	: V=0.9978623, theta=-61.107424 -> V=1.0, theta=0.0
% INFO    : Bus 11331	: V=1.0014142, theta=-60.734892 -> V=1.0, theta=0.0
% INFO    : Bus 11332	: V=1.0007917, theta=-60.808761 -> V=1.0, theta=0.0
% INFO    : Bus 11333	: V=1.0020351, theta=-60.715357 -> V=1.0, theta=0.0
% INFO    : Bus 11334	: V=1.0019058, theta=-60.734372 -> V=1.0, theta=0.0
% INFO    : Bus 11335	: V=1.0017769, theta=-60.756803 -> V=1.0, theta=0.0
% INFO    : Bus 11336	: V=0.9838119, theta=-62.799559 -> V=1.0, theta=0.0
% INFO    : Bus 11337	: V=0.9857156, theta=-62.663304 -> V=1.0, theta=0.0
% INFO    : Bus 11338	: V=0.9951823, theta=-61.212586 -> V=1.0, theta=0.0
% INFO    : Bus 11339	: V=0.9785892, theta=-63.443535 -> V=1.0, theta=0.0
% INFO    : Bus 11340	: V=0.9763936, theta=-63.611735 -> V=1.0, theta=0.0
% INFO    : Bus 11341	: V=0.9773005, theta=-63.485552 -> V=1.0, theta=0.0
% INFO    : Bus 11342	: V=0.9819044, theta=-63.027247 -> V=1.0, theta=0.0
% INFO    : Bus 11343	: V=0.9731858, theta=-64.032166 -> V=1.0, theta=0.0
% INFO    : Bus 11344	: V=0.9771939, theta=-63.619025 -> V=1.0, theta=0.0
% INFO    : Bus 11345	: V=0.9679446, theta=-64.719611 -> V=1.0, theta=0.0
% INFO    : Bus 11346	: V=0.9711074, theta=-64.303394 -> V=1.0, theta=0.0
% INFO    : Bus 11347	: V=0.974953, theta=-63.690079 -> V=1.0, theta=0.0
% INFO    : Bus 11348	: V=0.9744362, theta=-63.736078 -> V=1.0, theta=0.0
% INFO    : Bus 11349	: V=0.9762778, theta=-63.603235 -> V=1.0, theta=0.0
% INFO    : Bus 11350	: V=0.9670254, theta=-64.800632 -> V=1.0, theta=0.0
% INFO    : Bus 11351	: V=0.9758059, theta=-63.60396 -> V=1.0, theta=0.0
% INFO    : Bus 11352	: V=0.9768953, theta=-63.495441 -> V=1.0, theta=0.0
% INFO    : Bus 11353	: V=0.9721613, theta=-64.395656 -> V=1.0, theta=0.0
% INFO    : Bus 11354	: V=0.9671544, theta=-64.731526 -> V=1.0, theta=0.0
% INFO    : Bus 11355	: V=0.9667246, theta=-64.801143 -> V=1.0, theta=0.0
% INFO    : Bus 11356	: V=0.9935111, theta=-61.234382 -> V=1.0, theta=0.0
% INFO    : Bus 11357	: V=0.9748475, theta=-64.09015 -> V=1.0, theta=0.0
% INFO    : Bus 11358	: V=0.9684191, theta=-64.414981 -> V=1.0, theta=0.0
% INFO    : Bus 11359	: V=0.985764, theta=-62.369683 -> V=1.0, theta=0.0
% INFO    : Bus 11360	: V=0.9830062, theta=-62.561879 -> V=1.0, theta=0.0
% INFO    : Bus 11361	: V=0.9692865, theta=-64.322348 -> V=1.0, theta=0.0
% INFO    : Bus 11362	: V=0.9702241, theta=-64.29777 -> V=1.0, theta=0.0
% INFO    : Bus 11363	: V=0.9818816, theta=-62.640325 -> V=1.0, theta=0.0
% INFO    : Bus 11364	: V=0.9892531, theta=-62.02953 -> V=1.0, theta=0.0
% INFO    : Bus 11365	: V=0.9803734, theta=-62.863837 -> V=1.0, theta=0.0
% INFO    : Bus 11366	: V=0.9928703, theta=-61.697716 -> V=1.0, theta=0.0
% INFO    : Bus 11367	: V=0.9831429, theta=-62.736369 -> V=1.0, theta=0.0
% INFO    : Bus 11368	: V=0.9843954, theta=-62.738217 -> V=1.0, theta=0.0
% INFO    : Bus 11369	: V=0.9984877, theta=-61.172918 -> V=1.0, theta=0.0
% INFO    : Bus 11370	: V=0.9968982, theta=-61.34742 -> V=1.0, theta=0.0
% INFO    : Bus 11371	: V=0.9966697, theta=-61.364934 -> V=1.0, theta=0.0
% INFO    : Bus 11372	: V=0.9968675, theta=-61.346416 -> V=1.0, theta=0.0
% INFO    : Bus 11373	: V=0.9974906, theta=-61.287332 -> V=1.0, theta=0.0
% INFO    : Bus 11374	: V=0.9986707, theta=-61.134805 -> V=1.0, theta=0.0
% INFO    : Bus 11375	: V=0.9958696, theta=-61.477163 -> V=1.0, theta=0.0
% INFO    : Bus 11376	: V=0.9959834, theta=-61.600317 -> V=1.0, theta=0.0
% INFO    : Bus 11377	: V=0.9950377, theta=-61.595391 -> V=1.0, theta=0.0
% INFO    : Bus 11378	: V=0.9865998, theta=-63.05599 -> V=1.0, theta=0.0
% INFO    : Bus 11379	: V=0.9819853, theta=-63.523173 -> V=1.0, theta=0.0
% INFO    : Bus 11380	: V=0.9988595, theta=-61.173659 -> V=1.0, theta=0.0
% INFO    : Bus 11381	: V=0.9930656, theta=-62.491946 -> V=1.0, theta=0.0
% INFO    : Bus 11382	: V=1.0026758, theta=-61.004035 -> V=1.0, theta=0.0
% INFO    : Bus 11383	: V=1.0064785, theta=-60.052155 -> V=1.0, theta=0.0
% INFO    : Bus 11384	: V=0.9824254, theta=-62.106566 -> V=1.0, theta=0.0
% INFO    : Bus 11385	: V=0.9802958, theta=-62.732651 -> V=1.0, theta=0.0
% INFO    : Bus 11386	: V=0.983174, theta=-62.761668 -> V=1.0, theta=0.0
% INFO    : Bus 11387	: V=0.9747371, theta=-63.015339 -> V=1.0, theta=0.0
% INFO    : Bus 11388	: V=0.9755229, theta=-63.300051 -> V=1.0, theta=0.0
% INFO    : Bus 11389	: V=0.9758084, theta=-63.302942 -> V=1.0, theta=0.0
% INFO    : Bus 11390	: V=0.976074, theta=-63.027483 -> V=1.0, theta=0.0
% INFO    : Bus 11391	: V=0.9815664, theta=-62.245824 -> V=1.0, theta=0.0
% INFO    : Bus 11392	: V=0.9763169, theta=-63.176066 -> V=1.0, theta=0.0
% INFO    : Bus 11393	: V=0.9749054, theta=-62.594413 -> V=1.0, theta=0.0
% INFO    : Bus 11394	: V=0.974364, theta=-63.403899 -> V=1.0, theta=0.0
% INFO    : Bus 11395	: V=0.9715602, theta=-63.807713 -> V=1.0, theta=0.0
% INFO    : Bus 11396	: V=0.9693735, theta=-63.90507 -> V=1.0, theta=0.0
% INFO    : Bus 11397	: V=0.9683781, theta=-63.921967 -> V=1.0, theta=0.0
% INFO    : Bus 11398	: V=0.9701858, theta=-64.119206 -> V=1.0, theta=0.0
% INFO    : Bus 11399	: V=0.9702483, theta=-63.692192 -> V=1.0, theta=0.0
% INFO    : Bus 11400	: V=0.9848678, theta=-62.336809 -> V=1.0, theta=0.0
% INFO    : Bus 11401	: V=0.9843793, theta=-62.356874 -> V=1.0, theta=0.0
% INFO    : Bus 11402	: V=0.9734686, theta=-63.585422 -> V=1.0, theta=0.0
% INFO    : Bus 11403	: V=0.9736359, theta=-63.559197 -> V=1.0, theta=0.0
% INFO    : Bus 11404	: V=0.9824878, theta=-62.82943 -> V=1.0, theta=0.0
% INFO    : Bus 11405	: V=0.9700467, theta=-64.310162 -> V=1.0, theta=0.0
% INFO    : Bus 11406	: V=0.9672763, theta=-64.435782 -> V=1.0, theta=0.0
% INFO    : Bus 11407	: V=0.9811061, theta=-63.000039 -> V=1.0, theta=0.0
% INFO    : Bus 11408	: V=0.9724522, theta=-64.156248 -> V=1.0, theta=0.0
% INFO    : Bus 11409	: V=0.9728467, theta=-64.084724 -> V=1.0, theta=0.0
% INFO    : Bus 11410	: V=0.9802686, theta=-63.151638 -> V=1.0, theta=0.0
% INFO    : Bus 11411	: V=0.9739223, theta=-63.966817 -> V=1.0, theta=0.0
% INFO    : Bus 11412	: V=0.9748244, theta=-63.876312 -> V=1.0, theta=0.0
% INFO    : Bus 11413	: V=0.9732605, theta=-63.903201 -> V=1.0, theta=0.0
% INFO    : Bus 11414	: V=0.9725143, theta=-64.162398 -> V=1.0, theta=0.0
% INFO    : Bus 11415	: V=0.9803656, theta=-63.119397 -> V=1.0, theta=0.0
% INFO    : Bus 11416	: V=0.9697719, theta=-64.384574 -> V=1.0, theta=0.0
% INFO    : Bus 11417	: V=0.9847945, theta=-62.505623 -> V=1.0, theta=0.0
% INFO    : Bus 11418	: V=0.9823355, theta=-62.828249 -> V=1.0, theta=0.0
% INFO    : Bus 11419	: V=0.9781027, theta=-63.332143 -> V=1.0, theta=0.0
% INFO    : Bus 11420	: V=0.9746047, theta=-63.803211 -> V=1.0, theta=0.0
% INFO    : Bus 11421	: V=0.9738735, theta=-63.815417 -> V=1.0, theta=0.0
% INFO    : Bus 11422	: V=0.9778789, theta=-63.412937 -> V=1.0, theta=0.0
% INFO    : Bus 11423	: V=0.9749462, theta=-63.403998 -> V=1.0, theta=0.0
% INFO    : Bus 11424	: V=0.992084, theta=-61.303107 -> V=1.0, theta=0.0
% INFO    : Bus 11425	: V=0.979979, theta=-63.035121 -> V=1.0, theta=0.0
% INFO    : Bus 11426	: V=0.9927016, theta=-61.307299 -> V=1.0, theta=0.0
% INFO    : Bus 11427	: V=0.9789286, theta=-63.049978 -> V=1.0, theta=0.0
% INFO    : Bus 11428	: V=0.9790655, theta=-63.067197 -> V=1.0, theta=0.0
% INFO    : Bus 11429	: V=0.9776805, theta=-63.427017 -> V=1.0, theta=0.0
% INFO    : Bus 11430	: V=0.9784112, theta=-63.288853 -> V=1.0, theta=0.0
% INFO    : Bus 11431	: V=0.9785534, theta=-63.060784 -> V=1.0, theta=0.0
% INFO    : Bus 11432	: V=0.9913085, theta=-61.413769 -> V=1.0, theta=0.0
% INFO    : Bus 11433	: V=0.9943316, theta=-61.202348 -> V=1.0, theta=0.0
% INFO    : Bus 11434	: V=0.9949121, theta=-61.189776 -> V=1.0, theta=0.0
% INFO    : Bus 11435	: V=0.9969706, theta=-61.083002 -> V=1.0, theta=0.0
% INFO    : Bus 11436	: V=0.9870368, theta=-62.452911 -> V=1.0, theta=0.0
% INFO    : Bus 11437	: V=0.9875957, theta=-62.299149 -> V=1.0, theta=0.0
% INFO    : Bus 11438	: V=0.9892995, theta=-62.175646 -> V=1.0, theta=0.0
% INFO    : Bus 11439	: V=0.9976231, theta=-61.028505 -> V=1.0, theta=0.0
% INFO    : Bus 11440	: V=0.9990057, theta=-60.908337 -> V=1.0, theta=0.0
% INFO    : Bus 11441	: V=1.0001705, theta=-60.80211 -> V=1.0, theta=0.0
% INFO    : Bus 11442	: V=1.0029383, theta=-60.442385 -> V=1.0, theta=0.0
% INFO    : Bus 11443	: V=0.9799009, theta=-63.225303 -> V=1.0, theta=0.0
% INFO    : Bus 11444	: V=0.9747473, theta=-63.872063 -> V=1.0, theta=0.0
% INFO    : Bus 11445	: V=0.9782507, theta=-63.329524 -> V=1.0, theta=0.0
% INFO    : Bus 11446	: V=0.9963125, theta=-61.340387 -> V=1.0, theta=0.0
% INFO    : Bus 11447	: V=0.994834, theta=-61.60059 -> V=1.0, theta=0.0
% INFO    : Bus 11448	: V=0.9954032, theta=-61.625195 -> V=1.0, theta=0.0
% INFO    : Bus 11449	: V=0.9961852, theta=-61.499332 -> V=1.0, theta=0.0
% INFO    : Bus 11450	: V=1.0057664, theta=-60.060168 -> V=1.0, theta=0.0
% INFO    : Bus 11451	: V=1.0103552, theta=-59.439283 -> V=1.0, theta=0.0
% INFO    : Bus 11452	: V=0.968145, theta=-65.837285 -> V=1.0, theta=0.0
% INFO    : Bus 11453	: V=0.9632536, theta=-66.068884 -> V=1.0, theta=0.0
% INFO    : Bus 11454	: V=0.9701272, theta=-64.886472 -> V=1.0, theta=0.0
% INFO    : Bus 11455	: V=0.9707791, theta=-64.937973 -> V=1.0, theta=0.0
% INFO    : Bus 11456	: V=0.9681988, theta=-65.869629 -> V=1.0, theta=0.0
% INFO    : Bus 11457	: V=0.9683746, theta=-65.874797 -> V=1.0, theta=0.0
% INFO    : Bus 11458	: V=0.9642207, theta=-65.869549 -> V=1.0, theta=0.0
% INFO    : Bus 11459	: V=0.9687707, theta=-64.923982 -> V=1.0, theta=0.0
% INFO    : Bus 11460	: V=0.9624363, theta=-66.21908 -> V=1.0, theta=0.0
% INFO    : Bus 11461	: V=0.968489, theta=-64.818582 -> V=1.0, theta=0.0
% INFO    : Bus 11462	: V=0.9723503, theta=-64.553045 -> V=1.0, theta=0.0
% INFO    : Bus 11463	: V=0.9827613, theta=-67.042006 -> V=1.0, theta=0.0
% INFO    : Bus 11464	: V=0.9726953, theta=-67.42187 -> V=1.0, theta=0.0
% INFO    : Bus 11465	: V=0.9689276, theta=-66.237943 -> V=1.0, theta=0.0
% INFO    : Bus 11466	: V=0.9594578, theta=-66.382382 -> V=1.0, theta=0.0
% INFO    : Bus 11467	: V=0.9681011, theta=-66.056231 -> V=1.0, theta=0.0
% INFO    : Bus 11468	: V=0.9621254, theta=-66.791698 -> V=1.0, theta=0.0
% INFO    : Bus 11469	: V=0.9643138, theta=-67.050876 -> V=1.0, theta=0.0
% INFO    : Bus 11470	: V=0.9579324, theta=-66.666025 -> V=1.0, theta=0.0
% INFO    : Bus 11471	: V=0.9640092, theta=-66.927551 -> V=1.0, theta=0.0
% INFO    : Bus 11472	: V=0.9614095, theta=-66.496387 -> V=1.0, theta=0.0
% INFO    : Bus 11473	: V=0.9701336, theta=-64.827469 -> V=1.0, theta=0.0
% INFO    : Bus 11474	: V=0.9644183, theta=-65.628609 -> V=1.0, theta=0.0
% INFO    : Bus 11475	: V=0.9741462, theta=-64.923079 -> V=1.0, theta=0.0
% INFO    : Bus 11476	: V=0.9843807, theta=-64.550984 -> V=1.0, theta=0.0
% INFO    : Bus 11477	: V=0.9755422, theta=-63.82458 -> V=1.0, theta=0.0
% INFO    : Bus 11478	: V=0.9823752, theta=-63.227457 -> V=1.0, theta=0.0
% INFO    : Bus 11479	: V=0.9818775, theta=-62.693386 -> V=1.0, theta=0.0
% INFO    : Bus 11480	: V=0.976035, theta=-64.032712 -> V=1.0, theta=0.0
% INFO    : Bus 11481	: V=0.9740611, theta=-63.286479 -> V=1.0, theta=0.0
% INFO    : Bus 11482	: V=0.9725937, theta=-63.674835 -> V=1.0, theta=0.0
% INFO    : Bus 11483	: V=0.9660693, theta=-64.589052 -> V=1.0, theta=0.0
% INFO    : Bus 11484	: V=0.9835155, theta=-61.196881 -> V=1.0, theta=0.0
% INFO    : Bus 11485	: V=0.983149, theta=-61.028582 -> V=1.0, theta=0.0
% INFO    : Bus 11486	: V=0.9846404, theta=-60.831676 -> V=1.0, theta=0.0
% INFO    : Bus 11487	: V=0.9823202, theta=-61.206672 -> V=1.0, theta=0.0
% INFO    : Bus 11488	: V=0.9726211, theta=-62.592377 -> V=1.0, theta=0.0
% INFO    : Bus 11489	: V=0.9701405, theta=-62.799204 -> V=1.0, theta=0.0
% INFO    : Bus 11490	: V=0.9767616, theta=-62.018691 -> V=1.0, theta=0.0
% INFO    : Bus 11491	: V=0.9808021, theta=-61.583757 -> V=1.0, theta=0.0
% INFO    : Bus 11492	: V=0.9792599, theta=-61.967282 -> V=1.0, theta=0.0
% INFO    : Bus 11493	: V=0.9778263, theta=-62.573456 -> V=1.0, theta=0.0
% INFO    : Bus 11494	: V=0.9816778, theta=-63.096678 -> V=1.0, theta=0.0
% INFO    : Bus 11495	: V=0.9789548, theta=-62.693898 -> V=1.0, theta=0.0
% INFO    : Bus 11496	: V=1.0034217, theta=-59.782117 -> V=1.0, theta=0.0
% INFO    : Bus 11497	: V=1.0035348, theta=-59.761467 -> V=1.0, theta=0.0
% INFO    : Bus 11498	: V=1.0026373, theta=-59.892459 -> V=1.0, theta=0.0
% INFO    : Bus 11499	: V=0.9918793, theta=-61.814856 -> V=1.0, theta=0.0
% INFO    : Bus 11500	: V=1.0019764, theta=-59.985735 -> V=1.0, theta=0.0
% INFO    : Bus 11501	: V=1.0021767, theta=-59.958703 -> V=1.0, theta=0.0
% INFO    : Bus 11502	: V=1.0044248, theta=-59.739372 -> V=1.0, theta=0.0
% INFO    : Bus 11503	: V=1.0028115, theta=-59.936602 -> V=1.0, theta=0.0
% INFO    : Bus 11504	: V=1.0086269, theta=-59.101717 -> V=1.0, theta=0.0
% INFO    : Bus 11505	: V=1.0079387, theta=-59.213951 -> V=1.0, theta=0.0
% INFO    : Bus 11506	: V=0.9904501, theta=-61.853441 -> V=1.0, theta=0.0
% INFO    : Bus 11507	: V=0.989516, theta=-61.865308 -> V=1.0, theta=0.0
% INFO    : Bus 11508	: V=1.002087, theta=-60.163562 -> V=1.0, theta=0.0
% INFO    : Bus 11509	: V=0.9991444, theta=-60.240005 -> V=1.0, theta=0.0
% INFO    : Bus 11510	: V=0.9917207, theta=-61.813627 -> V=1.0, theta=0.0
% INFO    : Bus 11511	: V=1.005658, theta=-59.39835 -> V=1.0, theta=0.0
% INFO    : Bus 11512	: V=1.0038595, theta=-59.699768 -> V=1.0, theta=0.0
% INFO    : Bus 11513	: V=1.0043652, theta=-59.608091 -> V=1.0, theta=0.0
% INFO    : Bus 11514	: V=1.0016688, theta=-59.976978 -> V=1.0, theta=0.0
% INFO    : Bus 11515	: V=1.0099549, theta=-59.035927 -> V=1.0, theta=0.0
% INFO    : Bus 11516	: V=1.0086162, theta=-59.512481 -> V=1.0, theta=0.0
% INFO    : Bus 11517	: V=1.0070471, theta=-60.491534 -> V=1.0, theta=0.0
% INFO    : Bus 11518	: V=1.0008137, theta=-60.630525 -> V=1.0, theta=0.0
% INFO    : Bus 11519	: V=1.0012382, theta=-60.531345 -> V=1.0, theta=0.0
% INFO    : Bus 11520	: V=0.9972241, theta=-62.408185 -> V=1.0, theta=0.0
% INFO    : Bus 11521	: V=0.9844125, theta=-64.033868 -> V=1.0, theta=0.0
% INFO    : Bus 11522	: V=0.9869137, theta=-63.653711 -> V=1.0, theta=0.0
% INFO    : Bus 11523	: V=0.9988448, theta=-61.415506 -> V=1.0, theta=0.0
% INFO    : Bus 11524	: V=0.9995047, theta=-61.064918 -> V=1.0, theta=0.0
% INFO    : Bus 11525	: V=1.0065942, theta=-60.855935 -> V=1.0, theta=0.0
% INFO    : Bus 11526	: V=1.0074523, theta=-60.86039 -> V=1.0, theta=0.0
% INFO    : Bus 11527	: V=1.0022326, theta=-61.36293 -> V=1.0, theta=0.0
% INFO    : Bus 11528	: V=0.9988999, theta=-61.741912 -> V=1.0, theta=0.0
% INFO    : Bus 11529	: V=1.0030125, theta=-61.130455 -> V=1.0, theta=0.0
% INFO    : Bus 11530	: V=1.0027708, theta=-61.09917 -> V=1.0, theta=0.0
% INFO    : Bus 11531	: V=0.9963537, theta=-61.856839 -> V=1.0, theta=0.0
% INFO    : Bus 11532	: V=1.002788, theta=-60.662873 -> V=1.0, theta=0.0
% INFO    : Bus 11533	: V=1.0020733, theta=-60.083846 -> V=1.0, theta=0.0
% INFO    : Bus 11534	: V=1.0092604, theta=-58.997176 -> V=1.0, theta=0.0
% INFO    : Bus 11535	: V=0.9971489, theta=-60.656116 -> V=1.0, theta=0.0
% INFO    : Bus 11536	: V=1.0103707, theta=-58.819853 -> V=1.0, theta=0.0
% INFO    : Bus 11537	: V=0.998077, theta=-60.328466 -> V=1.0, theta=0.0
% INFO    : Bus 11538	: V=0.9491375, theta=-74.770279 -> V=1.0, theta=0.0
% INFO    : Bus 11539	: V=0.936547, theta=-77.191307 -> V=1.0, theta=0.0
% INFO    : Bus 11540	: V=0.9802299, theta=-62.716094 -> V=1.0, theta=0.0
% INFO    : Bus 11541	: V=0.9885398, theta=-61.937366 -> V=1.0, theta=0.0
% INFO    : Bus 11542	: V=0.9853761, theta=-62.590777 -> V=1.0, theta=0.0
% INFO    : Bus 11543	: V=0.9828434, theta=-62.988948 -> V=1.0, theta=0.0
% INFO    : Bus 11544	: V=1.0080335, theta=-58.762683 -> V=1.0, theta=0.0
% INFO    : Bus 11545	: V=1.0016933, theta=-60.358471 -> V=1.0, theta=0.0
% INFO    : Bus 11546	: V=1.0049325, theta=-59.887033 -> V=1.0, theta=0.0
% INFO    : Bus 11547	: V=0.9968724, theta=-61.097839 -> V=1.0, theta=0.0
% INFO    : Bus 11548	: V=0.9954369, theta=-61.34625 -> V=1.0, theta=0.0
% INFO    : Bus 11549	: V=0.9948517, theta=-61.501311 -> V=1.0, theta=0.0
% INFO    : Bus 11550	: V=0.9944762, theta=-61.676136 -> V=1.0, theta=0.0
% INFO    : Bus 11551	: V=1.0141185, theta=-58.50288 -> V=1.0, theta=0.0
% INFO    : Bus 11552	: V=0.9646812, theta=-70.489048 -> V=1.0, theta=0.0
% INFO    : Bus 11553	: V=0.9746428, theta=-68.567242 -> V=1.0, theta=0.0
% INFO    : Bus 11554	: V=0.9816863, theta=-65.720953 -> V=1.0, theta=0.0
% INFO    : Bus 11555	: V=0.979501, theta=-65.989887 -> V=1.0, theta=0.0
% INFO    : Bus 11556	: V=0.9709137, theta=-67.263175 -> V=1.0, theta=0.0
% INFO    : Bus 11557	: V=0.9597726, theta=-68.130731 -> V=1.0, theta=0.0
% INFO    : Bus 11558	: V=0.9712572, theta=-68.00179 -> V=1.0, theta=0.0
% INFO    : Bus 11559	: V=0.9692809, theta=-68.969362 -> V=1.0, theta=0.0
% INFO    : Bus 11560	: V=0.9676918, theta=-68.130271 -> V=1.0, theta=0.0
% INFO    : Bus 11561	: V=0.9823855, theta=-65.628183 -> V=1.0, theta=0.0
% INFO    : Bus 11562	: V=0.9685755, theta=-67.703964 -> V=1.0, theta=0.0
% INFO    : Bus 11563	: V=0.9656434, theta=-68.106853 -> V=1.0, theta=0.0
% INFO    : Bus 11564	: V=0.9656688, theta=-68.047669 -> V=1.0, theta=0.0
% INFO    : Bus 11565	: V=0.9667072, theta=-67.901584 -> V=1.0, theta=0.0
% INFO    : Bus 11566	: V=0.9630147, theta=-68.157941 -> V=1.0, theta=0.0
% INFO    : Bus 11567	: V=0.9643849, theta=-68.180617 -> V=1.0, theta=0.0
% INFO    : Bus 11568	: V=0.9644905, theta=-68.154758 -> V=1.0, theta=0.0
% INFO    : Bus 11569	: V=0.9637903, theta=-68.205715 -> V=1.0, theta=0.0
% INFO    : Bus 11570	: V=0.9632983, theta=-68.202806 -> V=1.0, theta=0.0
% INFO    : Bus 11571	: V=0.9574274, theta=-68.732775 -> V=1.0, theta=0.0
% INFO    : Bus 11572	: V=0.9644446, theta=-67.801086 -> V=1.0, theta=0.0
% INFO    : Bus 11573	: V=0.9553053, theta=-69.336213 -> V=1.0, theta=0.0
% INFO    : Bus 11574	: V=0.9555108, theta=-69.303681 -> V=1.0, theta=0.0
% INFO    : Bus 11575	: V=0.9641065, theta=-68.202275 -> V=1.0, theta=0.0
% INFO    : Bus 11576	: V=0.9641825, theta=-68.196641 -> V=1.0, theta=0.0
% INFO    : Bus 11577	: V=0.9628412, theta=-68.222745 -> V=1.0, theta=0.0
% INFO    : Bus 11578	: V=0.9628958, theta=-68.239482 -> V=1.0, theta=0.0
% INFO    : Bus 11579	: V=0.9554344, theta=-69.302705 -> V=1.0, theta=0.0
% INFO    : Bus 11580	: V=0.954426, theta=-69.356148 -> V=1.0, theta=0.0
% INFO    : Bus 11581	: V=0.9628728, theta=-68.198629 -> V=1.0, theta=0.0
% INFO    : Bus 11582	: V=0.9624882, theta=-68.356174 -> V=1.0, theta=0.0
% INFO    : Bus 11583	: V=0.9810706, theta=-62.910325 -> V=1.0, theta=0.0
% INFO    : Bus 11584	: V=0.9881538, theta=-61.477593 -> V=1.0, theta=0.0
% INFO    : Bus 11585	: V=0.982135, theta=-62.606284 -> V=1.0, theta=0.0
% INFO    : Bus 11586	: V=0.9845862, theta=-62.456325 -> V=1.0, theta=0.0
% INFO    : Bus 11587	: V=0.9890018, theta=-62.181357 -> V=1.0, theta=0.0
% INFO    : Bus 11588	: V=0.9796146, theta=-62.929117 -> V=1.0, theta=0.0
% INFO    : Bus 11589	: V=0.9796876, theta=-63.026588 -> V=1.0, theta=0.0
% INFO    : Bus 11590	: V=0.9812323, theta=-62.739714 -> V=1.0, theta=0.0
% INFO    : Bus 11591	: V=0.9873165, theta=-61.456681 -> V=1.0, theta=0.0
% INFO    : Bus 11592	: V=0.9858707, theta=-61.362454 -> V=1.0, theta=0.0
% INFO    : Bus 11593	: V=0.9877735, theta=-61.44613 -> V=1.0, theta=0.0
% INFO    : Bus 11594	: V=0.9885734, theta=-61.461386 -> V=1.0, theta=0.0
% INFO    : Bus 11595	: V=0.9881285, theta=-61.459952 -> V=1.0, theta=0.0
% INFO    : Bus 11596	: V=1.0070388, theta=-60.721863 -> V=1.0, theta=0.0
% INFO    : Bus 11597	: V=0.989201, theta=-62.395633 -> V=1.0, theta=0.0
% INFO    : Bus 11598	: V=1.0094498, theta=-60.665006 -> V=1.0, theta=0.0
% INFO    : Bus 11599	: V=1.0098817, theta=-60.590494 -> V=1.0, theta=0.0
% INFO    : Bus 11600	: V=0.9915165, theta=-62.325858 -> V=1.0, theta=0.0
% INFO    : Bus 11601	: V=1.0090264, theta=-60.63503 -> V=1.0, theta=0.0
% INFO    : Bus 11602	: V=0.9989383, theta=-60.977181 -> V=1.0, theta=0.0
% INFO    : Bus 11603	: V=1.0121104, theta=-60.180454 -> V=1.0, theta=0.0
% INFO    : Bus 11604	: V=1.0054175, theta=-60.510782 -> V=1.0, theta=0.0
% INFO    : Bus 11605	: V=0.9899021, theta=-63.26651 -> V=1.0, theta=0.0
% INFO    : Bus 11606	: V=0.9973462, theta=-62.790758 -> V=1.0, theta=0.0
% INFO    : Bus 11607	: V=0.9954089, theta=-62.804965 -> V=1.0, theta=0.0
% INFO    : Bus 11608	: V=0.9850811, theta=-63.655288 -> V=1.0, theta=0.0
% INFO    : Bus 11609	: V=0.9808877, theta=-63.749847 -> V=1.0, theta=0.0
% INFO    : Bus 11610	: V=0.9891518, theta=-62.613084 -> V=1.0, theta=0.0
% INFO    : Bus 11611	: V=0.9833027, theta=-62.963453 -> V=1.0, theta=0.0
% INFO    : Bus 11612	: V=0.9850836, theta=-62.112859 -> V=1.0, theta=0.0
% INFO    : Bus 11613	: V=1.0156025, theta=-58.138395 -> V=1.0, theta=0.0
% INFO    : Bus 11614	: V=0.9907619, theta=-61.288078 -> V=1.0, theta=0.0
% INFO    : Bus 11615	: V=0.9822187, theta=-62.27676 -> V=1.0, theta=0.0
% INFO    : Bus 11616	: V=0.9831401, theta=-62.003293 -> V=1.0, theta=0.0
% INFO    : Bus 11617	: V=0.984489, theta=-61.692111 -> V=1.0, theta=0.0
% INFO    : Bus 11618	: V=0.9855755, theta=-61.438433 -> V=1.0, theta=0.0
% INFO    : Bus 11619	: V=0.9749606, theta=-62.904268 -> V=1.0, theta=0.0
% INFO    : Bus 11620	: V=0.9863701, theta=-61.196242 -> V=1.0, theta=0.0
% INFO    : Bus 11621	: V=0.9862686, theta=-61.282688 -> V=1.0, theta=0.0
% INFO    : Bus 11622	: V=0.9875562, theta=-61.271088 -> V=1.0, theta=0.0
% INFO    : Bus 11623	: V=0.9846056, theta=-61.659128 -> V=1.0, theta=0.0
% INFO    : Bus 11624	: V=0.9789037, theta=-62.057177 -> V=1.0, theta=0.0
% INFO    : Bus 11625	: V=0.9870712, theta=-61.278102 -> V=1.0, theta=0.0
% INFO    : Bus 11626	: V=0.9951541, theta=-59.621799 -> V=1.0, theta=0.0
% INFO    : Bus 11627	: V=0.9886806, theta=-61.312653 -> V=1.0, theta=0.0
% INFO    : Bus 11628	: V=0.9894113, theta=-61.306231 -> V=1.0, theta=0.0
% INFO    : Bus 11629	: V=0.9870928, theta=-61.393964 -> V=1.0, theta=0.0
% INFO    : Bus 11630	: V=0.9868614, theta=-61.365478 -> V=1.0, theta=0.0
% INFO    : Bus 11631	: V=0.9849544, theta=-61.491436 -> V=1.0, theta=0.0
% INFO    : Bus 11632	: V=0.9850195, theta=-61.298 -> V=1.0, theta=0.0
% INFO    : Bus 11633	: V=0.984581, theta=-61.324783 -> V=1.0, theta=0.0
% INFO    : Bus 11634	: V=0.985858, theta=-61.136848 -> V=1.0, theta=0.0
% INFO    : Bus 11635	: V=0.9827121, theta=-60.176737 -> V=1.0, theta=0.0
% INFO    : Bus 11636	: V=0.981717, theta=-61.05488 -> V=1.0, theta=0.0
% INFO    : Bus 11637	: V=0.9824912, theta=-60.21233 -> V=1.0, theta=0.0
% INFO    : Bus 11638	: V=0.9800624, theta=-60.735424 -> V=1.0, theta=0.0
% INFO    : Bus 11639	: V=0.9844952, theta=-60.669992 -> V=1.0, theta=0.0
% INFO    : Bus 11640	: V=0.976495, theta=-61.062543 -> V=1.0, theta=0.0
% INFO    : Bus 11641	: V=0.967134, theta=-63.898455 -> V=1.0, theta=0.0
% INFO    : Bus 11642	: V=0.9660169, theta=-64.116867 -> V=1.0, theta=0.0
% INFO    : Bus 11643	: V=0.9856512, theta=-61.082177 -> V=1.0, theta=0.0
% INFO    : Bus 11644	: V=0.9702293, theta=-63.503517 -> V=1.0, theta=0.0
% INFO    : Bus 11645	: V=0.9744356, theta=-62.644431 -> V=1.0, theta=0.0
% INFO    : Bus 11646	: V=0.974742, theta=-62.608016 -> V=1.0, theta=0.0
% INFO    : Bus 11647	: V=0.952962, theta=-66.138755 -> V=1.0, theta=0.0
% INFO    : Bus 11648	: V=0.9723831, theta=-62.849147 -> V=1.0, theta=0.0
% INFO    : Bus 11649	: V=0.9646831, theta=-64.414496 -> V=1.0, theta=0.0
% INFO    : Bus 11650	: V=0.9796983, theta=-63.148024 -> V=1.0, theta=0.0
% INFO    : Bus 11651	: V=0.9797499, theta=-62.622052 -> V=1.0, theta=0.0
% INFO    : Bus 11652	: V=0.9722151, theta=-63.473227 -> V=1.0, theta=0.0
% INFO    : Bus 11653	: V=0.9774197, theta=-62.963647 -> V=1.0, theta=0.0
% INFO    : Bus 11654	: V=0.9752856, theta=-63.354187 -> V=1.0, theta=0.0
% INFO    : Bus 11655	: V=0.9751261, theta=-63.348588 -> V=1.0, theta=0.0
% INFO    : Bus 11656	: V=0.9724292, theta=-63.813585 -> V=1.0, theta=0.0
% INFO    : Bus 11657	: V=0.9673577, theta=-64.351062 -> V=1.0, theta=0.0
% INFO    : Bus 11658	: V=0.9589034, theta=-65.476682 -> V=1.0, theta=0.0
% INFO    : Bus 11659	: V=0.9711893, theta=-62.920163 -> V=1.0, theta=0.0
% INFO    : Bus 11660	: V=0.9713899, theta=-62.905674 -> V=1.0, theta=0.0
% INFO    : Bus 11661	: V=0.972451, theta=-62.494474 -> V=1.0, theta=0.0
% INFO    : Bus 11662	: V=0.9722946, theta=-62.546575 -> V=1.0, theta=0.0
% INFO    : Bus 11663	: V=0.9674558, theta=-63.2325 -> V=1.0, theta=0.0
% INFO    : Bus 11664	: V=0.9665348, theta=-63.25478 -> V=1.0, theta=0.0
% INFO    : Bus 11665	: V=0.9668387, theta=-63.241901 -> V=1.0, theta=0.0
% INFO    : Bus 11666	: V=0.9681732, theta=-63.046417 -> V=1.0, theta=0.0
% INFO    : Bus 11667	: V=0.9859643, theta=-59.75862 -> V=1.0, theta=0.0
% INFO    : Bus 11668	: V=0.9785969, theta=-60.039808 -> V=1.0, theta=0.0
% INFO    : Bus 11669	: V=0.9737347, theta=-60.34993 -> V=1.0, theta=0.0
% INFO    : Bus 11670	: V=0.9834692, theta=-60.071362 -> V=1.0, theta=0.0
% INFO    : Bus 11671	: V=0.9822701, theta=-59.452901 -> V=1.0, theta=0.0
% INFO    : Bus 11672	: V=0.9829412, theta=-59.490192 -> V=1.0, theta=0.0
% INFO    : Bus 11673	: V=0.9840962, theta=-59.323882 -> V=1.0, theta=0.0
% INFO    : Bus 11674	: V=0.9886906, theta=-58.924269 -> V=1.0, theta=0.0
% INFO    : Bus 11675	: V=0.987065, theta=-59.470325 -> V=1.0, theta=0.0
% INFO    : Bus 11676	: V=0.966728, theta=-62.893316 -> V=1.0, theta=0.0
% INFO    : Bus 11677	: V=0.9685565, theta=-62.850665 -> V=1.0, theta=0.0
% INFO    : Bus 11678	: V=0.9738587, theta=-62.204911 -> V=1.0, theta=0.0
% INFO    : Bus 11679	: V=0.9705866, theta=-62.784087 -> V=1.0, theta=0.0
% INFO    : Bus 11680	: V=0.9803685, theta=-60.95754 -> V=1.0, theta=0.0
% INFO    : Bus 11681	: V=0.9730157, theta=-60.839128 -> V=1.0, theta=0.0
% INFO    : Bus 11682	: V=0.9754107, theta=-60.80693 -> V=1.0, theta=0.0
% INFO    : Bus 11683	: V=0.9908941, theta=-58.739483 -> V=1.0, theta=0.0
% INFO    : Bus 11684	: V=0.9897194, theta=-58.840645 -> V=1.0, theta=0.0
% INFO    : Bus 11685	: V=0.9923737, theta=-58.550942 -> V=1.0, theta=0.0
% INFO    : Bus 11686	: V=0.9951974, theta=-58.17617 -> V=1.0, theta=0.0
% INFO    : Bus 11687	: V=0.9865645, theta=-61.217361 -> V=1.0, theta=0.0
% INFO    : Bus 11688	: V=1.0018038, theta=-60.7699 -> V=1.0, theta=0.0
% INFO    : Bus 11689	: V=0.9843717, theta=-61.016954 -> V=1.0, theta=0.0
% INFO    : Bus 11690	: V=0.9748488, theta=-61.093493 -> V=1.0, theta=0.0
% INFO    : Bus 11691	: V=0.9849535, theta=-60.914218 -> V=1.0, theta=0.0
% INFO    : Bus 11692	: V=0.9718376, theta=-62.828243 -> V=1.0, theta=0.0
% INFO    : Bus 11693	: V=0.9714814, theta=-62.876346 -> V=1.0, theta=0.0
% INFO    : Bus 11694	: V=0.9700484, theta=-64.053508 -> V=1.0, theta=0.0
% INFO    : Bus 11695	: V=0.9700751, theta=-64.073561 -> V=1.0, theta=0.0
% INFO    : Bus 11696	: V=0.9700427, theta=-62.961386 -> V=1.0, theta=0.0
% INFO    : Bus 11697	: V=0.9855376, theta=-59.876087 -> V=1.0, theta=0.0
% INFO    : Bus 11698	: V=0.9755019, theta=-61.888805 -> V=1.0, theta=0.0
% INFO    : Bus 11699	: V=0.9924757, theta=-69.180598 -> V=1.0, theta=0.0
% INFO    : Bus 11700	: V=0.9816707, theta=-68.769388 -> V=1.0, theta=0.0
% INFO    : Bus 11701	: V=0.9777252, theta=-69.240169 -> V=1.0, theta=0.0
% INFO    : Bus 11702	: V=0.9810307, theta=-69.424543 -> V=1.0, theta=0.0
% INFO    : Bus 11703	: V=0.9931629, theta=-67.864068 -> V=1.0, theta=0.0
% INFO    : Bus 11704	: V=0.9949146, theta=-67.038548 -> V=1.0, theta=0.0
% INFO    : Bus 11705	: V=0.9966249, theta=-67.678742 -> V=1.0, theta=0.0
% INFO    : Bus 11706	: V=1.0050018, theta=-65.87286 -> V=1.0, theta=0.0
% INFO    : Bus 11707	: V=1.006874, theta=-66.06967 -> V=1.0, theta=0.0
% INFO    : Bus 11708	: V=0.9878311, theta=-67.4171 -> V=1.0, theta=0.0
% INFO    : Bus 11709	: V=1.0101319, theta=-61.217706 -> V=1.0, theta=0.0
% INFO    : Bus 11710	: V=1.0099407, theta=-61.260275 -> V=1.0, theta=0.0
% INFO    : Bus 11711	: V=1.0071924, theta=-62.125571 -> V=1.0, theta=0.0
% INFO    : Bus 11712	: V=1.0018875, theta=-63.485451 -> V=1.0, theta=0.0
% INFO    : Bus 11713	: V=1.0000215, theta=-63.803029 -> V=1.0, theta=0.0
% INFO    : Bus 11714	: V=0.9945206, theta=-64.904183 -> V=1.0, theta=0.0
% INFO    : Bus 11715	: V=0.9890277, theta=-64.96184 -> V=1.0, theta=0.0
% INFO    : Bus 11716	: V=0.9882283, theta=-66.232473 -> V=1.0, theta=0.0
% INFO    : Bus 11717	: V=0.9854261, theta=-65.256102 -> V=1.0, theta=0.0
% INFO    : Bus 11718	: V=0.99039, theta=-64.59504 -> V=1.0, theta=0.0
% INFO    : Bus 11719	: V=0.9987434, theta=-64.21244 -> V=1.0, theta=0.0
% INFO    : Bus 11720	: V=0.9887059, theta=-65.889228 -> V=1.0, theta=0.0
% INFO    : Bus 11721	: V=0.9980703, theta=-64.142124 -> V=1.0, theta=0.0
% INFO    : Bus 11722	: V=0.9975205, theta=-63.792538 -> V=1.0, theta=0.0
% INFO    : Bus 11723	: V=0.9985149, theta=-64.139567 -> V=1.0, theta=0.0
% INFO    : Bus 11724	: V=0.9975026, theta=-63.414139 -> V=1.0, theta=0.0
% INFO    : Bus 11725	: V=0.9918317, theta=-63.830061 -> V=1.0, theta=0.0
% INFO    : Bus 11726	: V=0.9888435, theta=-64.280356 -> V=1.0, theta=0.0
% INFO    : Bus 11727	: V=0.9919236, theta=-63.513161 -> V=1.0, theta=0.0
% INFO    : Bus 11728	: V=0.9977294, theta=-62.915875 -> V=1.0, theta=0.0
% INFO    : Bus 11729	: V=0.9454683, theta=-74.244483 -> V=1.0, theta=0.0
% INFO    : Bus 11730	: V=0.960048, theta=-71.482492 -> V=1.0, theta=0.0
% INFO    : Bus 11731	: V=0.9424804, theta=-73.108244 -> V=1.0, theta=0.0
% INFO    : Bus 11732	: V=0.9408694, theta=-75.009042 -> V=1.0, theta=0.0
% INFO    : Bus 11733	: V=0.9595216, theta=-71.773536 -> V=1.0, theta=0.0
% INFO    : Bus 11734	: V=0.9451714, theta=-74.398369 -> V=1.0, theta=0.0
% INFO    : Bus 11735	: V=0.9586293, theta=-71.881188 -> V=1.0, theta=0.0
% INFO    : Bus 11736	: V=0.9386019, theta=-74.836722 -> V=1.0, theta=0.0
% INFO    : Bus 11737	: V=0.9392977, theta=-74.820454 -> V=1.0, theta=0.0
% INFO    : Bus 11738	: V=0.973796, theta=-64.034735 -> V=1.0, theta=0.0
% INFO    : Bus 11739	: V=0.9562588, theta=-69.613714 -> V=1.0, theta=0.0
% INFO    : Bus 11740	: V=0.9601556, theta=-69.468363 -> V=1.0, theta=0.0
% INFO    : Bus 11741	: V=0.9608547, theta=-68.324073 -> V=1.0, theta=0.0
% INFO    : Bus 11742	: V=0.9666661, theta=-65.296474 -> V=1.0, theta=0.0
% INFO    : Bus 11743	: V=0.9839706, theta=-62.766221 -> V=1.0, theta=0.0
% INFO    : Bus 11744	: V=0.981921, theta=-63.160919 -> V=1.0, theta=0.0
% INFO    : Bus 11745	: V=0.9736269, theta=-65.028632 -> V=1.0, theta=0.0
% INFO    : Bus 11746	: V=0.9660904, theta=-68.228306 -> V=1.0, theta=0.0
% INFO    : Bus 11747	: V=0.9685172, theta=-69.440313 -> V=1.0, theta=0.0
% INFO    : Bus 11748	: V=0.9679175, theta=-69.439714 -> V=1.0, theta=0.0
% INFO    : Bus 11749	: V=0.9626811, theta=-69.159197 -> V=1.0, theta=0.0
% INFO    : Bus 11750	: V=0.964873, theta=-68.636068 -> V=1.0, theta=0.0
% INFO    : Bus 11751	: V=0.9780024, theta=-63.979959 -> V=1.0, theta=0.0
% INFO    : Bus 11752	: V=0.9594428, theta=-69.009301 -> V=1.0, theta=0.0
% INFO    : Bus 11753	: V=0.9433907, theta=-76.130019 -> V=1.0, theta=0.0
% INFO    : Bus 11754	: V=0.9468254, theta=-74.286438 -> V=1.0, theta=0.0
% INFO    : Bus 11755	: V=0.9696676, theta=-71.887197 -> V=1.0, theta=0.0
% INFO    : Bus 11756	: V=0.9483192, theta=-71.329465 -> V=1.0, theta=0.0
% INFO    : Bus 11757	: V=0.9481096, theta=-71.025082 -> V=1.0, theta=0.0
% INFO    : Bus 11758	: V=0.9398428, theta=-73.110823 -> V=1.0, theta=0.0
% INFO    : Bus 11759	: V=0.9459053, theta=-72.230373 -> V=1.0, theta=0.0
% INFO    : Bus 11760	: V=0.941665, theta=-75.379951 -> V=1.0, theta=0.0
% INFO    : Bus 11761	: V=0.9507495, theta=-72.917153 -> V=1.0, theta=0.0
% INFO    : Bus 11762	: V=0.9793009, theta=-71.116088 -> V=1.0, theta=0.0
% INFO    : Bus 11763	: V=0.9595677, theta=-72.140953 -> V=1.0, theta=0.0
% INFO    : Bus 11764	: V=0.9566385, theta=-75.153587 -> V=1.0, theta=0.0
% INFO    : Bus 11765	: V=0.9719797, theta=-72.261848 -> V=1.0, theta=0.0
% INFO    : Bus 11766	: V=0.9590644, theta=-74.798463 -> V=1.0, theta=0.0
% INFO    : Bus 11767	: V=0.9619281, theta=-72.186552 -> V=1.0, theta=0.0
% INFO    : Bus 11768	: V=0.9504495, theta=-72.811434 -> V=1.0, theta=0.0
% INFO    : Bus 11769	: V=0.948635, theta=-72.889393 -> V=1.0, theta=0.0
% INFO    : Bus 11770	: V=0.9476433, theta=-72.917133 -> V=1.0, theta=0.0
% INFO    : Bus 11771	: V=0.9436909, theta=-74.836229 -> V=1.0, theta=0.0
% INFO    : Bus 11772	: V=0.9459454, theta=-72.691769 -> V=1.0, theta=0.0
% INFO    : Bus 11773	: V=0.9473359, theta=-71.306556 -> V=1.0, theta=0.0
% INFO    : Bus 11774	: V=0.9509406, theta=-69.819803 -> V=1.0, theta=0.0
% INFO    : Bus 11775	: V=0.9496659, theta=-70.361952 -> V=1.0, theta=0.0
% INFO    : Bus 11776	: V=0.966401, theta=-64.857847 -> V=1.0, theta=0.0
% INFO    : Bus 11777	: V=0.9676221, theta=-64.749381 -> V=1.0, theta=0.0
% INFO    : Bus 11778	: V=0.9855853, theta=-62.535159 -> V=1.0, theta=0.0
% INFO    : Bus 11779	: V=0.9807707, theta=-63.004143 -> V=1.0, theta=0.0
% INFO    : Bus 11780	: V=0.9847119, theta=-62.620746 -> V=1.0, theta=0.0
% INFO    : Bus 11781	: V=0.9836881, theta=-63.151525 -> V=1.0, theta=0.0
% INFO    : Bus 11782	: V=0.981552, theta=-63.127977 -> V=1.0, theta=0.0
% INFO    : Bus 11783	: V=0.9787311, theta=-63.486023 -> V=1.0, theta=0.0
% INFO    : Bus 11784	: V=0.9749706, theta=-63.790903 -> V=1.0, theta=0.0
% INFO    : Bus 11785	: V=0.9803819, theta=-63.137423 -> V=1.0, theta=0.0
% INFO    : Bus 11786	: V=0.9810953, theta=-63.06692 -> V=1.0, theta=0.0
% INFO    : Bus 11787	: V=0.9775907, theta=-63.710559 -> V=1.0, theta=0.0
% INFO    : Bus 11788	: V=0.9908466, theta=-61.860096 -> V=1.0, theta=0.0
% INFO    : Bus 11789	: V=0.995114, theta=-61.527719 -> V=1.0, theta=0.0
% INFO    : Bus 11790	: V=0.985359, theta=-62.833976 -> V=1.0, theta=0.0
% INFO    : Bus 11791	: V=0.9787936, theta=-63.219151 -> V=1.0, theta=0.0
% INFO    : Bus 11792	: V=0.9929132, theta=-61.784418 -> V=1.0, theta=0.0
% INFO    : Bus 11793	: V=0.9895266, theta=-62.129163 -> V=1.0, theta=0.0
% INFO    : Bus 11794	: V=1.0054807, theta=-59.602584 -> V=1.0, theta=0.0
% INFO    : Bus 11795	: V=1.0149294, theta=-57.921001 -> V=1.0, theta=0.0
% INFO    : Bus 11796	: V=0.9904628, theta=-62.062536 -> V=1.0, theta=0.0
% INFO    : Bus 11797	: V=0.9888596, theta=-62.1236 -> V=1.0, theta=0.0
% INFO    : Bus 11798	: V=0.9933463, theta=-61.644906 -> V=1.0, theta=0.0
% INFO    : Bus 11799	: V=0.9891082, theta=-61.977275 -> V=1.0, theta=0.0
% INFO    : Bus 11800	: V=0.9907676, theta=-61.948272 -> V=1.0, theta=0.0
% INFO    : Bus 11801	: V=0.9843497, theta=-62.474701 -> V=1.0, theta=0.0
% INFO    : Bus 11802	: V=0.9932051, theta=-61.759908 -> V=1.0, theta=0.0
% INFO    : Bus 11803	: V=0.9998714, theta=-60.736724 -> V=1.0, theta=0.0
% INFO    : Bus 11804	: V=0.99398, theta=-61.665773 -> V=1.0, theta=0.0
% INFO    : Bus 11805	: V=0.9852407, theta=-62.395332 -> V=1.0, theta=0.0
% INFO    : Bus 11806	: V=0.9948482, theta=-61.522057 -> V=1.0, theta=0.0
% INFO    : Bus 11807	: V=0.9956132, theta=-61.421439 -> V=1.0, theta=0.0
% INFO    : Bus 11808	: V=0.9895221, theta=-62.219669 -> V=1.0, theta=0.0
% INFO    : Bus 11809	: V=0.9903055, theta=-62.1404 -> V=1.0, theta=0.0
% INFO    : Bus 11810	: V=0.9914952, theta=-62.012119 -> V=1.0, theta=0.0
% INFO    : Bus 11811	: V=0.9990339, theta=-60.618712 -> V=1.0, theta=0.0
% INFO    : Bus 11812	: V=0.9890592, theta=-62.107737 -> V=1.0, theta=0.0
% INFO    : Bus 11813	: V=0.9882338, theta=-62.244188 -> V=1.0, theta=0.0
% INFO    : Bus 11814	: V=0.9981113, theta=-61.518878 -> V=1.0, theta=0.0
% INFO    : Bus 11815	: V=0.9859703, theta=-62.134024 -> V=1.0, theta=0.0
% INFO    : Bus 11816	: V=0.9859867, theta=-61.87782 -> V=1.0, theta=0.0
% INFO    : Bus 11817	: V=0.9990903, theta=-60.046328 -> V=1.0, theta=0.0
% INFO    : Bus 11818	: V=0.9969254, theta=-60.293376 -> V=1.0, theta=0.0
% INFO    : Bus 11819	: V=1.0005868, theta=-60.509866 -> V=1.0, theta=0.0
% INFO    : Bus 11820	: V=0.9960453, theta=-59.830346 -> V=1.0, theta=0.0
% INFO    : Bus 11821	: V=0.9958875, theta=-59.789715 -> V=1.0, theta=0.0
% INFO    : Bus 11822	: V=0.996362, theta=-59.695659 -> V=1.0, theta=0.0
% INFO    : Bus 11823	: V=0.9824357, theta=-62.933058 -> V=1.0, theta=0.0
% INFO    : Bus 11824	: V=0.9894077, theta=-61.969959 -> V=1.0, theta=0.0
% INFO    : Bus 11825	: V=0.9761437, theta=-63.804025 -> V=1.0, theta=0.0
% INFO    : Bus 11826	: V=0.9762521, theta=-64.025564 -> V=1.0, theta=0.0
% INFO    : Bus 11827	: V=0.976048, theta=-64.022395 -> V=1.0, theta=0.0
% INFO    : Bus 11828	: V=0.9828255, theta=-62.810745 -> V=1.0, theta=0.0
% INFO    : Bus 11829	: V=0.9824535, theta=-62.842259 -> V=1.0, theta=0.0
% INFO    : Bus 11830	: V=0.9818625, theta=-62.892528 -> V=1.0, theta=0.0
% INFO    : Bus 11831	: V=0.9815445, theta=-62.916233 -> V=1.0, theta=0.0
% INFO    : Bus 11832	: V=0.971063, theta=-64.526777 -> V=1.0, theta=0.0
% INFO    : Bus 11833	: V=0.9774234, theta=-63.518155 -> V=1.0, theta=0.0
% INFO    : Bus 11834	: V=0.97669, theta=-63.997901 -> V=1.0, theta=0.0
% INFO    : Bus 11835	: V=0.9750565, theta=-63.941569 -> V=1.0, theta=0.0
% INFO    : Bus 11836	: V=0.9791437, theta=-63.455247 -> V=1.0, theta=0.0
% INFO    : Bus 11837	: V=0.9796627, theta=-63.819383 -> V=1.0, theta=0.0
% INFO    : Bus 11838	: V=0.9758583, theta=-63.995513 -> V=1.0, theta=0.0
% INFO    : Bus 11839	: V=0.9735194, theta=-64.105663 -> V=1.0, theta=0.0
% INFO    : Bus 11840	: V=0.967137, theta=-64.776171 -> V=1.0, theta=0.0
% INFO    : Bus 11841	: V=0.9629047, theta=-64.861761 -> V=1.0, theta=0.0
% INFO    : Bus 11842	: V=0.9658299, theta=-65.061383 -> V=1.0, theta=0.0
% INFO    : Bus 11843	: V=0.9630099, theta=-65.112293 -> V=1.0, theta=0.0
% INFO    : Bus 11844	: V=0.965057, theta=-65.136185 -> V=1.0, theta=0.0
% INFO    : Bus 11845	: V=0.9717764, theta=-64.277096 -> V=1.0, theta=0.0
% INFO    : Bus 11846	: V=0.9724776, theta=-64.209537 -> V=1.0, theta=0.0
% INFO    : Bus 11847	: V=0.9759904, theta=-63.656786 -> V=1.0, theta=0.0
% INFO    : Bus 11848	: V=0.9588421, theta=-66.150989 -> V=1.0, theta=0.0
% INFO    : Bus 11849	: V=0.9620971, theta=-65.868662 -> V=1.0, theta=0.0
% INFO    : Bus 11850	: V=0.9543849, theta=-66.521329 -> V=1.0, theta=0.0
% INFO    : Bus 11851	: V=0.9495126, theta=-66.801777 -> V=1.0, theta=0.0
% INFO    : Bus 11852	: V=0.9703006, theta=-64.403919 -> V=1.0, theta=0.0
% INFO    : Bus 11853	: V=0.9642033, theta=-65.291618 -> V=1.0, theta=0.0
% INFO    : Bus 11854	: V=0.9703058, theta=-64.420109 -> V=1.0, theta=0.0
% INFO    : Bus 11855	: V=0.9708465, theta=-64.364147 -> V=1.0, theta=0.0
% INFO    : Bus 11856	: V=0.9634467, theta=-65.214271 -> V=1.0, theta=0.0
% INFO    : Bus 11857	: V=0.9697706, theta=-65.046762 -> V=1.0, theta=0.0
% INFO    : Bus 11858	: V=0.9780343, theta=-63.436943 -> V=1.0, theta=0.0
% INFO    : Bus 11859	: V=0.9790278, theta=-63.359812 -> V=1.0, theta=0.0
% INFO    : Bus 11860	: V=0.961852, theta=-65.666847 -> V=1.0, theta=0.0
% INFO    : Bus 11861	: V=0.9627943, theta=-65.646272 -> V=1.0, theta=0.0
% INFO    : Bus 11862	: V=0.9760778, theta=-63.954478 -> V=1.0, theta=0.0
% INFO    : Bus 11863	: V=0.9795343, theta=-63.21114 -> V=1.0, theta=0.0
% INFO    : Bus 11864	: V=0.9813269, theta=-62.868101 -> V=1.0, theta=0.0
% INFO    : Bus 11865	: V=0.9795306, theta=-63.198844 -> V=1.0, theta=0.0
% INFO    : Bus 11866	: V=0.9829115, theta=-62.622313 -> V=1.0, theta=0.0
% INFO    : Bus 11867	: V=0.9750489, theta=-64.102604 -> V=1.0, theta=0.0
% INFO    : Bus 11868	: V=0.9842013, theta=-62.358936 -> V=1.0, theta=0.0
% INFO    : Bus 11869	: V=0.9733626, theta=-64.166355 -> V=1.0, theta=0.0
% INFO    : Bus 11870	: V=0.9885462, theta=-61.865253 -> V=1.0, theta=0.0
% INFO    : Bus 11871	: V=0.9846496, theta=-62.261216 -> V=1.0, theta=0.0
% INFO    : Bus 11872	: V=0.9671838, theta=-64.958343 -> V=1.0, theta=0.0
% INFO    : Bus 11873	: V=0.9822821, theta=-63.522936 -> V=1.0, theta=0.0
% INFO    : Bus 11874	: V=0.9672243, theta=-64.688074 -> V=1.0, theta=0.0
% INFO    : Bus 11875	: V=0.9805156, theta=-63.547852 -> V=1.0, theta=0.0
% INFO    : Bus 11876	: V=0.9633035, theta=-65.548331 -> V=1.0, theta=0.0
% INFO    : Bus 11877	: V=0.9630329, theta=-65.525735 -> V=1.0, theta=0.0
% INFO    : Bus 11878	: V=0.9655164, theta=-64.819085 -> V=1.0, theta=0.0
% INFO    : Bus 11879	: V=0.9750613, theta=-65.310013 -> V=1.0, theta=0.0
% INFO    : Bus 11880	: V=0.9682055, theta=-64.74503 -> V=1.0, theta=0.0
% INFO    : Bus 11881	: V=0.9665378, theta=-66.497841 -> V=1.0, theta=0.0
% INFO    : Bus 11882	: V=0.9574143, theta=-66.728583 -> V=1.0, theta=0.0
% INFO    : Bus 11883	: V=0.9564778, theta=-68.916111 -> V=1.0, theta=0.0
% INFO    : Bus 11884	: V=0.9617034, theta=-68.498391 -> V=1.0, theta=0.0
% INFO    : Bus 11885	: V=0.9650306, theta=-68.425515 -> V=1.0, theta=0.0
% INFO    : Bus 11886	: V=0.9640845, theta=-69.024051 -> V=1.0, theta=0.0
% INFO    : Bus 11887	: V=0.9637909, theta=-68.885292 -> V=1.0, theta=0.0
% INFO    : Bus 11888	: V=0.9600871, theta=-68.848138 -> V=1.0, theta=0.0
% INFO    : Bus 11889	: V=0.9593098, theta=-68.829916 -> V=1.0, theta=0.0
% INFO    : Bus 11890	: V=0.9913773, theta=-61.455797 -> V=1.0, theta=0.0
% INFO    : Bus 11891	: V=0.998201, theta=-60.47471 -> V=1.0, theta=0.0
% INFO    : Bus 11892	: V=0.9933965, theta=-61.021323 -> V=1.0, theta=0.0
% INFO    : Bus 11893	: V=0.9935198, theta=-60.982706 -> V=1.0, theta=0.0
% INFO    : Bus 11894	: V=0.9893938, theta=-61.696872 -> V=1.0, theta=0.0
% INFO    : Bus 11895	: V=0.9932256, theta=-60.947926 -> V=1.0, theta=0.0
% INFO    : Bus 11896	: V=0.9938027, theta=-60.902682 -> V=1.0, theta=0.0
% INFO    : Bus 11897	: V=0.9921275, theta=-61.37959 -> V=1.0, theta=0.0
% INFO    : Bus 11898	: V=0.9945633, theta=-60.792556 -> V=1.0, theta=0.0
% INFO    : Bus 11899	: V=0.9944679, theta=-60.794663 -> V=1.0, theta=0.0
% INFO    : Bus 11900	: V=0.9943371, theta=-60.729791 -> V=1.0, theta=0.0
% INFO    : Bus 11901	: V=0.9936546, theta=-60.853688 -> V=1.0, theta=0.0
% INFO    : Bus 11902	: V=0.9936413, theta=-60.805497 -> V=1.0, theta=0.0
% INFO    : Bus 11903	: V=0.9936032, theta=-60.825883 -> V=1.0, theta=0.0
% INFO    : Bus 11904	: V=0.9948344, theta=-60.625954 -> V=1.0, theta=0.0
% INFO    : Bus 11905	: V=0.9958037, theta=-60.523068 -> V=1.0, theta=0.0
% INFO    : Bus 11906	: V=0.9951347, theta=-60.618698 -> V=1.0, theta=0.0
% INFO    : Bus 11907	: V=0.995114, theta=-60.71409 -> V=1.0, theta=0.0
% INFO    : Bus 11908	: V=0.9953799, theta=-60.710507 -> V=1.0, theta=0.0
% INFO    : Bus 11909	: V=0.9951711, theta=-60.680971 -> V=1.0, theta=0.0
% INFO    : Bus 11910	: V=1.0026846, theta=-59.68165 -> V=1.0, theta=0.0
% INFO    : Bus 11911	: V=1.0030198, theta=-59.57316 -> V=1.0, theta=0.0
% INFO    : Bus 11912	: V=0.9987278, theta=-60.363172 -> V=1.0, theta=0.0
% INFO    : Bus 11913	: V=0.9993258, theta=-60.243345 -> V=1.0, theta=0.0
% INFO    : Bus 11914	: V=1.0002152, theta=-60.113092 -> V=1.0, theta=0.0
% INFO    : Bus 11915	: V=1.0004465, theta=-60.091872 -> V=1.0, theta=0.0
% INFO    : Bus 11916	: V=0.9991946, theta=-60.333455 -> V=1.0, theta=0.0
% INFO    : Bus 11917	: V=1.0007264, theta=-60.064102 -> V=1.0, theta=0.0
% INFO    : Bus 11918	: V=0.99817, theta=-60.395204 -> V=1.0, theta=0.0
% INFO    : Bus 11919	: V=1.0099433, theta=-58.611269 -> V=1.0, theta=0.0
% INFO    : Bus 11920	: V=1.0031371, theta=-59.681713 -> V=1.0, theta=0.0
% INFO    : Bus 11921	: V=1.0037023, theta=-59.591711 -> V=1.0, theta=0.0
% INFO    : Bus 11922	: V=1.0123242, theta=-58.345842 -> V=1.0, theta=0.0
% INFO    : Bus 11923	: V=1.0037758, theta=-59.546087 -> V=1.0, theta=0.0
% INFO    : Bus 11924	: V=1.0146875, theta=-58.037247 -> V=1.0, theta=0.0
% INFO    : Bus 11925	: V=0.9991953, theta=-60.19103 -> V=1.0, theta=0.0
% INFO    : Bus 11926	: V=0.9988311, theta=-60.194394 -> V=1.0, theta=0.0
% INFO    : Bus 11927	: V=1.0051818, theta=-59.387326 -> V=1.0, theta=0.0
% INFO    : Bus 11928	: V=1.0045366, theta=-59.462257 -> V=1.0, theta=0.0
% INFO    : Bus 11929	: V=1.0034893, theta=-59.562635 -> V=1.0, theta=0.0
% INFO    : Bus 11930	: V=0.9996463, theta=-60.093327 -> V=1.0, theta=0.0
% INFO    : Bus 11931	: V=1.0019686, theta=-59.7854 -> V=1.0, theta=0.0
% INFO    : Bus 11932	: V=0.9981555, theta=-60.246752 -> V=1.0, theta=0.0
% INFO    : Bus 11933	: V=1.0150254, theta=-57.844449 -> V=1.0, theta=0.0
% INFO    : Bus 11934	: V=1.0065892, theta=-59.182962 -> V=1.0, theta=0.0
% INFO    : Bus 11935	: V=0.9986331, theta=-60.225972 -> V=1.0, theta=0.0
% INFO    : Bus 11936	: V=0.9992728, theta=-60.054562 -> V=1.0, theta=0.0
% INFO    : Bus 11937	: V=1.0063852, theta=-59.050225 -> V=1.0, theta=0.0
% INFO    : Bus 11938	: V=1.015443, theta=-57.768933 -> V=1.0, theta=0.0
% INFO    : Bus 11939	: V=1.0160477, theta=-57.657484 -> V=1.0, theta=0.0
% INFO    : Bus 11940	: V=1.0089861, theta=-58.837461 -> V=1.0, theta=0.0
% INFO    : Bus 11941	: V=1.0170792, theta=-57.767763 -> V=1.0, theta=0.0
% INFO    : Bus 11942	: V=1.0172368, theta=-57.745683 -> V=1.0, theta=0.0
% INFO    : Bus 11943	: V=1.0033621, theta=-59.586693 -> V=1.0, theta=0.0
% INFO    : Bus 11944	: V=1.0049108, theta=-59.384724 -> V=1.0, theta=0.0
% INFO    : Bus 11945	: V=1.0096134, theta=-58.716863 -> V=1.0, theta=0.0
% INFO    : Bus 11946	: V=1.0178549, theta=-57.664223 -> V=1.0, theta=0.0
% INFO    : Bus 11947	: V=1.0164024, theta=-57.593105 -> V=1.0, theta=0.0
% INFO    : Bus 11948	: V=1.0168851, theta=-57.479824 -> V=1.0, theta=0.0
% INFO    : Bus 11949	: V=1.0142702, theta=-58.028589 -> V=1.0, theta=0.0
% INFO    : Bus 11950	: V=1.0137149, theta=-58.085895 -> V=1.0, theta=0.0
% INFO    : Bus 11951	: V=1.0132685, theta=-58.129379 -> V=1.0, theta=0.0
% INFO    : Bus 11952	: V=1.0152736, theta=-57.887046 -> V=1.0, theta=0.0
% INFO    : Bus 11953	: V=1.0171503, theta=-57.394221 -> V=1.0, theta=0.0
% INFO    : Bus 11954	: V=1.0173049, theta=-57.3444 -> V=1.0, theta=0.0
% INFO    : Bus 11955	: V=1.017697, theta=-57.474878 -> V=1.0, theta=0.0
% INFO    : Bus 11956	: V=1.0176463, theta=-57.422554 -> V=1.0, theta=0.0
% INFO    : Bus 11957	: V=1.0180057, theta=-57.083697 -> V=1.0, theta=0.0
% INFO    : Bus 11958	: V=1.0183268, theta=-56.965047 -> V=1.0, theta=0.0
% INFO    : Bus 11959	: V=1.0129481, theta=-57.709982 -> V=1.0, theta=0.0
% INFO    : Bus 11960	: V=1.0090518, theta=-58.595775 -> V=1.0, theta=0.0
% INFO    : Bus 11961	: V=1.0093583, theta=-58.591683 -> V=1.0, theta=0.0
% INFO    : Bus 11962	: V=1.0063596, theta=-58.73522 -> V=1.0, theta=0.0
% INFO    : Bus 11963	: V=1.0111667, theta=-57.97854 -> V=1.0, theta=0.0
% INFO    : Bus 11964	: V=1.0050735, theta=-59.08606 -> V=1.0, theta=0.0
% INFO    : Bus 11965	: V=1.0174966, theta=-57.286828 -> V=1.0, theta=0.0
% INFO    : Bus 11966	: V=1.0188549, theta=-56.769011 -> V=1.0, theta=0.0
% INFO    : Bus 11967	: V=1.0195493, theta=-56.527699 -> V=1.0, theta=0.0
% INFO    : Bus 11968	: V=1.0089643, theta=-58.486737 -> V=1.0, theta=0.0
% INFO    : Bus 11969	: V=1.0065086, theta=-58.830043 -> V=1.0, theta=0.0
% INFO    : Bus 11970	: V=1.009164, theta=-58.481968 -> V=1.0, theta=0.0
% INFO    : Bus 11971	: V=0.9991326, theta=-59.737779 -> V=1.0, theta=0.0
% INFO    : Bus 11972	: V=1.0083855, theta=-58.558218 -> V=1.0, theta=0.0
% INFO    : Bus 11973	: V=1.0014779, theta=-59.468574 -> V=1.0, theta=0.0
% INFO    : Bus 11974	: V=1.0021124, theta=-59.390937 -> V=1.0, theta=0.0
% INFO    : Bus 11975	: V=0.9926102, theta=-60.36757 -> V=1.0, theta=0.0
% INFO    : Bus 11976	: V=1.0077646, theta=-58.650902 -> V=1.0, theta=0.0
% INFO    : Bus 11977	: V=1.00773, theta=-58.706412 -> V=1.0, theta=0.0
% INFO    : Bus 11978	: V=0.9966372, theta=-60.096551 -> V=1.0, theta=0.0
% INFO    : Bus 11979	: V=0.9987961, theta=-59.794406 -> V=1.0, theta=0.0
% INFO    : Bus 11980	: V=0.9929309, theta=-60.747757 -> V=1.0, theta=0.0
% INFO    : Bus 11981	: V=1.0064403, theta=-58.998395 -> V=1.0, theta=0.0
% INFO    : Bus 11982	: V=0.9919642, theta=-60.774159 -> V=1.0, theta=0.0
% INFO    : Bus 11983	: V=0.9926474, theta=-60.745282 -> V=1.0, theta=0.0
% INFO    : Bus 11984	: V=1.0047092, theta=-59.29288 -> V=1.0, theta=0.0
% INFO    : Bus 11985	: V=1.0029014, theta=-59.574149 -> V=1.0, theta=0.0
% INFO    : Bus 11986	: V=0.9908095, theta=-60.785821 -> V=1.0, theta=0.0
% INFO    : Bus 11987	: V=0.9960767, theta=-60.46699 -> V=1.0, theta=0.0
% INFO    : Bus 11988	: V=1.0002301, theta=-59.93616 -> V=1.0, theta=0.0
% INFO    : Bus 11989	: V=0.99764, theta=-60.273351 -> V=1.0, theta=0.0
% INFO    : Bus 11990	: V=1.0020361, theta=-59.708274 -> V=1.0, theta=0.0
% INFO    : Bus 11991	: V=1.0034986, theta=-59.48335 -> V=1.0, theta=0.0
% INFO    : Bus 11992	: V=0.9939999, theta=-60.525965 -> V=1.0, theta=0.0
% INFO    : Bus 11993	: V=0.9917769, theta=-60.799174 -> V=1.0, theta=0.0
% INFO    : Bus 11994	: V=0.9912349, theta=-60.782903 -> V=1.0, theta=0.0
% INFO    : Bus 11995	: V=0.9911627, theta=-60.905357 -> V=1.0, theta=0.0
% INFO    : Bus 11996	: V=0.9923031, theta=-60.805697 -> V=1.0, theta=0.0
% INFO    : Bus 11997	: V=0.9870378, theta=-61.436654 -> V=1.0, theta=0.0
% INFO    : Bus 11998	: V=0.9853223, theta=-61.687891 -> V=1.0, theta=0.0
% INFO    : Bus 11999	: V=0.9917732, theta=-60.916194 -> V=1.0, theta=0.0
% INFO    : Bus 12000	: V=0.9863302, theta=-61.59223 -> V=1.0, theta=0.0
% INFO    : Bus 12001	: V=0.9865089, theta=-61.541183 -> V=1.0, theta=0.0
% INFO    : Bus 12002	: V=0.9901933, theta=-61.135517 -> V=1.0, theta=0.0
% INFO    : Bus 12003	: V=0.9893116, theta=-61.240269 -> V=1.0, theta=0.0
% INFO    : Bus 12004	: V=0.9883299, theta=-61.354812 -> V=1.0, theta=0.0
% INFO    : Bus 12005	: V=0.9871204, theta=-61.537475 -> V=1.0, theta=0.0
% INFO    : Bus 12006	: V=0.9841078, theta=-62.158221 -> V=1.0, theta=0.0
% INFO    : Bus 12007	: V=0.9847357, theta=-62.153436 -> V=1.0, theta=0.0
% INFO    : Bus 12008	: V=0.9842916, theta=-62.210927 -> V=1.0, theta=0.0
% INFO    : Bus 12009	: V=0.9907017, theta=-61.118365 -> V=1.0, theta=0.0
% INFO    : Bus 12010	: V=0.9884883, theta=-61.531882 -> V=1.0, theta=0.0
% INFO    : Bus 12011	: V=0.9912703, theta=-61.012036 -> V=1.0, theta=0.0
% INFO    : Bus 12012	: V=0.9885799, theta=-61.61501 -> V=1.0, theta=0.0
% INFO    : Bus 12013	: V=0.9806626, theta=-62.604938 -> V=1.0, theta=0.0
% INFO    : Bus 12014	: V=0.97853, theta=-62.932318 -> V=1.0, theta=0.0
% INFO    : Bus 12015	: V=0.9815931, theta=-62.454956 -> V=1.0, theta=0.0
% INFO    : Bus 12016	: V=0.9785627, theta=-62.949664 -> V=1.0, theta=0.0
% INFO    : Bus 12017	: V=0.9781703, theta=-63.152122 -> V=1.0, theta=0.0
% INFO    : Bus 12018	: V=0.9768711, theta=-63.282223 -> V=1.0, theta=0.0
% INFO    : Bus 12019	: V=0.9815493, theta=-62.211312 -> V=1.0, theta=0.0
% INFO    : Bus 12020	: V=0.9880007, theta=-61.266595 -> V=1.0, theta=0.0
% INFO    : Bus 12021	: V=0.9881405, theta=-61.268004 -> V=1.0, theta=0.0
% INFO    : Bus 12022	: V=0.9874913, theta=-61.199193 -> V=1.0, theta=0.0
% INFO    : Bus 12023	: V=0.9856694, theta=-61.17808 -> V=1.0, theta=0.0
% INFO    : Bus 12024	: V=0.9884157, theta=-60.83652 -> V=1.0, theta=0.0
% INFO    : Bus 12025	: V=0.9887051, theta=-60.643656 -> V=1.0, theta=0.0
% INFO    : Bus 12026	: V=1.0043659, theta=-58.505936 -> V=1.0, theta=0.0
% INFO    : Bus 12027	: V=1.0072047, theta=-58.30124 -> V=1.0, theta=0.0
% INFO    : Bus 12028	: V=0.9932256, theta=-61.085006 -> V=1.0, theta=0.0
% INFO    : Bus 12029	: V=1.0077424, theta=-59.013226 -> V=1.0, theta=0.0
% INFO    : Bus 12030	: V=1.0044449, theta=-59.460912 -> V=1.0, theta=0.0
% INFO    : Bus 12031	: V=1.0141386, theta=-58.148234 -> V=1.0, theta=0.0
% INFO    : Bus 12032	: V=1.0077996, theta=-58.766791 -> V=1.0, theta=0.0
% INFO    : Bus 12033	: V=1.0078855, theta=-58.753485 -> V=1.0, theta=0.0
% INFO    : Bus 12034	: V=0.9626605, theta=-74.624201 -> V=1.0, theta=0.0
% INFO    : Bus 12035	: V=0.9797129, theta=-70.150116 -> V=1.0, theta=0.0
% INFO    : Bus 12036	: V=0.9695614, theta=-71.434574 -> V=1.0, theta=0.0
% INFO    : Bus 12037	: V=0.9721687, theta=-71.81602 -> V=1.0, theta=0.0
% INFO    : Bus 12038	: V=0.9644837, theta=-72.881412 -> V=1.0, theta=0.0
% INFO    : Bus 12039	: V=0.9840325, theta=-66.513599 -> V=1.0, theta=0.0
% INFO    : Bus 12040	: V=0.9655814, theta=-72.764201 -> V=1.0, theta=0.0
% INFO    : Bus 12041	: V=0.9615393, theta=-73.339265 -> V=1.0, theta=0.0
% INFO    : Bus 12042	: V=0.9550346, theta=-76.101774 -> V=1.0, theta=0.0
% INFO    : Bus 12043	: V=0.9568567, theta=-72.444087 -> V=1.0, theta=0.0
% INFO    : Bus 12044	: V=0.9697983, theta=-69.707545 -> V=1.0, theta=0.0
% INFO    : Bus 12045	: V=0.9618507, theta=-71.127995 -> V=1.0, theta=0.0
% INFO    : Bus 12046	: V=0.9666444, theta=-70.264233 -> V=1.0, theta=0.0
% INFO    : Bus 12047	: V=0.9497095, theta=-73.530608 -> V=1.0, theta=0.0
% INFO    : Bus 12048	: V=0.949616, theta=-73.419084 -> V=1.0, theta=0.0
% INFO    : Bus 12049	: V=0.9497414, theta=-73.55006 -> V=1.0, theta=0.0
% INFO    : Bus 12050	: V=0.9502373, theta=-73.535668 -> V=1.0, theta=0.0
% INFO    : Bus 12051	: V=0.9623893, theta=-71.095011 -> V=1.0, theta=0.0
% INFO    : Bus 12052	: V=0.9712937, theta=-69.496501 -> V=1.0, theta=0.0
% INFO    : Bus 12053	: V=0.9962258, theta=-64.360649 -> V=1.0, theta=0.0
% INFO    : Bus 12054	: V=0.9684085, theta=-70.096516 -> V=1.0, theta=0.0
% INFO    : Bus 12055	: V=0.9562109, theta=-72.70572 -> V=1.0, theta=0.0
% INFO    : Bus 12056	: V=0.9558553, theta=-72.715948 -> V=1.0, theta=0.0
% INFO    : Bus 12057	: V=0.9606195, theta=-71.200747 -> V=1.0, theta=0.0
% INFO    : Bus 12058	: V=0.9593188, theta=-71.339437 -> V=1.0, theta=0.0
% INFO    : Bus 12059	: V=0.9547007, theta=-72.773973 -> V=1.0, theta=0.0
% INFO    : Bus 12060	: V=0.9559146, theta=-72.713087 -> V=1.0, theta=0.0
% INFO    : Bus 12061	: V=0.9690895, theta=-69.977314 -> V=1.0, theta=0.0
% INFO    : Bus 12062	: V=0.9574968, theta=-72.431049 -> V=1.0, theta=0.0
% INFO    : Bus 12063	: V=0.9699195, theta=-69.670204 -> V=1.0, theta=0.0
% INFO    : Bus 12064	: V=0.9710284, theta=-69.637212 -> V=1.0, theta=0.0
% INFO    : Bus 12065	: V=0.9704169, theta=-69.739494 -> V=1.0, theta=0.0
% INFO    : Bus 12066	: V=0.9697518, theta=-69.854771 -> V=1.0, theta=0.0
% INFO    : Bus 12067	: V=0.9551567, theta=-72.735957 -> V=1.0, theta=0.0
% INFO    : Bus 12068	: V=0.9550136, theta=-72.764952 -> V=1.0, theta=0.0
% INFO    : Bus 12069	: V=0.9461378, theta=-74.071733 -> V=1.0, theta=0.0
% INFO    : Bus 12070	: V=0.9512636, theta=-73.147952 -> V=1.0, theta=0.0
% INFO    : Bus 12071	: V=0.9647106, theta=-70.109734 -> V=1.0, theta=0.0
% INFO    : Bus 12072	: V=0.9676565, theta=-70.005487 -> V=1.0, theta=0.0
% INFO    : Bus 12073	: V=0.9412173, theta=-72.466368 -> V=1.0, theta=0.0
% INFO    : Bus 12074	: V=0.9385214, theta=-73.032994 -> V=1.0, theta=0.0
% INFO    : Bus 12075	: V=0.93938, theta=-73.024824 -> V=1.0, theta=0.0
% INFO    : Bus 12076	: V=0.941308, theta=-72.966572 -> V=1.0, theta=0.0
% INFO    : Bus 12077	: V=0.9528098, theta=-71.31915 -> V=1.0, theta=0.0
% INFO    : Bus 12078	: V=0.9517322, theta=-71.399667 -> V=1.0, theta=0.0
% INFO    : Bus 12079	: V=0.9488393, theta=-72.783457 -> V=1.0, theta=0.0
% INFO    : Bus 12080	: V=0.9574117, theta=-70.899519 -> V=1.0, theta=0.0
% INFO    : Bus 12081	: V=0.946692, theta=-73.042077 -> V=1.0, theta=0.0
% INFO    : Bus 12082	: V=0.9513424, theta=-73.004198 -> V=1.0, theta=0.0
% INFO    : Bus 12083	: V=0.9568998, theta=-72.401557 -> V=1.0, theta=0.0
% INFO    : Bus 12084	: V=0.9705713, theta=-69.594641 -> V=1.0, theta=0.0
% INFO    : Bus 12085	: V=0.969196, theta=-69.708682 -> V=1.0, theta=0.0
% INFO    : Bus 12086	: V=0.9675355, theta=-69.866775 -> V=1.0, theta=0.0
% INFO    : Bus 12087	: V=0.9562266, theta=-72.499478 -> V=1.0, theta=0.0
% INFO    : Bus 12088	: V=0.9510551, theta=-72.947931 -> V=1.0, theta=0.0
% INFO    : Bus 12089	: V=0.9656905, theta=-70.077073 -> V=1.0, theta=0.0
% INFO    : Bus 12090	: V=0.9555891, theta=-72.495861 -> V=1.0, theta=0.0
% INFO    : Bus 12091	: V=0.9441536, theta=-74.122416 -> V=1.0, theta=0.0
% INFO    : Bus 12092	: V=0.9532372, theta=-73.004094 -> V=1.0, theta=0.0
% INFO    : Bus 12093	: V=0.949132, theta=-73.892966 -> V=1.0, theta=0.0
% INFO    : Bus 12094	: V=0.9639959, theta=-71.524257 -> V=1.0, theta=0.0
% INFO    : Bus 12095	: V=0.9411434, theta=-74.806245 -> V=1.0, theta=0.0
% INFO    : Bus 12096	: V=0.9589708, theta=-71.356384 -> V=1.0, theta=0.0
% INFO    : Bus 12097	: V=0.9407507, theta=-74.887593 -> V=1.0, theta=0.0
% INFO    : Bus 12098	: V=0.937756, theta=-74.978704 -> V=1.0, theta=0.0
% INFO    : Bus 12099	: V=0.938813, theta=-74.383744 -> V=1.0, theta=0.0
% INFO    : Bus 12100	: V=0.9709793, theta=-71.071173 -> V=1.0, theta=0.0
% INFO    : Bus 12101	: V=0.9624731, theta=-72.24579 -> V=1.0, theta=0.0
% INFO    : Bus 12102	: V=0.9551481, theta=-72.563682 -> V=1.0, theta=0.0
% INFO    : Bus 12103	: V=0.9425014, theta=-74.095674 -> V=1.0, theta=0.0
% INFO    : Bus 12104	: V=0.9624467, theta=-73.392154 -> V=1.0, theta=0.0
% INFO    : Bus 12105	: V=0.9614095, theta=-73.571484 -> V=1.0, theta=0.0
% INFO    : Bus 12106	: V=0.9420665, theta=-75.21306 -> V=1.0, theta=0.0
% INFO    : Bus 12107	: V=0.9403495, theta=-75.296044 -> V=1.0, theta=0.0
% INFO    : Bus 12108	: V=0.9436796, theta=-74.852779 -> V=1.0, theta=0.0
% INFO    : Bus 12109	: V=0.9501275, theta=-74.314039 -> V=1.0, theta=0.0
% INFO    : Bus 12110	: V=0.9621184, theta=-72.296585 -> V=1.0, theta=0.0
% INFO    : Bus 12111	: V=0.9442655, theta=-74.195546 -> V=1.0, theta=0.0
% INFO    : Bus 12112	: V=0.9592259, theta=-71.366889 -> V=1.0, theta=0.0
% INFO    : Bus 12113	: V=0.9489488, theta=-71.510309 -> V=1.0, theta=0.0
% INFO    : Bus 12114	: V=0.9822874, theta=-59.618882 -> V=1.0, theta=0.0
% INFO    : Bus 12115	: V=0.9767114, theta=-59.676499 -> V=1.0, theta=0.0
% INFO    : Bus 12116	: V=0.969008, theta=-60.728556 -> V=1.0, theta=0.0
% INFO    : Bus 12117	: V=0.9499185, theta=-63.647788 -> V=1.0, theta=0.0
% INFO    : Bus 12118	: V=0.9449567, theta=-63.782653 -> V=1.0, theta=0.0
% INFO    : Bus 12119	: V=0.97354, theta=-60.569901 -> V=1.0, theta=0.0
% INFO    : Bus 12120	: V=0.9765156, theta=-60.030867 -> V=1.0, theta=0.0
% INFO    : Bus 12121	: V=0.9769729, theta=-59.922852 -> V=1.0, theta=0.0
% INFO    : Bus 12122	: V=0.9674726, theta=-61.137733 -> V=1.0, theta=0.0
% INFO    : Bus 12123	: V=0.9790615, theta=-59.585683 -> V=1.0, theta=0.0
% INFO    : Bus 12124	: V=0.9795026, theta=-59.018451 -> V=1.0, theta=0.0
% INFO    : Bus 12125	: V=0.9864315, theta=-58.58219 -> V=1.0, theta=0.0
% INFO    : Bus 12126	: V=0.9929897, theta=-57.274473 -> V=1.0, theta=0.0
% INFO    : Bus 12127	: V=1.0047586, theta=-55.179165 -> V=1.0, theta=0.0
% INFO    : Bus 12128	: V=0.9987214, theta=-56.525267 -> V=1.0, theta=0.0
% INFO    : Bus 12129	: V=0.9973887, theta=-56.648687 -> V=1.0, theta=0.0
% INFO    : Bus 12130	: V=0.9955267, theta=-57.015345 -> V=1.0, theta=0.0
% INFO    : Bus 12131	: V=0.988297, theta=-58.109838 -> V=1.0, theta=0.0
% INFO    : Bus 12132	: V=0.9927979, theta=-57.436175 -> V=1.0, theta=0.0
% INFO    : Bus 12133	: V=0.9840991, theta=-58.307841 -> V=1.0, theta=0.0
% INFO    : Bus 12134	: V=0.9890795, theta=-57.914759 -> V=1.0, theta=0.0
% INFO    : Bus 12135	: V=0.9945823, theta=-57.419213 -> V=1.0, theta=0.0
% INFO    : Bus 12136	: V=0.9938071, theta=-57.43347 -> V=1.0, theta=0.0
% INFO    : Bus 12137	: V=0.9910547, theta=-57.753055 -> V=1.0, theta=0.0
% INFO    : Bus 12138	: V=0.9879917, theta=-57.934415 -> V=1.0, theta=0.0
% INFO    : Bus 12139	: V=0.9929598, theta=-57.801092 -> V=1.0, theta=0.0
% INFO    : Bus 12140	: V=0.9804961, theta=-58.487054 -> V=1.0, theta=0.0
% INFO    : Bus 12141	: V=0.9739963, theta=-58.571583 -> V=1.0, theta=0.0
% INFO    : Bus 12142	: V=1.0056472, theta=-56.981659 -> V=1.0, theta=0.0
% INFO    : Bus 12143	: V=0.989457, theta=-58.00952 -> V=1.0, theta=0.0
% INFO    : Bus 12144	: V=1.0077054, theta=-56.554362 -> V=1.0, theta=0.0
% INFO    : Bus 12145	: V=1.0049163, theta=-55.623784 -> V=1.0, theta=0.0
% INFO    : Bus 12146	: V=1.0138602, theta=-54.259915 -> V=1.0, theta=0.0
% INFO    : Bus 12147	: V=1.0171037, theta=-55.157608 -> V=1.0, theta=0.0
% INFO    : Bus 12148	: V=1.0117776, theta=-55.737695 -> V=1.0, theta=0.0
% INFO    : Bus 12149	: V=0.9737994, theta=-60.212909 -> V=1.0, theta=0.0
% INFO    : Bus 12150	: V=0.9930407, theta=-70.11493 -> V=1.0, theta=0.0
% INFO    : Bus 12151	: V=0.9798159, theta=-70.746429 -> V=1.0, theta=0.0
% INFO    : Bus 12152	: V=0.9977285, theta=-70.849065 -> V=1.0, theta=0.0
% INFO    : Bus 12153	: V=0.9938124, theta=-60.511828 -> V=1.0, theta=0.0
% INFO    : Bus 12154	: V=0.9953675, theta=-60.117608 -> V=1.0, theta=0.0
% INFO    : Bus 12155	: V=1.0007008, theta=-58.982679 -> V=1.0, theta=0.0
% INFO    : Bus 12156	: V=1.0129428, theta=-56.622728 -> V=1.0, theta=0.0
% INFO    : Bus 12157	: V=0.9967267, theta=-59.331586 -> V=1.0, theta=0.0
% INFO    : Bus 12158	: V=0.9962768, theta=-59.238013 -> V=1.0, theta=0.0
% INFO    : Bus 12159	: V=0.9915846, theta=-59.30884 -> V=1.0, theta=0.0
% INFO    : Bus 12160	: V=0.986585, theta=-61.252584 -> V=1.0, theta=0.0
% INFO    : Bus 12161	: V=0.9871885, theta=-61.16998 -> V=1.0, theta=0.0
% INFO    : Bus 12162	: V=0.9864798, theta=-61.245089 -> V=1.0, theta=0.0
% INFO    : Bus 12163	: V=0.985441, theta=-61.28626 -> V=1.0, theta=0.0
% INFO    : Bus 12164	: V=0.9857673, theta=-61.190705 -> V=1.0, theta=0.0
% INFO    : Bus 12165	: V=0.9879083, theta=-60.7843 -> V=1.0, theta=0.0
% INFO    : Bus 12166	: V=0.9775921, theta=-61.347231 -> V=1.0, theta=0.0
% INFO    : Bus 12167	: V=0.9918255, theta=-59.327021 -> V=1.0, theta=0.0
% INFO    : Bus 12168	: V=0.9898217, theta=-59.411091 -> V=1.0, theta=0.0
% INFO    : Bus 12169	: V=0.9868554, theta=-58.79672 -> V=1.0, theta=0.0
% INFO    : Bus 12170	: V=0.9831215, theta=-59.352342 -> V=1.0, theta=0.0
% INFO    : Bus 12171	: V=0.975167, theta=-60.719356 -> V=1.0, theta=0.0
% INFO    : Bus 12172	: V=0.9830191, theta=-59.307391 -> V=1.0, theta=0.0
% INFO    : Bus 12173	: V=0.9891619, theta=-59.391545 -> V=1.0, theta=0.0
% INFO    : Bus 12174	: V=0.9847708, theta=-59.024214 -> V=1.0, theta=0.0
% INFO    : Bus 12175	: V=0.9796497, theta=-60.360837 -> V=1.0, theta=0.0
% INFO    : Bus 12176	: V=0.9816287, theta=-59.311143 -> V=1.0, theta=0.0
% INFO    : Bus 12177	: V=0.9828645, theta=-59.218463 -> V=1.0, theta=0.0
% INFO    : Bus 12178	: V=0.9604077, theta=-62.297905 -> V=1.0, theta=0.0
% INFO    : Bus 12179	: V=0.9541658, theta=-62.388309 -> V=1.0, theta=0.0
% INFO    : Bus 12180	: V=0.9892459, theta=-60.095163 -> V=1.0, theta=0.0
% INFO    : Bus 12181	: V=0.9893845, theta=-60.551095 -> V=1.0, theta=0.0
% INFO    : Bus 12182	: V=0.9938946, theta=-57.807524 -> V=1.0, theta=0.0
% INFO    : Bus 12183	: V=1.0159932, theta=-52.95312 -> V=1.0, theta=0.0
% INFO    : Bus 12184	: V=1.0146757, theta=-53.042553 -> V=1.0, theta=0.0
% INFO    : Bus 12185	: V=0.98492, theta=-55.235429 -> V=1.0, theta=0.0
% INFO    : Bus 12186	: V=0.9876554, theta=-52.107531 -> V=1.0, theta=0.0
% INFO    : Bus 12187	: V=1.0040335, theta=-53.321939 -> V=1.0, theta=0.0
% INFO    : Bus 12188	: V=0.9901526, theta=-54.868332 -> V=1.0, theta=0.0
% INFO    : Bus 12189	: V=0.9917943, theta=-54.65168 -> V=1.0, theta=0.0
% INFO    : Bus 12190	: V=0.9796955, theta=-55.578004 -> V=1.0, theta=0.0
% INFO    : Bus 12191	: V=1.0048224, theta=-54.320224 -> V=1.0, theta=0.0
% INFO    : Bus 12192	: V=0.9535155, theta=-67.303055 -> V=1.0, theta=0.0
% INFO    : Bus 12193	: V=0.9698313, theta=-66.730817 -> V=1.0, theta=0.0
% INFO    : Bus 12194	: V=0.9723651, theta=-65.705203 -> V=1.0, theta=0.0
% INFO    : Bus 12195	: V=0.9770441, theta=-65.038768 -> V=1.0, theta=0.0
% INFO    : Bus 12196	: V=0.9771755, theta=-64.881526 -> V=1.0, theta=0.0
% INFO    : Bus 12197	: V=0.9895325, theta=-62.957288 -> V=1.0, theta=0.0
% INFO    : Bus 12198	: V=0.9915293, theta=-61.673055 -> V=1.0, theta=0.0
% INFO    : Bus 12199	: V=0.9881954, theta=-63.369362 -> V=1.0, theta=0.0
% INFO    : Bus 12200	: V=0.982897, theta=-64.206852 -> V=1.0, theta=0.0
% INFO    : Bus 12201	: V=0.9927962, theta=-60.883643 -> V=1.0, theta=0.0
% INFO    : Bus 12202	: V=0.9919609, theta=-61.281036 -> V=1.0, theta=0.0
% INFO    : Bus 12203	: V=0.9921793, theta=-61.790689 -> V=1.0, theta=0.0
% INFO    : Bus 12204	: V=1.0109848, theta=-60.125051 -> V=1.0, theta=0.0
% INFO    : Bus 12205	: V=0.9813605, theta=-61.506653 -> V=1.0, theta=0.0
% INFO    : Bus 12206	: V=1.0014728, theta=-61.481504 -> V=1.0, theta=0.0
% INFO    : Bus 12207	: V=1.0038592, theta=-60.676454 -> V=1.0, theta=0.0
% INFO    : Bus 12208	: V=0.9910648, theta=-60.849001 -> V=1.0, theta=0.0
% INFO    : Bus 12209	: V=1.0136474, theta=-58.419302 -> V=1.0, theta=0.0
% INFO    : Bus 12210	: V=1.0103822, theta=-59.105288 -> V=1.0, theta=0.0
% INFO    : Bus 12211	: V=1.0094233, theta=-59.303804 -> V=1.0, theta=0.0
% INFO    : Bus 12212	: V=1.0086416, theta=-59.493394 -> V=1.0, theta=0.0
% INFO    : Bus 12213	: V=1.0096, theta=-59.228655 -> V=1.0, theta=0.0
% INFO    : Bus 12214	: V=1.0094934, theta=-59.253074 -> V=1.0, theta=0.0
% INFO    : Bus 12215	: V=1.0095451, theta=-59.247122 -> V=1.0, theta=0.0
% INFO    : Bus 12216	: V=1.0020907, theta=-60.236062 -> V=1.0, theta=0.0
% INFO    : Bus 12217	: V=1.0067227, theta=-60.166219 -> V=1.0, theta=0.0
% INFO    : Bus 12218	: V=1.006763, theta=-60.368609 -> V=1.0, theta=0.0
% INFO    : Bus 12219	: V=1.0186279, theta=-56.86009 -> V=1.0, theta=0.0
% INFO    : Bus 12220	: V=1.0137862, theta=-58.086679 -> V=1.0, theta=0.0
% INFO    : Bus 12221	: V=1.0098913, theta=-58.676525 -> V=1.0, theta=0.0
% INFO    : Bus 12222	: V=0.9756743, theta=-61.862501 -> V=1.0, theta=0.0
% INFO    : Bus 12223	: V=0.9779264, theta=-61.82579 -> V=1.0, theta=0.0
% INFO    : Bus 12224	: V=1.0063018, theta=-59.264622 -> V=1.0, theta=0.0
% INFO    : Bus 12225	: V=0.9914809, theta=-60.227664 -> V=1.0, theta=0.0
% INFO    : Bus 12226	: V=1.0131643, theta=-58.189104 -> V=1.0, theta=0.0
% INFO    : Bus 12227	: V=0.9909301, theta=-65.58471 -> V=1.0, theta=0.0
% INFO    : Bus 12228	: V=0.9857875, theta=-67.951816 -> V=1.0, theta=0.0
% INFO    : Bus 12229	: V=0.9888591, theta=-66.885348 -> V=1.0, theta=0.0
% INFO    : Bus 12230	: V=0.9898444, theta=-66.578671 -> V=1.0, theta=0.0
% INFO    : Bus 12231	: V=0.9901304, theta=-66.507991 -> V=1.0, theta=0.0
% INFO    : Bus 12232	: V=0.9908945, theta=-66.372362 -> V=1.0, theta=0.0
% INFO    : Bus 12233	: V=1.0132827, theta=-60.527893 -> V=1.0, theta=0.0
% INFO    : Bus 12234	: V=1.012038, theta=-60.798464 -> V=1.0, theta=0.0
% INFO    : Bus 12235	: V=0.9996034, theta=-65.726877 -> V=1.0, theta=0.0
% INFO    : Bus 12236	: V=1.0168407, theta=-59.75956 -> V=1.0, theta=0.0
% INFO    : Bus 12237	: V=1.0130413, theta=-60.120108 -> V=1.0, theta=0.0
% INFO    : Bus 12238	: V=1.0134535, theta=-60.075211 -> V=1.0, theta=0.0
% INFO    : Bus 12239	: V=1.010296, theta=-60.987502 -> V=1.0, theta=0.0
% INFO    : Bus 12240	: V=0.9572718, theta=-68.779591 -> V=1.0, theta=0.0
% INFO    : Bus 12241	: V=1.004141, theta=-60.291022 -> V=1.0, theta=0.0
% INFO    : Bus 12242	: V=0.9429954, theta=-70.213158 -> V=1.0, theta=0.0
% INFO    : Bus 12243	: V=0.9566759, theta=-68.878351 -> V=1.0, theta=0.0
% INFO    : Bus 12244	: V=0.9584621, theta=-69.40542 -> V=1.0, theta=0.0
% INFO    : Bus 12245	: V=0.9490135, theta=-72.017875 -> V=1.0, theta=0.0
% INFO    : Bus 12246	: V=0.9572436, theta=-70.344818 -> V=1.0, theta=0.0
% INFO    : Bus 12247	: V=0.9492067, theta=-71.976292 -> V=1.0, theta=0.0
% INFO    : Bus 12248	: V=0.9488515, theta=-71.985807 -> V=1.0, theta=0.0
% INFO    : Bus 12249	: V=0.9489959, theta=-72.116925 -> V=1.0, theta=0.0
% INFO    : Bus 12250	: V=0.9487455, theta=-72.062343 -> V=1.0, theta=0.0
% INFO    : Bus 12251	: V=0.9549609, theta=-71.676953 -> V=1.0, theta=0.0
% INFO    : Bus 12252	: V=0.9489004, theta=-71.873517 -> V=1.0, theta=0.0
% INFO    : Bus 12253	: V=0.9483096, theta=-71.890798 -> V=1.0, theta=0.0
% INFO    : Bus 12254	: V=0.9513388, theta=-71.838898 -> V=1.0, theta=0.0
% INFO    : Bus 12255	: V=0.9485055, theta=-72.063231 -> V=1.0, theta=0.0
% INFO    : Bus 12256	: V=0.955284, theta=-71.636472 -> V=1.0, theta=0.0
% INFO    : Bus 12257	: V=0.9559882, theta=-71.56867 -> V=1.0, theta=0.0
% INFO    : Bus 12258	: V=0.9556495, theta=-71.599666 -> V=1.0, theta=0.0
% INFO    : Bus 12259	: V=0.9515265, theta=-71.789769 -> V=1.0, theta=0.0
% INFO    : Bus 12260	: V=0.9566138, theta=-71.513223 -> V=1.0, theta=0.0
% INFO    : Bus 12261	: V=0.956245, theta=-71.543819 -> V=1.0, theta=0.0
% INFO    : Bus 12262	: V=0.9548218, theta=-71.313147 -> V=1.0, theta=0.0
% INFO    : Bus 12263	: V=0.954837, theta=-71.271733 -> V=1.0, theta=0.0
% INFO    : Bus 12264	: V=0.9543366, theta=-71.338286 -> V=1.0, theta=0.0
% INFO    : Bus 12265	: V=0.957322, theta=-70.304277 -> V=1.0, theta=0.0
% INFO    : Bus 12266	: V=0.9574424, theta=-70.268847 -> V=1.0, theta=0.0
% INFO    : Bus 12267	: V=0.9482796, theta=-71.990991 -> V=1.0, theta=0.0
% INFO    : Bus 12268	: V=0.9548589, theta=-71.078 -> V=1.0, theta=0.0
% INFO    : Bus 12269	: V=0.9556706, theta=-71.05454 -> V=1.0, theta=0.0
% INFO    : Bus 12270	: V=0.957731, theta=-70.183214 -> V=1.0, theta=0.0
% INFO    : Bus 12271	: V=0.9582041, theta=-70.041559 -> V=1.0, theta=0.0
% INFO    : Bus 12272	: V=0.9631939, theta=-70.854177 -> V=1.0, theta=0.0
% INFO    : Bus 12273	: V=0.9570999, theta=-71.420278 -> V=1.0, theta=0.0
% INFO    : Bus 12274	: V=0.958478, theta=-70.622642 -> V=1.0, theta=0.0
% INFO    : Bus 12275	: V=0.9564773, theta=-71.864326 -> V=1.0, theta=0.0
% INFO    : Bus 12276	: V=0.9550665, theta=-71.83503 -> V=1.0, theta=0.0
% INFO    : Bus 12277	: V=0.9556346, theta=-71.865016 -> V=1.0, theta=0.0
% INFO    : Bus 12278	: V=0.9458173, theta=-72.410486 -> V=1.0, theta=0.0
% INFO    : Bus 12279	: V=0.9483903, theta=-72.374575 -> V=1.0, theta=0.0
% INFO    : Bus 12280	: V=0.9906903, theta=-66.607663 -> V=1.0, theta=0.0
% INFO    : Bus 12281	: V=0.9656766, theta=-70.498187 -> V=1.0, theta=0.0
% INFO    : Bus 12282	: V=0.9653238, theta=-70.558449 -> V=1.0, theta=0.0
% INFO    : Bus 12283	: V=0.9666323, theta=-70.354013 -> V=1.0, theta=0.0
% INFO    : Bus 12284	: V=0.9672065, theta=-70.201852 -> V=1.0, theta=0.0
% INFO    : Bus 12285	: V=0.9813358, theta=-67.890067 -> V=1.0, theta=0.0
% INFO    : Bus 12286	: V=0.9567307, theta=-71.203787 -> V=1.0, theta=0.0
% INFO    : Bus 12287	: V=0.967237, theta=-69.383813 -> V=1.0, theta=0.0
% INFO    : Bus 12288	: V=0.9532424, theta=-70.812387 -> V=1.0, theta=0.0
% INFO    : Bus 12289	: V=0.9505102, theta=-71.783105 -> V=1.0, theta=0.0
% INFO    : Bus 12290	: V=0.9522344, theta=-71.733113 -> V=1.0, theta=0.0
% INFO    : Bus 12291	: V=0.9496507, theta=-71.268662 -> V=1.0, theta=0.0
% INFO    : Bus 12292	: V=0.9629879, theta=-69.762435 -> V=1.0, theta=0.0
% INFO    : Bus 12293	: V=0.9482319, theta=-71.548464 -> V=1.0, theta=0.0
% INFO    : Bus 12294	: V=0.9454029, theta=-71.756684 -> V=1.0, theta=0.0
% INFO    : Bus 12295	: V=0.9484183, theta=-72.126231 -> V=1.0, theta=0.0
% INFO    : Bus 12296	: V=0.9483367, theta=-72.162335 -> V=1.0, theta=0.0
% INFO    : Bus 12297	: V=0.959873, theta=-71.310417 -> V=1.0, theta=0.0
% INFO    : Bus 12298	: V=0.961444, theta=-69.305894 -> V=1.0, theta=0.0
% INFO    : Bus 12299	: V=0.9504254, theta=-71.405407 -> V=1.0, theta=0.0
% INFO    : Bus 12300	: V=0.9606075, theta=-69.43043 -> V=1.0, theta=0.0
% INFO    : Bus 12301	: V=0.9591862, theta=-69.731684 -> V=1.0, theta=0.0
% INFO    : Bus 12302	: V=0.963994, theta=-65.170235 -> V=1.0, theta=0.0
% INFO    : Bus 12303	: V=0.9593093, theta=-69.705837 -> V=1.0, theta=0.0
% INFO    : Bus 12304	: V=0.9815785, theta=-61.904044 -> V=1.0, theta=0.0
% INFO    : Bus 12305	: V=0.9768069, theta=-62.566096 -> V=1.0, theta=0.0
% INFO    : Bus 12306	: V=0.9775342, theta=-62.437354 -> V=1.0, theta=0.0
% INFO    : Bus 12307	: V=0.9783366, theta=-62.418165 -> V=1.0, theta=0.0
% INFO    : Bus 12308	: V=0.9817805, theta=-61.969204 -> V=1.0, theta=0.0
% INFO    : Bus 12309	: V=0.9820253, theta=-61.924502 -> V=1.0, theta=0.0
% INFO    : Bus 12310	: V=0.9810771, theta=-61.926075 -> V=1.0, theta=0.0
% INFO    : Bus 12311	: V=0.9775879, theta=-62.471158 -> V=1.0, theta=0.0
% INFO    : Bus 12312	: V=0.977949, theta=-62.43767 -> V=1.0, theta=0.0
% INFO    : Bus 12313	: V=0.9818237, theta=-61.91905 -> V=1.0, theta=0.0
% INFO    : Bus 12314	: V=0.9768741, theta=-62.60224 -> V=1.0, theta=0.0
% INFO    : Bus 12315	: V=0.9792423, theta=-62.184249 -> V=1.0, theta=0.0
% INFO    : Bus 12316	: V=0.97741, theta=-62.297233 -> V=1.0, theta=0.0
% INFO    : Bus 12317	: V=0.9618157, theta=-66.128359 -> V=1.0, theta=0.0
% INFO    : Bus 12318	: V=0.9624002, theta=-66.283789 -> V=1.0, theta=0.0
% INFO    : Bus 12319	: V=0.9664884, theta=-65.667001 -> V=1.0, theta=0.0
% INFO    : Bus 12320	: V=0.9618354, theta=-66.116067 -> V=1.0, theta=0.0
% INFO    : Bus 12321	: V=0.9607719, theta=-65.365448 -> V=1.0, theta=0.0
% INFO    : Bus 12322	: V=0.9628126, theta=-65.089447 -> V=1.0, theta=0.0
% INFO    : Bus 12323	: V=0.9682506, theta=-64.354298 -> V=1.0, theta=0.0
% INFO    : Bus 12324	: V=0.965387, theta=-64.096451 -> V=1.0, theta=0.0
% INFO    : Bus 12325	: V=0.9748281, theta=-63.457641 -> V=1.0, theta=0.0
% INFO    : Bus 12326	: V=0.9812156, theta=-62.629081 -> V=1.0, theta=0.0
% INFO    : Bus 12327	: V=0.9806834, theta=-62.689504 -> V=1.0, theta=0.0
% INFO    : Bus 12328	: V=0.9845786, theta=-62.216395 -> V=1.0, theta=0.0
% INFO    : Bus 12329	: V=0.9852895, theta=-61.877566 -> V=1.0, theta=0.0
% INFO    : Bus 12330	: V=0.9766964, theta=-62.980858 -> V=1.0, theta=0.0
% INFO    : Bus 12331	: V=0.9775036, theta=-62.672169 -> V=1.0, theta=0.0
% INFO    : Bus 12332	: V=0.9794568, theta=-62.427246 -> V=1.0, theta=0.0
% INFO    : Bus 12333	: V=0.9829728, theta=-61.60709 -> V=1.0, theta=0.0
% INFO    : Bus 12334	: V=0.9752241, theta=-62.802091 -> V=1.0, theta=0.0
% INFO    : Bus 12335	: V=0.9833782, theta=-61.530886 -> V=1.0, theta=0.0
% INFO    : Bus 12336	: V=0.97608, theta=-62.836476 -> V=1.0, theta=0.0
% INFO    : Bus 12337	: V=0.9755637, theta=-62.889553 -> V=1.0, theta=0.0
% INFO    : Bus 12338	: V=0.9748656, theta=-63.004952 -> V=1.0, theta=0.0
% INFO    : Bus 12339	: V=0.9704455, theta=-63.467023 -> V=1.0, theta=0.0
% INFO    : Bus 12340	: V=0.9792183, theta=-62.462557 -> V=1.0, theta=0.0
% INFO    : Bus 12341	: V=0.9728767, theta=-63.218359 -> V=1.0, theta=0.0
% INFO    : Bus 12342	: V=0.9773181, theta=-62.656592 -> V=1.0, theta=0.0
% INFO    : Bus 12343	: V=0.9610758, theta=-64.985009 -> V=1.0, theta=0.0
% INFO    : Bus 12344	: V=0.9742307, theta=-62.753478 -> V=1.0, theta=0.0
% INFO    : Bus 12345	: V=0.9803222, theta=-62.20529 -> V=1.0, theta=0.0
% INFO    : Bus 12346	: V=0.9606517, theta=-65.169578 -> V=1.0, theta=0.0
% INFO    : Bus 12347	: V=0.9784206, theta=-62.426221 -> V=1.0, theta=0.0
% INFO    : Bus 12348	: V=0.990244, theta=-60.722458 -> V=1.0, theta=0.0
% INFO    : Bus 12349	: V=0.9605431, theta=-65.155662 -> V=1.0, theta=0.0
% INFO    : Bus 12350	: V=0.9567874, theta=-65.804234 -> V=1.0, theta=0.0
% INFO    : Bus 12351	: V=0.9571125, theta=-65.954111 -> V=1.0, theta=0.0
% INFO    : Bus 12352	: V=0.9574644, theta=-65.880098 -> V=1.0, theta=0.0
% INFO    : Bus 12353	: V=0.9537772, theta=-66.200694 -> V=1.0, theta=0.0
% INFO    : Bus 12354	: V=0.9510438, theta=-66.457477 -> V=1.0, theta=0.0
% INFO    : Bus 12355	: V=0.956744, theta=-66.107497 -> V=1.0, theta=0.0
% INFO    : Bus 12356	: V=0.9585129, theta=-66.713992 -> V=1.0, theta=0.0
% INFO    : Bus 12357	: V=0.9567081, theta=-66.329086 -> V=1.0, theta=0.0
% INFO    : Bus 12358	: V=0.9566106, theta=-66.312902 -> V=1.0, theta=0.0
% INFO    : Bus 12359	: V=0.9494015, theta=-67.196686 -> V=1.0, theta=0.0
% INFO    : Bus 12360	: V=0.9567868, theta=-66.252409 -> V=1.0, theta=0.0
% INFO    : Bus 12361	: V=0.9587817, theta=-66.716978 -> V=1.0, theta=0.0
% INFO    : Bus 12362	: V=0.9892757, theta=-63.764447 -> V=1.0, theta=0.0
% INFO    : Bus 12363	: V=0.9858803, theta=-64.069098 -> V=1.0, theta=0.0
% INFO    : Bus 12364	: V=0.9791335, theta=-65.198009 -> V=1.0, theta=0.0
% INFO    : Bus 12365	: V=0.967536, theta=-64.288438 -> V=1.0, theta=0.0
% INFO    : Bus 12366	: V=0.9675543, theta=-64.230469 -> V=1.0, theta=0.0
% INFO    : Bus 12367	: V=0.9682562, theta=-64.116151 -> V=1.0, theta=0.0
% INFO    : Bus 12368	: V=0.9693383, theta=-63.990539 -> V=1.0, theta=0.0
% INFO    : Bus 12369	: V=0.9564132, theta=-66.642539 -> V=1.0, theta=0.0
% INFO    : Bus 12370	: V=0.9736594, theta=-63.055991 -> V=1.0, theta=0.0
% INFO    : Bus 12371	: V=0.971583, theta=-63.424049 -> V=1.0, theta=0.0
% INFO    : Bus 12372	: V=0.9799811, theta=-61.898888 -> V=1.0, theta=0.0
% INFO    : Bus 12373	: V=0.9726026, theta=-63.105077 -> V=1.0, theta=0.0
% INFO    : Bus 12374	: V=0.9773574, theta=-62.2278 -> V=1.0, theta=0.0
% INFO    : Bus 12375	: V=0.9827171, theta=-61.520386 -> V=1.0, theta=0.0
% INFO    : Bus 12376	: V=0.9880949, theta=-60.581921 -> V=1.0, theta=0.0
% INFO    : Bus 12377	: V=0.9788935, theta=-62.247911 -> V=1.0, theta=0.0
% INFO    : Bus 12378	: V=0.9805742, theta=-61.930269 -> V=1.0, theta=0.0
% INFO    : Bus 12379	: V=0.9833598, theta=-61.688121 -> V=1.0, theta=0.0
% INFO    : Bus 12380	: V=0.9833088, theta=-61.775869 -> V=1.0, theta=0.0
% INFO    : Bus 12381	: V=0.981485, theta=-62.050594 -> V=1.0, theta=0.0
% INFO    : Bus 12382	: V=0.9892534, theta=-60.660358 -> V=1.0, theta=0.0
% INFO    : Bus 12383	: V=0.9892921, theta=-60.613866 -> V=1.0, theta=0.0
% INFO    : Bus 12384	: V=0.9854632, theta=-61.455041 -> V=1.0, theta=0.0
% INFO    : Bus 12385	: V=0.9883888, theta=-60.811436 -> V=1.0, theta=0.0
% INFO    : Bus 12386	: V=0.994766, theta=-59.849765 -> V=1.0, theta=0.0
% INFO    : Bus 12387	: V=0.989903, theta=-60.54746 -> V=1.0, theta=0.0
% INFO    : Bus 12388	: V=0.9950489, theta=-60.011205 -> V=1.0, theta=0.0
% INFO    : Bus 12389	: V=0.9798867, theta=-61.875744 -> V=1.0, theta=0.0
% INFO    : Bus 12390	: V=0.9478837, theta=-67.320475 -> V=1.0, theta=0.0
% INFO    : Bus 12391	: V=0.9745563, theta=-62.567157 -> V=1.0, theta=0.0
% INFO    : Bus 12392	: V=0.9660887, theta=-64.503916 -> V=1.0, theta=0.0
% INFO    : Bus 12393	: V=0.9726908, theta=-62.77104 -> V=1.0, theta=0.0
% INFO    : Bus 12394	: V=0.9790389, theta=-61.444094 -> V=1.0, theta=0.0
% INFO    : Bus 12395	: V=0.9880172, theta=-60.279296 -> V=1.0, theta=0.0
% INFO    : Bus 12396	: V=0.9733522, theta=-61.969711 -> V=1.0, theta=0.0
% INFO    : Bus 12397	: V=1.0136397, theta=-55.868875 -> V=1.0, theta=0.0
% INFO    : Bus 12398	: V=1.003213, theta=-57.148036 -> V=1.0, theta=0.0
% INFO    : Bus 12399	: V=0.9886903, theta=-58.678202 -> V=1.0, theta=0.0
% INFO    : Bus 12400	: V=0.9908068, theta=-59.163351 -> V=1.0, theta=0.0
% INFO    : Bus 12401	: V=0.9775751, theta=-62.46885 -> V=1.0, theta=0.0
% INFO    : Bus 12402	: V=0.9676742, theta=-63.335819 -> V=1.0, theta=0.0
% INFO    : Bus 12403	: V=0.9601568, theta=-64.364109 -> V=1.0, theta=0.0
% INFO    : Bus 12404	: V=0.9684016, theta=-63.181479 -> V=1.0, theta=0.0
% INFO    : Bus 12405	: V=0.9608543, theta=-64.391378 -> V=1.0, theta=0.0
% INFO    : Bus 12406	: V=0.9605602, theta=-63.844601 -> V=1.0, theta=0.0
% INFO    : Bus 12407	: V=0.9607552, theta=-63.842153 -> V=1.0, theta=0.0
% INFO    : Bus 12408	: V=0.9604138, theta=-63.849288 -> V=1.0, theta=0.0
% INFO    : Bus 12409	: V=0.9692795, theta=-63.038792 -> V=1.0, theta=0.0
% INFO    : Bus 12410	: V=0.9642242, theta=-63.601492 -> V=1.0, theta=0.0
% INFO    : Bus 12411	: V=0.9464886, theta=-66.898143 -> V=1.0, theta=0.0
% INFO    : Bus 12412	: V=0.9520987, theta=-66.217801 -> V=1.0, theta=0.0
% INFO    : Bus 12413	: V=0.9650173, theta=-64.332676 -> V=1.0, theta=0.0
% INFO    : Bus 12414	: V=0.9490954, theta=-66.300036 -> V=1.0, theta=0.0
% INFO    : Bus 12415	: V=0.9658848, theta=-63.753187 -> V=1.0, theta=0.0
% INFO    : Bus 12416	: V=0.9704384, theta=-62.943268 -> V=1.0, theta=0.0
% INFO    : Bus 12417	: V=0.9597062, theta=-63.76698 -> V=1.0, theta=0.0
% INFO    : Bus 12418	: V=0.9595017, theta=-64.422666 -> V=1.0, theta=0.0
% INFO    : Bus 12419	: V=0.9666088, theta=-63.56328 -> V=1.0, theta=0.0
% INFO    : Bus 12420	: V=0.9598088, theta=-65.294445 -> V=1.0, theta=0.0
% INFO    : Bus 12421	: V=0.9601347, theta=-64.947019 -> V=1.0, theta=0.0
% INFO    : Bus 12422	: V=0.9715697, theta=-62.503978 -> V=1.0, theta=0.0
% INFO    : Bus 12423	: V=0.9812026, theta=-61.168682 -> V=1.0, theta=0.0
% INFO    : Bus 12424	: V=0.9702353, theta=-62.202204 -> V=1.0, theta=0.0
% INFO    : Bus 12425	: V=0.9766947, theta=-61.315491 -> V=1.0, theta=0.0
% INFO    : Bus 12426	: V=0.9623387, theta=-64.957098 -> V=1.0, theta=0.0
% INFO    : Bus 12427	: V=0.9640952, theta=-64.714179 -> V=1.0, theta=0.0
% INFO    : Bus 12428	: V=0.9759968, theta=-62.486549 -> V=1.0, theta=0.0
% INFO    : Bus 12429	: V=0.9764596, theta=-62.446814 -> V=1.0, theta=0.0
% INFO    : Bus 12430	: V=0.9836556, theta=-64.742157 -> V=1.0, theta=0.0
% INFO    : Bus 12431	: V=0.9950976, theta=-63.24703 -> V=1.0, theta=0.0
% INFO    : Bus 12432	: V=0.994975, theta=-63.226015 -> V=1.0, theta=0.0
% INFO    : Bus 12433	: V=0.9879869, theta=-64.656719 -> V=1.0, theta=0.0
% INFO    : Bus 12434	: V=0.9971483, theta=-63.108184 -> V=1.0, theta=0.0
% INFO    : Bus 12435	: V=0.99894, theta=-63.002508 -> V=1.0, theta=0.0
% INFO    : Bus 12436	: V=0.9874813, theta=-63.517793 -> V=1.0, theta=0.0
% INFO    : Bus 12437	: V=0.9912969, theta=-63.683749 -> V=1.0, theta=0.0
% INFO    : Bus 12438	: V=0.9919485, theta=-63.422202 -> V=1.0, theta=0.0
% INFO    : Bus 12439	: V=1.0048314, theta=-60.25265 -> V=1.0, theta=0.0
% INFO    : Bus 12440	: V=0.9908712, theta=-63.282843 -> V=1.0, theta=0.0
% INFO    : Bus 12441	: V=0.9903842, theta=-63.418007 -> V=1.0, theta=0.0
% INFO    : Bus 12442	: V=0.9920659, theta=-63.359084 -> V=1.0, theta=0.0
% INFO    : Bus 12443	: V=0.9785831, theta=-65.225296 -> V=1.0, theta=0.0
% INFO    : Bus 12444	: V=1.0080953, theta=-62.001118 -> V=1.0, theta=0.0
% INFO    : Bus 12445	: V=1.0016969, theta=-62.962695 -> V=1.0, theta=0.0
% INFO    : Bus 12446	: V=1.0013951, theta=-62.99757 -> V=1.0, theta=0.0
% INFO    : Bus 12447	: V=0.9834231, theta=-65.201444 -> V=1.0, theta=0.0
% INFO    : Bus 12448	: V=0.9903046, theta=-63.812551 -> V=1.0, theta=0.0
% INFO    : Bus 12449	: V=0.9934539, theta=-63.515855 -> V=1.0, theta=0.0
% INFO    : Bus 12450	: V=1.001023, theta=-62.880472 -> V=1.0, theta=0.0
% INFO    : Bus 12451	: V=0.9962493, theta=-63.208789 -> V=1.0, theta=0.0
% INFO    : Bus 12452	: V=0.9775157, theta=-65.252321 -> V=1.0, theta=0.0
% INFO    : Bus 12453	: V=0.993926, theta=-63.278209 -> V=1.0, theta=0.0
% INFO    : Bus 12454	: V=0.9710988, theta=-65.461858 -> V=1.0, theta=0.0
% INFO    : Bus 12455	: V=0.9633859, theta=-65.948372 -> V=1.0, theta=0.0
% INFO    : Bus 12456	: V=0.9640798, theta=-65.902101 -> V=1.0, theta=0.0
% INFO    : Bus 12457	: V=0.9663065, theta=-65.128495 -> V=1.0, theta=0.0
% INFO    : Bus 12458	: V=0.971885, theta=-65.162531 -> V=1.0, theta=0.0
% INFO    : Bus 12459	: V=0.9707677, theta=-65.382955 -> V=1.0, theta=0.0
% INFO    : Bus 12460	: V=0.9709271, theta=-65.440955 -> V=1.0, theta=0.0
% INFO    : Bus 12461	: V=0.9846495, theta=-63.770505 -> V=1.0, theta=0.0
% INFO    : Bus 12462	: V=0.9956482, theta=-62.275314 -> V=1.0, theta=0.0
% INFO    : Bus 12463	: V=0.9882203, theta=-63.340893 -> V=1.0, theta=0.0
% INFO    : Bus 12464	: V=0.9879897, theta=-63.361543 -> V=1.0, theta=0.0
% INFO    : Bus 12465	: V=0.9873696, theta=-63.386876 -> V=1.0, theta=0.0
% INFO    : Bus 12466	: V=0.9881295, theta=-63.306297 -> V=1.0, theta=0.0
% INFO    : Bus 12467	: V=0.9948572, theta=-62.385455 -> V=1.0, theta=0.0
% INFO    : Bus 12468	: V=0.9882553, theta=-63.334593 -> V=1.0, theta=0.0
% INFO    : Bus 12469	: V=0.9879778, theta=-63.339066 -> V=1.0, theta=0.0
% INFO    : Bus 12470	: V=0.9878492, theta=-63.360999 -> V=1.0, theta=0.0
% INFO    : Bus 12471	: V=0.9951349, theta=-62.173691 -> V=1.0, theta=0.0
% INFO    : Bus 12472	: V=0.9953285, theta=-62.202918 -> V=1.0, theta=0.0
% INFO    : Bus 12473	: V=0.9958703, theta=-62.106562 -> V=1.0, theta=0.0
% INFO    : Bus 12474	: V=0.9874507, theta=-63.310835 -> V=1.0, theta=0.0
% INFO    : Bus 12475	: V=0.9948263, theta=-62.380227 -> V=1.0, theta=0.0
% INFO    : Bus 12476	: V=0.9948313, theta=-62.374255 -> V=1.0, theta=0.0
% INFO    : Bus 12477	: V=0.9881075, theta=-63.324397 -> V=1.0, theta=0.0
% INFO    : Bus 12478	: V=0.9948887, theta=-62.35798 -> V=1.0, theta=0.0
% INFO    : Bus 12479	: V=0.9879298, theta=-63.335768 -> V=1.0, theta=0.0
% INFO    : Bus 12480	: V=0.988084, theta=-63.318734 -> V=1.0, theta=0.0
% INFO    : Bus 12481	: V=0.9871815, theta=-63.359782 -> V=1.0, theta=0.0
% INFO    : Bus 12482	: V=0.9952021, theta=-62.314842 -> V=1.0, theta=0.0
% INFO    : Bus 12483	: V=0.9874994, theta=-63.267166 -> V=1.0, theta=0.0
% INFO    : Bus 12484	: V=0.9959, theta=-62.222139 -> V=1.0, theta=0.0
% INFO    : Bus 12485	: V=0.9835261, theta=-64.167575 -> V=1.0, theta=0.0
% INFO    : Bus 12486	: V=0.9949553, theta=-62.493535 -> V=1.0, theta=0.0
% INFO    : Bus 12487	: V=0.9950184, theta=-62.634162 -> V=1.0, theta=0.0
% INFO    : Bus 12488	: V=0.9958061, theta=-62.833986 -> V=1.0, theta=0.0
% INFO    : Bus 12489	: V=0.9996926, theta=-61.682796 -> V=1.0, theta=0.0
% INFO    : Bus 12490	: V=0.9985402, theta=-61.977628 -> V=1.0, theta=0.0
% INFO    : Bus 12491	: V=0.995127, theta=-62.534335 -> V=1.0, theta=0.0
% INFO    : Bus 12492	: V=0.9950811, theta=-62.578842 -> V=1.0, theta=0.0
% INFO    : Bus 12493	: V=0.9921854, theta=-62.466498 -> V=1.0, theta=0.0
% INFO    : Bus 12494	: V=0.9946055, theta=-62.423161 -> V=1.0, theta=0.0
% INFO    : Bus 12495	: V=0.9958145, theta=-62.768357 -> V=1.0, theta=0.0
% INFO    : Bus 12496	: V=0.993398, theta=-63.018791 -> V=1.0, theta=0.0
% INFO    : Bus 12497	: V=0.9974125, theta=-62.059482 -> V=1.0, theta=0.0
% INFO    : Bus 12498	: V=0.9875102, theta=-63.315681 -> V=1.0, theta=0.0
% INFO    : Bus 12499	: V=0.9897995, theta=-63.021754 -> V=1.0, theta=0.0
% INFO    : Bus 12500	: V=0.9978332, theta=-62.031432 -> V=1.0, theta=0.0
% INFO    : Bus 12501	: V=0.9944573, theta=-62.951565 -> V=1.0, theta=0.0
% INFO    : Bus 12502	: V=0.9929203, theta=-63.068308 -> V=1.0, theta=0.0
% INFO    : Bus 12503	: V=0.9960699, theta=-62.213174 -> V=1.0, theta=0.0
% INFO    : Bus 12504	: V=0.9987703, theta=-61.906725 -> V=1.0, theta=0.0
% INFO    : Bus 12505	: V=1.0008795, theta=-61.622147 -> V=1.0, theta=0.0
% INFO    : Bus 12506	: V=0.9980204, theta=-61.933401 -> V=1.0, theta=0.0
% INFO    : Bus 12507	: V=0.9853819, theta=-63.420442 -> V=1.0, theta=0.0
% INFO    : Bus 12508	: V=0.9971602, theta=-62.225859 -> V=1.0, theta=0.0
% INFO    : Bus 12509	: V=1.0109834, theta=-59.743938 -> V=1.0, theta=0.0
% INFO    : Bus 12510	: V=1.0183747, theta=-57.875542 -> V=1.0, theta=0.0
% INFO    : Bus 12511	: V=0.9952274, theta=-62.523361 -> V=1.0, theta=0.0
% INFO    : Bus 12512	: V=0.9883798, theta=-63.010908 -> V=1.0, theta=0.0
% INFO    : Bus 12513	: V=0.9960994, theta=-62.14687 -> V=1.0, theta=0.0
% INFO    : Bus 12514	: V=0.997086, theta=-62.047546 -> V=1.0, theta=0.0
% INFO    : Bus 12515	: V=0.9919413, theta=-62.645501 -> V=1.0, theta=0.0
% INFO    : Bus 12516	: V=0.9957884, theta=-62.303049 -> V=1.0, theta=0.0
% INFO    : Bus 12517	: V=0.9828371, theta=-63.535409 -> V=1.0, theta=0.0
% INFO    : Bus 12518	: V=0.9877945, theta=-62.938817 -> V=1.0, theta=0.0
% INFO    : Bus 12519	: V=0.990024, theta=-62.778793 -> V=1.0, theta=0.0
% INFO    : Bus 12520	: V=0.9826707, theta=-63.548369 -> V=1.0, theta=0.0
% INFO    : Bus 12521	: V=0.9859273, theta=-63.538521 -> V=1.0, theta=0.0
% INFO    : Bus 12522	: V=0.9857041, theta=-63.371475 -> V=1.0, theta=0.0
% INFO    : Bus 12523	: V=0.995443, theta=-62.205393 -> V=1.0, theta=0.0
% INFO    : Bus 12524	: V=0.9855847, theta=-63.584352 -> V=1.0, theta=0.0
% INFO    : Bus 12525	: V=0.9848412, theta=-63.18553 -> V=1.0, theta=0.0
% INFO    : Bus 12526	: V=0.9944614, theta=-62.177481 -> V=1.0, theta=0.0
% INFO    : Bus 12527	: V=0.9842263, theta=-63.323232 -> V=1.0, theta=0.0
% INFO    : Bus 12528	: V=0.9841611, theta=-63.379991 -> V=1.0, theta=0.0
% INFO    : Bus 12529	: V=0.9888392, theta=-62.67717 -> V=1.0, theta=0.0
% INFO    : Bus 12530	: V=0.9862085, theta=-63.516466 -> V=1.0, theta=0.0
% INFO    : Bus 12531	: V=0.9857193, theta=-63.524742 -> V=1.0, theta=0.0
% INFO    : Bus 12532	: V=0.9849271, theta=-63.691737 -> V=1.0, theta=0.0
% INFO    : Bus 12533	: V=0.9843038, theta=-63.715498 -> V=1.0, theta=0.0
% INFO    : Bus 12534	: V=0.9841283, theta=-63.704931 -> V=1.0, theta=0.0
% INFO    : Bus 12535	: V=0.9865598, theta=-63.464821 -> V=1.0, theta=0.0
% INFO    : Bus 12536	: V=0.9879494, theta=-63.343837 -> V=1.0, theta=0.0
% INFO    : Bus 12537	: V=0.973019, theta=-65.342528 -> V=1.0, theta=0.0
% INFO    : Bus 12538	: V=0.9711766, theta=-65.912444 -> V=1.0, theta=0.0
% INFO    : Bus 12539	: V=0.9722954, theta=-65.604379 -> V=1.0, theta=0.0
% INFO    : Bus 12540	: V=0.9732732, theta=-65.345365 -> V=1.0, theta=0.0
% INFO    : Bus 12541	: V=0.9737723, theta=-65.190363 -> V=1.0, theta=0.0
% INFO    : Bus 12542	: V=0.9751992, theta=-64.807702 -> V=1.0, theta=0.0
% INFO    : Bus 12543	: V=0.9746035, theta=-64.963737 -> V=1.0, theta=0.0
% INFO    : Bus 12544	: V=0.9735392, theta=-65.161214 -> V=1.0, theta=0.0
% INFO    : Bus 12545	: V=0.9734251, theta=-65.173109 -> V=1.0, theta=0.0
% INFO    : Bus 12546	: V=0.9733833, theta=-65.187067 -> V=1.0, theta=0.0
% INFO    : Bus 12547	: V=0.9727236, theta=-65.377081 -> V=1.0, theta=0.0
% INFO    : Bus 12548	: V=0.9722794, theta=-65.499091 -> V=1.0, theta=0.0
% INFO    : Bus 12549	: V=0.9716628, theta=-65.686572 -> V=1.0, theta=0.0
% INFO    : Bus 12550	: V=0.9734583, theta=-65.19403 -> V=1.0, theta=0.0
% INFO    : Bus 12551	: V=0.9715616, theta=-65.714 -> V=1.0, theta=0.0
% INFO    : Bus 12552	: V=0.973436, theta=-66.077833 -> V=1.0, theta=0.0
% INFO    : Bus 12553	: V=0.9551249, theta=-69.471257 -> V=1.0, theta=0.0
% INFO    : Bus 12554	: V=0.951764, theta=-69.559806 -> V=1.0, theta=0.0
% INFO    : Bus 12555	: V=0.9567005, theta=-69.471835 -> V=1.0, theta=0.0
% INFO    : Bus 12556	: V=0.9592453, theta=-69.349365 -> V=1.0, theta=0.0
% INFO    : Bus 12557	: V=0.9619853, theta=-69.044575 -> V=1.0, theta=0.0
% INFO    : Bus 12558	: V=0.9599325, theta=-69.170159 -> V=1.0, theta=0.0
% INFO    : Bus 12559	: V=0.9592046, theta=-69.394837 -> V=1.0, theta=0.0
% INFO    : Bus 12560	: V=0.9594027, theta=-69.290149 -> V=1.0, theta=0.0
% INFO    : Bus 12561	: V=0.9597873, theta=-69.173519 -> V=1.0, theta=0.0
% INFO    : Bus 12562	: V=0.959077, theta=-69.325552 -> V=1.0, theta=0.0
% INFO    : Bus 12563	: V=0.9635029, theta=-68.45231 -> V=1.0, theta=0.0
% INFO    : Bus 12564	: V=0.9602011, theta=-69.24251 -> V=1.0, theta=0.0
% INFO    : Bus 12565	: V=0.9590053, theta=-68.85099 -> V=1.0, theta=0.0
% INFO    : Bus 12566	: V=0.9612334, theta=-69.048153 -> V=1.0, theta=0.0
% INFO    : Bus 12567	: V=0.9659073, theta=-68.436797 -> V=1.0, theta=0.0
% INFO    : Bus 12568	: V=0.9607998, theta=-69.057387 -> V=1.0, theta=0.0
% INFO    : Bus 12569	: V=0.9643614, theta=-67.392854 -> V=1.0, theta=0.0
% INFO    : Bus 12570	: V=0.9616677, theta=-67.992539 -> V=1.0, theta=0.0
% INFO    : Bus 12571	: V=0.9607442, theta=-68.930104 -> V=1.0, theta=0.0
% INFO    : Bus 12572	: V=0.9610356, theta=-68.53842 -> V=1.0, theta=0.0
% INFO    : Bus 12573	: V=0.9652207, theta=-68.222802 -> V=1.0, theta=0.0
% INFO    : Bus 12574	: V=0.9607588, theta=-68.728416 -> V=1.0, theta=0.0
% INFO    : Bus 12575	: V=0.965187, theta=-67.889898 -> V=1.0, theta=0.0
% INFO    : Bus 12576	: V=0.9652968, theta=-67.591851 -> V=1.0, theta=0.0
% INFO    : Bus 12577	: V=0.9674442, theta=-67.000668 -> V=1.0, theta=0.0
% INFO    : Bus 12578	: V=0.9710285, theta=-65.752486 -> V=1.0, theta=0.0
% INFO    : Bus 12579	: V=0.9694402, theta=-66.420232 -> V=1.0, theta=0.0
% INFO    : Bus 12580	: V=0.9707946, theta=-65.951881 -> V=1.0, theta=0.0
% INFO    : Bus 12581	: V=0.9668147, theta=-67.297658 -> V=1.0, theta=0.0
% INFO    : Bus 12582	: V=0.9651649, theta=-68.025378 -> V=1.0, theta=0.0
% INFO    : Bus 12583	: V=0.9635121, theta=-67.773451 -> V=1.0, theta=0.0
% INFO    : Bus 12584	: V=0.968444, theta=-66.732618 -> V=1.0, theta=0.0
% INFO    : Bus 12585	: V=0.9638515, theta=-67.513654 -> V=1.0, theta=0.0
% INFO    : Bus 12586	: V=0.9654582, theta=-67.420553 -> V=1.0, theta=0.0
% INFO    : Bus 12587	: V=0.9654761, theta=-67.444482 -> V=1.0, theta=0.0
% INFO    : Bus 12588	: V=0.9655176, theta=-67.381008 -> V=1.0, theta=0.0
% INFO    : Bus 12589	: V=0.9694796, theta=-66.412758 -> V=1.0, theta=0.0
% INFO    : Bus 12590	: V=0.9639448, theta=-67.681031 -> V=1.0, theta=0.0
% INFO    : Bus 12591	: V=0.963452, theta=-67.48753 -> V=1.0, theta=0.0
% INFO    : Bus 12592	: V=0.9737811, theta=-65.298189 -> V=1.0, theta=0.0
% INFO    : Bus 12593	: V=0.974591, theta=-65.146479 -> V=1.0, theta=0.0
% INFO    : Bus 12594	: V=0.9752766, theta=-65.006082 -> V=1.0, theta=0.0
% INFO    : Bus 12595	: V=0.9691554, theta=-66.609367 -> V=1.0, theta=0.0
% INFO    : Bus 12596	: V=0.9718273, theta=-65.242088 -> V=1.0, theta=0.0
% INFO    : Bus 12597	: V=0.972137, theta=-65.237538 -> V=1.0, theta=0.0
% INFO    : Bus 12598	: V=0.9790828, theta=-64.257365 -> V=1.0, theta=0.0
% INFO    : Bus 12599	: V=0.9726096, theta=-65.229368 -> V=1.0, theta=0.0
% INFO    : Bus 12600	: V=0.9805682, theta=-64.011939 -> V=1.0, theta=0.0
% INFO    : Bus 12601	: V=0.9735647, theta=-65.095342 -> V=1.0, theta=0.0
% INFO    : Bus 12602	: V=0.9748785, theta=-65.041695 -> V=1.0, theta=0.0
% INFO    : Bus 12603	: V=0.9799336, theta=-63.629957 -> V=1.0, theta=0.0
% INFO    : Bus 12604	: V=0.9759778, theta=-64.739526 -> V=1.0, theta=0.0
% INFO    : Bus 12605	: V=0.9767894, theta=-64.397576 -> V=1.0, theta=0.0
% INFO    : Bus 12606	: V=0.9739695, theta=-65.016852 -> V=1.0, theta=0.0
% INFO    : Bus 12607	: V=0.97302, theta=-65.274784 -> V=1.0, theta=0.0
% INFO    : Bus 12608	: V=0.9900371, theta=-61.536516 -> V=1.0, theta=0.0
% INFO    : Bus 12609	: V=0.980878, theta=-63.363751 -> V=1.0, theta=0.0
% INFO    : Bus 12610	: V=0.9866301, theta=-62.134649 -> V=1.0, theta=0.0
% INFO    : Bus 12611	: V=0.9849449, theta=-62.500646 -> V=1.0, theta=0.0
% INFO    : Bus 12612	: V=1.0077001, theta=-57.786705 -> V=1.0, theta=0.0
% INFO    : Bus 12613	: V=0.9843149, theta=-63.026812 -> V=1.0, theta=0.0
% INFO    : Bus 12614	: V=0.9881605, theta=-62.908249 -> V=1.0, theta=0.0
% INFO    : Bus 12615	: V=0.9899062, theta=-62.321399 -> V=1.0, theta=0.0
% INFO    : Bus 12616	: V=0.96131, theta=-68.348974 -> V=1.0, theta=0.0
% INFO    : Bus 12617	: V=0.962451, theta=-68.063355 -> V=1.0, theta=0.0
% INFO    : Bus 12618	: V=0.9915118, theta=-61.829606 -> V=1.0, theta=0.0
% INFO    : Bus 12619	: V=1.0161157, theta=-56.416284 -> V=1.0, theta=0.0
% INFO    : Bus 12620	: V=1.0195032, theta=-55.357227 -> V=1.0, theta=0.0
% INFO    : Bus 12621	: V=0.9978508, theta=-59.916258 -> V=1.0, theta=0.0
% INFO    : Bus 12622	: V=1.0186216, theta=-56.552571 -> V=1.0, theta=0.0
% INFO    : Bus 12623	: V=1.0185925, theta=-56.552253 -> V=1.0, theta=0.0
% INFO    : Bus 12624	: V=1.0066858, theta=-58.662054 -> V=1.0, theta=0.0
% INFO    : Bus 12625	: V=1.0005125, theta=-59.821402 -> V=1.0, theta=0.0
% INFO    : Bus 12626	: V=0.9947448, theta=-60.735487 -> V=1.0, theta=0.0
% INFO    : Bus 12627	: V=1.0075348, theta=-58.758466 -> V=1.0, theta=0.0
% INFO    : Bus 12628	: V=1.0190094, theta=-56.49489 -> V=1.0, theta=0.0
% INFO    : Bus 12629	: V=1.0141323, theta=-57.618481 -> V=1.0, theta=0.0
% INFO    : Bus 12630	: V=1.0116865, theta=-58.18404 -> V=1.0, theta=0.0
% INFO    : Bus 12631	: V=1.0114256, theta=-58.171738 -> V=1.0, theta=0.0
% INFO    : Bus 12632	: V=1.011081, theta=-58.325594 -> V=1.0, theta=0.0
% INFO    : Bus 12633	: V=1.0182991, theta=-57.423525 -> V=1.0, theta=0.0
% INFO    : Bus 12634	: V=1.0179116, theta=-57.452398 -> V=1.0, theta=0.0
% INFO    : Bus 12635	: V=1.0121296, theta=-58.141863 -> V=1.0, theta=0.0
% INFO    : Bus 12636	: V=1.0130475, theta=-57.840316 -> V=1.0, theta=0.0
% INFO    : Bus 12637	: V=1.0131019, theta=-57.83157 -> V=1.0, theta=0.0
% INFO    : Bus 12638	: V=1.014144, theta=-57.606658 -> V=1.0, theta=0.0
% INFO    : Bus 12639	: V=0.9770391, theta=-64.647388 -> V=1.0, theta=0.0
% INFO    : Bus 12640	: V=1.0186521, theta=-56.55247 -> V=1.0, theta=0.0
% INFO    : Bus 12641	: V=0.9707461, theta=-70.64616 -> V=1.0, theta=0.0
% INFO    : Bus 12642	: V=0.972498, theta=-70.547857 -> V=1.0, theta=0.0
% INFO    : Bus 12643	: V=0.961711, theta=-72.073652 -> V=1.0, theta=0.0
% INFO    : Bus 12644	: V=0.9754593, theta=-69.877094 -> V=1.0, theta=0.0
% INFO    : Bus 12645	: V=0.973246, theta=-70.542781 -> V=1.0, theta=0.0
% INFO    : Bus 12646	: V=0.9726801, theta=-70.552726 -> V=1.0, theta=0.0
% INFO    : Bus 12647	: V=0.9756971, theta=-69.831807 -> V=1.0, theta=0.0
% INFO    : Bus 12648	: V=0.9963527, theta=-66.157585 -> V=1.0, theta=0.0
% INFO    : Bus 12649	: V=0.9773578, theta=-69.645263 -> V=1.0, theta=0.0
% INFO    : Bus 12650	: V=0.9525451, theta=-76.027989 -> V=1.0, theta=0.0
% INFO    : Bus 12651	: V=0.9363227, theta=-73.320142 -> V=1.0, theta=0.0
% INFO    : Bus 12652	: V=0.9689295, theta=-70.61335 -> V=1.0, theta=0.0
% INFO    : Bus 12653	: V=0.9579999, theta=-73.81275 -> V=1.0, theta=0.0
% INFO    : Bus 12654	: V=0.9749031, theta=-69.865264 -> V=1.0, theta=0.0
% INFO    : Bus 12655	: V=0.9609207, theta=-69.872358 -> V=1.0, theta=0.0
% INFO    : Bus 12656	: V=0.9664486, theta=-70.37429 -> V=1.0, theta=0.0
% INFO    : Bus 12657	: V=0.9588233, theta=-71.249898 -> V=1.0, theta=0.0
% INFO    : Bus 12658	: V=0.9688057, theta=-70.426256 -> V=1.0, theta=0.0
% INFO    : Bus 12659	: V=0.9699401, theta=-70.397413 -> V=1.0, theta=0.0
% INFO    : Bus 12660	: V=0.9714449, theta=-70.291593 -> V=1.0, theta=0.0
% INFO    : Bus 12661	: V=0.975182, theta=-69.908731 -> V=1.0, theta=0.0
% INFO    : Bus 12662	: V=0.9728056, theta=-70.126219 -> V=1.0, theta=0.0
% INFO    : Bus 12663	: V=0.9670122, theta=-71.77139 -> V=1.0, theta=0.0
% INFO    : Bus 12664	: V=0.9724622, theta=-70.01272 -> V=1.0, theta=0.0
% INFO    : Bus 12665	: V=0.9751016, theta=-70.291105 -> V=1.0, theta=0.0
% INFO    : Bus 12666	: V=0.972865, theta=-70.599185 -> V=1.0, theta=0.0
% INFO    : Bus 12667	: V=0.9720649, theta=-70.181197 -> V=1.0, theta=0.0
% INFO    : Bus 12668	: V=0.9587873, theta=-71.076908 -> V=1.0, theta=0.0
% INFO    : Bus 12669	: V=0.9650758, theta=-71.115609 -> V=1.0, theta=0.0
% INFO    : Bus 12670	: V=0.9922234, theta=-74.258172 -> V=1.0, theta=0.0
% INFO    : Bus 12671	: V=0.9888986, theta=-74.840145 -> V=1.0, theta=0.0
% INFO    : Bus 12672	: V=0.9892288, theta=-74.778935 -> V=1.0, theta=0.0
% INFO    : Bus 12673	: V=0.9884963, theta=-74.927661 -> V=1.0, theta=0.0
% INFO    : Bus 12674	: V=0.9771111, theta=-75.659391 -> V=1.0, theta=0.0
% INFO    : Bus 12675	: V=0.9630771, theta=-76.21499 -> V=1.0, theta=0.0
% INFO    : Bus 12676	: V=0.9420868, theta=-78.426699 -> V=1.0, theta=0.0
% INFO    : Bus 12677	: V=0.9442366, theta=-77.37135 -> V=1.0, theta=0.0
% INFO    : Bus 12678	: V=0.9542444, theta=-76.269656 -> V=1.0, theta=0.0
% INFO    : Bus 12679	: V=0.9962189, theta=-73.580545 -> V=1.0, theta=0.0
% INFO    : Bus 12680	: V=0.9692828, theta=-73.947547 -> V=1.0, theta=0.0
% INFO    : Bus 12681	: V=0.9807722, theta=-73.294319 -> V=1.0, theta=0.0
% INFO    : Bus 12682	: V=0.9415807, theta=-71.648386 -> V=1.0, theta=0.0
% INFO    : Bus 12683	: V=0.9407702, theta=-71.740734 -> V=1.0, theta=0.0
% INFO    : Bus 12684	: V=0.9398384, theta=-71.78532 -> V=1.0, theta=0.0
% INFO    : Bus 12685	: V=0.9425983, theta=-69.75967 -> V=1.0, theta=0.0
% INFO    : Bus 12686	: V=0.9433266, theta=-69.73837 -> V=1.0, theta=0.0
% INFO    : Bus 12687	: V=0.9433362, theta=-69.850326 -> V=1.0, theta=0.0
% INFO    : Bus 12688	: V=0.9613823, theta=-64.9875 -> V=1.0, theta=0.0
% INFO    : Bus 12689	: V=0.9489533, theta=-66.536474 -> V=1.0, theta=0.0
% INFO    : Bus 12690	: V=0.939594, theta=-69.973962 -> V=1.0, theta=0.0
% INFO    : Bus 12691	: V=0.9389839, theta=-69.992264 -> V=1.0, theta=0.0
% INFO    : Bus 12692	: V=0.9518466, theta=-74.982829 -> V=1.0, theta=0.0
% INFO    : Bus 12693	: V=0.95119, theta=-69.853069 -> V=1.0, theta=0.0
% INFO    : Bus 12694	: V=0.9533, theta=-69.008163 -> V=1.0, theta=0.0
% INFO    : Bus 12695	: V=0.9512311, theta=-73.633724 -> V=1.0, theta=0.0
% INFO    : Bus 12696	: V=0.9519415, theta=-73.511232 -> V=1.0, theta=0.0
% INFO    : Bus 12697	: V=0.938348, theta=-72.574351 -> V=1.0, theta=0.0
% INFO    : Bus 12698	: V=0.9527975, theta=-69.082699 -> V=1.0, theta=0.0
% INFO    : Bus 12699	: V=0.9533369, theta=-76.228594 -> V=1.0, theta=0.0
% INFO    : Bus 12700	: V=0.9522821, theta=-68.188677 -> V=1.0, theta=0.0
% INFO    : Bus 12701	: V=0.9599627, theta=-67.185905 -> V=1.0, theta=0.0
% INFO    : Bus 12702	: V=0.9615707, theta=-66.546607 -> V=1.0, theta=0.0
% INFO    : Bus 12703	: V=0.9636293, theta=-63.887652 -> V=1.0, theta=0.0
% INFO    : Bus 12704	: V=0.9604388, theta=-65.972128 -> V=1.0, theta=0.0
% INFO    : Bus 12705	: V=0.9782475, theta=-67.406806 -> V=1.0, theta=0.0
% INFO    : Bus 12706	: V=0.9591363, theta=-68.022847 -> V=1.0, theta=0.0
% INFO    : Bus 12707	: V=0.9591708, theta=-67.908945 -> V=1.0, theta=0.0
% INFO    : Bus 12708	: V=0.964235, theta=-65.508335 -> V=1.0, theta=0.0
% INFO    : Bus 12709	: V=0.9473832, theta=-68.937459 -> V=1.0, theta=0.0
% INFO    : Bus 12710	: V=0.9412797, theta=-72.088446 -> V=1.0, theta=0.0
% INFO    : Bus 12711	: V=0.9491788, theta=-68.621302 -> V=1.0, theta=0.0
% INFO    : Bus 12712	: V=0.9526712, theta=-69.769563 -> V=1.0, theta=0.0
% INFO    : Bus 12713	: V=0.9628493, theta=-68.083485 -> V=1.0, theta=0.0
% INFO    : Bus 12714	: V=0.9748309, theta=-64.853965 -> V=1.0, theta=0.0
% INFO    : Bus 12715	: V=0.9882523, theta=-63.354045 -> V=1.0, theta=0.0
% INFO    : Bus 12716	: V=0.9811897, theta=-63.998767 -> V=1.0, theta=0.0
% INFO    : Bus 12717	: V=0.9684669, theta=-67.057376 -> V=1.0, theta=0.0
% INFO    : Bus 12718	: V=0.9500423, theta=-69.845606 -> V=1.0, theta=0.0
% INFO    : Bus 12719	: V=0.9499292, theta=-69.85761 -> V=1.0, theta=0.0
% INFO    : Bus 12720	: V=0.9521345, theta=-69.792047 -> V=1.0, theta=0.0
% INFO    : Bus 12721	: V=0.9630306, theta=-67.958914 -> V=1.0, theta=0.0
% INFO    : Bus 12722	: V=0.9618403, theta=-68.132234 -> V=1.0, theta=0.0
% INFO    : Bus 12723	: V=0.9505417, theta=-69.843162 -> V=1.0, theta=0.0
% INFO    : Bus 12724	: V=0.9638156, theta=-67.494995 -> V=1.0, theta=0.0
% INFO    : Bus 12725	: V=0.9639896, theta=-67.481503 -> V=1.0, theta=0.0
% INFO    : Bus 12726	: V=0.9637576, theta=-67.474425 -> V=1.0, theta=0.0
% INFO    : Bus 12727	: V=0.959141, theta=-67.371407 -> V=1.0, theta=0.0
% INFO    : Bus 12728	: V=0.9673949, theta=-66.339291 -> V=1.0, theta=0.0
% INFO    : Bus 12729	: V=0.9741072, theta=-64.43677 -> V=1.0, theta=0.0
% INFO    : Bus 12730	: V=0.9574251, theta=-68.281874 -> V=1.0, theta=0.0
% INFO    : Bus 12731	: V=0.9643333, theta=-67.215576 -> V=1.0, theta=0.0
% INFO    : Bus 12732	: V=0.964937, theta=-67.047454 -> V=1.0, theta=0.0
% INFO    : Bus 12733	: V=0.971715, theta=-65.293022 -> V=1.0, theta=0.0
% INFO    : Bus 12734	: V=0.9704149, theta=-64.840471 -> V=1.0, theta=0.0
% INFO    : Bus 12735	: V=0.9752969, theta=-64.556568 -> V=1.0, theta=0.0
% INFO    : Bus 12736	: V=0.96428, theta=-67.030092 -> V=1.0, theta=0.0
% INFO    : Bus 12737	: V=0.9758931, theta=-64.436355 -> V=1.0, theta=0.0
% INFO    : Bus 12738	: V=0.9781349, theta=-63.977973 -> V=1.0, theta=0.0
% INFO    : Bus 12739	: V=0.9752683, theta=-64.578047 -> V=1.0, theta=0.0
% INFO    : Bus 12740	: V=0.9584225, theta=-66.662621 -> V=1.0, theta=0.0
% INFO    : Bus 12741	: V=0.9620671, theta=-66.558061 -> V=1.0, theta=0.0
% INFO    : Bus 12742	: V=0.9622808, theta=-66.551657 -> V=1.0, theta=0.0
% INFO    : Bus 12743	: V=0.9813049, theta=-63.654807 -> V=1.0, theta=0.0
% INFO    : Bus 12744	: V=0.9769333, theta=-64.293656 -> V=1.0, theta=0.0
% INFO    : Bus 12745	: V=0.9756876, theta=-64.497574 -> V=1.0, theta=0.0
% INFO    : Bus 12746	: V=0.9866157, theta=-62.887771 -> V=1.0, theta=0.0
% INFO    : Bus 12747	: V=0.983235, theta=-63.273618 -> V=1.0, theta=0.0
% INFO    : Bus 12748	: V=0.9866616, theta=-62.812987 -> V=1.0, theta=0.0
% INFO    : Bus 12749	: V=0.9841603, theta=-63.109263 -> V=1.0, theta=0.0
% INFO    : Bus 12750	: V=0.9957703, theta=-61.72297 -> V=1.0, theta=0.0
% INFO    : Bus 12751	: V=0.9813356, theta=-63.413643 -> V=1.0, theta=0.0
% INFO    : Bus 12752	: V=0.9801991, theta=-63.599885 -> V=1.0, theta=0.0
% INFO    : Bus 12753	: V=0.9831621, theta=-63.058815 -> V=1.0, theta=0.0
% INFO    : Bus 12754	: V=0.9951639, theta=-61.719802 -> V=1.0, theta=0.0
% INFO    : Bus 12755	: V=0.9637937, theta=-67.517554 -> V=1.0, theta=0.0
% INFO    : Bus 12756	: V=0.9632861, theta=-67.486271 -> V=1.0, theta=0.0
% INFO    : Bus 12757	: V=0.9666566, theta=-64.842926 -> V=1.0, theta=0.0
% INFO    : Bus 12758	: V=0.9663978, theta=-64.888028 -> V=1.0, theta=0.0
% INFO    : Bus 12759	: V=0.9660575, theta=-64.827611 -> V=1.0, theta=0.0
% INFO    : Bus 12760	: V=0.9654424, theta=-64.889415 -> V=1.0, theta=0.0
% INFO    : Bus 12761	: V=0.9659831, theta=-64.876568 -> V=1.0, theta=0.0
% INFO    : Bus 12762	: V=0.9728361, theta=-63.824096 -> V=1.0, theta=0.0
% INFO    : Bus 12763	: V=0.966227, theta=-64.717256 -> V=1.0, theta=0.0
% INFO    : Bus 12764	: V=0.96513, theta=-64.821181 -> V=1.0, theta=0.0
% INFO    : Bus 12765	: V=0.9626045, theta=-65.273952 -> V=1.0, theta=0.0
% INFO    : Bus 12766	: V=0.9711045, theta=-63.997712 -> V=1.0, theta=0.0
% INFO    : Bus 12767	: V=0.9635196, theta=-65.104249 -> V=1.0, theta=0.0
% INFO    : Bus 12768	: V=0.9652064, theta=-64.862424 -> V=1.0, theta=0.0
% INFO    : Bus 12769	: V=0.9668479, theta=-64.719821 -> V=1.0, theta=0.0
% INFO    : Bus 12770	: V=0.968132, theta=-64.587883 -> V=1.0, theta=0.0
% INFO    : Bus 12771	: V=0.9773947, theta=-63.243565 -> V=1.0, theta=0.0
% INFO    : Bus 12772	: V=0.9644859, theta=-64.833555 -> V=1.0, theta=0.0
% INFO    : Bus 12773	: V=0.9823879, theta=-62.716763 -> V=1.0, theta=0.0
% INFO    : Bus 12774	: V=0.9791791, theta=-63.039705 -> V=1.0, theta=0.0
% INFO    : Bus 12775	: V=0.9610494, theta=-65.131495 -> V=1.0, theta=0.0
% INFO    : Bus 12776	: V=0.9772348, theta=-63.828419 -> V=1.0, theta=0.0
% INFO    : Bus 12777	: V=0.9909283, theta=-61.829056 -> V=1.0, theta=0.0
% INFO    : Bus 12778	: V=0.98649, theta=-62.307386 -> V=1.0, theta=0.0
% INFO    : Bus 12779	: V=0.9800308, theta=-63.50116 -> V=1.0, theta=0.0
% INFO    : Bus 12780	: V=0.9877768, theta=-62.181834 -> V=1.0, theta=0.0
% INFO    : Bus 12781	: V=0.995057, theta=-61.42517 -> V=1.0, theta=0.0
% INFO    : Bus 12782	: V=0.9963817, theta=-61.364211 -> V=1.0, theta=0.0
% INFO    : Bus 12783	: V=1.0130587, theta=-58.803307 -> V=1.0, theta=0.0
% INFO    : Bus 12784	: V=0.9995965, theta=-60.964812 -> V=1.0, theta=0.0
% INFO    : Bus 12785	: V=0.9991999, theta=-61.004068 -> V=1.0, theta=0.0
% INFO    : Bus 12786	: V=0.9953198, theta=-61.503201 -> V=1.0, theta=0.0
% INFO    : Bus 12787	: V=0.9942486, theta=-61.574342 -> V=1.0, theta=0.0
% INFO    : Bus 12788	: V=0.9924171, theta=-61.685169 -> V=1.0, theta=0.0
% INFO    : Bus 12789	: V=0.9784645, theta=-63.739277 -> V=1.0, theta=0.0
% INFO    : Bus 12790	: V=1.004547, theta=-61.438588 -> V=1.0, theta=0.0
% INFO    : Bus 12791	: V=0.9958266, theta=-61.471291 -> V=1.0, theta=0.0
% INFO    : Bus 12792	: V=0.9900586, theta=-61.838276 -> V=1.0, theta=0.0
% INFO    : Bus 12793	: V=1.0050303, theta=-61.421574 -> V=1.0, theta=0.0
% INFO    : Bus 12794	: V=1.0047198, theta=-61.426927 -> V=1.0, theta=0.0
% INFO    : Bus 12795	: V=0.9722169, theta=-64.242923 -> V=1.0, theta=0.0
% INFO    : Bus 12796	: V=0.9742352, theta=-64.102489 -> V=1.0, theta=0.0
% INFO    : Bus 12797	: V=0.9707877, theta=-64.506393 -> V=1.0, theta=0.0
% INFO    : Bus 12798	: V=0.9659693, theta=-64.998335 -> V=1.0, theta=0.0
% INFO    : Bus 12799	: V=0.9729951, theta=-63.88909 -> V=1.0, theta=0.0
% INFO    : Bus 12800	: V=0.9666508, theta=-64.86937 -> V=1.0, theta=0.0
% INFO    : Bus 12801	: V=0.9650187, theta=-64.986695 -> V=1.0, theta=0.0
% INFO    : Bus 12802	: V=0.9705914, theta=-64.068515 -> V=1.0, theta=0.0
% INFO    : Bus 12803	: V=0.9609077, theta=-65.30966 -> V=1.0, theta=0.0
% INFO    : Bus 12804	: V=0.9610834, theta=-65.316319 -> V=1.0, theta=0.0
% INFO    : Bus 12805	: V=0.961485, theta=-65.166104 -> V=1.0, theta=0.0
% INFO    : Bus 12806	: V=0.967756, theta=-64.822239 -> V=1.0, theta=0.0
% INFO    : Bus 12807	: V=0.9665225, theta=-64.904159 -> V=1.0, theta=0.0
% INFO    : Bus 12808	: V=0.9654968, theta=-64.961671 -> V=1.0, theta=0.0
% INFO    : Bus 12809	: V=0.9591081, theta=-65.23909 -> V=1.0, theta=0.0
% INFO    : Bus 12810	: V=0.9634598, theta=-65.043279 -> V=1.0, theta=0.0
% INFO    : Bus 12811	: V=0.9704852, theta=-64.059889 -> V=1.0, theta=0.0
% INFO    : Bus 12812	: V=0.9637564, theta=-65.136567 -> V=1.0, theta=0.0
% INFO    : Bus 12813	: V=0.9634694, theta=-65.157144 -> V=1.0, theta=0.0
% INFO    : Bus 12814	: V=0.9635454, theta=-65.148277 -> V=1.0, theta=0.0
% INFO    : Bus 12815	: V=0.9672093, theta=-64.558918 -> V=1.0, theta=0.0
% INFO    : Bus 12816	: V=0.9670235, theta=-64.576 -> V=1.0, theta=0.0
% INFO    : Bus 12817	: V=0.9634987, theta=-65.152866 -> V=1.0, theta=0.0
% INFO    : Bus 12818	: V=0.9614536, theta=-65.306522 -> V=1.0, theta=0.0
% INFO    : Bus 12819	: V=0.9681404, theta=-64.458403 -> V=1.0, theta=0.0
% INFO    : Bus 12820	: V=0.9676549, theta=-64.51451 -> V=1.0, theta=0.0
% INFO    : Bus 12821	: V=0.9589016, theta=-65.388858 -> V=1.0, theta=0.0
% INFO    : Bus 12822	: V=0.9621675, theta=-65.16509 -> V=1.0, theta=0.0
% INFO    : Bus 12823	: V=0.9665821, theta=-64.58192 -> V=1.0, theta=0.0
% INFO    : Bus 12824	: V=0.9664091, theta=-64.602602 -> V=1.0, theta=0.0
% INFO    : Bus 12825	: V=0.9605801, theta=-65.349991 -> V=1.0, theta=0.0
% INFO    : Bus 12826	: V=0.9652318, theta=-64.828603 -> V=1.0, theta=0.0
% INFO    : Bus 12827	: V=0.9680537, theta=-64.528197 -> V=1.0, theta=0.0
% INFO    : Bus 12828	: V=0.9623688, theta=-65.102642 -> V=1.0, theta=0.0
% INFO    : Bus 12829	: V=0.9624763, theta=-65.101686 -> V=1.0, theta=0.0
% INFO    : Bus 12830	: V=0.9618744, theta=-65.098134 -> V=1.0, theta=0.0
% INFO    : Bus 12831	: V=0.9632084, theta=-64.994575 -> V=1.0, theta=0.0
% INFO    : Bus 12832	: V=0.9608101, theta=-65.293125 -> V=1.0, theta=0.0
% INFO    : Bus 12833	: V=0.9611746, theta=-65.199949 -> V=1.0, theta=0.0
% INFO    : Bus 12834	: V=0.9684603, theta=-64.418765 -> V=1.0, theta=0.0
% INFO    : Bus 12835	: V=0.9690253, theta=-64.358549 -> V=1.0, theta=0.0
% INFO    : Bus 12836	: V=0.973219, theta=-63.916359 -> V=1.0, theta=0.0
% INFO    : Bus 12837	: V=0.9753547, theta=-63.707299 -> V=1.0, theta=0.0
% INFO    : Bus 12838	: V=0.9734469, theta=-63.904981 -> V=1.0, theta=0.0
% INFO    : Bus 12839	: V=0.9776781, theta=-63.365599 -> V=1.0, theta=0.0
% INFO    : Bus 12840	: V=0.978392, theta=-63.32775 -> V=1.0, theta=0.0
% INFO    : Bus 12841	: V=0.968536, theta=-64.565067 -> V=1.0, theta=0.0
% INFO    : Bus 12842	: V=0.9699985, theta=-64.471322 -> V=1.0, theta=0.0
% INFO    : Bus 12843	: V=0.9674479, theta=-64.750527 -> V=1.0, theta=0.0
% INFO    : Bus 12844	: V=0.9684118, theta=-64.619791 -> V=1.0, theta=0.0
% INFO    : Bus 12845	: V=0.9691764, theta=-64.521722 -> V=1.0, theta=0.0
% INFO    : Bus 12846	: V=0.9802794, theta=-63.506589 -> V=1.0, theta=0.0
% INFO    : Bus 12847	: V=0.9706715, theta=-64.445381 -> V=1.0, theta=0.0
% INFO    : Bus 12848	: V=0.9758378, theta=-63.74868 -> V=1.0, theta=0.0
% INFO    : Bus 12849	: V=0.9793344, theta=-63.274012 -> V=1.0, theta=0.0
% INFO    : Bus 12850	: V=0.9862461, theta=-62.554133 -> V=1.0, theta=0.0
% INFO    : Bus 12851	: V=0.9839605, theta=-62.766297 -> V=1.0, theta=0.0
% INFO    : Bus 12852	: V=0.9747657, theta=-63.824232 -> V=1.0, theta=0.0
% INFO    : Bus 12853	: V=0.9758278, theta=-63.761921 -> V=1.0, theta=0.0
% INFO    : Bus 12854	: V=0.9743192, theta=-63.820205 -> V=1.0, theta=0.0
% INFO    : Bus 12855	: V=0.9783963, theta=-63.630217 -> V=1.0, theta=0.0
% INFO    : Bus 12856	: V=0.9775218, theta=-63.662845 -> V=1.0, theta=0.0
% INFO    : Bus 12857	: V=0.9820396, theta=-62.958976 -> V=1.0, theta=0.0
% INFO    : Bus 12858	: V=0.9824596, theta=-62.91293 -> V=1.0, theta=0.0
% INFO    : Bus 12859	: V=0.9763733, theta=-63.75352 -> V=1.0, theta=0.0
% INFO    : Bus 12860	: V=0.9760751, theta=-63.764231 -> V=1.0, theta=0.0
% INFO    : Bus 12861	: V=0.9932629, theta=-61.202396 -> V=1.0, theta=0.0
% INFO    : Bus 12862	: V=0.9772398, theta=-63.494747 -> V=1.0, theta=0.0
% INFO    : Bus 12863	: V=0.9795016, theta=-63.247615 -> V=1.0, theta=0.0
% INFO    : Bus 12864	: V=0.9705471, theta=-64.393038 -> V=1.0, theta=0.0
% INFO    : Bus 12865	: V=0.9713205, theta=-64.369005 -> V=1.0, theta=0.0
% INFO    : Bus 12866	: V=0.9788252, theta=-63.301684 -> V=1.0, theta=0.0
% INFO    : Bus 12867	: V=0.9806185, theta=-63.108397 -> V=1.0, theta=0.0
% INFO    : Bus 12868	: V=0.9807591, theta=-63.096647 -> V=1.0, theta=0.0
% INFO    : Bus 12869	: V=0.9781661, theta=-63.048735 -> V=1.0, theta=0.0
% INFO    : Bus 12870	: V=0.977513, theta=-63.122309 -> V=1.0, theta=0.0
% INFO    : Bus 12871	: V=0.9817553, theta=-62.573298 -> V=1.0, theta=0.0
% INFO    : Bus 12872	: V=0.9846093, theta=-62.005238 -> V=1.0, theta=0.0
% INFO    : Bus 12873	: V=0.9769193, theta=-63.413946 -> V=1.0, theta=0.0
% INFO    : Bus 12874	: V=0.9843204, theta=-62.07306 -> V=1.0, theta=0.0
% INFO    : Bus 12875	: V=0.9699124, theta=-64.071097 -> V=1.0, theta=0.0
% INFO    : Bus 12876	: V=0.9768995, theta=-63.026996 -> V=1.0, theta=0.0
% INFO    : Bus 12877	: V=0.9794361, theta=-62.859819 -> V=1.0, theta=0.0
% INFO    : Bus 12878	: V=0.9842469, theta=-62.433214 -> V=1.0, theta=0.0
% INFO    : Bus 12879	: V=0.9801776, theta=-62.759716 -> V=1.0, theta=0.0
% INFO    : Bus 12880	: V=0.9814839, theta=-62.609715 -> V=1.0, theta=0.0
% INFO    : Bus 12881	: V=0.9854713, theta=-61.841529 -> V=1.0, theta=0.0
% INFO    : Bus 12882	: V=0.9863258, theta=-61.682381 -> V=1.0, theta=0.0
% INFO    : Bus 12883	: V=0.9816549, theta=-62.577855 -> V=1.0, theta=0.0
% INFO    : Bus 12884	: V=0.983889, theta=-62.304749 -> V=1.0, theta=0.0
% INFO    : Bus 12885	: V=0.9818561, theta=-62.565227 -> V=1.0, theta=0.0
% INFO    : Bus 12886	: V=0.9765375, theta=-63.653502 -> V=1.0, theta=0.0
% INFO    : Bus 12887	: V=1.0135689, theta=-58.389921 -> V=1.0, theta=0.0
% INFO    : Bus 12888	: V=0.9800355, theta=-63.198965 -> V=1.0, theta=0.0
% INFO    : Bus 12889	: V=0.9773888, theta=-63.546155 -> V=1.0, theta=0.0
% INFO    : Bus 12890	: V=0.9838563, theta=-62.691942 -> V=1.0, theta=0.0
% INFO    : Bus 12891	: V=0.9817785, theta=-63.046531 -> V=1.0, theta=0.0
% INFO    : Bus 12892	: V=0.9803768, theta=-63.179811 -> V=1.0, theta=0.0
% INFO    : Bus 12893	: V=0.9807712, theta=-62.9856 -> V=1.0, theta=0.0
% INFO    : Bus 12894	: V=0.9785006, theta=-63.188293 -> V=1.0, theta=0.0
% INFO    : Bus 12895	: V=0.9828353, theta=-62.825362 -> V=1.0, theta=0.0
% INFO    : Bus 12896	: V=0.981124, theta=-63.06621 -> V=1.0, theta=0.0
% INFO    : Bus 12897	: V=0.9830448, theta=-62.908299 -> V=1.0, theta=0.0
% INFO    : Bus 12898	: V=0.9812847, theta=-62.963806 -> V=1.0, theta=0.0
% INFO    : Bus 12899	: V=0.9892141, theta=-62.265152 -> V=1.0, theta=0.0
% INFO    : Bus 12900	: V=0.9929634, theta=-61.941877 -> V=1.0, theta=0.0
% INFO    : Bus 12901	: V=0.9998314, theta=-61.389211 -> V=1.0, theta=0.0
% INFO    : Bus 12902	: V=1.006254, theta=-59.95582 -> V=1.0, theta=0.0
% INFO    : Bus 12903	: V=1.0086516, theta=-59.71602 -> V=1.0, theta=0.0
% INFO    : Bus 12904	: V=1.0064115, theta=-60.620613 -> V=1.0, theta=0.0
% INFO    : Bus 12905	: V=1.0118321, theta=-60.040619 -> V=1.0, theta=0.0
% INFO    : Bus 12906	: V=1.0119344, theta=-60.113903 -> V=1.0, theta=0.0
% INFO    : Bus 12907	: V=0.9970992, theta=-61.357131 -> V=1.0, theta=0.0
% INFO    : Bus 12908	: V=1.0094304, theta=-60.620946 -> V=1.0, theta=0.0
% INFO    : Bus 12909	: V=1.0012644, theta=-61.375175 -> V=1.0, theta=0.0
% INFO    : Bus 12910	: V=1.0086021, theta=-59.991364 -> V=1.0, theta=0.0
% INFO    : Bus 12911	: V=1.0045018, theta=-60.423866 -> V=1.0, theta=0.0
% INFO    : Bus 12912	: V=1.0065534, theta=-60.19736 -> V=1.0, theta=0.0
% INFO    : Bus 12913	: V=1.0058301, theta=-60.158501 -> V=1.0, theta=0.0
% INFO    : Bus 12914	: V=0.9945099, theta=-61.804694 -> V=1.0, theta=0.0
% INFO    : Bus 12915	: V=0.9760749, theta=-63.719072 -> V=1.0, theta=0.0
% INFO    : Bus 12916	: V=0.9789592, theta=-63.067417 -> V=1.0, theta=0.0
% INFO    : Bus 12917	: V=0.9968548, theta=-61.379033 -> V=1.0, theta=0.0
% INFO    : Bus 12918	: V=0.9983671, theta=-61.240624 -> V=1.0, theta=0.0
% INFO    : Bus 12919	: V=0.9941673, theta=-62.078681 -> V=1.0, theta=0.0
% INFO    : Bus 12920	: V=0.9918518, theta=-62.526948 -> V=1.0, theta=0.0
% INFO    : Bus 12921	: V=1.0048648, theta=-60.285386 -> V=1.0, theta=0.0
% INFO    : Bus 12922	: V=1.0022901, theta=-60.817177 -> V=1.0, theta=0.0
% INFO    : Bus 12923	: V=1.001622, theta=-60.908789 -> V=1.0, theta=0.0
% INFO    : Bus 12924	: V=1.0010235, theta=-60.966454 -> V=1.0, theta=0.0
% INFO    : Bus 12925	: V=0.9991234, theta=-61.127547 -> V=1.0, theta=0.0
% INFO    : Bus 12926	: V=0.9890399, theta=-62.247686 -> V=1.0, theta=0.0
% INFO    : Bus 12927	: V=0.9898961, theta=-62.236497 -> V=1.0, theta=0.0
% INFO    : Bus 12928	: V=0.9993029, theta=-61.038602 -> V=1.0, theta=0.0
% INFO    : Bus 12929	: V=0.9939174, theta=-61.767293 -> V=1.0, theta=0.0
% INFO    : Bus 12930	: V=1.0001123, theta=-61.090944 -> V=1.0, theta=0.0
% INFO    : Bus 12931	: V=1.012086, theta=-59.266531 -> V=1.0, theta=0.0
% INFO    : Bus 12932	: V=0.9978849, theta=-61.429476 -> V=1.0, theta=0.0
% INFO    : Bus 12933	: V=0.9958539, theta=-61.67918 -> V=1.0, theta=0.0
% INFO    : Bus 12934	: V=0.9965693, theta=-61.592482 -> V=1.0, theta=0.0
% INFO    : Bus 12935	: V=0.9959388, theta=-61.673884 -> V=1.0, theta=0.0
% INFO    : Bus 12936	: V=0.9841666, theta=-63.93898 -> V=1.0, theta=0.0
% INFO    : Bus 12937	: V=0.9853795, theta=-63.60396 -> V=1.0, theta=0.0
% INFO    : Bus 12938	: V=0.98853, theta=-63.929994 -> V=1.0, theta=0.0
% INFO    : Bus 12939	: V=0.9874594, theta=-63.670057 -> V=1.0, theta=0.0
% INFO    : Bus 12940	: V=0.987302, theta=-63.185251 -> V=1.0, theta=0.0
% INFO    : Bus 12941	: V=1.0006509, theta=-61.2061 -> V=1.0, theta=0.0
% INFO    : Bus 12942	: V=1.0081921, theta=-59.441065 -> V=1.0, theta=0.0
% INFO    : Bus 12943	: V=1.0122173, theta=-59.258732 -> V=1.0, theta=0.0
% INFO    : Bus 12944	: V=1.0132715, theta=-59.069678 -> V=1.0, theta=0.0
% INFO    : Bus 12945	: V=1.0187614, theta=-58.003537 -> V=1.0, theta=0.0
% INFO    : Bus 12946	: V=1.013184, theta=-59.16926 -> V=1.0, theta=0.0
% INFO    : Bus 12947	: V=0.9931539, theta=-63.036223 -> V=1.0, theta=0.0
% INFO    : Bus 12948	: V=0.9947918, theta=-62.693317 -> V=1.0, theta=0.0
% INFO    : Bus 12949	: V=1.0046937, theta=-60.692249 -> V=1.0, theta=0.0
% INFO    : Bus 12950	: V=0.9889551, theta=-63.363676 -> V=1.0, theta=0.0
% INFO    : Bus 12951	: V=0.9996755, theta=-62.854234 -> V=1.0, theta=0.0
% INFO    : Bus 12952	: V=0.9901166, theta=-63.379219 -> V=1.0, theta=0.0
% INFO    : Bus 12953	: V=0.994192, theta=-63.119922 -> V=1.0, theta=0.0
% INFO    : Bus 12954	: V=0.9891116, theta=-63.377805 -> V=1.0, theta=0.0
% INFO    : Bus 12955	: V=0.991393, theta=-63.222486 -> V=1.0, theta=0.0
% INFO    : Bus 12956	: V=0.991361, theta=-63.24269 -> V=1.0, theta=0.0
% INFO    : Bus 12957	: V=0.9903293, theta=-63.465069 -> V=1.0, theta=0.0
% INFO    : Bus 12958	: V=0.989379, theta=-63.362012 -> V=1.0, theta=0.0
% INFO    : Bus 12959	: V=0.9967703, theta=-63.247372 -> V=1.0, theta=0.0
% INFO    : Bus 12960	: V=0.9910428, theta=-63.453609 -> V=1.0, theta=0.0
% INFO    : Bus 12961	: V=0.970702, theta=-64.182954 -> V=1.0, theta=0.0
% INFO    : Bus 12962	: V=0.969867, theta=-64.273468 -> V=1.0, theta=0.0
% INFO    : Bus 12963	: V=0.9617166, theta=-65.096082 -> V=1.0, theta=0.0
% INFO    : Bus 12964	: V=0.9595918, theta=-65.162048 -> V=1.0, theta=0.0
% INFO    : Bus 12965	: V=0.9640557, theta=-64.900521 -> V=1.0, theta=0.0
% INFO    : Bus 12966	: V=0.9788668, theta=-63.291618 -> V=1.0, theta=0.0
% INFO    : Bus 12967	: V=0.9955051, theta=-61.461137 -> V=1.0, theta=0.0
% INFO    : Bus 12968	: V=0.9548753, theta=-71.058155 -> V=1.0, theta=0.0
% INFO    : Bus 12969	: V=0.973568, theta=-69.644492 -> V=1.0, theta=0.0
% INFO    : Bus 12970	: V=0.9625124, theta=-71.12834 -> V=1.0, theta=0.0
% INFO    : Bus 12971	: V=0.9622531, theta=-71.284886 -> V=1.0, theta=0.0
% INFO    : Bus 12972	: V=0.9963536, theta=-61.912202 -> V=1.0, theta=0.0
% INFO    : Bus 12973	: V=0.9928031, theta=-62.51683 -> V=1.0, theta=0.0
% INFO    : Bus 12974	: V=0.98461, theta=-63.588087 -> V=1.0, theta=0.0
% INFO    : Bus 12975	: V=1.0027665, theta=-60.991108 -> V=1.0, theta=0.0
% INFO    : Bus 12976	: V=1.0038128, theta=-60.913413 -> V=1.0, theta=0.0
% INFO    : Bus 12977	: V=1.0032586, theta=-60.951175 -> V=1.0, theta=0.0
% INFO    : Bus 12978	: V=0.9854439, theta=-63.57297 -> V=1.0, theta=0.0
% INFO    : Bus 12979	: V=0.9848669, theta=-63.58368 -> V=1.0, theta=0.0
% INFO    : Bus 12980	: V=0.9844737, theta=-63.667706 -> V=1.0, theta=0.0
% INFO    : Bus 12981	: V=0.9848857, theta=-63.637963 -> V=1.0, theta=0.0
% INFO    : Bus 12982	: V=0.9854905, theta=-63.593066 -> V=1.0, theta=0.0
% INFO    : Bus 12983	: V=0.9867064, theta=-63.506332 -> V=1.0, theta=0.0
% INFO    : Bus 12984	: V=1.0035455, theta=-60.949519 -> V=1.0, theta=0.0
% INFO    : Bus 12985	: V=0.9972274, theta=-61.483469 -> V=1.0, theta=0.0
% INFO    : Bus 12986	: V=1.0042234, theta=-60.590173 -> V=1.0, theta=0.0
% INFO    : Bus 12987	: V=0.9978834, theta=-61.394998 -> V=1.0, theta=0.0
% INFO    : Bus 12988	: V=0.9979708, theta=-61.363531 -> V=1.0, theta=0.0
% INFO    : Bus 12989	: V=1.0038755, theta=-60.529706 -> V=1.0, theta=0.0
% INFO    : Bus 12990	: V=1.0051346, theta=-60.461409 -> V=1.0, theta=0.0
% INFO    : Bus 12991	: V=1.004348, theta=-60.505587 -> V=1.0, theta=0.0
% INFO    : Bus 12992	: V=1.001255, theta=-60.921544 -> V=1.0, theta=0.0
% INFO    : Bus 12993	: V=0.9929303, theta=-62.074023 -> V=1.0, theta=0.0
% INFO    : Bus 12994	: V=1.0125613, theta=-59.062069 -> V=1.0, theta=0.0
% INFO    : Bus 12995	: V=0.9895595, theta=-62.43294 -> V=1.0, theta=0.0
% INFO    : Bus 12996	: V=0.9938354, theta=-62.149573 -> V=1.0, theta=0.0
% INFO    : Bus 12997	: V=0.9980631, theta=-61.505679 -> V=1.0, theta=0.0
% INFO    : Bus 12998	: V=0.9979924, theta=-61.782335 -> V=1.0, theta=0.0
% INFO    : Bus 12999	: V=0.997592, theta=-62.003008 -> V=1.0, theta=0.0
% INFO    : Bus 13000	: V=0.9985241, theta=-61.954541 -> V=1.0, theta=0.0
% INFO    : Bus 13001	: V=0.9971024, theta=-62.130703 -> V=1.0, theta=0.0
% INFO    : Bus 13002	: V=0.9958328, theta=-62.282666 -> V=1.0, theta=0.0
% INFO    : Bus 13003	: V=0.9952492, theta=-62.354501 -> V=1.0, theta=0.0
% INFO    : Bus 13004	: V=0.9951823, theta=-62.360079 -> V=1.0, theta=0.0
% INFO    : Bus 13005	: V=0.9974361, theta=-62.759273 -> V=1.0, theta=0.0
% INFO    : Bus 13006	: V=1.0101046, theta=-61.444523 -> V=1.0, theta=0.0
% INFO    : Bus 13007	: V=0.9941645, theta=-62.97088 -> V=1.0, theta=0.0
% INFO    : Bus 13008	: V=0.9972786, theta=-62.733383 -> V=1.0, theta=0.0
% INFO    : Bus 13009	: V=1.0044874, theta=-61.78499 -> V=1.0, theta=0.0
% INFO    : Bus 13010	: V=0.9934048, theta=-62.676737 -> V=1.0, theta=0.0
% INFO    : Bus 13011	: V=0.9918706, theta=-62.439524 -> V=1.0, theta=0.0
% INFO    : Bus 13012	: V=0.997767, theta=-61.771658 -> V=1.0, theta=0.0
% INFO    : Bus 13013	: V=0.9969023, theta=-61.988509 -> V=1.0, theta=0.0
% INFO    : Bus 13014	: V=0.9987371, theta=-61.661895 -> V=1.0, theta=0.0
% INFO    : Bus 13015	: V=0.9948704, theta=-62.10397 -> V=1.0, theta=0.0
% INFO    : Bus 13016	: V=0.9962239, theta=-61.743644 -> V=1.0, theta=0.0
% INFO    : Bus 13017	: V=1.0043472, theta=-60.505926 -> V=1.0, theta=0.0
% INFO    : Bus 13018	: V=1.0044705, theta=-60.574715 -> V=1.0, theta=0.0
% INFO    : Bus 13019	: V=1.0034819, theta=-61.024683 -> V=1.0, theta=0.0
% INFO    : Bus 13020	: V=0.9956126, theta=-61.829322 -> V=1.0, theta=0.0
% INFO    : Bus 13021	: V=0.996745, theta=-61.496346 -> V=1.0, theta=0.0
% INFO    : Bus 13022	: V=0.9981609, theta=-61.475888 -> V=1.0, theta=0.0
% INFO    : Bus 13023	: V=1.0058266, theta=-60.406982 -> V=1.0, theta=0.0
% INFO    : Bus 13024	: V=0.9971654, theta=-61.878671 -> V=1.0, theta=0.0
% INFO    : Bus 13025	: V=0.9969721, theta=-61.788938 -> V=1.0, theta=0.0
% INFO    : Bus 13026	: V=0.9979144, theta=-61.662373 -> V=1.0, theta=0.0
% INFO    : Bus 13027	: V=1.0079306, theta=-60.219105 -> V=1.0, theta=0.0
% INFO    : Bus 13028	: V=1.0178577, theta=-58.723272 -> V=1.0, theta=0.0
% INFO    : Bus 13029	: V=0.9954187, theta=-62.250308 -> V=1.0, theta=0.0
% INFO    : Bus 13030	: V=0.989873, theta=-63.031056 -> V=1.0, theta=0.0
% INFO    : Bus 13031	: V=0.9953973, theta=-62.228201 -> V=1.0, theta=0.0
% INFO    : Bus 13032	: V=0.9915605, theta=-62.991416 -> V=1.0, theta=0.0
% INFO    : Bus 13033	: V=1.002021, theta=-61.076559 -> V=1.0, theta=0.0
% INFO    : Bus 13034	: V=0.991374, theta=-62.780406 -> V=1.0, theta=0.0
% INFO    : Bus 13035	: V=1.0094671, theta=-60.364833 -> V=1.0, theta=0.0
% INFO    : Bus 13036	: V=0.9909777, theta=-62.834077 -> V=1.0, theta=0.0
% INFO    : Bus 13037	: V=1.0050292, theta=-60.427472 -> V=1.0, theta=0.0
% INFO    : Bus 13038	: V=1.0119336, theta=-59.221969 -> V=1.0, theta=0.0
% INFO    : Bus 13039	: V=0.9994519, theta=-61.215624 -> V=1.0, theta=0.0
% INFO    : Bus 13040	: V=0.9571279, theta=-71.399337 -> V=1.0, theta=0.0
% INFO    : Bus 13041	: V=0.9684213, theta=-70.391476 -> V=1.0, theta=0.0
% INFO    : Bus 13042	: V=0.9736215, theta=-69.998333 -> V=1.0, theta=0.0
% INFO    : Bus 13043	: V=0.967094, theta=-71.158457 -> V=1.0, theta=0.0
% INFO    : Bus 13044	: V=1.001028, theta=-68.202933 -> V=1.0, theta=0.0
% INFO    : Bus 13045	: V=1.0000287, theta=-68.262173 -> V=1.0, theta=0.0
% INFO    : Bus 13046	: V=0.9788655, theta=-69.434873 -> V=1.0, theta=0.0
% INFO    : Bus 13047	: V=0.966662, theta=-69.604456 -> V=1.0, theta=0.0
% INFO    : Bus 13048	: V=0.9632704, theta=-69.241462 -> V=1.0, theta=0.0
% INFO    : Bus 13049	: V=0.9622063, theta=-69.32658 -> V=1.0, theta=0.0
% INFO    : Bus 13050	: V=0.9617862, theta=-69.331367 -> V=1.0, theta=0.0
% INFO    : Bus 13051	: V=0.9750913, theta=-68.996522 -> V=1.0, theta=0.0
% INFO    : Bus 13052	: V=0.9776978, theta=-68.924152 -> V=1.0, theta=0.0
% INFO    : Bus 13053	: V=0.9782976, theta=-68.851717 -> V=1.0, theta=0.0
% INFO    : Bus 13054	: V=0.9762191, theta=-68.976043 -> V=1.0, theta=0.0
% INFO    : Bus 13055	: V=0.9768009, theta=-68.955167 -> V=1.0, theta=0.0
% INFO    : Bus 13056	: V=0.9764727, theta=-68.968122 -> V=1.0, theta=0.0
% INFO    : Bus 13057	: V=0.9809689, theta=-68.812559 -> V=1.0, theta=0.0
% INFO    : Bus 13058	: V=0.995598, theta=-68.381438 -> V=1.0, theta=0.0
% INFO    : Bus 13059	: V=1.0000041, theta=-68.231976 -> V=1.0, theta=0.0
% INFO    : Bus 13060	: V=0.9904823, theta=-69.900569 -> V=1.0, theta=0.0
% INFO    : Bus 13061	: V=1.0003116, theta=-68.18957 -> V=1.0, theta=0.0
% INFO    : Bus 13062	: V=0.9693473, theta=-69.270798 -> V=1.0, theta=0.0
% INFO    : Bus 13063	: V=0.9661794, theta=-69.196258 -> V=1.0, theta=0.0
% INFO    : Bus 13064	: V=0.9577512, theta=-68.673198 -> V=1.0, theta=0.0
% INFO    : Bus 13065	: V=0.9584965, theta=-68.631054 -> V=1.0, theta=0.0
% INFO    : Bus 13066	: V=0.9670303, theta=-66.674332 -> V=1.0, theta=0.0
% INFO    : Bus 13067	: V=0.9658607, theta=-65.30297 -> V=1.0, theta=0.0
% INFO    : Bus 13068	: V=0.9602918, theta=-66.466318 -> V=1.0, theta=0.0
% INFO    : Bus 13069	: V=0.9729394, theta=-63.306053 -> V=1.0, theta=0.0
% INFO    : Bus 13070	: V=0.9899257, theta=-62.117968 -> V=1.0, theta=0.0
% INFO    : Bus 13071	: V=0.9893798, theta=-62.151819 -> V=1.0, theta=0.0
% INFO    : Bus 13072	: V=0.9894018, theta=-62.107048 -> V=1.0, theta=0.0
% INFO    : Bus 13073	: V=1.0044553, theta=-60.176843 -> V=1.0, theta=0.0
% INFO    : Bus 13074	: V=0.9946842, theta=-61.46133 -> V=1.0, theta=0.0
% INFO    : Bus 13075	: V=0.9950677, theta=-61.274827 -> V=1.0, theta=0.0
% INFO    : Bus 13076	: V=0.9950058, theta=-61.301763 -> V=1.0, theta=0.0
% INFO    : Bus 13077	: V=0.9889593, theta=-62.260459 -> V=1.0, theta=0.0
% INFO    : Bus 13078	: V=0.9960808, theta=-61.19714 -> V=1.0, theta=0.0
% INFO    : Bus 13079	: V=0.989867, theta=-61.9436 -> V=1.0, theta=0.0
% INFO    : Bus 13080	: V=0.9900492, theta=-61.923817 -> V=1.0, theta=0.0
% INFO    : Bus 13081	: V=0.9969193, theta=-61.124493 -> V=1.0, theta=0.0
% INFO    : Bus 13082	: V=0.9917631, theta=-61.986582 -> V=1.0, theta=0.0
% INFO    : Bus 13083	: V=0.9891288, theta=-62.258326 -> V=1.0, theta=0.0
% INFO    : Bus 13084	: V=0.9890293, theta=-62.241081 -> V=1.0, theta=0.0
% INFO    : Bus 13085	: V=0.9903521, theta=-61.885023 -> V=1.0, theta=0.0
% INFO    : Bus 13086	: V=0.9898395, theta=-61.893315 -> V=1.0, theta=0.0
% INFO    : Bus 13087	: V=0.9897606, theta=-61.90856 -> V=1.0, theta=0.0
% INFO    : Bus 13088	: V=0.9896884, theta=-61.913677 -> V=1.0, theta=0.0
% INFO    : Bus 13089	: V=0.997511, theta=-61.042021 -> V=1.0, theta=0.0
% INFO    : Bus 13090	: V=0.990036, theta=-61.889455 -> V=1.0, theta=0.0
% INFO    : Bus 13091	: V=0.998551, theta=-60.977366 -> V=1.0, theta=0.0
% INFO    : Bus 13092	: V=0.9978078, theta=-61.021953 -> V=1.0, theta=0.0
% INFO    : Bus 13093	: V=0.9947142, theta=-61.545707 -> V=1.0, theta=0.0
% INFO    : Bus 13094	: V=0.9894207, theta=-62.23739 -> V=1.0, theta=0.0
% INFO    : Bus 13095	: V=0.9902559, theta=-61.861363 -> V=1.0, theta=0.0
% INFO    : Bus 13096	: V=0.9896105, theta=-61.917985 -> V=1.0, theta=0.0
% INFO    : Bus 13097	: V=0.9897403, theta=-61.906904 -> V=1.0, theta=0.0
% INFO    : Bus 13098	: V=0.9903963, theta=-61.85912 -> V=1.0, theta=0.0
% INFO    : Bus 13099	: V=0.9894966, theta=-62.233777 -> V=1.0, theta=0.0
% INFO    : Bus 13100	: V=0.9960259, theta=-61.358831 -> V=1.0, theta=0.0
% INFO    : Bus 13101	: V=0.9987923, theta=-60.846247 -> V=1.0, theta=0.0
% INFO    : Bus 13102	: V=0.9984782, theta=-60.814283 -> V=1.0, theta=0.0
% INFO    : Bus 13103	: V=0.9981312, theta=-60.77279 -> V=1.0, theta=0.0
% INFO    : Bus 13104	: V=0.9977056, theta=-60.830705 -> V=1.0, theta=0.0
% INFO    : Bus 13105	: V=0.9961609, theta=-60.934469 -> V=1.0, theta=0.0
% INFO    : Bus 13106	: V=0.9870992, theta=-61.627468 -> V=1.0, theta=0.0
% INFO    : Bus 13107	: V=0.9868693, theta=-61.630361 -> V=1.0, theta=0.0
% INFO    : Bus 13108	: V=0.987354, theta=-61.617503 -> V=1.0, theta=0.0
% INFO    : Bus 13109	: V=0.9981105, theta=-60.696949 -> V=1.0, theta=0.0
% INFO    : Bus 13110	: V=0.9983882, theta=-60.685026 -> V=1.0, theta=0.0
% INFO    : Bus 13111	: V=0.9988714, theta=-60.572831 -> V=1.0, theta=0.0
% INFO    : Bus 13112	: V=0.9960817, theta=-61.061573 -> V=1.0, theta=0.0
% INFO    : Bus 13113	: V=0.9891995, theta=-62.251352 -> V=1.0, theta=0.0
% INFO    : Bus 13114	: V=0.9953827, theta=-61.369129 -> V=1.0, theta=0.0
% INFO    : Bus 13115	: V=0.9995253, theta=-60.877395 -> V=1.0, theta=0.0
% INFO    : Bus 13116	: V=0.9873778, theta=-62.414422 -> V=1.0, theta=0.0
% INFO    : Bus 13117	: V=0.9887993, theta=-62.287553 -> V=1.0, theta=0.0
% INFO    : Bus 13118	: V=0.9891025, theta=-62.239629 -> V=1.0, theta=0.0
% INFO    : Bus 13119	: V=1.0005028, theta=-60.253983 -> V=1.0, theta=0.0
% INFO    : Bus 13120	: V=0.9994289, theta=-60.447211 -> V=1.0, theta=0.0
% INFO    : Bus 13121	: V=0.988839, theta=-62.151871 -> V=1.0, theta=0.0
% INFO    : Bus 13122	: V=0.9882628, theta=-61.529898 -> V=1.0, theta=0.0
% INFO    : Bus 13123	: V=0.9881601, theta=-61.537399 -> V=1.0, theta=0.0
% INFO    : Bus 13124	: V=0.9861887, theta=-61.594032 -> V=1.0, theta=0.0
% INFO    : Bus 13125	: V=0.987437, theta=-61.563093 -> V=1.0, theta=0.0
% INFO    : Bus 13126	: V=0.9861508, theta=-61.593411 -> V=1.0, theta=0.0
% INFO    : Bus 13127	: V=0.9844219, theta=-61.571548 -> V=1.0, theta=0.0
% INFO    : Bus 13128	: V=1.0033626, theta=-59.44628 -> V=1.0, theta=0.0
% INFO    : Bus 13129	: V=1.0101052, theta=-58.624815 -> V=1.0, theta=0.0
% INFO    : Bus 13130	: V=1.0140588, theta=-58.000548 -> V=1.0, theta=0.0
% INFO    : Bus 13131	: V=1.0121236, theta=-58.352507 -> V=1.0, theta=0.0
% INFO    : Bus 13132	: V=1.0137928, theta=-58.035904 -> V=1.0, theta=0.0
% INFO    : Bus 13133	: V=0.9987284, theta=-60.307506 -> V=1.0, theta=0.0
% INFO    : Bus 13134	: V=1.0135308, theta=-58.070384 -> V=1.0, theta=0.0
% INFO    : Bus 13135	: V=0.9986517, theta=-60.308609 -> V=1.0, theta=0.0
% INFO    : Bus 13136	: V=0.9984234, theta=-60.371661 -> V=1.0, theta=0.0
% INFO    : Bus 13137	: V=0.9945674, theta=-60.958516 -> V=1.0, theta=0.0
% INFO    : Bus 13138	: V=1.0009249, theta=-59.977863 -> V=1.0, theta=0.0
% INFO    : Bus 13139	: V=1.0013964, theta=-59.912407 -> V=1.0, theta=0.0
% INFO    : Bus 13140	: V=0.9948548, theta=-60.924219 -> V=1.0, theta=0.0
% INFO    : Bus 13141	: V=1.000499, theta=-60.025771 -> V=1.0, theta=0.0
% INFO    : Bus 13142	: V=0.9951882, theta=-60.940249 -> V=1.0, theta=0.0
% INFO    : Bus 13143	: V=0.9966632, theta=-60.849823 -> V=1.0, theta=0.0
% INFO    : Bus 13144	: V=0.9968054, theta=-60.802767 -> V=1.0, theta=0.0
% INFO    : Bus 13145	: V=0.9965926, theta=-60.893075 -> V=1.0, theta=0.0
% INFO    : Bus 13146	: V=0.9949979, theta=-60.952286 -> V=1.0, theta=0.0
% INFO    : Bus 13147	: V=0.9915841, theta=-61.719938 -> V=1.0, theta=0.0
% INFO    : Bus 13148	: V=0.9965437, theta=-60.93879 -> V=1.0, theta=0.0
% INFO    : Bus 13149	: V=0.9944126, theta=-60.992635 -> V=1.0, theta=0.0
% INFO    : Bus 13150	: V=0.9903743, theta=-61.574503 -> V=1.0, theta=0.0
% INFO    : Bus 13151	: V=0.9969546, theta=-60.758432 -> V=1.0, theta=0.0
% INFO    : Bus 13152	: V=0.9939754, theta=-61.184617 -> V=1.0, theta=0.0
% INFO    : Bus 13153	: V=0.9973005, theta=-60.670991 -> V=1.0, theta=0.0
% INFO    : Bus 13154	: V=0.9935809, theta=-61.193576 -> V=1.0, theta=0.0
% INFO    : Bus 13155	: V=0.9965038, theta=-60.836871 -> V=1.0, theta=0.0
% INFO    : Bus 13156	: V=0.9961362, theta=-60.898533 -> V=1.0, theta=0.0
% INFO    : Bus 13157	: V=0.9957275, theta=-60.98113 -> V=1.0, theta=0.0
% INFO    : Bus 13158	: V=0.9957584, theta=-61.056243 -> V=1.0, theta=0.0
% INFO    : Bus 13159	: V=0.9954599, theta=-61.071126 -> V=1.0, theta=0.0
% INFO    : Bus 13160	: V=0.9962407, theta=-61.030586 -> V=1.0, theta=0.0
% INFO    : Bus 13161	: V=0.9965329, theta=-61.014237 -> V=1.0, theta=0.0
% INFO    : Bus 13162	: V=0.9973877, theta=-60.986573 -> V=1.0, theta=0.0
% INFO    : Bus 13163	: V=0.9969338, theta=-61.002244 -> V=1.0, theta=0.0
% INFO    : Bus 13164	: V=0.9929043, theta=-61.682473 -> V=1.0, theta=0.0
% INFO    : Bus 13165	: V=0.9933485, theta=-61.65143 -> V=1.0, theta=0.0
% INFO    : Bus 13166	: V=0.9917706, theta=-61.797073 -> V=1.0, theta=0.0
% INFO    : Bus 13167	: V=0.9905724, theta=-61.560913 -> V=1.0, theta=0.0
% INFO    : Bus 13168	: V=0.9901425, theta=-61.824288 -> V=1.0, theta=0.0
% INFO    : Bus 13169	: V=0.9930443, theta=-61.186459 -> V=1.0, theta=0.0
% INFO    : Bus 13170	: V=0.9930814, theta=-61.157258 -> V=1.0, theta=0.0
% INFO    : Bus 13171	: V=0.9840556, theta=-62.294815 -> V=1.0, theta=0.0
% INFO    : Bus 13172	: V=0.9868267, theta=-61.967993 -> V=1.0, theta=0.0
% INFO    : Bus 13173	: V=0.9859277, theta=-62.078999 -> V=1.0, theta=0.0
% INFO    : Bus 13174	: V=0.9918323, theta=-61.138113 -> V=1.0, theta=0.0
% INFO    : Bus 13175	: V=0.9931052, theta=-61.20928 -> V=1.0, theta=0.0
% INFO    : Bus 13176	: V=0.9932402, theta=-61.219975 -> V=1.0, theta=0.0
% INFO    : Bus 13177	: V=0.9934, theta=-61.22957 -> V=1.0, theta=0.0
% INFO    : Bus 13178	: V=0.9907636, theta=-61.75745 -> V=1.0, theta=0.0
% INFO    : Bus 13179	: V=0.9907468, theta=-61.862739 -> V=1.0, theta=0.0
% INFO    : Bus 13180	: V=0.9898121, theta=-61.931035 -> V=1.0, theta=0.0
% INFO    : Bus 13181	: V=0.992035, theta=-61.75869 -> V=1.0, theta=0.0
% INFO    : Bus 13182	: V=0.9924001, theta=-61.7236 -> V=1.0, theta=0.0
% INFO    : Bus 13183	: V=0.9912799, theta=-61.4622 -> V=1.0, theta=0.0
% INFO    : Bus 13184	: V=0.9867017, theta=-62.189415 -> V=1.0, theta=0.0
% INFO    : Bus 13185	: V=0.991568, theta=-61.168128 -> V=1.0, theta=0.0
% INFO    : Bus 13186	: V=0.9853108, theta=-62.297791 -> V=1.0, theta=0.0
% INFO    : Bus 13187	: V=0.9847357, theta=-62.283298 -> V=1.0, theta=0.0
% INFO    : Bus 13188	: V=0.9857394, theta=-62.080481 -> V=1.0, theta=0.0
% INFO    : Bus 13189	: V=0.982093, theta=-62.545835 -> V=1.0, theta=0.0
% INFO    : Bus 13190	: V=0.9841777, theta=-62.40181 -> V=1.0, theta=0.0
% INFO    : Bus 13191	: V=0.9833192, theta=-62.461463 -> V=1.0, theta=0.0
% INFO    : Bus 13192	: V=0.9811663, theta=-62.686948 -> V=1.0, theta=0.0
% INFO    : Bus 13193	: V=0.9806781, theta=-62.763717 -> V=1.0, theta=0.0
% INFO    : Bus 13194	: V=0.9791351, theta=-62.948228 -> V=1.0, theta=0.0
% INFO    : Bus 13195	: V=0.9787697, theta=-63.00163 -> V=1.0, theta=0.0
% INFO    : Bus 13196	: V=0.9793984, theta=-62.926791 -> V=1.0, theta=0.0
% INFO    : Bus 13197	: V=0.9939626, theta=-61.402062 -> V=1.0, theta=0.0
% INFO    : Bus 13198	: V=0.9943643, theta=-61.327917 -> V=1.0, theta=0.0
% INFO    : Bus 13199	: V=0.9850282, theta=-62.791191 -> V=1.0, theta=0.0
% INFO    : Bus 13200	: V=0.9845987, theta=-62.801013 -> V=1.0, theta=0.0
% INFO    : Bus 13201	: V=0.9840668, theta=-62.829989 -> V=1.0, theta=0.0
% INFO    : Bus 13202	: V=0.9845399, theta=-62.803762 -> V=1.0, theta=0.0
% INFO    : Bus 13203	: V=0.9842772, theta=-62.805615 -> V=1.0, theta=0.0
% INFO    : Bus 13204	: V=0.9836168, theta=-62.841803 -> V=1.0, theta=0.0
% INFO    : Bus 13205	: V=0.9834148, theta=-62.844625 -> V=1.0, theta=0.0
% INFO    : Bus 13206	: V=0.9827335, theta=-62.836397 -> V=1.0, theta=0.0
% INFO    : Bus 13207	: V=0.983732, theta=-62.771213 -> V=1.0, theta=0.0
% INFO    : Bus 13208	: V=0.9911832, theta=-61.627821 -> V=1.0, theta=0.0
% INFO    : Bus 13209	: V=0.9837801, theta=-62.804417 -> V=1.0, theta=0.0
% INFO    : Bus 13210	: V=0.9941168, theta=-61.345739 -> V=1.0, theta=0.0
% INFO    : Bus 13211	: V=0.9928085, theta=-61.670446 -> V=1.0, theta=0.0
% INFO    : Bus 13212	: V=0.99253, theta=-61.740489 -> V=1.0, theta=0.0
% INFO    : Bus 13213	: V=0.9836959, theta=-62.837128 -> V=1.0, theta=0.0
% INFO    : Bus 13214	: V=0.9838621, theta=-62.82349 -> V=1.0, theta=0.0
% INFO    : Bus 13215	: V=0.9901089, theta=-61.861009 -> V=1.0, theta=0.0
% INFO    : Bus 13216	: V=0.9837838, theta=-62.813375 -> V=1.0, theta=0.0
% INFO    : Bus 13217	: V=0.9902319, theta=-61.691396 -> V=1.0, theta=0.0
% INFO    : Bus 13218	: V=0.9833045, theta=-62.774136 -> V=1.0, theta=0.0
% INFO    : Bus 13219	: V=0.988051, theta=-61.806607 -> V=1.0, theta=0.0
% INFO    : Bus 13220	: V=0.9807738, theta=-62.98823 -> V=1.0, theta=0.0
% INFO    : Bus 13221	: V=0.9893296, theta=-61.750038 -> V=1.0, theta=0.0
% INFO    : Bus 13222	: V=0.988875, theta=-61.785445 -> V=1.0, theta=0.0
% INFO    : Bus 13223	: V=0.9825969, theta=-62.854603 -> V=1.0, theta=0.0
% INFO    : Bus 13224	: V=0.9828944, theta=-62.849382 -> V=1.0, theta=0.0
% INFO    : Bus 13225	: V=0.9918257, theta=-61.77831 -> V=1.0, theta=0.0
% INFO    : Bus 13226	: V=0.9917766, theta=-61.754296 -> V=1.0, theta=0.0
% INFO    : Bus 13227	: V=0.9853679, theta=-62.271912 -> V=1.0, theta=0.0
% INFO    : Bus 13228	: V=0.98861, theta=-62.056995 -> V=1.0, theta=0.0
% INFO    : Bus 13229	: V=0.9872213, theta=-62.17931 -> V=1.0, theta=0.0
% INFO    : Bus 13230	: V=0.9880101, theta=-62.08875 -> V=1.0, theta=0.0
% INFO    : Bus 13231	: V=0.9820699, theta=-62.948611 -> V=1.0, theta=0.0
% INFO    : Bus 13232	: V=0.9818705, theta=-62.962719 -> V=1.0, theta=0.0
% INFO    : Bus 13233	: V=0.9815271, theta=-62.976648 -> V=1.0, theta=0.0
% INFO    : Bus 13234	: V=0.9817335, theta=-62.97385 -> V=1.0, theta=0.0
% INFO    : Bus 13235	: V=0.9794279, theta=-63.189306 -> V=1.0, theta=0.0
% INFO    : Bus 13236	: V=0.9796412, theta=-63.075553 -> V=1.0, theta=0.0
% INFO    : Bus 13237	: V=0.9872424, theta=-61.876777 -> V=1.0, theta=0.0
% INFO    : Bus 13238	: V=0.986021, theta=-62.1076 -> V=1.0, theta=0.0
% INFO    : Bus 13239	: V=0.9865658, theta=-61.937007 -> V=1.0, theta=0.0
% INFO    : Bus 13240	: V=0.9774917, theta=-63.322623 -> V=1.0, theta=0.0
% INFO    : Bus 13241	: V=0.9785009, theta=-63.204981 -> V=1.0, theta=0.0
% INFO    : Bus 13242	: V=0.9773489, theta=-63.344831 -> V=1.0, theta=0.0
% INFO    : Bus 13243	: V=0.9810716, theta=-62.987108 -> V=1.0, theta=0.0
% INFO    : Bus 13244	: V=0.9847635, theta=-62.416788 -> V=1.0, theta=0.0
% INFO    : Bus 13245	: V=0.9864945, theta=-62.247676 -> V=1.0, theta=0.0
% INFO    : Bus 13246	: V=0.9801774, theta=-62.700983 -> V=1.0, theta=0.0
% INFO    : Bus 13247	: V=0.9819277, theta=-62.692251 -> V=1.0, theta=0.0
% INFO    : Bus 13248	: V=0.9807564, theta=-62.671341 -> V=1.0, theta=0.0
% INFO    : Bus 13249	: V=0.9906938, theta=-61.771167 -> V=1.0, theta=0.0
% INFO    : Bus 13250	: V=0.9909882, theta=-61.755363 -> V=1.0, theta=0.0
% INFO    : Bus 13251	: V=0.9863835, theta=-62.176231 -> V=1.0, theta=0.0
% INFO    : Bus 13252	: V=0.9868434, theta=-62.137729 -> V=1.0, theta=0.0
% INFO    : Bus 13253	: V=0.9826678, theta=-62.466579 -> V=1.0, theta=0.0
% INFO    : Bus 13254	: V=0.9938942, theta=-60.811567 -> V=1.0, theta=0.0
% INFO    : Bus 13255	: V=0.9799027, theta=-62.866357 -> V=1.0, theta=0.0
% INFO    : Bus 13256	: V=0.9787347, theta=-63.012516 -> V=1.0, theta=0.0
% INFO    : Bus 13257	: V=0.9849056, theta=-62.315243 -> V=1.0, theta=0.0
% INFO    : Bus 13258	: V=0.981235, theta=-62.763929 -> V=1.0, theta=0.0
% INFO    : Bus 13259	: V=0.9856346, theta=-62.327323 -> V=1.0, theta=0.0
% INFO    : Bus 13260	: V=0.9852572, theta=-62.36246 -> V=1.0, theta=0.0
% INFO    : Bus 13261	: V=0.981313, theta=-62.734571 -> V=1.0, theta=0.0
% INFO    : Bus 13262	: V=0.9821826, theta=-62.653802 -> V=1.0, theta=0.0
% INFO    : Bus 13263	: V=0.9833231, theta=-62.545602 -> V=1.0, theta=0.0
% INFO    : Bus 13264	: V=0.9763177, theta=-63.465144 -> V=1.0, theta=0.0
% INFO    : Bus 13265	: V=0.9765449, theta=-63.460487 -> V=1.0, theta=0.0
% INFO    : Bus 13266	: V=0.9761284, theta=-63.517493 -> V=1.0, theta=0.0
% INFO    : Bus 13267	: V=0.9760366, theta=-63.525783 -> V=1.0, theta=0.0
% INFO    : Bus 13268	: V=0.9762652, theta=-63.506048 -> V=1.0, theta=0.0
% INFO    : Bus 13269	: V=0.9726536, theta=-63.888616 -> V=1.0, theta=0.0
% INFO    : Bus 13270	: V=0.984896, theta=-62.193709 -> V=1.0, theta=0.0
% INFO    : Bus 13271	: V=0.9852079, theta=-62.179216 -> V=1.0, theta=0.0
% INFO    : Bus 13272	: V=0.9772966, theta=-63.283027 -> V=1.0, theta=0.0
% INFO    : Bus 13273	: V=0.9770655, theta=-63.285357 -> V=1.0, theta=0.0
% INFO    : Bus 13274	: V=0.9777009, theta=-63.163077 -> V=1.0, theta=0.0
% INFO    : Bus 13275	: V=0.9770608, theta=-63.256632 -> V=1.0, theta=0.0
% INFO    : Bus 13276	: V=0.9769577, theta=-63.27735 -> V=1.0, theta=0.0
% INFO    : Bus 13277	: V=0.9761917, theta=-63.408053 -> V=1.0, theta=0.0
% INFO    : Bus 13278	: V=0.9759528, theta=-63.459574 -> V=1.0, theta=0.0
% INFO    : Bus 13279	: V=0.9843207, theta=-62.100186 -> V=1.0, theta=0.0
% INFO    : Bus 13280	: V=0.9838596, theta=-62.143054 -> V=1.0, theta=0.0
% INFO    : Bus 13281	: V=0.9747145, theta=-63.704266 -> V=1.0, theta=0.0
% INFO    : Bus 13282	: V=0.9763012, theta=-63.373207 -> V=1.0, theta=0.0
% INFO    : Bus 13283	: V=0.974196, theta=-63.742808 -> V=1.0, theta=0.0
% INFO    : Bus 13284	: V=0.9770106, theta=-63.408088 -> V=1.0, theta=0.0
% INFO    : Bus 13285	: V=0.9771466, theta=-63.39919 -> V=1.0, theta=0.0
% INFO    : Bus 13286	: V=0.9655607, theta=-64.769885 -> V=1.0, theta=0.0
% INFO    : Bus 13287	: V=0.9767253, theta=-63.271467 -> V=1.0, theta=0.0
% INFO    : Bus 13288	: V=0.9767322, theta=-63.26037 -> V=1.0, theta=0.0
% INFO    : Bus 13289	: V=0.9693265, theta=-64.365608 -> V=1.0, theta=0.0
% INFO    : Bus 13290	: V=0.9773874, theta=-63.20213 -> V=1.0, theta=0.0
% INFO    : Bus 13291	: V=0.9724976, theta=-63.977713 -> V=1.0, theta=0.0
% INFO    : Bus 13292	: V=0.9728922, theta=-63.940901 -> V=1.0, theta=0.0
% INFO    : Bus 13293	: V=0.9719983, theta=-64.017679 -> V=1.0, theta=0.0
% INFO    : Bus 13294	: V=0.971519, theta=-64.053392 -> V=1.0, theta=0.0
% INFO    : Bus 13295	: V=0.9750231, theta=-63.600729 -> V=1.0, theta=0.0
% INFO    : Bus 13296	: V=0.9721747, theta=-63.984948 -> V=1.0, theta=0.0
% INFO    : Bus 13297	: V=0.9699258, theta=-64.268317 -> V=1.0, theta=0.0
% INFO    : Bus 13298	: V=0.9711126, theta=-64.090883 -> V=1.0, theta=0.0
% INFO    : Bus 13299	: V=0.9684494, theta=-64.448106 -> V=1.0, theta=0.0
% INFO    : Bus 13300	: V=0.9693225, theta=-64.332964 -> V=1.0, theta=0.0
% INFO    : Bus 13301	: V=0.9652619, theta=-64.818618 -> V=1.0, theta=0.0
% INFO    : Bus 13302	: V=0.9686525, theta=-64.426564 -> V=1.0, theta=0.0
% INFO    : Bus 13303	: V=0.9678072, theta=-64.552771 -> V=1.0, theta=0.0
% INFO    : Bus 13304	: V=0.9665026, theta=-64.695023 -> V=1.0, theta=0.0
% INFO    : Bus 13305	: V=0.965557, theta=-64.790773 -> V=1.0, theta=0.0
% INFO    : Bus 13306	: V=0.9683864, theta=-64.402223 -> V=1.0, theta=0.0
% INFO    : Bus 13307	: V=0.9689262, theta=-64.351535 -> V=1.0, theta=0.0
% INFO    : Bus 13308	: V=0.9633681, theta=-65.058269 -> V=1.0, theta=0.0
% INFO    : Bus 13309	: V=0.9614891, theta=-65.273217 -> V=1.0, theta=0.0
% INFO    : Bus 13310	: V=0.9615511, theta=-65.271195 -> V=1.0, theta=0.0
% INFO    : Bus 13311	: V=0.9625757, theta=-65.153911 -> V=1.0, theta=0.0
% INFO    : Bus 13312	: V=0.9674284, theta=-64.478797 -> V=1.0, theta=0.0
% INFO    : Bus 13313	: V=0.9670724, theta=-64.507808 -> V=1.0, theta=0.0
% INFO    : Bus 13314	: V=0.9668741, theta=-64.522222 -> V=1.0, theta=0.0
% INFO    : Bus 13315	: V=0.9632535, theta=-65.024332 -> V=1.0, theta=0.0
% INFO    : Bus 13316	: V=0.9639873, theta=-64.955524 -> V=1.0, theta=0.0
% INFO    : Bus 13317	: V=0.9616745, theta=-65.126846 -> V=1.0, theta=0.0
% INFO    : Bus 13318	: V=0.9634172, theta=-65.001408 -> V=1.0, theta=0.0
% INFO    : Bus 13319	: V=0.9631091, theta=-65.001461 -> V=1.0, theta=0.0
% INFO    : Bus 13320	: V=0.9631847, theta=-64.97464 -> V=1.0, theta=0.0
% INFO    : Bus 13321	: V=0.9641541, theta=-64.910554 -> V=1.0, theta=0.0
% INFO    : Bus 13322	: V=0.9654913, theta=-64.835488 -> V=1.0, theta=0.0
% INFO    : Bus 13323	: V=0.9664891, theta=-64.736512 -> V=1.0, theta=0.0
% INFO    : Bus 13324	: V=0.9670485, theta=-64.732055 -> V=1.0, theta=0.0
% INFO    : Bus 13325	: V=0.9664383, theta=-64.689326 -> V=1.0, theta=0.0
% INFO    : Bus 13326	: V=0.9666899, theta=-64.685202 -> V=1.0, theta=0.0
% INFO    : Bus 13327	: V=0.9660357, theta=-64.738493 -> V=1.0, theta=0.0
% INFO    : Bus 13328	: V=0.9656492, theta=-64.774016 -> V=1.0, theta=0.0
% INFO    : Bus 13329	: V=0.9640505, theta=-64.943079 -> V=1.0, theta=0.0
% INFO    : Bus 13330	: V=0.9655616, theta=-64.789102 -> V=1.0, theta=0.0
% INFO    : Bus 13331	: V=0.9652833, theta=-64.808903 -> V=1.0, theta=0.0
% INFO    : Bus 13332	: V=0.9686563, theta=-64.435053 -> V=1.0, theta=0.0
% INFO    : Bus 13333	: V=0.9731224, theta=-63.881901 -> V=1.0, theta=0.0
% INFO    : Bus 13334	: V=0.9725767, theta=-63.892987 -> V=1.0, theta=0.0
% INFO    : Bus 13335	: V=0.9674351, theta=-64.593505 -> V=1.0, theta=0.0
% INFO    : Bus 13336	: V=0.9807874, theta=-62.784922 -> V=1.0, theta=0.0
% INFO    : Bus 13337	: V=0.9697168, theta=-64.422996 -> V=1.0, theta=0.0
% INFO    : Bus 13338	: V=0.9691694, theta=-64.471353 -> V=1.0, theta=0.0
% INFO    : Bus 13339	: V=0.9687795, theta=-64.503688 -> V=1.0, theta=0.0
% INFO    : Bus 13340	: V=0.9805144, theta=-62.812588 -> V=1.0, theta=0.0
% INFO    : Bus 13341	: V=0.9802229, theta=-62.836548 -> V=1.0, theta=0.0
% INFO    : Bus 13342	: V=0.982966, theta=-62.565033 -> V=1.0, theta=0.0
% INFO    : Bus 13343	: V=0.9826499, theta=-62.592252 -> V=1.0, theta=0.0
% INFO    : Bus 13344	: V=0.979807, theta=-62.867973 -> V=1.0, theta=0.0
% INFO    : Bus 13345	: V=0.9795691, theta=-62.881809 -> V=1.0, theta=0.0
% INFO    : Bus 13346	: V=0.9822568, theta=-62.622766 -> V=1.0, theta=0.0
% INFO    : Bus 13347	: V=0.9833906, theta=-62.522935 -> V=1.0, theta=0.0
% INFO    : Bus 13348	: V=0.98073, theta=-62.782192 -> V=1.0, theta=0.0
% INFO    : Bus 13349	: V=0.9816625, theta=-62.329458 -> V=1.0, theta=0.0
% INFO    : Bus 13350	: V=0.9739404, theta=-63.439443 -> V=1.0, theta=0.0
% INFO    : Bus 13351	: V=0.9818745, theta=-62.325394 -> V=1.0, theta=0.0
% INFO    : Bus 13352	: V=0.981932, theta=-62.691673 -> V=1.0, theta=0.0
% INFO    : Bus 13353	: V=0.9806515, theta=-62.832572 -> V=1.0, theta=0.0
% INFO    : Bus 13354	: V=0.9683458, theta=-64.544381 -> V=1.0, theta=0.0
% INFO    : Bus 13355	: V=0.9783144, theta=-63.03115 -> V=1.0, theta=0.0
% INFO    : Bus 13356	: V=0.9681841, theta=-64.517829 -> V=1.0, theta=0.0
% INFO    : Bus 13357	: V=0.9676851, theta=-64.586694 -> V=1.0, theta=0.0
% INFO    : Bus 13358	: V=0.9684702, theta=-64.518861 -> V=1.0, theta=0.0
% INFO    : Bus 13359	: V=0.9678239, theta=-64.565061 -> V=1.0, theta=0.0
% INFO    : Bus 13360	: V=0.9770931, theta=-63.174391 -> V=1.0, theta=0.0
% INFO    : Bus 13361	: V=0.9680341, theta=-64.551971 -> V=1.0, theta=0.0
% INFO    : Bus 13362	: V=0.9716239, theta=-64.155578 -> V=1.0, theta=0.0
% INFO    : Bus 13363	: V=0.9723401, theta=-64.080963 -> V=1.0, theta=0.0
% INFO    : Bus 13364	: V=0.9784584, theta=-63.049093 -> V=1.0, theta=0.0
% INFO    : Bus 13365	: V=0.9777415, theta=-63.113738 -> V=1.0, theta=0.0
% INFO    : Bus 13366	: V=0.9725937, theta=-63.898874 -> V=1.0, theta=0.0
% INFO    : Bus 13367	: V=0.972225, theta=-63.875451 -> V=1.0, theta=0.0
% INFO    : Bus 13368	: V=0.9728712, theta=-63.893379 -> V=1.0, theta=0.0
% INFO    : Bus 13369	: V=0.9733015, theta=-63.837886 -> V=1.0, theta=0.0
% INFO    : Bus 13370	: V=0.9733555, theta=-63.877823 -> V=1.0, theta=0.0
% INFO    : Bus 13371	: V=0.9729962, theta=-64.017115 -> V=1.0, theta=0.0
% INFO    : Bus 13372	: V=0.9812005, theta=-62.376001 -> V=1.0, theta=0.0
% INFO    : Bus 13373	: V=0.9807557, theta=-62.422205 -> V=1.0, theta=0.0
% INFO    : Bus 13374	: V=0.980485, theta=-62.539519 -> V=1.0, theta=0.0
% INFO    : Bus 13375	: V=0.9747556, theta=-63.626533 -> V=1.0, theta=0.0
% INFO    : Bus 13376	: V=0.9786137, theta=-62.803196 -> V=1.0, theta=0.0
% INFO    : Bus 13377	: V=0.9780679, theta=-62.886711 -> V=1.0, theta=0.0
% INFO    : Bus 13378	: V=0.9721009, theta=-63.957623 -> V=1.0, theta=0.0
% INFO    : Bus 13379	: V=0.977666, theta=-62.931703 -> V=1.0, theta=0.0
% INFO    : Bus 13380	: V=0.9772073, theta=-62.983772 -> V=1.0, theta=0.0
% INFO    : Bus 13381	: V=0.976732, theta=-63.034559 -> V=1.0, theta=0.0
% INFO    : Bus 13382	: V=0.9726891, theta=-63.936455 -> V=1.0, theta=0.0
% INFO    : Bus 13383	: V=0.9700523, theta=-64.335751 -> V=1.0, theta=0.0
% INFO    : Bus 13384	: V=0.9700359, theta=-64.352308 -> V=1.0, theta=0.0
% INFO    : Bus 13385	: V=0.9765836, theta=-63.234257 -> V=1.0, theta=0.0
% INFO    : Bus 13386	: V=0.9696852, theta=-64.39869 -> V=1.0, theta=0.0
% INFO    : Bus 13387	: V=0.9698079, theta=-64.389227 -> V=1.0, theta=0.0
% INFO    : Bus 13388	: V=0.9684605, theta=-64.42418 -> V=1.0, theta=0.0
% INFO    : Bus 13389	: V=0.969211, theta=-64.460279 -> V=1.0, theta=0.0
% INFO    : Bus 13390	: V=0.9678237, theta=-64.608419 -> V=1.0, theta=0.0
% INFO    : Bus 13391	: V=0.9682127, theta=-64.544389 -> V=1.0, theta=0.0
% INFO    : Bus 13392	: V=0.9664507, theta=-64.604389 -> V=1.0, theta=0.0
% INFO    : Bus 13393	: V=0.9609946, theta=-65.210656 -> V=1.0, theta=0.0
% INFO    : Bus 13394	: V=0.9681337, theta=-64.499529 -> V=1.0, theta=0.0
% INFO    : Bus 13395	: V=0.9702014, theta=-64.356143 -> V=1.0, theta=0.0
% INFO    : Bus 13396	: V=0.9700497, theta=-64.361432 -> V=1.0, theta=0.0
% INFO    : Bus 13397	: V=0.969269, theta=-64.3237 -> V=1.0, theta=0.0
% INFO    : Bus 13398	: V=0.9702525, theta=-64.305438 -> V=1.0, theta=0.0
% INFO    : Bus 13399	: V=0.9762258, theta=-63.092191 -> V=1.0, theta=0.0
% INFO    : Bus 13400	: V=0.9706625, theta=-64.243363 -> V=1.0, theta=0.0
% INFO    : Bus 13401	: V=0.9704944, theta=-64.298049 -> V=1.0, theta=0.0
% INFO    : Bus 13402	: V=0.9694844, theta=-64.315963 -> V=1.0, theta=0.0
% INFO    : Bus 13403	: V=0.9713902, theta=-64.144526 -> V=1.0, theta=0.0
% INFO    : Bus 13404	: V=0.9721271, theta=-64.11242 -> V=1.0, theta=0.0
% INFO    : Bus 13405	: V=0.9726687, theta=-64.075823 -> V=1.0, theta=0.0
% INFO    : Bus 13406	: V=0.9711793, theta=-64.264631 -> V=1.0, theta=0.0
% INFO    : Bus 13407	: V=0.9717845, theta=-64.219043 -> V=1.0, theta=0.0
% INFO    : Bus 13408	: V=0.9712564, theta=-64.2859 -> V=1.0, theta=0.0
% INFO    : Bus 13409	: V=0.9683056, theta=-64.565626 -> V=1.0, theta=0.0
% INFO    : Bus 13410	: V=0.9672483, theta=-64.704431 -> V=1.0, theta=0.0
% INFO    : Bus 13411	: V=0.9665154, theta=-64.834812 -> V=1.0, theta=0.0
% INFO    : Bus 13412	: V=0.9666665, theta=-64.791278 -> V=1.0, theta=0.0
% INFO    : Bus 13413	: V=0.9660816, theta=-64.90249 -> V=1.0, theta=0.0
% INFO    : Bus 13414	: V=0.9667711, theta=-64.846243 -> V=1.0, theta=0.0
% INFO    : Bus 13415	: V=0.9791123, theta=-63.384643 -> V=1.0, theta=0.0
% INFO    : Bus 13416	: V=0.9763131, theta=-63.836305 -> V=1.0, theta=0.0
% INFO    : Bus 13417	: V=0.9729685, theta=-64.126203 -> V=1.0, theta=0.0
% INFO    : Bus 13418	: V=0.9736726, theta=-64.071723 -> V=1.0, theta=0.0
% INFO    : Bus 13419	: V=0.9887041, theta=-62.116063 -> V=1.0, theta=0.0
% INFO    : Bus 13420	: V=0.990261, theta=-61.958471 -> V=1.0, theta=0.0
% INFO    : Bus 13421	: V=0.9774828, theta=-63.717785 -> V=1.0, theta=0.0
% INFO    : Bus 13422	: V=0.97561, theta=-63.910209 -> V=1.0, theta=0.0
% INFO    : Bus 13423	: V=0.9726046, theta=-64.195289 -> V=1.0, theta=0.0
% INFO    : Bus 13424	: V=0.9682352, theta=-64.685559 -> V=1.0, theta=0.0
% INFO    : Bus 13425	: V=0.9698187, theta=-64.508158 -> V=1.0, theta=0.0
% INFO    : Bus 13426	: V=0.9954017, theta=-60.981738 -> V=1.0, theta=0.0
% INFO    : Bus 13427	: V=0.9832125, theta=-63.326288 -> V=1.0, theta=0.0
% INFO    : Bus 13428	: V=1.0129488, theta=-58.370448 -> V=1.0, theta=0.0
% INFO    : Bus 13429	: V=0.9871968, theta=-61.523693 -> V=1.0, theta=0.0
% INFO    : Bus 13430	: V=0.989715, theta=-61.322125 -> V=1.0, theta=0.0
% INFO    : Bus 13431	: V=0.9857786, theta=-62.065698 -> V=1.0, theta=0.0
% INFO    : Bus 13432	: V=0.9946607, theta=-61.306255 -> V=1.0, theta=0.0
% INFO    : Bus 13433	: V=0.9892364, theta=-61.947901 -> V=1.0, theta=0.0
% INFO    : Bus 13434	: V=1.0086645, theta=-58.835122 -> V=1.0, theta=0.0
% INFO    : Bus 13435	: V=0.989026, theta=-61.872957 -> V=1.0, theta=0.0
% INFO    : Bus 13436	: V=0.9816817, theta=-62.64793 -> V=1.0, theta=0.0
% INFO    : Bus 13437	: V=0.9791039, theta=-62.697766 -> V=1.0, theta=0.0
% INFO    : Bus 13438	: V=0.9872278, theta=-62.077826 -> V=1.0, theta=0.0
% INFO    : Bus 13439	: V=0.9950071, theta=-60.732519 -> V=1.0, theta=0.0
% INFO    : Bus 13440	: V=0.9697458, theta=-64.359632 -> V=1.0, theta=0.0
% INFO    : Bus 13441	: V=0.9639327, theta=-65.217192 -> V=1.0, theta=0.0
% INFO    : Bus 13442	: V=0.9689299, theta=-64.428263 -> V=1.0, theta=0.0
% INFO    : Bus 13443	: V=0.970518, theta=-64.203522 -> V=1.0, theta=0.0
% INFO    : Bus 13444	: V=0.9677512, theta=-64.581307 -> V=1.0, theta=0.0
% INFO    : Bus 13445	: V=0.9661962, theta=-64.712853 -> V=1.0, theta=0.0
% INFO    : Bus 13446	: V=0.9703955, theta=-64.26148 -> V=1.0, theta=0.0
% INFO    : Bus 13447	: V=0.9895768, theta=-61.643843 -> V=1.0, theta=0.0
% INFO    : Bus 13448	: V=0.9762786, theta=-63.347095 -> V=1.0, theta=0.0
% INFO    : Bus 13449	: V=0.969657, theta=-64.392952 -> V=1.0, theta=0.0
% INFO    : Bus 13450	: V=1.0010866, theta=-60.328471 -> V=1.0, theta=0.0
% INFO    : Bus 13451	: V=0.9931699, theta=-61.173973 -> V=1.0, theta=0.0
% INFO    : Bus 13452	: V=0.9884463, theta=-61.429054 -> V=1.0, theta=0.0
% INFO    : Bus 13453	: V=0.9973827, theta=-60.146857 -> V=1.0, theta=0.0
% INFO    : Bus 13454	: V=0.9877321, theta=-61.872355 -> V=1.0, theta=0.0
% INFO    : Bus 13455	: V=1.0129476, theta=-58.109547 -> V=1.0, theta=0.0
% INFO    : Bus 13456	: V=0.9704903, theta=-64.184827 -> V=1.0, theta=0.0
% INFO    : Bus 13457	: V=0.9660121, theta=-68.638822 -> V=1.0, theta=0.0
% INFO    : Bus 13458	: V=0.9528648, theta=-69.811453 -> V=1.0, theta=0.0
% INFO    : Bus 13459	: V=0.9553206, theta=-69.74149 -> V=1.0, theta=0.0
% INFO    : Bus 13460	: V=0.966054, theta=-69.046795 -> V=1.0, theta=0.0
% INFO    : Bus 13461	: V=0.9644297, theta=-68.67915 -> V=1.0, theta=0.0
% INFO    : Bus 13462	: V=0.9655929, theta=-69.173127 -> V=1.0, theta=0.0
% INFO    : Bus 13463	: V=0.9657167, theta=-69.245829 -> V=1.0, theta=0.0
% INFO    : Bus 13464	: V=0.9653637, theta=-68.849304 -> V=1.0, theta=0.0
% INFO    : Bus 13465	: V=0.9628754, theta=-68.766289 -> V=1.0, theta=0.0
% INFO    : Bus 13466	: V=0.9660683, theta=-68.377882 -> V=1.0, theta=0.0
% INFO    : Bus 13467	: V=0.9598302, theta=-69.618503 -> V=1.0, theta=0.0
% INFO    : Bus 13468	: V=0.9656156, theta=-68.440388 -> V=1.0, theta=0.0
% INFO    : Bus 13469	: V=0.9657516, theta=-68.386808 -> V=1.0, theta=0.0
% INFO    : Bus 13470	: V=0.9664301, theta=-67.909589 -> V=1.0, theta=0.0
% INFO    : Bus 13471	: V=0.9608601, theta=-68.158935 -> V=1.0, theta=0.0
% INFO    : Bus 13472	: V=0.9628269, theta=-67.967517 -> V=1.0, theta=0.0
% INFO    : Bus 13473	: V=0.9628143, theta=-67.756261 -> V=1.0, theta=0.0
% INFO    : Bus 13474	: V=0.9620274, theta=-68.537444 -> V=1.0, theta=0.0
% INFO    : Bus 13475	: V=0.9528715, theta=-79.952116 -> V=1.0, theta=0.0
% INFO    : Bus 13476	: V=0.941964, theta=-82.884428 -> V=1.0, theta=0.0
% INFO    : Bus 13477	: V=0.941134, theta=-81.427726 -> V=1.0, theta=0.0
% INFO    : Bus 13478	: V=0.9408717, theta=-80.286757 -> V=1.0, theta=0.0
% INFO    : Bus 13479	: V=0.9369429, theta=-80.415146 -> V=1.0, theta=0.0
% INFO    : Bus 13480	: V=1.006107, theta=-59.518166 -> V=1.0, theta=0.0
% INFO    : Bus 13481	: V=1.0181058, theta=-56.893486 -> V=1.0, theta=0.0
% INFO    : Bus 13482	: V=1.0103736, theta=-59.163663 -> V=1.0, theta=0.0
% INFO    : Bus 13483	: V=1.010773, theta=-59.519853 -> V=1.0, theta=0.0
% INFO    : Bus 13484	: V=1.0109446, theta=-59.518315 -> V=1.0, theta=0.0
% INFO    : Bus 13485	: V=1.016929, theta=-58.972367 -> V=1.0, theta=0.0
% INFO    : Bus 13486	: V=1.0175639, theta=-58.870569 -> V=1.0, theta=0.0
% INFO    : Bus 13487	: V=1.0166361, theta=-59.043946 -> V=1.0, theta=0.0
% INFO    : Bus 13488	: V=1.0170067, theta=-60.857102 -> V=1.0, theta=0.0
% INFO    : Bus 13489	: V=0.9622975, theta=-69.532535 -> V=1.0, theta=0.0
% INFO    : Bus 13490	: V=0.9620336, theta=-69.567803 -> V=1.0, theta=0.0
% INFO    : Bus 13491	: V=0.9738911, theta=-68.720977 -> V=1.0, theta=0.0
% INFO    : Bus 13492	: V=0.9723054, theta=-68.26827 -> V=1.0, theta=0.0
% INFO    : Bus 13493	: V=0.9704327, theta=-67.468355 -> V=1.0, theta=0.0
% INFO    : Bus 13494	: V=0.967611, theta=-68.652175 -> V=1.0, theta=0.0
% INFO    : Bus 13495	: V=0.9718632, theta=-67.954361 -> V=1.0, theta=0.0
% INFO    : Bus 13496	: V=0.9744697, theta=-67.54718 -> V=1.0, theta=0.0
% INFO    : Bus 13497	: V=0.9859508, theta=-64.692507 -> V=1.0, theta=0.0
% INFO    : Bus 13498	: V=0.9847117, theta=-65.585818 -> V=1.0, theta=0.0
% INFO    : Bus 13499	: V=0.9870811, theta=-64.526349 -> V=1.0, theta=0.0
% INFO    : Bus 13500	: V=0.9877515, theta=-64.439384 -> V=1.0, theta=0.0
% INFO    : Bus 13501	: V=0.9862256, theta=-64.539341 -> V=1.0, theta=0.0
% INFO    : Bus 13502	: V=0.9922936, theta=-63.950058 -> V=1.0, theta=0.0
% INFO    : Bus 13503	: V=0.9898245, theta=-64.212374 -> V=1.0, theta=0.0
% INFO    : Bus 13504	: V=1.0052503, theta=-62.397362 -> V=1.0, theta=0.0
% INFO    : Bus 13505	: V=1.0018652, theta=-62.501992 -> V=1.0, theta=0.0
% INFO    : Bus 13506	: V=1.0074057, theta=-59.551185 -> V=1.0, theta=0.0
% INFO    : Bus 13507	: V=1.0065418, theta=-59.662802 -> V=1.0, theta=0.0
% INFO    : Bus 13508	: V=1.0057643, theta=-59.769596 -> V=1.0, theta=0.0
% INFO    : Bus 13509	: V=0.9985998, theta=-62.706029 -> V=1.0, theta=0.0
% INFO    : Bus 13510	: V=0.9791241, theta=-65.156972 -> V=1.0, theta=0.0
% INFO    : Bus 13511	: V=0.9807766, theta=-65.001873 -> V=1.0, theta=0.0
% INFO    : Bus 13512	: V=0.9805633, theta=-65.093913 -> V=1.0, theta=0.0
% INFO    : Bus 13513	: V=0.9800423, theta=-65.132799 -> V=1.0, theta=0.0
% INFO    : Bus 13514	: V=0.9680621, theta=-66.402601 -> V=1.0, theta=0.0
% INFO    : Bus 13515	: V=0.9805375, theta=-65.074809 -> V=1.0, theta=0.0
% INFO    : Bus 13516	: V=0.9816379, theta=-64.956547 -> V=1.0, theta=0.0
% INFO    : Bus 13517	: V=0.9732469, theta=-67.198821 -> V=1.0, theta=0.0
% INFO    : Bus 13518	: V=0.9829445, theta=-64.81909 -> V=1.0, theta=0.0
% INFO    : Bus 13519	: V=0.9838616, theta=-64.72085 -> V=1.0, theta=0.0
% INFO    : Bus 13520	: V=1.0022675, theta=-68.106132 -> V=1.0, theta=0.0
% INFO    : Bus 13521	: V=0.9688542, theta=-70.144138 -> V=1.0, theta=0.0
% INFO    : Bus 13522	: V=0.95889, theta=-70.469354 -> V=1.0, theta=0.0
% INFO    : Bus 13523	: V=0.9602706, theta=-69.498569 -> V=1.0, theta=0.0
% INFO    : Bus 13524	: V=0.9611804, theta=-69.27568 -> V=1.0, theta=0.0
% INFO    : Bus 13525	: V=0.9682888, theta=-69.685801 -> V=1.0, theta=0.0
% INFO    : Bus 13526	: V=1.0017412, theta=-67.923514 -> V=1.0, theta=0.0
% INFO    : Bus 13527	: V=0.9802842, theta=-69.405147 -> V=1.0, theta=0.0
% INFO    : Bus 13528	: V=0.9948666, theta=-60.311186 -> V=1.0, theta=0.0
% INFO    : Bus 13529	: V=0.9895013, theta=-60.868411 -> V=1.0, theta=0.0
% INFO    : Bus 13530	: V=0.9828472, theta=-62.038531 -> V=1.0, theta=0.0
% INFO    : Bus 13531	: V=0.9812764, theta=-62.412167 -> V=1.0, theta=0.0
% INFO    : Bus 13532	: V=1.0010663, theta=-59.799032 -> V=1.0, theta=0.0
% INFO    : Bus 13533	: V=1.0005543, theta=-59.887416 -> V=1.0, theta=0.0
% INFO    : Bus 13534	: V=1.0018454, theta=-59.779157 -> V=1.0, theta=0.0
% INFO    : Bus 13535	: V=0.9708643, theta=-61.267938 -> V=1.0, theta=0.0
% INFO    : Bus 13536	: V=0.9704602, theta=-61.457193 -> V=1.0, theta=0.0
% INFO    : Bus 13537	: V=0.972725, theta=-61.697387 -> V=1.0, theta=0.0
% INFO    : Bus 13538	: V=0.9701896, theta=-61.509743 -> V=1.0, theta=0.0
% INFO    : Bus 13539	: V=0.9704107, theta=-61.500512 -> V=1.0, theta=0.0
% INFO    : Bus 13540	: V=1.0031267, theta=-59.000259 -> V=1.0, theta=0.0
% INFO    : Bus 13541	: V=1.0027566, theta=-57.673091 -> V=1.0, theta=0.0
% INFO    : Bus 13542	: V=1.0047472, theta=-57.744918 -> V=1.0, theta=0.0
% INFO    : Bus 13543	: V=1.0064073, theta=-57.572386 -> V=1.0, theta=0.0
% INFO    : Bus 13544	: V=1.0037253, theta=-57.802426 -> V=1.0, theta=0.0
% INFO    : Bus 13545	: V=1.00553, theta=-57.555219 -> V=1.0, theta=0.0
% INFO    : Bus 13546	: V=0.9878303, theta=-59.929735 -> V=1.0, theta=0.0
% INFO    : Bus 13547	: V=0.9615471, theta=-61.329895 -> V=1.0, theta=0.0
% INFO    : Bus 13548	: V=1.0050536, theta=-57.448994 -> V=1.0, theta=0.0
% INFO    : Bus 13549	: V=0.974686, theta=-69.443886 -> V=1.0, theta=0.0
% INFO    : Bus 13550	: V=0.9748756, theta=-69.649847 -> V=1.0, theta=0.0
% INFO    : Bus 13551	: V=0.9357366, theta=-76.907421 -> V=1.0, theta=0.0
% INFO    : Bus 13552	: V=0.9480922, theta=-74.905181 -> V=1.0, theta=0.0
% INFO    : Bus 13553	: V=0.9370205, theta=-74.298148 -> V=1.0, theta=0.0
% INFO    : Bus 13554	: V=0.931476, theta=-74.57439 -> V=1.0, theta=0.0
% INFO    : Bus 13555	: V=0.948849, theta=-72.884439 -> V=1.0, theta=0.0
% INFO    : Bus 13556	: V=0.9560142, theta=-73.399515 -> V=1.0, theta=0.0
% INFO    : Bus 13557	: V=0.9592385, theta=-73.320968 -> V=1.0, theta=0.0
% INFO    : Bus 13558	: V=0.9678155, theta=-71.618802 -> V=1.0, theta=0.0
% INFO    : Bus 13559	: V=0.9630527, theta=-71.780341 -> V=1.0, theta=0.0
% INFO    : Bus 13560	: V=0.9559721, theta=-72.297728 -> V=1.0, theta=0.0
% INFO    : Bus 13561	: V=0.9610091, theta=-71.197271 -> V=1.0, theta=0.0
% INFO    : Bus 13562	: V=0.9462207, theta=-80.741073 -> V=1.0, theta=0.0
% INFO    : Bus 13563	: V=0.9393542, theta=-82.245364 -> V=1.0, theta=0.0
% INFO    : Bus 13564	: V=0.9499829, theta=-80.396172 -> V=1.0, theta=0.0
% INFO    : Bus 13565	: V=0.9489947, theta=-80.518238 -> V=1.0, theta=0.0
% INFO    : Bus 13566	: V=0.9537136, theta=-78.677995 -> V=1.0, theta=0.0
% INFO    : Bus 13567	: V=0.9480116, theta=-79.943319 -> V=1.0, theta=0.0
% INFO    : Bus 13568	: V=0.9543818, theta=-79.56645 -> V=1.0, theta=0.0
% INFO    : Bus 13569	: V=0.950817, theta=-80.105907 -> V=1.0, theta=0.0
% INFO    : Bus 13570	: V=0.9413703, theta=-81.357328 -> V=1.0, theta=0.0
% INFO    : Bus 13571	: V=0.9492593, theta=-78.097372 -> V=1.0, theta=0.0
% INFO    : Bus 13572	: V=0.9628455, theta=-71.534224 -> V=1.0, theta=0.0
% INFO    : Bus 13573	: V=0.9698139, theta=-69.567273 -> V=1.0, theta=0.0
% INFO    : Bus 13574	: V=0.9709612, theta=-69.781123 -> V=1.0, theta=0.0
% INFO    : Bus 13575	: V=0.9649354, theta=-70.487156 -> V=1.0, theta=0.0
% INFO    : Bus 13576	: V=0.9741691, theta=-69.760277 -> V=1.0, theta=0.0
% INFO    : Bus 13577	: V=0.9858067, theta=-69.091232 -> V=1.0, theta=0.0
% INFO    : Bus 13578	: V=0.9796433, theta=-69.458332 -> V=1.0, theta=0.0
% INFO    : Bus 13579	: V=0.9653986, theta=-71.160781 -> V=1.0, theta=0.0
% INFO    : Bus 13580	: V=0.9774075, theta=-69.583381 -> V=1.0, theta=0.0
% INFO    : Bus 13581	: V=0.970443, theta=-70.666912 -> V=1.0, theta=0.0
% INFO    : Bus 13582	: V=0.9531923, theta=-74.883349 -> V=1.0, theta=0.0
% INFO    : Bus 13583	: V=0.9757603, theta=-71.687547 -> V=1.0, theta=0.0
% INFO    : Bus 13584	: V=0.9980596, theta=-69.514012 -> V=1.0, theta=0.0
% INFO    : Bus 13585	: V=0.9939902, theta=-69.902667 -> V=1.0, theta=0.0
% INFO    : Bus 13586	: V=0.9797648, theta=-71.821001 -> V=1.0, theta=0.0
% INFO    : Bus 13587	: V=0.9807714, theta=-71.800687 -> V=1.0, theta=0.0
% INFO    : Bus 13588	: V=0.9921452, theta=-70.058259 -> V=1.0, theta=0.0
% INFO    : Bus 13589	: V=0.9998974, theta=-68.925954 -> V=1.0, theta=0.0
% INFO    : Bus 13590	: V=1.0010564, theta=-68.808899 -> V=1.0, theta=0.0
% INFO    : Bus 13591	: V=0.9949485, theta=-69.560937 -> V=1.0, theta=0.0
% INFO    : Bus 13592	: V=0.9911538, theta=-70.40011 -> V=1.0, theta=0.0
% INFO    : Bus 13593	: V=0.994591, theta=-69.782761 -> V=1.0, theta=0.0
% INFO    : Bus 13594	: V=0.9944089, theta=-69.19087 -> V=1.0, theta=0.0
% INFO    : Bus 13595	: V=1.0048197, theta=-68.432408 -> V=1.0, theta=0.0
% INFO    : Bus 13596	: V=0.9793596, theta=-68.09204 -> V=1.0, theta=0.0
% INFO    : Bus 13597	: V=1.0020364, theta=-68.337961 -> V=1.0, theta=0.0
% INFO    : Bus 13598	: V=1.0087129, theta=-71.595348 -> V=1.0, theta=0.0
% INFO    : Bus 13599	: V=0.9733993, theta=-74.517939 -> V=1.0, theta=0.0
% INFO    : Bus 13600	: V=0.9673121, theta=-73.474388 -> V=1.0, theta=0.0
% INFO    : Bus 13601	: V=0.973644, theta=-74.481706 -> V=1.0, theta=0.0
% INFO    : Bus 13602	: V=0.977408, theta=-73.203876 -> V=1.0, theta=0.0
% INFO    : Bus 13603	: V=1.0043405, theta=-71.438972 -> V=1.0, theta=0.0
% INFO    : Bus 13604	: V=0.9979812, theta=-72.282713 -> V=1.0, theta=0.0
% INFO    : Bus 13605	: V=1.0087345, theta=-71.146419 -> V=1.0, theta=0.0
% INFO    : Bus 13606	: V=0.9968285, theta=-72.348772 -> V=1.0, theta=0.0
% INFO    : Bus 13607	: V=1.005505, theta=-71.563452 -> V=1.0, theta=0.0
% INFO    : Bus 13608	: V=0.998453, theta=-71.736128 -> V=1.0, theta=0.0
% INFO    : Bus 13609	: V=0.9955074, theta=-71.926965 -> V=1.0, theta=0.0
% INFO    : Bus 13610	: V=0.9830613, theta=-73.260908 -> V=1.0, theta=0.0
% INFO    : Bus 13611	: V=0.9875956, theta=-56.502167 -> V=1.0, theta=0.0
% INFO    : Bus 13612	: V=0.9893272, theta=-55.074241 -> V=1.0, theta=0.0
% INFO    : Bus 13613	: V=0.9744811, theta=-57.802293 -> V=1.0, theta=0.0
% INFO    : Bus 13614	: V=0.9759652, theta=-57.768264 -> V=1.0, theta=0.0
% INFO    : Bus 13615	: V=0.9563191, theta=-62.752282 -> V=1.0, theta=0.0
% INFO    : Bus 13616	: V=0.9648394, theta=-61.802567 -> V=1.0, theta=0.0
% INFO    : Bus 13617	: V=0.9692768, theta=-56.718954 -> V=1.0, theta=0.0
% INFO    : Bus 13618	: V=0.9697524, theta=-59.197021 -> V=1.0, theta=0.0
% INFO    : Bus 13619	: V=0.9741665, theta=-55.280509 -> V=1.0, theta=0.0
% INFO    : Bus 13620	: V=0.9744322, theta=-56.30173 -> V=1.0, theta=0.0
% INFO    : Bus 13621	: V=0.9749922, theta=-59.393602 -> V=1.0, theta=0.0
% INFO    : Bus 13622	: V=0.9646285, theta=-62.026408 -> V=1.0, theta=0.0
% INFO    : Bus 13623	: V=0.9715423, theta=-59.140587 -> V=1.0, theta=0.0
% INFO    : Bus 13624	: V=0.9701497, theta=-58.967711 -> V=1.0, theta=0.0
% INFO    : Bus 13625	: V=0.9711827, theta=-59.147102 -> V=1.0, theta=0.0
% INFO    : Bus 13626	: V=0.9811929, theta=-58.80438 -> V=1.0, theta=0.0
% INFO    : Bus 13627	: V=0.9829736, theta=-58.647615 -> V=1.0, theta=0.0
% INFO    : Bus 13628	: V=0.9851909, theta=-58.453649 -> V=1.0, theta=0.0
% INFO    : Bus 13629	: V=0.9885008, theta=-57.59094 -> V=1.0, theta=0.0
% INFO    : Bus 13630	: V=0.9680852, theta=-62.010125 -> V=1.0, theta=0.0
% INFO    : Bus 13631	: V=0.9683651, theta=-61.821101 -> V=1.0, theta=0.0
% INFO    : Bus 13632	: V=0.9713581, theta=-61.30537 -> V=1.0, theta=0.0
% INFO    : Bus 13633	: V=0.9852998, theta=-59.836802 -> V=1.0, theta=0.0
% INFO    : Bus 13634	: V=0.9704622, theta=-57.991165 -> V=1.0, theta=0.0
% INFO    : Bus 13635	: V=0.9846389, theta=-56.636092 -> V=1.0, theta=0.0
% INFO    : Bus 13636	: V=0.9738586, theta=-57.077115 -> V=1.0, theta=0.0
% INFO    : Bus 13637	: V=0.987976, theta=-56.494615 -> V=1.0, theta=0.0
% INFO    : Bus 13638	: V=0.988853, theta=-56.422902 -> V=1.0, theta=0.0
% INFO    : Bus 13639	: V=0.9772769, theta=-57.764008 -> V=1.0, theta=0.0
% INFO    : Bus 13640	: V=0.9864172, theta=-56.559692 -> V=1.0, theta=0.0
% INFO    : Bus 13641	: V=0.9768921, theta=-57.679065 -> V=1.0, theta=0.0
% INFO    : Bus 13642	: V=0.9765546, theta=-57.684788 -> V=1.0, theta=0.0
% INFO    : Bus 13643	: V=0.9858407, theta=-56.649456 -> V=1.0, theta=0.0
% INFO    : Bus 13644	: V=1.0079203, theta=-53.418049 -> V=1.0, theta=0.0
% INFO    : Bus 13645	: V=0.977006, theta=-55.980207 -> V=1.0, theta=0.0
% INFO    : Bus 13646	: V=0.9603859, theta=-60.708149 -> V=1.0, theta=0.0
% INFO    : Bus 13647	: V=1.0119201, theta=-53.207123 -> V=1.0, theta=0.0
% INFO    : Bus 13648	: V=0.9835961, theta=-58.893727 -> V=1.0, theta=0.0
% INFO    : Bus 13649	: V=0.9771353, theta=-59.599725 -> V=1.0, theta=0.0
% INFO    : Bus 13650	: V=0.991536, theta=-59.262389 -> V=1.0, theta=0.0
% INFO    : Bus 13651	: V=0.9753592, theta=-61.870071 -> V=1.0, theta=0.0
% INFO    : Bus 13652	: V=0.9991114, theta=-59.025301 -> V=1.0, theta=0.0
% INFO    : Bus 13653	: V=0.9801887, theta=-60.361793 -> V=1.0, theta=0.0
% INFO    : Bus 13654	: V=0.979762, theta=-60.367494 -> V=1.0, theta=0.0
% INFO    : Bus 13655	: V=0.9942987, theta=-59.264308 -> V=1.0, theta=0.0
% INFO    : Bus 13656	: V=0.9952173, theta=-57.695547 -> V=1.0, theta=0.0
% INFO    : Bus 13657	: V=0.9838077, theta=-59.980579 -> V=1.0, theta=0.0
% INFO    : Bus 13658	: V=0.9691178, theta=-60.26824 -> V=1.0, theta=0.0
% INFO    : Bus 13659	: V=0.9763103, theta=-60.061927 -> V=1.0, theta=0.0
% INFO    : Bus 13660	: V=0.980174, theta=-58.669105 -> V=1.0, theta=0.0
% INFO    : Bus 13661	: V=0.9806536, theta=-58.61538 -> V=1.0, theta=0.0
% INFO    : Bus 13662	: V=0.9827405, theta=-58.399148 -> V=1.0, theta=0.0
% INFO    : Bus 13663	: V=0.9758183, theta=-59.835155 -> V=1.0, theta=0.0
% INFO    : Bus 13664	: V=0.9864119, theta=-58.013724 -> V=1.0, theta=0.0
% INFO    : Bus 13665	: V=0.9891092, theta=-57.703311 -> V=1.0, theta=0.0
% INFO    : Bus 13666	: V=0.9935549, theta=-57.079292 -> V=1.0, theta=0.0
% INFO    : Bus 13667	: V=0.9784102, theta=-59.064939 -> V=1.0, theta=0.0
% INFO    : Bus 13668	: V=0.9901951, theta=-58.102978 -> V=1.0, theta=0.0
% INFO    : Bus 13669	: V=0.9745603, theta=-55.334288 -> V=1.0, theta=0.0
% INFO    : Bus 13670	: V=0.9430843, theta=-72.32055 -> V=1.0, theta=0.0
% INFO    : Bus 13671	: V=0.9445497, theta=-72.759485 -> V=1.0, theta=0.0
% INFO    : Bus 13672	: V=0.9615786, theta=-71.029796 -> V=1.0, theta=0.0
% INFO    : Bus 13673	: V=0.9435163, theta=-71.504538 -> V=1.0, theta=0.0
% INFO    : Bus 13674	: V=0.9365711, theta=-71.682977 -> V=1.0, theta=0.0
% INFO    : Bus 13675	: V=0.9664878, theta=-69.29375 -> V=1.0, theta=0.0
% INFO    : Bus 13676	: V=0.967329, theta=-69.386899 -> V=1.0, theta=0.0
% INFO    : Bus 13677	: V=0.967741, theta=-69.477625 -> V=1.0, theta=0.0
% INFO    : Bus 13678	: V=0.9692797, theta=-69.305268 -> V=1.0, theta=0.0
% INFO    : Bus 13679	: V=0.967417, theta=-69.37578 -> V=1.0, theta=0.0
% INFO    : Bus 13680	: V=0.965908, theta=-69.34983 -> V=1.0, theta=0.0
% INFO    : Bus 13681	: V=0.9612151, theta=-69.931032 -> V=1.0, theta=0.0
% INFO    : Bus 13682	: V=0.9596169, theta=-69.891932 -> V=1.0, theta=0.0
% INFO    : Bus 13683	: V=0.9607512, theta=-68.791875 -> V=1.0, theta=0.0
% INFO    : Bus 13684	: V=0.9949028, theta=-61.120351 -> V=1.0, theta=0.0
% INFO    : Bus 13685	: V=0.9918275, theta=-61.598025 -> V=1.0, theta=0.0
% INFO    : Bus 13686	: V=0.9944067, theta=-61.154744 -> V=1.0, theta=0.0
% INFO    : Bus 13687	: V=0.9939087, theta=-61.187607 -> V=1.0, theta=0.0
% INFO    : Bus 13688	: V=0.9952324, theta=-61.105726 -> V=1.0, theta=0.0
% INFO    : Bus 13689	: V=0.9955428, theta=-61.085012 -> V=1.0, theta=0.0
% INFO    : Bus 13690	: V=0.9960053, theta=-61.044971 -> V=1.0, theta=0.0
% INFO    : Bus 13691	: V=0.9889031, theta=-61.764032 -> V=1.0, theta=0.0
% INFO    : Bus 13692	: V=0.9898131, theta=-61.702094 -> V=1.0, theta=0.0
% INFO    : Bus 13693	: V=0.9908353, theta=-61.653013 -> V=1.0, theta=0.0
% INFO    : Bus 13694	: V=0.990378, theta=-61.683604 -> V=1.0, theta=0.0
% INFO    : Bus 13695	: V=0.9901897, theta=-61.675147 -> V=1.0, theta=0.0
% INFO    : Bus 13696	: V=0.9925542, theta=-60.954582 -> V=1.0, theta=0.0
% INFO    : Bus 13697	: V=1.0005148, theta=-60.052078 -> V=1.0, theta=0.0
% INFO    : Bus 13698	: V=1.0042164, theta=-59.718935 -> V=1.0, theta=0.0
% INFO    : Bus 13699	: V=1.0138875, theta=-58.276309 -> V=1.0, theta=0.0
% INFO    : Bus 13700	: V=1.002897, theta=-60.088945 -> V=1.0, theta=0.0
% INFO    : Bus 13701	: V=0.9981409, theta=-60.634478 -> V=1.0, theta=0.0
% INFO    : Bus 13702	: V=0.9787006, theta=-62.83725 -> V=1.0, theta=0.0
% INFO    : Bus 13703	: V=0.9767789, theta=-62.836529 -> V=1.0, theta=0.0
% INFO    : Bus 13704	: V=0.9743434, theta=-62.665643 -> V=1.0, theta=0.0
% INFO    : Bus 13705	: V=0.972907, theta=-62.52346 -> V=1.0, theta=0.0
% INFO    : Bus 13706	: V=0.9708264, theta=-63.713409 -> V=1.0, theta=0.0
% INFO    : Bus 13707	: V=0.9762377, theta=-62.452797 -> V=1.0, theta=0.0
% INFO    : Bus 13708	: V=0.9811058, theta=-62.511058 -> V=1.0, theta=0.0
% INFO    : Bus 13709	: V=0.9697481, theta=-63.800141 -> V=1.0, theta=0.0
% INFO    : Bus 13710	: V=0.9624786, theta=-64.304495 -> V=1.0, theta=0.0
% INFO    : Bus 13711	: V=0.9645278, theta=-64.013312 -> V=1.0, theta=0.0
% INFO    : Bus 13712	: V=0.9607737, theta=-64.43714 -> V=1.0, theta=0.0
% INFO    : Bus 13713	: V=0.9544951, theta=-64.521275 -> V=1.0, theta=0.0
% INFO    : Bus 13714	: V=0.9593251, theta=-64.461474 -> V=1.0, theta=0.0
% INFO    : Bus 13715	: V=0.9507301, theta=-64.551644 -> V=1.0, theta=0.0
% INFO    : Bus 13716	: V=0.9497455, theta=-64.662734 -> V=1.0, theta=0.0
% INFO    : Bus 13717	: V=0.9503293, theta=-64.611924 -> V=1.0, theta=0.0
% INFO    : Bus 13718	: V=0.9497982, theta=-64.64271 -> V=1.0, theta=0.0
% INFO    : Bus 13719	: V=0.9574446, theta=-62.947714 -> V=1.0, theta=0.0
% INFO    : Bus 13720	: V=0.9605018, theta=-63.012586 -> V=1.0, theta=0.0
% INFO    : Bus 13721	: V=0.9616839, theta=-62.883036 -> V=1.0, theta=0.0
% INFO    : Bus 13722	: V=0.9612239, theta=-62.932721 -> V=1.0, theta=0.0
% INFO    : Bus 13723	: V=0.9631105, theta=-63.808369 -> V=1.0, theta=0.0
% INFO    : Bus 13724	: V=0.9625355, theta=-63.506648 -> V=1.0, theta=0.0
% INFO    : Bus 13725	: V=0.9675789, theta=-62.256118 -> V=1.0, theta=0.0
% INFO    : Bus 13726	: V=0.9659813, theta=-62.432934 -> V=1.0, theta=0.0
% INFO    : Bus 13727	: V=0.9636968, theta=-62.681113 -> V=1.0, theta=0.0
% INFO    : Bus 13728	: V=0.9600729, theta=-63.442211 -> V=1.0, theta=0.0
% INFO    : Bus 13729	: V=0.9526692, theta=-64.343909 -> V=1.0, theta=0.0
% INFO    : Bus 13730	: V=0.9488404, theta=-64.741449 -> V=1.0, theta=0.0
% INFO    : Bus 13731	: V=0.9667747, theta=-62.714113 -> V=1.0, theta=0.0
% INFO    : Bus 13732	: V=0.9484134, theta=-64.742236 -> V=1.0, theta=0.0
% INFO    : Bus 13733	: V=0.9460515, theta=-64.882392 -> V=1.0, theta=0.0
% INFO    : Bus 13734	: V=0.9470771, theta=-64.807064 -> V=1.0, theta=0.0
% INFO    : Bus 13735	: V=0.9446524, theta=-64.895637 -> V=1.0, theta=0.0
% INFO    : Bus 13736	: V=0.9440124, theta=-65.021738 -> V=1.0, theta=0.0
% INFO    : Bus 13737	: V=0.9447818, theta=-64.870212 -> V=1.0, theta=0.0
% INFO    : Bus 13738	: V=0.9455004, theta=-64.795099 -> V=1.0, theta=0.0
% INFO    : Bus 13739	: V=0.9468108, theta=-64.611733 -> V=1.0, theta=0.0
% INFO    : Bus 13740	: V=0.9429419, theta=-65.047665 -> V=1.0, theta=0.0
% INFO    : Bus 13741	: V=0.949343, theta=-64.288733 -> V=1.0, theta=0.0
% INFO    : Bus 13742	: V=0.9504051, theta=-63.895827 -> V=1.0, theta=0.0
% INFO    : Bus 13743	: V=0.946458, theta=-64.759209 -> V=1.0, theta=0.0
% INFO    : Bus 13744	: V=0.9483461, theta=-64.752359 -> V=1.0, theta=0.0
% INFO    : Bus 13745	: V=0.9600199, theta=-62.665046 -> V=1.0, theta=0.0
% INFO    : Bus 13746	: V=0.9578686, theta=-61.885772 -> V=1.0, theta=0.0
% INFO    : Bus 13747	: V=0.9579585, theta=-62.760291 -> V=1.0, theta=0.0
% INFO    : Bus 13748	: V=0.9687535, theta=-62.51254 -> V=1.0, theta=0.0
% INFO    : Bus 13749	: V=0.9778934, theta=-60.16097 -> V=1.0, theta=0.0
% INFO    : Bus 13750	: V=0.9785299, theta=-60.152241 -> V=1.0, theta=0.0
% INFO    : Bus 13751	: V=0.9770964, theta=-60.208403 -> V=1.0, theta=0.0
% INFO    : Bus 13752	: V=0.9759258, theta=-60.223692 -> V=1.0, theta=0.0
% INFO    : Bus 13753	: V=0.9824027, theta=-60.045641 -> V=1.0, theta=0.0
% INFO    : Bus 13754	: V=0.9786759, theta=-60.301945 -> V=1.0, theta=0.0
% INFO    : Bus 13755	: V=0.9730247, theta=-61.063799 -> V=1.0, theta=0.0
% INFO    : Bus 13756	: V=0.9689048, theta=-61.877558 -> V=1.0, theta=0.0
% INFO    : Bus 13757	: V=0.9699498, theta=-61.511779 -> V=1.0, theta=0.0
% INFO    : Bus 13758	: V=0.959291, theta=-62.735574 -> V=1.0, theta=0.0
% INFO    : Bus 13759	: V=0.9634034, theta=-61.32294 -> V=1.0, theta=0.0
% INFO    : Bus 13760	: V=0.9527511, theta=-63.626171 -> V=1.0, theta=0.0
% INFO    : Bus 13761	: V=0.9508072, theta=-63.72252 -> V=1.0, theta=0.0
% INFO    : Bus 13762	: V=0.9623588, theta=-61.412487 -> V=1.0, theta=0.0
% INFO    : Bus 13763	: V=0.9519127, theta=-63.531789 -> V=1.0, theta=0.0
% INFO    : Bus 13764	: V=0.9515315, theta=-63.542329 -> V=1.0, theta=0.0
% INFO    : Bus 13765	: V=0.9602106, theta=-61.639284 -> V=1.0, theta=0.0
% INFO    : Bus 13766	: V=0.9476999, theta=-63.577607 -> V=1.0, theta=0.0
% INFO    : Bus 13767	: V=0.9496543, theta=-63.520695 -> V=1.0, theta=0.0
% INFO    : Bus 13768	: V=0.944654, theta=-64.656121 -> V=1.0, theta=0.0
% INFO    : Bus 13769	: V=0.9429645, theta=-64.576277 -> V=1.0, theta=0.0
% INFO    : Bus 13770	: V=0.9513679, theta=-64.401316 -> V=1.0, theta=0.0
% INFO    : Bus 13771	: V=0.9421665, theta=-64.835005 -> V=1.0, theta=0.0
% INFO    : Bus 13772	: V=0.9514938, theta=-64.285379 -> V=1.0, theta=0.0
% INFO    : Bus 13773	: V=0.9669721, theta=-62.233419 -> V=1.0, theta=0.0
% INFO    : Bus 13774	: V=0.9527195, theta=-64.058028 -> V=1.0, theta=0.0
% INFO    : Bus 13775	: V=0.9694541, theta=-61.981051 -> V=1.0, theta=0.0
% INFO    : Bus 13776	: V=0.9801042, theta=-60.964735 -> V=1.0, theta=0.0
% INFO    : Bus 13777	: V=0.9638704, theta=-61.901741 -> V=1.0, theta=0.0
% INFO    : Bus 13778	: V=0.9771442, theta=-61.309024 -> V=1.0, theta=0.0
% INFO    : Bus 13779	: V=0.9928494, theta=-59.107126 -> V=1.0, theta=0.0
% INFO    : Bus 13780	: V=0.9832092, theta=-59.126197 -> V=1.0, theta=0.0
% INFO    : Bus 13781	: V=0.9766701, theta=-59.668606 -> V=1.0, theta=0.0
% INFO    : Bus 13782	: V=0.9811596, theta=-59.540163 -> V=1.0, theta=0.0
% INFO    : Bus 13783	: V=0.9409773, theta=-63.504837 -> V=1.0, theta=0.0
% INFO    : Bus 13784	: V=0.9767954, theta=-70.935374 -> V=1.0, theta=0.0
% INFO    : Bus 13785	: V=0.9838996, theta=-68.241115 -> V=1.0, theta=0.0
% INFO    : Bus 13786	: V=0.9593339, theta=-71.807277 -> V=1.0, theta=0.0
% INFO    : Bus 13787	: V=0.9695982, theta=-71.093291 -> V=1.0, theta=0.0
% INFO    : Bus 13788	: V=0.9642442, theta=-71.242071 -> V=1.0, theta=0.0
% INFO    : Bus 13789	: V=0.9654025, theta=-70.861557 -> V=1.0, theta=0.0
% INFO    : Bus 13790	: V=0.9617768, theta=-69.825862 -> V=1.0, theta=0.0
% INFO    : Bus 13791	: V=0.9761123, theta=-62.545372 -> V=1.0, theta=0.0
% INFO    : Bus 13792	: V=0.9767832, theta=-62.550965 -> V=1.0, theta=0.0
% INFO    : Bus 13793	: V=0.9828062, theta=-61.778312 -> V=1.0, theta=0.0
% INFO    : Bus 13794	: V=0.9825019, theta=-61.795238 -> V=1.0, theta=0.0
% INFO    : Bus 13795	: V=0.9824951, theta=-61.800132 -> V=1.0, theta=0.0
% INFO    : Bus 13796	: V=0.9756838, theta=-62.643354 -> V=1.0, theta=0.0
% INFO    : Bus 13797	: V=0.9754436, theta=-62.683229 -> V=1.0, theta=0.0
% INFO    : Bus 13798	: V=0.9824204, theta=-61.820394 -> V=1.0, theta=0.0
% INFO    : Bus 13799	: V=0.9747973, theta=-62.680301 -> V=1.0, theta=0.0
% INFO    : Bus 13800	: V=0.9752344, theta=-62.671987 -> V=1.0, theta=0.0
% INFO    : Bus 13801	: V=0.9747856, theta=-62.721973 -> V=1.0, theta=0.0
% INFO    : Bus 13802	: V=0.9744129, theta=-62.729543 -> V=1.0, theta=0.0
% INFO    : Bus 13803	: V=0.9823525, theta=-61.781127 -> V=1.0, theta=0.0
% INFO    : Bus 13804	: V=0.9827338, theta=-61.742694 -> V=1.0, theta=0.0
% INFO    : Bus 13805	: V=0.9749728, theta=-62.725375 -> V=1.0, theta=0.0
% INFO    : Bus 13806	: V=0.9749189, theta=-62.71947 -> V=1.0, theta=0.0
% INFO    : Bus 13807	: V=0.9837818, theta=-61.743577 -> V=1.0, theta=0.0
% INFO    : Bus 13808	: V=0.9850425, theta=-61.637239 -> V=1.0, theta=0.0
% INFO    : Bus 13809	: V=0.9857795, theta=-61.505363 -> V=1.0, theta=0.0
% INFO    : Bus 13810	: V=0.9827147, theta=-61.757601 -> V=1.0, theta=0.0
% INFO    : Bus 13811	: V=0.9832629, theta=-61.691413 -> V=1.0, theta=0.0
% INFO    : Bus 13812	: V=0.9831995, theta=-61.745535 -> V=1.0, theta=0.0
% INFO    : Bus 13813	: V=0.9755141, theta=-62.564334 -> V=1.0, theta=0.0
% INFO    : Bus 13814	: V=0.9846436, theta=-61.642065 -> V=1.0, theta=0.0
% INFO    : Bus 13815	: V=0.9745444, theta=-62.812501 -> V=1.0, theta=0.0
% INFO    : Bus 13816	: V=0.9797769, theta=-63.201144 -> V=1.0, theta=0.0
% INFO    : Bus 13817	: V=0.9779752, theta=-63.450413 -> V=1.0, theta=0.0
% INFO    : Bus 13818	: V=0.9892461, theta=-61.870654 -> V=1.0, theta=0.0
% INFO    : Bus 13819	: V=0.9774457, theta=-63.267472 -> V=1.0, theta=0.0
% INFO    : Bus 13820	: V=0.9864719, theta=-61.912735 -> V=1.0, theta=0.0
% INFO    : Bus 13821	: V=0.9865925, theta=-61.060912 -> V=1.0, theta=0.0
% INFO    : Bus 13822	: V=0.9855914, theta=-61.531429 -> V=1.0, theta=0.0
% INFO    : Bus 13823	: V=0.9851374, theta=-61.876086 -> V=1.0, theta=0.0
% INFO    : Bus 13824	: V=0.9953848, theta=-60.150007 -> V=1.0, theta=0.0
% INFO    : Bus 13825	: V=0.9937143, theta=-60.690885 -> V=1.0, theta=0.0
% INFO    : Bus 13826	: V=0.9943988, theta=-60.451403 -> V=1.0, theta=0.0
% INFO    : Bus 13827	: V=0.983581, theta=-61.520423 -> V=1.0, theta=0.0
% INFO    : Bus 13828	: V=0.9825094, theta=-61.683017 -> V=1.0, theta=0.0
% INFO    : Bus 13829	: V=0.982033, theta=-61.763903 -> V=1.0, theta=0.0
% INFO    : Bus 13830	: V=0.9691252, theta=-63.128235 -> V=1.0, theta=0.0
% INFO    : Bus 13831	: V=0.9873192, theta=-61.724775 -> V=1.0, theta=0.0
% INFO    : Bus 13832	: V=0.9897623, theta=-61.517494 -> V=1.0, theta=0.0
% INFO    : Bus 13833	: V=0.9760719, theta=-63.042458 -> V=1.0, theta=0.0
% INFO    : Bus 13834	: V=0.9854272, theta=-61.689127 -> V=1.0, theta=0.0
% INFO    : Bus 13835	: V=0.9751126, theta=-62.884325 -> V=1.0, theta=0.0
% INFO    : Bus 13836	: V=1.0057621, theta=-58.302778 -> V=1.0, theta=0.0
% INFO    : Bus 13837	: V=0.9776415, theta=-62.639312 -> V=1.0, theta=0.0
% INFO    : Bus 13838	: V=0.9787029, theta=-62.458973 -> V=1.0, theta=0.0
% INFO    : Bus 13839	: V=0.9739313, theta=-62.764926 -> V=1.0, theta=0.0
% INFO    : Bus 13840	: V=0.9820589, theta=-61.79872 -> V=1.0, theta=0.0
% INFO    : Bus 13841	: V=0.9770972, theta=-62.603185 -> V=1.0, theta=0.0
% INFO    : Bus 13842	: V=0.9861279, theta=-61.459274 -> V=1.0, theta=0.0
% INFO    : Bus 13843	: V=0.9875491, theta=-61.352108 -> V=1.0, theta=0.0
% INFO    : Bus 13844	: V=0.9937163, theta=-60.177424 -> V=1.0, theta=0.0
% INFO    : Bus 13845	: V=0.9872627, theta=-60.760069 -> V=1.0, theta=0.0
% INFO    : Bus 13846	: V=0.9748005, theta=-62.756923 -> V=1.0, theta=0.0
% INFO    : Bus 13847	: V=0.9778425, theta=-61.29227 -> V=1.0, theta=0.0
% INFO    : Bus 13848	: V=0.9889022, theta=-60.278747 -> V=1.0, theta=0.0
% INFO    : Bus 13849	: V=0.986857, theta=-60.076797 -> V=1.0, theta=0.0
% INFO    : Bus 13850	: V=0.9791009, theta=-61.288515 -> V=1.0, theta=0.0
% INFO    : Bus 13851	: V=0.9878598, theta=-60.080472 -> V=1.0, theta=0.0
% INFO    : Bus 13852	: V=0.9771375, theta=-61.45533 -> V=1.0, theta=0.0
% INFO    : Bus 13853	: V=0.9876484, theta=-60.034493 -> V=1.0, theta=0.0
% INFO    : Bus 13854	: V=0.975342, theta=-60.921324 -> V=1.0, theta=0.0
% INFO    : Bus 13855	: V=0.9746191, theta=-61.029682 -> V=1.0, theta=0.0
% INFO    : Bus 13856	: V=0.9786081, theta=-61.197561 -> V=1.0, theta=0.0
% INFO    : Bus 13857	: V=0.9787848, theta=-61.527987 -> V=1.0, theta=0.0
% INFO    : Bus 13858	: V=0.9835961, theta=-61.732329 -> V=1.0, theta=0.0
% INFO    : Bus 13859	: V=0.9770125, theta=-62.036892 -> V=1.0, theta=0.0
% INFO    : Bus 13860	: V=0.9665486, theta=-63.510775 -> V=1.0, theta=0.0
% INFO    : Bus 13861	: V=0.9767723, theta=-61.909403 -> V=1.0, theta=0.0
% INFO    : Bus 13862	: V=0.9763415, theta=-61.999412 -> V=1.0, theta=0.0
% INFO    : Bus 13863	: V=0.9754118, theta=-62.059269 -> V=1.0, theta=0.0
% INFO    : Bus 13864	: V=0.9700354, theta=-62.365583 -> V=1.0, theta=0.0
% INFO    : Bus 13865	: V=0.9853666, theta=-61.472873 -> V=1.0, theta=0.0
% INFO    : Bus 13866	: V=0.9704052, theta=-62.715557 -> V=1.0, theta=0.0
% INFO    : Bus 13867	: V=0.9777117, theta=-62.509399 -> V=1.0, theta=0.0
% INFO    : Bus 13868	: V=0.9823855, theta=-61.787391 -> V=1.0, theta=0.0
% INFO    : Bus 13869	: V=0.9874038, theta=-61.076188 -> V=1.0, theta=0.0
% INFO    : Bus 13870	: V=0.9895586, theta=-60.697032 -> V=1.0, theta=0.0
% INFO    : Bus 13871	: V=0.9761306, theta=-61.160726 -> V=1.0, theta=0.0
% INFO    : Bus 13872	: V=0.97791, theta=-61.102782 -> V=1.0, theta=0.0
% INFO    : Bus 13873	: V=1.0013007, theta=-57.577332 -> V=1.0, theta=0.0
% INFO    : Bus 13874	: V=0.9790978, theta=-60.93243 -> V=1.0, theta=0.0
% INFO    : Bus 13875	: V=0.9843669, theta=-60.278615 -> V=1.0, theta=0.0
% INFO    : Bus 13876	: V=0.9895195, theta=-59.704232 -> V=1.0, theta=0.0
% INFO    : Bus 13877	: V=0.9911066, theta=-59.587235 -> V=1.0, theta=0.0
% INFO    : Bus 13878	: V=0.9802846, theta=-60.438768 -> V=1.0, theta=0.0
% INFO    : Bus 13879	: V=0.9958125, theta=-57.191841 -> V=1.0, theta=0.0
% INFO    : Bus 13880	: V=0.9866666, theta=-59.630705 -> V=1.0, theta=0.0
% INFO    : Bus 13881	: V=1.0194016, theta=-51.988399 -> V=1.0, theta=0.0
% INFO    : Bus 13882	: V=1.02, theta=-56.015799 -> V=1.0, theta=0.0
% INFO    : Bus 13883	: V=0.9894361, theta=-55.441134 -> V=1.0, theta=0.0
% INFO    : Bus 13884	: V=1.02, theta=-43.375729 -> V=1.0, theta=0.0
% INFO    : Bus 13885	: V=1.02, theta=-55.797968 -> V=1.0, theta=0.0
% INFO    : Bus 13886	: V=1.02, theta=-51.819978 -> V=1.0, theta=0.0
% INFO    : Bus 13887	: V=1.0184577, theta=-51.870514 -> V=1.0, theta=0.0
% INFO    : Bus 13888	: V=1.0056302, theta=-53.667475 -> V=1.0, theta=0.0
% INFO    : Bus 13889	: V=1.012941, theta=-56.392183 -> V=1.0, theta=0.0
% INFO    : Bus 13890	: V=1.0061662, theta=-49.036448 -> V=1.0, theta=0.0
% INFO    : Bus 13891	: V=0.9961786, theta=-57.809786 -> V=1.0, theta=0.0
% INFO    : Bus 13892	: V=1.02, theta=-47.745087 -> V=1.0, theta=0.0
% INFO    : Bus 13893	: V=1.004019, theta=-53.24365 -> V=1.0, theta=0.0
% INFO    : Bus 13894	: V=1.02, theta=-47.219814 -> V=1.0, theta=0.0
% INFO    : Bus 13895	: V=1.02, theta=-46.175529 -> V=1.0, theta=0.0
% INFO    : Bus 13896	: V=1.0176667, theta=-52.857644 -> V=1.0, theta=0.0
% INFO    : Bus 13897	: V=0.9951735, theta=-54.389842 -> V=1.0, theta=0.0
% INFO    : Bus 13898	: V=1.011485, theta=-55.486515 -> V=1.0, theta=0.0
% INFO    : Bus 13899	: V=1.0080846, theta=-55.019086 -> V=1.0, theta=0.0
% INFO    : Bus 13900	: V=1.02, theta=-54.990734 -> V=1.0, theta=0.0
% INFO    : Bus 13901	: V=1.02, theta=-48.218701 -> V=1.0, theta=0.0
% INFO    : Bus 13902	: V=0.9819264, theta=-57.704856 -> V=1.0, theta=0.0
% INFO    : Bus 13903	: V=1.0050458, theta=-54.360154 -> V=1.0, theta=0.0
% INFO    : Bus 13904	: V=1.00024, theta=-55.409608 -> V=1.0, theta=0.0
% INFO    : Bus 13905	: V=0.9776349, theta=-57.16423 -> V=1.0, theta=0.0
% INFO    : Bus 13906	: V=0.9797129, theta=-57.033245 -> V=1.0, theta=0.0
% INFO    : Bus 13907	: V=1.0014172, theta=-49.219406 -> V=1.0, theta=0.0
% INFO    : Bus 13908	: V=1.02, theta=-47.649092 -> V=1.0, theta=0.0
% INFO    : Bus 13909	: V=1.0202708, theta=-51.49055 -> V=1.0, theta=0.0
% INFO    : Bus 13910	: V=0.9902229, theta=-54.991005 -> V=1.0, theta=0.0
% INFO    : Bus 13911	: V=0.976519, theta=-57.267656 -> V=1.0, theta=0.0
% INFO    : Bus 13912	: V=1.0052128, theta=-51.254299 -> V=1.0, theta=0.0
% INFO    : Bus 13913	: V=1.0062537, theta=-55.371376 -> V=1.0, theta=0.0
% INFO    : Bus 13914	: V=1.0045596, theta=-51.145716 -> V=1.0, theta=0.0
% INFO    : Bus 13915	: V=1.0152628, theta=-52.7814 -> V=1.0, theta=0.0
% INFO    : Bus 13916	: V=0.9641581, theta=-55.59096 -> V=1.0, theta=0.0
% INFO    : Bus 13917	: V=0.9612825, theta=-55.790585 -> V=1.0, theta=0.0
% INFO    : Bus 13918	: V=0.9990123, theta=-54.46634 -> V=1.0, theta=0.0
% INFO    : Bus 13919	: V=1.0214893, theta=-51.316522 -> V=1.0, theta=0.0
% INFO    : Bus 13920	: V=1.0064618, theta=-41.886433 -> V=1.0, theta=0.0
% INFO    : Bus 13921	: V=1.02, theta=-35.176387 -> V=1.0, theta=0.0
% INFO    : Bus 13922	: V=1.02, theta=-23.201417 -> V=1.0, theta=0.0
% INFO    : Bus 13923	: V=1.0057115, theta=-37.237906 -> V=1.0, theta=0.0
% INFO    : Bus 13924	: V=1.02, theta=-36.596517 -> V=1.0, theta=0.0
% INFO    : Bus 13925	: V=1.02, theta=-34.870917 -> V=1.0, theta=0.0
% INFO    : Bus 13926	: V=1.02, theta=-33.651502 -> V=1.0, theta=0.0
% INFO    : Bus 13927	: V=1.02, theta=-38.803635 -> V=1.0, theta=0.0
% INFO    : Bus 13928	: V=1.02, theta=-40.538586 -> V=1.0, theta=0.0
% INFO    : Bus 13929	: V=1.02, theta=-34.178854 -> V=1.0, theta=0.0
% INFO    : Bus 13930	: V=1.02, theta=-35.086389 -> V=1.0, theta=0.0
% INFO    : Bus 13931	: V=1.0165605, theta=-25.938591 -> V=1.0, theta=0.0
% INFO    : Bus 13932	: V=1.0144581, theta=-37.889378 -> V=1.0, theta=0.0
% INFO    : Bus 13933	: V=1.02, theta=-35.25175 -> V=1.0, theta=0.0
% INFO    : Bus 13934	: V=1.0076318, theta=-37.33992 -> V=1.0, theta=0.0
% INFO    : Bus 13935	: V=1.0147821, theta=-36.406809 -> V=1.0, theta=0.0
% INFO    : Bus 13936	: V=1.0193049, theta=-34.279807 -> V=1.0, theta=0.0
% INFO    : Bus 13937	: V=1.02, theta=-36.141575 -> V=1.0, theta=0.0
% INFO    : Bus 13938	: V=1.02, theta=-22.807642 -> V=1.0, theta=0.0
% INFO    : Bus 13939	: V=1.0162976, theta=-37.640958 -> V=1.0, theta=0.0
% INFO    : Bus 13940	: V=1.0041237, theta=-37.556629 -> V=1.0, theta=0.0
% INFO    : Bus 13941	: V=1.0181733, theta=-38.748202 -> V=1.0, theta=0.0
% INFO    : Bus 13942	: V=0.9842553, theta=-43.061972 -> V=1.0, theta=0.0
% INFO    : Bus 13943	: V=1.02, theta=-36.311414 -> V=1.0, theta=0.0
% INFO    : Bus 13944	: V=1.0200002, theta=-33.70967 -> V=1.0, theta=0.0
% INFO    : Bus 13945	: V=0.9649153, theta=-40.62987 -> V=1.0, theta=0.0
% INFO    : Bus 13946	: V=0.9722746, theta=-48.222137 -> V=1.0, theta=0.0
% INFO    : Bus 13947	: V=1.0149192, theta=-24.508562 -> V=1.0, theta=0.0
% INFO    : Bus 13948	: V=0.9762207, theta=-37.873395 -> V=1.0, theta=0.0
% INFO    : Bus 13949	: V=1.02, theta=-34.618821 -> V=1.0, theta=0.0
% INFO    : Bus 13950	: V=1.02, theta=-38.61313 -> V=1.0, theta=0.0
% INFO    : Bus 13951	: V=0.9793545, theta=-37.201642 -> V=1.0, theta=0.0
% INFO    : Bus 13952	: V=0.9931392, theta=-30.425956 -> V=1.0, theta=0.0
% INFO    : Bus 13953	: V=1.0110556, theta=-38.367401 -> V=1.0, theta=0.0
% INFO    : Bus 13954	: V=0.9974216, theta=-40.5246 -> V=1.0, theta=0.0
% INFO    : Bus 13955	: V=1.018384, theta=-38.640996 -> V=1.0, theta=0.0
% INFO    : Bus 13956	: V=1.02, theta=-37.818303 -> V=1.0, theta=0.0
% INFO    : Bus 13957	: V=1.02, theta=-38.436427 -> V=1.0, theta=0.0
% INFO    : Bus 13958	: V=0.9731308, theta=-44.808512 -> V=1.0, theta=0.0
% INFO    : Bus 13959	: V=1.0123884, theta=-44.281362 -> V=1.0, theta=0.0
% INFO    : Bus 13960	: V=1.0156425, theta=-34.747468 -> V=1.0, theta=0.0
% INFO    : Bus 13961	: V=1.0090458, theta=-35.706348 -> V=1.0, theta=0.0
% INFO    : Bus 13962	: V=0.9961405, theta=-41.102841 -> V=1.0, theta=0.0
% INFO    : Bus 13963	: V=0.9721862, theta=-42.612802 -> V=1.0, theta=0.0
% INFO    : Bus 13964	: V=0.992457, theta=-37.305808 -> V=1.0, theta=0.0
% INFO    : Bus 13965	: V=0.9791503, theta=-37.964125 -> V=1.0, theta=0.0
% INFO    : Bus 13966	: V=0.9887437, theta=-38.141632 -> V=1.0, theta=0.0
% INFO    : Bus 13967	: V=0.9987946, theta=-36.852679 -> V=1.0, theta=0.0
% INFO    : Bus 13968	: V=1.0182283, theta=-38.766289 -> V=1.0, theta=0.0
% INFO    : Bus 13969	: V=0.9565163, theta=-44.131902 -> V=1.0, theta=0.0
% INFO    : Bus 13970	: V=1.0103978, theta=-41.837911 -> V=1.0, theta=0.0
% INFO    : Bus 13971	: V=0.9563862, theta=-47.774851 -> V=1.0, theta=0.0
% INFO    : Bus 13972	: V=0.9679044, theta=-44.599072 -> V=1.0, theta=0.0
% INFO    : Bus 13973	: V=0.9617191, theta=-45.997246 -> V=1.0, theta=0.0
% INFO    : Bus 13974	: V=1.0196946, theta=-38.659187 -> V=1.0, theta=0.0
% INFO    : Bus 13975	: V=1.0199122, theta=-36.464455 -> V=1.0, theta=0.0
% INFO    : Bus 13976	: V=0.9912548, theta=-45.802535 -> V=1.0, theta=0.0
% INFO    : Bus 13977	: V=1.0166616, theta=-40.395081 -> V=1.0, theta=0.0
% INFO    : Bus 13978	: V=0.984764, theta=-42.022165 -> V=1.0, theta=0.0
% INFO    : Bus 13979	: V=1.02, theta=-35.620721 -> V=1.0, theta=0.0
% INFO    : Bus 13980	: V=1.02, theta=-41.969137 -> V=1.0, theta=0.0
% INFO    : Bus 13981	: V=1.0127684, theta=-46.410986 -> V=1.0, theta=0.0
% INFO    : Bus 13982	: V=1.02, theta=-36.486256 -> V=1.0, theta=0.0
% INFO    : Bus 13983	: V=1.02, theta=-35.977233 -> V=1.0, theta=0.0
% INFO    : Bus 13984	: V=1.02, theta=-36.851555 -> V=1.0, theta=0.0
% INFO    : Bus 13985	: V=1.02, theta=-43.774689 -> V=1.0, theta=0.0
% INFO    : Bus 13986	: V=1.02, theta=-41.641445 -> V=1.0, theta=0.0
% INFO    : Bus 13987	: V=1.02, theta=-39.621203 -> V=1.0, theta=0.0
% INFO    : Bus 13988	: V=1.02, theta=-39.23675 -> V=1.0, theta=0.0
% INFO    : Bus 13989	: V=1.02, theta=-42.082379 -> V=1.0, theta=0.0
% INFO    : Bus 13990	: V=1.017503, theta=-45.216486 -> V=1.0, theta=0.0
% INFO    : Bus 13991	: V=1.0166574, theta=-45.279453 -> V=1.0, theta=0.0
% INFO    : Bus 13992	: V=1.0132353, theta=-39.595613 -> V=1.0, theta=0.0
% INFO    : Bus 13993	: V=1.02, theta=-39.677195 -> V=1.0, theta=0.0
% INFO    : Bus 13994	: V=1.0001341, theta=-41.047433 -> V=1.0, theta=0.0
% INFO    : Bus 13995	: V=1.02, theta=-39.861887 -> V=1.0, theta=0.0
% INFO    : Bus 13996	: V=1.02, theta=-37.455672 -> V=1.0, theta=0.0
% INFO    : Bus 13997	: V=1.0180006, theta=-38.047702 -> V=1.0, theta=0.0
% INFO    : Bus 13998	: V=1.02, theta=-40.201394 -> V=1.0, theta=0.0
% INFO    : Bus 13999	: V=1.0168016, theta=-37.535464 -> V=1.0, theta=0.0
% INFO    : Bus 14000	: V=1.0164378, theta=-45.562377 -> V=1.0, theta=0.0
% INFO    : Bus 14001	: V=1.0080281, theta=-40.870616 -> V=1.0, theta=0.0
% INFO    : Bus 14002	: V=1.0199551, theta=-42.542203 -> V=1.0, theta=0.0
% INFO    : Bus 14003	: V=1.01682, theta=-39.708081 -> V=1.0, theta=0.0
% INFO    : Bus 14004	: V=1.019939, theta=-36.522895 -> V=1.0, theta=0.0
% INFO    : Bus 14005	: V=1.02, theta=-42.494423 -> V=1.0, theta=0.0
% INFO    : Bus 14006	: V=0.9745552, theta=-49.276447 -> V=1.0, theta=0.0
% INFO    : Bus 14007	: V=1.0172591, theta=-37.69918 -> V=1.0, theta=0.0
% INFO    : Bus 14008	: V=1.0182011, theta=-41.29112 -> V=1.0, theta=0.0
% INFO    : Bus 14009	: V=1.0092923, theta=-40.791798 -> V=1.0, theta=0.0
% INFO    : Bus 14010	: V=1.02, theta=-38.227721 -> V=1.0, theta=0.0
% INFO    : Bus 14011	: V=1.02, theta=-38.947259 -> V=1.0, theta=0.0
% INFO    : Bus 14012	: V=1.0110517, theta=-43.154414 -> V=1.0, theta=0.0
% INFO    : Bus 14013	: V=0.9847401, theta=-50.775735 -> V=1.0, theta=0.0
% INFO    : Bus 14014	: V=1.02, theta=-43.007467 -> V=1.0, theta=0.0
% INFO    : Bus 14015	: V=0.990239, theta=-42.324919 -> V=1.0, theta=0.0
% INFO    : Bus 14016	: V=1.0178757, theta=-37.575366 -> V=1.0, theta=0.0
% INFO    : Bus 14017	: V=1.0117887, theta=-40.2837 -> V=1.0, theta=0.0
% INFO    : Bus 14018	: V=1.0147703, theta=-44.051389 -> V=1.0, theta=0.0
% INFO    : Bus 14019	: V=1.0167416, theta=-37.54371 -> V=1.0, theta=0.0
% INFO    : Bus 14020	: V=1.02, theta=-37.342943 -> V=1.0, theta=0.0
% INFO    : Bus 14021	: V=1.0198449, theta=-41.125985 -> V=1.0, theta=0.0
% INFO    : Bus 14022	: V=0.9692926, theta=-50.45409 -> V=1.0, theta=0.0
% INFO    : Bus 14023	: V=0.9619132, theta=-54.231162 -> V=1.0, theta=0.0
% INFO    : Bus 14024	: V=0.9986028, theta=-47.475997 -> V=1.0, theta=0.0
% INFO    : Bus 14025	: V=1.0091224, theta=-43.735787 -> V=1.0, theta=0.0
% INFO    : Bus 14026	: V=0.9671418, theta=-49.974526 -> V=1.0, theta=0.0
% INFO    : Bus 14027	: V=0.9981243, theta=-46.715269 -> V=1.0, theta=0.0
% INFO    : Bus 14028	: V=0.9690493, theta=-49.976156 -> V=1.0, theta=0.0
% INFO    : Bus 14029	: V=0.9996645, theta=-43.574302 -> V=1.0, theta=0.0
% INFO    : Bus 14030	: V=0.9994916, theta=-45.349725 -> V=1.0, theta=0.0
% INFO    : Bus 14031	: V=1.0188806, theta=-41.036915 -> V=1.0, theta=0.0
% INFO    : Bus 14032	: V=0.98749, theta=-42.968371 -> V=1.0, theta=0.0
% INFO    : Bus 14033	: V=1.02, theta=-35.101563 -> V=1.0, theta=0.0
% INFO    : Bus 14034	: V=1.02, theta=-37.905535 -> V=1.0, theta=0.0
% INFO    : Bus 14035	: V=1.02, theta=-44.239644 -> V=1.0, theta=0.0
% INFO    : Bus 14036	: V=1.02, theta=-47.315685 -> V=1.0, theta=0.0
% INFO    : Bus 14037	: V=1.02, theta=-42.360582 -> V=1.0, theta=0.0
% INFO    : Bus 14038	: V=1.02, theta=-50.074955 -> V=1.0, theta=0.0
% INFO    : Bus 14039	: V=1.02, theta=-49.779369 -> V=1.0, theta=0.0
% INFO    : Bus 14040	: V=1.02, theta=-44.307096 -> V=1.0, theta=0.0
% INFO    : Bus 14041	: V=1.0189549, theta=-39.798264 -> V=1.0, theta=0.0
% INFO    : Bus 14042	: V=1.02, theta=-41.511704 -> V=1.0, theta=0.0
% INFO    : Bus 14043	: V=1.02, theta=-35.053385 -> V=1.0, theta=0.0
% INFO    : Bus 14044	: V=1.0119694, theta=-42.973287 -> V=1.0, theta=0.0
% INFO    : Bus 14045	: V=1.02, theta=-48.573208 -> V=1.0, theta=0.0
% INFO    : Bus 14046	: V=1.0194241, theta=-48.691317 -> V=1.0, theta=0.0
% INFO    : Bus 14047	: V=1.02, theta=-30.949613 -> V=1.0, theta=0.0
% INFO    : Bus 14048	: V=1.0190005, theta=-49.594793 -> V=1.0, theta=0.0
% INFO    : Bus 14049	: V=1.02, theta=-50.884682 -> V=1.0, theta=0.0
% INFO    : Bus 14050	: V=1.01673, theta=-51.006039 -> V=1.0, theta=0.0
% INFO    : Bus 14051	: V=1.0130932, theta=-49.950827 -> V=1.0, theta=0.0
% INFO    : Bus 14052	: V=1.02, theta=-32.10491 -> V=1.0, theta=0.0
% INFO    : Bus 14053	: V=1.02, theta=-41.852379 -> V=1.0, theta=0.0
% INFO    : Bus 14054	: V=0.9960853, theta=-44.540114 -> V=1.0, theta=0.0
% INFO    : Bus 14055	: V=1.0172844, theta=-44.907164 -> V=1.0, theta=0.0
% INFO    : Bus 14056	: V=1.0194354, theta=-49.585009 -> V=1.0, theta=0.0
% INFO    : Bus 14057	: V=1.0200397, theta=-44.293361 -> V=1.0, theta=0.0
% INFO    : Bus 14058	: V=1.0135824, theta=-42.085698 -> V=1.0, theta=0.0
% INFO    : Bus 14059	: V=1.0061987, theta=-37.818804 -> V=1.0, theta=0.0
% INFO    : Bus 14060	: V=1.0122281, theta=-37.046078 -> V=1.0, theta=0.0
% INFO    : Bus 14061	: V=0.9940106, theta=-54.412684 -> V=1.0, theta=0.0
% INFO    : Bus 14062	: V=1.004351, theta=-53.738337 -> V=1.0, theta=0.0
% INFO    : Bus 14063	: V=1.0063422, theta=-53.465744 -> V=1.0, theta=0.0
% INFO    : Bus 14064	: V=0.9946902, theta=-54.431551 -> V=1.0, theta=0.0
% INFO    : Bus 14065	: V=1.0160126, theta=-52.36302 -> V=1.0, theta=0.0
% INFO    : Bus 14066	: V=1.009137, theta=-53.025784 -> V=1.0, theta=0.0
% INFO    : Bus 14067	: V=1.0128084, theta=-52.837368 -> V=1.0, theta=0.0
% INFO    : Bus 14068	: V=1.0095081, theta=-52.906529 -> V=1.0, theta=0.0
% INFO    : Bus 14069	: V=1.0039313, theta=-53.200671 -> V=1.0, theta=0.0
% INFO    : Bus 14070	: V=1.0147304, theta=-52.067716 -> V=1.0, theta=0.0
% INFO    : Bus 14071	: V=1.0081979, theta=-52.606146 -> V=1.0, theta=0.0
% INFO    : Bus 14072	: V=1.0090877, theta=-52.823882 -> V=1.0, theta=0.0
% INFO    : Bus 14073	: V=1.0191573, theta=-51.850373 -> V=1.0, theta=0.0
% INFO    : Bus 14074	: V=1.0171967, theta=-51.852625 -> V=1.0, theta=0.0
% INFO    : Bus 14075	: V=1.0125414, theta=-52.375374 -> V=1.0, theta=0.0
% INFO    : Bus 14076	: V=1.0145875, theta=-51.857169 -> V=1.0, theta=0.0
% INFO    : Bus 14077	: V=1.0151166, theta=-51.767804 -> V=1.0, theta=0.0
% INFO    : Bus 14078	: V=0.998147, theta=-53.751144 -> V=1.0, theta=0.0
% INFO    : Bus 14079	: V=1.015685, theta=-52.21807 -> V=1.0, theta=0.0
% INFO    : Bus 14080	: V=0.9895245, theta=-53.886805 -> V=1.0, theta=0.0
% INFO    : Bus 14081	: V=0.9925834, theta=-53.304609 -> V=1.0, theta=0.0
% INFO    : Bus 14082	: V=1.0007048, theta=-52.918982 -> V=1.0, theta=0.0
% INFO    : Bus 14083	: V=1.0133454, theta=-51.660192 -> V=1.0, theta=0.0
% INFO    : Bus 14084	: V=1.010373, theta=-51.315539 -> V=1.0, theta=0.0
% INFO    : Bus 14085	: V=1.0031993, theta=-49.766091 -> V=1.0, theta=0.0
% INFO    : Bus 14086	: V=0.9849351, theta=-52.685347 -> V=1.0, theta=0.0
% INFO    : Bus 14087	: V=0.9869711, theta=-50.953512 -> V=1.0, theta=0.0
% INFO    : Bus 14088	: V=0.9817603, theta=-51.700934 -> V=1.0, theta=0.0
% INFO    : Bus 14089	: V=0.9819097, theta=-51.883768 -> V=1.0, theta=0.0
% INFO    : Bus 14090	: V=1.0005274, theta=-53.193627 -> V=1.0, theta=0.0
% INFO    : Bus 14091	: V=1.0108426, theta=-52.967517 -> V=1.0, theta=0.0
% INFO    : Bus 14092	: V=1.0053828, theta=-50.475944 -> V=1.0, theta=0.0
% INFO    : Bus 14093	: V=1.0119981, theta=-56.576022 -> V=1.0, theta=0.0
% INFO    : Bus 14094	: V=1.0124915, theta=-56.508466 -> V=1.0, theta=0.0
% INFO    : Bus 14095	: V=1.0051513, theta=-57.324786 -> V=1.0, theta=0.0
% INFO    : Bus 14096	: V=1.0128627, theta=-56.463478 -> V=1.0, theta=0.0
% INFO    : Bus 14097	: V=1.0070786, theta=-57.261888 -> V=1.0, theta=0.0
% INFO    : Bus 14098	: V=1.0130833, theta=-56.43824 -> V=1.0, theta=0.0
% INFO    : Bus 14099	: V=1.0169784, theta=-56.071947 -> V=1.0, theta=0.0
% INFO    : Bus 14100	: V=1.0037128, theta=-57.398076 -> V=1.0, theta=0.0
% INFO    : Bus 14101	: V=1.0032523, theta=-57.4021 -> V=1.0, theta=0.0
% INFO    : Bus 14102	: V=1.0024006, theta=-57.417434 -> V=1.0, theta=0.0
% INFO    : Bus 14103	: V=1.0101063, theta=-56.648751 -> V=1.0, theta=0.0
% INFO    : Bus 14104	: V=1.0031128, theta=-57.380367 -> V=1.0, theta=0.0
% INFO    : Bus 14105	: V=1.0081848, theta=-56.971842 -> V=1.0, theta=0.0
% INFO    : Bus 14106	: V=1.0120227, theta=-56.444957 -> V=1.0, theta=0.0
% INFO    : Bus 14107	: V=1.0078063, theta=-56.99033 -> V=1.0, theta=0.0
% INFO    : Bus 14108	: V=1.004305, theta=-57.299038 -> V=1.0, theta=0.0
% INFO    : Bus 14109	: V=1.0033171, theta=-57.350968 -> V=1.0, theta=0.0
% INFO    : Bus 14110	: V=1.0020762, theta=-57.426297 -> V=1.0, theta=0.0
% INFO    : Bus 14111	: V=1.0043194, theta=-57.289153 -> V=1.0, theta=0.0
% INFO    : Bus 14112	: V=1.005343, theta=-57.228298 -> V=1.0, theta=0.0
% INFO    : Bus 14113	: V=1.0067897, theta=-57.051975 -> V=1.0, theta=0.0
% INFO    : Bus 14114	: V=1.0188024, theta=-55.873569 -> V=1.0, theta=0.0
% INFO    : Bus 14115	: V=1.0132509, theta=-56.391406 -> V=1.0, theta=0.0
% INFO    : Bus 14116	: V=1.0140587, theta=-56.361063 -> V=1.0, theta=0.0
% INFO    : Bus 14117	: V=0.9938225, theta=-58.615903 -> V=1.0, theta=0.0
% INFO    : Bus 14118	: V=0.99543, theta=-58.524426 -> V=1.0, theta=0.0
% INFO    : Bus 14119	: V=0.9944542, theta=-58.5494 -> V=1.0, theta=0.0
% INFO    : Bus 14120	: V=0.9947514, theta=-58.545657 -> V=1.0, theta=0.0
% INFO    : Bus 14121	: V=0.9987973, theta=-58.270502 -> V=1.0, theta=0.0
% INFO    : Bus 14122	: V=1.0102146, theta=-57.060898 -> V=1.0, theta=0.0
% INFO    : Bus 14123	: V=1.0179638, theta=-56.141602 -> V=1.0, theta=0.0
% INFO    : Bus 14124	: V=1.0115738, theta=-56.645664 -> V=1.0, theta=0.0
% INFO    : Bus 14125	: V=1.0016573, theta=-57.948426 -> V=1.0, theta=0.0
% INFO    : Bus 14126	: V=1.0088481, theta=-57.360736 -> V=1.0, theta=0.0
% INFO    : Bus 14127	: V=0.9963991, theta=-58.473431 -> V=1.0, theta=0.0
% INFO    : Bus 14128	: V=0.9948908, theta=-58.398551 -> V=1.0, theta=0.0
% INFO    : Bus 14129	: V=0.9940963, theta=-58.499511 -> V=1.0, theta=0.0
% INFO    : Bus 14130	: V=0.9939276, theta=-58.602461 -> V=1.0, theta=0.0
% INFO    : Bus 14131	: V=0.9948347, theta=-58.564538 -> V=1.0, theta=0.0
% INFO    : Bus 14132	: V=0.9943631, theta=-58.518023 -> V=1.0, theta=0.0
% INFO    : Bus 14133	: V=0.9948624, theta=-58.525579 -> V=1.0, theta=0.0
% INFO    : Bus 14134	: V=1.0074186, theta=-57.781766 -> V=1.0, theta=0.0
% INFO    : Bus 14135	: V=0.995038, theta=-58.529867 -> V=1.0, theta=0.0
% INFO    : Bus 14136	: V=0.9966579, theta=-58.236207 -> V=1.0, theta=0.0
% INFO    : Bus 14137	: V=0.9985427, theta=-58.039697 -> V=1.0, theta=0.0
% INFO    : Bus 14138	: V=1.0090192, theta=-56.529633 -> V=1.0, theta=0.0
% INFO    : Bus 14139	: V=0.9775586, theta=-59.316834 -> V=1.0, theta=0.0
% INFO    : Bus 14140	: V=0.9985904, theta=-57.48599 -> V=1.0, theta=0.0
% INFO    : Bus 14141	: V=0.9965582, theta=-57.789419 -> V=1.0, theta=0.0
% INFO    : Bus 14142	: V=0.9975292, theta=-57.72868 -> V=1.0, theta=0.0
% INFO    : Bus 14143	: V=1.0074023, theta=-56.675964 -> V=1.0, theta=0.0
% INFO    : Bus 14144	: V=1.0001907, theta=-57.584904 -> V=1.0, theta=0.0
% INFO    : Bus 14145	: V=0.9957816, theta=-57.760262 -> V=1.0, theta=0.0
% INFO    : Bus 14146	: V=1.0089928, theta=-56.596781 -> V=1.0, theta=0.0
% INFO    : Bus 14147	: V=1.0070245, theta=-56.691046 -> V=1.0, theta=0.0
% INFO    : Bus 14148	: V=1.0047689, theta=-56.768094 -> V=1.0, theta=0.0
% INFO    : Bus 14149	: V=1.0177236, theta=-55.693618 -> V=1.0, theta=0.0
% INFO    : Bus 14150	: V=1.0038408, theta=-56.83774 -> V=1.0, theta=0.0
% INFO    : Bus 14151	: V=1.0030866, theta=-56.888356 -> V=1.0, theta=0.0
% INFO    : Bus 14152	: V=0.992174, theta=-58.077535 -> V=1.0, theta=0.0
% INFO    : Bus 14153	: V=1.0024952, theta=-56.917101 -> V=1.0, theta=0.0
% INFO    : Bus 14154	: V=0.991146, theta=-58.089704 -> V=1.0, theta=0.0
% INFO    : Bus 14155	: V=0.976981, theta=-59.121587 -> V=1.0, theta=0.0
% INFO    : Bus 14156	: V=0.9793971, theta=-58.825195 -> V=1.0, theta=0.0
% INFO    : Bus 14157	: V=0.9780019, theta=-58.830056 -> V=1.0, theta=0.0
% INFO    : Bus 14158	: V=0.9777461, theta=-58.805628 -> V=1.0, theta=0.0
% INFO    : Bus 14159	: V=0.9826467, theta=-58.329043 -> V=1.0, theta=0.0
% INFO    : Bus 14160	: V=0.9791349, theta=-58.679034 -> V=1.0, theta=0.0
% INFO    : Bus 14161	: V=0.9840092, theta=-58.279628 -> V=1.0, theta=0.0
% INFO    : Bus 14162	: V=0.9785701, theta=-58.638576 -> V=1.0, theta=0.0
% INFO    : Bus 14163	: V=0.9785079, theta=-58.707479 -> V=1.0, theta=0.0
% INFO    : Bus 14164	: V=0.9800959, theta=-58.693772 -> V=1.0, theta=0.0
% INFO    : Bus 14165	: V=0.9837514, theta=-58.534024 -> V=1.0, theta=0.0
% INFO    : Bus 14166	: V=0.9887748, theta=-58.084857 -> V=1.0, theta=0.0
% INFO    : Bus 14167	: V=0.9846545, theta=-58.270585 -> V=1.0, theta=0.0
% INFO    : Bus 14168	: V=0.9810031, theta=-58.435095 -> V=1.0, theta=0.0
% INFO    : Bus 14169	: V=0.996412, theta=-57.134716 -> V=1.0, theta=0.0
% INFO    : Bus 14170	: V=0.9805121, theta=-58.267589 -> V=1.0, theta=0.0
% INFO    : Bus 14171	: V=0.9812428, theta=-57.977678 -> V=1.0, theta=0.0
% INFO    : Bus 14172	: V=0.98194, theta=-57.956705 -> V=1.0, theta=0.0
% INFO    : Bus 14173	: V=0.9935876, theta=-57.304131 -> V=1.0, theta=0.0
% INFO    : Bus 14174	: V=0.9794474, theta=-58.426344 -> V=1.0, theta=0.0
% INFO    : Bus 14175	: V=0.9793768, theta=-58.477286 -> V=1.0, theta=0.0
% INFO    : Bus 14176	: V=0.9798124, theta=-58.564219 -> V=1.0, theta=0.0
% INFO    : Bus 14177	: V=0.9787329, theta=-58.311787 -> V=1.0, theta=0.0
% INFO    : Bus 14178	: V=0.9805706, theta=-58.426195 -> V=1.0, theta=0.0
% INFO    : Bus 14179	: V=0.991698, theta=-57.464628 -> V=1.0, theta=0.0
% INFO    : Bus 14180	: V=0.9794746, theta=-58.499392 -> V=1.0, theta=0.0
% INFO    : Bus 14181	: V=0.9893001, theta=-56.916381 -> V=1.0, theta=0.0
% INFO    : Bus 14182	: V=0.9769942, theta=-58.317972 -> V=1.0, theta=0.0
% INFO    : Bus 14183	: V=0.9789141, theta=-58.37574 -> V=1.0, theta=0.0
% INFO    : Bus 14184	: V=0.9787935, theta=-58.315538 -> V=1.0, theta=0.0
% INFO    : Bus 14185	: V=0.979365, theta=-58.166326 -> V=1.0, theta=0.0
% INFO    : Bus 14186	: V=0.979403, theta=-58.209119 -> V=1.0, theta=0.0
% INFO    : Bus 14187	: V=0.9870176, theta=-56.896986 -> V=1.0, theta=0.0
% INFO    : Bus 14188	: V=0.989495, theta=-57.028489 -> V=1.0, theta=0.0
% INFO    : Bus 14189	: V=0.9797852, theta=-58.079706 -> V=1.0, theta=0.0
% INFO    : Bus 14190	: V=0.9881516, theta=-56.843366 -> V=1.0, theta=0.0
% INFO    : Bus 14191	: V=0.9810528, theta=-57.536965 -> V=1.0, theta=0.0
% INFO    : Bus 14192	: V=0.9824257, theta=-57.716296 -> V=1.0, theta=0.0
% INFO    : Bus 14193	: V=0.9876559, theta=-57.345428 -> V=1.0, theta=0.0
% INFO    : Bus 14194	: V=0.9826992, theta=-57.736819 -> V=1.0, theta=0.0
% INFO    : Bus 14195	: V=0.984593, theta=-57.540144 -> V=1.0, theta=0.0
% INFO    : Bus 14196	: V=0.9889705, theta=-57.283215 -> V=1.0, theta=0.0
% INFO    : Bus 14197	: V=0.9894996, theta=-57.323319 -> V=1.0, theta=0.0
% INFO    : Bus 14198	: V=1.0048665, theta=-56.644747 -> V=1.0, theta=0.0
% INFO    : Bus 14199	: V=0.9992171, theta=-56.547347 -> V=1.0, theta=0.0
% INFO    : Bus 14200	: V=1.0067911, theta=-56.579933 -> V=1.0, theta=0.0
% INFO    : Bus 14201	: V=1.0053482, theta=-56.541601 -> V=1.0, theta=0.0
% INFO    : Bus 14202	: V=1.0173827, theta=-55.350095 -> V=1.0, theta=0.0
% INFO    : Bus 14203	: V=1.0060078, theta=-56.563457 -> V=1.0, theta=0.0
% INFO    : Bus 14204	: V=1.0021793, theta=-56.557481 -> V=1.0, theta=0.0
% INFO    : Bus 14205	: V=0.9885627, theta=-57.732958 -> V=1.0, theta=0.0
% INFO    : Bus 14206	: V=1.0001134, theta=-56.56099 -> V=1.0, theta=0.0
% INFO    : Bus 14207	: V=0.9870674, theta=-57.754464 -> V=1.0, theta=0.0
% INFO    : Bus 14208	: V=0.9979243, theta=-56.484809 -> V=1.0, theta=0.0
% INFO    : Bus 14209	: V=0.9894635, theta=-56.608784 -> V=1.0, theta=0.0
% INFO    : Bus 14210	: V=0.9921967, theta=-56.274188 -> V=1.0, theta=0.0
% INFO    : Bus 14211	: V=0.9964025, theta=-56.343629 -> V=1.0, theta=0.0
% INFO    : Bus 14212	: V=0.9859648, theta=-57.030728 -> V=1.0, theta=0.0
% INFO    : Bus 14213	: V=0.9872972, theta=-55.680375 -> V=1.0, theta=0.0
% INFO    : Bus 14214	: V=0.9837992, theta=-55.964372 -> V=1.0, theta=0.0
% INFO    : Bus 14215	: V=0.9882557, theta=-55.453999 -> V=1.0, theta=0.0
% INFO    : Bus 14216	: V=0.9898141, theta=-55.237963 -> V=1.0, theta=0.0
% INFO    : Bus 14217	: V=0.9810939, theta=-56.728821 -> V=1.0, theta=0.0
% INFO    : Bus 14218	: V=0.9958339, theta=-54.606769 -> V=1.0, theta=0.0
% INFO    : Bus 14219	: V=0.9784414, theta=-56.583665 -> V=1.0, theta=0.0
% INFO    : Bus 14220	: V=1.0006995, theta=-54.107153 -> V=1.0, theta=0.0
% INFO    : Bus 14221	: V=0.982678, theta=-55.914329 -> V=1.0, theta=0.0
% INFO    : Bus 14222	: V=1.0130404, theta=-56.430165 -> V=1.0, theta=0.0
% INFO    : Bus 14223	: V=0.9959811, theta=-49.761296 -> V=1.0, theta=0.0
% INFO    : Bus 14224	: V=0.9975119, theta=-48.795292 -> V=1.0, theta=0.0
% INFO    : Bus 14225	: V=1.0023387, theta=-49.306117 -> V=1.0, theta=0.0
% INFO    : Bus 14226	: V=1.0022828, theta=-48.566183 -> V=1.0, theta=0.0
% INFO    : Bus 14227	: V=1.0042086, theta=-47.269886 -> V=1.0, theta=0.0
% INFO    : Bus 14228	: V=0.9852654, theta=-51.173927 -> V=1.0, theta=0.0
% INFO    : Bus 14229	: V=0.9867613, theta=-47.661493 -> V=1.0, theta=0.0
% INFO    : Bus 14230	: V=1.0032669, theta=-48.994693 -> V=1.0, theta=0.0
% INFO    : Bus 14231	: V=1.0061435, theta=-49.000985 -> V=1.0, theta=0.0
% INFO    : Bus 14232	: V=1.0011047, theta=-48.887034 -> V=1.0, theta=0.0
% INFO    : Bus 14233	: V=1.0012899, theta=-48.771822 -> V=1.0, theta=0.0
% INFO    : Bus 14234	: V=0.9900989, theta=-49.448379 -> V=1.0, theta=0.0
% INFO    : Bus 14235	: V=0.9844448, theta=-49.692961 -> V=1.0, theta=0.0
% INFO    : Bus 14236	: V=0.9935776, theta=-48.337389 -> V=1.0, theta=0.0
% INFO    : Bus 14237	: V=1.00669, theta=-46.052232 -> V=1.0, theta=0.0
% INFO    : Bus 14238	: V=1.0093089, theta=-45.400781 -> V=1.0, theta=0.0
% INFO    : Bus 14239	: V=0.9974272, theta=-46.178735 -> V=1.0, theta=0.0
% INFO    : Bus 14240	: V=1.0129103, theta=-43.971505 -> V=1.0, theta=0.0
% INFO    : Bus 14241	: V=1.0141711, theta=-44.50474 -> V=1.0, theta=0.0
% INFO    : Bus 14242	: V=1.01506, theta=-44.14791 -> V=1.0, theta=0.0
% INFO    : Bus 14243	: V=1.0035959, theta=-45.325335 -> V=1.0, theta=0.0
% INFO    : Bus 14244	: V=1.0135349, theta=-43.885235 -> V=1.0, theta=0.0
% INFO    : Bus 14245	: V=1.0016447, theta=-45.391337 -> V=1.0, theta=0.0
% INFO    : Bus 14246	: V=0.9988742, theta=-47.097518 -> V=1.0, theta=0.0
% INFO    : Bus 14247	: V=1.0090026, theta=-45.143574 -> V=1.0, theta=0.0
% INFO    : Bus 14248	: V=1.0064703, theta=-45.440253 -> V=1.0, theta=0.0
% INFO    : Bus 14249	: V=0.996871, theta=-46.918889 -> V=1.0, theta=0.0
% INFO    : Bus 14250	: V=1.0086633, theta=-44.04652 -> V=1.0, theta=0.0
% INFO    : Bus 14251	: V=0.9918165, theta=-46.056253 -> V=1.0, theta=0.0
% INFO    : Bus 14252	: V=0.9868626, theta=-46.169597 -> V=1.0, theta=0.0
% INFO    : Bus 14253	: V=0.999475, theta=-45.886206 -> V=1.0, theta=0.0
% INFO    : Bus 14254	: V=0.9987114, theta=-45.822079 -> V=1.0, theta=0.0
% INFO    : Bus 14255	: V=0.9944305, theta=-45.993729 -> V=1.0, theta=0.0
% INFO    : Bus 14256	: V=0.9923133, theta=-46.015183 -> V=1.0, theta=0.0
% INFO    : Bus 14257	: V=0.9918784, theta=-46.021888 -> V=1.0, theta=0.0
% INFO    : Bus 14258	: V=0.9985189, theta=-45.434666 -> V=1.0, theta=0.0
% INFO    : Bus 14259	: V=0.9973861, theta=-45.45168 -> V=1.0, theta=0.0
% INFO    : Bus 14260	: V=0.9939624, theta=-45.633358 -> V=1.0, theta=0.0
% INFO    : Bus 14261	: V=0.9943934, theta=-45.628376 -> V=1.0, theta=0.0
% INFO    : Bus 14262	: V=0.9935279, theta=-45.653773 -> V=1.0, theta=0.0
% INFO    : Bus 14263	: V=0.991992, theta=-45.717473 -> V=1.0, theta=0.0
% INFO    : Bus 14264	: V=1.011691, theta=-43.947579 -> V=1.0, theta=0.0
% INFO    : Bus 14265	: V=1.000416, theta=-45.401088 -> V=1.0, theta=0.0
% INFO    : Bus 14266	: V=1.0073564, theta=-44.231596 -> V=1.0, theta=0.0
% INFO    : Bus 14267	: V=0.9907945, theta=-45.795111 -> V=1.0, theta=0.0
% INFO    : Bus 14268	: V=0.9925397, theta=-45.698797 -> V=1.0, theta=0.0
% INFO    : Bus 14269	: V=1.0030212, theta=-44.932603 -> V=1.0, theta=0.0
% INFO    : Bus 14270	: V=1.0083043, theta=-44.710328 -> V=1.0, theta=0.0
% INFO    : Bus 14271	: V=0.9891211, theta=-46.627037 -> V=1.0, theta=0.0
% INFO    : Bus 14272	: V=1.0013134, theta=-44.969702 -> V=1.0, theta=0.0
% INFO    : Bus 14273	: V=1.0071228, theta=-48.793377 -> V=1.0, theta=0.0
% INFO    : Bus 14274	: V=0.9953754, theta=-48.062707 -> V=1.0, theta=0.0
% INFO    : Bus 14275	: V=0.9912232, theta=-48.702008 -> V=1.0, theta=0.0
% INFO    : Bus 14276	: V=0.9563727, theta=-55.348308 -> V=1.0, theta=0.0
% INFO    : Bus 14277	: V=0.9548116, theta=-55.477609 -> V=1.0, theta=0.0
% INFO    : Bus 14278	: V=0.95532, theta=-55.434246 -> V=1.0, theta=0.0
% INFO    : Bus 14279	: V=0.9543304, theta=-55.524702 -> V=1.0, theta=0.0
% INFO    : Bus 14280	: V=0.9499993, theta=-56.063601 -> V=1.0, theta=0.0
% INFO    : Bus 14281	: V=0.9511047, theta=-56.037728 -> V=1.0, theta=0.0
% INFO    : Bus 14282	: V=0.9504837, theta=-56.049026 -> V=1.0, theta=0.0
% INFO    : Bus 14283	: V=0.9480143, theta=-56.903898 -> V=1.0, theta=0.0
% INFO    : Bus 14284	: V=0.9488465, theta=-56.736389 -> V=1.0, theta=0.0
% INFO    : Bus 14285	: V=0.9540003, theta=-55.556636 -> V=1.0, theta=0.0
% INFO    : Bus 14286	: V=0.947742, theta=-56.712297 -> V=1.0, theta=0.0
% INFO    : Bus 14287	: V=0.9506046, theta=-56.348474 -> V=1.0, theta=0.0
% INFO    : Bus 14288	: V=0.9547244, theta=-55.727075 -> V=1.0, theta=0.0
% INFO    : Bus 14289	: V=0.9546469, theta=-55.641292 -> V=1.0, theta=0.0
% INFO    : Bus 14290	: V=0.9551623, theta=-55.80409 -> V=1.0, theta=0.0
% INFO    : Bus 14291	: V=0.9479743, theta=-56.901368 -> V=1.0, theta=0.0
% INFO    : Bus 14292	: V=0.955895, theta=-55.838523 -> V=1.0, theta=0.0
% INFO    : Bus 14293	: V=0.9478637, theta=-56.947164 -> V=1.0, theta=0.0
% INFO    : Bus 14294	: V=0.9479071, theta=-56.952853 -> V=1.0, theta=0.0
% INFO    : Bus 14295	: V=0.956809, theta=-55.328131 -> V=1.0, theta=0.0
% INFO    : Bus 14296	: V=0.9480912, theta=-56.921921 -> V=1.0, theta=0.0
% INFO    : Bus 14297	: V=0.948272, theta=-56.933814 -> V=1.0, theta=0.0
% INFO    : Bus 14298	: V=0.9502718, theta=-56.819642 -> V=1.0, theta=0.0
% INFO    : Bus 14299	: V=0.9544948, theta=-56.549436 -> V=1.0, theta=0.0
% INFO    : Bus 14300	: V=0.9464802, theta=-57.079519 -> V=1.0, theta=0.0
% INFO    : Bus 14301	: V=0.9492562, theta=-56.888016 -> V=1.0, theta=0.0
% INFO    : Bus 14302	: V=0.9483573, theta=-56.917307 -> V=1.0, theta=0.0
% INFO    : Bus 14303	: V=0.9580849, theta=-55.72812 -> V=1.0, theta=0.0
% INFO    : Bus 14304	: V=0.9481351, theta=-56.978504 -> V=1.0, theta=0.0
% INFO    : Bus 14305	: V=0.9480296, theta=-56.935162 -> V=1.0, theta=0.0
% INFO    : Bus 14306	: V=0.947851, theta=-56.858305 -> V=1.0, theta=0.0
% INFO    : Bus 14307	: V=0.9480229, theta=-56.818073 -> V=1.0, theta=0.0
% INFO    : Bus 14308	: V=0.9577279, theta=-55.666514 -> V=1.0, theta=0.0
% INFO    : Bus 14309	: V=0.949709, theta=-56.631937 -> V=1.0, theta=0.0
% INFO    : Bus 14310	: V=0.952002, theta=-56.381789 -> V=1.0, theta=0.0
% INFO    : Bus 14311	: V=0.9506751, theta=-56.425769 -> V=1.0, theta=0.0
% INFO    : Bus 14312	: V=0.9587322, theta=-55.361826 -> V=1.0, theta=0.0
% INFO    : Bus 14313	: V=0.9502874, theta=-56.451346 -> V=1.0, theta=0.0
% INFO    : Bus 14314	: V=0.9496637, theta=-56.346156 -> V=1.0, theta=0.0
% INFO    : Bus 14315	: V=0.9501835, theta=-56.328186 -> V=1.0, theta=0.0
% INFO    : Bus 14316	: V=0.9480705, theta=-56.882275 -> V=1.0, theta=0.0
% INFO    : Bus 14317	: V=0.9506778, theta=-56.166468 -> V=1.0, theta=0.0
% INFO    : Bus 14318	: V=0.9509022, theta=-56.129249 -> V=1.0, theta=0.0
% INFO    : Bus 14319	: V=0.9505147, theta=-56.217185 -> V=1.0, theta=0.0
% INFO    : Bus 14320	: V=0.9512956, theta=-56.101264 -> V=1.0, theta=0.0
% INFO    : Bus 14321	: V=0.9503357, theta=-56.290344 -> V=1.0, theta=0.0
% INFO    : Bus 14322	: V=0.9509084, theta=-56.10534 -> V=1.0, theta=0.0
% INFO    : Bus 14323	: V=0.9576013, theta=-55.482819 -> V=1.0, theta=0.0
% INFO    : Bus 14324	: V=0.9501437, theta=-56.258615 -> V=1.0, theta=0.0
% INFO    : Bus 14325	: V=0.9562321, theta=-55.599035 -> V=1.0, theta=0.0
% INFO    : Bus 14326	: V=0.967225, theta=-54.464275 -> V=1.0, theta=0.0
% INFO    : Bus 14327	: V=0.9552039, theta=-55.697511 -> V=1.0, theta=0.0
% INFO    : Bus 14328	: V=0.9579499, theta=-55.389947 -> V=1.0, theta=0.0
% INFO    : Bus 14329	: V=0.9537108, theta=-55.839704 -> V=1.0, theta=0.0
% INFO    : Bus 14330	: V=0.953172, theta=-55.870038 -> V=1.0, theta=0.0
% INFO    : Bus 14331	: V=0.9527497, theta=-55.903529 -> V=1.0, theta=0.0
% INFO    : Bus 14332	: V=0.9582684, theta=-55.178915 -> V=1.0, theta=0.0
% INFO    : Bus 14333	: V=0.9585352, theta=-55.160011 -> V=1.0, theta=0.0
% INFO    : Bus 14334	: V=0.9588427, theta=-55.137953 -> V=1.0, theta=0.0
% INFO    : Bus 14335	: V=0.9539424, theta=-55.782058 -> V=1.0, theta=0.0
% INFO    : Bus 14336	: V=0.9526919, theta=-55.900226 -> V=1.0, theta=0.0
% INFO    : Bus 14337	: V=0.9593299, theta=-55.092378 -> V=1.0, theta=0.0
% INFO    : Bus 14338	: V=0.9529128, theta=-55.87939 -> V=1.0, theta=0.0
% INFO    : Bus 14339	: V=0.9583003, theta=-55.314245 -> V=1.0, theta=0.0
% INFO    : Bus 14340	: V=0.9610299, theta=-55.146418 -> V=1.0, theta=0.0
% INFO    : Bus 14341	: V=0.9560667, theta=-55.426564 -> V=1.0, theta=0.0
% INFO    : Bus 14342	: V=0.9635989, theta=-54.478276 -> V=1.0, theta=0.0
% INFO    : Bus 14343	: V=0.9673089, theta=-54.415868 -> V=1.0, theta=0.0
% INFO    : Bus 14344	: V=0.9565588, theta=-55.407753 -> V=1.0, theta=0.0
% INFO    : Bus 14345	: V=0.9628155, theta=-54.831101 -> V=1.0, theta=0.0
% INFO    : Bus 14346	: V=0.9570591, theta=-55.387223 -> V=1.0, theta=0.0
% INFO    : Bus 14347	: V=0.9616747, theta=-54.914278 -> V=1.0, theta=0.0
% INFO    : Bus 14348	: V=0.9578305, theta=-55.344903 -> V=1.0, theta=0.0
% INFO    : Bus 14349	: V=0.9606693, theta=-54.986193 -> V=1.0, theta=0.0
% INFO    : Bus 14350	: V=0.9597745, theta=-55.050989 -> V=1.0, theta=0.0
% INFO    : Bus 14351	: V=0.9674754, theta=-54.312163 -> V=1.0, theta=0.0
% INFO    : Bus 14352	: V=0.9541847, theta=-55.645386 -> V=1.0, theta=0.0
% INFO    : Bus 14353	: V=0.9845892, theta=-52.314926 -> V=1.0, theta=0.0
% INFO    : Bus 14354	: V=0.9555334, theta=-55.452439 -> V=1.0, theta=0.0
% INFO    : Bus 14355	: V=0.9581258, theta=-54.984735 -> V=1.0, theta=0.0
% INFO    : Bus 14356	: V=0.9515046, theta=-55.49755 -> V=1.0, theta=0.0
% INFO    : Bus 14357	: V=0.952517, theta=-55.536786 -> V=1.0, theta=0.0
% INFO    : Bus 14358	: V=0.9530498, theta=-55.558063 -> V=1.0, theta=0.0
% INFO    : Bus 14359	: V=0.9589518, theta=-54.808396 -> V=1.0, theta=0.0
% INFO    : Bus 14360	: V=0.951895, theta=-55.753602 -> V=1.0, theta=0.0
% INFO    : Bus 14361	: V=0.9514894, theta=-55.772983 -> V=1.0, theta=0.0
% INFO    : Bus 14362	: V=0.9587208, theta=-54.830802 -> V=1.0, theta=0.0
% INFO    : Bus 14363	: V=0.9592627, theta=-54.765257 -> V=1.0, theta=0.0
% INFO    : Bus 14364	: V=0.9525085, theta=-55.486957 -> V=1.0, theta=0.0
% INFO    : Bus 14365	: V=0.9595539, theta=-54.726144 -> V=1.0, theta=0.0
% INFO    : Bus 14366	: V=0.9511219, theta=-55.545774 -> V=1.0, theta=0.0
% INFO    : Bus 14367	: V=0.959358, theta=-54.462982 -> V=1.0, theta=0.0
% INFO    : Bus 14368	: V=0.9608899, theta=-54.346308 -> V=1.0, theta=0.0
% INFO    : Bus 14369	: V=0.95509, theta=-55.019622 -> V=1.0, theta=0.0
% INFO    : Bus 14370	: V=0.9562502, theta=-54.990614 -> V=1.0, theta=0.0
% INFO    : Bus 14371	: V=0.9602706, theta=-54.45062 -> V=1.0, theta=0.0
% INFO    : Bus 14372	: V=0.9558781, theta=-54.996063 -> V=1.0, theta=0.0
% INFO    : Bus 14373	: V=0.9598832, theta=-54.522005 -> V=1.0, theta=0.0
% INFO    : Bus 14374	: V=0.956172, theta=-55.00994 -> V=1.0, theta=0.0
% INFO    : Bus 14375	: V=0.9563554, theta=-54.978789 -> V=1.0, theta=0.0
% INFO    : Bus 14376	: V=0.9561864, theta=-55.021554 -> V=1.0, theta=0.0
% INFO    : Bus 14377	: V=0.9597071, theta=-54.572953 -> V=1.0, theta=0.0
% INFO    : Bus 14378	: V=0.9559412, theta=-55.007511 -> V=1.0, theta=0.0
% INFO    : Bus 14379	: V=0.9595911, theta=-54.635936 -> V=1.0, theta=0.0
% INFO    : Bus 14380	: V=0.9604959, theta=-54.482546 -> V=1.0, theta=0.0
% INFO    : Bus 14381	: V=0.959826, theta=-54.605264 -> V=1.0, theta=0.0
% INFO    : Bus 14382	: V=0.955907, theta=-55.012039 -> V=1.0, theta=0.0
% INFO    : Bus 14383	: V=0.9505756, theta=-55.716888 -> V=1.0, theta=0.0
% INFO    : Bus 14384	: V=0.9600816, theta=-54.660673 -> V=1.0, theta=0.0
% INFO    : Bus 14385	: V=0.9510757, theta=-55.76522 -> V=1.0, theta=0.0
% INFO    : Bus 14386	: V=0.9591444, theta=-54.726173 -> V=1.0, theta=0.0
% INFO    : Bus 14387	: V=0.9585385, theta=-54.905111 -> V=1.0, theta=0.0
% INFO    : Bus 14388	: V=0.9506913, theta=-55.752857 -> V=1.0, theta=0.0
% INFO    : Bus 14389	: V=0.9504514, theta=-55.774305 -> V=1.0, theta=0.0
% INFO    : Bus 14390	: V=0.9487079, theta=-55.781412 -> V=1.0, theta=0.0
% INFO    : Bus 14391	: V=0.9490768, theta=-55.777492 -> V=1.0, theta=0.0
% INFO    : Bus 14392	: V=0.950449, theta=-55.769635 -> V=1.0, theta=0.0
% INFO    : Bus 14393	: V=0.958502, theta=-54.895085 -> V=1.0, theta=0.0
% INFO    : Bus 14394	: V=0.9524988, theta=-55.716069 -> V=1.0, theta=0.0
% INFO    : Bus 14395	: V=0.952586, theta=-55.735337 -> V=1.0, theta=0.0
% INFO    : Bus 14396	: V=0.9585854, theta=-54.865373 -> V=1.0, theta=0.0
% INFO    : Bus 14397	: V=0.9530266, theta=-55.674379 -> V=1.0, theta=0.0
% INFO    : Bus 14398	: V=0.9535167, theta=-55.584445 -> V=1.0, theta=0.0
% INFO    : Bus 14399	: V=0.9532209, theta=-55.636995 -> V=1.0, theta=0.0
% INFO    : Bus 14400	: V=0.9573677, theta=-55.199179 -> V=1.0, theta=0.0
% INFO    : Bus 14401	: V=0.9574927, theta=-55.191628 -> V=1.0, theta=0.0
% INFO    : Bus 14402	: V=0.9576218, theta=-55.183337 -> V=1.0, theta=0.0
% INFO    : Bus 14403	: V=0.9599988, theta=-55.141499 -> V=1.0, theta=0.0
% INFO    : Bus 14404	: V=0.9595763, theta=-55.172607 -> V=1.0, theta=0.0
% INFO    : Bus 14405	: V=0.9578479, theta=-55.168893 -> V=1.0, theta=0.0
% INFO    : Bus 14406	: V=0.9588085, theta=-55.150506 -> V=1.0, theta=0.0
% INFO    : Bus 14407	: V=0.9584318, theta=-55.136832 -> V=1.0, theta=0.0
% INFO    : Bus 14408	: V=0.9525763, theta=-55.718026 -> V=1.0, theta=0.0
% INFO    : Bus 14409	: V=0.9584901, theta=-54.922143 -> V=1.0, theta=0.0
% INFO    : Bus 14410	: V=0.9554529, theta=-55.987959 -> V=1.0, theta=0.0
% INFO    : Bus 14411	: V=0.9526872, theta=-55.907925 -> V=1.0, theta=0.0
% INFO    : Bus 14412	: V=0.9511143, theta=-56.325166 -> V=1.0, theta=0.0
% INFO    : Bus 14413	: V=0.9552181, theta=-55.806812 -> V=1.0, theta=0.0
% INFO    : Bus 14414	: V=0.9551333, theta=-55.812869 -> V=1.0, theta=0.0
% INFO    : Bus 14415	: V=0.9555805, theta=-55.896616 -> V=1.0, theta=0.0
% INFO    : Bus 14416	: V=0.9551144, theta=-55.814423 -> V=1.0, theta=0.0
% INFO    : Bus 14417	: V=0.9684505, theta=-54.582127 -> V=1.0, theta=0.0
% INFO    : Bus 14418	: V=0.9588119, theta=-55.47534 -> V=1.0, theta=0.0
% INFO    : Bus 14419	: V=0.9596015, theta=-55.531984 -> V=1.0, theta=0.0
% INFO    : Bus 14420	: V=0.9591171, theta=-55.485237 -> V=1.0, theta=0.0
% INFO    : Bus 14421	: V=0.9530004, theta=-56.414739 -> V=1.0, theta=0.0
% INFO    : Bus 14422	: V=0.9585558, theta=-55.618253 -> V=1.0, theta=0.0
% INFO    : Bus 14423	: V=0.9586175, theta=-55.609816 -> V=1.0, theta=0.0
% INFO    : Bus 14424	: V=0.9588202, theta=-55.592837 -> V=1.0, theta=0.0
% INFO    : Bus 14425	: V=0.9512193, theta=-55.778593 -> V=1.0, theta=0.0
% INFO    : Bus 14426	: V=0.9507043, theta=-55.792074 -> V=1.0, theta=0.0
% INFO    : Bus 14427	: V=0.9509726, theta=-55.711845 -> V=1.0, theta=0.0
% INFO    : Bus 14428	: V=0.9507214, theta=-55.787378 -> V=1.0, theta=0.0
% INFO    : Bus 14429	: V=0.9615577, theta=-54.240499 -> V=1.0, theta=0.0
% INFO    : Bus 14430	: V=0.9619986, theta=-54.171514 -> V=1.0, theta=0.0
% INFO    : Bus 14431	: V=0.9622672, theta=-54.130866 -> V=1.0, theta=0.0
% INFO    : Bus 14432	: V=0.9609676, theta=-54.280179 -> V=1.0, theta=0.0
% INFO    : Bus 14433	: V=0.9561481, theta=-54.916543 -> V=1.0, theta=0.0
% INFO    : Bus 14434	: V=0.957452, theta=-54.795292 -> V=1.0, theta=0.0
% INFO    : Bus 14435	: V=0.9623212, theta=-54.106337 -> V=1.0, theta=0.0
% INFO    : Bus 14436	: V=0.9626378, theta=-54.079119 -> V=1.0, theta=0.0
% INFO    : Bus 14437	: V=0.9505693, theta=-55.755638 -> V=1.0, theta=0.0
% INFO    : Bus 14438	: V=0.9533666, theta=-55.420504 -> V=1.0, theta=0.0
% INFO    : Bus 14439	: V=0.9492913, theta=-55.768673 -> V=1.0, theta=0.0
% INFO    : Bus 14440	: V=0.9500414, theta=-55.72456 -> V=1.0, theta=0.0
% INFO    : Bus 14441	: V=0.9495572, theta=-55.756607 -> V=1.0, theta=0.0
% INFO    : Bus 14442	: V=0.9591828, theta=-54.801154 -> V=1.0, theta=0.0
% INFO    : Bus 14443	: V=0.9596461, theta=-54.727447 -> V=1.0, theta=0.0
% INFO    : Bus 14444	: V=0.9842478, theta=-52.357933 -> V=1.0, theta=0.0
% INFO    : Bus 14445	: V=0.96238, theta=-54.551119 -> V=1.0, theta=0.0
% INFO    : Bus 14446	: V=0.9592457, theta=-55.744138 -> V=1.0, theta=0.0
% INFO    : Bus 14447	: V=0.960507, theta=-54.318145 -> V=1.0, theta=0.0
% INFO    : Bus 14448	: V=0.9618885, theta=-54.579533 -> V=1.0, theta=0.0
% INFO    : Bus 14449	: V=0.9540135, theta=-55.591065 -> V=1.0, theta=0.0
% INFO    : Bus 14450	: V=0.9840059, theta=-52.393798 -> V=1.0, theta=0.0
% INFO    : Bus 14451	: V=0.9586538, theta=-55.105925 -> V=1.0, theta=0.0
% INFO    : Bus 14452	: V=0.963268, theta=-53.910021 -> V=1.0, theta=0.0
% INFO    : Bus 14453	: V=0.952531, theta=-55.444153 -> V=1.0, theta=0.0
% INFO    : Bus 14454	: V=0.9851536, theta=-52.552779 -> V=1.0, theta=0.0
% INFO    : Bus 14455	: V=1.0116043, theta=-54.104208 -> V=1.0, theta=0.0
% INFO    : Bus 14456	: V=1.0150501, theta=-53.391677 -> V=1.0, theta=0.0
% INFO    : Bus 14457	: V=1.0046432, theta=-54.062471 -> V=1.0, theta=0.0
% INFO    : Bus 14458	: V=1.0065069, theta=-54.046397 -> V=1.0, theta=0.0
% INFO    : Bus 14459	: V=1.0145078, theta=-53.285821 -> V=1.0, theta=0.0
% INFO    : Bus 14460	: V=1.014308, theta=-53.307659 -> V=1.0, theta=0.0
% INFO    : Bus 14461	: V=1.014298, theta=-53.311601 -> V=1.0, theta=0.0
% INFO    : Bus 14462	: V=1.0163791, theta=-53.106754 -> V=1.0, theta=0.0
% INFO    : Bus 14463	: V=1.0100575, theta=-53.788395 -> V=1.0, theta=0.0
% INFO    : Bus 14464	: V=1.0099382, theta=-53.78582 -> V=1.0, theta=0.0
% INFO    : Bus 14465	: V=1.0165385, theta=-53.07089 -> V=1.0, theta=0.0
% INFO    : Bus 14466	: V=1.0134415, theta=-53.340588 -> V=1.0, theta=0.0
% INFO    : Bus 14467	: V=1.0183111, theta=-52.664538 -> V=1.0, theta=0.0
% INFO    : Bus 14468	: V=1.0182698, theta=-52.672662 -> V=1.0, theta=0.0
% INFO    : Bus 14469	: V=1.0104219, theta=-53.862671 -> V=1.0, theta=0.0
% INFO    : Bus 14470	: V=1.0132499, theta=-53.805764 -> V=1.0, theta=0.0
% INFO    : Bus 14471	: V=1.0191125, theta=-52.421945 -> V=1.0, theta=0.0
% INFO    : Bus 14472	: V=1.0186839, theta=-52.554459 -> V=1.0, theta=0.0
% INFO    : Bus 14473	: V=0.9979202, theta=-54.173421 -> V=1.0, theta=0.0
% INFO    : Bus 14474	: V=0.994627, theta=-54.183666 -> V=1.0, theta=0.0
% INFO    : Bus 14475	: V=1.0126644, theta=-53.311619 -> V=1.0, theta=0.0
% INFO    : Bus 14476	: V=0.9976526, theta=-54.009969 -> V=1.0, theta=0.0
% INFO    : Bus 14477	: V=1.0135775, theta=-53.007133 -> V=1.0, theta=0.0
% INFO    : Bus 14478	: V=0.9830128, theta=-54.488156 -> V=1.0, theta=0.0
% INFO    : Bus 14479	: V=1.0005899, theta=-51.595915 -> V=1.0, theta=0.0
% INFO    : Bus 14480	: V=0.9807169, theta=-54.084024 -> V=1.0, theta=0.0
% INFO    : Bus 14481	: V=0.9773864, theta=-53.111224 -> V=1.0, theta=0.0
% INFO    : Bus 14482	: V=1.0033943, theta=-50.538443 -> V=1.0, theta=0.0
% INFO    : Bus 14483	: V=0.9664838, theta=-56.450017 -> V=1.0, theta=0.0
% INFO    : Bus 14484	: V=0.9579212, theta=-55.720705 -> V=1.0, theta=0.0
% INFO    : Bus 14485	: V=0.9575564, theta=-55.794021 -> V=1.0, theta=0.0
% INFO    : Bus 14486	: V=0.9576075, theta=-55.825624 -> V=1.0, theta=0.0
% INFO    : Bus 14487	: V=0.9541503, theta=-56.466446 -> V=1.0, theta=0.0
% INFO    : Bus 14488	: V=0.9516032, theta=-56.632398 -> V=1.0, theta=0.0
% INFO    : Bus 14489	: V=0.9507136, theta=-56.288491 -> V=1.0, theta=0.0
% INFO    : Bus 14490	: V=0.9878172, theta=-53.871037 -> V=1.0, theta=0.0
% INFO    : Bus 14491	: V=0.9993508, theta=-52.072476 -> V=1.0, theta=0.0
% INFO    : Bus 14492	: V=0.9899672, theta=-53.692092 -> V=1.0, theta=0.0
% INFO    : Bus 14493	: V=0.9828711, theta=-54.478146 -> V=1.0, theta=0.0
% INFO    : Bus 14494	: V=0.9949728, theta=-53.643282 -> V=1.0, theta=0.0
% INFO    : Bus 14495	: V=0.9876159, theta=-54.905693 -> V=1.0, theta=0.0
% INFO    : Bus 14496	: V=0.9899164, theta=-53.861088 -> V=1.0, theta=0.0
% INFO    : Bus 14497	: V=0.9822488, theta=-54.547683 -> V=1.0, theta=0.0
% INFO    : Bus 14498	: V=0.9813501, theta=-54.568316 -> V=1.0, theta=0.0
% INFO    : Bus 14499	: V=0.9899072, theta=-53.763125 -> V=1.0, theta=0.0
% INFO    : Bus 14500	: V=0.9898854, theta=-53.807607 -> V=1.0, theta=0.0
% INFO    : Bus 14501	: V=0.9994469, theta=-52.210012 -> V=1.0, theta=0.0
% INFO    : Bus 14502	: V=0.9995444, theta=-52.298824 -> V=1.0, theta=0.0
% INFO    : Bus 14503	: V=0.990769, theta=-53.805865 -> V=1.0, theta=0.0
% INFO    : Bus 14504	: V=0.9909563, theta=-51.788599 -> V=1.0, theta=0.0
% INFO    : Bus 14505	: V=0.9929358, theta=-51.571841 -> V=1.0, theta=0.0
% INFO    : Bus 14506	: V=0.9828763, theta=-52.483929 -> V=1.0, theta=0.0
% INFO    : Bus 14507	: V=0.9793622, theta=-52.622832 -> V=1.0, theta=0.0
% INFO    : Bus 14508	: V=1.0003292, theta=-54.452505 -> V=1.0, theta=0.0
% INFO    : Bus 14509	: V=0.9689738, theta=-57.042098 -> V=1.0, theta=0.0
% INFO    : Bus 14510	: V=0.9769739, theta=-56.283841 -> V=1.0, theta=0.0
% INFO    : Bus 14511	: V=0.9670563, theta=-57.181458 -> V=1.0, theta=0.0
% INFO    : Bus 14512	: V=0.9657702, theta=-57.306346 -> V=1.0, theta=0.0
% INFO    : Bus 14513	: V=0.9664222, theta=-57.19166 -> V=1.0, theta=0.0
% INFO    : Bus 14514	: V=0.97199, theta=-56.51836 -> V=1.0, theta=0.0
% INFO    : Bus 14515	: V=0.9718498, theta=-56.474749 -> V=1.0, theta=0.0
% INFO    : Bus 14516	: V=0.968895, theta=-56.722763 -> V=1.0, theta=0.0
% INFO    : Bus 14517	: V=0.9697153, theta=-56.688558 -> V=1.0, theta=0.0
% INFO    : Bus 14518	: V=0.9720262, theta=-56.367083 -> V=1.0, theta=0.0
% INFO    : Bus 14519	: V=0.9689712, theta=-56.823482 -> V=1.0, theta=0.0
% INFO    : Bus 14520	: V=0.9768458, theta=-56.075055 -> V=1.0, theta=0.0
% INFO    : Bus 14521	: V=0.981915, theta=-55.723397 -> V=1.0, theta=0.0
% INFO    : Bus 14522	: V=0.9864198, theta=-55.164289 -> V=1.0, theta=0.0
% INFO    : Bus 14523	: V=0.9895502, theta=-54.039833 -> V=1.0, theta=0.0
% INFO    : Bus 14524	: V=0.9885285, theta=-54.330843 -> V=1.0, theta=0.0
% INFO    : Bus 14525	: V=0.987698, theta=-54.481264 -> V=1.0, theta=0.0
% INFO    : Bus 14526	: V=0.9886331, theta=-54.499534 -> V=1.0, theta=0.0
% INFO    : Bus 14527	: V=0.9846634, theta=-55.037487 -> V=1.0, theta=0.0
% INFO    : Bus 14528	: V=0.98607, theta=-55.210897 -> V=1.0, theta=0.0
% INFO    : Bus 14529	: V=0.986716, theta=-55.06571 -> V=1.0, theta=0.0
% INFO    : Bus 14530	: V=0.9856925, theta=-55.337446 -> V=1.0, theta=0.0
% INFO    : Bus 14531	: V=0.98536, theta=-55.436756 -> V=1.0, theta=0.0
% INFO    : Bus 14532	: V=0.9850284, theta=-55.554025 -> V=1.0, theta=0.0
% INFO    : Bus 14533	: V=0.9746669, theta=-56.346884 -> V=1.0, theta=0.0
% INFO    : Bus 14534	: V=0.985211, theta=-55.655107 -> V=1.0, theta=0.0
% INFO    : Bus 14535	: V=0.9856966, theta=-55.694503 -> V=1.0, theta=0.0
% INFO    : Bus 14536	: V=0.9897487, theta=-54.905493 -> V=1.0, theta=0.0
% INFO    : Bus 14537	: V=0.9899884, theta=-55.360129 -> V=1.0, theta=0.0
% INFO    : Bus 14538	: V=0.9725083, theta=-56.487234 -> V=1.0, theta=0.0
% INFO    : Bus 14539	: V=0.994755, theta=-55.338149 -> V=1.0, theta=0.0
% INFO    : Bus 14540	: V=0.9850346, theta=-55.988275 -> V=1.0, theta=0.0
% INFO    : Bus 14541	: V=0.9775438, theta=-56.229662 -> V=1.0, theta=0.0
% INFO    : Bus 14542	: V=0.986535, theta=-55.688022 -> V=1.0, theta=0.0
% INFO    : Bus 14543	: V=0.96321, theta=-57.1612 -> V=1.0, theta=0.0
% INFO    : Bus 14544	: V=0.9675709, theta=-56.893541 -> V=1.0, theta=0.0
% INFO    : Bus 14545	: V=0.9625495, theta=-57.235037 -> V=1.0, theta=0.0
% INFO    : Bus 14546	: V=0.9659754, theta=-56.794948 -> V=1.0, theta=0.0
% INFO    : Bus 14547	: V=0.969632, theta=-56.777414 -> V=1.0, theta=0.0
% INFO    : Bus 14548	: V=0.966979, theta=-56.784718 -> V=1.0, theta=0.0
% INFO    : Bus 14549	: V=0.9660733, theta=-56.788262 -> V=1.0, theta=0.0
% INFO    : Bus 14550	: V=0.9660232, theta=-56.639644 -> V=1.0, theta=0.0
% INFO    : Bus 14551	: V=0.9655988, theta=-56.744259 -> V=1.0, theta=0.0
% INFO    : Bus 14552	: V=0.9643496, theta=-56.970181 -> V=1.0, theta=0.0
% INFO    : Bus 14553	: V=0.9654079, theta=-56.718487 -> V=1.0, theta=0.0
% INFO    : Bus 14554	: V=0.9650545, theta=-56.76893 -> V=1.0, theta=0.0
% INFO    : Bus 14555	: V=0.9622324, theta=-57.193533 -> V=1.0, theta=0.0
% INFO    : Bus 14556	: V=0.9662764, theta=-56.298467 -> V=1.0, theta=0.0
% INFO    : Bus 14557	: V=0.95469, theta=-57.590611 -> V=1.0, theta=0.0
% INFO    : Bus 14558	: V=0.9515759, theta=-56.995024 -> V=1.0, theta=0.0
% INFO    : Bus 14559	: V=0.952116, theta=-57.937973 -> V=1.0, theta=0.0
% INFO    : Bus 14560	: V=0.9549221, theta=-57.628224 -> V=1.0, theta=0.0
% INFO    : Bus 14561	: V=0.9687491, theta=-56.524787 -> V=1.0, theta=0.0
% INFO    : Bus 14562	: V=0.9803853, theta=-56.542743 -> V=1.0, theta=0.0
% INFO    : Bus 14563	: V=0.9802479, theta=-56.607802 -> V=1.0, theta=0.0
% INFO    : Bus 14564	: V=0.9655947, theta=-57.634659 -> V=1.0, theta=0.0
% INFO    : Bus 14565	: V=0.975122, theta=-56.629001 -> V=1.0, theta=0.0
% INFO    : Bus 14566	: V=0.9806596, theta=-56.428624 -> V=1.0, theta=0.0
% INFO    : Bus 14567	: V=0.9639868, theta=-57.947785 -> V=1.0, theta=0.0
% INFO    : Bus 14568	: V=0.9638508, theta=-57.679116 -> V=1.0, theta=0.0
% INFO    : Bus 14569	: V=0.9706054, theta=-56.89336 -> V=1.0, theta=0.0
% INFO    : Bus 14570	: V=0.9669078, theta=-57.384093 -> V=1.0, theta=0.0
% INFO    : Bus 14571	: V=0.9664338, theta=-57.384111 -> V=1.0, theta=0.0
% INFO    : Bus 14572	: V=0.9721333, theta=-56.748738 -> V=1.0, theta=0.0
% INFO    : Bus 14573	: V=0.9740501, theta=-56.629874 -> V=1.0, theta=0.0
% INFO    : Bus 14574	: V=0.981047, theta=-56.301195 -> V=1.0, theta=0.0
% INFO    : Bus 14575	: V=0.9640629, theta=-57.362119 -> V=1.0, theta=0.0
% INFO    : Bus 14576	: V=0.9685039, theta=-57.120079 -> V=1.0, theta=0.0
% INFO    : Bus 14577	: V=0.9683451, theta=-56.85559 -> V=1.0, theta=0.0
% INFO    : Bus 14578	: V=0.9652389, theta=-56.724873 -> V=1.0, theta=0.0
% INFO    : Bus 14579	: V=0.9742309, theta=-55.435816 -> V=1.0, theta=0.0
% INFO    : Bus 14580	: V=0.9640917, theta=-56.086858 -> V=1.0, theta=0.0
% INFO    : Bus 14581	: V=0.9692332, theta=-57.026824 -> V=1.0, theta=0.0
% INFO    : Bus 14582	: V=0.9569542, theta=-58.682782 -> V=1.0, theta=0.0
% INFO    : Bus 14583	: V=0.9557354, theta=-58.746521 -> V=1.0, theta=0.0
% INFO    : Bus 14584	: V=0.9608512, theta=-58.271598 -> V=1.0, theta=0.0
% INFO    : Bus 14585	: V=0.9585268, theta=-58.448815 -> V=1.0, theta=0.0
% INFO    : Bus 14586	: V=0.9547262, theta=-58.815456 -> V=1.0, theta=0.0
% INFO    : Bus 14587	: V=0.9569752, theta=-58.569376 -> V=1.0, theta=0.0
% INFO    : Bus 14588	: V=0.9542124, theta=-58.884125 -> V=1.0, theta=0.0
% INFO    : Bus 14589	: V=0.9571289, theta=-58.559165 -> V=1.0, theta=0.0
% INFO    : Bus 14590	: V=0.9545061, theta=-59.062661 -> V=1.0, theta=0.0
% INFO    : Bus 14591	: V=0.9574422, theta=-58.538121 -> V=1.0, theta=0.0
% INFO    : Bus 14592	: V=0.9607187, theta=-58.401988 -> V=1.0, theta=0.0
% INFO    : Bus 14593	: V=0.9622232, theta=-58.293185 -> V=1.0, theta=0.0
% INFO    : Bus 14594	: V=0.9548896, theta=-59.23268 -> V=1.0, theta=0.0
% INFO    : Bus 14595	: V=0.9541698, theta=-58.920162 -> V=1.0, theta=0.0
% INFO    : Bus 14596	: V=0.954395, theta=-58.893418 -> V=1.0, theta=0.0
% INFO    : Bus 14597	: V=0.957643, theta=-58.518535 -> V=1.0, theta=0.0
% INFO    : Bus 14598	: V=0.9575481, theta=-58.609234 -> V=1.0, theta=0.0
% INFO    : Bus 14599	: V=0.9584465, theta=-58.566009 -> V=1.0, theta=0.0
% INFO    : Bus 14600	: V=0.9596952, theta=-58.476891 -> V=1.0, theta=0.0
% INFO    : Bus 14601	: V=0.9528642, theta=-59.418032 -> V=1.0, theta=0.0
% INFO    : Bus 14602	: V=0.9533298, theta=-59.415779 -> V=1.0, theta=0.0
% INFO    : Bus 14603	: V=0.9610928, theta=-58.863955 -> V=1.0, theta=0.0
% INFO    : Bus 14604	: V=0.9531941, theta=-59.369656 -> V=1.0, theta=0.0
% INFO    : Bus 14605	: V=0.9531497, theta=-59.427023 -> V=1.0, theta=0.0
% INFO    : Bus 14606	: V=0.9590526, theta=-58.662655 -> V=1.0, theta=0.0
% INFO    : Bus 14607	: V=0.9541014, theta=-59.376306 -> V=1.0, theta=0.0
% INFO    : Bus 14608	: V=0.954231, theta=-59.398607 -> V=1.0, theta=0.0
% INFO    : Bus 14609	: V=0.9532249, theta=-59.392667 -> V=1.0, theta=0.0
% INFO    : Bus 14610	: V=0.9607642, theta=-58.713801 -> V=1.0, theta=0.0
% INFO    : Bus 14611	: V=0.9542299, theta=-59.31775 -> V=1.0, theta=0.0
% INFO    : Bus 14612	: V=0.9539435, theta=-59.35772 -> V=1.0, theta=0.0
% INFO    : Bus 14613	: V=0.9529911, theta=-59.385195 -> V=1.0, theta=0.0
% INFO    : Bus 14614	: V=0.9528613, theta=-59.429003 -> V=1.0, theta=0.0
% INFO    : Bus 14615	: V=0.9531635, theta=-59.409165 -> V=1.0, theta=0.0
% INFO    : Bus 14616	: V=0.9585032, theta=-58.878289 -> V=1.0, theta=0.0
% INFO    : Bus 14617	: V=0.9538139, theta=-59.361809 -> V=1.0, theta=0.0
% INFO    : Bus 14618	: V=0.9587526, theta=-58.989054 -> V=1.0, theta=0.0
% INFO    : Bus 14619	: V=0.9582956, theta=-58.975838 -> V=1.0, theta=0.0
% INFO    : Bus 14620	: V=0.9576863, theta=-59.022894 -> V=1.0, theta=0.0
% INFO    : Bus 14621	: V=0.9591454, theta=-58.83053 -> V=1.0, theta=0.0
% INFO    : Bus 14622	: V=0.9573336, theta=-59.05048 -> V=1.0, theta=0.0
% INFO    : Bus 14623	: V=0.959708, theta=-58.789444 -> V=1.0, theta=0.0
% INFO    : Bus 14624	: V=0.9544802, theta=-59.388996 -> V=1.0, theta=0.0
% INFO    : Bus 14625	: V=0.9551906, theta=-59.372346 -> V=1.0, theta=0.0
% INFO    : Bus 14626	: V=0.9546387, theta=-59.313324 -> V=1.0, theta=0.0
% INFO    : Bus 14627	: V=0.9538888, theta=-59.429219 -> V=1.0, theta=0.0
% INFO    : Bus 14628	: V=0.9633844, theta=-58.576563 -> V=1.0, theta=0.0
% INFO    : Bus 14629	: V=0.9769995, theta=-56.98518 -> V=1.0, theta=0.0
% INFO    : Bus 14630	: V=0.9641659, theta=-58.55692 -> V=1.0, theta=0.0
% INFO    : Bus 14631	: V=0.9642985, theta=-58.55459 -> V=1.0, theta=0.0
% INFO    : Bus 14632	: V=0.9555122, theta=-59.192149 -> V=1.0, theta=0.0
% INFO    : Bus 14633	: V=0.9529807, theta=-59.703573 -> V=1.0, theta=0.0
% INFO    : Bus 14634	: V=0.9515469, theta=-59.845937 -> V=1.0, theta=0.0
% INFO    : Bus 14635	: V=0.9549213, theta=-59.718433 -> V=1.0, theta=0.0
% INFO    : Bus 14636	: V=0.9552296, theta=-59.588362 -> V=1.0, theta=0.0
% INFO    : Bus 14637	: V=0.9641531, theta=-58.561908 -> V=1.0, theta=0.0
% INFO    : Bus 14638	: V=0.9591294, theta=-59.085315 -> V=1.0, theta=0.0
% INFO    : Bus 14639	: V=0.9595723, theta=-59.099453 -> V=1.0, theta=0.0
% INFO    : Bus 14640	: V=0.9609079, theta=-59.158509 -> V=1.0, theta=0.0
% INFO    : Bus 14641	: V=0.9603707, theta=-59.079457 -> V=1.0, theta=0.0
% INFO    : Bus 14642	: V=0.9627855, theta=-59.263297 -> V=1.0, theta=0.0
% INFO    : Bus 14643	: V=0.9541902, theta=-59.953033 -> V=1.0, theta=0.0
% INFO    : Bus 14644	: V=0.9629133, theta=-59.165106 -> V=1.0, theta=0.0
% INFO    : Bus 14645	: V=0.9620982, theta=-59.211906 -> V=1.0, theta=0.0
% INFO    : Bus 14646	: V=0.961337, theta=-59.187199 -> V=1.0, theta=0.0
% INFO    : Bus 14647	: V=0.9649992, theta=-59.229281 -> V=1.0, theta=0.0
% INFO    : Bus 14648	: V=0.9631839, theta=-59.022702 -> V=1.0, theta=0.0
% INFO    : Bus 14649	: V=0.9623038, theta=-59.325465 -> V=1.0, theta=0.0
% INFO    : Bus 14650	: V=0.9712058, theta=-59.327641 -> V=1.0, theta=0.0
% INFO    : Bus 14651	: V=0.9782241, theta=-59.39322 -> V=1.0, theta=0.0
% INFO    : Bus 14652	: V=0.9720224, theta=-59.242941 -> V=1.0, theta=0.0
% INFO    : Bus 14653	: V=0.978725, theta=-59.103544 -> V=1.0, theta=0.0
% INFO    : Bus 14654	: V=0.9684383, theta=-59.212336 -> V=1.0, theta=0.0
% INFO    : Bus 14655	: V=0.9557639, theta=-59.769353 -> V=1.0, theta=0.0
% INFO    : Bus 14656	: V=0.9554506, theta=-59.800291 -> V=1.0, theta=0.0
% INFO    : Bus 14657	: V=0.9627003, theta=-59.330099 -> V=1.0, theta=0.0
% INFO    : Bus 14658	: V=0.9632062, theta=-59.317769 -> V=1.0, theta=0.0
% INFO    : Bus 14659	: V=0.9643211, theta=-59.266894 -> V=1.0, theta=0.0
% INFO    : Bus 14660	: V=0.9648072, theta=-59.282203 -> V=1.0, theta=0.0
% INFO    : Bus 14661	: V=0.9640468, theta=-59.309279 -> V=1.0, theta=0.0
% INFO    : Bus 14662	: V=0.9558867, theta=-59.872746 -> V=1.0, theta=0.0
% INFO    : Bus 14663	: V=0.9643999, theta=-59.303026 -> V=1.0, theta=0.0
% INFO    : Bus 14664	: V=0.9641371, theta=-59.312919 -> V=1.0, theta=0.0
% INFO    : Bus 14665	: V=0.9638854, theta=-59.322118 -> V=1.0, theta=0.0
% INFO    : Bus 14666	: V=0.9565335, theta=-59.840046 -> V=1.0, theta=0.0
% INFO    : Bus 14667	: V=0.9559252, theta=-59.792262 -> V=1.0, theta=0.0
% INFO    : Bus 14668	: V=0.9564887, theta=-59.841526 -> V=1.0, theta=0.0
% INFO    : Bus 14669	: V=0.9556912, theta=-59.842142 -> V=1.0, theta=0.0
% INFO    : Bus 14670	: V=0.9559018, theta=-59.865513 -> V=1.0, theta=0.0
% INFO    : Bus 14671	: V=0.9594867, theta=-59.796581 -> V=1.0, theta=0.0
% INFO    : Bus 14672	: V=0.970677, theta=-59.018409 -> V=1.0, theta=0.0
% INFO    : Bus 14673	: V=0.9702117, theta=-58.979257 -> V=1.0, theta=0.0
% INFO    : Bus 14674	: V=0.9846629, theta=-57.515941 -> V=1.0, theta=0.0
% INFO    : Bus 14675	: V=0.9869602, theta=-57.410381 -> V=1.0, theta=0.0
% INFO    : Bus 14676	: V=0.979619, theta=-58.118106 -> V=1.0, theta=0.0
% INFO    : Bus 14677	: V=0.9808809, theta=-57.883835 -> V=1.0, theta=0.0
% INFO    : Bus 14678	: V=0.9870089, theta=-57.300928 -> V=1.0, theta=0.0
% INFO    : Bus 14679	: V=0.982874, theta=-57.40267 -> V=1.0, theta=0.0
% INFO    : Bus 14680	: V=0.9821301, theta=-57.39097 -> V=1.0, theta=0.0
% INFO    : Bus 14681	: V=0.9824591, theta=-57.560303 -> V=1.0, theta=0.0
% INFO    : Bus 14682	: V=0.9836978, theta=-57.396785 -> V=1.0, theta=0.0
% INFO    : Bus 14683	: V=0.9848777, theta=-57.372285 -> V=1.0, theta=0.0
% INFO    : Bus 14684	: V=0.980606, theta=-57.72622 -> V=1.0, theta=0.0
% INFO    : Bus 14685	: V=0.9825761, theta=-57.608552 -> V=1.0, theta=0.0
% INFO    : Bus 14686	: V=0.9794164, theta=-57.736149 -> V=1.0, theta=0.0
% INFO    : Bus 14687	: V=0.979949, theta=-57.72235 -> V=1.0, theta=0.0
% INFO    : Bus 14688	: V=0.9812822, theta=-57.666076 -> V=1.0, theta=0.0
% INFO    : Bus 14689	: V=0.9806156, theta=-57.692891 -> V=1.0, theta=0.0
% INFO    : Bus 14690	: V=0.9929306, theta=-55.902639 -> V=1.0, theta=0.0
% INFO    : Bus 14691	: V=1.0015736, theta=-54.95038 -> V=1.0, theta=0.0
% INFO    : Bus 14692	: V=0.994069, theta=-55.793207 -> V=1.0, theta=0.0
% INFO    : Bus 14693	: V=0.9946622, theta=-55.734605 -> V=1.0, theta=0.0
% INFO    : Bus 14694	: V=0.9951759, theta=-55.684968 -> V=1.0, theta=0.0
% INFO    : Bus 14695	: V=1.0013368, theta=-55.009916 -> V=1.0, theta=0.0
% INFO    : Bus 14696	: V=1.0011956, theta=-55.047723 -> V=1.0, theta=0.0
% INFO    : Bus 14697	: V=0.990824, theta=-56.100913 -> V=1.0, theta=0.0
% INFO    : Bus 14698	: V=0.9916858, theta=-56.026952 -> V=1.0, theta=0.0
% INFO    : Bus 14699	: V=0.9930415, theta=-55.905147 -> V=1.0, theta=0.0
% INFO    : Bus 14700	: V=0.9906013, theta=-56.168921 -> V=1.0, theta=0.0
% INFO    : Bus 14701	: V=0.9944833, theta=-55.779882 -> V=1.0, theta=0.0
% INFO    : Bus 14702	: V=0.9946432, theta=-55.757471 -> V=1.0, theta=0.0
% INFO    : Bus 14703	: V=0.9948353, theta=-55.734985 -> V=1.0, theta=0.0
% INFO    : Bus 14704	: V=0.9966303, theta=-55.626865 -> V=1.0, theta=0.0
% INFO    : Bus 14705	: V=0.9933711, theta=-55.919405 -> V=1.0, theta=0.0
% INFO    : Bus 14706	: V=1.0016675, theta=-54.41588 -> V=1.0, theta=0.0
% INFO    : Bus 14707	: V=1.0016537, theta=-54.43277 -> V=1.0, theta=0.0
% INFO    : Bus 14708	: V=0.9761977, theta=-56.837095 -> V=1.0, theta=0.0
% INFO    : Bus 14709	: V=0.9772668, theta=-56.777218 -> V=1.0, theta=0.0
% INFO    : Bus 14710	: V=0.9610429, theta=-58.213542 -> V=1.0, theta=0.0
% INFO    : Bus 14711	: V=0.9624569, theta=-58.095426 -> V=1.0, theta=0.0
% INFO    : Bus 14712	: V=0.9713997, theta=-57.288701 -> V=1.0, theta=0.0
% INFO    : Bus 14713	: V=0.9704841, theta=-57.165094 -> V=1.0, theta=0.0
% INFO    : Bus 14714	: V=0.9609688, theta=-58.363256 -> V=1.0, theta=0.0
% INFO    : Bus 14715	: V=0.9597752, theta=-58.541268 -> V=1.0, theta=0.0
% INFO    : Bus 14716	: V=0.9681926, theta=-57.781899 -> V=1.0, theta=0.0
% INFO    : Bus 14717	: V=0.9781971, theta=-57.767163 -> V=1.0, theta=0.0
% INFO    : Bus 14718	: V=0.9751039, theta=-57.774671 -> V=1.0, theta=0.0
% INFO    : Bus 14719	: V=0.9758132, theta=-57.781848 -> V=1.0, theta=0.0
% INFO    : Bus 14720	: V=0.9805029, theta=-57.301224 -> V=1.0, theta=0.0
% INFO    : Bus 14721	: V=0.9807577, theta=-57.334051 -> V=1.0, theta=0.0
% INFO    : Bus 14722	: V=0.9816935, theta=-57.373577 -> V=1.0, theta=0.0
% INFO    : Bus 14723	: V=0.987865, theta=-56.576631 -> V=1.0, theta=0.0
% INFO    : Bus 14724	: V=0.9829551, theta=-57.443185 -> V=1.0, theta=0.0
% INFO    : Bus 14725	: V=0.981098, theta=-57.352415 -> V=1.0, theta=0.0
% INFO    : Bus 14726	: V=0.9865079, theta=-56.675063 -> V=1.0, theta=0.0
% INFO    : Bus 14727	: V=0.9831682, theta=-56.947924 -> V=1.0, theta=0.0
% INFO    : Bus 14728	: V=0.9872695, theta=-56.592543 -> V=1.0, theta=0.0
% INFO    : Bus 14729	: V=0.9787829, theta=-57.489303 -> V=1.0, theta=0.0
% INFO    : Bus 14730	: V=0.9885897, theta=-56.447337 -> V=1.0, theta=0.0
% INFO    : Bus 14731	: V=0.9904161, theta=-56.341708 -> V=1.0, theta=0.0
% INFO    : Bus 14732	: V=0.9917732, theta=-56.260969 -> V=1.0, theta=0.0
% INFO    : Bus 14733	: V=0.9905975, theta=-56.398094 -> V=1.0, theta=0.0
% INFO    : Bus 14734	: V=0.9933885, theta=-56.167182 -> V=1.0, theta=0.0
% INFO    : Bus 14735	: V=0.9917486, theta=-56.3931 -> V=1.0, theta=0.0
% INFO    : Bus 14736	: V=1.0009975, theta=-55.354895 -> V=1.0, theta=0.0
% INFO    : Bus 14737	: V=0.9990045, theta=-55.502374 -> V=1.0, theta=0.0
% INFO    : Bus 14738	: V=0.9898989, theta=-56.490595 -> V=1.0, theta=0.0
% INFO    : Bus 14739	: V=0.9877458, theta=-56.526913 -> V=1.0, theta=0.0
% INFO    : Bus 14740	: V=1.000999, theta=-55.299486 -> V=1.0, theta=0.0
% INFO    : Bus 14741	: V=0.9896541, theta=-56.428035 -> V=1.0, theta=0.0
% INFO    : Bus 14742	: V=0.9841537, theta=-57.301587 -> V=1.0, theta=0.0
% INFO    : Bus 14743	: V=0.9858281, theta=-57.138893 -> V=1.0, theta=0.0
% INFO    : Bus 14744	: V=0.9891972, theta=-56.890395 -> V=1.0, theta=0.0
% INFO    : Bus 14745	: V=0.996195, theta=-55.99199 -> V=1.0, theta=0.0
% INFO    : Bus 14746	: V=1.0040624, theta=-55.299647 -> V=1.0, theta=0.0
% INFO    : Bus 14747	: V=0.9990375, theta=-55.729963 -> V=1.0, theta=0.0
% INFO    : Bus 14748	: V=1.0015769, theta=-55.451563 -> V=1.0, theta=0.0
% INFO    : Bus 14749	: V=1.0052959, theta=-54.703014 -> V=1.0, theta=0.0
% INFO    : Bus 14750	: V=0.9959043, theta=-56.183356 -> V=1.0, theta=0.0
% INFO    : Bus 14751	: V=0.9957847, theta=-56.171031 -> V=1.0, theta=0.0
% INFO    : Bus 14752	: V=0.9845045, theta=-56.529729 -> V=1.0, theta=0.0
% INFO    : Bus 14753	: V=0.985438, theta=-56.488667 -> V=1.0, theta=0.0
% INFO    : Bus 14754	: V=0.9867662, theta=-56.47157 -> V=1.0, theta=0.0
% INFO    : Bus 14755	: V=0.9903187, theta=-56.205613 -> V=1.0, theta=0.0
% INFO    : Bus 14756	: V=1.0009945, theta=-55.177062 -> V=1.0, theta=0.0
% INFO    : Bus 14757	: V=1.0010872, theta=-55.118282 -> V=1.0, theta=0.0
% INFO    : Bus 14758	: V=0.9668695, theta=-58.703851 -> V=1.0, theta=0.0
% INFO    : Bus 14759	: V=0.956452, theta=-59.776046 -> V=1.0, theta=0.0
% INFO    : Bus 14760	: V=0.9680438, theta=-58.307801 -> V=1.0, theta=0.0
% INFO    : Bus 14761	: V=0.9663648, theta=-58.656765 -> V=1.0, theta=0.0
% INFO    : Bus 14762	: V=0.964825, theta=-58.528567 -> V=1.0, theta=0.0
% INFO    : Bus 14763	: V=0.9656907, theta=-58.474737 -> V=1.0, theta=0.0
% INFO    : Bus 14764	: V=0.965094, theta=-58.624483 -> V=1.0, theta=0.0
% INFO    : Bus 14765	: V=0.9699066, theta=-57.917918 -> V=1.0, theta=0.0
% INFO    : Bus 14766	: V=0.9641703, theta=-58.620407 -> V=1.0, theta=0.0
% INFO    : Bus 14767	: V=0.9670579, theta=-58.387273 -> V=1.0, theta=0.0
% INFO    : Bus 14768	: V=0.955454, theta=-59.797497 -> V=1.0, theta=0.0
% INFO    : Bus 14769	: V=0.9679428, theta=-58.332044 -> V=1.0, theta=0.0
% INFO    : Bus 14770	: V=0.9695448, theta=-57.95831 -> V=1.0, theta=0.0
% INFO    : Bus 14771	: V=0.9697532, theta=-58.240132 -> V=1.0, theta=0.0
% INFO    : Bus 14772	: V=0.9666492, theta=-58.583415 -> V=1.0, theta=0.0
% INFO    : Bus 14773	: V=0.9661924, theta=-58.614404 -> V=1.0, theta=0.0
% INFO    : Bus 14774	: V=0.9721803, theta=-58.107077 -> V=1.0, theta=0.0
% INFO    : Bus 14775	: V=0.9676962, theta=-58.609119 -> V=1.0, theta=0.0
% INFO    : Bus 14776	: V=0.9677704, theta=-58.494285 -> V=1.0, theta=0.0
% INFO    : Bus 14777	: V=0.9747681, theta=-57.846136 -> V=1.0, theta=0.0
% INFO    : Bus 14778	: V=0.9703673, theta=-58.325372 -> V=1.0, theta=0.0
% INFO    : Bus 14779	: V=0.9749843, theta=-57.881297 -> V=1.0, theta=0.0
% INFO    : Bus 14780	: V=0.9743812, theta=-57.977985 -> V=1.0, theta=0.0
% INFO    : Bus 14781	: V=0.9757269, theta=-57.938047 -> V=1.0, theta=0.0
% INFO    : Bus 14782	: V=0.9781311, theta=-57.790853 -> V=1.0, theta=0.0
% INFO    : Bus 14783	: V=0.9753037, theta=-57.904287 -> V=1.0, theta=0.0
% INFO    : Bus 14784	: V=0.9763586, theta=-57.848847 -> V=1.0, theta=0.0
% INFO    : Bus 14785	: V=0.9776061, theta=-57.775727 -> V=1.0, theta=0.0
% INFO    : Bus 14786	: V=0.9760043, theta=-57.866963 -> V=1.0, theta=0.0
% INFO    : Bus 14787	: V=0.9790963, theta=-57.806404 -> V=1.0, theta=0.0
% INFO    : Bus 14788	: V=0.9910997, theta=-56.477072 -> V=1.0, theta=0.0
% INFO    : Bus 14789	: V=0.9592455, theta=-58.993372 -> V=1.0, theta=0.0
% INFO    : Bus 14790	: V=0.9590925, theta=-59.03854 -> V=1.0, theta=0.0
% INFO    : Bus 14791	: V=0.9569295, theta=-58.649534 -> V=1.0, theta=0.0
% INFO    : Bus 14792	: V=0.9775227, theta=-57.869371 -> V=1.0, theta=0.0
% INFO    : Bus 14793	: V=0.9984119, theta=-55.492468 -> V=1.0, theta=0.0
% INFO    : Bus 14794	: V=0.9786935, theta=-56.69376 -> V=1.0, theta=0.0
% INFO    : Bus 14795	: V=0.9726766, theta=-57.035004 -> V=1.0, theta=0.0
% INFO    : Bus 14796	: V=0.9742394, theta=-52.736129 -> V=1.0, theta=0.0
% INFO    : Bus 14797	: V=0.981621, theta=-52.457037 -> V=1.0, theta=0.0
% INFO    : Bus 14798	: V=0.9907709, theta=-51.343186 -> V=1.0, theta=0.0
% INFO    : Bus 14799	: V=0.995486, theta=-50.79704 -> V=1.0, theta=0.0
% INFO    : Bus 14800	: V=0.9943281, theta=-50.995669 -> V=1.0, theta=0.0
% INFO    : Bus 14801	: V=0.994872, theta=-50.887363 -> V=1.0, theta=0.0
% INFO    : Bus 14802	: V=0.9961902, theta=-51.065599 -> V=1.0, theta=0.0
% INFO    : Bus 14803	: V=0.9976908, theta=-50.90564 -> V=1.0, theta=0.0
% INFO    : Bus 14804	: V=1.0044658, theta=-49.770996 -> V=1.0, theta=0.0
% INFO    : Bus 14805	: V=1.0114257, theta=-48.738057 -> V=1.0, theta=0.0
% INFO    : Bus 14806	: V=1.0043615, theta=-49.787199 -> V=1.0, theta=0.0
% INFO    : Bus 14807	: V=1.0127315, theta=-48.637684 -> V=1.0, theta=0.0
% INFO    : Bus 14808	: V=1.0150097, theta=-48.425378 -> V=1.0, theta=0.0
% INFO    : Bus 14809	: V=1.0074984, theta=-49.433876 -> V=1.0, theta=0.0
% INFO    : Bus 14810	: V=1.0102422, theta=-48.766611 -> V=1.0, theta=0.0
% INFO    : Bus 14811	: V=1.0176725, theta=-48.081536 -> V=1.0, theta=0.0
% INFO    : Bus 14812	: V=1.0055491, theta=-48.864903 -> V=1.0, theta=0.0
% INFO    : Bus 14813	: V=1.0118032, theta=-48.591969 -> V=1.0, theta=0.0
% INFO    : Bus 14814	: V=0.9858245, theta=-53.795925 -> V=1.0, theta=0.0
% INFO    : Bus 14815	: V=0.9817119, theta=-53.739576 -> V=1.0, theta=0.0
% INFO    : Bus 14816	: V=0.9810087, theta=-53.503501 -> V=1.0, theta=0.0
% INFO    : Bus 14817	: V=0.9845257, theta=-52.909704 -> V=1.0, theta=0.0
% INFO    : Bus 14818	: V=0.9812359, theta=-52.524605 -> V=1.0, theta=0.0
% INFO    : Bus 14819	: V=0.9830723, theta=-52.691838 -> V=1.0, theta=0.0
% INFO    : Bus 14820	: V=0.9861101, theta=-51.85469 -> V=1.0, theta=0.0
% INFO    : Bus 14821	: V=0.9963941, theta=-49.931885 -> V=1.0, theta=0.0
% INFO    : Bus 14822	: V=0.9985601, theta=-49.673764 -> V=1.0, theta=0.0
% INFO    : Bus 14823	: V=0.9834299, theta=-58.925674 -> V=1.0, theta=0.0
% INFO    : Bus 14824	: V=0.9835687, theta=-58.825822 -> V=1.0, theta=0.0
% INFO    : Bus 14825	: V=0.9804346, theta=-58.926338 -> V=1.0, theta=0.0
% INFO    : Bus 14826	: V=0.9716322, theta=-60.555399 -> V=1.0, theta=0.0
% INFO    : Bus 14827	: V=0.9695728, theta=-59.104132 -> V=1.0, theta=0.0
% INFO    : Bus 14828	: V=0.9700621, theta=-59.010953 -> V=1.0, theta=0.0
% INFO    : Bus 14829	: V=0.9713967, theta=-58.855993 -> V=1.0, theta=0.0
% INFO    : Bus 14830	: V=0.9645175, theta=-58.622263 -> V=1.0, theta=0.0
% INFO    : Bus 14831	: V=0.9639969, theta=-58.719468 -> V=1.0, theta=0.0
% INFO    : Bus 14832	: V=0.9641559, theta=-58.588101 -> V=1.0, theta=0.0
% INFO    : Bus 14833	: V=0.9633362, theta=-58.655793 -> V=1.0, theta=0.0
% INFO    : Bus 14834	: V=0.9622736, theta=-58.741946 -> V=1.0, theta=0.0
% INFO    : Bus 14835	: V=0.9653115, theta=-58.484041 -> V=1.0, theta=0.0
% INFO    : Bus 14836	: V=0.9659509, theta=-58.325072 -> V=1.0, theta=0.0
% INFO    : Bus 14837	: V=0.9804338, theta=-59.591277 -> V=1.0, theta=0.0
% INFO    : Bus 14838	: V=0.9699292, theta=-59.796043 -> V=1.0, theta=0.0
% INFO    : Bus 14839	: V=0.9787578, theta=-59.610072 -> V=1.0, theta=0.0
% INFO    : Bus 14840	: V=0.9793462, theta=-59.165284 -> V=1.0, theta=0.0
% INFO    : Bus 14841	: V=0.9791471, theta=-59.332389 -> V=1.0, theta=0.0
% INFO    : Bus 14842	: V=0.9826879, theta=-58.337528 -> V=1.0, theta=0.0
% INFO    : Bus 14843	: V=0.9750906, theta=-58.928326 -> V=1.0, theta=0.0
% INFO    : Bus 14844	: V=0.9704618, theta=-59.697314 -> V=1.0, theta=0.0
% INFO    : Bus 14845	: V=0.9713865, theta=-59.70051 -> V=1.0, theta=0.0
% INFO    : Bus 14846	: V=0.974956, theta=-58.991581 -> V=1.0, theta=0.0
% INFO    : Bus 14847	: V=0.9666675, theta=-59.636485 -> V=1.0, theta=0.0
% INFO    : Bus 14848	: V=0.9679641, theta=-59.839665 -> V=1.0, theta=0.0
% INFO    : Bus 14849	: V=0.971044, theta=-59.340251 -> V=1.0, theta=0.0
% INFO    : Bus 14850	: V=0.9714053, theta=-59.285084 -> V=1.0, theta=0.0
% INFO    : Bus 14851	: V=0.9759512, theta=-58.380845 -> V=1.0, theta=0.0
% INFO    : Bus 14852	: V=0.9756884, theta=-57.785199 -> V=1.0, theta=0.0
% INFO    : Bus 14853	: V=0.9809659, theta=-58.740417 -> V=1.0, theta=0.0
% INFO    : Bus 14854	: V=0.976255, theta=-58.67478 -> V=1.0, theta=0.0
% INFO    : Bus 14855	: V=0.9792739, theta=-58.643097 -> V=1.0, theta=0.0
% INFO    : Bus 14856	: V=0.9807021, theta=-57.135454 -> V=1.0, theta=0.0
% INFO    : Bus 14857	: V=0.9798772, theta=-57.175831 -> V=1.0, theta=0.0
% INFO    : Bus 14858	: V=0.9631295, theta=-59.522155 -> V=1.0, theta=0.0
% INFO    : Bus 14859	: V=0.9701833, theta=-58.125964 -> V=1.0, theta=0.0
% INFO    : Bus 14860	: V=0.9673276, theta=-58.33675 -> V=1.0, theta=0.0
% INFO    : Bus 14861	: V=0.9818226, theta=-56.685996 -> V=1.0, theta=0.0
% INFO    : Bus 14862	: V=0.9840875, theta=-56.891429 -> V=1.0, theta=0.0
% INFO    : Bus 14863	: V=1.0058116, theta=-56.065658 -> V=1.0, theta=0.0
% INFO    : Bus 14864	: V=1.006901, theta=-56.202669 -> V=1.0, theta=0.0
% INFO    : Bus 14865	: V=1.0057526, theta=-56.157099 -> V=1.0, theta=0.0
% INFO    : Bus 14866	: V=0.9954321, theta=-57.029694 -> V=1.0, theta=0.0
% INFO    : Bus 14867	: V=0.9928989, theta=-56.898359 -> V=1.0, theta=0.0
% INFO    : Bus 14868	: V=0.9971001, theta=-56.964368 -> V=1.0, theta=0.0
% INFO    : Bus 14869	: V=0.9933399, theta=-57.356345 -> V=1.0, theta=0.0
% INFO    : Bus 14870	: V=1.0088302, theta=-56.081863 -> V=1.0, theta=0.0
% INFO    : Bus 14871	: V=0.9942155, theta=-57.187725 -> V=1.0, theta=0.0
% INFO    : Bus 14872	: V=0.9875118, theta=-57.504406 -> V=1.0, theta=0.0
% INFO    : Bus 14873	: V=0.9834149, theta=-58.305683 -> V=1.0, theta=0.0
% INFO    : Bus 14874	: V=0.9949349, theta=-57.281676 -> V=1.0, theta=0.0
% INFO    : Bus 14875	: V=0.9986498, theta=-57.049455 -> V=1.0, theta=0.0
% INFO    : Bus 14876	: V=0.9932424, theta=-57.385539 -> V=1.0, theta=0.0
% INFO    : Bus 14877	: V=0.9996844, theta=-57.021686 -> V=1.0, theta=0.0
% INFO    : Bus 14878	: V=1.0189266, theta=-55.377795 -> V=1.0, theta=0.0
% INFO    : Bus 14879	: V=1.0023221, theta=-57.035857 -> V=1.0, theta=0.0
% INFO    : Bus 14880	: V=1.0016012, theta=-48.695384 -> V=1.0, theta=0.0
% INFO    : Bus 14881	: V=0.9937714, theta=-49.275862 -> V=1.0, theta=0.0
% INFO    : Bus 14882	: V=1.0068161, theta=-47.553283 -> V=1.0, theta=0.0
% INFO    : Bus 14883	: V=1.0054097, theta=-47.835255 -> V=1.0, theta=0.0
% INFO    : Bus 14884	: V=0.9917707, theta=-49.066403 -> V=1.0, theta=0.0
% INFO    : Bus 14885	: V=1.0042529, theta=-46.927485 -> V=1.0, theta=0.0
% INFO    : Bus 14886	: V=0.9991663, theta=-48.020286 -> V=1.0, theta=0.0
% INFO    : Bus 14887	: V=0.9954257, theta=-48.853504 -> V=1.0, theta=0.0
% INFO    : Bus 14888	: V=0.9772301, theta=-51.308619 -> V=1.0, theta=0.0
% INFO    : Bus 14889	: V=0.9767552, theta=-51.424761 -> V=1.0, theta=0.0
% INFO    : Bus 14890	: V=0.9792449, theta=-51.309295 -> V=1.0, theta=0.0
% INFO    : Bus 14891	: V=0.9802012, theta=-50.648585 -> V=1.0, theta=0.0
% INFO    : Bus 14892	: V=0.9813966, theta=-50.476285 -> V=1.0, theta=0.0
% INFO    : Bus 14893	: V=0.9937925, theta=-49.247127 -> V=1.0, theta=0.0
% INFO    : Bus 14894	: V=0.9906949, theta=-49.710712 -> V=1.0, theta=0.0
% INFO    : Bus 14895	: V=1.0020931, theta=-49.067183 -> V=1.0, theta=0.0
% INFO    : Bus 14896	: V=1.0020161, theta=-49.073393 -> V=1.0, theta=0.0
% INFO    : Bus 14897	: V=0.9969856, theta=-49.419375 -> V=1.0, theta=0.0
% INFO    : Bus 14898	: V=0.9974775, theta=-49.283047 -> V=1.0, theta=0.0
% INFO    : Bus 14899	: V=0.9943884, theta=-49.494804 -> V=1.0, theta=0.0
% INFO    : Bus 14900	: V=0.9863137, theta=-50.891671 -> V=1.0, theta=0.0
% INFO    : Bus 14901	: V=0.9969046, theta=-49.418787 -> V=1.0, theta=0.0
% INFO    : Bus 14902	: V=0.9999673, theta=-48.732005 -> V=1.0, theta=0.0
% INFO    : Bus 14903	: V=1.008918, theta=-47.879789 -> V=1.0, theta=0.0
% INFO    : Bus 14904	: V=1.005081, theta=-47.979621 -> V=1.0, theta=0.0
% INFO    : Bus 14905	: V=1.0111092, theta=-46.894508 -> V=1.0, theta=0.0
% INFO    : Bus 14906	: V=1.001474, theta=-47.944783 -> V=1.0, theta=0.0
% INFO    : Bus 14907	: V=0.9988543, theta=-48.910136 -> V=1.0, theta=0.0
% INFO    : Bus 14908	: V=1.0037903, theta=-49.206082 -> V=1.0, theta=0.0
% INFO    : Bus 14909	: V=0.9916202, theta=-49.663541 -> V=1.0, theta=0.0
% INFO    : Bus 14910	: V=1.015103, theta=-48.521693 -> V=1.0, theta=0.0
% INFO    : Bus 14911	: V=1.0049618, theta=-49.503437 -> V=1.0, theta=0.0
% INFO    : Bus 14912	: V=1.0155757, theta=-48.648065 -> V=1.0, theta=0.0
% INFO    : Bus 14913	: V=1.018683, theta=-48.329604 -> V=1.0, theta=0.0
% INFO    : Bus 14914	: V=1.0148976, theta=-48.948939 -> V=1.0, theta=0.0
% INFO    : Bus 14915	: V=1.0186645, theta=-48.354135 -> V=1.0, theta=0.0
% INFO    : Bus 14916	: V=1.011231, theta=-49.404883 -> V=1.0, theta=0.0
% INFO    : Bus 14917	: V=1.0138825, theta=-48.043402 -> V=1.0, theta=0.0
% INFO    : Bus 14918	: V=1.0105364, theta=-48.017089 -> V=1.0, theta=0.0
% INFO    : Bus 14919	: V=0.9826303, theta=-57.449396 -> V=1.0, theta=0.0
% INFO    : Bus 14920	: V=0.9748508, theta=-57.663095 -> V=1.0, theta=0.0
% INFO    : Bus 14921	: V=0.9760367, theta=-57.631895 -> V=1.0, theta=0.0
% INFO    : Bus 14922	: V=0.9742162, theta=-57.690437 -> V=1.0, theta=0.0
% INFO    : Bus 14923	: V=0.9711661, theta=-57.814318 -> V=1.0, theta=0.0
% INFO    : Bus 14924	: V=0.9734251, theta=-57.742546 -> V=1.0, theta=0.0
% INFO    : Bus 14925	: V=0.9828868, theta=-56.714968 -> V=1.0, theta=0.0
% INFO    : Bus 14926	: V=0.9699832, theta=-57.841311 -> V=1.0, theta=0.0
% INFO    : Bus 14927	: V=0.9737281, theta=-57.734615 -> V=1.0, theta=0.0
% INFO    : Bus 14928	: V=0.971609, theta=-58.033983 -> V=1.0, theta=0.0
% INFO    : Bus 14929	: V=0.9767764, theta=-57.463643 -> V=1.0, theta=0.0
% INFO    : Bus 14930	: V=0.9737207, theta=-57.83506 -> V=1.0, theta=0.0
% INFO    : Bus 14931	: V=0.974816, theta=-57.881382 -> V=1.0, theta=0.0
% INFO    : Bus 14932	: V=0.9847307, theta=-56.929979 -> V=1.0, theta=0.0
% INFO    : Bus 14933	: V=0.9753583, theta=-57.685422 -> V=1.0, theta=0.0
% INFO    : Bus 14934	: V=0.9756106, theta=-57.682122 -> V=1.0, theta=0.0
% INFO    : Bus 14935	: V=0.9977584, theta=-55.2908 -> V=1.0, theta=0.0
% INFO    : Bus 14936	: V=0.9787095, theta=-57.307044 -> V=1.0, theta=0.0
% INFO    : Bus 14937	: V=0.9771603, theta=-57.438904 -> V=1.0, theta=0.0
% INFO    : Bus 14938	: V=0.9776922, theta=-57.399012 -> V=1.0, theta=0.0
% INFO    : Bus 14939	: V=0.9787244, theta=-57.322898 -> V=1.0, theta=0.0
% INFO    : Bus 14940	: V=0.9683983, theta=-58.012613 -> V=1.0, theta=0.0
% INFO    : Bus 14941	: V=0.9631549, theta=-58.184271 -> V=1.0, theta=0.0
% INFO    : Bus 14942	: V=0.974157, theta=-58.546212 -> V=1.0, theta=0.0
% INFO    : Bus 14943	: V=0.9784361, theta=-57.571854 -> V=1.0, theta=0.0
% INFO    : Bus 14944	: V=0.9747763, theta=-58.178097 -> V=1.0, theta=0.0
% INFO    : Bus 14945	: V=0.9823732, theta=-57.154904 -> V=1.0, theta=0.0
% INFO    : Bus 14946	: V=0.9809665, theta=-57.265433 -> V=1.0, theta=0.0
% INFO    : Bus 14947	: V=0.9824219, theta=-57.196357 -> V=1.0, theta=0.0
% INFO    : Bus 14948	: V=0.9879847, theta=-56.588698 -> V=1.0, theta=0.0
% INFO    : Bus 14949	: V=0.9828774, theta=-56.739385 -> V=1.0, theta=0.0
% INFO    : Bus 14950	: V=0.9990811, theta=-55.390659 -> V=1.0, theta=0.0
% INFO    : Bus 14951	: V=0.9810294, theta=-57.079416 -> V=1.0, theta=0.0
% INFO    : Bus 14952	: V=0.9823954, theta=-56.477211 -> V=1.0, theta=0.0
% INFO    : Bus 14953	: V=0.9837543, theta=-56.435565 -> V=1.0, theta=0.0
% INFO    : Bus 14954	: V=0.9862773, theta=-56.149074 -> V=1.0, theta=0.0
% INFO    : Bus 14955	: V=0.9816698, theta=-56.802532 -> V=1.0, theta=0.0
% INFO    : Bus 14956	: V=0.9873959, theta=-56.268007 -> V=1.0, theta=0.0
% INFO    : Bus 14957	: V=0.9867328, theta=-56.486328 -> V=1.0, theta=0.0
% INFO    : Bus 14958	: V=0.9960281, theta=-54.895712 -> V=1.0, theta=0.0
% INFO    : Bus 14959	: V=0.9901739, theta=-55.791934 -> V=1.0, theta=0.0
% INFO    : Bus 14960	: V=0.9849372, theta=-56.497204 -> V=1.0, theta=0.0
% INFO    : Bus 14961	: V=0.9901362, theta=-55.783195 -> V=1.0, theta=0.0
% INFO    : Bus 14962	: V=0.9806998, theta=-57.376534 -> V=1.0, theta=0.0
% INFO    : Bus 14963	: V=0.9816437, theta=-56.910176 -> V=1.0, theta=0.0
% INFO    : Bus 14964	: V=0.9801548, theta=-57.1082 -> V=1.0, theta=0.0
% INFO    : Bus 14965	: V=0.9794798, theta=-58.430078 -> V=1.0, theta=0.0
% INFO    : Bus 14966	: V=0.9858374, theta=-57.401311 -> V=1.0, theta=0.0
% INFO    : Bus 14967	: V=0.9837511, theta=-58.603624 -> V=1.0, theta=0.0
% INFO    : Bus 14968	: V=0.9767513, theta=-58.704947 -> V=1.0, theta=0.0
% INFO    : Bus 14969	: V=0.9827386, theta=-58.704781 -> V=1.0, theta=0.0
% INFO    : Bus 14970	: V=0.9731317, theta=-57.698175 -> V=1.0, theta=0.0
% INFO    : Bus 14971	: V=0.9841144, theta=-58.908895 -> V=1.0, theta=0.0
% INFO    : Bus 14972	: V=0.9827358, theta=-58.803819 -> V=1.0, theta=0.0
% INFO    : Bus 14973	: V=0.9702472, theta=-58.187025 -> V=1.0, theta=0.0
% INFO    : Bus 14974	: V=0.9822071, theta=-57.396587 -> V=1.0, theta=0.0
% INFO    : Bus 14975	: V=0.9970587, theta=-55.380842 -> V=1.0, theta=0.0
% INFO    : Bus 14976	: V=0.9763651, theta=-57.837958 -> V=1.0, theta=0.0
% INFO    : Bus 14977	: V=0.9925116, theta=-55.482769 -> V=1.0, theta=0.0
% INFO    : Bus 14978	: V=0.99038, theta=-55.745885 -> V=1.0, theta=0.0
% INFO    : Bus 14979	: V=0.9828995, theta=-57.156444 -> V=1.0, theta=0.0
% INFO    : Bus 14980	: V=1.0214384, theta=-51.481232 -> V=1.0, theta=0.0
% INFO    : Bus 14981	: V=1.0210404, theta=-51.641492 -> V=1.0, theta=0.0
% INFO    : Bus 14982	: V=1.0202377, theta=-52.014753 -> V=1.0, theta=0.0
% INFO    : Bus 14983	: V=1.0201843, theta=-51.470488 -> V=1.0, theta=0.0
% INFO    : Bus 14984	: V=1.0209709, theta=-51.509987 -> V=1.0, theta=0.0
% INFO    : Bus 14985	: V=1.0207703, theta=-50.958099 -> V=1.0, theta=0.0
% INFO    : Bus 14986	: V=1.0203886, theta=-50.38834 -> V=1.0, theta=0.0
% INFO    : Bus 14987	: V=0.9903299, theta=-57.39562 -> V=1.0, theta=0.0
% INFO    : Bus 14988	: V=0.9882741, theta=-57.537665 -> V=1.0, theta=0.0
% INFO    : Bus 14989	: V=0.9798955, theta=-58.053908 -> V=1.0, theta=0.0
% INFO    : Bus 14990	: V=0.9846792, theta=-57.922132 -> V=1.0, theta=0.0
% INFO    : Bus 14991	: V=0.9887874, theta=-57.501071 -> V=1.0, theta=0.0
% INFO    : Bus 14992	: V=0.9846337, theta=-57.884742 -> V=1.0, theta=0.0
% INFO    : Bus 14993	: V=0.9854835, theta=-57.748996 -> V=1.0, theta=0.0
% INFO    : Bus 14994	: V=0.9884122, theta=-57.502567 -> V=1.0, theta=0.0
% INFO    : Bus 14995	: V=0.9877198, theta=-57.575335 -> V=1.0, theta=0.0
% INFO    : Bus 14996	: V=0.9906405, theta=-57.21797 -> V=1.0, theta=0.0
% INFO    : Bus 14997	: V=1.0058199, theta=-55.717712 -> V=1.0, theta=0.0
% INFO    : Bus 14998	: V=0.989894, theta=-57.209437 -> V=1.0, theta=0.0
% INFO    : Bus 14999	: V=0.9913451, theta=-57.128635 -> V=1.0, theta=0.0
% INFO    : Bus 15000	: V=1.0088687, theta=-54.96858 -> V=1.0, theta=0.0
% INFO    : Bus 15001	: V=1.0079096, theta=-55.546866 -> V=1.0, theta=0.0
% INFO    : Bus 15002	: V=0.993612, theta=-57.140602 -> V=1.0, theta=0.0
% INFO    : Bus 15003	: V=0.9940041, theta=-57.055406 -> V=1.0, theta=0.0
% INFO    : Bus 15004	: V=0.9936497, theta=-57.128242 -> V=1.0, theta=0.0
% INFO    : Bus 15005	: V=0.988931, theta=-57.786306 -> V=1.0, theta=0.0
% INFO    : Bus 15006	: V=0.9905006, theta=-57.517224 -> V=1.0, theta=0.0
% INFO    : Bus 15007	: V=0.9960675, theta=-56.99195 -> V=1.0, theta=0.0
% INFO    : Bus 15008	: V=0.9913332, theta=-57.476771 -> V=1.0, theta=0.0
% INFO    : Bus 15009	: V=0.9867846, theta=-57.981259 -> V=1.0, theta=0.0
% INFO    : Bus 15010	: V=0.9928726, theta=-57.349874 -> V=1.0, theta=0.0
% INFO    : Bus 15011	: V=0.9937423, theta=-57.25088 -> V=1.0, theta=0.0
% INFO    : Bus 15012	: V=0.9844875, theta=-57.881184 -> V=1.0, theta=0.0
% INFO    : Bus 15013	: V=0.9762369, theta=-58.483475 -> V=1.0, theta=0.0
% INFO    : Bus 15014	: V=0.9839903, theta=-58.201334 -> V=1.0, theta=0.0
% INFO    : Bus 15015	: V=0.9776674, theta=-58.618613 -> V=1.0, theta=0.0
% INFO    : Bus 15016	: V=0.9768212, theta=-58.64537 -> V=1.0, theta=0.0
% INFO    : Bus 15017	: V=0.9760982, theta=-58.641351 -> V=1.0, theta=0.0
% INFO    : Bus 15018	: V=0.9767869, theta=-58.633394 -> V=1.0, theta=0.0
% INFO    : Bus 15019	: V=0.9785358, theta=-58.328254 -> V=1.0, theta=0.0
% INFO    : Bus 15020	: V=0.9803309, theta=-58.185653 -> V=1.0, theta=0.0
% INFO    : Bus 15021	: V=0.9828752, theta=-57.975838 -> V=1.0, theta=0.0
% INFO    : Bus 15022	: V=0.9800626, theta=-58.194269 -> V=1.0, theta=0.0
% INFO    : Bus 15023	: V=0.9738809, theta=-58.59905 -> V=1.0, theta=0.0
% INFO    : Bus 15024	: V=0.9820299, theta=-58.060121 -> V=1.0, theta=0.0
% INFO    : Bus 15025	: V=0.9788647, theta=-58.435302 -> V=1.0, theta=0.0
% INFO    : Bus 15026	: V=0.9726173, theta=-58.612224 -> V=1.0, theta=0.0
% INFO    : Bus 15027	: V=0.989577, theta=-57.522562 -> V=1.0, theta=0.0
% INFO    : Bus 15028	: V=0.9808769, theta=-58.120242 -> V=1.0, theta=0.0
% INFO    : Bus 15029	: V=0.9786319, theta=-58.477906 -> V=1.0, theta=0.0
% INFO    : Bus 15030	: V=0.9812793, theta=-58.103495 -> V=1.0, theta=0.0
% INFO    : Bus 15031	: V=0.9774184, theta=-58.529608 -> V=1.0, theta=0.0
% INFO    : Bus 15032	: V=0.978613, theta=-59.260049 -> V=1.0, theta=0.0
% INFO    : Bus 15033	: V=0.9844918, theta=-58.502181 -> V=1.0, theta=0.0
% INFO    : Bus 15034	: V=0.975722, theta=-58.69518 -> V=1.0, theta=0.0
% INFO    : Bus 15035	: V=0.97651, theta=-58.615634 -> V=1.0, theta=0.0
% INFO    : Bus 15036	: V=0.9925064, theta=-57.677887 -> V=1.0, theta=0.0
% INFO    : Bus 15037	: V=0.9935245, theta=-57.299313 -> V=1.0, theta=0.0
% INFO    : Bus 15038	: V=0.9903396, theta=-57.684023 -> V=1.0, theta=0.0
% INFO    : Bus 15039	: V=0.9927388, theta=-57.407092 -> V=1.0, theta=0.0
% INFO    : Bus 15040	: V=0.987962, theta=-57.918878 -> V=1.0, theta=0.0
% INFO    : Bus 15041	: V=0.9923272, theta=-57.417695 -> V=1.0, theta=0.0
% INFO    : Bus 15042	: V=0.9939835, theta=-57.331341 -> V=1.0, theta=0.0
% INFO    : Bus 15043	: V=0.9951089, theta=-56.902229 -> V=1.0, theta=0.0
% INFO    : Bus 15044	: V=0.9536901, theta=-58.962078 -> V=1.0, theta=0.0
% INFO    : Bus 15045	: V=0.954174, theta=-58.902655 -> V=1.0, theta=0.0
% INFO    : Bus 15046	: V=0.9524868, theta=-59.127491 -> V=1.0, theta=0.0
% INFO    : Bus 15047	: V=0.9515171, theta=-59.138898 -> V=1.0, theta=0.0
% INFO    : Bus 15048	: V=0.9530322, theta=-59.05298 -> V=1.0, theta=0.0
% INFO    : Bus 15049	: V=0.9688333, theta=-57.138678 -> V=1.0, theta=0.0
% INFO    : Bus 15050	: V=0.9681277, theta=-56.892781 -> V=1.0, theta=0.0
% INFO    : Bus 15051	: V=0.9680777, theta=-57.065745 -> V=1.0, theta=0.0
% INFO    : Bus 15052	: V=0.95538, theta=-58.674336 -> V=1.0, theta=0.0
% INFO    : Bus 15053	: V=0.9564051, theta=-58.505419 -> V=1.0, theta=0.0
% INFO    : Bus 15054	: V=0.9558288, theta=-58.615933 -> V=1.0, theta=0.0
% INFO    : Bus 15055	: V=0.9567546, theta=-58.574953 -> V=1.0, theta=0.0
% INFO    : Bus 15056	: V=0.9495149, theta=-59.330266 -> V=1.0, theta=0.0
% INFO    : Bus 15057	: V=0.9501782, theta=-59.379532 -> V=1.0, theta=0.0
% INFO    : Bus 15058	: V=0.9509347, theta=-59.376305 -> V=1.0, theta=0.0
% INFO    : Bus 15059	: V=0.9559005, theta=-58.633998 -> V=1.0, theta=0.0
% INFO    : Bus 15060	: V=0.9521548, theta=-59.416997 -> V=1.0, theta=0.0
% INFO    : Bus 15061	: V=0.9568824, theta=-58.575386 -> V=1.0, theta=0.0
% INFO    : Bus 15062	: V=0.9566885, theta=-58.632262 -> V=1.0, theta=0.0
% INFO    : Bus 15063	: V=0.9522081, theta=-59.392108 -> V=1.0, theta=0.0
% INFO    : Bus 15064	: V=0.9593287, theta=-58.425176 -> V=1.0, theta=0.0
% INFO    : Bus 15065	: V=0.9645555, theta=-58.096571 -> V=1.0, theta=0.0
% INFO    : Bus 15066	: V=0.9521892, theta=-59.451375 -> V=1.0, theta=0.0
% INFO    : Bus 15067	: V=0.9729253, theta=-57.567285 -> V=1.0, theta=0.0
% INFO    : Bus 15068	: V=0.9655859, theta=-57.610226 -> V=1.0, theta=0.0
% INFO    : Bus 15069	: V=0.9530142, theta=-57.956825 -> V=1.0, theta=0.0
% INFO    : Bus 15070	: V=0.953593, theta=-57.859477 -> V=1.0, theta=0.0
% INFO    : Bus 15071	: V=0.9484923, theta=-58.670861 -> V=1.0, theta=0.0
% INFO    : Bus 15072	: V=0.947406, theta=-59.270761 -> V=1.0, theta=0.0
% INFO    : Bus 15073	: V=0.9487995, theta=-59.233632 -> V=1.0, theta=0.0
% INFO    : Bus 15074	: V=0.9519934, theta=-58.293502 -> V=1.0, theta=0.0
% INFO    : Bus 15075	: V=0.9515998, theta=-58.34802 -> V=1.0, theta=0.0
% INFO    : Bus 15076	: V=0.9527311, theta=-58.130804 -> V=1.0, theta=0.0
% INFO    : Bus 15077	: V=0.9525282, theta=-58.217636 -> V=1.0, theta=0.0
% INFO    : Bus 15078	: V=0.9490234, theta=-58.903127 -> V=1.0, theta=0.0
% INFO    : Bus 15079	: V=0.9486382, theta=-59.070782 -> V=1.0, theta=0.0
% INFO    : Bus 15080	: V=0.9504951, theta=-59.206474 -> V=1.0, theta=0.0
% INFO    : Bus 15081	: V=0.9494351, theta=-59.205489 -> V=1.0, theta=0.0
% INFO    : Bus 15082	: V=0.9516573, theta=-59.154141 -> V=1.0, theta=0.0
% INFO    : Bus 15083	: V=0.9521861, theta=-59.146148 -> V=1.0, theta=0.0
% INFO    : Bus 15084	: V=0.9512345, theta=-59.191622 -> V=1.0, theta=0.0
% INFO    : Bus 15085	: V=0.952327, theta=-58.959168 -> V=1.0, theta=0.0
% INFO    : Bus 15086	: V=0.9521786, theta=-59.074946 -> V=1.0, theta=0.0
% INFO    : Bus 15087	: V=0.9525511, theta=-58.963337 -> V=1.0, theta=0.0
% INFO    : Bus 15088	: V=0.9526534, theta=-59.10607 -> V=1.0, theta=0.0
% INFO    : Bus 15089	: V=0.972353, theta=-56.026134 -> V=1.0, theta=0.0
% INFO    : Bus 15090	: V=0.9528846, theta=-58.769857 -> V=1.0, theta=0.0
% INFO    : Bus 15091	: V=0.9525005, theta=-58.878841 -> V=1.0, theta=0.0
% INFO    : Bus 15092	: V=0.9604986, theta=-56.957348 -> V=1.0, theta=0.0
% INFO    : Bus 15093	: V=0.9540961, theta=-58.37142 -> V=1.0, theta=0.0
% INFO    : Bus 15094	: V=0.9736548, theta=-55.847303 -> V=1.0, theta=0.0
% INFO    : Bus 15095	: V=0.9643637, theta=-56.697271 -> V=1.0, theta=0.0
% INFO    : Bus 15096	: V=0.9629342, theta=-57.065904 -> V=1.0, theta=0.0
% INFO    : Bus 15097	: V=0.9638118, theta=-56.651084 -> V=1.0, theta=0.0
% INFO    : Bus 15098	: V=0.9640366, theta=-56.681421 -> V=1.0, theta=0.0
% INFO    : Bus 15099	: V=0.982431, theta=-55.642001 -> V=1.0, theta=0.0
% INFO    : Bus 15100	: V=0.9801032, theta=-56.234028 -> V=1.0, theta=0.0
% INFO    : Bus 15101	: V=0.9793359, theta=-54.830879 -> V=1.0, theta=0.0
% INFO    : Bus 15102	: V=0.9819218, theta=-55.737775 -> V=1.0, theta=0.0
% INFO    : Bus 15103	: V=0.9835183, theta=-55.359358 -> V=1.0, theta=0.0
% INFO    : Bus 15104	: V=0.9643012, theta=-56.849001 -> V=1.0, theta=0.0
% INFO    : Bus 15105	: V=0.9683614, theta=-56.940139 -> V=1.0, theta=0.0
% INFO    : Bus 15106	: V=0.9661797, theta=-56.768188 -> V=1.0, theta=0.0
% INFO    : Bus 15107	: V=0.9722336, theta=-56.314288 -> V=1.0, theta=0.0
% INFO    : Bus 15108	: V=0.9785921, theta=-56.632129 -> V=1.0, theta=0.0
% INFO    : Bus 15109	: V=0.969261, theta=-56.793488 -> V=1.0, theta=0.0
% INFO    : Bus 15110	: V=0.970561, theta=-56.900663 -> V=1.0, theta=0.0
% INFO    : Bus 15111	: V=0.9713529, theta=-56.889142 -> V=1.0, theta=0.0
% INFO    : Bus 15112	: V=0.9759415, theta=-56.737496 -> V=1.0, theta=0.0
% INFO    : Bus 15113	: V=0.9716822, theta=-56.431829 -> V=1.0, theta=0.0
% INFO    : Bus 15114	: V=0.9767916, theta=-55.844584 -> V=1.0, theta=0.0
% INFO    : Bus 15115	: V=0.9759717, theta=-56.042996 -> V=1.0, theta=0.0
% INFO    : Bus 15116	: V=0.9763145, theta=-55.895669 -> V=1.0, theta=0.0
% INFO    : Bus 15117	: V=0.9813444, theta=-55.144114 -> V=1.0, theta=0.0
% INFO    : Bus 15118	: V=0.9792822, theta=-55.896107 -> V=1.0, theta=0.0
% INFO    : Bus 15119	: V=0.9806034, theta=-55.812407 -> V=1.0, theta=0.0
% INFO    : Bus 15120	: V=0.9933994, theta=-54.481829 -> V=1.0, theta=0.0
% INFO    : Bus 15121	: V=0.9804383, theta=-55.638589 -> V=1.0, theta=0.0
% INFO    : Bus 15122	: V=0.9714239, theta=-55.881352 -> V=1.0, theta=0.0
% INFO    : Bus 15123	: V=0.9656406, theta=-56.047331 -> V=1.0, theta=0.0
% INFO    : Bus 15124	: V=0.9642256, theta=-56.073082 -> V=1.0, theta=0.0
% INFO    : Bus 15125	: V=0.9580379, theta=-56.486459 -> V=1.0, theta=0.0
% INFO    : Bus 15126	: V=0.9745356, theta=-55.83122 -> V=1.0, theta=0.0
% INFO    : Bus 15127	: V=0.9781604, theta=-55.575723 -> V=1.0, theta=0.0
% INFO    : Bus 15128	: V=0.9755788, theta=-55.762538 -> V=1.0, theta=0.0
% INFO    : Bus 15129	: V=0.9751332, theta=-55.828765 -> V=1.0, theta=0.0
% INFO    : Bus 15130	: V=0.9673213, theta=-56.017814 -> V=1.0, theta=0.0
% INFO    : Bus 15131	: V=0.965433, theta=-56.343688 -> V=1.0, theta=0.0
% INFO    : Bus 15132	: V=0.9824827, theta=-54.508326 -> V=1.0, theta=0.0
% INFO    : Bus 15133	: V=0.9755067, theta=-55.778018 -> V=1.0, theta=0.0
% INFO    : Bus 15134	: V=0.9572113, theta=-57.279394 -> V=1.0, theta=0.0
% INFO    : Bus 15135	: V=0.9593318, theta=-57.142477 -> V=1.0, theta=0.0
% INFO    : Bus 15136	: V=0.977241, theta=-55.58551 -> V=1.0, theta=0.0
% INFO    : Bus 15137	: V=0.9736131, theta=-56.111605 -> V=1.0, theta=0.0
% INFO    : Bus 15138	: V=0.9651051, theta=-56.791224 -> V=1.0, theta=0.0
% INFO    : Bus 15139	: V=0.9824145, theta=-54.516218 -> V=1.0, theta=0.0
% INFO    : Bus 15140	: V=0.9598606, theta=-56.976524 -> V=1.0, theta=0.0
% INFO    : Bus 15141	: V=0.9830223, theta=-54.551567 -> V=1.0, theta=0.0
% INFO    : Bus 15142	: V=0.96487, theta=-56.78078 -> V=1.0, theta=0.0
% INFO    : Bus 15143	: V=0.9769458, theta=-55.648847 -> V=1.0, theta=0.0
% INFO    : Bus 15144	: V=0.984196, theta=-54.585609 -> V=1.0, theta=0.0
% INFO    : Bus 15145	: V=0.9834171, theta=-54.576064 -> V=1.0, theta=0.0
% INFO    : Bus 15146	: V=0.9764601, theta=-55.592478 -> V=1.0, theta=0.0
% INFO    : Bus 15147	: V=0.9694906, theta=-56.558437 -> V=1.0, theta=0.0
% INFO    : Bus 15148	: V=0.9676857, theta=-56.670748 -> V=1.0, theta=0.0
% INFO    : Bus 15149	: V=0.9745475, theta=-55.990668 -> V=1.0, theta=0.0
% INFO    : Bus 15150	: V=0.9742761, theta=-56.085543 -> V=1.0, theta=0.0
% INFO    : Bus 15151	: V=0.9754433, theta=-55.85609 -> V=1.0, theta=0.0
% INFO    : Bus 15152	: V=0.9695443, theta=-56.012984 -> V=1.0, theta=0.0
% INFO    : Bus 15153	: V=0.9685894, theta=-56.053134 -> V=1.0, theta=0.0
% INFO    : Bus 15154	: V=0.9759579, theta=-55.87083 -> V=1.0, theta=0.0
% INFO    : Bus 15155	: V=0.975662, theta=-55.895482 -> V=1.0, theta=0.0
% INFO    : Bus 15156	: V=0.9703219, theta=-56.241397 -> V=1.0, theta=0.0
% INFO    : Bus 15157	: V=0.9744796, theta=-55.800612 -> V=1.0, theta=0.0
% INFO    : Bus 15158	: V=0.9740513, theta=-55.827686 -> V=1.0, theta=0.0
% INFO    : Bus 15159	: V=0.9730443, theta=-55.854882 -> V=1.0, theta=0.0
% INFO    : Bus 15160	: V=0.972521, theta=-55.866476 -> V=1.0, theta=0.0
% INFO    : Bus 15161	: V=0.9710896, theta=-55.937529 -> V=1.0, theta=0.0
% INFO    : Bus 15162	: V=0.974229, theta=-55.772991 -> V=1.0, theta=0.0
% INFO    : Bus 15163	: V=0.9756099, theta=-55.983242 -> V=1.0, theta=0.0
% INFO    : Bus 15164	: V=0.975583, theta=-55.902368 -> V=1.0, theta=0.0
% INFO    : Bus 15165	: V=0.9698517, theta=-56.602307 -> V=1.0, theta=0.0
% INFO    : Bus 15166	: V=0.9751637, theta=-56.040074 -> V=1.0, theta=0.0
% INFO    : Bus 15167	: V=0.9697862, theta=-56.632609 -> V=1.0, theta=0.0
% INFO    : Bus 15168	: V=0.9646441, theta=-56.219423 -> V=1.0, theta=0.0
% INFO    : Bus 15169	: V=0.9528978, theta=-57.306391 -> V=1.0, theta=0.0
% INFO    : Bus 15170	: V=0.9814847, theta=-54.29248 -> V=1.0, theta=0.0
% INFO    : Bus 15171	: V=0.9811071, theta=-54.149253 -> V=1.0, theta=0.0
% INFO    : Bus 15172	: V=0.9810132, theta=-54.095312 -> V=1.0, theta=0.0
% INFO    : Bus 15173	: V=0.9557812, theta=-57.077978 -> V=1.0, theta=0.0
% INFO    : Bus 15174	: V=0.9525213, theta=-57.122329 -> V=1.0, theta=0.0
% INFO    : Bus 15175	: V=0.9583281, theta=-56.964722 -> V=1.0, theta=0.0
% INFO    : Bus 15176	: V=0.9530706, theta=-57.167676 -> V=1.0, theta=0.0
% INFO    : Bus 15177	: V=0.9514741, theta=-57.346034 -> V=1.0, theta=0.0
% INFO    : Bus 15178	: V=0.9598592, theta=-56.936301 -> V=1.0, theta=0.0
% INFO    : Bus 15179	: V=0.9812975, theta=-54.22106 -> V=1.0, theta=0.0
% INFO    : Bus 15180	: V=0.9811947, theta=-54.181632 -> V=1.0, theta=0.0
% INFO    : Bus 15181	: V=0.9628753, theta=-55.883165 -> V=1.0, theta=0.0
% INFO    : Bus 15182	: V=0.9642766, theta=-55.759514 -> V=1.0, theta=0.0
% INFO    : Bus 15183	: V=0.966609, theta=-55.615297 -> V=1.0, theta=0.0
% INFO    : Bus 15184	: V=0.9614648, theta=-55.916055 -> V=1.0, theta=0.0
% INFO    : Bus 15185	: V=0.9513543, theta=-57.135155 -> V=1.0, theta=0.0
% INFO    : Bus 15186	: V=0.9817601, theta=-54.401786 -> V=1.0, theta=0.0
% INFO    : Bus 15187	: V=0.9643194, theta=-56.316995 -> V=1.0, theta=0.0
% INFO    : Bus 15188	: V=0.9803894, theta=-53.988901 -> V=1.0, theta=0.0
% INFO    : Bus 15189	: V=0.9508696, theta=-56.974244 -> V=1.0, theta=0.0
% INFO    : Bus 15190	: V=0.9801999, theta=-53.954794 -> V=1.0, theta=0.0
% INFO    : Bus 15191	: V=0.9806299, theta=-54.034292 -> V=1.0, theta=0.0
% INFO    : Bus 15192	: V=0.9809338, theta=-54.049291 -> V=1.0, theta=0.0
% INFO    : Bus 15193	: V=0.967759, theta=-55.565696 -> V=1.0, theta=0.0
% INFO    : Bus 15194	: V=0.9616769, theta=-55.997848 -> V=1.0, theta=0.0
% INFO    : Bus 15195	: V=0.962825, theta=-56.045153 -> V=1.0, theta=0.0
% INFO    : Bus 15196	: V=0.9502694, theta=-57.572078 -> V=1.0, theta=0.0
% INFO    : Bus 15197	: V=0.9525872, theta=-57.796855 -> V=1.0, theta=0.0
% INFO    : Bus 15198	: V=0.9544555, theta=-57.506092 -> V=1.0, theta=0.0
% INFO    : Bus 15199	: V=0.9612322, theta=-56.623353 -> V=1.0, theta=0.0
% INFO    : Bus 15200	: V=0.9565014, theta=-56.87548 -> V=1.0, theta=0.0
% INFO    : Bus 15201	: V=0.9589071, theta=-56.842282 -> V=1.0, theta=0.0
% INFO    : Bus 15202	: V=0.9539084, theta=-57.50485 -> V=1.0, theta=0.0
% INFO    : Bus 15203	: V=0.9576497, theta=-56.865652 -> V=1.0, theta=0.0
% INFO    : Bus 15204	: V=0.9574594, theta=-57.080218 -> V=1.0, theta=0.0
% INFO    : Bus 15205	: V=0.9554066, theta=-57.449113 -> V=1.0, theta=0.0
% INFO    : Bus 15206	: V=0.9507674, theta=-58.127539 -> V=1.0, theta=0.0
% INFO    : Bus 15207	: V=0.9510527, theta=-57.732155 -> V=1.0, theta=0.0
% INFO    : Bus 15208	: V=0.9546406, theta=-57.527375 -> V=1.0, theta=0.0
% INFO    : Bus 15209	: V=0.9555174, theta=-57.215928 -> V=1.0, theta=0.0
% INFO    : Bus 15210	: V=0.9598848, theta=-56.740509 -> V=1.0, theta=0.0
% INFO    : Bus 15211	: V=0.9560273, theta=-57.177679 -> V=1.0, theta=0.0
% INFO    : Bus 15212	: V=0.9540361, theta=-57.371189 -> V=1.0, theta=0.0
% INFO    : Bus 15213	: V=0.9586448, theta=-56.66211 -> V=1.0, theta=0.0
% INFO    : Bus 15214	: V=0.9586659, theta=-56.613851 -> V=1.0, theta=0.0
% INFO    : Bus 15215	: V=0.9587488, theta=-56.549321 -> V=1.0, theta=0.0
% INFO    : Bus 15216	: V=0.9591221, theta=-56.426984 -> V=1.0, theta=0.0
% INFO    : Bus 15217	: V=0.9587452, theta=-56.69097 -> V=1.0, theta=0.0
% INFO    : Bus 15218	: V=0.9589076, theta=-56.717607 -> V=1.0, theta=0.0
% INFO    : Bus 15219	: V=0.9572872, theta=-56.798017 -> V=1.0, theta=0.0
% INFO    : Bus 15220	: V=0.9596704, theta=-56.193624 -> V=1.0, theta=0.0
% INFO    : Bus 15221	: V=0.9575904, theta=-56.765824 -> V=1.0, theta=0.0
% INFO    : Bus 15222	: V=0.9512646, theta=-57.627181 -> V=1.0, theta=0.0
% INFO    : Bus 15223	: V=0.9555489, theta=-56.876648 -> V=1.0, theta=0.0
% INFO    : Bus 15224	: V=0.9598835, theta=-56.249322 -> V=1.0, theta=0.0
% INFO    : Bus 15225	: V=0.9563542, theta=-56.538991 -> V=1.0, theta=0.0
% INFO    : Bus 15226	: V=0.9559343, theta=-56.559956 -> V=1.0, theta=0.0
% INFO    : Bus 15227	: V=0.9519591, theta=-56.567945 -> V=1.0, theta=0.0
% INFO    : Bus 15228	: V=0.9600659, theta=-55.851602 -> V=1.0, theta=0.0
% INFO    : Bus 15229	: V=0.9548264, theta=-56.550003 -> V=1.0, theta=0.0
% INFO    : Bus 15230	: V=0.9588592, theta=-55.726002 -> V=1.0, theta=0.0
% INFO    : Bus 15231	: V=0.9596076, theta=-55.777766 -> V=1.0, theta=0.0
% INFO    : Bus 15232	: V=0.9600457, theta=-55.857221 -> V=1.0, theta=0.0
% INFO    : Bus 15233	: V=0.9600693, theta=-55.860366 -> V=1.0, theta=0.0
% INFO    : Bus 15234	: V=0.9555648, theta=-56.585402 -> V=1.0, theta=0.0
% INFO    : Bus 15235	: V=0.9597547, theta=-56.126765 -> V=1.0, theta=0.0
% INFO    : Bus 15236	: V=0.9556366, theta=-56.573412 -> V=1.0, theta=0.0
% INFO    : Bus 15237	: V=0.9554832, theta=-56.56563 -> V=1.0, theta=0.0
% INFO    : Bus 15238	: V=0.9600023, theta=-55.995581 -> V=1.0, theta=0.0
% INFO    : Bus 15239	: V=0.955636, theta=-56.525461 -> V=1.0, theta=0.0
% INFO    : Bus 15240	: V=0.9604911, theta=-55.801751 -> V=1.0, theta=0.0
% INFO    : Bus 15241	: V=0.9801107, theta=-53.554862 -> V=1.0, theta=0.0
% INFO    : Bus 15242	: V=0.9564696, theta=-56.500704 -> V=1.0, theta=0.0
% INFO    : Bus 15243	: V=0.9559613, theta=-56.523077 -> V=1.0, theta=0.0
% INFO    : Bus 15244	: V=0.9601526, theta=-55.884816 -> V=1.0, theta=0.0
% INFO    : Bus 15245	: V=0.9601133, theta=-55.909204 -> V=1.0, theta=0.0
% INFO    : Bus 15246	: V=0.9603609, theta=-55.905296 -> V=1.0, theta=0.0
% INFO    : Bus 15247	: V=0.9557449, theta=-56.618135 -> V=1.0, theta=0.0
% INFO    : Bus 15248	: V=0.9512489, theta=-56.888736 -> V=1.0, theta=0.0
% INFO    : Bus 15249	: V=0.9548254, theta=-56.723525 -> V=1.0, theta=0.0
% INFO    : Bus 15250	: V=0.948986, theta=-57.620578 -> V=1.0, theta=0.0
% INFO    : Bus 15251	: V=0.9522367, theta=-57.304229 -> V=1.0, theta=0.0
% INFO    : Bus 15252	: V=0.9662589, theta=-55.114528 -> V=1.0, theta=0.0
% INFO    : Bus 15253	: V=0.9525324, theta=-57.130374 -> V=1.0, theta=0.0
% INFO    : Bus 15254	: V=0.9518579, theta=-57.031939 -> V=1.0, theta=0.0
% INFO    : Bus 15255	: V=0.9521318, theta=-56.800329 -> V=1.0, theta=0.0
% INFO    : Bus 15256	: V=0.9515139, theta=-57.414885 -> V=1.0, theta=0.0
% INFO    : Bus 15257	: V=0.9545484, theta=-56.84793 -> V=1.0, theta=0.0
% INFO    : Bus 15258	: V=0.9490759, theta=-57.536463 -> V=1.0, theta=0.0
% INFO    : Bus 15259	: V=0.9508374, theta=-57.439412 -> V=1.0, theta=0.0
% INFO    : Bus 15260	: V=0.9547489, theta=-56.835453 -> V=1.0, theta=0.0
% INFO    : Bus 15261	: V=0.9504588, theta=-57.552412 -> V=1.0, theta=0.0
% INFO    : Bus 15262	: V=0.9505116, theta=-57.547239 -> V=1.0, theta=0.0
% INFO    : Bus 15263	: V=0.955112, theta=-56.856176 -> V=1.0, theta=0.0
% INFO    : Bus 15264	: V=0.9496016, theta=-57.561517 -> V=1.0, theta=0.0
% INFO    : Bus 15265	: V=0.9554437, theta=-56.621971 -> V=1.0, theta=0.0
% INFO    : Bus 15266	: V=0.9530738, theta=-57.202854 -> V=1.0, theta=0.0
% INFO    : Bus 15267	: V=0.9610589, theta=-56.037871 -> V=1.0, theta=0.0
% INFO    : Bus 15268	: V=0.9602273, theta=-56.110341 -> V=1.0, theta=0.0
% INFO    : Bus 15269	: V=0.9596873, theta=-56.14517 -> V=1.0, theta=0.0
% INFO    : Bus 15270	: V=0.9517298, theta=-57.151804 -> V=1.0, theta=0.0
% INFO    : Bus 15271	: V=0.96201, theta=-55.958596 -> V=1.0, theta=0.0
% INFO    : Bus 15272	: V=0.9526748, theta=-56.986104 -> V=1.0, theta=0.0
% INFO    : Bus 15273	: V=0.9523263, theta=-57.005922 -> V=1.0, theta=0.0
% INFO    : Bus 15274	: V=0.9578315, theta=-56.10859 -> V=1.0, theta=0.0
% INFO    : Bus 15275	: V=0.9521259, theta=-57.149154 -> V=1.0, theta=0.0
% INFO    : Bus 15276	: V=0.9521486, theta=-57.126065 -> V=1.0, theta=0.0
% INFO    : Bus 15277	: V=0.9574443, theta=-56.145583 -> V=1.0, theta=0.0
% INFO    : Bus 15278	: V=0.9517654, theta=-56.887287 -> V=1.0, theta=0.0
% INFO    : Bus 15279	: V=0.9582831, theta=-56.027893 -> V=1.0, theta=0.0
% INFO    : Bus 15280	: V=0.9586399, theta=-56.000549 -> V=1.0, theta=0.0
% INFO    : Bus 15281	: V=0.9527451, theta=-56.857002 -> V=1.0, theta=0.0
% INFO    : Bus 15282	: V=0.9583263, theta=-56.062072 -> V=1.0, theta=0.0
% INFO    : Bus 15283	: V=0.951992, theta=-56.954737 -> V=1.0, theta=0.0
% INFO    : Bus 15284	: V=0.9655082, theta=-55.60547 -> V=1.0, theta=0.0
% INFO    : Bus 15285	: V=0.9637343, theta=-55.684973 -> V=1.0, theta=0.0
% INFO    : Bus 15286	: V=0.9624818, theta=-55.741426 -> V=1.0, theta=0.0
% INFO    : Bus 15287	: V=0.9514005, theta=-56.955695 -> V=1.0, theta=0.0
% INFO    : Bus 15288	: V=0.9505162, theta=-56.968013 -> V=1.0, theta=0.0
% INFO    : Bus 15289	: V=0.9516416, theta=-56.90495 -> V=1.0, theta=0.0
% INFO    : Bus 15290	: V=0.9583524, theta=-55.907944 -> V=1.0, theta=0.0
% INFO    : Bus 15291	: V=0.9488967, theta=-56.986762 -> V=1.0, theta=0.0
% INFO    : Bus 15292	: V=0.9504832, theta=-56.791675 -> V=1.0, theta=0.0
% INFO    : Bus 15293	: V=0.9601518, theta=-55.866721 -> V=1.0, theta=0.0
% INFO    : Bus 15294	: V=0.9602478, theta=-55.862043 -> V=1.0, theta=0.0
% INFO    : Bus 15295	: V=0.9605587, theta=-55.844916 -> V=1.0, theta=0.0
% INFO    : Bus 15296	: V=0.9801104, theta=-53.741228 -> V=1.0, theta=0.0
% INFO    : Bus 15297	: V=0.9605504, theta=-55.853738 -> V=1.0, theta=0.0
% INFO    : Bus 15298	: V=0.951192, theta=-56.807944 -> V=1.0, theta=0.0
% INFO    : Bus 15299	: V=0.9490962, theta=-56.863791 -> V=1.0, theta=0.0
% INFO    : Bus 15300	: V=0.9508392, theta=-56.785689 -> V=1.0, theta=0.0
% INFO    : Bus 15301	: V=0.9460711, theta=-57.063753 -> V=1.0, theta=0.0
% INFO    : Bus 15302	: V=0.9503797, theta=-56.796711 -> V=1.0, theta=0.0
% INFO    : Bus 15303	: V=0.9462052, theta=-57.046869 -> V=1.0, theta=0.0
% INFO    : Bus 15304	: V=0.9464238, theta=-57.053446 -> V=1.0, theta=0.0
% INFO    : Bus 15305	: V=0.9496641, theta=-56.808675 -> V=1.0, theta=0.0
% INFO    : Bus 15306	: V=0.9453333, theta=-57.084466 -> V=1.0, theta=0.0
% INFO    : Bus 15307	: V=0.9544103, theta=-56.023419 -> V=1.0, theta=0.0
% INFO    : Bus 15308	: V=0.9504778, theta=-56.959945 -> V=1.0, theta=0.0
% INFO    : Bus 15309	: V=0.9499615, theta=-56.716237 -> V=1.0, theta=0.0
% INFO    : Bus 15310	: V=0.9502095, theta=-56.813721 -> V=1.0, theta=0.0
% INFO    : Bus 15311	: V=0.9593173, theta=-55.951545 -> V=1.0, theta=0.0
% INFO    : Bus 15312	: V=0.9601204, theta=-55.981208 -> V=1.0, theta=0.0
% INFO    : Bus 15313	: V=0.957891, theta=-55.897099 -> V=1.0, theta=0.0
% INFO    : Bus 15314	: V=0.9583968, theta=-55.934337 -> V=1.0, theta=0.0
% INFO    : Bus 15315	: V=0.9509044, theta=-57.063594 -> V=1.0, theta=0.0
% INFO    : Bus 15316	: V=0.9520672, theta=-57.059343 -> V=1.0, theta=0.0
% INFO    : Bus 15317	: V=0.9516155, theta=-56.973035 -> V=1.0, theta=0.0
% INFO    : Bus 15318	: V=0.9499921, theta=-57.022898 -> V=1.0, theta=0.0
% INFO    : Bus 15319	: V=0.963689, theta=-56.611309 -> V=1.0, theta=0.0
% INFO    : Bus 15320	: V=0.9679932, theta=-56.172699 -> V=1.0, theta=0.0
% INFO    : Bus 15321	: V=0.9613483, theta=-56.933894 -> V=1.0, theta=0.0
% INFO    : Bus 15322	: V=0.9605384, theta=-56.948979 -> V=1.0, theta=0.0
% INFO    : Bus 15323	: V=0.9615158, theta=-56.898062 -> V=1.0, theta=0.0
% INFO    : Bus 15324	: V=0.9628036, theta=-56.653038 -> V=1.0, theta=0.0
% INFO    : Bus 15325	: V=0.9608597, theta=-56.736552 -> V=1.0, theta=0.0
% INFO    : Bus 15326	: V=0.9666548, theta=-56.229491 -> V=1.0, theta=0.0
% INFO    : Bus 15327	: V=0.9779806, theta=-54.808776 -> V=1.0, theta=0.0
% INFO    : Bus 15328	: V=0.9683805, theta=-56.140438 -> V=1.0, theta=0.0
% INFO    : Bus 15329	: V=0.9671131, theta=-56.270336 -> V=1.0, theta=0.0
% INFO    : Bus 15330	: V=0.968814, theta=-56.105375 -> V=1.0, theta=0.0
% INFO    : Bus 15331	: V=0.9607848, theta=-56.863498 -> V=1.0, theta=0.0
% INFO    : Bus 15332	: V=0.9656544, theta=-56.407295 -> V=1.0, theta=0.0
% INFO    : Bus 15333	: V=0.96818, theta=-56.17305 -> V=1.0, theta=0.0
% INFO    : Bus 15334	: V=0.9681464, theta=-56.216745 -> V=1.0, theta=0.0
% INFO    : Bus 15335	: V=0.9516566, theta=-56.805581 -> V=1.0, theta=0.0
% INFO    : Bus 15336	: V=0.9575911, theta=-55.641979 -> V=1.0, theta=0.0
% INFO    : Bus 15337	: V=0.9507327, theta=-57.0473 -> V=1.0, theta=0.0
% INFO    : Bus 15338	: V=0.9502873, theta=-57.104527 -> V=1.0, theta=0.0
% INFO    : Bus 15339	: V=0.9502969, theta=-56.895121 -> V=1.0, theta=0.0
% INFO    : Bus 15340	: V=0.9508428, theta=-57.358698 -> V=1.0, theta=0.0
% INFO    : Bus 15341	: V=0.9497154, theta=-57.564241 -> V=1.0, theta=0.0
% INFO    : Bus 15342	: V=0.9501655, theta=-57.316685 -> V=1.0, theta=0.0
% INFO    : Bus 15343	: V=0.9498225, theta=-57.272509 -> V=1.0, theta=0.0
% INFO    : Bus 15344	: V=0.9590679, theta=-55.51586 -> V=1.0, theta=0.0
% INFO    : Bus 15345	: V=0.9606774, theta=-55.286334 -> V=1.0, theta=0.0
% INFO    : Bus 15346	: V=0.9692845, theta=-53.925352 -> V=1.0, theta=0.0
% INFO    : Bus 15347	: V=0.9616775, theta=-54.607084 -> V=1.0, theta=0.0
% INFO    : Bus 15348	: V=0.9661842, theta=-54.411689 -> V=1.0, theta=0.0
% INFO    : Bus 15349	: V=0.9573891, theta=-56.25907 -> V=1.0, theta=0.0
% INFO    : Bus 15350	: V=0.947948, theta=-57.195606 -> V=1.0, theta=0.0
% INFO    : Bus 15351	: V=0.9594535, theta=-54.947538 -> V=1.0, theta=0.0
% INFO    : Bus 15352	: V=0.9619067, theta=-55.126733 -> V=1.0, theta=0.0
% INFO    : Bus 15353	: V=0.9602319, theta=-54.791444 -> V=1.0, theta=0.0
% INFO    : Bus 15354	: V=0.9597062, theta=-54.880839 -> V=1.0, theta=0.0
% INFO    : Bus 15355	: V=0.9641533, theta=-54.742085 -> V=1.0, theta=0.0
% INFO    : Bus 15356	: V=0.9593845, theta=-55.757379 -> V=1.0, theta=0.0
% INFO    : Bus 15357	: V=0.973803, theta=-53.23384 -> V=1.0, theta=0.0
% INFO    : Bus 15358	: V=0.9720541, theta=-53.476916 -> V=1.0, theta=0.0
% INFO    : Bus 15359	: V=0.9739443, theta=-53.108679 -> V=1.0, theta=0.0
% INFO    : Bus 15360	: V=0.9703901, theta=-53.561932 -> V=1.0, theta=0.0
% INFO    : Bus 15361	: V=0.9642553, theta=-54.292955 -> V=1.0, theta=0.0
% INFO    : Bus 15362	: V=0.9670701, theta=-53.958964 -> V=1.0, theta=0.0
% INFO    : Bus 15363	: V=0.9581286, theta=-54.378884 -> V=1.0, theta=0.0
% INFO    : Bus 15364	: V=0.9683033, theta=-53.50059 -> V=1.0, theta=0.0
% INFO    : Bus 15365	: V=0.9670026, theta=-53.473806 -> V=1.0, theta=0.0
% INFO    : Bus 15366	: V=0.9789299, theta=-52.051707 -> V=1.0, theta=0.0
% INFO    : Bus 15367	: V=0.9622302, theta=-53.899528 -> V=1.0, theta=0.0
% INFO    : Bus 15368	: V=0.9671797, theta=-53.176235 -> V=1.0, theta=0.0
% INFO    : Bus 15369	: V=0.9980752, theta=-49.32261 -> V=1.0, theta=0.0
% INFO    : Bus 15370	: V=1.0063242, theta=-48.750622 -> V=1.0, theta=0.0
% INFO    : Bus 15371	: V=0.9838456, theta=-51.676843 -> V=1.0, theta=0.0
% INFO    : Bus 15372	: V=0.9809823, theta=-51.889449 -> V=1.0, theta=0.0
% INFO    : Bus 15373	: V=0.9804237, theta=-51.932893 -> V=1.0, theta=0.0
% INFO    : Bus 15374	: V=0.9957549, theta=-50.350386 -> V=1.0, theta=0.0
% INFO    : Bus 15375	: V=0.9768889, theta=-52.577307 -> V=1.0, theta=0.0
% INFO    : Bus 15376	: V=0.9734329, theta=-52.929827 -> V=1.0, theta=0.0
% INFO    : Bus 15377	: V=0.9775483, theta=-52.057341 -> V=1.0, theta=0.0
% INFO    : Bus 15378	: V=0.9704707, theta=-53.058891 -> V=1.0, theta=0.0
% INFO    : Bus 15379	: V=0.9716213, theta=-53.178477 -> V=1.0, theta=0.0
% INFO    : Bus 15380	: V=0.9703673, theta=-53.323224 -> V=1.0, theta=0.0
% INFO    : Bus 15381	: V=0.9723556, theta=-52.846047 -> V=1.0, theta=0.0
% INFO    : Bus 15382	: V=0.9688062, theta=-53.620785 -> V=1.0, theta=0.0
% INFO    : Bus 15383	: V=0.9707881, theta=-53.292571 -> V=1.0, theta=0.0
% INFO    : Bus 15384	: V=0.9755868, theta=-52.353468 -> V=1.0, theta=0.0
% INFO    : Bus 15385	: V=0.9739006, theta=-52.917043 -> V=1.0, theta=0.0
% INFO    : Bus 15386	: V=0.999494, theta=-49.188058 -> V=1.0, theta=0.0
% INFO    : Bus 15387	: V=0.9930255, theta=-50.514393 -> V=1.0, theta=0.0
% INFO    : Bus 15388	: V=0.9792317, theta=-51.838279 -> V=1.0, theta=0.0
% INFO    : Bus 15389	: V=0.9962187, theta=-49.823306 -> V=1.0, theta=0.0
% INFO    : Bus 15390	: V=0.9970145, theta=-49.657136 -> V=1.0, theta=0.0
% INFO    : Bus 15391	: V=0.9880164, theta=-50.130328 -> V=1.0, theta=0.0
% INFO    : Bus 15392	: V=0.9830531, theta=-51.215442 -> V=1.0, theta=0.0
% INFO    : Bus 15393	: V=0.9953368, theta=-50.011929 -> V=1.0, theta=0.0
% INFO    : Bus 15394	: V=0.9939811, theta=-50.304152 -> V=1.0, theta=0.0
% INFO    : Bus 15395	: V=0.9707453, theta=-53.024531 -> V=1.0, theta=0.0
% INFO    : Bus 15396	: V=0.9712404, theta=-53.09642 -> V=1.0, theta=0.0
% INFO    : Bus 15397	: V=0.9921917, theta=-50.700668 -> V=1.0, theta=0.0
% INFO    : Bus 15398	: V=0.9709685, theta=-53.072532 -> V=1.0, theta=0.0
% INFO    : Bus 15399	: V=0.9716874, theta=-53.096758 -> V=1.0, theta=0.0
% INFO    : Bus 15400	: V=0.9740581, theta=-52.77469 -> V=1.0, theta=0.0
% INFO    : Bus 15401	: V=0.9714526, theta=-52.60884 -> V=1.0, theta=0.0
% INFO    : Bus 15402	: V=0.9748732, theta=-52.55026 -> V=1.0, theta=0.0
% INFO    : Bus 15403	: V=0.9655175, theta=-53.649185 -> V=1.0, theta=0.0
% INFO    : Bus 15404	: V=0.9582306, theta=-54.703903 -> V=1.0, theta=0.0
% INFO    : Bus 15405	: V=0.9645143, theta=-54.057107 -> V=1.0, theta=0.0
% INFO    : Bus 15406	: V=0.9696086, theta=-53.350917 -> V=1.0, theta=0.0
% INFO    : Bus 15407	: V=0.964801, theta=-53.891026 -> V=1.0, theta=0.0
% INFO    : Bus 15408	: V=0.9676552, theta=-53.578056 -> V=1.0, theta=0.0
% INFO    : Bus 15409	: V=0.967684, theta=-53.516766 -> V=1.0, theta=0.0
% INFO    : Bus 15410	: V=0.9685686, theta=-53.4777 -> V=1.0, theta=0.0
% INFO    : Bus 15411	: V=0.9663012, theta=-53.740683 -> V=1.0, theta=0.0
% INFO    : Bus 15412	: V=0.9658667, theta=-53.79909 -> V=1.0, theta=0.0
% INFO    : Bus 15413	: V=0.9621827, theta=-54.262808 -> V=1.0, theta=0.0
% INFO    : Bus 15414	: V=0.9615977, theta=-54.337239 -> V=1.0, theta=0.0
% INFO    : Bus 15415	: V=0.958205, theta=-54.81803 -> V=1.0, theta=0.0
% INFO    : Bus 15416	: V=0.9631058, theta=-54.149618 -> V=1.0, theta=0.0
% INFO    : Bus 15417	: V=0.9689717, theta=-53.491915 -> V=1.0, theta=0.0
% INFO    : Bus 15418	: V=0.9636628, theta=-54.257294 -> V=1.0, theta=0.0
% INFO    : Bus 15419	: V=0.9674833, theta=-53.689671 -> V=1.0, theta=0.0
% INFO    : Bus 15420	: V=0.963737, theta=-54.252946 -> V=1.0, theta=0.0
% INFO    : Bus 15421	: V=0.9570019, theta=-55.071264 -> V=1.0, theta=0.0
% INFO    : Bus 15422	: V=0.9652383, theta=-53.884375 -> V=1.0, theta=0.0
% INFO    : Bus 15423	: V=0.9650931, theta=-53.961802 -> V=1.0, theta=0.0
% INFO    : Bus 15424	: V=0.9640393, theta=-54.116746 -> V=1.0, theta=0.0
% INFO    : Bus 15425	: V=0.9654038, theta=-54.001907 -> V=1.0, theta=0.0
% INFO    : Bus 15426	: V=0.9949326, theta=-50.431259 -> V=1.0, theta=0.0
% INFO    : Bus 15427	: V=0.9661442, theta=-53.942773 -> V=1.0, theta=0.0
% INFO    : Bus 15428	: V=0.9652849, theta=-54.01481 -> V=1.0, theta=0.0
% INFO    : Bus 15429	: V=0.9607003, theta=-54.520749 -> V=1.0, theta=0.0
% INFO    : Bus 15430	: V=0.9661255, theta=-54.089661 -> V=1.0, theta=0.0
% INFO    : Bus 15431	: V=0.9642427, theta=-54.473193 -> V=1.0, theta=0.0
% INFO    : Bus 15432	: V=0.9648049, theta=-54.049393 -> V=1.0, theta=0.0
% INFO    : Bus 15433	: V=0.9644575, theta=-54.076854 -> V=1.0, theta=0.0
% INFO    : Bus 15434	: V=0.9616218, theta=-54.367006 -> V=1.0, theta=0.0
% INFO    : Bus 15435	: V=0.962891, theta=-54.267785 -> V=1.0, theta=0.0
% INFO    : Bus 15436	: V=0.9559703, theta=-55.12367 -> V=1.0, theta=0.0
% INFO    : Bus 15437	: V=0.9561451, theta=-55.115014 -> V=1.0, theta=0.0
% INFO    : Bus 15438	: V=0.9610731, theta=-54.429141 -> V=1.0, theta=0.0
% INFO    : Bus 15439	: V=0.9609707, theta=-54.530974 -> V=1.0, theta=0.0
% INFO    : Bus 15440	: V=0.9538263, theta=-55.375799 -> V=1.0, theta=0.0
% INFO    : Bus 15441	: V=0.9480614, theta=-55.788707 -> V=1.0, theta=0.0
% INFO    : Bus 15442	: V=0.955186, theta=-55.228382 -> V=1.0, theta=0.0
% INFO    : Bus 15443	: V=0.9625657, theta=-54.616353 -> V=1.0, theta=0.0
% INFO    : Bus 15444	: V=0.9615034, theta=-54.703859 -> V=1.0, theta=0.0
% INFO    : Bus 15445	: V=0.949719, theta=-56.236542 -> V=1.0, theta=0.0
% INFO    : Bus 15446	: V=0.9491377, theta=-56.10667 -> V=1.0, theta=0.0
% INFO    : Bus 15447	: V=0.9487979, theta=-56.260541 -> V=1.0, theta=0.0
% INFO    : Bus 15448	: V=0.9497926, theta=-56.092002 -> V=1.0, theta=0.0
% INFO    : Bus 15449	: V=0.9517485, theta=-56.62413 -> V=1.0, theta=0.0
% INFO    : Bus 15450	: V=0.9510449, theta=-56.575101 -> V=1.0, theta=0.0
% INFO    : Bus 15451	: V=0.9499072, theta=-56.535988 -> V=1.0, theta=0.0
% INFO    : Bus 15452	: V=0.9510022, theta=-56.571171 -> V=1.0, theta=0.0
% INFO    : Bus 15453	: V=0.9503516, theta=-56.550012 -> V=1.0, theta=0.0
% INFO    : Bus 15454	: V=0.9527915, theta=-56.636751 -> V=1.0, theta=0.0
% INFO    : Bus 15455	: V=0.9543954, theta=-55.653198 -> V=1.0, theta=0.0
% INFO    : Bus 15456	: V=0.9533448, theta=-55.748895 -> V=1.0, theta=0.0
% INFO    : Bus 15457	: V=0.9511836, theta=-55.854609 -> V=1.0, theta=0.0
% INFO    : Bus 15458	: V=0.9505407, theta=-56.898678 -> V=1.0, theta=0.0
% INFO    : Bus 15459	: V=0.9492963, theta=-56.282141 -> V=1.0, theta=0.0
% INFO    : Bus 15460	: V=0.9492429, theta=-56.936111 -> V=1.0, theta=0.0
% INFO    : Bus 15461	: V=0.9503742, theta=-56.352131 -> V=1.0, theta=0.0
% INFO    : Bus 15462	: V=0.9594154, theta=-54.85414 -> V=1.0, theta=0.0
% INFO    : Bus 15463	: V=0.9519367, theta=-56.070661 -> V=1.0, theta=0.0
% INFO    : Bus 15464	: V=0.9504884, theta=-56.414209 -> V=1.0, theta=0.0
% INFO    : Bus 15465	: V=0.9492869, theta=-56.554541 -> V=1.0, theta=0.0
% INFO    : Bus 15466	: V=0.9515959, theta=-55.839237 -> V=1.0, theta=0.0
% INFO    : Bus 15467	: V=0.9529387, theta=-55.807931 -> V=1.0, theta=0.0
% INFO    : Bus 15468	: V=0.952229, theta=-56.640552 -> V=1.0, theta=0.0
% INFO    : Bus 15469	: V=0.9709994, theta=-54.791339 -> V=1.0, theta=0.0
% INFO    : Bus 15470	: V=0.9502858, theta=-56.829153 -> V=1.0, theta=0.0
% INFO    : Bus 15471	: V=0.9585948, theta=-56.129621 -> V=1.0, theta=0.0
% INFO    : Bus 15472	: V=0.9514367, theta=-56.827438 -> V=1.0, theta=0.0
% INFO    : Bus 15473	: V=0.9592124, theta=-56.04068 -> V=1.0, theta=0.0
% INFO    : Bus 15474	: V=0.9503247, theta=-56.81615 -> V=1.0, theta=0.0
% INFO    : Bus 15475	: V=0.9521626, theta=-56.733845 -> V=1.0, theta=0.0
% INFO    : Bus 15476	: V=0.9507603, theta=-56.80459 -> V=1.0, theta=0.0
% INFO    : Bus 15477	: V=0.9507727, theta=-56.667006 -> V=1.0, theta=0.0
% INFO    : Bus 15478	: V=0.9581841, theta=-55.867255 -> V=1.0, theta=0.0
% INFO    : Bus 15479	: V=0.9504522, theta=-56.821625 -> V=1.0, theta=0.0
% INFO    : Bus 15480	: V=0.9505142, theta=-56.749889 -> V=1.0, theta=0.0
% INFO    : Bus 15481	: V=0.9583827, theta=-55.85497 -> V=1.0, theta=0.0
% INFO    : Bus 15482	: V=0.9590569, theta=-55.801265 -> V=1.0, theta=0.0
% INFO    : Bus 15483	: V=0.9520956, theta=-56.600591 -> V=1.0, theta=0.0
% INFO    : Bus 15484	: V=0.958892, theta=-55.794611 -> V=1.0, theta=0.0
% INFO    : Bus 15485	: V=0.9530199, theta=-56.495654 -> V=1.0, theta=0.0
% INFO    : Bus 15486	: V=0.9836503, theta=-52.813991 -> V=1.0, theta=0.0
% INFO    : Bus 15487	: V=0.9548279, theta=-56.165008 -> V=1.0, theta=0.0
% INFO    : Bus 15488	: V=0.9553951, theta=-56.097799 -> V=1.0, theta=0.0
% INFO    : Bus 15489	: V=0.956046, theta=-56.069173 -> V=1.0, theta=0.0
% INFO    : Bus 15490	: V=0.9602197, theta=-55.495789 -> V=1.0, theta=0.0
% INFO    : Bus 15491	: V=0.9532543, theta=-56.433752 -> V=1.0, theta=0.0
% INFO    : Bus 15492	: V=0.9531857, theta=-56.37284 -> V=1.0, theta=0.0
% INFO    : Bus 15493	: V=0.9510156, theta=-56.50457 -> V=1.0, theta=0.0
% INFO    : Bus 15494	: V=0.9519743, theta=-56.492192 -> V=1.0, theta=0.0
% INFO    : Bus 15495	: V=0.9532049, theta=-56.482556 -> V=1.0, theta=0.0
% INFO    : Bus 15496	: V=0.9534909, theta=-56.564114 -> V=1.0, theta=0.0
% INFO    : Bus 15497	: V=0.9540246, theta=-56.57691 -> V=1.0, theta=0.0
% INFO    : Bus 15498	: V=0.96013, theta=-55.866953 -> V=1.0, theta=0.0
% INFO    : Bus 15499	: V=0.954996, theta=-56.543633 -> V=1.0, theta=0.0
% INFO    : Bus 15500	: V=0.9604144, theta=-55.849551 -> V=1.0, theta=0.0
% INFO    : Bus 15501	: V=0.951483, theta=-56.615727 -> V=1.0, theta=0.0
% INFO    : Bus 15502	: V=0.9525962, theta=-56.617766 -> V=1.0, theta=0.0
% INFO    : Bus 15503	: V=0.9611569, theta=-55.797972 -> V=1.0, theta=0.0
% INFO    : Bus 15504	: V=0.9556122, theta=-56.565052 -> V=1.0, theta=0.0
% INFO    : Bus 15505	: V=0.9554423, theta=-56.565177 -> V=1.0, theta=0.0
% INFO    : Bus 15506	: V=0.9529202, theta=-56.562601 -> V=1.0, theta=0.0
% INFO    : Bus 15507	: V=0.9509438, theta=-56.633525 -> V=1.0, theta=0.0
% INFO    : Bus 15508	: V=0.9522663, theta=-56.541124 -> V=1.0, theta=0.0
% INFO    : Bus 15509	: V=0.9520523, theta=-56.550482 -> V=1.0, theta=0.0
% INFO    : Bus 15510	: V=0.9515282, theta=-56.625669 -> V=1.0, theta=0.0
% INFO    : Bus 15511	: V=0.9589345, theta=-55.796228 -> V=1.0, theta=0.0
% INFO    : Bus 15512	: V=0.9536911, theta=-56.554817 -> V=1.0, theta=0.0
% INFO    : Bus 15513	: V=0.9512072, theta=-56.740546 -> V=1.0, theta=0.0
% INFO    : Bus 15514	: V=0.9504061, theta=-56.774665 -> V=1.0, theta=0.0
% INFO    : Bus 15515	: V=0.9512998, theta=-56.731909 -> V=1.0, theta=0.0
% INFO    : Bus 15516	: V=0.9506738, theta=-56.773891 -> V=1.0, theta=0.0
% INFO    : Bus 15517	: V=0.9612412, theta=-55.887052 -> V=1.0, theta=0.0
% INFO    : Bus 15518	: V=0.9507389, theta=-57.394331 -> V=1.0, theta=0.0
% INFO    : Bus 15519	: V=0.9507241, theta=-57.381961 -> V=1.0, theta=0.0
% INFO    : Bus 15520	: V=0.9500351, theta=-57.425971 -> V=1.0, theta=0.0
% INFO    : Bus 15521	: V=0.952669, theta=-56.622675 -> V=1.0, theta=0.0
% INFO    : Bus 15522	: V=0.952626, theta=-56.61018 -> V=1.0, theta=0.0
% INFO    : Bus 15523	: V=0.9534044, theta=-56.586527 -> V=1.0, theta=0.0
% INFO    : Bus 15524	: V=0.9539575, theta=-56.568195 -> V=1.0, theta=0.0
% INFO    : Bus 15525	: V=0.9850657, theta=-53.202585 -> V=1.0, theta=0.0
% INFO    : Bus 15526	: V=0.9528562, theta=-56.66823 -> V=1.0, theta=0.0
% INFO    : Bus 15527	: V=0.9629569, theta=-55.671833 -> V=1.0, theta=0.0
% INFO    : Bus 15528	: V=0.9559565, theta=-56.48173 -> V=1.0, theta=0.0
% INFO    : Bus 15529	: V=0.9614144, theta=-56.138667 -> V=1.0, theta=0.0
% INFO    : Bus 15530	: V=0.956252, theta=-56.535508 -> V=1.0, theta=0.0
% INFO    : Bus 15531	: V=0.9691216, theta=-55.584947 -> V=1.0, theta=0.0
% INFO    : Bus 15532	: V=0.9660765, theta=-55.802087 -> V=1.0, theta=0.0
% INFO    : Bus 15533	: V=0.9565914, theta=-57.093431 -> V=1.0, theta=0.0
% INFO    : Bus 15534	: V=0.9860928, theta=-53.488193 -> V=1.0, theta=0.0
% INFO    : Bus 15535	: V=0.9635829, theta=-55.986987 -> V=1.0, theta=0.0
% INFO    : Bus 15536	: V=0.9568087, theta=-56.925858 -> V=1.0, theta=0.0
% INFO    : Bus 15537	: V=0.9794431, theta=-55.002742 -> V=1.0, theta=0.0
% INFO    : Bus 15538	: V=0.9829407, theta=-54.341233 -> V=1.0, theta=0.0
% INFO    : Bus 15539	: V=0.9768938, theta=-54.730356 -> V=1.0, theta=0.0
% INFO    : Bus 15540	: V=0.9837944, theta=-54.106219 -> V=1.0, theta=0.0
% INFO    : Bus 15541	: V=0.9773079, theta=-54.108081 -> V=1.0, theta=0.0
% INFO    : Bus 15542	: V=0.989555, theta=-53.2042 -> V=1.0, theta=0.0
% INFO    : Bus 15543	: V=0.9888373, theta=-53.320611 -> V=1.0, theta=0.0
% INFO    : Bus 15544	: V=0.9888412, theta=-53.463637 -> V=1.0, theta=0.0
% INFO    : Bus 15545	: V=0.9903238, theta=-52.984877 -> V=1.0, theta=0.0
% INFO    : Bus 15546	: V=0.9929103, theta=-52.408625 -> V=1.0, theta=0.0
% INFO    : Bus 15547	: V=0.9885642, theta=-53.424999 -> V=1.0, theta=0.0
% INFO    : Bus 15548	: V=0.9895487, theta=-49.971425 -> V=1.0, theta=0.0
% INFO    : Bus 15549	: V=0.9946975, theta=-49.847311 -> V=1.0, theta=0.0
% INFO    : Bus 15550	: V=0.9877257, theta=-48.538416 -> V=1.0, theta=0.0
% INFO    : Bus 15551	: V=0.9929558, theta=-48.430873 -> V=1.0, theta=0.0
% INFO    : Bus 15552	: V=0.9856884, theta=-49.011001 -> V=1.0, theta=0.0
% INFO    : Bus 15553	: V=0.982202, theta=-49.442341 -> V=1.0, theta=0.0
% INFO    : Bus 15554	: V=0.9845486, theta=-49.489459 -> V=1.0, theta=0.0
% INFO    : Bus 15555	: V=0.9861256, theta=-49.626263 -> V=1.0, theta=0.0
% INFO    : Bus 15556	: V=0.9896663, theta=-49.564019 -> V=1.0, theta=0.0
% INFO    : Bus 15557	: V=1.0023086, theta=-48.001022 -> V=1.0, theta=0.0
% INFO    : Bus 15558	: V=0.9957561, theta=-49.234113 -> V=1.0, theta=0.0
% INFO    : Bus 15559	: V=0.9854322, theta=-49.450248 -> V=1.0, theta=0.0
% INFO    : Bus 15560	: V=0.9790453, theta=-49.915624 -> V=1.0, theta=0.0
% INFO    : Bus 15561	: V=0.9916312, theta=-49.345154 -> V=1.0, theta=0.0
% INFO    : Bus 15562	: V=0.983227, theta=-49.405496 -> V=1.0, theta=0.0
% INFO    : Bus 15563	: V=0.9831271, theta=-49.052205 -> V=1.0, theta=0.0
% INFO    : Bus 15564	: V=0.9675259, theta=-50.435266 -> V=1.0, theta=0.0
% INFO    : Bus 15565	: V=0.9979748, theta=-46.039223 -> V=1.0, theta=0.0
% INFO    : Bus 15566	: V=0.9904464, theta=-46.267219 -> V=1.0, theta=0.0
% INFO    : Bus 15567	: V=0.9846518, theta=-46.36706 -> V=1.0, theta=0.0
% INFO    : Bus 15568	: V=0.9991421, theta=-46.050701 -> V=1.0, theta=0.0
% INFO    : Bus 15569	: V=0.9920102, theta=-45.825212 -> V=1.0, theta=0.0
% INFO    : Bus 15570	: V=0.9832513, theta=-46.134415 -> V=1.0, theta=0.0
% INFO    : Bus 15571	: V=1.0035863, theta=-45.356507 -> V=1.0, theta=0.0
% INFO    : Bus 15572	: V=0.9929243, theta=-52.278248 -> V=1.0, theta=0.0
% INFO    : Bus 15573	: V=1.0028117, theta=-51.211295 -> V=1.0, theta=0.0
% INFO    : Bus 15574	: V=1.0053555, theta=-51.18438 -> V=1.0, theta=0.0
% INFO    : Bus 15575	: V=1.0048632, theta=-51.130128 -> V=1.0, theta=0.0
% INFO    : Bus 15576	: V=1.0040988, theta=-51.403601 -> V=1.0, theta=0.0
% INFO    : Bus 15577	: V=1.0058465, theta=-50.815352 -> V=1.0, theta=0.0
% INFO    : Bus 15578	: V=0.9979928, theta=-51.337427 -> V=1.0, theta=0.0
% INFO    : Bus 15579	: V=1.0012118, theta=-51.241145 -> V=1.0, theta=0.0
% INFO    : Bus 15580	: V=0.9989102, theta=-51.269274 -> V=1.0, theta=0.0
% INFO    : Bus 15581	: V=1.0095983, theta=-49.972921 -> V=1.0, theta=0.0
% INFO    : Bus 15582	: V=0.9873096, theta=-57.952037 -> V=1.0, theta=0.0
% INFO    : Bus 15583	: V=0.9943429, theta=-57.277205 -> V=1.0, theta=0.0
% INFO    : Bus 15584	: V=0.9950601, theta=-57.170962 -> V=1.0, theta=0.0
% INFO    : Bus 15585	: V=0.9946314, theta=-57.204228 -> V=1.0, theta=0.0
% INFO    : Bus 15586	: V=0.9944195, theta=-57.221454 -> V=1.0, theta=0.0
% INFO    : Bus 15587	: V=0.9935992, theta=-57.323542 -> V=1.0, theta=0.0
% INFO    : Bus 15588	: V=0.9869091, theta=-57.999168 -> V=1.0, theta=0.0
% INFO    : Bus 15589	: V=0.9934832, theta=-57.239281 -> V=1.0, theta=0.0
% INFO    : Bus 15590	: V=0.99429, theta=-57.177213 -> V=1.0, theta=0.0
% INFO    : Bus 15591	: V=0.9887348, theta=-57.751591 -> V=1.0, theta=0.0
% INFO    : Bus 15592	: V=0.9964609, theta=-56.942125 -> V=1.0, theta=0.0
% INFO    : Bus 15593	: V=0.9956735, theta=-56.984526 -> V=1.0, theta=0.0
% INFO    : Bus 15594	: V=0.9927266, theta=-57.335951 -> V=1.0, theta=0.0
% INFO    : Bus 15595	: V=0.9719508, theta=-58.919344 -> V=1.0, theta=0.0
% INFO    : Bus 15596	: V=0.9864506, theta=-58.443663 -> V=1.0, theta=0.0
% INFO    : Bus 15597	: V=0.9919971, theta=-57.823242 -> V=1.0, theta=0.0
% INFO    : Bus 15598	: V=0.99498, theta=-57.596508 -> V=1.0, theta=0.0
% INFO    : Bus 15599	: V=1.0072708, theta=-55.423629 -> V=1.0, theta=0.0
% INFO    : Bus 15600	: V=1.0077168, theta=-55.071288 -> V=1.0, theta=0.0
% INFO    : Bus 15601	: V=0.998651, theta=-55.786793 -> V=1.0, theta=0.0
% INFO    : Bus 15602	: V=1.0032908, theta=-56.04914 -> V=1.0, theta=0.0
% INFO    : Bus 15603	: V=1.0059253, theta=-55.346815 -> V=1.0, theta=0.0
% INFO    : Bus 15604	: V=0.9952839, theta=-56.691182 -> V=1.0, theta=0.0
% INFO    : Bus 15605	: V=0.9775266, theta=-58.419102 -> V=1.0, theta=0.0
% INFO    : Bus 15606	: V=0.9816579, theta=-58.242115 -> V=1.0, theta=0.0
% INFO    : Bus 15607	: V=0.9903533, theta=-57.6606 -> V=1.0, theta=0.0
% INFO    : Bus 15608	: V=0.9844106, theta=-58.104002 -> V=1.0, theta=0.0
% INFO    : Bus 15609	: V=0.9861514, theta=-58.367592 -> V=1.0, theta=0.0
% INFO    : Bus 15610	: V=0.9808102, theta=-58.151779 -> V=1.0, theta=0.0
% INFO    : Bus 15611	: V=0.9901662, theta=-56.776281 -> V=1.0, theta=0.0
% INFO    : Bus 15612	: V=0.9944439, theta=-55.543524 -> V=1.0, theta=0.0
% INFO    : Bus 15613	: V=0.9950503, theta=-55.775359 -> V=1.0, theta=0.0
% INFO    : Bus 15614	: V=0.9862255, theta=-47.751282 -> V=1.0, theta=0.0
% INFO    : Bus 15615	: V=0.9859452, theta=-47.867638 -> V=1.0, theta=0.0
% INFO    : Bus 15616	: V=0.9860908, theta=-47.796821 -> V=1.0, theta=0.0
% INFO    : Bus 15617	: V=0.99192, theta=-46.863675 -> V=1.0, theta=0.0
% INFO    : Bus 15618	: V=0.9860981, theta=-47.733575 -> V=1.0, theta=0.0
% INFO    : Bus 15619	: V=0.995651, theta=-46.104189 -> V=1.0, theta=0.0
% INFO    : Bus 15620	: V=0.9861888, theta=-47.659189 -> V=1.0, theta=0.0
% INFO    : Bus 15621	: V=0.9871913, theta=-48.256597 -> V=1.0, theta=0.0
% INFO    : Bus 15622	: V=0.9836191, theta=-48.24863 -> V=1.0, theta=0.0
% INFO    : Bus 15623	: V=0.9931972, theta=-46.738937 -> V=1.0, theta=0.0
% INFO    : Bus 15624	: V=0.9895162, theta=-47.568237 -> V=1.0, theta=0.0
% INFO    : Bus 15625	: V=0.9868383, theta=-47.540999 -> V=1.0, theta=0.0
% INFO    : Bus 15626	: V=0.980864, theta=-47.569493 -> V=1.0, theta=0.0
% INFO    : Bus 15627	: V=0.987812, theta=-46.943959 -> V=1.0, theta=0.0
% INFO    : Bus 15628	: V=0.9852152, theta=-47.592227 -> V=1.0, theta=0.0
% INFO    : Bus 15629	: V=0.986027, theta=-46.958602 -> V=1.0, theta=0.0
% INFO    : Bus 15630	: V=1.0090937, theta=-48.408 -> V=1.0, theta=0.0
% INFO    : Bus 15631	: V=1.0070748, theta=-48.214482 -> V=1.0, theta=0.0
% INFO    : Bus 15632	: V=1.007006, theta=-47.886528 -> V=1.0, theta=0.0
% INFO    : Bus 15633	: V=0.9737159, theta=-46.874399 -> V=1.0, theta=0.0
% INFO    : Bus 15634	: V=0.9769193, theta=-46.771168 -> V=1.0, theta=0.0
% INFO    : Bus 15635	: V=0.9816334, theta=-46.451487 -> V=1.0, theta=0.0
% INFO    : Bus 15636	: V=0.973497, theta=-46.926965 -> V=1.0, theta=0.0
% INFO    : Bus 15637	: V=0.9731512, theta=-46.908113 -> V=1.0, theta=0.0
% INFO    : Bus 15638	: V=0.971937, theta=-46.919856 -> V=1.0, theta=0.0
% INFO    : Bus 15639	: V=0.9757248, theta=-46.752506 -> V=1.0, theta=0.0
% INFO    : Bus 15640	: V=0.9831963, theta=-46.499719 -> V=1.0, theta=0.0
% INFO    : Bus 15641	: V=0.9829708, theta=-46.468543 -> V=1.0, theta=0.0
% INFO    : Bus 15642	: V=0.9751439, theta=-46.89379 -> V=1.0, theta=0.0
% INFO    : Bus 15643	: V=0.9906636, theta=-46.104374 -> V=1.0, theta=0.0
% INFO    : Bus 15644	: V=0.9914152, theta=-46.062489 -> V=1.0, theta=0.0
% INFO    : Bus 15645	: V=0.9956099, theta=-45.735122 -> V=1.0, theta=0.0
% INFO    : Bus 15646	: V=1.0148378, theta=-43.493589 -> V=1.0, theta=0.0
% INFO    : Bus 15647	: V=0.9776278, theta=-46.573005 -> V=1.0, theta=0.0
% INFO    : Bus 15648	: V=0.9757301, theta=-57.554041 -> V=1.0, theta=0.0
% INFO    : Bus 15649	: V=0.977268, theta=-57.406074 -> V=1.0, theta=0.0
% INFO    : Bus 15650	: V=0.9766592, theta=-57.429427 -> V=1.0, theta=0.0
% INFO    : Bus 15651	: V=0.9763436, theta=-57.502861 -> V=1.0, theta=0.0
% INFO    : Bus 15652	: V=0.9765962, theta=-57.443631 -> V=1.0, theta=0.0
% INFO    : Bus 15653	: V=0.9766243, theta=-57.447879 -> V=1.0, theta=0.0
% INFO    : Bus 15654	: V=0.9767064, theta=-57.449794 -> V=1.0, theta=0.0
% INFO    : Bus 15655	: V=0.9771588, theta=-57.437606 -> V=1.0, theta=0.0
% INFO    : Bus 15656	: V=0.97606, theta=-57.5046 -> V=1.0, theta=0.0
% INFO    : Bus 15657	: V=0.9761343, theta=-57.495461 -> V=1.0, theta=0.0
% INFO    : Bus 15658	: V=0.9759043, theta=-57.326195 -> V=1.0, theta=0.0
% INFO    : Bus 15659	: V=0.9751983, theta=-57.375366 -> V=1.0, theta=0.0
% INFO    : Bus 15660	: V=0.9787339, theta=-57.305937 -> V=1.0, theta=0.0
% INFO    : Bus 15661	: V=0.9763742, theta=-57.499187 -> V=1.0, theta=0.0
% INFO    : Bus 15662	: V=0.9759682, theta=-57.527598 -> V=1.0, theta=0.0
% INFO    : Bus 15663	: V=0.9756705, theta=-57.555196 -> V=1.0, theta=0.0
% INFO    : Bus 15664	: V=0.9800865, theta=-57.227485 -> V=1.0, theta=0.0
% INFO    : Bus 15665	: V=0.9761047, theta=-57.534666 -> V=1.0, theta=0.0
% INFO    : Bus 15666	: V=0.9758277, theta=-57.539112 -> V=1.0, theta=0.0
% INFO    : Bus 15667	: V=0.9784274, theta=-57.158875 -> V=1.0, theta=0.0
% INFO    : Bus 15668	: V=0.977951, theta=-57.277014 -> V=1.0, theta=0.0
% INFO    : Bus 15669	: V=0.9803736, theta=-57.063777 -> V=1.0, theta=0.0
% INFO    : Bus 15670	: V=0.9803504, theta=-57.042901 -> V=1.0, theta=0.0
% INFO    : Bus 15671	: V=0.9805107, theta=-57.008487 -> V=1.0, theta=0.0
% INFO    : Bus 15672	: V=0.9757842, theta=-57.605119 -> V=1.0, theta=0.0
% INFO    : Bus 15673	: V=0.979862, theta=-57.055787 -> V=1.0, theta=0.0
% INFO    : Bus 15674	: V=0.9728877, theta=-57.763896 -> V=1.0, theta=0.0
% INFO    : Bus 15675	: V=0.9731881, theta=-57.732806 -> V=1.0, theta=0.0
% INFO    : Bus 15676	: V=0.9735756, theta=-57.696322 -> V=1.0, theta=0.0
% INFO    : Bus 15677	: V=0.9740355, theta=-57.65546 -> V=1.0, theta=0.0
% INFO    : Bus 15678	: V=0.9699113, theta=-58.049104 -> V=1.0, theta=0.0
% INFO    : Bus 15679	: V=0.9763519, theta=-57.399573 -> V=1.0, theta=0.0
% INFO    : Bus 15680	: V=0.970139, theta=-58.023213 -> V=1.0, theta=0.0
% INFO    : Bus 15681	: V=0.9703114, theta=-58.008827 -> V=1.0, theta=0.0
% INFO    : Bus 15682	: V=0.9777182, theta=-57.193327 -> V=1.0, theta=0.0
% INFO    : Bus 15683	: V=0.9714903, theta=-57.899939 -> V=1.0, theta=0.0
% INFO    : Bus 15684	: V=0.971602, theta=-57.886996 -> V=1.0, theta=0.0
% INFO    : Bus 15685	: V=0.978148, theta=-57.162038 -> V=1.0, theta=0.0
% INFO    : Bus 15686	: V=0.9706714, theta=-57.964968 -> V=1.0, theta=0.0
% INFO    : Bus 15687	: V=0.9709146, theta=-57.942427 -> V=1.0, theta=0.0
% INFO    : Bus 15688	: V=0.9772097, theta=-57.245992 -> V=1.0, theta=0.0
% INFO    : Bus 15689	: V=0.9755156, theta=-57.355311 -> V=1.0, theta=0.0
% INFO    : Bus 15690	: V=0.9752235, theta=-57.375611 -> V=1.0, theta=0.0
% INFO    : Bus 15691	: V=0.9749925, theta=-57.392722 -> V=1.0, theta=0.0
% INFO    : Bus 15692	: V=0.9735777, theta=-57.596299 -> V=1.0, theta=0.0
% INFO    : Bus 15693	: V=0.9701559, theta=-58.085605 -> V=1.0, theta=0.0
% INFO    : Bus 15694	: V=0.9815447, theta=-56.609761 -> V=1.0, theta=0.0
% INFO    : Bus 15695	: V=0.9703521, theta=-58.02214 -> V=1.0, theta=0.0
% INFO    : Bus 15696	: V=0.9703145, theta=-58.006522 -> V=1.0, theta=0.0
% INFO    : Bus 15697	: V=0.970848, theta=-57.94602 -> V=1.0, theta=0.0
% INFO    : Bus 15698	: V=0.9770346, theta=-57.252421 -> V=1.0, theta=0.0
% INFO    : Bus 15699	: V=0.9826064, theta=-56.451464 -> V=1.0, theta=0.0
% INFO    : Bus 15700	: V=0.9711841, theta=-57.982834 -> V=1.0, theta=0.0
% INFO    : Bus 15701	: V=0.9708025, theta=-57.985219 -> V=1.0, theta=0.0
% INFO    : Bus 15702	: V=0.9700627, theta=-58.054808 -> V=1.0, theta=0.0
% INFO    : Bus 15703	: V=0.9641309, theta=-58.543209 -> V=1.0, theta=0.0
% INFO    : Bus 15704	: V=0.9758049, theta=-57.339594 -> V=1.0, theta=0.0
% INFO    : Bus 15705	: V=0.9643951, theta=-58.506454 -> V=1.0, theta=0.0
% INFO    : Bus 15706	: V=0.9621302, theta=-58.715753 -> V=1.0, theta=0.0
% INFO    : Bus 15707	: V=0.9751105, theta=-57.376254 -> V=1.0, theta=0.0
% INFO    : Bus 15708	: V=0.958827, theta=-58.906477 -> V=1.0, theta=0.0
% INFO    : Bus 15709	: V=0.9610762, theta=-58.723562 -> V=1.0, theta=0.0
% INFO    : Bus 15710	: V=0.9718646, theta=-57.925807 -> V=1.0, theta=0.0
% INFO    : Bus 15711	: V=0.9706513, theta=-58.009181 -> V=1.0, theta=0.0
% INFO    : Bus 15712	: V=0.970708, theta=-58.0082 -> V=1.0, theta=0.0
% INFO    : Bus 15713	: V=0.9693059, theta=-58.111547 -> V=1.0, theta=0.0
% INFO    : Bus 15714	: V=0.9687356, theta=-58.140854 -> V=1.0, theta=0.0
% INFO    : Bus 15715	: V=0.9683824, theta=-58.144792 -> V=1.0, theta=0.0
% INFO    : Bus 15716	: V=0.9697854, theta=-57.762616 -> V=1.0, theta=0.0
% INFO    : Bus 15717	: V=0.9689971, theta=-57.820908 -> V=1.0, theta=0.0
% INFO    : Bus 15718	: V=0.9682264, theta=-58.029397 -> V=1.0, theta=0.0
% INFO    : Bus 15719	: V=0.9624645, theta=-58.667616 -> V=1.0, theta=0.0
% INFO    : Bus 15720	: V=0.9621527, theta=-58.704054 -> V=1.0, theta=0.0
% INFO    : Bus 15721	: V=0.9592964, theta=-58.957447 -> V=1.0, theta=0.0
% INFO    : Bus 15722	: V=0.9575566, theta=-59.012833 -> V=1.0, theta=0.0
% INFO    : Bus 15723	: V=0.9649607, theta=-58.32205 -> V=1.0, theta=0.0
% INFO    : Bus 15724	: V=0.9658023, theta=-58.250772 -> V=1.0, theta=0.0
% INFO    : Bus 15725	: V=0.9683613, theta=-57.865604 -> V=1.0, theta=0.0
% INFO    : Bus 15726	: V=0.9678784, theta=-57.897381 -> V=1.0, theta=0.0
% INFO    : Bus 15727	: V=0.9699758, theta=-58.086705 -> V=1.0, theta=0.0
% INFO    : Bus 15728	: V=0.9694168, theta=-58.114656 -> V=1.0, theta=0.0
% INFO    : Bus 15729	: V=0.9692291, theta=-58.117673 -> V=1.0, theta=0.0
% INFO    : Bus 15730	: V=0.9692605, theta=-58.139386 -> V=1.0, theta=0.0
% INFO    : Bus 15731	: V=0.9712276, theta=-57.657714 -> V=1.0, theta=0.0
% INFO    : Bus 15732	: V=0.9699546, theta=-57.847315 -> V=1.0, theta=0.0
% INFO    : Bus 15733	: V=0.9690684, theta=-57.942489 -> V=1.0, theta=0.0
% INFO    : Bus 15734	: V=0.9576707, theta=-58.789131 -> V=1.0, theta=0.0
% INFO    : Bus 15735	: V=0.9580465, theta=-58.782617 -> V=1.0, theta=0.0
% INFO    : Bus 15736	: V=0.9748527, theta=-57.401445 -> V=1.0, theta=0.0
% INFO    : Bus 15737	: V=0.9705611, theta=-57.938095 -> V=1.0, theta=0.0
% INFO    : Bus 15738	: V=0.9748058, theta=-57.403002 -> V=1.0, theta=0.0
% INFO    : Bus 15739	: V=0.9748374, theta=-57.396972 -> V=1.0, theta=0.0
% INFO    : Bus 15740	: V=0.9702919, theta=-58.037312 -> V=1.0, theta=0.0
% INFO    : Bus 15741	: V=0.9745771, theta=-57.413405 -> V=1.0, theta=0.0
% INFO    : Bus 15742	: V=0.9698281, theta=-58.110973 -> V=1.0, theta=0.0
% INFO    : Bus 15743	: V=0.9686772, theta=-58.234087 -> V=1.0, theta=0.0
% INFO    : Bus 15744	: V=0.9689277, theta=-58.229142 -> V=1.0, theta=0.0
% INFO    : Bus 15745	: V=0.9693223, theta=-58.156267 -> V=1.0, theta=0.0
% INFO    : Bus 15746	: V=0.9709995, theta=-57.739573 -> V=1.0, theta=0.0
% INFO    : Bus 15747	: V=0.9733197, theta=-57.51475 -> V=1.0, theta=0.0
% INFO    : Bus 15748	: V=0.9721014, theta=-57.631987 -> V=1.0, theta=0.0
% INFO    : Bus 15749	: V=0.9699034, theta=-58.029017 -> V=1.0, theta=0.0
% INFO    : Bus 15750	: V=0.9721351, theta=-57.586421 -> V=1.0, theta=0.0
% INFO    : Bus 15751	: V=0.9710378, theta=-57.638865 -> V=1.0, theta=0.0
% INFO    : Bus 15752	: V=0.9614122, theta=-58.621953 -> V=1.0, theta=0.0
% INFO    : Bus 15753	: V=0.9601987, theta=-58.680703 -> V=1.0, theta=0.0
% INFO    : Bus 15754	: V=0.9761726, theta=-57.274079 -> V=1.0, theta=0.0
% INFO    : Bus 15755	: V=0.9978274, theta=-54.143966 -> V=1.0, theta=0.0
% INFO    : Bus 15756	: V=0.9764864, theta=-57.268565 -> V=1.0, theta=0.0
% INFO    : Bus 15757	: V=0.9782543, theta=-57.292033 -> V=1.0, theta=0.0
% INFO    : Bus 15758	: V=0.9779413, theta=-57.14435 -> V=1.0, theta=0.0
% INFO    : Bus 15759	: V=0.9788697, theta=-57.06869 -> V=1.0, theta=0.0
% INFO    : Bus 15760	: V=0.9809129, theta=-56.954667 -> V=1.0, theta=0.0
% INFO    : Bus 15761	: V=0.9787829, theta=-57.092728 -> V=1.0, theta=0.0
% INFO    : Bus 15762	: V=0.9782003, theta=-57.128283 -> V=1.0, theta=0.0
% INFO    : Bus 15763	: V=0.9860888, theta=-56.740821 -> V=1.0, theta=0.0
% INFO    : Bus 15764	: V=0.956714, theta=-58.709925 -> V=1.0, theta=0.0
% INFO    : Bus 15765	: V=0.9584764, theta=-58.696683 -> V=1.0, theta=0.0
% INFO    : Bus 15766	: V=0.9690999, theta=-57.7385 -> V=1.0, theta=0.0
% INFO    : Bus 15767	: V=0.9751251, theta=-57.169362 -> V=1.0, theta=0.0
% INFO    : Bus 15768	: V=0.9803202, theta=-56.795113 -> V=1.0, theta=0.0
% INFO    : Bus 15769	: V=0.9759984, theta=-57.156734 -> V=1.0, theta=0.0
% INFO    : Bus 15770	: V=0.9712624, theta=-57.612212 -> V=1.0, theta=0.0
% INFO    : Bus 15771	: V=0.9797838, theta=-56.886756 -> V=1.0, theta=0.0
% INFO    : Bus 15772	: V=0.9808238, theta=-57.095564 -> V=1.0, theta=0.0
% INFO    : Bus 15773	: V=0.9676022, theta=-58.001918 -> V=1.0, theta=0.0
% INFO    : Bus 15774	: V=0.982135, theta=-56.544604 -> V=1.0, theta=0.0
% INFO    : Bus 15775	: V=0.9796812, theta=-56.986789 -> V=1.0, theta=0.0
% INFO    : Bus 15776	: V=1.0022507, theta=-53.721701 -> V=1.0, theta=0.0
% INFO    : Bus 15777	: V=1.0001509, theta=-53.820913 -> V=1.0, theta=0.0
% INFO    : Bus 15778	: V=0.9803905, theta=-57.254341 -> V=1.0, theta=0.0
% INFO    : Bus 15779	: V=0.9810414, theta=-57.118669 -> V=1.0, theta=0.0
% INFO    : Bus 15780	: V=0.9808922, theta=-57.097286 -> V=1.0, theta=0.0
% INFO    : Bus 15781	: V=0.9806512, theta=-57.090335 -> V=1.0, theta=0.0
% INFO    : Bus 15782	: V=0.9817678, theta=-56.998283 -> V=1.0, theta=0.0
% INFO    : Bus 15783	: V=0.9804775, theta=-57.083274 -> V=1.0, theta=0.0
% INFO    : Bus 15784	: V=0.9783594, theta=-57.418708 -> V=1.0, theta=0.0
% INFO    : Bus 15785	: V=0.9986825, theta=-54.50368 -> V=1.0, theta=0.0
% INFO    : Bus 15786	: V=0.9840545, theta=-56.740253 -> V=1.0, theta=0.0
% INFO    : Bus 15787	: V=0.9824053, theta=-56.926805 -> V=1.0, theta=0.0
% INFO    : Bus 15788	: V=0.9788767, theta=-57.443184 -> V=1.0, theta=0.0
% INFO    : Bus 15789	: V=0.9845903, theta=-56.696622 -> V=1.0, theta=0.0
% INFO    : Bus 15790	: V=0.9898076, theta=-56.190968 -> V=1.0, theta=0.0
% INFO    : Bus 15791	: V=0.9902527, theta=-56.212258 -> V=1.0, theta=0.0
% INFO    : Bus 15792	: V=1.0006244, theta=-54.270396 -> V=1.0, theta=0.0
% INFO    : Bus 15793	: V=0.9862671, theta=-56.521353 -> V=1.0, theta=0.0
% INFO    : Bus 15794	: V=0.9777828, theta=-57.366235 -> V=1.0, theta=0.0
% INFO    : Bus 15795	: V=0.9754264, theta=-57.581627 -> V=1.0, theta=0.0
% INFO    : Bus 15796	: V=0.9844356, theta=-56.664065 -> V=1.0, theta=0.0
% INFO    : Bus 15797	: V=0.9755215, theta=-57.572623 -> V=1.0, theta=0.0
% INFO    : Bus 15798	: V=0.9776981, theta=-57.428726 -> V=1.0, theta=0.0
% INFO    : Bus 15799	: V=0.9749851, theta=-57.859433 -> V=1.0, theta=0.0
% INFO    : Bus 15800	: V=0.9703279, theta=-58.093233 -> V=1.0, theta=0.0
% INFO    : Bus 15801	: V=0.9709184, theta=-58.088531 -> V=1.0, theta=0.0
% INFO    : Bus 15802	: V=0.9742478, theta=-57.918852 -> V=1.0, theta=0.0
% INFO    : Bus 15803	: V=0.9728147, theta=-58.005274 -> V=1.0, theta=0.0
% INFO    : Bus 15804	: V=0.9800479, theta=-57.164966 -> V=1.0, theta=0.0
% INFO    : Bus 15805	: V=0.9786439, theta=-57.553763 -> V=1.0, theta=0.0
% INFO    : Bus 15806	: V=0.9739006, theta=-57.925574 -> V=1.0, theta=0.0
% INFO    : Bus 15807	: V=0.9710045, theta=-58.17878 -> V=1.0, theta=0.0
% INFO    : Bus 15808	: V=0.9709073, theta=-58.176461 -> V=1.0, theta=0.0
% INFO    : Bus 15809	: V=0.9712887, theta=-58.171802 -> V=1.0, theta=0.0
% INFO    : Bus 15810	: V=0.9710357, theta=-58.232067 -> V=1.0, theta=0.0
% INFO    : Bus 15811	: V=0.9659605, theta=-58.607036 -> V=1.0, theta=0.0
% INFO    : Bus 15812	: V=0.9740199, theta=-57.824919 -> V=1.0, theta=0.0
% INFO    : Bus 15813	: V=0.9749234, theta=-57.768481 -> V=1.0, theta=0.0
% INFO    : Bus 15814	: V=0.96528, theta=-58.624472 -> V=1.0, theta=0.0
% INFO    : Bus 15815	: V=0.9736708, theta=-57.845349 -> V=1.0, theta=0.0
% INFO    : Bus 15816	: V=0.9699455, theta=-58.117705 -> V=1.0, theta=0.0
% INFO    : Bus 15817	: V=0.9703396, theta=-58.113284 -> V=1.0, theta=0.0
% INFO    : Bus 15818	: V=0.9754248, theta=-57.470261 -> V=1.0, theta=0.0
% INFO    : Bus 15819	: V=0.9698187, theta=-58.078605 -> V=1.0, theta=0.0
% INFO    : Bus 15820	: V=0.9734731, theta=-57.854563 -> V=1.0, theta=0.0
% INFO    : Bus 15821	: V=0.9696446, theta=-58.124793 -> V=1.0, theta=0.0
% INFO    : Bus 15822	: V=0.9696515, theta=-58.121751 -> V=1.0, theta=0.0
% INFO    : Bus 15823	: V=0.9709716, theta=-57.818541 -> V=1.0, theta=0.0
% INFO    : Bus 15824	: V=0.9591121, theta=-58.944713 -> V=1.0, theta=0.0
% INFO    : Bus 15825	: V=0.963347, theta=-58.550484 -> V=1.0, theta=0.0
% INFO    : Bus 15826	: V=0.9557961, theta=-59.152308 -> V=1.0, theta=0.0
% INFO    : Bus 15827	: V=0.9588919, theta=-58.923099 -> V=1.0, theta=0.0
% INFO    : Bus 15828	: V=0.9597691, theta=-58.859196 -> V=1.0, theta=0.0
% INFO    : Bus 15829	: V=0.9570542, theta=-59.044464 -> V=1.0, theta=0.0
% INFO    : Bus 15830	: V=0.9571928, theta=-59.142324 -> V=1.0, theta=0.0
% INFO    : Bus 15831	: V=0.958005, theta=-59.065711 -> V=1.0, theta=0.0
% INFO    : Bus 15832	: V=0.9563113, theta=-59.205012 -> V=1.0, theta=0.0
% INFO    : Bus 15833	: V=0.9557943, theta=-59.295109 -> V=1.0, theta=0.0
% INFO    : Bus 15834	: V=0.9560033, theta=-59.324865 -> V=1.0, theta=0.0
% INFO    : Bus 15835	: V=0.9565084, theta=-59.320349 -> V=1.0, theta=0.0
% INFO    : Bus 15836	: V=0.9553328, theta=-59.296819 -> V=1.0, theta=0.0
% INFO    : Bus 15837	: V=0.9571211, theta=-59.299282 -> V=1.0, theta=0.0
% INFO    : Bus 15838	: V=0.9552477, theta=-59.316173 -> V=1.0, theta=0.0
% INFO    : Bus 15839	: V=0.955146, theta=-59.282531 -> V=1.0, theta=0.0
% INFO    : Bus 15840	: V=0.9558727, theta=-59.091578 -> V=1.0, theta=0.0
% INFO    : Bus 15841	: V=0.9565158, theta=-59.075979 -> V=1.0, theta=0.0
% INFO    : Bus 15842	: V=0.956249, theta=-59.063206 -> V=1.0, theta=0.0
% INFO    : Bus 15843	: V=0.9552727, theta=-58.830451 -> V=1.0, theta=0.0
% INFO    : Bus 15844	: V=0.9565183, theta=-58.805256 -> V=1.0, theta=0.0
% INFO    : Bus 15845	: V=0.9541072, theta=-58.856208 -> V=1.0, theta=0.0
% INFO    : Bus 15846	: V=0.9572496, theta=-58.796444 -> V=1.0, theta=0.0
% INFO    : Bus 15847	: V=0.9764366, theta=-57.301521 -> V=1.0, theta=0.0
% INFO    : Bus 15848	: V=0.9587846, theta=-44.779859 -> V=1.0, theta=0.0
% INFO    : Bus 15849	: V=0.9583661, theta=-44.711325 -> V=1.0, theta=0.0
% INFO    : Bus 15850	: V=0.9577943, theta=-44.484629 -> V=1.0, theta=0.0
% INFO    : Bus 15851	: V=0.9622459, theta=-44.45574 -> V=1.0, theta=0.0
% INFO    : Bus 15852	: V=0.9615416, theta=-44.590043 -> V=1.0, theta=0.0
% INFO    : Bus 15853	: V=0.9605424, theta=-44.592988 -> V=1.0, theta=0.0
% INFO    : Bus 15854	: V=0.9505148, theta=-46.505075 -> V=1.0, theta=0.0
% INFO    : Bus 15855	: V=0.9510684, theta=-46.435306 -> V=1.0, theta=0.0
% INFO    : Bus 15856	: V=0.9488504, theta=-46.627145 -> V=1.0, theta=0.0
% INFO    : Bus 15857	: V=0.9477472, theta=-46.677471 -> V=1.0, theta=0.0
% INFO    : Bus 15858	: V=0.9458849, theta=-46.743229 -> V=1.0, theta=0.0
% INFO    : Bus 15859	: V=0.9483443, theta=-46.385571 -> V=1.0, theta=0.0
% INFO    : Bus 15860	: V=0.9433157, theta=-46.589725 -> V=1.0, theta=0.0
% INFO    : Bus 15861	: V=0.9429064, theta=-46.604112 -> V=1.0, theta=0.0
% INFO    : Bus 15862	: V=0.9474593, theta=-46.18473 -> V=1.0, theta=0.0
% INFO    : Bus 15863	: V=0.9462012, theta=-46.193223 -> V=1.0, theta=0.0
% INFO    : Bus 15864	: V=0.9431298, theta=-46.574124 -> V=1.0, theta=0.0
% INFO    : Bus 15865	: V=0.9580008, theta=-44.163213 -> V=1.0, theta=0.0
% INFO    : Bus 15866	: V=0.9453071, theta=-45.978682 -> V=1.0, theta=0.0
% INFO    : Bus 15867	: V=0.9479486, theta=-45.394179 -> V=1.0, theta=0.0
% INFO    : Bus 15868	: V=0.9575954, theta=-44.020649 -> V=1.0, theta=0.0
% INFO    : Bus 15869	: V=0.9477827, theta=-45.527717 -> V=1.0, theta=0.0
% INFO    : Bus 15870	: V=0.9595963, theta=-45.037936 -> V=1.0, theta=0.0
% INFO    : Bus 15871	: V=0.9700321, theta=-43.82224 -> V=1.0, theta=0.0
% INFO    : Bus 15872	: V=0.9727272, theta=-43.836436 -> V=1.0, theta=0.0
% INFO    : Bus 15873	: V=0.9644346, theta=-44.403523 -> V=1.0, theta=0.0
% INFO    : Bus 15874	: V=0.9481284, theta=-46.694713 -> V=1.0, theta=0.0
% INFO    : Bus 15875	: V=0.9485837, theta=-46.635662 -> V=1.0, theta=0.0
% INFO    : Bus 15876	: V=0.9597646, theta=-45.070088 -> V=1.0, theta=0.0
% INFO    : Bus 15877	: V=0.9434084, theta=-47.049883 -> V=1.0, theta=0.0
% INFO    : Bus 15878	: V=0.936371, theta=-47.218283 -> V=1.0, theta=0.0
% INFO    : Bus 15879	: V=0.9350693, theta=-47.850257 -> V=1.0, theta=0.0
% INFO    : Bus 15880	: V=0.9370436, theta=-46.735493 -> V=1.0, theta=0.0
% INFO    : Bus 15881	: V=0.9317051, theta=-47.126 -> V=1.0, theta=0.0
% INFO    : Bus 15882	: V=0.9336047, theta=-46.358477 -> V=1.0, theta=0.0
% INFO    : Bus 15883	: V=0.9330439, theta=-46.334119 -> V=1.0, theta=0.0
% INFO    : Bus 15884	: V=0.945555, theta=-49.098287 -> V=1.0, theta=0.0
% INFO    : Bus 15885	: V=0.9499717, theta=-48.756003 -> V=1.0, theta=0.0
% INFO    : Bus 15886	: V=0.9537669, theta=-46.893159 -> V=1.0, theta=0.0
% INFO    : Bus 15887	: V=0.9427247, theta=-48.225849 -> V=1.0, theta=0.0
% INFO    : Bus 15888	: V=0.9530766, theta=-46.943642 -> V=1.0, theta=0.0
% INFO    : Bus 15889	: V=0.9657324, theta=-45.659736 -> V=1.0, theta=0.0
% INFO    : Bus 15890	: V=0.9588952, theta=-45.88358 -> V=1.0, theta=0.0
% INFO    : Bus 15891	: V=0.9692418, theta=-48.561852 -> V=1.0, theta=0.0
% INFO    : Bus 15892	: V=0.9638261, theta=-49.075725 -> V=1.0, theta=0.0
% INFO    : Bus 15893	: V=0.9546669, theta=-50.053411 -> V=1.0, theta=0.0
% INFO    : Bus 15894	: V=1.0198339, theta=-36.370755 -> V=1.0, theta=0.0
% INFO    : Bus 15895	: V=0.991236, theta=-39.869573 -> V=1.0, theta=0.0
% INFO    : Bus 15896	: V=0.9897743, theta=-38.483621 -> V=1.0, theta=0.0
% INFO    : Bus 15897	: V=1.0056649, theta=-37.274666 -> V=1.0, theta=0.0
% INFO    : Bus 15898	: V=0.9827136, theta=-39.17752 -> V=1.0, theta=0.0
% INFO    : Bus 15899	: V=0.9739586, theta=-39.27455 -> V=1.0, theta=0.0
% INFO    : Bus 15900	: V=0.9643701, theta=-48.800087 -> V=1.0, theta=0.0
% INFO    : Bus 15901	: V=0.9623847, theta=-48.817335 -> V=1.0, theta=0.0
% INFO    : Bus 15902	: V=0.9639347, theta=-48.718888 -> V=1.0, theta=0.0
% INFO    : Bus 15903	: V=0.9555152, theta=-49.988003 -> V=1.0, theta=0.0
% INFO    : Bus 15904	: V=0.9672331, theta=-48.314071 -> V=1.0, theta=0.0
% INFO    : Bus 15905	: V=0.9524184, theta=-50.272723 -> V=1.0, theta=0.0
% INFO    : Bus 15906	: V=1.0025675, theta=-42.93157 -> V=1.0, theta=0.0
% INFO    : Bus 15907	: V=0.9873872, theta=-45.123996 -> V=1.0, theta=0.0
% INFO    : Bus 15908	: V=1.0009221, theta=-43.22326 -> V=1.0, theta=0.0
% INFO    : Bus 15909	: V=0.9762459, theta=-46.066678 -> V=1.0, theta=0.0
% INFO    : Bus 15910	: V=0.9768541, theta=-46.01384 -> V=1.0, theta=0.0
% INFO    : Bus 15911	: V=0.9612479, theta=-41.679929 -> V=1.0, theta=0.0
% INFO    : Bus 15912	: V=0.9611862, theta=-42.262941 -> V=1.0, theta=0.0
% INFO    : Bus 15913	: V=0.9614267, theta=-41.969968 -> V=1.0, theta=0.0
% INFO    : Bus 15914	: V=0.9446386, theta=-44.326815 -> V=1.0, theta=0.0
% INFO    : Bus 15915	: V=0.9476152, theta=-43.685349 -> V=1.0, theta=0.0
% INFO    : Bus 15916	: V=0.9469699, theta=-43.869077 -> V=1.0, theta=0.0
% INFO    : Bus 15917	: V=0.9565441, theta=-43.306807 -> V=1.0, theta=0.0
% INFO    : Bus 15918	: V=0.962849, theta=-41.188305 -> V=1.0, theta=0.0
% INFO    : Bus 15919	: V=0.9633222, theta=-40.101748 -> V=1.0, theta=0.0
% INFO    : Bus 15920	: V=0.9521725, theta=-42.885198 -> V=1.0, theta=0.0
% INFO    : Bus 15921	: V=0.963117, theta=-41.620118 -> V=1.0, theta=0.0
% INFO    : Bus 15922	: V=0.9639212, theta=-43.765311 -> V=1.0, theta=0.0
% INFO    : Bus 15923	: V=0.9614179, theta=-43.844455 -> V=1.0, theta=0.0
% INFO    : Bus 15924	: V=0.9555902, theta=-44.291956 -> V=1.0, theta=0.0
% INFO    : Bus 15925	: V=0.9336271, theta=-48.510167 -> V=1.0, theta=0.0
% INFO    : Bus 15926	: V=0.9668583, theta=-35.931622 -> V=1.0, theta=0.0
% INFO    : Bus 15927	: V=0.9932186, theta=-36.969632 -> V=1.0, theta=0.0
% INFO    : Bus 15928	: V=0.9964043, theta=-37.080839 -> V=1.0, theta=0.0
% INFO    : Bus 15929	: V=1.0013997, theta=-34.97976 -> V=1.0, theta=0.0
% INFO    : Bus 15930	: V=1.0076747, theta=-35.024189 -> V=1.0, theta=0.0
% INFO    : Bus 15931	: V=0.9929915, theta=-34.746064 -> V=1.0, theta=0.0
% INFO    : Bus 15932	: V=0.9992776, theta=-28.92908 -> V=1.0, theta=0.0
% INFO    : Bus 15933	: V=0.9842911, theta=-29.797035 -> V=1.0, theta=0.0
% INFO    : Bus 15934	: V=1.0017281, theta=-27.921698 -> V=1.0, theta=0.0
% INFO    : Bus 15935	: V=0.9947011, theta=-28.751665 -> V=1.0, theta=0.0
% INFO    : Bus 15936	: V=0.9938291, theta=-28.766162 -> V=1.0, theta=0.0
% INFO    : Bus 15937	: V=0.9933225, theta=-27.896921 -> V=1.0, theta=0.0
% INFO    : Bus 15938	: V=1.0032496, theta=-26.831813 -> V=1.0, theta=0.0
% INFO    : Bus 15939	: V=1.0058928, theta=-26.022929 -> V=1.0, theta=0.0
% INFO    : Bus 15940	: V=0.9948971, theta=-26.85475 -> V=1.0, theta=0.0
% INFO    : Bus 15941	: V=1.0022545, theta=-25.680082 -> V=1.0, theta=0.0
% INFO    : Bus 15942	: V=1.0118663, theta=-24.369459 -> V=1.0, theta=0.0
% INFO    : Bus 15943	: V=1.015626, theta=-24.318332 -> V=1.0, theta=0.0
% INFO    : Bus 15944	: V=1.0198568, theta=-23.688513 -> V=1.0, theta=0.0
% INFO    : Bus 15945	: V=0.9972804, theta=-26.461434 -> V=1.0, theta=0.0
% INFO    : Bus 15946	: V=0.9998998, theta=-26.054053 -> V=1.0, theta=0.0
% INFO    : Bus 15947	: V=1.0106934, theta=-24.375548 -> V=1.0, theta=0.0
% INFO    : Bus 15948	: V=0.9866739, theta=-27.883952 -> V=1.0, theta=0.0
% INFO    : Bus 15949	: V=0.9904717, theta=-27.275709 -> V=1.0, theta=0.0
% INFO    : Bus 15950	: V=0.9888326, theta=-27.872248 -> V=1.0, theta=0.0
% INFO    : Bus 15951	: V=0.9943857, theta=-26.966738 -> V=1.0, theta=0.0
% INFO    : Bus 15952	: V=0.9541953, theta=-32.414778 -> V=1.0, theta=0.0
% INFO    : Bus 15953	: V=0.9581385, theta=-31.553413 -> V=1.0, theta=0.0
% INFO    : Bus 15954	: V=0.9765978, theta=-29.254746 -> V=1.0, theta=0.0
% INFO    : Bus 15955	: V=0.9616547, theta=-31.107528 -> V=1.0, theta=0.0
% INFO    : Bus 15956	: V=0.9651381, theta=-30.787708 -> V=1.0, theta=0.0
% INFO    : Bus 15957	: V=0.9638443, theta=-30.930498 -> V=1.0, theta=0.0
% INFO    : Bus 15958	: V=0.9691267, theta=-30.332297 -> V=1.0, theta=0.0
% INFO    : Bus 15959	: V=0.9751988, theta=-29.271965 -> V=1.0, theta=0.0
% INFO    : Bus 15960	: V=0.9689607, theta=-30.333826 -> V=1.0, theta=0.0
% INFO    : Bus 15961	: V=0.9765635, theta=-28.566802 -> V=1.0, theta=0.0
% INFO    : Bus 15962	: V=1.0011834, theta=-27.490109 -> V=1.0, theta=0.0
% INFO    : Bus 15963	: V=0.9949469, theta=-26.917816 -> V=1.0, theta=0.0
% INFO    : Bus 15964	: V=0.9460113, theta=-50.198959 -> V=1.0, theta=0.0
% INFO    : Bus 15965	: V=0.9467721, theta=-50.251115 -> V=1.0, theta=0.0
% INFO    : Bus 15966	: V=0.9455723, theta=-50.275472 -> V=1.0, theta=0.0
% INFO    : Bus 15967	: V=0.9446239, theta=-50.31565 -> V=1.0, theta=0.0
% INFO    : Bus 15968	: V=0.9482055, theta=-50.050135 -> V=1.0, theta=0.0
% INFO    : Bus 15969	: V=0.9465161, theta=-50.166783 -> V=1.0, theta=0.0
% INFO    : Bus 15970	: V=0.9461082, theta=-50.184234 -> V=1.0, theta=0.0
% INFO    : Bus 15971	: V=0.9465248, theta=-50.127226 -> V=1.0, theta=0.0
% INFO    : Bus 15972	: V=0.9535829, theta=-48.449865 -> V=1.0, theta=0.0
% INFO    : Bus 15973	: V=0.9468306, theta=-50.004622 -> V=1.0, theta=0.0
% INFO    : Bus 15974	: V=0.9470268, theta=-50.071493 -> V=1.0, theta=0.0
% INFO    : Bus 15975	: V=0.9475315, theta=-50.129244 -> V=1.0, theta=0.0
% INFO    : Bus 15976	: V=0.9479514, theta=-50.109836 -> V=1.0, theta=0.0
% INFO    : Bus 15977	: V=0.9494689, theta=-50.103653 -> V=1.0, theta=0.0
% INFO    : Bus 15978	: V=0.9502765, theta=-50.033848 -> V=1.0, theta=0.0
% INFO    : Bus 15979	: V=0.9583739, theta=-49.043315 -> V=1.0, theta=0.0
% INFO    : Bus 15980	: V=0.9496216, theta=-49.97074 -> V=1.0, theta=0.0
% INFO    : Bus 15981	: V=0.9452058, theta=-50.232191 -> V=1.0, theta=0.0
% INFO    : Bus 15982	: V=0.9440658, theta=-50.267252 -> V=1.0, theta=0.0
% INFO    : Bus 15983	: V=0.9432335, theta=-50.149863 -> V=1.0, theta=0.0
% INFO    : Bus 15984	: V=0.9453128, theta=-50.042775 -> V=1.0, theta=0.0
% INFO    : Bus 15985	: V=0.9492215, theta=-49.814522 -> V=1.0, theta=0.0
% INFO    : Bus 15986	: V=0.9500851, theta=-48.164206 -> V=1.0, theta=0.0
% INFO    : Bus 15987	: V=0.9377244, theta=-50.704803 -> V=1.0, theta=0.0
% INFO    : Bus 15988	: V=0.9409972, theta=-50.443956 -> V=1.0, theta=0.0
% INFO    : Bus 15989	: V=0.9379747, theta=-50.692094 -> V=1.0, theta=0.0
% INFO    : Bus 15990	: V=0.9410803, theta=-50.425212 -> V=1.0, theta=0.0
% INFO    : Bus 15991	: V=0.9516287, theta=-48.703409 -> V=1.0, theta=0.0
% INFO    : Bus 15992	: V=0.9543225, theta=-48.471657 -> V=1.0, theta=0.0
% INFO    : Bus 15993	: V=0.9613578, theta=-48.511468 -> V=1.0, theta=0.0
% INFO    : Bus 15994	: V=0.9573213, theta=-48.964003 -> V=1.0, theta=0.0
% INFO    : Bus 15995	: V=0.9465844, theta=-50.204169 -> V=1.0, theta=0.0
% INFO    : Bus 15996	: V=0.9446814, theta=-50.260567 -> V=1.0, theta=0.0
% INFO    : Bus 15997	: V=0.9499139, theta=-49.971202 -> V=1.0, theta=0.0
% INFO    : Bus 15998	: V=0.9483031, theta=-50.077994 -> V=1.0, theta=0.0
% INFO    : Bus 15999	: V=0.96602, theta=-48.598163 -> V=1.0, theta=0.0
% INFO    : Bus 16000	: V=0.9640144, theta=-48.99928 -> V=1.0, theta=0.0
% INFO    : Bus 16001	: V=0.9459738, theta=-50.125852 -> V=1.0, theta=0.0
% INFO    : Bus 16002	: V=0.9450651, theta=-50.332882 -> V=1.0, theta=0.0
% INFO    : Bus 16003	: V=0.9472892, theta=-50.266847 -> V=1.0, theta=0.0
% INFO    : Bus 16004	: V=0.9524655, theta=-49.784556 -> V=1.0, theta=0.0
% INFO    : Bus 16005	: V=0.9615784, theta=-48.839935 -> V=1.0, theta=0.0
% INFO    : Bus 16006	: V=0.9533992, theta=-49.715909 -> V=1.0, theta=0.0
% INFO    : Bus 16007	: V=0.9713923, theta=-48.06119 -> V=1.0, theta=0.0
% INFO    : Bus 16008	: V=0.9669117, theta=-48.425943 -> V=1.0, theta=0.0
% INFO    : Bus 16009	: V=0.9555056, theta=-49.354837 -> V=1.0, theta=0.0
% INFO    : Bus 16010	: V=0.9432791, theta=-50.153173 -> V=1.0, theta=0.0
% INFO    : Bus 16011	: V=0.9386148, theta=-50.501341 -> V=1.0, theta=0.0
% INFO    : Bus 16012	: V=0.9534597, theta=-48.158135 -> V=1.0, theta=0.0
% INFO    : Bus 16013	: V=0.9379971, theta=-50.143592 -> V=1.0, theta=0.0
% INFO    : Bus 16014	: V=0.9457516, theta=-49.464178 -> V=1.0, theta=0.0
% INFO    : Bus 16015	: V=0.9445413, theta=-49.893278 -> V=1.0, theta=0.0
% INFO    : Bus 16016	: V=0.9387328, theta=-50.469194 -> V=1.0, theta=0.0
% INFO    : Bus 16017	: V=0.9544952, theta=-47.682899 -> V=1.0, theta=0.0
% INFO    : Bus 16018	: V=0.9582219, theta=-47.047502 -> V=1.0, theta=0.0
% INFO    : Bus 16019	: V=0.964601, theta=-46.0024 -> V=1.0, theta=0.0
% INFO    : Bus 16020	: V=0.9580469, theta=-47.747979 -> V=1.0, theta=0.0
% INFO    : Bus 16021	: V=0.9532045, theta=-48.222058 -> V=1.0, theta=0.0
% INFO    : Bus 16022	: V=0.9496599, theta=-48.096562 -> V=1.0, theta=0.0
% INFO    : Bus 16023	: V=0.9509113, theta=-47.543264 -> V=1.0, theta=0.0
% INFO    : Bus 16024	: V=0.9473358, theta=-48.343889 -> V=1.0, theta=0.0
% INFO    : Bus 16025	: V=0.9434664, theta=-48.292906 -> V=1.0, theta=0.0
% INFO    : Bus 16026	: V=0.9397844, theta=-48.863533 -> V=1.0, theta=0.0
% INFO    : Bus 16027	: V=0.9420475, theta=-48.339563 -> V=1.0, theta=0.0
% INFO    : Bus 16028	: V=0.9401606, theta=-48.654365 -> V=1.0, theta=0.0
% INFO    : Bus 16029	: V=0.9605768, theta=-45.78782 -> V=1.0, theta=0.0
% INFO    : Bus 16030	: V=0.953691, theta=-47.257641 -> V=1.0, theta=0.0
% INFO    : Bus 16031	: V=0.9664962, theta=-45.395849 -> V=1.0, theta=0.0
% INFO    : Bus 16032	: V=0.9438976, theta=-47.842592 -> V=1.0, theta=0.0
% INFO    : Bus 16033	: V=0.9562998, theta=-46.378682 -> V=1.0, theta=0.0
% INFO    : Bus 16034	: V=0.9500882, theta=-44.076822 -> V=1.0, theta=0.0
% INFO    : Bus 16035	: V=0.945664, theta=-48.403089 -> V=1.0, theta=0.0
% INFO    : Bus 16036	: V=0.9402079, theta=-48.56824 -> V=1.0, theta=0.0
% INFO    : Bus 16037	: V=0.946334, theta=-47.670232 -> V=1.0, theta=0.0
% INFO    : Bus 16038	: V=0.9646501, theta=-42.118659 -> V=1.0, theta=0.0
% INFO    : Bus 16039	: V=0.9770934, theta=-41.741147 -> V=1.0, theta=0.0
% INFO    : Bus 16040	: V=0.9902567, theta=-40.566645 -> V=1.0, theta=0.0
% INFO    : Bus 16041	: V=0.9888126, theta=-40.487301 -> V=1.0, theta=0.0
% INFO    : Bus 16042	: V=0.9861203, theta=-40.660241 -> V=1.0, theta=0.0
% INFO    : Bus 16043	: V=0.9883491, theta=-40.426865 -> V=1.0, theta=0.0
% INFO    : Bus 16044	: V=0.9818982, theta=-40.988252 -> V=1.0, theta=0.0
% INFO    : Bus 16045	: V=0.9880998, theta=-40.368049 -> V=1.0, theta=0.0
% INFO    : Bus 16046	: V=0.9784566, theta=-41.243965 -> V=1.0, theta=0.0
% INFO    : Bus 16047	: V=0.988001, theta=-40.138508 -> V=1.0, theta=0.0
% INFO    : Bus 16048	: V=0.9906212, theta=-39.773054 -> V=1.0, theta=0.0
% INFO    : Bus 16049	: V=0.9864389, theta=-40.04353 -> V=1.0, theta=0.0
% INFO    : Bus 16050	: V=0.9861678, theta=-39.944837 -> V=1.0, theta=0.0
% INFO    : Bus 16051	: V=0.9740577, theta=-40.511129 -> V=1.0, theta=0.0
% INFO    : Bus 16052	: V=0.9660022, theta=-40.960754 -> V=1.0, theta=0.0
% INFO    : Bus 16053	: V=0.9684703, theta=-41.355322 -> V=1.0, theta=0.0
% INFO    : Bus 16054	: V=0.9539856, theta=-41.293784 -> V=1.0, theta=0.0
% INFO    : Bus 16055	: V=0.9664698, theta=-41.930071 -> V=1.0, theta=0.0
% INFO    : Bus 16056	: V=0.9695408, theta=-42.057405 -> V=1.0, theta=0.0
% INFO    : Bus 16057	: V=0.9746361, theta=-41.993974 -> V=1.0, theta=0.0
% INFO    : Bus 16058	: V=0.9724358, theta=-41.796396 -> V=1.0, theta=0.0
% INFO    : Bus 16059	: V=0.9797651, theta=-41.067746 -> V=1.0, theta=0.0
% INFO    : Bus 16060	: V=0.9697834, theta=-41.654841 -> V=1.0, theta=0.0
% INFO    : Bus 16061	: V=0.9789242, theta=-41.113842 -> V=1.0, theta=0.0
% INFO    : Bus 16062	: V=0.9718655, theta=-41.790635 -> V=1.0, theta=0.0
% INFO    : Bus 16063	: V=0.9669453, theta=-42.095614 -> V=1.0, theta=0.0
% INFO    : Bus 16064	: V=0.9807486, theta=-40.996934 -> V=1.0, theta=0.0
% INFO    : Bus 16065	: V=0.9843386, theta=-40.794358 -> V=1.0, theta=0.0
% INFO    : Bus 16066	: V=0.9770441, theta=-41.604543 -> V=1.0, theta=0.0
% INFO    : Bus 16067	: V=0.9833998, theta=-40.616099 -> V=1.0, theta=0.0
% INFO    : Bus 16068	: V=0.9724563, theta=-41.748709 -> V=1.0, theta=0.0
% INFO    : Bus 16069	: V=0.9746858, theta=-41.486896 -> V=1.0, theta=0.0
% INFO    : Bus 16070	: V=0.9739113, theta=-41.49345 -> V=1.0, theta=0.0
% INFO    : Bus 16071	: V=0.9839305, theta=-40.362879 -> V=1.0, theta=0.0
% INFO    : Bus 16072	: V=0.9713971, theta=-41.425578 -> V=1.0, theta=0.0
% INFO    : Bus 16073	: V=0.9696582, theta=-41.621656 -> V=1.0, theta=0.0
% INFO    : Bus 16074	: V=0.9691978, theta=-41.211845 -> V=1.0, theta=0.0
% INFO    : Bus 16075	: V=0.9540613, theta=-47.26255 -> V=1.0, theta=0.0
% INFO    : Bus 16076	: V=0.9546885, theta=-48.553842 -> V=1.0, theta=0.0
% INFO    : Bus 16077	: V=0.9521276, theta=-47.338944 -> V=1.0, theta=0.0
% INFO    : Bus 16078	: V=0.9421039, theta=-49.113711 -> V=1.0, theta=0.0
% INFO    : Bus 16079	: V=0.9541146, theta=-47.452983 -> V=1.0, theta=0.0
% INFO    : Bus 16080	: V=0.9526984, theta=-47.19761 -> V=1.0, theta=0.0
% INFO    : Bus 16081	: V=0.9451962, theta=-48.646004 -> V=1.0, theta=0.0
% INFO    : Bus 16082	: V=0.9366582, theta=-49.427197 -> V=1.0, theta=0.0
% INFO    : Bus 16083	: V=0.9829437, theta=-45.036698 -> V=1.0, theta=0.0
% INFO    : Bus 16084	: V=0.9626538, theta=-47.737912 -> V=1.0, theta=0.0
% INFO    : Bus 16085	: V=0.9555034, theta=-47.93953 -> V=1.0, theta=0.0
% INFO    : Bus 16086	: V=0.9509633, theta=-48.636132 -> V=1.0, theta=0.0
% INFO    : Bus 16087	: V=0.9463376, theta=-48.630415 -> V=1.0, theta=0.0
% INFO    : Bus 16088	: V=0.9574253, theta=-46.003283 -> V=1.0, theta=0.0
% INFO    : Bus 16089	: V=0.9473793, theta=-48.437767 -> V=1.0, theta=0.0
% INFO    : Bus 16090	: V=0.9569377, theta=-46.960709 -> V=1.0, theta=0.0
% INFO    : Bus 16091	: V=0.9563212, theta=-46.742106 -> V=1.0, theta=0.0
% INFO    : Bus 16092	: V=0.9666226, theta=-44.399673 -> V=1.0, theta=0.0
% INFO    : Bus 16093	: V=0.968832, theta=-44.435568 -> V=1.0, theta=0.0
% INFO    : Bus 16094	: V=0.9369517, theta=-44.119123 -> V=1.0, theta=0.0
% INFO    : Bus 16095	: V=0.9351188, theta=-43.366319 -> V=1.0, theta=0.0
% INFO    : Bus 16096	: V=0.9319523, theta=-41.064932 -> V=1.0, theta=0.0
% INFO    : Bus 16097	: V=0.9349643, theta=-40.967807 -> V=1.0, theta=0.0
% INFO    : Bus 16098	: V=0.9348903, theta=-42.177835 -> V=1.0, theta=0.0
% INFO    : Bus 16099	: V=0.9376515, theta=-40.619605 -> V=1.0, theta=0.0
% INFO    : Bus 16100	: V=0.9386105, theta=-40.590889 -> V=1.0, theta=0.0
% INFO    : Bus 16101	: V=0.9361129, theta=-40.933846 -> V=1.0, theta=0.0
% INFO    : Bus 16102	: V=0.943362, theta=-40.243555 -> V=1.0, theta=0.0
% INFO    : Bus 16103	: V=0.9524732, theta=-38.499547 -> V=1.0, theta=0.0
% INFO    : Bus 16104	: V=0.9409815, theta=-40.361865 -> V=1.0, theta=0.0
% INFO    : Bus 16105	: V=0.9555723, theta=-38.222779 -> V=1.0, theta=0.0
% INFO    : Bus 16106	: V=0.9444726, theta=-40.198897 -> V=1.0, theta=0.0
% INFO    : Bus 16107	: V=0.9440428, theta=-40.212956 -> V=1.0, theta=0.0
% INFO    : Bus 16108	: V=0.945872, theta=-40.149834 -> V=1.0, theta=0.0
% INFO    : Bus 16109	: V=0.9522722, theta=-38.513013 -> V=1.0, theta=0.0
% INFO    : Bus 16110	: V=0.9601643, theta=-37.402165 -> V=1.0, theta=0.0
% INFO    : Bus 16111	: V=0.9604348, theta=-37.409835 -> V=1.0, theta=0.0
% INFO    : Bus 16112	: V=0.9470463, theta=-39.724396 -> V=1.0, theta=0.0
% INFO    : Bus 16113	: V=0.9467827, theta=-39.72617 -> V=1.0, theta=0.0
% INFO    : Bus 16114	: V=0.9527854, theta=-38.55903 -> V=1.0, theta=0.0
% INFO    : Bus 16115	: V=0.9520893, theta=-38.600111 -> V=1.0, theta=0.0
% INFO    : Bus 16116	: V=0.9612612, theta=-37.417627 -> V=1.0, theta=0.0
% INFO    : Bus 16117	: V=0.9539597, theta=-39.015966 -> V=1.0, theta=0.0
% INFO    : Bus 16118	: V=0.95003, theta=-37.994504 -> V=1.0, theta=0.0
% INFO    : Bus 16119	: V=0.9571622, theta=-37.224563 -> V=1.0, theta=0.0
% INFO    : Bus 16120	: V=0.9516162, theta=-38.21769 -> V=1.0, theta=0.0
% INFO    : Bus 16121	: V=0.9477334, theta=-38.378433 -> V=1.0, theta=0.0
% INFO    : Bus 16122	: V=0.9483516, theta=-38.452988 -> V=1.0, theta=0.0
% INFO    : Bus 16123	: V=0.9518494, theta=-38.136118 -> V=1.0, theta=0.0
% INFO    : Bus 16124	: V=0.957566, theta=-37.278117 -> V=1.0, theta=0.0
% INFO    : Bus 16125	: V=0.9580554, theta=-37.311354 -> V=1.0, theta=0.0
% INFO    : Bus 16126	: V=0.959478, theta=-37.374568 -> V=1.0, theta=0.0
% INFO    : Bus 16127	: V=0.9461783, theta=-39.751494 -> V=1.0, theta=0.0
% INFO    : Bus 16128	: V=0.942686, theta=-40.264276 -> V=1.0, theta=0.0
% INFO    : Bus 16129	: V=0.9401546, theta=-40.437453 -> V=1.0, theta=0.0
% INFO    : Bus 16130	: V=1.0007085, theta=-39.201212 -> V=1.0, theta=0.0
% INFO    : Bus 16131	: V=1.0018903, theta=-40.183624 -> V=1.0, theta=0.0
% INFO    : Bus 16132	: V=0.9824685, theta=-42.427152 -> V=1.0, theta=0.0
% INFO    : Bus 16133	: V=0.9894502, theta=-42.07927 -> V=1.0, theta=0.0
% INFO    : Bus 16134	: V=0.9840842, theta=-42.560635 -> V=1.0, theta=0.0
% INFO    : Bus 16135	: V=0.9849151, theta=-41.167753 -> V=1.0, theta=0.0
% INFO    : Bus 16136	: V=0.9693089, theta=-44.696836 -> V=1.0, theta=0.0
% INFO    : Bus 16137	: V=0.9648946, theta=-44.45121 -> V=1.0, theta=0.0
% INFO    : Bus 16138	: V=0.9717229, theta=-44.605748 -> V=1.0, theta=0.0
% INFO    : Bus 16139	: V=0.9742209, theta=-43.275992 -> V=1.0, theta=0.0
% INFO    : Bus 16140	: V=0.9653516, theta=-44.800551 -> V=1.0, theta=0.0
% INFO    : Bus 16141	: V=0.9627365, theta=-45.252215 -> V=1.0, theta=0.0
% INFO    : Bus 16142	: V=0.9671571, theta=-44.541061 -> V=1.0, theta=0.0
% INFO    : Bus 16143	: V=0.9763404, theta=-43.225477 -> V=1.0, theta=0.0
% INFO    : Bus 16144	: V=0.9655342, theta=-44.937934 -> V=1.0, theta=0.0
% INFO    : Bus 16145	: V=0.9755043, theta=-43.471534 -> V=1.0, theta=0.0
% INFO    : Bus 16146	: V=0.9749605, theta=-43.514395 -> V=1.0, theta=0.0
% INFO    : Bus 16147	: V=0.9602414, theta=-45.571799 -> V=1.0, theta=0.0
% INFO    : Bus 16148	: V=0.9862089, theta=-42.25081 -> V=1.0, theta=0.0
% INFO    : Bus 16149	: V=0.9661798, theta=-45.076787 -> V=1.0, theta=0.0
% INFO    : Bus 16150	: V=0.9707378, theta=-44.398939 -> V=1.0, theta=0.0
% INFO    : Bus 16151	: V=1.005998, theta=-38.954775 -> V=1.0, theta=0.0
% INFO    : Bus 16152	: V=0.9631973, theta=-45.318216 -> V=1.0, theta=0.0
% INFO    : Bus 16153	: V=0.9698797, theta=-44.477453 -> V=1.0, theta=0.0
% INFO    : Bus 16154	: V=0.9723408, theta=-43.024185 -> V=1.0, theta=0.0
% INFO    : Bus 16155	: V=0.9715363, theta=-42.890539 -> V=1.0, theta=0.0
% INFO    : Bus 16156	: V=0.9716131, theta=-43.495083 -> V=1.0, theta=0.0
% INFO    : Bus 16157	: V=0.9739276, theta=-42.237146 -> V=1.0, theta=0.0
% INFO    : Bus 16158	: V=0.9644751, theta=-43.815919 -> V=1.0, theta=0.0
% INFO    : Bus 16159	: V=0.964296, theta=-43.850185 -> V=1.0, theta=0.0
% INFO    : Bus 16160	: V=0.9802197, theta=-41.057399 -> V=1.0, theta=0.0
% INFO    : Bus 16161	: V=0.9619852, theta=-43.695381 -> V=1.0, theta=0.0
% INFO    : Bus 16162	: V=0.981706, theta=-40.85412 -> V=1.0, theta=0.0
% INFO    : Bus 16163	: V=0.9741964, theta=-43.071914 -> V=1.0, theta=0.0
% INFO    : Bus 16164	: V=0.9782202, theta=-41.557668 -> V=1.0, theta=0.0
% INFO    : Bus 16165	: V=0.9622276, theta=-45.398072 -> V=1.0, theta=0.0
% INFO    : Bus 16166	: V=0.9478794, theta=-44.338524 -> V=1.0, theta=0.0
% INFO    : Bus 16167	: V=0.9579486, theta=-43.470485 -> V=1.0, theta=0.0
% INFO    : Bus 16168	: V=0.964345, theta=-42.749098 -> V=1.0, theta=0.0
% INFO    : Bus 16169	: V=0.9559346, theta=-43.779199 -> V=1.0, theta=0.0
% INFO    : Bus 16170	: V=0.9538905, theta=-44.07013 -> V=1.0, theta=0.0
% INFO    : Bus 16171	: V=0.9475682, theta=-45.56406 -> V=1.0, theta=0.0
% INFO    : Bus 16172	: V=0.9277182, theta=-48.377234 -> V=1.0, theta=0.0
% INFO    : Bus 16173	: V=0.9296856, theta=-48.252686 -> V=1.0, theta=0.0
% INFO    : Bus 16174	: V=0.9288145, theta=-48.639102 -> V=1.0, theta=0.0
% INFO    : Bus 16175	: V=0.9734718, theta=-42.640658 -> V=1.0, theta=0.0
% INFO    : Bus 16176	: V=0.9825397, theta=-41.351128 -> V=1.0, theta=0.0
% INFO    : Bus 16177	: V=0.95793, theta=-42.990605 -> V=1.0, theta=0.0
% INFO    : Bus 16178	: V=1.0104163, theta=-38.211411 -> V=1.0, theta=0.0
% INFO    : Bus 16179	: V=0.9882029, theta=-40.221274 -> V=1.0, theta=0.0
% INFO    : Bus 16180	: V=0.9999947, theta=-38.758119 -> V=1.0, theta=0.0
% INFO    : Bus 16181	: V=0.9957036, theta=-38.924386 -> V=1.0, theta=0.0
% INFO    : Bus 16182	: V=1.0197398, theta=-36.071613 -> V=1.0, theta=0.0
% INFO    : Bus 16183	: V=1.0053258, theta=-38.009736 -> V=1.0, theta=0.0
% INFO    : Bus 16184	: V=1.0006125, theta=-38.349517 -> V=1.0, theta=0.0
% INFO    : Bus 16185	: V=1.0082508, theta=-37.596754 -> V=1.0, theta=0.0
% INFO    : Bus 16186	: V=1.0029302, theta=-37.353757 -> V=1.0, theta=0.0
% INFO    : Bus 16187	: V=0.9591714, theta=-44.347965 -> V=1.0, theta=0.0
% INFO    : Bus 16188	: V=0.9497642, theta=-45.974291 -> V=1.0, theta=0.0
% INFO    : Bus 16189	: V=0.9620798, theta=-44.208247 -> V=1.0, theta=0.0
% INFO    : Bus 16190	: V=0.985877, theta=-39.165219 -> V=1.0, theta=0.0
% INFO    : Bus 16191	: V=0.9838, theta=-39.387545 -> V=1.0, theta=0.0
% INFO    : Bus 16192	: V=0.9566327, theta=-43.260126 -> V=1.0, theta=0.0
% INFO    : Bus 16193	: V=0.979492, theta=-41.210472 -> V=1.0, theta=0.0
% INFO    : Bus 16194	: V=0.9622237, theta=-42.686041 -> V=1.0, theta=0.0
% INFO    : Bus 16195	: V=0.9627049, theta=-42.385978 -> V=1.0, theta=0.0
% INFO    : Bus 16196	: V=0.9588955, theta=-41.456469 -> V=1.0, theta=0.0
% INFO    : Bus 16197	: V=0.9667352, theta=-39.992899 -> V=1.0, theta=0.0
% INFO    : Bus 16198	: V=0.9676546, theta=-39.908713 -> V=1.0, theta=0.0
% INFO    : Bus 16199	: V=0.9601884, theta=-41.57016 -> V=1.0, theta=0.0
% INFO    : Bus 16200	: V=0.964109, theta=-41.454371 -> V=1.0, theta=0.0
% INFO    : Bus 16201	: V=0.96436, theta=-42.022421 -> V=1.0, theta=0.0
% INFO    : Bus 16202	: V=0.9682653, theta=-42.171937 -> V=1.0, theta=0.0
% INFO    : Bus 16203	: V=0.9873374, theta=-40.315901 -> V=1.0, theta=0.0
% INFO    : Bus 16204	: V=0.9689868, theta=-42.004186 -> V=1.0, theta=0.0
% INFO    : Bus 16205	: V=0.9694787, theta=-41.980573 -> V=1.0, theta=0.0
% INFO    : Bus 16206	: V=0.9905412, theta=-40.144312 -> V=1.0, theta=0.0
% INFO    : Bus 16207	: V=0.989116, theta=-40.286 -> V=1.0, theta=0.0
% INFO    : Bus 16208	: V=0.9932214, theta=-40.090636 -> V=1.0, theta=0.0
% INFO    : Bus 16209	: V=1.0080953, theta=-38.966727 -> V=1.0, theta=0.0
% INFO    : Bus 16210	: V=1.0031668, theta=-39.419532 -> V=1.0, theta=0.0
% INFO    : Bus 16211	: V=0.9956117, theta=-39.837854 -> V=1.0, theta=0.0
% INFO    : Bus 16212	: V=0.9747544, theta=-41.181598 -> V=1.0, theta=0.0
% INFO    : Bus 16213	: V=0.9676604, theta=-41.480365 -> V=1.0, theta=0.0
% INFO    : Bus 16214	: V=0.9882838, theta=-30.838873 -> V=1.0, theta=0.0
% INFO    : Bus 16215	: V=0.988867, theta=-31.789046 -> V=1.0, theta=0.0
% INFO    : Bus 16216	: V=0.9776175, theta=-33.828932 -> V=1.0, theta=0.0
% INFO    : Bus 16217	: V=0.9567499, theta=-34.86346 -> V=1.0, theta=0.0
% INFO    : Bus 16218	: V=0.9733495, theta=-34.966179 -> V=1.0, theta=0.0
% INFO    : Bus 16219	: V=0.9509264, theta=-36.836788 -> V=1.0, theta=0.0
% INFO    : Bus 16220	: V=0.9681952, theta=-34.917174 -> V=1.0, theta=0.0
% INFO    : Bus 16221	: V=0.9534806, theta=-35.645331 -> V=1.0, theta=0.0
% INFO    : Bus 16222	: V=0.9665436, theta=-34.523908 -> V=1.0, theta=0.0
% INFO    : Bus 16223	: V=0.9507667, theta=-36.510925 -> V=1.0, theta=0.0
% INFO    : Bus 16224	: V=0.9450356, theta=-36.126329 -> V=1.0, theta=0.0
% INFO    : Bus 16225	: V=0.9402759, theta=-36.613679 -> V=1.0, theta=0.0
% INFO    : Bus 16226	: V=0.9449242, theta=-34.959524 -> V=1.0, theta=0.0
% INFO    : Bus 16227	: V=0.9686793, theta=-38.053187 -> V=1.0, theta=0.0
% INFO    : Bus 16228	: V=0.9656449, theta=-39.445155 -> V=1.0, theta=0.0
% INFO    : Bus 16229	: V=0.9756065, theta=-38.16519 -> V=1.0, theta=0.0
% INFO    : Bus 16230	: V=0.9552497, theta=-40.752988 -> V=1.0, theta=0.0
% INFO    : Bus 16231	: V=0.9742344, theta=-37.903711 -> V=1.0, theta=0.0
% INFO    : Bus 16232	: V=0.9625717, theta=-38.850284 -> V=1.0, theta=0.0
% INFO    : Bus 16233	: V=0.9615638, theta=-38.862785 -> V=1.0, theta=0.0
% INFO    : Bus 16234	: V=0.9721177, theta=-37.922308 -> V=1.0, theta=0.0
% INFO    : Bus 16235	: V=0.9765976, theta=-37.984424 -> V=1.0, theta=0.0
% INFO    : Bus 16236	: V=0.971434, theta=-38.053387 -> V=1.0, theta=0.0
% INFO    : Bus 16237	: V=0.9634928, theta=-38.855032 -> V=1.0, theta=0.0
% INFO    : Bus 16238	: V=0.9641514, theta=-38.824979 -> V=1.0, theta=0.0
% INFO    : Bus 16239	: V=0.9703266, theta=-38.087936 -> V=1.0, theta=0.0
% INFO    : Bus 16240	: V=0.9681146, theta=-37.584702 -> V=1.0, theta=0.0
% INFO    : Bus 16241	: V=0.9681834, theta=-37.851143 -> V=1.0, theta=0.0
% INFO    : Bus 16242	: V=0.9583343, theta=-37.35723 -> V=1.0, theta=0.0
% INFO    : Bus 16243	: V=0.9669414, theta=-36.878264 -> V=1.0, theta=0.0
% INFO    : Bus 16244	: V=1.0032673, theta=-29.272006 -> V=1.0, theta=0.0
% INFO    : Bus 16245	: V=0.9624002, theta=-36.942814 -> V=1.0, theta=0.0
% INFO    : Bus 16246	: V=0.9657339, theta=-37.069191 -> V=1.0, theta=0.0
% INFO    : Bus 16247	: V=0.9649989, theta=-37.443883 -> V=1.0, theta=0.0
% INFO    : Bus 16248	: V=0.9665334, theta=-39.894091 -> V=1.0, theta=0.0
% INFO    : Bus 16249	: V=0.961363, theta=-40.265017 -> V=1.0, theta=0.0
% INFO    : Bus 16250	: V=0.9733335, theta=-39.187854 -> V=1.0, theta=0.0
% INFO    : Bus 16251	: V=0.9721078, theta=-39.573843 -> V=1.0, theta=0.0
% INFO    : Bus 16252	: V=0.974797, theta=-39.086855 -> V=1.0, theta=0.0
% INFO    : Bus 16253	: V=0.9764859, theta=-38.969741 -> V=1.0, theta=0.0
% INFO    : Bus 16254	: V=0.9780583, theta=-38.874078 -> V=1.0, theta=0.0
% INFO    : Bus 16255	: V=0.9796296, theta=-38.77898 -> V=1.0, theta=0.0
% INFO    : Bus 16256	: V=0.9809656, theta=-38.702668 -> V=1.0, theta=0.0
% INFO    : Bus 16257	: V=0.9833348, theta=-38.563593 -> V=1.0, theta=0.0
% INFO    : Bus 16258	: V=0.9640489, theta=-40.384983 -> V=1.0, theta=0.0
% INFO    : Bus 16259	: V=0.9635617, theta=-40.102548 -> V=1.0, theta=0.0
% INFO    : Bus 16260	: V=0.9696898, theta=-39.31874 -> V=1.0, theta=0.0
% INFO    : Bus 16261	: V=0.9628254, theta=-40.135771 -> V=1.0, theta=0.0
% INFO    : Bus 16262	: V=0.9611148, theta=-40.243984 -> V=1.0, theta=0.0
% INFO    : Bus 16263	: V=0.9696511, theta=-39.404727 -> V=1.0, theta=0.0
% INFO    : Bus 16264	: V=0.9717875, theta=-39.294888 -> V=1.0, theta=0.0
% INFO    : Bus 16265	: V=0.9646059, theta=-39.921044 -> V=1.0, theta=0.0
% INFO    : Bus 16266	: V=0.9703188, theta=-39.385724 -> V=1.0, theta=0.0
% INFO    : Bus 16267	: V=0.9698113, theta=-39.418684 -> V=1.0, theta=0.0
% INFO    : Bus 16268	: V=0.9746855, theta=-39.192545 -> V=1.0, theta=0.0
% INFO    : Bus 16269	: V=0.973257, theta=-39.24824 -> V=1.0, theta=0.0
% INFO    : Bus 16270	: V=0.9753382, theta=-39.165251 -> V=1.0, theta=0.0
% INFO    : Bus 16271	: V=0.9781533, theta=-39.022828 -> V=1.0, theta=0.0
% INFO    : Bus 16272	: V=0.9768211, theta=-39.087506 -> V=1.0, theta=0.0
% INFO    : Bus 16273	: V=0.9752939, theta=-39.302162 -> V=1.0, theta=0.0
% INFO    : Bus 16274	: V=0.9922395, theta=-37.082314 -> V=1.0, theta=0.0
% INFO    : Bus 16275	: V=0.9728237, theta=-39.548621 -> V=1.0, theta=0.0
% INFO    : Bus 16276	: V=0.9692448, theta=-39.704641 -> V=1.0, theta=0.0
% INFO    : Bus 16277	: V=0.9712598, theta=-39.626608 -> V=1.0, theta=0.0
% INFO    : Bus 16278	: V=0.9716537, theta=-39.627067 -> V=1.0, theta=0.0
% INFO    : Bus 16279	: V=0.982207, theta=-38.688013 -> V=1.0, theta=0.0
% INFO    : Bus 16280	: V=0.9778053, theta=-39.054969 -> V=1.0, theta=0.0
% INFO    : Bus 16281	: V=0.9790584, theta=-38.555016 -> V=1.0, theta=0.0
% INFO    : Bus 16282	: V=0.982679, theta=-38.048869 -> V=1.0, theta=0.0
% INFO    : Bus 16283	: V=0.9701742, theta=-39.500193 -> V=1.0, theta=0.0
% INFO    : Bus 16284	: V=0.9577256, theta=-40.158315 -> V=1.0, theta=0.0
% INFO    : Bus 16285	: V=0.96453, theta=-39.832117 -> V=1.0, theta=0.0
% INFO    : Bus 16286	: V=0.9643926, theta=-39.852635 -> V=1.0, theta=0.0
% INFO    : Bus 16287	: V=0.9700978, theta=-39.207957 -> V=1.0, theta=0.0
% INFO    : Bus 16288	: V=0.9686001, theta=-39.501568 -> V=1.0, theta=0.0
% INFO    : Bus 16289	: V=0.9693712, theta=-39.447524 -> V=1.0, theta=0.0
% INFO    : Bus 16290	: V=0.9689932, theta=-39.474064 -> V=1.0, theta=0.0
% INFO    : Bus 16291	: V=0.9655581, theta=-39.822483 -> V=1.0, theta=0.0
% INFO    : Bus 16292	: V=0.9653159, theta=-39.816604 -> V=1.0, theta=0.0
% INFO    : Bus 16293	: V=0.9764287, theta=-39.101554 -> V=1.0, theta=0.0
% INFO    : Bus 16294	: V=0.978004, theta=-38.999818 -> V=1.0, theta=0.0
% INFO    : Bus 16295	: V=0.9659857, theta=-39.840132 -> V=1.0, theta=0.0
% INFO    : Bus 16296	: V=0.9676651, theta=-39.757223 -> V=1.0, theta=0.0
% INFO    : Bus 16297	: V=0.9666687, theta=-39.809987 -> V=1.0, theta=0.0
% INFO    : Bus 16298	: V=0.9663893, theta=-39.82591 -> V=1.0, theta=0.0
% INFO    : Bus 16299	: V=0.9655685, theta=-39.853367 -> V=1.0, theta=0.0
% INFO    : Bus 16300	: V=0.9751783, theta=-39.129469 -> V=1.0, theta=0.0
% INFO    : Bus 16301	: V=0.9753454, theta=-39.131916 -> V=1.0, theta=0.0
% INFO    : Bus 16302	: V=0.9869086, theta=-38.666586 -> V=1.0, theta=0.0
% INFO    : Bus 16303	: V=1.0116151, theta=-35.680007 -> V=1.0, theta=0.0
% INFO    : Bus 16304	: V=0.9859972, theta=-38.587992 -> V=1.0, theta=0.0
% INFO    : Bus 16305	: V=0.9811369, theta=-39.071193 -> V=1.0, theta=0.0
% INFO    : Bus 16306	: V=0.9842908, theta=-38.688525 -> V=1.0, theta=0.0
% INFO    : Bus 16307	: V=0.9802308, theta=-39.098732 -> V=1.0, theta=0.0
% INFO    : Bus 16308	: V=0.9813792, theta=-38.852877 -> V=1.0, theta=0.0
% INFO    : Bus 16309	: V=0.9767418, theta=-39.366867 -> V=1.0, theta=0.0
% INFO    : Bus 16310	: V=0.9847436, theta=-38.881525 -> V=1.0, theta=0.0
% INFO    : Bus 16311	: V=0.9836226, theta=-39.031816 -> V=1.0, theta=0.0
% INFO    : Bus 16312	: V=0.9827033, theta=-39.027332 -> V=1.0, theta=0.0
% INFO    : Bus 16313	: V=0.9781407, theta=-38.867577 -> V=1.0, theta=0.0
% INFO    : Bus 16314	: V=0.9850654, theta=-38.832589 -> V=1.0, theta=0.0
% INFO    : Bus 16315	: V=0.9740638, theta=-39.558385 -> V=1.0, theta=0.0
% INFO    : Bus 16316	: V=0.9582584, theta=-46.1317 -> V=1.0, theta=0.0
% INFO    : Bus 16317	: V=0.9514873, theta=-46.130768 -> V=1.0, theta=0.0
% INFO    : Bus 16318	: V=0.9702681, theta=-43.959497 -> V=1.0, theta=0.0
% INFO    : Bus 16319	: V=0.9596501, theta=-45.890568 -> V=1.0, theta=0.0
% INFO    : Bus 16320	: V=0.9679884, theta=-44.324708 -> V=1.0, theta=0.0
% INFO    : Bus 16321	: V=0.9673577, theta=-46.021006 -> V=1.0, theta=0.0
% INFO    : Bus 16322	: V=0.9697519, theta=-45.072329 -> V=1.0, theta=0.0
% INFO    : Bus 16323	: V=0.9649334, theta=-45.977596 -> V=1.0, theta=0.0
% INFO    : Bus 16324	: V=0.987869, theta=-45.893335 -> V=1.0, theta=0.0
% INFO    : Bus 16325	: V=0.9830344, theta=-46.000591 -> V=1.0, theta=0.0
% INFO    : Bus 16326	: V=0.9845853, theta=-46.061126 -> V=1.0, theta=0.0
% INFO    : Bus 16327	: V=0.9726099, theta=-48.120246 -> V=1.0, theta=0.0
% INFO    : Bus 16328	: V=0.9608851, theta=-48.416248 -> V=1.0, theta=0.0
% INFO    : Bus 16329	: V=0.9763583, theta=-48.464381 -> V=1.0, theta=0.0
% INFO    : Bus 16330	: V=0.9789056, theta=-48.020499 -> V=1.0, theta=0.0
% INFO    : Bus 16331	: V=0.9709227, theta=-48.16845 -> V=1.0, theta=0.0
% INFO    : Bus 16332	: V=0.9627911, theta=-46.051925 -> V=1.0, theta=0.0
% INFO    : Bus 16333	: V=0.9656639, theta=-45.458314 -> V=1.0, theta=0.0
% INFO    : Bus 16334	: V=0.9699584, theta=-45.086937 -> V=1.0, theta=0.0
% INFO    : Bus 16335	: V=0.9703824, theta=-45.102408 -> V=1.0, theta=0.0
% INFO    : Bus 16336	: V=0.9805026, theta=-43.681575 -> V=1.0, theta=0.0
% INFO    : Bus 16337	: V=0.9678351, theta=-44.943351 -> V=1.0, theta=0.0
% INFO    : Bus 16338	: V=0.9733983, theta=-44.397736 -> V=1.0, theta=0.0
% INFO    : Bus 16339	: V=0.9748525, theta=-44.192887 -> V=1.0, theta=0.0
% INFO    : Bus 16340	: V=0.9742754, theta=-44.123407 -> V=1.0, theta=0.0
% INFO    : Bus 16341	: V=0.9835716, theta=-43.067008 -> V=1.0, theta=0.0
% INFO    : Bus 16342	: V=0.9750402, theta=-44.097385 -> V=1.0, theta=0.0
% INFO    : Bus 16343	: V=0.9620797, theta=-45.812792 -> V=1.0, theta=0.0
% INFO    : Bus 16344	: V=0.9608865, theta=-45.993044 -> V=1.0, theta=0.0
% INFO    : Bus 16345	: V=0.9626878, theta=-45.864172 -> V=1.0, theta=0.0
% INFO    : Bus 16346	: V=0.9712512, theta=-44.577155 -> V=1.0, theta=0.0
% INFO    : Bus 16347	: V=0.9643812, theta=-45.518807 -> V=1.0, theta=0.0
% INFO    : Bus 16348	: V=0.9656002, theta=-45.648331 -> V=1.0, theta=0.0
% INFO    : Bus 16349	: V=0.9753795, theta=-43.9591 -> V=1.0, theta=0.0
% INFO    : Bus 16350	: V=0.9887927, theta=-42.267334 -> V=1.0, theta=0.0
% INFO    : Bus 16351	: V=0.9814881, theta=-43.212697 -> V=1.0, theta=0.0
% INFO    : Bus 16352	: V=0.9898576, theta=-42.1391 -> V=1.0, theta=0.0
% INFO    : Bus 16353	: V=0.9921266, theta=-41.852856 -> V=1.0, theta=0.0
% INFO    : Bus 16354	: V=0.9952847, theta=-41.50831 -> V=1.0, theta=0.0
% INFO    : Bus 16355	: V=0.9913704, theta=-41.965015 -> V=1.0, theta=0.0
% INFO    : Bus 16356	: V=0.9938914, theta=-41.657325 -> V=1.0, theta=0.0
% INFO    : Bus 16357	: V=0.9898608, theta=-42.037441 -> V=1.0, theta=0.0
% INFO    : Bus 16358	: V=0.9971872, theta=-41.232485 -> V=1.0, theta=0.0
% INFO    : Bus 16359	: V=0.995369, theta=-41.376926 -> V=1.0, theta=0.0
% INFO    : Bus 16360	: V=1.0154626, theta=-38.670531 -> V=1.0, theta=0.0
% INFO    : Bus 16361	: V=0.9980267, theta=-41.053969 -> V=1.0, theta=0.0
% INFO    : Bus 16362	: V=0.9898178, theta=-41.926743 -> V=1.0, theta=0.0
% INFO    : Bus 16363	: V=0.9923698, theta=-41.63209 -> V=1.0, theta=0.0
% INFO    : Bus 16364	: V=0.991901, theta=-41.223059 -> V=1.0, theta=0.0
% INFO    : Bus 16365	: V=0.988828, theta=-41.718217 -> V=1.0, theta=0.0
% INFO    : Bus 16366	: V=0.9793574, theta=-43.144142 -> V=1.0, theta=0.0
% INFO    : Bus 16367	: V=0.967454, theta=-44.558821 -> V=1.0, theta=0.0
% INFO    : Bus 16368	: V=0.979487, theta=-43.579526 -> V=1.0, theta=0.0
% INFO    : Bus 16369	: V=0.9806577, theta=-43.208668 -> V=1.0, theta=0.0
% INFO    : Bus 16370	: V=0.9887185, theta=-42.324319 -> V=1.0, theta=0.0
% INFO    : Bus 16371	: V=0.9785892, theta=-43.275949 -> V=1.0, theta=0.0
% INFO    : Bus 16372	: V=0.9971671, theta=-41.352325 -> V=1.0, theta=0.0
% INFO    : Bus 16373	: V=0.9823699, theta=-37.228217 -> V=1.0, theta=0.0
% INFO    : Bus 16374	: V=0.9784841, theta=-36.751335 -> V=1.0, theta=0.0
% INFO    : Bus 16375	: V=0.9752006, theta=-36.692427 -> V=1.0, theta=0.0
% INFO    : Bus 16376	: V=0.9677783, theta=-37.700817 -> V=1.0, theta=0.0
% INFO    : Bus 16377	: V=0.9776165, theta=-36.672406 -> V=1.0, theta=0.0
% INFO    : Bus 16378	: V=0.9768062, theta=-36.016678 -> V=1.0, theta=0.0
% INFO    : Bus 16379	: V=0.9765472, theta=-35.157737 -> V=1.0, theta=0.0
% INFO    : Bus 16380	: V=0.9679299, theta=-36.434697 -> V=1.0, theta=0.0
% INFO    : Bus 16381	: V=0.9683407, theta=-35.908422 -> V=1.0, theta=0.0
% INFO    : Bus 16382	: V=0.9607061, theta=-36.536465 -> V=1.0, theta=0.0
% INFO    : Bus 16383	: V=0.9763457, theta=-35.611247 -> V=1.0, theta=0.0
% INFO    : Bus 16384	: V=0.9730907, theta=-41.686087 -> V=1.0, theta=0.0
% INFO    : Bus 16385	: V=0.9615057, theta=-43.052073 -> V=1.0, theta=0.0
% INFO    : Bus 16386	: V=0.9730216, theta=-41.703094 -> V=1.0, theta=0.0
% INFO    : Bus 16387	: V=0.9610837, theta=-43.088236 -> V=1.0, theta=0.0
% INFO    : Bus 16388	: V=0.962724, theta=-43.047282 -> V=1.0, theta=0.0
% INFO    : Bus 16389	: V=0.965753, theta=-42.303663 -> V=1.0, theta=0.0
% INFO    : Bus 16390	: V=0.9659072, theta=-42.289181 -> V=1.0, theta=0.0
% INFO    : Bus 16391	: V=0.9608094, theta=-43.065813 -> V=1.0, theta=0.0
% INFO    : Bus 16392	: V=0.9546319, theta=-43.53571 -> V=1.0, theta=0.0
% INFO    : Bus 16393	: V=0.9641809, theta=-42.818381 -> V=1.0, theta=0.0
% INFO    : Bus 16394	: V=0.9731549, theta=-41.699114 -> V=1.0, theta=0.0
% INFO    : Bus 16395	: V=0.973678, theta=-41.661033 -> V=1.0, theta=0.0
% INFO    : Bus 16396	: V=0.9675938, theta=-42.479168 -> V=1.0, theta=0.0
% INFO    : Bus 16397	: V=0.9734172, theta=-41.686873 -> V=1.0, theta=0.0
% INFO    : Bus 16398	: V=0.9675677, theta=-42.554085 -> V=1.0, theta=0.0
% INFO    : Bus 16399	: V=0.9674284, theta=-42.580209 -> V=1.0, theta=0.0
% INFO    : Bus 16400	: V=0.9667567, theta=-42.587748 -> V=1.0, theta=0.0
% INFO    : Bus 16401	: V=0.9851391, theta=-40.32785 -> V=1.0, theta=0.0
% INFO    : Bus 16402	: V=0.9677333, theta=-42.150877 -> V=1.0, theta=0.0
% INFO    : Bus 16403	: V=0.9665928, theta=-42.240872 -> V=1.0, theta=0.0
% INFO    : Bus 16404	: V=0.9623429, theta=-43.052326 -> V=1.0, theta=0.0
% INFO    : Bus 16405	: V=0.976695, theta=-41.439864 -> V=1.0, theta=0.0
% INFO    : Bus 16406	: V=0.9652508, theta=-42.643987 -> V=1.0, theta=0.0
% INFO    : Bus 16407	: V=0.9683972, theta=-42.173437 -> V=1.0, theta=0.0
% INFO    : Bus 16408	: V=0.9656617, theta=-42.315731 -> V=1.0, theta=0.0
% INFO    : Bus 16409	: V=0.955442, theta=-43.530266 -> V=1.0, theta=0.0
% INFO    : Bus 16410	: V=0.9661642, theta=-42.298863 -> V=1.0, theta=0.0
% INFO    : Bus 16411	: V=0.974584, theta=-41.577969 -> V=1.0, theta=0.0
% INFO    : Bus 16412	: V=0.9742298, theta=-41.600495 -> V=1.0, theta=0.0
% INFO    : Bus 16413	: V=0.9734781, theta=-41.639638 -> V=1.0, theta=0.0
% INFO    : Bus 16414	: V=0.9604388, theta=-42.98281 -> V=1.0, theta=0.0
% INFO    : Bus 16415	: V=0.9768166, theta=-41.426484 -> V=1.0, theta=0.0
% INFO    : Bus 16416	: V=0.967226, theta=-42.464252 -> V=1.0, theta=0.0
% INFO    : Bus 16417	: V=0.976038, theta=-41.463724 -> V=1.0, theta=0.0
% INFO    : Bus 16418	: V=0.9760567, theta=-41.453407 -> V=1.0, theta=0.0
% INFO    : Bus 16419	: V=0.9767822, theta=-41.393606 -> V=1.0, theta=0.0
% INFO    : Bus 16420	: V=0.9779191, theta=-41.304982 -> V=1.0, theta=0.0
% INFO    : Bus 16421	: V=0.9722871, theta=-41.81888 -> V=1.0, theta=0.0
% INFO    : Bus 16422	: V=0.9578759, theta=-43.350508 -> V=1.0, theta=0.0
% INFO    : Bus 16423	: V=0.9566523, theta=-43.362941 -> V=1.0, theta=0.0
% INFO    : Bus 16424	: V=0.9660001, theta=-42.546025 -> V=1.0, theta=0.0
% INFO    : Bus 16425	: V=0.9724709, theta=-41.931534 -> V=1.0, theta=0.0
% INFO    : Bus 16426	: V=0.9560907, theta=-43.564597 -> V=1.0, theta=0.0
% INFO    : Bus 16427	: V=0.9633192, theta=-42.959852 -> V=1.0, theta=0.0
% INFO    : Bus 16428	: V=0.9538787, theta=-43.935681 -> V=1.0, theta=0.0
% INFO    : Bus 16429	: V=0.9614029, theta=-43.114843 -> V=1.0, theta=0.0
% INFO    : Bus 16430	: V=0.9558973, theta=-43.574823 -> V=1.0, theta=0.0
% INFO    : Bus 16431	: V=0.9678199, theta=-42.343809 -> V=1.0, theta=0.0
% INFO    : Bus 16432	: V=0.9644499, theta=-42.641289 -> V=1.0, theta=0.0
% INFO    : Bus 16433	: V=0.9617787, theta=-42.757479 -> V=1.0, theta=0.0
% INFO    : Bus 16434	: V=0.9626372, theta=-42.696535 -> V=1.0, theta=0.0
% INFO    : Bus 16435	: V=0.9601236, theta=-42.78543 -> V=1.0, theta=0.0
% INFO    : Bus 16436	: V=0.9716264, theta=-42.018439 -> V=1.0, theta=0.0
% INFO    : Bus 16437	: V=0.9638012, theta=-42.693231 -> V=1.0, theta=0.0
% INFO    : Bus 16438	: V=0.9859335, theta=-40.190365 -> V=1.0, theta=0.0
% INFO    : Bus 16439	: V=0.9968489, theta=-38.755919 -> V=1.0, theta=0.0
% INFO    : Bus 16440	: V=0.9838074, theta=-40.966763 -> V=1.0, theta=0.0
% INFO    : Bus 16441	: V=0.9644722, theta=-42.943819 -> V=1.0, theta=0.0
% INFO    : Bus 16442	: V=0.9679639, theta=-42.51932 -> V=1.0, theta=0.0
% INFO    : Bus 16443	: V=0.9971852, theta=-38.670541 -> V=1.0, theta=0.0
% INFO    : Bus 16444	: V=0.9585596, theta=-44.430833 -> V=1.0, theta=0.0
% INFO    : Bus 16445	: V=0.9486157, theta=-45.872476 -> V=1.0, theta=0.0
% INFO    : Bus 16446	: V=0.9485064, theta=-45.936883 -> V=1.0, theta=0.0
% INFO    : Bus 16447	: V=0.9633384, theta=-45.957682 -> V=1.0, theta=0.0
% INFO    : Bus 16448	: V=0.959507, theta=-46.068666 -> V=1.0, theta=0.0
% INFO    : Bus 16449	: V=0.944538, theta=-46.55994 -> V=1.0, theta=0.0
% INFO    : Bus 16450	: V=0.9434727, theta=-46.769389 -> V=1.0, theta=0.0
% INFO    : Bus 16451	: V=0.944992, theta=-46.729517 -> V=1.0, theta=0.0
% INFO    : Bus 16452	: V=0.9698564, theta=-44.019915 -> V=1.0, theta=0.0
% INFO    : Bus 16453	: V=0.9415366, theta=-46.963178 -> V=1.0, theta=0.0
% INFO    : Bus 16454	: V=0.9431306, theta=-46.716167 -> V=1.0, theta=0.0
% INFO    : Bus 16455	: V=0.9545551, theta=-44.66797 -> V=1.0, theta=0.0
% INFO    : Bus 16456	: V=0.9519763, theta=-44.711516 -> V=1.0, theta=0.0
% INFO    : Bus 16457	: V=0.9504754, theta=-44.703779 -> V=1.0, theta=0.0
% INFO    : Bus 16458	: V=0.9789509, theta=-44.278537 -> V=1.0, theta=0.0
% INFO    : Bus 16459	: V=0.9803, theta=-44.145944 -> V=1.0, theta=0.0
% INFO    : Bus 16460	: V=0.9734426, theta=-45.0277 -> V=1.0, theta=0.0
% INFO    : Bus 16461	: V=0.9736852, theta=-44.998419 -> V=1.0, theta=0.0
% INFO    : Bus 16462	: V=0.9749962, theta=-44.939332 -> V=1.0, theta=0.0
% INFO    : Bus 16463	: V=0.9810997, theta=-44.097756 -> V=1.0, theta=0.0
% INFO    : Bus 16464	: V=0.9797724, theta=-44.19793 -> V=1.0, theta=0.0
% INFO    : Bus 16465	: V=0.9785508, theta=-44.288418 -> V=1.0, theta=0.0
% INFO    : Bus 16466	: V=0.9773802, theta=-44.371487 -> V=1.0, theta=0.0
% INFO    : Bus 16467	: V=0.9762951, theta=-44.429722 -> V=1.0, theta=0.0
% INFO    : Bus 16468	: V=0.9779002, theta=-44.347291 -> V=1.0, theta=0.0
% INFO    : Bus 16469	: V=0.9678668, theta=-45.318559 -> V=1.0, theta=0.0
% INFO    : Bus 16470	: V=0.9771745, theta=-44.398712 -> V=1.0, theta=0.0
% INFO    : Bus 16471	: V=0.9733938, theta=-45.058641 -> V=1.0, theta=0.0
% INFO    : Bus 16472	: V=0.985687, theta=-43.572732 -> V=1.0, theta=0.0
% INFO    : Bus 16473	: V=1.0029151, theta=-41.497505 -> V=1.0, theta=0.0
% INFO    : Bus 16474	: V=1.0027546, theta=-41.517226 -> V=1.0, theta=0.0
% INFO    : Bus 16475	: V=0.9854563, theta=-43.658216 -> V=1.0, theta=0.0
% INFO    : Bus 16476	: V=0.9821516, theta=-44.017413 -> V=1.0, theta=0.0
% INFO    : Bus 16477	: V=0.9811673, theta=-44.126264 -> V=1.0, theta=0.0
% INFO    : Bus 16478	: V=0.9685311, theta=-45.259635 -> V=1.0, theta=0.0
% INFO    : Bus 16479	: V=0.9751816, theta=-44.485445 -> V=1.0, theta=0.0
% INFO    : Bus 16480	: V=0.9695218, theta=-45.305275 -> V=1.0, theta=0.0
% INFO    : Bus 16481	: V=0.9742477, theta=-44.530528 -> V=1.0, theta=0.0
% INFO    : Bus 16482	: V=0.9663311, theta=-45.36955 -> V=1.0, theta=0.0
% INFO    : Bus 16483	: V=0.9738509, theta=-44.626533 -> V=1.0, theta=0.0
% INFO    : Bus 16484	: V=0.974434, theta=-44.594277 -> V=1.0, theta=0.0
% INFO    : Bus 16485	: V=0.9713494, theta=-45.123161 -> V=1.0, theta=0.0
% INFO    : Bus 16486	: V=0.968585, theta=-45.213822 -> V=1.0, theta=0.0
% INFO    : Bus 16487	: V=0.9724395, theta=-45.098329 -> V=1.0, theta=0.0
% INFO    : Bus 16488	: V=0.9661072, theta=-45.458928 -> V=1.0, theta=0.0
% INFO    : Bus 16489	: V=0.9634198, theta=-45.564471 -> V=1.0, theta=0.0
% INFO    : Bus 16490	: V=0.9747916, theta=-44.88273 -> V=1.0, theta=0.0
% INFO    : Bus 16491	: V=0.9771665, theta=-44.832615 -> V=1.0, theta=0.0
% INFO    : Bus 16492	: V=0.9738316, theta=-45.017741 -> V=1.0, theta=0.0
% INFO    : Bus 16493	: V=0.9573998, theta=-46.753993 -> V=1.0, theta=0.0
% INFO    : Bus 16494	: V=0.9753265, theta=-45.001702 -> V=1.0, theta=0.0
% INFO    : Bus 16495	: V=0.990774, theta=-43.222286 -> V=1.0, theta=0.0
% INFO    : Bus 16496	: V=0.9694995, theta=-45.905587 -> V=1.0, theta=0.0
% INFO    : Bus 16497	: V=0.9734876, theta=-45.098115 -> V=1.0, theta=0.0
% INFO    : Bus 16498	: V=0.961496, theta=-46.641834 -> V=1.0, theta=0.0
% INFO    : Bus 16499	: V=0.9796996, theta=-44.575157 -> V=1.0, theta=0.0
% INFO    : Bus 16500	: V=1.0023831, theta=-41.752277 -> V=1.0, theta=0.0
% INFO    : Bus 16501	: V=0.9839182, theta=-44.237154 -> V=1.0, theta=0.0
% INFO    : Bus 16502	: V=0.977744, theta=-44.78239 -> V=1.0, theta=0.0
% INFO    : Bus 16503	: V=0.9766295, theta=-44.883492 -> V=1.0, theta=0.0
% INFO    : Bus 16504	: V=0.9795372, theta=-44.465071 -> V=1.0, theta=0.0
% INFO    : Bus 16505	: V=0.9865162, theta=-43.918597 -> V=1.0, theta=0.0
% INFO    : Bus 16506	: V=1.0035633, theta=-41.827018 -> V=1.0, theta=0.0
% INFO    : Bus 16507	: V=1.0048875, theta=-41.854507 -> V=1.0, theta=0.0
% INFO    : Bus 16508	: V=0.9829585, theta=-44.207754 -> V=1.0, theta=0.0
% INFO    : Bus 16509	: V=0.9826599, theta=-44.292191 -> V=1.0, theta=0.0
% INFO    : Bus 16510	: V=0.9809744, theta=-44.353792 -> V=1.0, theta=0.0
% INFO    : Bus 16511	: V=0.9799712, theta=-44.544863 -> V=1.0, theta=0.0
% INFO    : Bus 16512	: V=0.9785836, theta=-44.540885 -> V=1.0, theta=0.0
% INFO    : Bus 16513	: V=0.9790393, theta=-44.426118 -> V=1.0, theta=0.0
% INFO    : Bus 16514	: V=0.980107, theta=-44.236293 -> V=1.0, theta=0.0
% INFO    : Bus 16515	: V=0.984683, theta=-43.823778 -> V=1.0, theta=0.0
% INFO    : Bus 16516	: V=0.9757237, theta=-44.902928 -> V=1.0, theta=0.0
% INFO    : Bus 16517	: V=0.9710045, theta=-45.329175 -> V=1.0, theta=0.0
% INFO    : Bus 16518	: V=0.9682673, theta=-45.565774 -> V=1.0, theta=0.0
% INFO    : Bus 16519	: V=0.975304, theta=-45.015551 -> V=1.0, theta=0.0
% INFO    : Bus 16520	: V=0.9823274, theta=-44.123252 -> V=1.0, theta=0.0
% INFO    : Bus 16521	: V=0.9728676, theta=-44.863489 -> V=1.0, theta=0.0
% INFO    : Bus 16522	: V=0.9787177, theta=-44.304779 -> V=1.0, theta=0.0
% INFO    : Bus 16523	: V=0.9690248, theta=-45.189412 -> V=1.0, theta=0.0
% INFO    : Bus 16524	: V=0.9791031, theta=-44.232026 -> V=1.0, theta=0.0
% INFO    : Bus 16525	: V=0.9730131, theta=-44.551312 -> V=1.0, theta=0.0
% INFO    : Bus 16526	: V=0.965909, theta=-45.380883 -> V=1.0, theta=0.0
% INFO    : Bus 16527	: V=0.9665499, theta=-45.288677 -> V=1.0, theta=0.0
% INFO    : Bus 16528	: V=0.972709, theta=-44.51827 -> V=1.0, theta=0.0
% INFO    : Bus 16529	: V=0.9629971, theta=-45.374592 -> V=1.0, theta=0.0
% INFO    : Bus 16530	: V=0.9733461, theta=-44.545324 -> V=1.0, theta=0.0
% INFO    : Bus 16531	: V=0.9727075, theta=-44.648533 -> V=1.0, theta=0.0
% INFO    : Bus 16532	: V=0.9634671, theta=-45.370182 -> V=1.0, theta=0.0
% INFO    : Bus 16533	: V=0.9721639, theta=-44.682822 -> V=1.0, theta=0.0
% INFO    : Bus 16534	: V=0.9605872, theta=-45.531509 -> V=1.0, theta=0.0
% INFO    : Bus 16535	: V=0.965563, theta=-45.350246 -> V=1.0, theta=0.0
% INFO    : Bus 16536	: V=0.9661527, theta=-45.305274 -> V=1.0, theta=0.0
% INFO    : Bus 16537	: V=0.9642709, theta=-45.47404 -> V=1.0, theta=0.0
% INFO    : Bus 16538	: V=0.9630174, theta=-45.485669 -> V=1.0, theta=0.0
% INFO    : Bus 16539	: V=0.9755406, theta=-44.141114 -> V=1.0, theta=0.0
% INFO    : Bus 16540	: V=0.9622896, theta=-45.161342 -> V=1.0, theta=0.0
% INFO    : Bus 16541	: V=0.9526491, theta=-45.610212 -> V=1.0, theta=0.0
% INFO    : Bus 16542	: V=0.9576292, theta=-45.584818 -> V=1.0, theta=0.0
% INFO    : Bus 16543	: V=0.9568526, theta=-45.628817 -> V=1.0, theta=0.0
% INFO    : Bus 16544	: V=0.9583301, theta=-45.583987 -> V=1.0, theta=0.0
% INFO    : Bus 16545	: V=0.9602236, theta=-45.501249 -> V=1.0, theta=0.0
% INFO    : Bus 16546	: V=0.9626176, theta=-45.401444 -> V=1.0, theta=0.0
% INFO    : Bus 16547	: V=0.9651283, theta=-45.187626 -> V=1.0, theta=0.0
% INFO    : Bus 16548	: V=0.96827, theta=-45.704558 -> V=1.0, theta=0.0
% INFO    : Bus 16549	: V=0.9645593, theta=-45.616499 -> V=1.0, theta=0.0
% INFO    : Bus 16550	: V=0.970624, theta=-45.406589 -> V=1.0, theta=0.0
% INFO    : Bus 16551	: V=0.9783162, theta=-41.640393 -> V=1.0, theta=0.0
% INFO    : Bus 16552	: V=0.9710552, theta=-42.341788 -> V=1.0, theta=0.0
% INFO    : Bus 16553	: V=0.9701734, theta=-42.352719 -> V=1.0, theta=0.0
% INFO    : Bus 16554	: V=0.9690008, theta=-42.43939 -> V=1.0, theta=0.0
% INFO    : Bus 16555	: V=0.977884, theta=-41.495039 -> V=1.0, theta=0.0
% INFO    : Bus 16556	: V=0.9753149, theta=-41.765104 -> V=1.0, theta=0.0
% INFO    : Bus 16557	: V=0.971915, theta=-42.061947 -> V=1.0, theta=0.0
% INFO    : Bus 16558	: V=0.970697, theta=-42.150303 -> V=1.0, theta=0.0
% INFO    : Bus 16559	: V=0.9679193, theta=-42.49295 -> V=1.0, theta=0.0
% INFO    : Bus 16560	: V=0.9653885, theta=-42.942171 -> V=1.0, theta=0.0
% INFO    : Bus 16561	: V=0.964222, theta=-42.760865 -> V=1.0, theta=0.0
% INFO    : Bus 16562	: V=0.9624471, theta=-42.900095 -> V=1.0, theta=0.0
% INFO    : Bus 16563	: V=1.0051504, theta=-37.355357 -> V=1.0, theta=0.0
% INFO    : Bus 16564	: V=1.0030376, theta=-37.616992 -> V=1.0, theta=0.0
% INFO    : Bus 16565	: V=0.9911923, theta=-38.713303 -> V=1.0, theta=0.0
% INFO    : Bus 16566	: V=0.9803724, theta=-39.628864 -> V=1.0, theta=0.0
% INFO    : Bus 16567	: V=0.986472, theta=-39.197469 -> V=1.0, theta=0.0
% INFO    : Bus 16568	: V=0.9649997, theta=-41.702265 -> V=1.0, theta=0.0
% INFO    : Bus 16569	: V=0.9870165, theta=-39.18761 -> V=1.0, theta=0.0
% INFO    : Bus 16570	: V=0.9632884, theta=-41.853999 -> V=1.0, theta=0.0
% INFO    : Bus 16571	: V=0.9851581, theta=-39.345379 -> V=1.0, theta=0.0
% INFO    : Bus 16572	: V=0.9580708, theta=-42.26418 -> V=1.0, theta=0.0
% INFO    : Bus 16573	: V=0.9607993, theta=-41.427896 -> V=1.0, theta=0.0
% INFO    : Bus 16574	: V=0.9578476, theta=-42.43102 -> V=1.0, theta=0.0
% INFO    : Bus 16575	: V=0.9570536, theta=-42.450491 -> V=1.0, theta=0.0
% INFO    : Bus 16576	: V=0.9593736, theta=-42.434041 -> V=1.0, theta=0.0
% INFO    : Bus 16577	: V=0.9734919, theta=-41.004995 -> V=1.0, theta=0.0
% INFO    : Bus 16578	: V=0.9672696, theta=-41.255276 -> V=1.0, theta=0.0
% INFO    : Bus 16579	: V=0.9796823, theta=-39.760982 -> V=1.0, theta=0.0
% INFO    : Bus 16580	: V=0.9874444, theta=-39.171424 -> V=1.0, theta=0.0
% INFO    : Bus 16581	: V=0.9783014, theta=-39.73123 -> V=1.0, theta=0.0
% INFO    : Bus 16582	: V=0.9794008, theta=-39.665154 -> V=1.0, theta=0.0
% INFO    : Bus 16583	: V=0.9820576, theta=-39.531988 -> V=1.0, theta=0.0
% INFO    : Bus 16584	: V=0.980643, theta=-39.658613 -> V=1.0, theta=0.0
% INFO    : Bus 16585	: V=0.9992865, theta=-37.850057 -> V=1.0, theta=0.0
% INFO    : Bus 16586	: V=0.9880504, theta=-39.20079 -> V=1.0, theta=0.0
% INFO    : Bus 16587	: V=0.9875771, theta=-39.224023 -> V=1.0, theta=0.0
% INFO    : Bus 16588	: V=0.9779521, theta=-39.780795 -> V=1.0, theta=0.0
% INFO    : Bus 16589	: V=0.9778665, theta=-39.717315 -> V=1.0, theta=0.0
% INFO    : Bus 16590	: V=0.986277, theta=-39.23551 -> V=1.0, theta=0.0
% INFO    : Bus 16591	: V=0.9794601, theta=-39.758766 -> V=1.0, theta=0.0
% INFO    : Bus 16592	: V=0.9994667, theta=-37.623396 -> V=1.0, theta=0.0
% INFO    : Bus 16593	: V=0.9751075, theta=-40.983537 -> V=1.0, theta=0.0
% INFO    : Bus 16594	: V=0.9591827, theta=-40.934412 -> V=1.0, theta=0.0
% INFO    : Bus 16595	: V=0.9768876, theta=-40.272116 -> V=1.0, theta=0.0
% INFO    : Bus 16596	: V=0.9561793, theta=-40.97617 -> V=1.0, theta=0.0
% INFO    : Bus 16597	: V=0.9798928, theta=-40.076971 -> V=1.0, theta=0.0
% INFO    : Bus 16598	: V=0.9875345, theta=-39.161573 -> V=1.0, theta=0.0
% INFO    : Bus 16599	: V=0.986837, theta=-39.205757 -> V=1.0, theta=0.0
% INFO    : Bus 16600	: V=0.977736, theta=-39.93448 -> V=1.0, theta=0.0
% INFO    : Bus 16601	: V=0.9832709, theta=-39.441844 -> V=1.0, theta=0.0
% INFO    : Bus 16602	: V=0.9877856, theta=-39.170462 -> V=1.0, theta=0.0
% INFO    : Bus 16603	: V=0.9889982, theta=-38.961723 -> V=1.0, theta=0.0
% INFO    : Bus 16604	: V=0.9953661, theta=-38.148229 -> V=1.0, theta=0.0
% INFO    : Bus 16605	: V=1.0065917, theta=-36.765173 -> V=1.0, theta=0.0
% INFO    : Bus 16606	: V=0.9949493, theta=-38.336262 -> V=1.0, theta=0.0
% INFO    : Bus 16607	: V=0.9776312, theta=-40.056727 -> V=1.0, theta=0.0
% INFO    : Bus 16608	: V=0.9886927, theta=-38.588221 -> V=1.0, theta=0.0
% INFO    : Bus 16609	: V=0.9897561, theta=-38.520965 -> V=1.0, theta=0.0
% INFO    : Bus 16610	: V=0.992361, theta=-38.344029 -> V=1.0, theta=0.0
% INFO    : Bus 16611	: V=0.9774769, theta=-39.891538 -> V=1.0, theta=0.0
% INFO    : Bus 16612	: V=0.9756628, theta=-40.119071 -> V=1.0, theta=0.0
% INFO    : Bus 16613	: V=0.9741601, theta=-40.08866 -> V=1.0, theta=0.0
% INFO    : Bus 16614	: V=0.974875, theta=-40.081302 -> V=1.0, theta=0.0
% INFO    : Bus 16615	: V=0.9765746, theta=-40.145316 -> V=1.0, theta=0.0
% INFO    : Bus 16616	: V=0.9756457, theta=-40.245915 -> V=1.0, theta=0.0
% INFO    : Bus 16617	: V=0.9763884, theta=-40.219957 -> V=1.0, theta=0.0
% INFO    : Bus 16618	: V=0.9702431, theta=-40.348114 -> V=1.0, theta=0.0
% INFO    : Bus 16619	: V=0.9747873, theta=-40.245046 -> V=1.0, theta=0.0
% INFO    : Bus 16620	: V=0.9737445, theta=-40.269047 -> V=1.0, theta=0.0
% INFO    : Bus 16621	: V=0.9780329, theta=-39.932701 -> V=1.0, theta=0.0
% INFO    : Bus 16622	: V=0.971175, theta=-40.148217 -> V=1.0, theta=0.0
% INFO    : Bus 16623	: V=0.971276, theta=-39.918818 -> V=1.0, theta=0.0
% INFO    : Bus 16624	: V=0.9785948, theta=-39.375182 -> V=1.0, theta=0.0
% INFO    : Bus 16625	: V=0.9894047, theta=-38.75361 -> V=1.0, theta=0.0
% INFO    : Bus 16626	: V=0.9805707, theta=-38.734671 -> V=1.0, theta=0.0
% INFO    : Bus 16627	: V=0.9814315, theta=-39.693037 -> V=1.0, theta=0.0
% INFO    : Bus 16628	: V=0.9633859, theta=-43.13324 -> V=1.0, theta=0.0
% INFO    : Bus 16629	: V=0.9751944, theta=-42.824318 -> V=1.0, theta=0.0
% INFO    : Bus 16630	: V=0.9858587, theta=-42.297619 -> V=1.0, theta=0.0
% INFO    : Bus 16631	: V=1.0152411, theta=-36.838082 -> V=1.0, theta=0.0
% INFO    : Bus 16632	: V=1.0137414, theta=-37.520392 -> V=1.0, theta=0.0
% INFO    : Bus 16633	: V=1.0011795, theta=-38.285349 -> V=1.0, theta=0.0
% INFO    : Bus 16634	: V=1.0069216, theta=-39.494943 -> V=1.0, theta=0.0
% INFO    : Bus 16635	: V=1.0056831, theta=-39.124226 -> V=1.0, theta=0.0
% INFO    : Bus 16636	: V=0.9890933, theta=-40.263163 -> V=1.0, theta=0.0
% INFO    : Bus 16637	: V=0.9877085, theta=-40.469548 -> V=1.0, theta=0.0
% INFO    : Bus 16638	: V=0.982529, theta=-40.955405 -> V=1.0, theta=0.0
% INFO    : Bus 16639	: V=0.9812607, theta=-41.184153 -> V=1.0, theta=0.0
% INFO    : Bus 16640	: V=0.9650468, theta=-42.31033 -> V=1.0, theta=0.0
% INFO    : Bus 16641	: V=0.9821303, theta=-41.05473 -> V=1.0, theta=0.0
% INFO    : Bus 16642	: V=1.006066, theta=-38.439877 -> V=1.0, theta=0.0
% INFO    : Bus 16643	: V=0.9900604, theta=-40.340871 -> V=1.0, theta=0.0
% INFO    : Bus 16644	: V=0.9872677, theta=-40.588667 -> V=1.0, theta=0.0
% INFO    : Bus 16645	: V=0.9924541, theta=-39.841746 -> V=1.0, theta=0.0
% INFO    : Bus 16646	: V=0.9763685, theta=-41.773778 -> V=1.0, theta=0.0
% INFO    : Bus 16647	: V=0.9574727, theta=-42.277501 -> V=1.0, theta=0.0
% INFO    : Bus 16648	: V=0.9397857, theta=-44.292261 -> V=1.0, theta=0.0
% INFO    : Bus 16649	: V=0.9675851, theta=-40.54253 -> V=1.0, theta=0.0
% INFO    : Bus 16650	: V=0.9458489, theta=-42.741108 -> V=1.0, theta=0.0
% INFO    : Bus 16651	: V=0.9500578, theta=-47.512695 -> V=1.0, theta=0.0
% INFO    : Bus 16652	: V=0.962722, theta=-45.943266 -> V=1.0, theta=0.0
% INFO    : Bus 16653	: V=0.9500231, theta=-47.499926 -> V=1.0, theta=0.0
% INFO    : Bus 16654	: V=0.9551617, theta=-47.083811 -> V=1.0, theta=0.0
% INFO    : Bus 16655	: V=0.9642121, theta=-46.12507 -> V=1.0, theta=0.0
% INFO    : Bus 16656	: V=0.9567043, theta=-46.898521 -> V=1.0, theta=0.0
% INFO    : Bus 16657	: V=0.96229, theta=-46.290972 -> V=1.0, theta=0.0
% INFO    : Bus 16658	: V=0.9629206, theta=-46.431405 -> V=1.0, theta=0.0
% INFO    : Bus 16659	: V=0.9620399, theta=-46.504706 -> V=1.0, theta=0.0
% INFO    : Bus 16660	: V=0.9530287, theta=-47.369168 -> V=1.0, theta=0.0
% INFO    : Bus 16661	: V=0.957266, theta=-46.873629 -> V=1.0, theta=0.0
% INFO    : Bus 16662	: V=0.9608064, theta=-46.102727 -> V=1.0, theta=0.0
% INFO    : Bus 16663	: V=0.9519061, theta=-47.420997 -> V=1.0, theta=0.0
% INFO    : Bus 16664	: V=0.950529, theta=-47.518579 -> V=1.0, theta=0.0
% INFO    : Bus 16665	: V=0.9490307, theta=-47.676836 -> V=1.0, theta=0.0
% INFO    : Bus 16666	: V=0.9542262, theta=-47.340446 -> V=1.0, theta=0.0
% INFO    : Bus 16667	: V=0.9538051, theta=-47.374062 -> V=1.0, theta=0.0
% INFO    : Bus 16668	: V=0.9710198, theta=-45.245579 -> V=1.0, theta=0.0
% INFO    : Bus 16669	: V=0.9562964, theta=-47.206798 -> V=1.0, theta=0.0
% INFO    : Bus 16670	: V=0.9574867, theta=-47.077105 -> V=1.0, theta=0.0
% INFO    : Bus 16671	: V=0.9590164, theta=-46.920621 -> V=1.0, theta=0.0
% INFO    : Bus 16672	: V=0.9723046, theta=-45.238101 -> V=1.0, theta=0.0
% INFO    : Bus 16673	: V=0.9664965, theta=-45.69285 -> V=1.0, theta=0.0
% INFO    : Bus 16674	: V=0.9554147, theta=-47.2631 -> V=1.0, theta=0.0
% INFO    : Bus 16675	: V=0.9653314, theta=-46.024114 -> V=1.0, theta=0.0
% INFO    : Bus 16676	: V=0.9640657, theta=-46.328626 -> V=1.0, theta=0.0
% INFO    : Bus 16677	: V=0.963754, theta=-46.320257 -> V=1.0, theta=0.0
% INFO    : Bus 16678	: V=0.963139, theta=-46.232743 -> V=1.0, theta=0.0
% INFO    : Bus 16679	: V=0.9631858, theta=-46.259641 -> V=1.0, theta=0.0
% INFO    : Bus 16680	: V=0.9738226, theta=-45.260024 -> V=1.0, theta=0.0
% INFO    : Bus 16681	: V=0.9633873, theta=-46.293717 -> V=1.0, theta=0.0
% INFO    : Bus 16682	: V=0.9750803, theta=-45.058053 -> V=1.0, theta=0.0
% INFO    : Bus 16683	: V=0.9502913, theta=-47.634578 -> V=1.0, theta=0.0
% INFO    : Bus 16684	: V=0.9657157, theta=-46.140525 -> V=1.0, theta=0.0
% INFO    : Bus 16685	: V=0.9613327, theta=-46.648908 -> V=1.0, theta=0.0
% INFO    : Bus 16686	: V=0.9633416, theta=-46.312768 -> V=1.0, theta=0.0
% INFO    : Bus 16687	: V=0.9500661, theta=-47.70757 -> V=1.0, theta=0.0
% INFO    : Bus 16688	: V=0.9486397, theta=-47.832026 -> V=1.0, theta=0.0
% INFO    : Bus 16689	: V=0.9474878, theta=-47.940527 -> V=1.0, theta=0.0
% INFO    : Bus 16690	: V=0.9646092, theta=-46.219595 -> V=1.0, theta=0.0
% INFO    : Bus 16691	: V=0.9683465, theta=-45.770421 -> V=1.0, theta=0.0
% INFO    : Bus 16692	: V=0.9644221, theta=-45.830292 -> V=1.0, theta=0.0
% INFO    : Bus 16693	: V=0.9507313, theta=-47.238621 -> V=1.0, theta=0.0
% INFO    : Bus 16694	: V=0.949558, theta=-47.335986 -> V=1.0, theta=0.0
% INFO    : Bus 16695	: V=0.9490985, theta=-47.421948 -> V=1.0, theta=0.0
% INFO    : Bus 16696	: V=0.9558727, theta=-46.969679 -> V=1.0, theta=0.0
% INFO    : Bus 16697	: V=0.9550785, theta=-47.087278 -> V=1.0, theta=0.0
% INFO    : Bus 16698	: V=0.9511083, theta=-47.734979 -> V=1.0, theta=0.0
% INFO    : Bus 16699	: V=0.9470747, theta=-47.650798 -> V=1.0, theta=0.0
% INFO    : Bus 16700	: V=0.959043, theta=-46.409376 -> V=1.0, theta=0.0
% INFO    : Bus 16701	: V=0.9585849, theta=-46.448544 -> V=1.0, theta=0.0
% INFO    : Bus 16702	: V=0.9470081, theta=-47.685388 -> V=1.0, theta=0.0
% INFO    : Bus 16703	: V=0.9556938, theta=-46.704204 -> V=1.0, theta=0.0
% INFO    : Bus 16704	: V=0.9585533, theta=-46.452063 -> V=1.0, theta=0.0
% INFO    : Bus 16705	: V=0.9563845, theta=-46.655 -> V=1.0, theta=0.0
% INFO    : Bus 16706	: V=0.9585238, theta=-46.477496 -> V=1.0, theta=0.0
% INFO    : Bus 16707	: V=0.9454084, theta=-47.846951 -> V=1.0, theta=0.0
% INFO    : Bus 16708	: V=0.9608046, theta=-46.233687 -> V=1.0, theta=0.0
% INFO    : Bus 16709	: V=0.9605239, theta=-46.058679 -> V=1.0, theta=0.0
% INFO    : Bus 16710	: V=0.9543066, theta=-46.979943 -> V=1.0, theta=0.0
% INFO    : Bus 16711	: V=0.9600025, theta=-46.340147 -> V=1.0, theta=0.0
% INFO    : Bus 16712	: V=0.948497, theta=-47.537748 -> V=1.0, theta=0.0
% INFO    : Bus 16713	: V=0.9480666, theta=-47.587902 -> V=1.0, theta=0.0
% INFO    : Bus 16714	: V=0.9655944, theta=-45.705644 -> V=1.0, theta=0.0
% INFO    : Bus 16715	: V=0.9391805, theta=-48.778176 -> V=1.0, theta=0.0
% INFO    : Bus 16716	: V=0.9451703, theta=-48.049115 -> V=1.0, theta=0.0
% INFO    : Bus 16717	: V=0.9649758, theta=-44.728323 -> V=1.0, theta=0.0
% INFO    : Bus 16718	: V=0.9540088, theta=-45.452945 -> V=1.0, theta=0.0
% INFO    : Bus 16719	: V=0.9525772, theta=-46.164666 -> V=1.0, theta=0.0
% INFO    : Bus 16720	: V=0.9571422, theta=-45.855485 -> V=1.0, theta=0.0
% INFO    : Bus 16721	: V=0.9691738, theta=-45.482532 -> V=1.0, theta=0.0
% INFO    : Bus 16722	: V=0.972683, theta=-45.286319 -> V=1.0, theta=0.0
% INFO    : Bus 16723	: V=1.0073849, theta=-41.595893 -> V=1.0, theta=0.0
% INFO    : Bus 16724	: V=0.961557, theta=-46.463522 -> V=1.0, theta=0.0
% INFO    : Bus 16725	: V=0.9759608, theta=-44.995844 -> V=1.0, theta=0.0
% INFO    : Bus 16726	: V=0.9737951, theta=-45.199161 -> V=1.0, theta=0.0
% INFO    : Bus 16727	: V=0.9753455, theta=-45.22509 -> V=1.0, theta=0.0
% INFO    : Bus 16728	: V=0.963535, theta=-45.991657 -> V=1.0, theta=0.0
% INFO    : Bus 16729	: V=0.983839, theta=-44.341443 -> V=1.0, theta=0.0
% INFO    : Bus 16730	: V=0.9927382, theta=-43.434356 -> V=1.0, theta=0.0
% INFO    : Bus 16731	: V=0.9863143, theta=-43.502649 -> V=1.0, theta=0.0
% INFO    : Bus 16732	: V=0.9748211, theta=-45.235928 -> V=1.0, theta=0.0
% INFO    : Bus 16733	: V=0.9783555, theta=-44.863709 -> V=1.0, theta=0.0
% INFO    : Bus 16734	: V=0.9749414, theta=-45.207827 -> V=1.0, theta=0.0
% INFO    : Bus 16735	: V=0.9739785, theta=-45.306203 -> V=1.0, theta=0.0
% INFO    : Bus 16736	: V=0.9742408, theta=-45.29438 -> V=1.0, theta=0.0
% INFO    : Bus 16737	: V=0.9741621, theta=-45.312999 -> V=1.0, theta=0.0
% INFO    : Bus 16738	: V=0.9626529, theta=-46.137848 -> V=1.0, theta=0.0
% INFO    : Bus 16739	: V=0.9891195, theta=-43.613788 -> V=1.0, theta=0.0
% INFO    : Bus 16740	: V=0.9715497, theta=-45.56151 -> V=1.0, theta=0.0
% INFO    : Bus 16741	: V=0.9701447, theta=-45.732638 -> V=1.0, theta=0.0
% INFO    : Bus 16742	: V=0.9669338, theta=-46.046745 -> V=1.0, theta=0.0
% INFO    : Bus 16743	: V=0.9830446, theta=-44.080605 -> V=1.0, theta=0.0
% INFO    : Bus 16744	: V=0.973486, theta=-45.231979 -> V=1.0, theta=0.0
% INFO    : Bus 16745	: V=0.9715916, theta=-45.456147 -> V=1.0, theta=0.0
% INFO    : Bus 16746	: V=0.9587912, theta=-46.646609 -> V=1.0, theta=0.0
% INFO    : Bus 16747	: V=0.9581666, theta=-46.654017 -> V=1.0, theta=0.0
% INFO    : Bus 16748	: V=0.9573106, theta=-46.683293 -> V=1.0, theta=0.0
% INFO    : Bus 16749	: V=0.957096, theta=-46.681254 -> V=1.0, theta=0.0
% INFO    : Bus 16750	: V=0.9491031, theta=-47.408642 -> V=1.0, theta=0.0
% INFO    : Bus 16751	: V=0.9707081, theta=-45.743499 -> V=1.0, theta=0.0
% INFO    : Bus 16752	: V=0.9887327, theta=-43.648617 -> V=1.0, theta=0.0
% INFO    : Bus 16753	: V=0.9596207, theta=-46.866983 -> V=1.0, theta=0.0
% INFO    : Bus 16754	: V=0.9575954, theta=-47.04614 -> V=1.0, theta=0.0
% INFO    : Bus 16755	: V=0.9570404, theta=-47.084885 -> V=1.0, theta=0.0
% INFO    : Bus 16756	: V=0.959416, theta=-46.353783 -> V=1.0, theta=0.0
% INFO    : Bus 16757	: V=0.9526436, theta=-47.536796 -> V=1.0, theta=0.0
% INFO    : Bus 16758	: V=0.9673533, theta=-46.01396 -> V=1.0, theta=0.0
% INFO    : Bus 16759	: V=0.9567863, theta=-47.084109 -> V=1.0, theta=0.0
% INFO    : Bus 16760	: V=0.9566709, theta=-47.084838 -> V=1.0, theta=0.0
% INFO    : Bus 16761	: V=0.9404381, theta=-48.169003 -> V=1.0, theta=0.0
% INFO    : Bus 16762	: V=0.9429145, theta=-47.802521 -> V=1.0, theta=0.0
% INFO    : Bus 16763	: V=0.9399258, theta=-47.99227 -> V=1.0, theta=0.0
% INFO    : Bus 16764	: V=0.9517304, theta=-47.358974 -> V=1.0, theta=0.0
% INFO    : Bus 16765	: V=0.9481184, theta=-47.615102 -> V=1.0, theta=0.0
% INFO    : Bus 16766	: V=0.9371915, theta=-48.170036 -> V=1.0, theta=0.0
% INFO    : Bus 16767	: V=0.9457962, theta=-48.293164 -> V=1.0, theta=0.0
% INFO    : Bus 16768	: V=0.9437687, theta=-47.908162 -> V=1.0, theta=0.0
% INFO    : Bus 16769	: V=0.973387, theta=-45.432941 -> V=1.0, theta=0.0
% INFO    : Bus 16770	: V=1.0067912, theta=-39.989707 -> V=1.0, theta=0.0
% INFO    : Bus 16771	: V=1.0183781, theta=-38.703283 -> V=1.0, theta=0.0
% INFO    : Bus 16772	: V=1.0184203, theta=-38.74307 -> V=1.0, theta=0.0
% INFO    : Bus 16773	: V=1.0135933, theta=-39.404822 -> V=1.0, theta=0.0
% INFO    : Bus 16774	: V=1.0178129, theta=-38.82057 -> V=1.0, theta=0.0
% INFO    : Bus 16775	: V=1.0177352, theta=-38.83392 -> V=1.0, theta=0.0
% INFO    : Bus 16776	: V=1.0035161, theta=-39.525925 -> V=1.0, theta=0.0
% INFO    : Bus 16777	: V=1.016549, theta=-38.827249 -> V=1.0, theta=0.0
% INFO    : Bus 16778	: V=0.9941606, theta=-40.983701 -> V=1.0, theta=0.0
% INFO    : Bus 16779	: V=0.9865321, theta=-42.075006 -> V=1.0, theta=0.0
% INFO    : Bus 16780	: V=0.9967154, theta=-40.914548 -> V=1.0, theta=0.0
% INFO    : Bus 16781	: V=0.9402903, theta=-44.498822 -> V=1.0, theta=0.0
% INFO    : Bus 16782	: V=0.9689409, theta=-40.110521 -> V=1.0, theta=0.0
% INFO    : Bus 16783	: V=0.956415, theta=-41.482258 -> V=1.0, theta=0.0
% INFO    : Bus 16784	: V=0.9685149, theta=-40.422472 -> V=1.0, theta=0.0
% INFO    : Bus 16785	: V=0.9656439, theta=-41.217261 -> V=1.0, theta=0.0
% INFO    : Bus 16786	: V=0.966994, theta=-40.8046 -> V=1.0, theta=0.0
% INFO    : Bus 16787	: V=0.9522198, theta=-41.607548 -> V=1.0, theta=0.0
% INFO    : Bus 16788	: V=0.9804838, theta=-39.440177 -> V=1.0, theta=0.0
% INFO    : Bus 16789	: V=0.9791333, theta=-39.796636 -> V=1.0, theta=0.0
% INFO    : Bus 16790	: V=0.9660374, theta=-41.197906 -> V=1.0, theta=0.0
% INFO    : Bus 16791	: V=0.9670025, theta=-41.126998 -> V=1.0, theta=0.0
% INFO    : Bus 16792	: V=0.9676178, theta=-41.181526 -> V=1.0, theta=0.0
% INFO    : Bus 16793	: V=0.9658657, theta=-41.187603 -> V=1.0, theta=0.0
% INFO    : Bus 16794	: V=0.966349, theta=-41.219952 -> V=1.0, theta=0.0
% INFO    : Bus 16795	: V=0.9736165, theta=-40.920573 -> V=1.0, theta=0.0
% INFO    : Bus 16796	: V=0.9743369, theta=-40.905179 -> V=1.0, theta=0.0
% INFO    : Bus 16797	: V=0.9834106, theta=-40.11136 -> V=1.0, theta=0.0
% INFO    : Bus 16798	: V=0.9800093, theta=-40.081065 -> V=1.0, theta=0.0
% INFO    : Bus 16799	: V=0.9794547, theta=-39.660877 -> V=1.0, theta=0.0
% INFO    : Bus 16800	: V=0.9807187, theta=-39.519745 -> V=1.0, theta=0.0
% INFO    : Bus 16801	: V=0.9821247, theta=-39.268401 -> V=1.0, theta=0.0
% INFO    : Bus 16802	: V=0.9809918, theta=-39.440921 -> V=1.0, theta=0.0
% INFO    : Bus 16803	: V=0.97336, theta=-40.259142 -> V=1.0, theta=0.0
% INFO    : Bus 16804	: V=0.974458, theta=-40.395066 -> V=1.0, theta=0.0
% INFO    : Bus 16805	: V=0.9742089, theta=-40.220234 -> V=1.0, theta=0.0
% INFO    : Bus 16806	: V=0.9760076, theta=-40.00761 -> V=1.0, theta=0.0
% INFO    : Bus 16807	: V=0.9748101, theta=-40.341182 -> V=1.0, theta=0.0
% INFO    : Bus 16808	: V=0.9789057, theta=-39.809331 -> V=1.0, theta=0.0
% INFO    : Bus 16809	: V=1.0063948, theta=-44.26324 -> V=1.0, theta=0.0
% INFO    : Bus 16810	: V=0.9954789, theta=-46.067778 -> V=1.0, theta=0.0
% INFO    : Bus 16811	: V=0.967892, theta=-46.661481 -> V=1.0, theta=0.0
% INFO    : Bus 16812	: V=0.9684646, theta=-48.361122 -> V=1.0, theta=0.0
% INFO    : Bus 16813	: V=0.9717637, theta=-48.0191 -> V=1.0, theta=0.0
% INFO    : Bus 16814	: V=0.9712784, theta=-47.395084 -> V=1.0, theta=0.0
% INFO    : Bus 16815	: V=0.9730683, theta=-46.644464 -> V=1.0, theta=0.0
% INFO    : Bus 16816	: V=0.9683701, theta=-45.104152 -> V=1.0, theta=0.0
% INFO    : Bus 16817	: V=0.9723164, theta=-45.069384 -> V=1.0, theta=0.0
% INFO    : Bus 16818	: V=0.9727077, theta=-45.599665 -> V=1.0, theta=0.0
% INFO    : Bus 16819	: V=0.9723179, theta=-46.115145 -> V=1.0, theta=0.0
% INFO    : Bus 16820	: V=0.9713189, theta=-45.613632 -> V=1.0, theta=0.0
% INFO    : Bus 16821	: V=0.9916922, theta=-43.502857 -> V=1.0, theta=0.0
% INFO    : Bus 16822	: V=0.9738488, theta=-44.965864 -> V=1.0, theta=0.0
% INFO    : Bus 16823	: V=0.96338, theta=-47.773535 -> V=1.0, theta=0.0
% INFO    : Bus 16824	: V=1.0047584, theta=-45.270944 -> V=1.0, theta=0.0
% INFO    : Bus 16825	: V=0.9395803, theta=-48.549227 -> V=1.0, theta=0.0
% INFO    : Bus 16826	: V=0.9459723, theta=-48.252884 -> V=1.0, theta=0.0
% INFO    : Bus 16827	: V=0.9421052, theta=-49.276485 -> V=1.0, theta=0.0
% INFO    : Bus 16828	: V=0.9415376, theta=-49.284906 -> V=1.0, theta=0.0
% INFO    : Bus 16829	: V=0.9402783, theta=-49.337802 -> V=1.0, theta=0.0
% INFO    : Bus 16830	: V=0.9403341, theta=-50.107119 -> V=1.0, theta=0.0
% INFO    : Bus 16831	: V=0.9385413, theta=-50.369573 -> V=1.0, theta=0.0
% INFO    : Bus 16832	: V=0.9396574, theta=-50.397399 -> V=1.0, theta=0.0
% INFO    : Bus 16833	: V=0.9391179, theta=-50.535119 -> V=1.0, theta=0.0
% INFO    : Bus 16834	: V=0.9402235, theta=-50.246181 -> V=1.0, theta=0.0
% INFO    : Bus 16835	: V=0.9431635, theta=-49.786615 -> V=1.0, theta=0.0
% INFO    : Bus 16836	: V=0.9419604, theta=-49.747125 -> V=1.0, theta=0.0
% INFO    : Bus 16837	: V=0.9498667, theta=-47.51739 -> V=1.0, theta=0.0
% INFO    : Bus 16838	: V=0.944479, theta=-49.114059 -> V=1.0, theta=0.0
% INFO    : Bus 16839	: V=0.9514424, theta=-47.357537 -> V=1.0, theta=0.0
% INFO    : Bus 16840	: V=0.9471102, theta=-48.76428 -> V=1.0, theta=0.0
% INFO    : Bus 16841	: V=0.9535208, theta=-47.092369 -> V=1.0, theta=0.0
% INFO    : Bus 16842	: V=0.9578855, theta=-46.261635 -> V=1.0, theta=0.0
% INFO    : Bus 16843	: V=0.949629, theta=-48.120904 -> V=1.0, theta=0.0
% INFO    : Bus 16844	: V=0.947851, theta=-48.579525 -> V=1.0, theta=0.0
% INFO    : Bus 16845	: V=0.9467066, theta=-48.610664 -> V=1.0, theta=0.0
% INFO    : Bus 16846	: V=0.9415771, theta=-49.567833 -> V=1.0, theta=0.0
% INFO    : Bus 16847	: V=0.9417219, theta=-49.365138 -> V=1.0, theta=0.0
% INFO    : Bus 16848	: V=0.9437334, theta=-49.050891 -> V=1.0, theta=0.0
% INFO    : Bus 16849	: V=0.9473653, theta=-48.549864 -> V=1.0, theta=0.0
% INFO    : Bus 16850	: V=0.9452654, theta=-47.840207 -> V=1.0, theta=0.0
% INFO    : Bus 16851	: V=0.9910369, theta=-41.916306 -> V=1.0, theta=0.0
% INFO    : Bus 16852	: V=0.9721225, theta=-43.388448 -> V=1.0, theta=0.0
% INFO    : Bus 16853	: V=0.9605586, theta=-44.476771 -> V=1.0, theta=0.0
% INFO    : Bus 16854	: V=0.9644328, theta=-43.924608 -> V=1.0, theta=0.0
% INFO    : Bus 16855	: V=0.9672002, theta=-43.777206 -> V=1.0, theta=0.0
% INFO    : Bus 16856	: V=0.9666678, theta=-39.790722 -> V=1.0, theta=0.0
% INFO    : Bus 16857	: V=0.9753571, theta=-39.066444 -> V=1.0, theta=0.0
% INFO    : Bus 16858	: V=0.9662429, theta=-39.591964 -> V=1.0, theta=0.0
% INFO    : Bus 16859	: V=0.9712102, theta=-39.5546 -> V=1.0, theta=0.0
% INFO    : Bus 16860	: V=0.9802278, theta=-38.269466 -> V=1.0, theta=0.0
% INFO    : Bus 16861	: V=0.9765965, theta=-38.835262 -> V=1.0, theta=0.0
% INFO    : Bus 16862	: V=0.9694823, theta=-39.172077 -> V=1.0, theta=0.0
% INFO    : Bus 16863	: V=0.975024, theta=-38.466524 -> V=1.0, theta=0.0
% INFO    : Bus 16864	: V=0.9427182, theta=-44.500837 -> V=1.0, theta=0.0
% INFO    : Bus 16865	: V=0.9710961, theta=-44.272772 -> V=1.0, theta=0.0
% INFO    : Bus 16866	: V=0.9794819, theta=-42.893351 -> V=1.0, theta=0.0
% INFO    : Bus 16867	: V=0.9666334, theta=-44.219388 -> V=1.0, theta=0.0
% INFO    : Bus 16868	: V=0.9758476, theta=-43.347268 -> V=1.0, theta=0.0
% INFO    : Bus 16869	: V=0.9663556, theta=-45.098117 -> V=1.0, theta=0.0
% INFO    : Bus 16870	: V=0.9781581, theta=-43.373637 -> V=1.0, theta=0.0
% INFO    : Bus 16871	: V=0.9742351, theta=-43.895007 -> V=1.0, theta=0.0
% INFO    : Bus 16872	: V=0.9932535, theta=-41.399169 -> V=1.0, theta=0.0
% INFO    : Bus 16873	: V=0.9753099, theta=-43.209223 -> V=1.0, theta=0.0
% INFO    : Bus 16874	: V=0.9793169, theta=-43.296356 -> V=1.0, theta=0.0
% INFO    : Bus 16875	: V=0.9724427, theta=-44.336528 -> V=1.0, theta=0.0
% INFO    : Bus 16876	: V=0.9635875, theta=-46.051717 -> V=1.0, theta=0.0
% INFO    : Bus 16877	: V=0.9675677, theta=-45.218666 -> V=1.0, theta=0.0
% INFO    : Bus 16878	: V=0.9463936, theta=-48.935665 -> V=1.0, theta=0.0
% INFO    : Bus 16879	: V=0.9537792, theta=-47.86516 -> V=1.0, theta=0.0
% INFO    : Bus 16880	: V=0.9609149, theta=-46.083414 -> V=1.0, theta=0.0
% INFO    : Bus 16881	: V=0.9567802, theta=-45.650989 -> V=1.0, theta=0.0
% INFO    : Bus 16882	: V=0.9632024, theta=-45.598782 -> V=1.0, theta=0.0
% INFO    : Bus 16883	: V=0.9638831, theta=-44.963749 -> V=1.0, theta=0.0
% INFO    : Bus 16884	: V=0.9620593, theta=-45.184774 -> V=1.0, theta=0.0
% INFO    : Bus 16885	: V=0.9635033, theta=-45.056596 -> V=1.0, theta=0.0
% INFO    : Bus 16886	: V=0.9626263, theta=-45.24704 -> V=1.0, theta=0.0
% INFO    : Bus 16887	: V=0.9647037, theta=-44.231724 -> V=1.0, theta=0.0
% INFO    : Bus 16888	: V=0.9788292, theta=-42.854414 -> V=1.0, theta=0.0
% INFO    : Bus 16889	: V=0.9819491, theta=-41.596761 -> V=1.0, theta=0.0
% INFO    : Bus 16890	: V=0.9827546, theta=-41.277929 -> V=1.0, theta=0.0
% INFO    : Bus 16891	: V=0.9637346, theta=-44.106865 -> V=1.0, theta=0.0
% INFO    : Bus 16892	: V=0.9863897, theta=-41.991663 -> V=1.0, theta=0.0
% INFO    : Bus 16893	: V=0.9906882, theta=-41.222439 -> V=1.0, theta=0.0
% INFO    : Bus 16894	: V=1.0061472, theta=-39.226438 -> V=1.0, theta=0.0
% INFO    : Bus 16895	: V=0.985704, theta=-41.293874 -> V=1.0, theta=0.0
% INFO    : Bus 16896	: V=0.9917625, theta=-39.357115 -> V=1.0, theta=0.0
% INFO    : Bus 16897	: V=0.9901741, theta=-39.560049 -> V=1.0, theta=0.0
% INFO    : Bus 16898	: V=0.9828292, theta=-41.157391 -> V=1.0, theta=0.0
% INFO    : Bus 16899	: V=0.9844158, theta=-40.715638 -> V=1.0, theta=0.0
% INFO    : Bus 16900	: V=0.9818897, theta=-41.046294 -> V=1.0, theta=0.0
% INFO    : Bus 16901	: V=0.9935553, theta=-39.137852 -> V=1.0, theta=0.0
% INFO    : Bus 16902	: V=0.9943332, theta=-39.643026 -> V=1.0, theta=0.0
% INFO    : Bus 16903	: V=0.9813383, theta=-41.228403 -> V=1.0, theta=0.0
% INFO    : Bus 16904	: V=0.9899105, theta=-40.98248 -> V=1.0, theta=0.0
% INFO    : Bus 16905	: V=0.9864024, theta=-41.167074 -> V=1.0, theta=0.0
% INFO    : Bus 16906	: V=0.984309, theta=-41.17631 -> V=1.0, theta=0.0
% INFO    : Bus 16907	: V=0.9930737, theta=-40.503721 -> V=1.0, theta=0.0
% INFO    : Bus 16908	: V=0.9799284, theta=-41.309895 -> V=1.0, theta=0.0
% INFO    : Bus 16909	: V=0.992783, theta=-41.118585 -> V=1.0, theta=0.0
% INFO    : Bus 16910	: V=0.9748069, theta=-43.989326 -> V=1.0, theta=0.0
% INFO    : Bus 16911	: V=0.9880871, theta=-41.587302 -> V=1.0, theta=0.0
% INFO    : Bus 16912	: V=0.9850669, theta=-41.895761 -> V=1.0, theta=0.0
% INFO    : Bus 16913	: V=0.9780399, theta=-42.470307 -> V=1.0, theta=0.0
% INFO    : Bus 16914	: V=0.9839235, theta=-42.025268 -> V=1.0, theta=0.0
% INFO    : Bus 16915	: V=0.9792571, theta=-43.86041 -> V=1.0, theta=0.0
% INFO    : Bus 16916	: V=0.9784678, theta=-43.300616 -> V=1.0, theta=0.0
% INFO    : Bus 16917	: V=0.9628743, theta=-45.85327 -> V=1.0, theta=0.0
% INFO    : Bus 16918	: V=0.9788386, theta=-39.561464 -> V=1.0, theta=0.0
% INFO    : Bus 16919	: V=0.9527439, theta=-43.279991 -> V=1.0, theta=0.0
% INFO    : Bus 16920	: V=0.9585841, theta=-42.514821 -> V=1.0, theta=0.0
% INFO    : Bus 16921	: V=0.9541576, theta=-42.895106 -> V=1.0, theta=0.0
% INFO    : Bus 16922	: V=0.9761445, theta=-39.999002 -> V=1.0, theta=0.0
% INFO    : Bus 16923	: V=0.9829873, theta=-39.304601 -> V=1.0, theta=0.0
% INFO    : Bus 16924	: V=0.9801348, theta=-39.511566 -> V=1.0, theta=0.0
% INFO    : Bus 16925	: V=0.9872388, theta=-38.715159 -> V=1.0, theta=0.0
% INFO    : Bus 16926	: V=0.9780974, theta=-39.681353 -> V=1.0, theta=0.0
% INFO    : Bus 16927	: V=0.9732176, theta=-40.328576 -> V=1.0, theta=0.0
% INFO    : Bus 16928	: V=0.9710948, theta=-40.473531 -> V=1.0, theta=0.0
% INFO    : Bus 16929	: V=0.9680615, theta=-41.221891 -> V=1.0, theta=0.0
% INFO    : Bus 16930	: V=0.9533468, theta=-42.700652 -> V=1.0, theta=0.0
% INFO    : Bus 16931	: V=0.9645517, theta=-41.859901 -> V=1.0, theta=0.0
% INFO    : Bus 16932	: V=0.9645702, theta=-41.933606 -> V=1.0, theta=0.0
% INFO    : Bus 16933	: V=0.9522157, theta=-42.488597 -> V=1.0, theta=0.0
% INFO    : Bus 16934	: V=0.9573464, theta=-42.421149 -> V=1.0, theta=0.0
% INFO    : Bus 16935	: V=0.9551357, theta=-42.275218 -> V=1.0, theta=0.0
% INFO    : Bus 16936	: V=0.9689547, theta=-40.613715 -> V=1.0, theta=0.0
% INFO    : Bus 16937	: V=0.9708859, theta=-39.99533 -> V=1.0, theta=0.0
% INFO    : Bus 16938	: V=0.974546, theta=-39.661985 -> V=1.0, theta=0.0
% INFO    : Bus 16939	: V=0.9683321, theta=-40.34561 -> V=1.0, theta=0.0
% INFO    : Bus 16940	: V=0.9668854, theta=-40.917015 -> V=1.0, theta=0.0
% INFO    : Bus 16941	: V=0.9630015, theta=-41.593557 -> V=1.0, theta=0.0
% INFO    : Bus 16942	: V=0.9668722, theta=-41.026019 -> V=1.0, theta=0.0
% INFO    : Bus 16943	: V=0.9663984, theta=-37.772066 -> V=1.0, theta=0.0
% INFO    : Bus 16944	: V=0.9507488, theta=-39.205101 -> V=1.0, theta=0.0
% INFO    : Bus 16945	: V=0.9516747, theta=-39.820028 -> V=1.0, theta=0.0
% INFO    : Bus 16946	: V=0.9671021, theta=-41.609796 -> V=1.0, theta=0.0
% INFO    : Bus 16947	: V=0.9665144, theta=-41.571245 -> V=1.0, theta=0.0
% INFO    : Bus 16948	: V=0.9692993, theta=-41.676193 -> V=1.0, theta=0.0
% INFO    : Bus 16949	: V=0.9693038, theta=-41.575492 -> V=1.0, theta=0.0
% INFO    : Bus 16950	: V=0.9879887, theta=-39.985546 -> V=1.0, theta=0.0
% INFO    : Bus 16951	: V=0.9817538, theta=-40.38205 -> V=1.0, theta=0.0
% INFO    : Bus 16952	: V=0.9701221, theta=-41.080672 -> V=1.0, theta=0.0
% INFO    : Bus 16953	: V=0.9709311, theta=-41.310398 -> V=1.0, theta=0.0
% INFO    : Bus 16954	: V=0.9787662, theta=-40.388536 -> V=1.0, theta=0.0
% INFO    : Bus 16955	: V=0.9683418, theta=-41.194772 -> V=1.0, theta=0.0
% INFO    : Bus 16956	: V=0.9671648, theta=-41.570805 -> V=1.0, theta=0.0
% INFO    : Bus 16957	: V=1.0086769, theta=-38.358961 -> V=1.0, theta=0.0
% INFO    : Bus 16958	: V=1.0045924, theta=-38.156923 -> V=1.0, theta=0.0
% INFO    : Bus 16959	: V=0.9454703, theta=-41.533233 -> V=1.0, theta=0.0
% INFO    : Bus 16960	: V=0.9478798, theta=-41.470615 -> V=1.0, theta=0.0
% INFO    : Bus 16961	: V=0.9511883, theta=-40.642491 -> V=1.0, theta=0.0
% INFO    : Bus 16962	: V=0.9513494, theta=-40.668073 -> V=1.0, theta=0.0
% INFO    : Bus 16963	: V=0.9467612, theta=-41.763118 -> V=1.0, theta=0.0
% INFO    : Bus 16964	: V=0.9517216, theta=-40.710681 -> V=1.0, theta=0.0
% INFO    : Bus 16965	: V=0.9471908, theta=-41.603447 -> V=1.0, theta=0.0
% INFO    : Bus 16966	: V=0.9505825, theta=-40.910964 -> V=1.0, theta=0.0
% INFO    : Bus 16967	: V=0.9483442, theta=-41.242847 -> V=1.0, theta=0.0
% INFO    : Bus 16968	: V=0.9591951, theta=-39.857583 -> V=1.0, theta=0.0
% INFO    : Bus 16969	: V=0.9666139, theta=-39.486159 -> V=1.0, theta=0.0
% INFO    : Bus 16970	: V=0.9690104, theta=-39.332759 -> V=1.0, theta=0.0
% INFO    : Bus 16971	: V=0.968808, theta=-38.556472 -> V=1.0, theta=0.0
% INFO    : Bus 16972	: V=0.9616449, theta=-39.483006 -> V=1.0, theta=0.0
% INFO    : Bus 16973	: V=0.950922, theta=-40.413969 -> V=1.0, theta=0.0
% INFO    : Bus 16974	: V=0.9575566, theta=-42.420225 -> V=1.0, theta=0.0
% INFO    : Bus 16975	: V=0.9557842, theta=-42.651426 -> V=1.0, theta=0.0
% INFO    : Bus 16976	: V=0.9553259, theta=-42.478846 -> V=1.0, theta=0.0
% INFO    : Bus 16977	: V=0.9770799, theta=-40.268304 -> V=1.0, theta=0.0
% INFO    : Bus 16978	: V=0.9581016, theta=-42.286383 -> V=1.0, theta=0.0
% INFO    : Bus 16979	: V=0.9534633, theta=-43.220612 -> V=1.0, theta=0.0
% INFO    : Bus 16980	: V=0.9429754, theta=-44.453778 -> V=1.0, theta=0.0
% INFO    : Bus 16981	: V=0.9551478, theta=-43.454189 -> V=1.0, theta=0.0
% INFO    : Bus 16982	: V=0.9511048, theta=-43.06677 -> V=1.0, theta=0.0
% INFO    : Bus 16983	: V=0.9655955, theta=-41.918633 -> V=1.0, theta=0.0
% INFO    : Bus 16984	: V=0.9846238, theta=-39.997084 -> V=1.0, theta=0.0
% INFO    : Bus 16985	: V=0.9823317, theta=-39.901511 -> V=1.0, theta=0.0
% INFO    : Bus 16986	: V=0.9828777, theta=-39.500598 -> V=1.0, theta=0.0
% INFO    : Bus 16987	: V=0.9925537, theta=-39.323151 -> V=1.0, theta=0.0
% INFO    : Bus 16988	: V=1.0045808, theta=-37.541141 -> V=1.0, theta=0.0
% INFO    : Bus 16989	: V=1.0022623, theta=-38.027024 -> V=1.0, theta=0.0
% INFO    : Bus 16990	: V=0.9963035, theta=-38.810459 -> V=1.0, theta=0.0
% INFO    : Bus 16991	: V=0.9948984, theta=-38.991066 -> V=1.0, theta=0.0
% INFO    : Bus 16992	: V=0.9487562, theta=-48.684628 -> V=1.0, theta=0.0
% INFO    : Bus 16993	: V=0.9549715, theta=-47.802878 -> V=1.0, theta=0.0
% INFO    : Bus 16994	: V=0.9559812, theta=-47.632122 -> V=1.0, theta=0.0
% INFO    : Bus 16995	: V=0.957028, theta=-47.515636 -> V=1.0, theta=0.0
% INFO    : Bus 16996	: V=0.9606075, theta=-46.566096 -> V=1.0, theta=0.0
% INFO    : Bus 16997	: V=0.9618628, theta=-46.406586 -> V=1.0, theta=0.0
% INFO    : Bus 16998	: V=0.9546547, theta=-48.027295 -> V=1.0, theta=0.0
% INFO    : Bus 16999	: V=0.9572446, theta=-46.69723 -> V=1.0, theta=0.0
% INFO    : Bus 17000	: V=0.9431405, theta=-48.619107 -> V=1.0, theta=0.0
% INFO    : Bus 17001	: V=0.9689512, theta=-45.475443 -> V=1.0, theta=0.0
% INFO    : Bus 17002	: V=1.0029124, theta=-39.576028 -> V=1.0, theta=0.0
% INFO    : Bus 17003	: V=1.0070407, theta=-38.858904 -> V=1.0, theta=0.0
% INFO    : Bus 17004	: V=0.9870365, theta=-41.182662 -> V=1.0, theta=0.0
% INFO    : Bus 17005	: V=0.9903754, theta=-40.768249 -> V=1.0, theta=0.0
% INFO    : Bus 17006	: V=0.9842667, theta=-41.627125 -> V=1.0, theta=0.0
% INFO    : Bus 17007	: V=0.9692617, theta=-43.420927 -> V=1.0, theta=0.0
% INFO    : Bus 17008	: V=0.9747519, theta=-42.443628 -> V=1.0, theta=0.0
% INFO    : Bus 17009	: V=0.979911, theta=-41.850544 -> V=1.0, theta=0.0
% INFO    : Bus 17010	: V=0.9837146, theta=-41.239802 -> V=1.0, theta=0.0
% INFO    : Bus 17011	: V=0.9654508, theta=-48.501373 -> V=1.0, theta=0.0
% INFO    : Bus 17012	: V=0.9776691, theta=-47.765529 -> V=1.0, theta=0.0
% INFO    : Bus 17013	: V=0.9709396, theta=-48.33453 -> V=1.0, theta=0.0
% INFO    : Bus 17014	: V=0.9666648, theta=-48.800226 -> V=1.0, theta=0.0
% INFO    : Bus 17015	: V=0.9767703, theta=-47.660864 -> V=1.0, theta=0.0
% INFO    : Bus 17016	: V=0.963877, theta=-48.876086 -> V=1.0, theta=0.0
% INFO    : Bus 17017	: V=0.9599827, theta=-43.370635 -> V=1.0, theta=0.0
% INFO    : Bus 17018	: V=0.9324303, theta=-49.194686 -> V=1.0, theta=0.0
% INFO    : Bus 17019	: V=0.9324379, theta=-49.168245 -> V=1.0, theta=0.0
% INFO    : Bus 17020	: V=0.9512558, theta=-44.652955 -> V=1.0, theta=0.0
% INFO    : Bus 17021	: V=0.9343726, theta=-48.797079 -> V=1.0, theta=0.0
% INFO    : Bus 17022	: V=0.9483372, theta=-44.82577 -> V=1.0, theta=0.0
% INFO    : Bus 17023	: V=0.9879871, theta=-38.500698 -> V=1.0, theta=0.0
% INFO    : Bus 17024	: V=0.9815263, theta=-39.058191 -> V=1.0, theta=0.0
% INFO    : Bus 17025	: V=0.9869515, theta=-38.71834 -> V=1.0, theta=0.0
% INFO    : Bus 17026	: V=0.9858209, theta=-38.790582 -> V=1.0, theta=0.0
% INFO    : Bus 17027	: V=0.9823931, theta=-39.163651 -> V=1.0, theta=0.0
% INFO    : Bus 17028	: V=0.9796313, theta=-39.449374 -> V=1.0, theta=0.0
% INFO    : Bus 17029	: V=0.9809097, theta=-39.305268 -> V=1.0, theta=0.0
% INFO    : Bus 17030	: V=0.9857157, theta=-38.931258 -> V=1.0, theta=0.0
% INFO    : Bus 17031	: V=0.980418, theta=-39.302625 -> V=1.0, theta=0.0
% INFO    : Bus 17032	: V=0.9828277, theta=-38.860867 -> V=1.0, theta=0.0
% INFO    : Bus 17033	: V=0.980226, theta=-39.088596 -> V=1.0, theta=0.0
% INFO    : Bus 17034	: V=0.98165, theta=-39.029677 -> V=1.0, theta=0.0
% INFO    : Bus 17035	: V=0.9788602, theta=-39.503678 -> V=1.0, theta=0.0
% INFO    : Bus 17036	: V=0.970682, theta=-39.961648 -> V=1.0, theta=0.0
% INFO    : Bus 17037	: V=0.9748479, theta=-39.918923 -> V=1.0, theta=0.0
% INFO    : Bus 17038	: V=0.9691725, theta=-39.993525 -> V=1.0, theta=0.0
% INFO    : Bus 17039	: V=0.9691499, theta=-40.051651 -> V=1.0, theta=0.0
% INFO    : Bus 17040	: V=0.972185, theta=-39.915657 -> V=1.0, theta=0.0
% INFO    : Bus 17041	: V=0.9713619, theta=-39.921553 -> V=1.0, theta=0.0
% INFO    : Bus 17042	: V=0.9712819, theta=-39.923155 -> V=1.0, theta=0.0
% INFO    : Bus 17043	: V=0.9789365, theta=-39.139656 -> V=1.0, theta=0.0
% INFO    : Bus 17044	: V=0.9722239, theta=-39.842858 -> V=1.0, theta=0.0
% INFO    : Bus 17045	: V=0.9702678, theta=-40.005874 -> V=1.0, theta=0.0
% INFO    : Bus 17046	: V=0.9706921, theta=-39.942318 -> V=1.0, theta=0.0
% INFO    : Bus 17047	: V=0.9688179, theta=-40.129613 -> V=1.0, theta=0.0
% INFO    : Bus 17048	: V=0.9759692, theta=-39.48023 -> V=1.0, theta=0.0
% INFO    : Bus 17049	: V=0.97753, theta=-39.187827 -> V=1.0, theta=0.0
% INFO    : Bus 17050	: V=0.9818939, theta=-38.915733 -> V=1.0, theta=0.0
% INFO    : Bus 17051	: V=0.9812425, theta=-38.951712 -> V=1.0, theta=0.0
% INFO    : Bus 17052	: V=0.9693577, theta=-39.89503 -> V=1.0, theta=0.0
% INFO    : Bus 17053	: V=0.9689067, theta=-39.923993 -> V=1.0, theta=0.0
% INFO    : Bus 17054	: V=0.9677369, theta=-40.214587 -> V=1.0, theta=0.0
% INFO    : Bus 17055	: V=0.9726148, theta=-39.625495 -> V=1.0, theta=0.0
% INFO    : Bus 17056	: V=0.9772983, theta=-39.02221 -> V=1.0, theta=0.0
% INFO    : Bus 17057	: V=0.9671416, theta=-40.140517 -> V=1.0, theta=0.0
% INFO    : Bus 17058	: V=0.966545, theta=-40.099618 -> V=1.0, theta=0.0
% INFO    : Bus 17059	: V=0.9768167, theta=-39.190219 -> V=1.0, theta=0.0
% INFO    : Bus 17060	: V=0.976467, theta=-39.182712 -> V=1.0, theta=0.0
% INFO    : Bus 17061	: V=0.9764184, theta=-39.134189 -> V=1.0, theta=0.0
% INFO    : Bus 17062	: V=0.9710212, theta=-39.662767 -> V=1.0, theta=0.0
% INFO    : Bus 17063	: V=0.9662187, theta=-40.283881 -> V=1.0, theta=0.0
% INFO    : Bus 17064	: V=0.9670161, theta=-40.188902 -> V=1.0, theta=0.0
% INFO    : Bus 17065	: V=0.9735069, theta=-39.444471 -> V=1.0, theta=0.0
% INFO    : Bus 17066	: V=0.9740414, theta=-39.310167 -> V=1.0, theta=0.0
% INFO    : Bus 17067	: V=0.9802953, theta=-38.749806 -> V=1.0, theta=0.0
% INFO    : Bus 17068	: V=0.9741636, theta=-39.54473 -> V=1.0, theta=0.0
% INFO    : Bus 17069	: V=0.9754507, theta=-39.472314 -> V=1.0, theta=0.0
% INFO    : Bus 17070	: V=0.9780173, theta=-39.294451 -> V=1.0, theta=0.0
% INFO    : Bus 17071	: V=0.9838212, theta=-38.795608 -> V=1.0, theta=0.0
% INFO    : Bus 17072	: V=0.98504, theta=-38.719968 -> V=1.0, theta=0.0
% INFO    : Bus 17073	: V=0.9818179, theta=-39.056635 -> V=1.0, theta=0.0
% INFO    : Bus 17074	: V=0.9797151, theta=-39.173952 -> V=1.0, theta=0.0
% INFO    : Bus 17075	: V=0.9790846, theta=-39.102072 -> V=1.0, theta=0.0
% INFO    : Bus 17076	: V=0.9787557, theta=-39.252974 -> V=1.0, theta=0.0
% INFO    : Bus 17077	: V=0.9822901, theta=-38.659784 -> V=1.0, theta=0.0
% INFO    : Bus 17078	: V=0.9809456, theta=-38.727837 -> V=1.0, theta=0.0
% INFO    : Bus 17079	: V=0.97878, theta=-39.061642 -> V=1.0, theta=0.0
% INFO    : Bus 17080	: V=0.9836541, theta=-38.597832 -> V=1.0, theta=0.0
% INFO    : Bus 17081	: V=0.9823038, theta=-38.479885 -> V=1.0, theta=0.0
% INFO    : Bus 17082	: V=0.9819163, theta=-38.386085 -> V=1.0, theta=0.0
% INFO    : Bus 17083	: V=0.9897731, theta=-37.525522 -> V=1.0, theta=0.0
% INFO    : Bus 17084	: V=0.9836866, theta=-38.345091 -> V=1.0, theta=0.0
% INFO    : Bus 17085	: V=0.991113, theta=-37.427353 -> V=1.0, theta=0.0
% INFO    : Bus 17086	: V=0.9798298, theta=-38.536147 -> V=1.0, theta=0.0
% INFO    : Bus 17087	: V=0.973812, theta=-39.160865 -> V=1.0, theta=0.0
% INFO    : Bus 17088	: V=0.9764655, theta=-38.907977 -> V=1.0, theta=0.0
% INFO    : Bus 17089	: V=0.9787403, theta=-38.610994 -> V=1.0, theta=0.0
% INFO    : Bus 17090	: V=0.9774349, theta=-38.779062 -> V=1.0, theta=0.0
% INFO    : Bus 17091	: V=0.9862493, theta=-38.254962 -> V=1.0, theta=0.0
% INFO    : Bus 17092	: V=0.9854916, theta=-38.507184 -> V=1.0, theta=0.0
% INFO    : Bus 17093	: V=0.9867678, theta=-38.058849 -> V=1.0, theta=0.0
% INFO    : Bus 17094	: V=0.9934074, theta=-37.310652 -> V=1.0, theta=0.0
% INFO    : Bus 17095	: V=0.9934923, theta=-37.29167 -> V=1.0, theta=0.0
% INFO    : Bus 17096	: V=0.9863012, theta=-38.018847 -> V=1.0, theta=0.0
% INFO    : Bus 17097	: V=0.9869933, theta=-38.446622 -> V=1.0, theta=0.0
% INFO    : Bus 17098	: V=0.9862016, theta=-38.479851 -> V=1.0, theta=0.0
% INFO    : Bus 17099	: V=0.9789501, theta=-39.132538 -> V=1.0, theta=0.0
% INFO    : Bus 17100	: V=0.982197, theta=-38.968077 -> V=1.0, theta=0.0
% INFO    : Bus 17101	: V=0.9810611, theta=-39.045042 -> V=1.0, theta=0.0
% INFO    : Bus 17102	: V=0.981076, theta=-39.05813 -> V=1.0, theta=0.0
% INFO    : Bus 17103	: V=0.9859018, theta=-38.72867 -> V=1.0, theta=0.0
% INFO    : Bus 17104	: V=0.990652, theta=-38.255257 -> V=1.0, theta=0.0
% INFO    : Bus 17105	: V=0.9884335, theta=-38.377146 -> V=1.0, theta=0.0
% INFO    : Bus 17106	: V=0.9896446, theta=-38.177567 -> V=1.0, theta=0.0
% INFO    : Bus 17107	: V=0.9959051, theta=-37.179946 -> V=1.0, theta=0.0
% INFO    : Bus 17108	: V=0.9945006, theta=-37.258794 -> V=1.0, theta=0.0
% INFO    : Bus 17109	: V=0.9939321, theta=-37.284211 -> V=1.0, theta=0.0
% INFO    : Bus 17110	: V=0.9910127, theta=-38.26 -> V=1.0, theta=0.0
% INFO    : Bus 17111	: V=0.9923951, theta=-38.167391 -> V=1.0, theta=0.0
% INFO    : Bus 17112	: V=0.9922883, theta=-38.223069 -> V=1.0, theta=0.0
% INFO    : Bus 17113	: V=1.0029623, theta=-36.93906 -> V=1.0, theta=0.0
% INFO    : Bus 17114	: V=1.0162839, theta=-35.35302 -> V=1.0, theta=0.0
% INFO    : Bus 17115	: V=0.9944996, theta=-38.057212 -> V=1.0, theta=0.0
% INFO    : Bus 17116	: V=0.9918174, theta=-38.450497 -> V=1.0, theta=0.0
% INFO    : Bus 17117	: V=1.016857, theta=-35.381703 -> V=1.0, theta=0.0
% INFO    : Bus 17118	: V=0.9938138, theta=-38.243422 -> V=1.0, theta=0.0
% INFO    : Bus 17119	: V=1.0025006, theta=-37.174131 -> V=1.0, theta=0.0
% INFO    : Bus 17120	: V=0.9927321, theta=-38.161064 -> V=1.0, theta=0.0
% INFO    : Bus 17121	: V=0.9919654, theta=-38.209613 -> V=1.0, theta=0.0
% INFO    : Bus 17122	: V=0.9911339, theta=-38.39428 -> V=1.0, theta=0.0
% INFO    : Bus 17123	: V=0.9818658, theta=-39.351833 -> V=1.0, theta=0.0
% INFO    : Bus 17124	: V=0.9882383, theta=-38.632643 -> V=1.0, theta=0.0
% INFO    : Bus 17125	: V=0.9808058, theta=-39.448878 -> V=1.0, theta=0.0
% INFO    : Bus 17126	: V=0.9876866, theta=-38.842528 -> V=1.0, theta=0.0
% INFO    : Bus 17127	: V=0.9863144, theta=-38.901317 -> V=1.0, theta=0.0
% INFO    : Bus 17128	: V=0.9986165, theta=-37.49782 -> V=1.0, theta=0.0
% INFO    : Bus 17129	: V=0.9754245, theta=-39.820416 -> V=1.0, theta=0.0
% INFO    : Bus 17130	: V=0.9752177, theta=-39.837909 -> V=1.0, theta=0.0
% INFO    : Bus 17131	: V=0.9767141, theta=-39.784259 -> V=1.0, theta=0.0
% INFO    : Bus 17132	: V=0.9762246, theta=-39.788113 -> V=1.0, theta=0.0
% INFO    : Bus 17133	: V=0.9901712, theta=-38.724481 -> V=1.0, theta=0.0
% INFO    : Bus 17134	: V=0.9899471, theta=-38.72265 -> V=1.0, theta=0.0
% INFO    : Bus 17135	: V=0.9888773, theta=-38.777976 -> V=1.0, theta=0.0
% INFO    : Bus 17136	: V=1.0022904, theta=-37.750737 -> V=1.0, theta=0.0
% INFO    : Bus 17137	: V=0.9884372, theta=-39.254454 -> V=1.0, theta=0.0
% INFO    : Bus 17138	: V=0.9906965, theta=-38.758652 -> V=1.0, theta=0.0
% INFO    : Bus 17139	: V=0.9880849, theta=-39.166124 -> V=1.0, theta=0.0
% INFO    : Bus 17140	: V=0.9882974, theta=-38.869676 -> V=1.0, theta=0.0
% INFO    : Bus 17141	: V=0.9871657, theta=-39.266239 -> V=1.0, theta=0.0
% INFO    : Bus 17142	: V=0.9854449, theta=-39.437721 -> V=1.0, theta=0.0
% INFO    : Bus 17143	: V=0.9875875, theta=-39.630063 -> V=1.0, theta=0.0
% INFO    : Bus 17144	: V=0.9863847, theta=-39.571258 -> V=1.0, theta=0.0
% INFO    : Bus 17145	: V=0.9886865, theta=-39.439528 -> V=1.0, theta=0.0
% INFO    : Bus 17146	: V=0.983903, theta=-39.727107 -> V=1.0, theta=0.0
% INFO    : Bus 17147	: V=0.9830982, theta=-39.851608 -> V=1.0, theta=0.0
% INFO    : Bus 17148	: V=0.9805876, theta=-39.920434 -> V=1.0, theta=0.0
% INFO    : Bus 17149	: V=0.9777117, theta=-40.109788 -> V=1.0, theta=0.0
% INFO    : Bus 17150	: V=0.9845657, theta=-39.416453 -> V=1.0, theta=0.0
% INFO    : Bus 17151	: V=0.9844675, theta=-39.248725 -> V=1.0, theta=0.0
% INFO    : Bus 17152	: V=0.9858884, theta=-38.943593 -> V=1.0, theta=0.0
% INFO    : Bus 17153	: V=0.9816135, theta=-39.451134 -> V=1.0, theta=0.0
% INFO    : Bus 17154	: V=0.9805879, theta=-39.516823 -> V=1.0, theta=0.0
% INFO    : Bus 17155	: V=0.9763523, theta=-40.12555 -> V=1.0, theta=0.0
% INFO    : Bus 17156	: V=0.9757528, theta=-40.202673 -> V=1.0, theta=0.0
% INFO    : Bus 17157	: V=0.9760797, theta=-40.191444 -> V=1.0, theta=0.0
% INFO    : Bus 17158	: V=0.9797372, theta=-39.578251 -> V=1.0, theta=0.0
% INFO    : Bus 17159	: V=0.9735284, theta=-39.94489 -> V=1.0, theta=0.0
% INFO    : Bus 17160	: V=0.979, theta=-39.635599 -> V=1.0, theta=0.0
% INFO    : Bus 17161	: V=0.9709482, theta=-40.456434 -> V=1.0, theta=0.0
% INFO    : Bus 17162	: V=0.9728879, theta=-39.949869 -> V=1.0, theta=0.0
% INFO    : Bus 17163	: V=0.9681837, theta=-40.066104 -> V=1.0, theta=0.0
% INFO    : Bus 17164	: V=0.968187, theta=-40.5564 -> V=1.0, theta=0.0
% INFO    : Bus 17165	: V=0.965829, theta=-40.611754 -> V=1.0, theta=0.0
% INFO    : Bus 17166	: V=0.9654449, theta=-40.50159 -> V=1.0, theta=0.0
% INFO    : Bus 17167	: V=0.9638212, theta=-40.853996 -> V=1.0, theta=0.0
% INFO    : Bus 17168	: V=0.9633531, theta=-40.717828 -> V=1.0, theta=0.0
% INFO    : Bus 17169	: V=0.971805, theta=-39.473867 -> V=1.0, theta=0.0
% INFO    : Bus 17170	: V=0.9666475, theta=-39.979934 -> V=1.0, theta=0.0
% INFO    : Bus 17171	: V=0.9690746, theta=-39.77314 -> V=1.0, theta=0.0
% INFO    : Bus 17172	: V=0.9709741, theta=-39.587666 -> V=1.0, theta=0.0
% INFO    : Bus 17173	: V=0.9693639, theta=-39.763934 -> V=1.0, theta=0.0
% INFO    : Bus 17174	: V=0.9631908, theta=-40.804032 -> V=1.0, theta=0.0
% INFO    : Bus 17175	: V=0.9604875, theta=-40.940253 -> V=1.0, theta=0.0
% INFO    : Bus 17176	: V=0.9706206, theta=-39.631217 -> V=1.0, theta=0.0
% INFO    : Bus 17177	: V=0.9709448, theta=-39.550137 -> V=1.0, theta=0.0
% INFO    : Bus 17178	: V=0.9793824, theta=-38.773414 -> V=1.0, theta=0.0
% INFO    : Bus 17179	: V=0.9856543, theta=-37.389503 -> V=1.0, theta=0.0
% INFO    : Bus 17180	: V=0.9873603, theta=-37.675635 -> V=1.0, theta=0.0
% INFO    : Bus 17181	: V=0.9788311, theta=-38.45357 -> V=1.0, theta=0.0
% INFO    : Bus 17182	: V=0.9865047, theta=-37.719788 -> V=1.0, theta=0.0
% INFO    : Bus 17183	: V=0.9851294, theta=-37.780333 -> V=1.0, theta=0.0
% INFO    : Bus 17184	: V=1.0047851, theta=-36.078724 -> V=1.0, theta=0.0
% INFO    : Bus 17185	: V=0.985488, theta=-37.911738 -> V=1.0, theta=0.0
% INFO    : Bus 17186	: V=0.9869124, theta=-37.898318 -> V=1.0, theta=0.0
% INFO    : Bus 17187	: V=0.9938789, theta=-37.219126 -> V=1.0, theta=0.0
% INFO    : Bus 17188	: V=0.9926644, theta=-37.318619 -> V=1.0, theta=0.0
% INFO    : Bus 17189	: V=0.9938966, theta=-36.994666 -> V=1.0, theta=0.0
% INFO    : Bus 17190	: V=0.9857445, theta=-37.953161 -> V=1.0, theta=0.0
% INFO    : Bus 17191	: V=0.9844485, theta=-38.006759 -> V=1.0, theta=0.0
% INFO    : Bus 17192	: V=0.976059, theta=-38.901691 -> V=1.0, theta=0.0
% INFO    : Bus 17193	: V=0.9743592, theta=-39.081604 -> V=1.0, theta=0.0
% INFO    : Bus 17194	: V=0.9701482, theta=-39.382972 -> V=1.0, theta=0.0
% INFO    : Bus 17195	: V=0.969372, theta=-39.344444 -> V=1.0, theta=0.0
% INFO    : Bus 17196	: V=0.9820022, theta=-37.873179 -> V=1.0, theta=0.0
% INFO    : Bus 17197	: V=0.9909988, theta=-36.856547 -> V=1.0, theta=0.0
% INFO    : Bus 17198	: V=0.990558, theta=-36.655691 -> V=1.0, theta=0.0
% INFO    : Bus 17199	: V=0.9831271, theta=-38.0307 -> V=1.0, theta=0.0
% INFO    : Bus 17200	: V=0.9822718, theta=-38.03858 -> V=1.0, theta=0.0
% INFO    : Bus 17201	: V=0.9815714, theta=-38.035034 -> V=1.0, theta=0.0
% INFO    : Bus 17202	: V=0.9792157, theta=-38.344735 -> V=1.0, theta=0.0
% INFO    : Bus 17203	: V=0.9805224, theta=-38.034815 -> V=1.0, theta=0.0
% INFO    : Bus 17204	: V=0.9802447, theta=-38.010402 -> V=1.0, theta=0.0
% INFO    : Bus 17205	: V=0.9781588, theta=-38.435154 -> V=1.0, theta=0.0
% INFO    : Bus 17206	: V=0.976687, theta=-38.405514 -> V=1.0, theta=0.0
% INFO    : Bus 17207	: V=0.9858162, theta=-37.752951 -> V=1.0, theta=0.0
% INFO    : Bus 17208	: V=0.9760158, theta=-38.862172 -> V=1.0, theta=0.0
% INFO    : Bus 17209	: V=1.0047693, theta=-36.932915 -> V=1.0, theta=0.0
% INFO    : Bus 17210	: V=1.0040023, theta=-36.734023 -> V=1.0, theta=0.0
% INFO    : Bus 17211	: V=0.9917061, theta=-37.516637 -> V=1.0, theta=0.0
% INFO    : Bus 17212	: V=1.0050795, theta=-36.700028 -> V=1.0, theta=0.0
% INFO    : Bus 17213	: V=0.9923572, theta=-37.511285 -> V=1.0, theta=0.0
% INFO    : Bus 17214	: V=0.9893696, theta=-37.526892 -> V=1.0, theta=0.0
% INFO    : Bus 17215	: V=0.9946342, theta=-37.53507 -> V=1.0, theta=0.0
% INFO    : Bus 17216	: V=1.0009493, theta=-36.836596 -> V=1.0, theta=0.0
% INFO    : Bus 17217	: V=1.0180437, theta=-34.919622 -> V=1.0, theta=0.0
% INFO    : Bus 17218	: V=0.9952529, theta=-37.43492 -> V=1.0, theta=0.0
% INFO    : Bus 17219	: V=0.9955394, theta=-37.432064 -> V=1.0, theta=0.0
% INFO    : Bus 17220	: V=0.9973036, theta=-37.159494 -> V=1.0, theta=0.0
% INFO    : Bus 17221	: V=0.9948843, theta=-37.347791 -> V=1.0, theta=0.0
% INFO    : Bus 17222	: V=0.9968105, theta=-38.036976 -> V=1.0, theta=0.0
% INFO    : Bus 17223	: V=0.9909981, theta=-38.621791 -> V=1.0, theta=0.0
% INFO    : Bus 17224	: V=1.0019652, theta=-37.698075 -> V=1.0, theta=0.0
% INFO    : Bus 17225	: V=1.0002104, theta=-37.817685 -> V=1.0, theta=0.0
% INFO    : Bus 17226	: V=0.9984224, theta=-37.93415 -> V=1.0, theta=0.0
% INFO    : Bus 17227	: V=1.0174107, theta=-35.378603 -> V=1.0, theta=0.0
% INFO    : Bus 17228	: V=1.0038639, theta=-37.455326 -> V=1.0, theta=0.0
% INFO    : Bus 17229	: V=1.0012902, theta=-37.663082 -> V=1.0, theta=0.0
% INFO    : Bus 17230	: V=0.9964964, theta=-38.220844 -> V=1.0, theta=0.0
% INFO    : Bus 17231	: V=0.9903703, theta=-38.592377 -> V=1.0, theta=0.0
% INFO    : Bus 17232	: V=0.9934328, theta=-38.54794 -> V=1.0, theta=0.0
% INFO    : Bus 17233	: V=0.9940152, theta=-38.43474 -> V=1.0, theta=0.0
% INFO    : Bus 17234	: V=0.9920268, theta=-38.612987 -> V=1.0, theta=0.0
% INFO    : Bus 17235	: V=0.9900269, theta=-39.269357 -> V=1.0, theta=0.0
% INFO    : Bus 17236	: V=1.0053101, theta=-37.622163 -> V=1.0, theta=0.0
% INFO    : Bus 17237	: V=0.9911972, theta=-39.243014 -> V=1.0, theta=0.0
% INFO    : Bus 17238	: V=0.9936004, theta=-39.092036 -> V=1.0, theta=0.0
% INFO    : Bus 17239	: V=0.9937355, theta=-38.902742 -> V=1.0, theta=0.0
% INFO    : Bus 17240	: V=1.0087608, theta=-36.866816 -> V=1.0, theta=0.0
% INFO    : Bus 17241	: V=0.9944789, theta=-38.89289 -> V=1.0, theta=0.0
% INFO    : Bus 17242	: V=1.0030173, theta=-37.678457 -> V=1.0, theta=0.0
% INFO    : Bus 17243	: V=0.994507, theta=-38.789058 -> V=1.0, theta=0.0
% INFO    : Bus 17244	: V=0.9961908, theta=-38.406493 -> V=1.0, theta=0.0
% INFO    : Bus 17245	: V=0.991754, theta=-38.99256 -> V=1.0, theta=0.0
% INFO    : Bus 17246	: V=0.9962689, theta=-38.61594 -> V=1.0, theta=0.0
% INFO    : Bus 17247	: V=0.9939179, theta=-38.820873 -> V=1.0, theta=0.0
% INFO    : Bus 17248	: V=0.9950735, theta=-39.370842 -> V=1.0, theta=0.0
% INFO    : Bus 17249	: V=0.9933641, theta=-39.408885 -> V=1.0, theta=0.0
% INFO    : Bus 17250	: V=0.9916359, theta=-39.383753 -> V=1.0, theta=0.0
% INFO    : Bus 17251	: V=0.9969219, theta=-38.961298 -> V=1.0, theta=0.0
% INFO    : Bus 17252	: V=0.990927, theta=-39.23773 -> V=1.0, theta=0.0
% INFO    : Bus 17253	: V=0.9946983, theta=-38.004477 -> V=1.0, theta=0.0
% INFO    : Bus 17254	: V=1.0172973, theta=-34.975124 -> V=1.0, theta=0.0
% INFO    : Bus 17255	: V=0.9820564, theta=-39.054584 -> V=1.0, theta=0.0
% INFO    : Bus 17256	: V=0.9547009, theta=-47.399097 -> V=1.0, theta=0.0
% INFO    : Bus 17257	: V=0.9592287, theta=-47.259455 -> V=1.0, theta=0.0
% INFO    : Bus 17258	: V=0.9705256, theta=-46.469972 -> V=1.0, theta=0.0
% INFO    : Bus 17259	: V=0.9670031, theta=-46.752214 -> V=1.0, theta=0.0
% INFO    : Bus 17260	: V=0.9565969, theta=-43.502631 -> V=1.0, theta=0.0
% INFO    : Bus 17261	: V=0.9661481, theta=-42.814779 -> V=1.0, theta=0.0
% INFO    : Bus 17262	: V=0.9658012, theta=-42.914735 -> V=1.0, theta=0.0
% INFO    : Bus 17263	: V=1.0073245, theta=-40.486801 -> V=1.0, theta=0.0
% INFO    : Bus 17264	: V=0.9976685, theta=-41.02075 -> V=1.0, theta=0.0
% INFO    : Bus 17265	: V=0.9888714, theta=-40.262167 -> V=1.0, theta=0.0
% INFO    : Bus 17266	: V=0.9658789, theta=-41.949026 -> V=1.0, theta=0.0
% INFO    : Bus 17267	: V=0.9551903, theta=-43.143604 -> V=1.0, theta=0.0
% INFO    : Bus 17268	: V=0.9700181, theta=-41.454287 -> V=1.0, theta=0.0
% INFO    : Bus 17269	: V=0.9799718, theta=-40.73451 -> V=1.0, theta=0.0
% INFO    : Bus 17270	: V=0.9766338, theta=-40.90455 -> V=1.0, theta=0.0
% INFO    : Bus 17271	: V=0.9763665, theta=-40.881766 -> V=1.0, theta=0.0
% INFO    : Bus 17272	: V=0.9768723, theta=-40.297031 -> V=1.0, theta=0.0
% INFO    : Bus 17273	: V=0.9760256, theta=-40.147614 -> V=1.0, theta=0.0
% INFO    : Bus 17274	: V=0.9664027, theta=-41.308037 -> V=1.0, theta=0.0
% INFO    : Bus 17275	: V=0.9705268, theta=-40.846445 -> V=1.0, theta=0.0
% INFO    : Bus 17276	: V=0.9657619, theta=-41.262232 -> V=1.0, theta=0.0
% INFO    : Bus 17277	: V=0.9657436, theta=-41.037332 -> V=1.0, theta=0.0
% INFO    : Bus 17278	: V=0.9677728, theta=-41.014839 -> V=1.0, theta=0.0
% INFO    : Bus 17279	: V=0.9764659, theta=-39.906033 -> V=1.0, theta=0.0
% INFO    : Bus 17280	: V=0.9770564, theta=-39.705859 -> V=1.0, theta=0.0
% INFO    : Bus 17281	: V=0.9668482, theta=-40.891268 -> V=1.0, theta=0.0
% INFO    : Bus 17282	: V=0.9798764, theta=-39.191879 -> V=1.0, theta=0.0
% INFO    : Bus 17283	: V=0.9775275, theta=-39.400965 -> V=1.0, theta=0.0
% INFO    : Bus 17284	: V=0.9485247, theta=-45.84167 -> V=1.0, theta=0.0
% INFO    : Bus 17285	: V=0.9497339, theta=-45.758195 -> V=1.0, theta=0.0
% INFO    : Bus 17286	: V=0.9629394, theta=-44.169818 -> V=1.0, theta=0.0
% INFO    : Bus 17287	: V=0.9635954, theta=-44.125915 -> V=1.0, theta=0.0
% INFO    : Bus 17288	: V=0.957797, theta=-45.105155 -> V=1.0, theta=0.0
% INFO    : Bus 17289	: V=0.9524815, theta=-45.48953 -> V=1.0, theta=0.0
% INFO    : Bus 17290	: V=0.9594147, theta=-45.17917 -> V=1.0, theta=0.0
% INFO    : Bus 17291	: V=0.9595302, theta=-45.221486 -> V=1.0, theta=0.0
% INFO    : Bus 17292	: V=0.9778085, theta=-43.166239 -> V=1.0, theta=0.0
% INFO    : Bus 17293	: V=0.9697377, theta=-43.717614 -> V=1.0, theta=0.0
% INFO    : Bus 17294	: V=0.9734753, theta=-42.690904 -> V=1.0, theta=0.0
% INFO    : Bus 17295	: V=0.9616978, theta=-43.384477 -> V=1.0, theta=0.0
% INFO    : Bus 17296	: V=0.9619227, theta=-44.048259 -> V=1.0, theta=0.0
% INFO    : Bus 17297	: V=0.9609903, theta=-43.888963 -> V=1.0, theta=0.0
% INFO    : Bus 17298	: V=0.9529188, theta=-45.231053 -> V=1.0, theta=0.0
% INFO    : Bus 17299	: V=0.9584422, theta=-43.513826 -> V=1.0, theta=0.0
% INFO    : Bus 17300	: V=0.9492903, theta=-44.174037 -> V=1.0, theta=0.0
% INFO    : Bus 17301	: V=0.9623023, theta=-42.920916 -> V=1.0, theta=0.0
% INFO    : Bus 17302	: V=0.9942091, theta=-28.611063 -> V=1.0, theta=0.0
% INFO    : Bus 17303	: V=0.9929385, theta=-28.760128 -> V=1.0, theta=0.0
% INFO    : Bus 17304	: V=0.9943707, theta=-28.718288 -> V=1.0, theta=0.0
% INFO    : Bus 17305	: V=0.991072, theta=-28.825248 -> V=1.0, theta=0.0
% INFO    : Bus 17306	: V=0.9934259, theta=-28.767429 -> V=1.0, theta=0.0
% INFO    : Bus 17307	: V=0.9941651, theta=-28.684598 -> V=1.0, theta=0.0
% INFO    : Bus 17308	: V=0.9928611, theta=-28.67912 -> V=1.0, theta=0.0
% INFO    : Bus 17309	: V=1.0046244, theta=-27.343113 -> V=1.0, theta=0.0
% INFO    : Bus 17310	: V=1.0149273, theta=-25.48448 -> V=1.0, theta=0.0
% INFO    : Bus 17311	: V=0.9965262, theta=-28.444514 -> V=1.0, theta=0.0
% INFO    : Bus 17312	: V=0.9959736, theta=-28.507676 -> V=1.0, theta=0.0
% INFO    : Bus 17313	: V=0.9944423, theta=-28.611325 -> V=1.0, theta=0.0
% INFO    : Bus 17314	: V=0.9947455, theta=-28.606322 -> V=1.0, theta=0.0
% INFO    : Bus 17315	: V=1.0052124, theta=-27.361538 -> V=1.0, theta=0.0
% INFO    : Bus 17316	: V=1.0054319, theta=-27.431331 -> V=1.0, theta=0.0
% INFO    : Bus 17317	: V=1.0151438, theta=-26.257806 -> V=1.0, theta=0.0
% INFO    : Bus 17318	: V=0.9946794, theta=-29.238185 -> V=1.0, theta=0.0
% INFO    : Bus 17319	: V=0.9926916, theta=-28.860704 -> V=1.0, theta=0.0
% INFO    : Bus 17320	: V=0.9914014, theta=-29.022951 -> V=1.0, theta=0.0
% INFO    : Bus 17321	: V=0.9891676, theta=-29.319974 -> V=1.0, theta=0.0
% INFO    : Bus 17322	: V=0.9905501, theta=-30.107373 -> V=1.0, theta=0.0
% INFO    : Bus 17323	: V=0.990774, theta=-29.090171 -> V=1.0, theta=0.0
% INFO    : Bus 17324	: V=0.9895861, theta=-29.267379 -> V=1.0, theta=0.0
% INFO    : Bus 17325	: V=0.9882215, theta=-29.482229 -> V=1.0, theta=0.0
% INFO    : Bus 17326	: V=0.982649, theta=-28.850715 -> V=1.0, theta=0.0
% INFO    : Bus 17327	: V=0.9926356, theta=-28.807255 -> V=1.0, theta=0.0
% INFO    : Bus 17328	: V=0.9923411, theta=-28.871774 -> V=1.0, theta=0.0
% INFO    : Bus 17329	: V=0.9890887, theta=-29.344635 -> V=1.0, theta=0.0
% INFO    : Bus 17330	: V=0.9932443, theta=-28.723861 -> V=1.0, theta=0.0
% INFO    : Bus 17331	: V=0.9842865, theta=-28.831486 -> V=1.0, theta=0.0
% INFO    : Bus 17332	: V=0.9950078, theta=-28.474455 -> V=1.0, theta=0.0
% INFO    : Bus 17333	: V=0.9964485, theta=-28.379677 -> V=1.0, theta=0.0
% INFO    : Bus 17334	: V=0.9881469, theta=-28.523848 -> V=1.0, theta=0.0
% INFO    : Bus 17335	: V=0.9949033, theta=-28.535746 -> V=1.0, theta=0.0
% INFO    : Bus 17336	: V=0.9868033, theta=-28.671175 -> V=1.0, theta=0.0
% INFO    : Bus 17337	: V=0.9914979, theta=-28.376838 -> V=1.0, theta=0.0
% INFO    : Bus 17338	: V=0.9888377, theta=-28.428795 -> V=1.0, theta=0.0
% INFO    : Bus 17339	: V=0.9911469, theta=-28.193581 -> V=1.0, theta=0.0
% INFO    : Bus 17340	: V=1.0075272, theta=-26.391302 -> V=1.0, theta=0.0
% INFO    : Bus 17341	: V=1.0091689, theta=-25.945973 -> V=1.0, theta=0.0
% INFO    : Bus 17342	: V=1.0098373, theta=-25.772242 -> V=1.0, theta=0.0
% INFO    : Bus 17343	: V=1.012217, theta=-25.158976 -> V=1.0, theta=0.0
% INFO    : Bus 17344	: V=0.9869739, theta=-29.870916 -> V=1.0, theta=0.0
% INFO    : Bus 17345	: V=0.992563, theta=-29.310623 -> V=1.0, theta=0.0
% INFO    : Bus 17346	: V=1.0013603, theta=-41.038214 -> V=1.0, theta=0.0
% INFO    : Bus 17347	: V=0.9630424, theta=-44.163518 -> V=1.0, theta=0.0
% INFO    : Bus 17348	: V=1.0121218, theta=-39.318094 -> V=1.0, theta=0.0
% INFO    : Bus 17349	: V=1.0169529, theta=-38.906197 -> V=1.0, theta=0.0
% INFO    : Bus 17350	: V=1.0185903, theta=-38.719545 -> V=1.0, theta=0.0
% INFO    : Bus 17351	: V=0.9581377, theta=-36.991192 -> V=1.0, theta=0.0
% INFO    : Bus 17352	: V=0.9620439, theta=-37.4685 -> V=1.0, theta=0.0
% INFO    : Bus 17353	: V=0.9538006, theta=-38.836125 -> V=1.0, theta=0.0
% INFO    : Bus 17354	: V=0.9561624, theta=-38.146808 -> V=1.0, theta=0.0
% INFO    : Bus 17355	: V=0.9580914, theta=-37.053104 -> V=1.0, theta=0.0
% INFO    : Bus 17356	: V=0.9549266, theta=-36.84542 -> V=1.0, theta=0.0
% INFO    : Bus 17357	: V=0.9714418, theta=-34.130802 -> V=1.0, theta=0.0
% INFO    : Bus 17358	: V=0.9692585, theta=-34.67302 -> V=1.0, theta=0.0
% INFO    : Bus 17359	: V=0.971237, theta=-34.23373 -> V=1.0, theta=0.0
% INFO    : Bus 17360	: V=0.9649733, theta=-36.070354 -> V=1.0, theta=0.0
% INFO    : Bus 17361	: V=0.9664291, theta=-35.551211 -> V=1.0, theta=0.0
% INFO    : Bus 17362	: V=0.9762011, theta=-34.453014 -> V=1.0, theta=0.0
% INFO    : Bus 17363	: V=0.9645691, theta=-36.65983 -> V=1.0, theta=0.0
% INFO    : Bus 17364	: V=0.9567985, theta=-37.485719 -> V=1.0, theta=0.0
% INFO    : Bus 17365	: V=0.9500356, theta=-37.90682 -> V=1.0, theta=0.0
% INFO    : Bus 17366	: V=0.9483437, theta=-37.87162 -> V=1.0, theta=0.0
% INFO    : Bus 17367	: V=0.9493818, theta=-37.927008 -> V=1.0, theta=0.0
% INFO    : Bus 17368	: V=0.9582721, theta=-37.664427 -> V=1.0, theta=0.0
% INFO    : Bus 17369	: V=0.9611914, theta=-37.178451 -> V=1.0, theta=0.0
% INFO    : Bus 17370	: V=0.9529009, theta=-37.798576 -> V=1.0, theta=0.0
% INFO    : Bus 17371	: V=0.9532246, theta=-37.78092 -> V=1.0, theta=0.0
% INFO    : Bus 17372	: V=0.9536564, theta=-37.748498 -> V=1.0, theta=0.0
% INFO    : Bus 17373	: V=0.9535439, theta=-37.764607 -> V=1.0, theta=0.0
% INFO    : Bus 17374	: V=0.9623162, theta=-36.873373 -> V=1.0, theta=0.0
% INFO    : Bus 17375	: V=0.9589097, theta=-37.440783 -> V=1.0, theta=0.0
% INFO    : Bus 17376	: V=0.9636888, theta=-36.583504 -> V=1.0, theta=0.0
% INFO    : Bus 17377	: V=0.9592759, theta=-36.702859 -> V=1.0, theta=0.0
% INFO    : Bus 17378	: V=0.9614116, theta=-36.677864 -> V=1.0, theta=0.0
% INFO    : Bus 17379	: V=0.95799, theta=-37.079493 -> V=1.0, theta=0.0
% INFO    : Bus 17380	: V=0.9629793, theta=-36.401437 -> V=1.0, theta=0.0
% INFO    : Bus 17381	: V=0.9503805, theta=-37.500912 -> V=1.0, theta=0.0
% INFO    : Bus 17382	: V=0.9424483, theta=-45.032729 -> V=1.0, theta=0.0
% INFO    : Bus 17383	: V=0.9526334, theta=-44.428495 -> V=1.0, theta=0.0
% INFO    : Bus 17384	: V=0.9513022, theta=-44.363006 -> V=1.0, theta=0.0
% INFO    : Bus 17385	: V=0.9515599, theta=-44.522451 -> V=1.0, theta=0.0
% INFO    : Bus 17386	: V=0.9541512, theta=-44.244061 -> V=1.0, theta=0.0
% INFO    : Bus 17387	: V=0.9628956, theta=-43.6707 -> V=1.0, theta=0.0
% INFO    : Bus 17388	: V=0.9807212, theta=-41.092923 -> V=1.0, theta=0.0
% INFO    : Bus 17389	: V=0.9725719, theta=-41.866319 -> V=1.0, theta=0.0
% INFO    : Bus 17390	: V=0.9542339, theta=-43.476411 -> V=1.0, theta=0.0
% INFO    : Bus 17391	: V=0.9617445, theta=-43.272122 -> V=1.0, theta=0.0
% INFO    : Bus 17392	: V=0.9641313, theta=-43.136343 -> V=1.0, theta=0.0
% INFO    : Bus 17393	: V=0.952077, theta=-44.82963 -> V=1.0, theta=0.0
% INFO    : Bus 17394	: V=0.9252606, theta=-46.206592 -> V=1.0, theta=0.0
% INFO    : Bus 17395	: V=0.9324711, theta=-46.26682 -> V=1.0, theta=0.0
% INFO    : Bus 17396	: V=0.9598713, theta=-43.313127 -> V=1.0, theta=0.0
% INFO    : Bus 17397	: V=0.9594588, theta=-43.310687 -> V=1.0, theta=0.0
% INFO    : Bus 17398	: V=0.9539654, theta=-44.256085 -> V=1.0, theta=0.0
% INFO    : Bus 17399	: V=0.9587841, theta=-43.337951 -> V=1.0, theta=0.0
% INFO    : Bus 17400	: V=0.9541183, theta=-44.211813 -> V=1.0, theta=0.0
% INFO    : Bus 17401	: V=0.9540594, theta=-44.246877 -> V=1.0, theta=0.0
% INFO    : Bus 17402	: V=0.9543409, theta=-44.212895 -> V=1.0, theta=0.0
% INFO    : Bus 17403	: V=0.9554546, theta=-44.205281 -> V=1.0, theta=0.0
% INFO    : Bus 17404	: V=0.9586843, theta=-43.360074 -> V=1.0, theta=0.0
% INFO    : Bus 17405	: V=0.9589961, theta=-43.345051 -> V=1.0, theta=0.0
% INFO    : Bus 17406	: V=0.9545678, theta=-44.182254 -> V=1.0, theta=0.0
% INFO    : Bus 17407	: V=0.9595596, theta=-43.253563 -> V=1.0, theta=0.0
% INFO    : Bus 17408	: V=0.9527466, theta=-44.248618 -> V=1.0, theta=0.0
% INFO    : Bus 17409	: V=0.9545938, theta=-44.20557 -> V=1.0, theta=0.0
% INFO    : Bus 17410	: V=0.9612409, theta=-38.807927 -> V=1.0, theta=0.0
% INFO    : Bus 17411	: V=0.9635906, theta=-38.957987 -> V=1.0, theta=0.0
% INFO    : Bus 17412	: V=0.9672648, theta=-37.56601 -> V=1.0, theta=0.0
% INFO    : Bus 17413	: V=0.9649629, theta=-38.313285 -> V=1.0, theta=0.0
% INFO    : Bus 17414	: V=0.9639621, theta=-44.727654 -> V=1.0, theta=0.0
% INFO    : Bus 17415	: V=0.9657927, theta=-44.504451 -> V=1.0, theta=0.0
% INFO    : Bus 17416	: V=0.964868, theta=-44.616102 -> V=1.0, theta=0.0
% INFO    : Bus 17417	: V=0.9634534, theta=-44.791768 -> V=1.0, theta=0.0
% INFO    : Bus 17418	: V=0.9664443, theta=-44.392018 -> V=1.0, theta=0.0
% INFO    : Bus 17419	: V=0.96672, theta=-44.351929 -> V=1.0, theta=0.0
% INFO    : Bus 17420	: V=0.964817, theta=-44.330113 -> V=1.0, theta=0.0
% INFO    : Bus 17421	: V=0.9771992, theta=-42.793699 -> V=1.0, theta=0.0
% INFO    : Bus 17422	: V=0.9606099, theta=-44.605581 -> V=1.0, theta=0.0
% INFO    : Bus 17423	: V=0.985366, theta=-30.552673 -> V=1.0, theta=0.0
% INFO    : Bus 17424	: V=0.9750749, theta=-33.413923 -> V=1.0, theta=0.0
% INFO    : Bus 17425	: V=0.9762737, theta=-33.171503 -> V=1.0, theta=0.0
% INFO    : Bus 17426	: V=0.9795479, theta=-32.195094 -> V=1.0, theta=0.0
% INFO    : Bus 17427	: V=0.9845524, theta=-30.90726 -> V=1.0, theta=0.0
% INFO    : Bus 17428	: V=0.9788369, theta=-32.135897 -> V=1.0, theta=0.0
% INFO    : Bus 17429	: V=0.9735495, theta=-32.889286 -> V=1.0, theta=0.0
% INFO    : Bus 17430	: V=0.9725698, theta=-34.14276 -> V=1.0, theta=0.0
% INFO    : Bus 17431	: V=0.985872, theta=-31.878241 -> V=1.0, theta=0.0
% INFO    : Bus 17432	: V=0.9788586, theta=-32.965696 -> V=1.0, theta=0.0
% INFO    : Bus 17433	: V=0.9842112, theta=-32.259211 -> V=1.0, theta=0.0
% INFO    : Bus 17434	: V=0.967978, theta=-32.348839 -> V=1.0, theta=0.0
% INFO    : Bus 17435	: V=0.9962102, theta=-29.626614 -> V=1.0, theta=0.0
% INFO    : Bus 17436	: V=0.9876311, theta=-31.494593 -> V=1.0, theta=0.0
% INFO    : Bus 17437	: V=0.9912296, theta=-30.869178 -> V=1.0, theta=0.0
% INFO    : Bus 17438	: V=0.9617616, theta=-44.552785 -> V=1.0, theta=0.0
% INFO    : Bus 17439	: V=0.961054, theta=-44.369886 -> V=1.0, theta=0.0
% INFO    : Bus 17440	: V=0.944005, theta=-46.207939 -> V=1.0, theta=0.0
% INFO    : Bus 17441	: V=1.0130076, theta=-37.869287 -> V=1.0, theta=0.0
% INFO    : Bus 17442	: V=1.0169524, theta=-37.593269 -> V=1.0, theta=0.0
% INFO    : Bus 17443	: V=1.0094079, theta=-38.190903 -> V=1.0, theta=0.0
% INFO    : Bus 17444	: V=1.0011183, theta=-38.8689 -> V=1.0, theta=0.0
% INFO    : Bus 17445	: V=1.0043035, theta=-38.688087 -> V=1.0, theta=0.0
% INFO    : Bus 17446	: V=0.9977853, theta=-39.559792 -> V=1.0, theta=0.0
% INFO    : Bus 17447	: V=0.9837004, theta=-42.203509 -> V=1.0, theta=0.0
% INFO    : Bus 17448	: V=0.9428302, theta=-45.121293 -> V=1.0, theta=0.0
% INFO    : Bus 17449	: V=0.9380918, theta=-46.128384 -> V=1.0, theta=0.0
% INFO    : Bus 17450	: V=0.9376681, theta=-46.190023 -> V=1.0, theta=0.0
% INFO    : Bus 17451	: V=0.9358465, theta=-46.48125 -> V=1.0, theta=0.0
% INFO    : Bus 17452	: V=0.936822, theta=-46.365938 -> V=1.0, theta=0.0
% INFO    : Bus 17453	: V=0.9374236, theta=-46.247774 -> V=1.0, theta=0.0
% INFO    : Bus 17454	: V=0.9374046, theta=-46.324543 -> V=1.0, theta=0.0
% INFO    : Bus 17455	: V=0.936438, theta=-46.454425 -> V=1.0, theta=0.0
% INFO    : Bus 17456	: V=0.944335, theta=-44.908694 -> V=1.0, theta=0.0
% INFO    : Bus 17457	: V=0.9404729, theta=-45.532432 -> V=1.0, theta=0.0
% INFO    : Bus 17458	: V=0.9384027, theta=-45.345356 -> V=1.0, theta=0.0
% INFO    : Bus 17459	: V=0.9436112, theta=-45.043396 -> V=1.0, theta=0.0
% INFO    : Bus 17460	: V=0.9401488, theta=-45.70277 -> V=1.0, theta=0.0
% INFO    : Bus 17461	: V=0.9359382, theta=-46.481933 -> V=1.0, theta=0.0
% INFO    : Bus 17462	: V=0.9502481, theta=-44.123967 -> V=1.0, theta=0.0
% INFO    : Bus 17463	: V=0.9420023, theta=-45.49738 -> V=1.0, theta=0.0
% INFO    : Bus 17464	: V=0.9430699, theta=-45.465332 -> V=1.0, theta=0.0
% INFO    : Bus 17465	: V=0.9433626, theta=-45.132175 -> V=1.0, theta=0.0
% INFO    : Bus 17466	: V=0.9479774, theta=-44.650046 -> V=1.0, theta=0.0
% INFO    : Bus 17467	: V=0.9578253, theta=-41.607143 -> V=1.0, theta=0.0
% INFO    : Bus 17468	: V=0.9398225, theta=-44.912112 -> V=1.0, theta=0.0
% INFO    : Bus 17469	: V=0.9422153, theta=-44.812999 -> V=1.0, theta=0.0
% INFO    : Bus 17470	: V=0.9509742, theta=-42.555346 -> V=1.0, theta=0.0
% INFO    : Bus 17471	: V=0.9389864, theta=-44.034611 -> V=1.0, theta=0.0
% INFO    : Bus 17472	: V=0.9460451, theta=-43.609829 -> V=1.0, theta=0.0
% INFO    : Bus 17473	: V=0.936541, theta=-42.523077 -> V=1.0, theta=0.0
% INFO    : Bus 17474	: V=0.9354428, theta=-45.473616 -> V=1.0, theta=0.0
% INFO    : Bus 17475	: V=0.9472549, theta=-44.562233 -> V=1.0, theta=0.0
% INFO    : Bus 17476	: V=0.9508057, theta=-43.643965 -> V=1.0, theta=0.0
% INFO    : Bus 17477	: V=0.9488859, theta=-44.659179 -> V=1.0, theta=0.0
% INFO    : Bus 17478	: V=0.9443991, theta=-45.852935 -> V=1.0, theta=0.0
% INFO    : Bus 17479	: V=0.9463378, theta=-44.857254 -> V=1.0, theta=0.0
% INFO    : Bus 17480	: V=0.9843872, theta=-42.395685 -> V=1.0, theta=0.0
% INFO    : Bus 17481	: V=0.9793634, theta=-43.199418 -> V=1.0, theta=0.0
% INFO    : Bus 17482	: V=0.9744598, theta=-43.842635 -> V=1.0, theta=0.0
% INFO    : Bus 17483	: V=0.9722491, theta=-44.587931 -> V=1.0, theta=0.0
% INFO    : Bus 17484	: V=0.9712631, theta=-44.312516 -> V=1.0, theta=0.0
% INFO    : Bus 17485	: V=0.9608149, theta=-46.479862 -> V=1.0, theta=0.0
% INFO    : Bus 17486	: V=0.9674648, theta=-44.890631 -> V=1.0, theta=0.0
% INFO    : Bus 17487	: V=0.9477275, theta=-45.964515 -> V=1.0, theta=0.0
% INFO    : Bus 17488	: V=0.9486981, theta=-45.760564 -> V=1.0, theta=0.0
% INFO    : Bus 17489	: V=0.9476336, theta=-46.010086 -> V=1.0, theta=0.0
% INFO    : Bus 17490	: V=0.9432546, theta=-47.283932 -> V=1.0, theta=0.0
% INFO    : Bus 17491	: V=0.9445051, theta=-47.157095 -> V=1.0, theta=0.0
% INFO    : Bus 17492	: V=0.9448329, theta=-46.852309 -> V=1.0, theta=0.0
% INFO    : Bus 17493	: V=0.9409528, theta=-47.213509 -> V=1.0, theta=0.0
% INFO    : Bus 17494	: V=0.951428, theta=-46.291522 -> V=1.0, theta=0.0
% INFO    : Bus 17495	: V=0.9642441, theta=-44.798045 -> V=1.0, theta=0.0
% INFO    : Bus 17496	: V=0.9492648, theta=-46.352143 -> V=1.0, theta=0.0
% INFO    : Bus 17497	: V=0.9618551, theta=-44.931814 -> V=1.0, theta=0.0
% INFO    : Bus 17498	: V=0.9549696, theta=-44.98135 -> V=1.0, theta=0.0
% INFO    : Bus 17499	: V=0.9527021, theta=-45.005186 -> V=1.0, theta=0.0
% INFO    : Bus 17500	: V=0.9685495, theta=-43.462352 -> V=1.0, theta=0.0
% INFO    : Bus 17501	: V=0.9372909, theta=-48.244534 -> V=1.0, theta=0.0
% INFO    : Bus 17502	: V=0.9364233, theta=-48.371689 -> V=1.0, theta=0.0
% INFO    : Bus 17503	: V=0.9403195, theta=-48.073462 -> V=1.0, theta=0.0
% INFO    : Bus 17504	: V=0.9358224, theta=-49.016794 -> V=1.0, theta=0.0
% INFO    : Bus 17505	: V=0.9367129, theta=-49.073779 -> V=1.0, theta=0.0
% INFO    : Bus 17506	: V=0.9341137, theta=-48.635223 -> V=1.0, theta=0.0
% INFO    : Bus 17507	: V=0.9438956, theta=-47.841276 -> V=1.0, theta=0.0
% INFO    : Bus 17508	: V=0.9440867, theta=-47.34527 -> V=1.0, theta=0.0
% INFO    : Bus 17509	: V=0.9458585, theta=-48.195652 -> V=1.0, theta=0.0
% INFO    : Bus 17510	: V=0.9449794, theta=-48.365112 -> V=1.0, theta=0.0
% INFO    : Bus 17511	: V=0.9415544, theta=-48.709309 -> V=1.0, theta=0.0
% INFO    : Bus 17512	: V=0.9386182, theta=-48.932126 -> V=1.0, theta=0.0
% INFO    : Bus 17513	: V=0.9650609, theta=-45.743461 -> V=1.0, theta=0.0
% INFO    : Bus 17514	: V=0.9584562, theta=-46.427326 -> V=1.0, theta=0.0
% INFO    : Bus 17515	: V=0.985942, theta=-38.454374 -> V=1.0, theta=0.0
% INFO    : Bus 17516	: V=1.0126099, theta=-38.53616 -> V=1.0, theta=0.0
% INFO    : Bus 17517	: V=1.0163781, theta=-36.279289 -> V=1.0, theta=0.0
% INFO    : Bus 17518	: V=0.9966538, theta=-36.077814 -> V=1.0, theta=0.0
% INFO    : Bus 17519	: V=1.0133502, theta=-36.068641 -> V=1.0, theta=0.0
% INFO    : Bus 17520	: V=1.0093786, theta=-35.977111 -> V=1.0, theta=0.0
% INFO    : Bus 17521	: V=1.0115762, theta=-35.920325 -> V=1.0, theta=0.0
% INFO    : Bus 17522	: V=1.0119687, theta=-34.81295 -> V=1.0, theta=0.0
% INFO    : Bus 17523	: V=1.0186169, theta=-34.028799 -> V=1.0, theta=0.0
% INFO    : Bus 17524	: V=1.0061668, theta=-36.093132 -> V=1.0, theta=0.0
% INFO    : Bus 17525	: V=1.0076117, theta=-35.841819 -> V=1.0, theta=0.0
% INFO    : Bus 17526	: V=0.9601489, theta=-39.401424 -> V=1.0, theta=0.0
% INFO    : Bus 17527	: V=0.972654, theta=-38.515878 -> V=1.0, theta=0.0
% INFO    : Bus 17528	: V=0.9718848, theta=-38.842024 -> V=1.0, theta=0.0
% INFO    : Bus 17529	: V=0.9745822, theta=-38.430749 -> V=1.0, theta=0.0
% INFO    : Bus 17530	: V=0.9782231, theta=-37.898857 -> V=1.0, theta=0.0
% INFO    : Bus 17531	: V=0.9846372, theta=-37.053566 -> V=1.0, theta=0.0
% INFO    : Bus 17532	: V=0.9793914, theta=-37.4764 -> V=1.0, theta=0.0
% INFO    : Bus 17533	: V=0.989497, theta=-35.869582 -> V=1.0, theta=0.0
% INFO    : Bus 17534	: V=0.9889376, theta=-35.887811 -> V=1.0, theta=0.0
% INFO    : Bus 17535	: V=0.9868303, theta=-36.735773 -> V=1.0, theta=0.0
% INFO    : Bus 17536	: V=0.9899985, theta=-35.669698 -> V=1.0, theta=0.0
% INFO    : Bus 17537	: V=0.9802555, theta=-37.40061 -> V=1.0, theta=0.0
% INFO    : Bus 17538	: V=0.9887165, theta=-36.892032 -> V=1.0, theta=0.0
% INFO    : Bus 17539	: V=0.9912834, theta=-36.530525 -> V=1.0, theta=0.0
% INFO    : Bus 17540	: V=1.0082909, theta=-35.712644 -> V=1.0, theta=0.0
% INFO    : Bus 17541	: V=0.9951452, theta=-36.625651 -> V=1.0, theta=0.0
% INFO    : Bus 17542	: V=1.0125201, theta=-35.228216 -> V=1.0, theta=0.0
% INFO    : Bus 17543	: V=1.0078273, theta=-35.681828 -> V=1.0, theta=0.0
% INFO    : Bus 17544	: V=0.996611, theta=-36.526937 -> V=1.0, theta=0.0
% INFO    : Bus 17545	: V=1.0075264, theta=-35.76895 -> V=1.0, theta=0.0
% INFO    : Bus 17546	: V=1.0104433, theta=-35.442363 -> V=1.0, theta=0.0
% INFO    : Bus 17547	: V=1.0034347, theta=-36.271984 -> V=1.0, theta=0.0
% INFO    : Bus 17548	: V=1.0148697, theta=-34.800841 -> V=1.0, theta=0.0
% INFO    : Bus 17549	: V=0.9976321, theta=-35.809366 -> V=1.0, theta=0.0
% INFO    : Bus 17550	: V=0.9837274, theta=-34.955188 -> V=1.0, theta=0.0
% INFO    : Bus 17551	: V=0.9939072, theta=-34.352972 -> V=1.0, theta=0.0
% INFO    : Bus 17552	: V=0.9985284, theta=-33.802016 -> V=1.0, theta=0.0
% INFO    : Bus 17553	: V=0.9829454, theta=-36.948438 -> V=1.0, theta=0.0
% INFO    : Bus 17554	: V=0.9840713, theta=-35.197429 -> V=1.0, theta=0.0
% INFO    : Bus 17555	: V=0.9926069, theta=-35.742563 -> V=1.0, theta=0.0
% INFO    : Bus 17556	: V=0.9868596, theta=-36.0864 -> V=1.0, theta=0.0
% INFO    : Bus 17557	: V=0.9873327, theta=-43.432677 -> V=1.0, theta=0.0
% INFO    : Bus 17558	: V=0.98954, theta=-42.469191 -> V=1.0, theta=0.0
% INFO    : Bus 17559	: V=0.9883779, theta=-43.678062 -> V=1.0, theta=0.0
% INFO    : Bus 17560	: V=0.9932226, theta=-43.4917 -> V=1.0, theta=0.0
% INFO    : Bus 17561	: V=0.9908621, theta=-43.577274 -> V=1.0, theta=0.0
% INFO    : Bus 17562	: V=0.9921212, theta=-43.102781 -> V=1.0, theta=0.0
% INFO    : Bus 17563	: V=0.9900573, theta=-43.665211 -> V=1.0, theta=0.0
% INFO    : Bus 17564	: V=1.0000699, theta=-42.633722 -> V=1.0, theta=0.0
% INFO    : Bus 17565	: V=0.9864506, theta=-44.241721 -> V=1.0, theta=0.0
% INFO    : Bus 17566	: V=0.9891669, theta=-44.435166 -> V=1.0, theta=0.0
% INFO    : Bus 17567	: V=1.0060699, theta=-42.361759 -> V=1.0, theta=0.0
% INFO    : Bus 17568	: V=1.0015386, theta=-42.614716 -> V=1.0, theta=0.0
% INFO    : Bus 17569	: V=0.9975572, theta=-42.984697 -> V=1.0, theta=0.0
% INFO    : Bus 17570	: V=1.0041372, theta=-42.446837 -> V=1.0, theta=0.0
% INFO    : Bus 17571	: V=0.9943719, theta=-43.128132 -> V=1.0, theta=0.0
% INFO    : Bus 17572	: V=0.9970604, theta=-42.507843 -> V=1.0, theta=0.0
% INFO    : Bus 17573	: V=0.9981383, theta=-41.830188 -> V=1.0, theta=0.0
% INFO    : Bus 17574	: V=1.0012912, theta=-41.891744 -> V=1.0, theta=0.0
% INFO    : Bus 17575	: V=0.9915283, theta=-42.855635 -> V=1.0, theta=0.0
% INFO    : Bus 17576	: V=0.9982083, theta=-42.90826 -> V=1.0, theta=0.0
% INFO    : Bus 17577	: V=0.9960758, theta=-43.269235 -> V=1.0, theta=0.0
% INFO    : Bus 17578	: V=1.0061599, theta=-39.832969 -> V=1.0, theta=0.0
% INFO    : Bus 17579	: V=1.0063461, theta=-39.767439 -> V=1.0, theta=0.0
% INFO    : Bus 17580	: V=0.9900733, theta=-41.51145 -> V=1.0, theta=0.0
% INFO    : Bus 17581	: V=1.0022229, theta=-40.423627 -> V=1.0, theta=0.0
% INFO    : Bus 17582	: V=1.0023957, theta=-40.451586 -> V=1.0, theta=0.0
% INFO    : Bus 17583	: V=0.9984075, theta=-40.906279 -> V=1.0, theta=0.0
% INFO    : Bus 17584	: V=1.0062792, theta=-39.886364 -> V=1.0, theta=0.0
% INFO    : Bus 17585	: V=0.9992524, theta=-40.828671 -> V=1.0, theta=0.0
% INFO    : Bus 17586	: V=0.9949524, theta=-40.961484 -> V=1.0, theta=0.0
% INFO    : Bus 17587	: V=0.9951008, theta=-40.992393 -> V=1.0, theta=0.0
% INFO    : Bus 17588	: V=0.978943, theta=-41.954329 -> V=1.0, theta=0.0
% INFO    : Bus 17589	: V=0.995078, theta=-40.787719 -> V=1.0, theta=0.0
% INFO    : Bus 17590	: V=0.9831804, theta=-41.482465 -> V=1.0, theta=0.0
% INFO    : Bus 17591	: V=1.0037835, theta=-39.754956 -> V=1.0, theta=0.0
% INFO    : Bus 17592	: V=1.0114363, theta=-39.428408 -> V=1.0, theta=0.0
% INFO    : Bus 17593	: V=1.0043692, theta=-40.353382 -> V=1.0, theta=0.0
% INFO    : Bus 17594	: V=1.0021834, theta=-40.324245 -> V=1.0, theta=0.0
% INFO    : Bus 17595	: V=1.0080702, theta=-40.033604 -> V=1.0, theta=0.0
% INFO    : Bus 17596	: V=0.9953523, theta=-41.211771 -> V=1.0, theta=0.0
% INFO    : Bus 17597	: V=1.0046517, theta=-40.281936 -> V=1.0, theta=0.0
% INFO    : Bus 17598	: V=1.0004318, theta=-39.6169 -> V=1.0, theta=0.0
% INFO    : Bus 17599	: V=0.983771, theta=-41.049359 -> V=1.0, theta=0.0
% INFO    : Bus 17600	: V=0.9839253, theta=-40.951008 -> V=1.0, theta=0.0
% INFO    : Bus 17601	: V=0.9855924, theta=-41.070356 -> V=1.0, theta=0.0
% INFO    : Bus 17602	: V=0.9910705, theta=-40.917687 -> V=1.0, theta=0.0
% INFO    : Bus 17603	: V=0.9829435, theta=-41.010682 -> V=1.0, theta=0.0
% INFO    : Bus 17604	: V=0.9846181, theta=-40.956655 -> V=1.0, theta=0.0
% INFO    : Bus 17605	: V=0.9902455, theta=-40.67309 -> V=1.0, theta=0.0
% INFO    : Bus 17606	: V=1.0163845, theta=-39.166428 -> V=1.0, theta=0.0
% INFO    : Bus 17607	: V=0.9925088, theta=-41.469242 -> V=1.0, theta=0.0
% INFO    : Bus 17608	: V=0.9660641, theta=-42.627638 -> V=1.0, theta=0.0
% INFO    : Bus 17609	: V=0.9832149, theta=-43.342682 -> V=1.0, theta=0.0
% INFO    : Bus 17610	: V=0.9725601, theta=-44.820021 -> V=1.0, theta=0.0
% INFO    : Bus 17611	: V=0.9947943, theta=-41.305747 -> V=1.0, theta=0.0
% INFO    : Bus 17612	: V=1.0107403, theta=-38.701895 -> V=1.0, theta=0.0
% INFO    : Bus 17613	: V=0.9912437, theta=-41.199113 -> V=1.0, theta=0.0
% INFO    : Bus 17614	: V=0.9818468, theta=-41.609847 -> V=1.0, theta=0.0
% INFO    : Bus 17615	: V=0.9871684, theta=-41.252116 -> V=1.0, theta=0.0
% INFO    : Bus 17616	: V=1.0007056, theta=-39.740473 -> V=1.0, theta=0.0
% INFO    : Bus 17617	: V=0.990776, theta=-40.700842 -> V=1.0, theta=0.0
% INFO    : Bus 17618	: V=1.0089964, theta=-38.876522 -> V=1.0, theta=0.0
% INFO    : Bus 17619	: V=1.0012544, theta=-39.767549 -> V=1.0, theta=0.0
% INFO    : Bus 17620	: V=0.9970777, theta=-40.740718 -> V=1.0, theta=0.0
% INFO    : Bus 17621	: V=0.9729777, theta=-37.879732 -> V=1.0, theta=0.0
% INFO    : Bus 17622	: V=0.9758298, theta=-38.84209 -> V=1.0, theta=0.0
% INFO    : Bus 17623	: V=0.9719978, theta=-39.590554 -> V=1.0, theta=0.0
% INFO    : Bus 17624	: V=0.9703747, theta=-39.482438 -> V=1.0, theta=0.0
% INFO    : Bus 17625	: V=0.970642, theta=-38.990415 -> V=1.0, theta=0.0
% INFO    : Bus 17626	: V=0.9658878, theta=-39.184764 -> V=1.0, theta=0.0
% INFO    : Bus 17627	: V=0.9664286, theta=-38.694627 -> V=1.0, theta=0.0
% INFO    : Bus 17628	: V=0.9701482, theta=-38.114876 -> V=1.0, theta=0.0
% INFO    : Bus 17629	: V=0.9561803, theta=-38.284084 -> V=1.0, theta=0.0
% INFO    : Bus 17630	: V=0.9486619, theta=-36.872831 -> V=1.0, theta=0.0
% INFO    : Bus 17631	: V=0.9617633, theta=-36.644748 -> V=1.0, theta=0.0
% INFO    : Bus 17632	: V=0.9946502, theta=-36.050592 -> V=1.0, theta=0.0
% INFO    : Bus 17633	: V=0.9998943, theta=-35.798096 -> V=1.0, theta=0.0
% INFO    : Bus 17634	: V=1.001288, theta=-35.503534 -> V=1.0, theta=0.0
% INFO    : Bus 17635	: V=1.0057706, theta=-34.482618 -> V=1.0, theta=0.0
% INFO    : Bus 17636	: V=1.0177415, theta=-33.815137 -> V=1.0, theta=0.0
% INFO    : Bus 17637	: V=1.0020163, theta=-35.870578 -> V=1.0, theta=0.0
% INFO    : Bus 17638	: V=0.9881124, theta=-37.123608 -> V=1.0, theta=0.0
% INFO    : Bus 17639	: V=0.9589412, theta=-43.171303 -> V=1.0, theta=0.0
% INFO    : Bus 17640	: V=0.993753, theta=-40.648323 -> V=1.0, theta=0.0
% INFO    : Bus 17641	: V=0.9621235, theta=-43.260749 -> V=1.0, theta=0.0
% INFO    : Bus 17642	: V=0.9638503, theta=-43.009161 -> V=1.0, theta=0.0
% INFO    : Bus 17643	: V=0.9643332, theta=-42.273184 -> V=1.0, theta=0.0
% INFO    : Bus 17644	: V=0.965009, theta=-41.87672 -> V=1.0, theta=0.0
% INFO    : Bus 17645	: V=0.9614902, theta=-41.875868 -> V=1.0, theta=0.0
% INFO    : Bus 17646	: V=0.9690203, theta=-40.875101 -> V=1.0, theta=0.0
% INFO    : Bus 17647	: V=0.9670354, theta=-41.361084 -> V=1.0, theta=0.0
% INFO    : Bus 17648	: V=0.9908202, theta=-41.709757 -> V=1.0, theta=0.0
% INFO    : Bus 17649	: V=0.9973896, theta=-41.114672 -> V=1.0, theta=0.0
% INFO    : Bus 17650	: V=0.964113, theta=-42.354703 -> V=1.0, theta=0.0
% INFO    : Bus 17651	: V=0.9647592, theta=-42.130594 -> V=1.0, theta=0.0
% INFO    : Bus 17652	: V=0.9795021, theta=-45.846069 -> V=1.0, theta=0.0
% INFO    : Bus 17653	: V=0.9645693, theta=-47.58069 -> V=1.0, theta=0.0
% INFO    : Bus 17654	: V=0.9498962, theta=-48.957665 -> V=1.0, theta=0.0
% INFO    : Bus 17655	: V=0.950728, theta=-49.759786 -> V=1.0, theta=0.0
% INFO    : Bus 17656	: V=0.9522524, theta=-48.257247 -> V=1.0, theta=0.0
% INFO    : Bus 17657	: V=0.9520001, theta=-49.493552 -> V=1.0, theta=0.0
% INFO    : Bus 17658	: V=0.953939, theta=-48.190689 -> V=1.0, theta=0.0
% INFO    : Bus 17659	: V=0.962388, theta=-47.322449 -> V=1.0, theta=0.0
% INFO    : Bus 17660	: V=0.995762, theta=-43.054693 -> V=1.0, theta=0.0
% INFO    : Bus 17661	: V=0.9536809, theta=-50.325645 -> V=1.0, theta=0.0
% INFO    : Bus 17662	: V=0.9496276, theta=-50.320341 -> V=1.0, theta=0.0
% INFO    : Bus 17663	: V=0.9538438, theta=-50.338962 -> V=1.0, theta=0.0
% INFO    : Bus 17664	: V=0.9511392, theta=-50.407585 -> V=1.0, theta=0.0
% INFO    : Bus 17665	: V=0.9430185, theta=-51.892109 -> V=1.0, theta=0.0
% INFO    : Bus 17666	: V=0.9542952, theta=-50.309235 -> V=1.0, theta=0.0
% INFO    : Bus 17667	: V=0.9465042, theta=-51.741382 -> V=1.0, theta=0.0
% INFO    : Bus 17668	: V=0.946217, theta=-51.715691 -> V=1.0, theta=0.0
% INFO    : Bus 17669	: V=0.954738, theta=-50.298754 -> V=1.0, theta=0.0
% INFO    : Bus 17670	: V=0.9515772, theta=-50.544059 -> V=1.0, theta=0.0
% INFO    : Bus 17671	: V=0.9585534, theta=-49.962074 -> V=1.0, theta=0.0
% INFO    : Bus 17672	: V=0.9655543, theta=-48.819186 -> V=1.0, theta=0.0
% INFO    : Bus 17673	: V=0.960458, theta=-49.145141 -> V=1.0, theta=0.0
% INFO    : Bus 17674	: V=0.9528901, theta=-48.819692 -> V=1.0, theta=0.0
% INFO    : Bus 17675	: V=0.9446487, theta=-50.852403 -> V=1.0, theta=0.0
% INFO    : Bus 17676	: V=0.9442254, theta=-51.652277 -> V=1.0, theta=0.0
% INFO    : Bus 17677	: V=0.9423922, theta=-51.753167 -> V=1.0, theta=0.0
% INFO    : Bus 17678	: V=0.9425644, theta=-51.435621 -> V=1.0, theta=0.0
% INFO    : Bus 17679	: V=0.9436018, theta=-51.597997 -> V=1.0, theta=0.0
% INFO    : Bus 17680	: V=0.9343115, theta=-50.22284 -> V=1.0, theta=0.0
% INFO    : Bus 17681	: V=0.9469752, theta=-49.268017 -> V=1.0, theta=0.0
% INFO    : Bus 17682	: V=0.9496988, theta=-50.026171 -> V=1.0, theta=0.0
% INFO    : Bus 17683	: V=1.0065455, theta=-38.959913 -> V=1.0, theta=0.0
% INFO    : Bus 17684	: V=0.9996655, theta=-40.172664 -> V=1.0, theta=0.0
% INFO    : Bus 17685	: V=0.9873976, theta=-40.672924 -> V=1.0, theta=0.0
% INFO    : Bus 17686	: V=1.0010422, theta=-39.914267 -> V=1.0, theta=0.0
% INFO    : Bus 17687	: V=0.9498248, theta=-48.747497 -> V=1.0, theta=0.0
% INFO    : Bus 17688	: V=0.9518244, theta=-47.849563 -> V=1.0, theta=0.0
% INFO    : Bus 17689	: V=0.9555676, theta=-45.841575 -> V=1.0, theta=0.0
% INFO    : Bus 17690	: V=0.9479603, theta=-48.358798 -> V=1.0, theta=0.0
% INFO    : Bus 17691	: V=0.9473354, theta=-48.237928 -> V=1.0, theta=0.0
% INFO    : Bus 17692	: V=0.957425, theta=-46.555209 -> V=1.0, theta=0.0
% INFO    : Bus 17693	: V=0.9601494, theta=-46.228336 -> V=1.0, theta=0.0
% INFO    : Bus 17694	: V=0.9516512, theta=-44.982321 -> V=1.0, theta=0.0
% INFO    : Bus 17695	: V=0.982502, theta=-39.196567 -> V=1.0, theta=0.0
% INFO    : Bus 17696	: V=0.9826807, theta=-38.159106 -> V=1.0, theta=0.0
% INFO    : Bus 17697	: V=0.97128, theta=-40.346802 -> V=1.0, theta=0.0
% INFO    : Bus 17698	: V=0.9718263, theta=-40.342054 -> V=1.0, theta=0.0
% INFO    : Bus 17699	: V=0.9767822, theta=-38.326575 -> V=1.0, theta=0.0
% INFO    : Bus 17700	: V=0.9864243, theta=-37.522423 -> V=1.0, theta=0.0
% INFO    : Bus 17701	: V=0.9931365, theta=-36.495685 -> V=1.0, theta=0.0
% INFO    : Bus 17702	: V=0.9794174, theta=-38.155109 -> V=1.0, theta=0.0
% INFO    : Bus 17703	: V=0.9712718, theta=-40.243255 -> V=1.0, theta=0.0
% INFO    : Bus 17704	: V=0.9713318, theta=-40.209332 -> V=1.0, theta=0.0
% INFO    : Bus 17705	: V=0.9721597, theta=-39.454849 -> V=1.0, theta=0.0
% INFO    : Bus 17706	: V=0.9839642, theta=-37.693369 -> V=1.0, theta=0.0
% INFO    : Bus 17707	: V=0.9731007, theta=-39.24138 -> V=1.0, theta=0.0
% INFO    : Bus 17708	: V=0.9700684, theta=-39.144658 -> V=1.0, theta=0.0
% INFO    : Bus 17709	: V=0.9718186, theta=-38.940469 -> V=1.0, theta=0.0
% INFO    : Bus 17710	: V=0.9847627, theta=-37.61603 -> V=1.0, theta=0.0
% INFO    : Bus 17711	: V=0.9757055, theta=-38.458767 -> V=1.0, theta=0.0
% INFO    : Bus 17712	: V=0.9753995, theta=-38.49015 -> V=1.0, theta=0.0
% INFO    : Bus 17713	: V=0.9761596, theta=-38.359906 -> V=1.0, theta=0.0
% INFO    : Bus 17714	: V=0.9893599, theta=-37.149498 -> V=1.0, theta=0.0
% INFO    : Bus 17715	: V=0.9767106, theta=-38.172306 -> V=1.0, theta=0.0
% INFO    : Bus 17716	: V=0.9810328, theta=-37.909064 -> V=1.0, theta=0.0
% INFO    : Bus 17717	: V=1.0142757, theta=-34.938489 -> V=1.0, theta=0.0
% INFO    : Bus 17718	: V=0.9869828, theta=-37.729068 -> V=1.0, theta=0.0
% INFO    : Bus 17719	: V=0.9922321, theta=-37.255822 -> V=1.0, theta=0.0
% INFO    : Bus 17720	: V=0.9837994, theta=-38.211273 -> V=1.0, theta=0.0
% INFO    : Bus 17721	: V=0.9898138, theta=-37.849873 -> V=1.0, theta=0.0
% INFO    : Bus 17722	: V=0.9807687, theta=-38.375789 -> V=1.0, theta=0.0
% INFO    : Bus 17723	: V=0.9856255, theta=-37.222551 -> V=1.0, theta=0.0
% INFO    : Bus 17724	: V=0.9745685, theta=-38.367496 -> V=1.0, theta=0.0
% INFO    : Bus 17725	: V=0.9818445, theta=-37.651594 -> V=1.0, theta=0.0
% INFO    : Bus 17726	: V=0.9762987, theta=-38.35568 -> V=1.0, theta=0.0
% INFO    : Bus 17727	: V=0.9775181, theta=-38.166399 -> V=1.0, theta=0.0
% INFO    : Bus 17728	: V=0.9783138, theta=-37.979443 -> V=1.0, theta=0.0
% INFO    : Bus 17729	: V=0.9752887, theta=-38.293811 -> V=1.0, theta=0.0
% INFO    : Bus 17730	: V=0.9758911, theta=-38.49142 -> V=1.0, theta=0.0
% INFO    : Bus 17731	: V=0.9722206, theta=-38.587817 -> V=1.0, theta=0.0
% INFO    : Bus 17732	: V=0.9724248, theta=-38.39032 -> V=1.0, theta=0.0
% INFO    : Bus 17733	: V=0.9616041, theta=-39.167797 -> V=1.0, theta=0.0
% INFO    : Bus 17734	: V=0.9600496, theta=-39.180771 -> V=1.0, theta=0.0
% INFO    : Bus 17735	: V=0.9550162, theta=-39.289337 -> V=1.0, theta=0.0
% INFO    : Bus 17736	: V=0.9928044, theta=-40.342849 -> V=1.0, theta=0.0
% INFO    : Bus 17737	: V=1.0065523, theta=-39.018525 -> V=1.0, theta=0.0
% INFO    : Bus 17738	: V=0.9924097, theta=-39.924097 -> V=1.0, theta=0.0
% INFO    : Bus 17739	: V=0.9785609, theta=-41.416055 -> V=1.0, theta=0.0
% INFO    : Bus 17740	: V=0.9804458, theta=-41.374615 -> V=1.0, theta=0.0
% INFO    : Bus 17741	: V=0.9872076, theta=-40.802176 -> V=1.0, theta=0.0
% INFO    : Bus 17742	: V=0.9857788, theta=-40.916368 -> V=1.0, theta=0.0
% INFO    : Bus 17743	: V=0.9850419, theta=-40.987454 -> V=1.0, theta=0.0
% INFO    : Bus 17744	: V=0.9829641, theta=-41.13599 -> V=1.0, theta=0.0
% INFO    : Bus 17745	: V=0.9800699, theta=-41.391492 -> V=1.0, theta=0.0
% INFO    : Bus 17746	: V=0.9619195, theta=-42.278167 -> V=1.0, theta=0.0
% INFO    : Bus 17747	: V=0.9622271, theta=-42.249399 -> V=1.0, theta=0.0
% INFO    : Bus 17748	: V=0.9514861, theta=-43.749173 -> V=1.0, theta=0.0
% INFO    : Bus 17749	: V=0.9502586, theta=-43.858813 -> V=1.0, theta=0.0
% INFO    : Bus 17750	: V=0.9522603, theta=-43.651541 -> V=1.0, theta=0.0
% INFO    : Bus 17751	: V=0.9527454, theta=-43.624147 -> V=1.0, theta=0.0
% INFO    : Bus 17752	: V=0.9533711, theta=-43.568581 -> V=1.0, theta=0.0
% INFO    : Bus 17753	: V=0.9614103, theta=-42.380528 -> V=1.0, theta=0.0
% INFO    : Bus 17754	: V=0.9536266, theta=-43.499903 -> V=1.0, theta=0.0
% INFO    : Bus 17755	: V=0.953953, theta=-43.33484 -> V=1.0, theta=0.0
% INFO    : Bus 17756	: V=0.9533244, theta=-43.451627 -> V=1.0, theta=0.0
% INFO    : Bus 17757	: V=0.9625268, theta=-42.222555 -> V=1.0, theta=0.0
% INFO    : Bus 17758	: V=0.9634767, theta=-42.146476 -> V=1.0, theta=0.0
% INFO    : Bus 17759	: V=0.9560963, theta=-43.239973 -> V=1.0, theta=0.0
% INFO    : Bus 17760	: V=0.9650619, theta=-42.039948 -> V=1.0, theta=0.0
% INFO    : Bus 17761	: V=0.9525992, theta=-43.428001 -> V=1.0, theta=0.0
% INFO    : Bus 17762	: V=0.9535932, theta=-43.60263 -> V=1.0, theta=0.0
% INFO    : Bus 17763	: V=0.9511492, theta=-43.739903 -> V=1.0, theta=0.0
% INFO    : Bus 17764	: V=0.9523578, theta=-43.614297 -> V=1.0, theta=0.0
% INFO    : Bus 17765	: V=0.962884, theta=-42.408138 -> V=1.0, theta=0.0
% INFO    : Bus 17766	: V=0.9532272, theta=-43.601037 -> V=1.0, theta=0.0
% INFO    : Bus 17767	: V=0.9524388, theta=-43.528394 -> V=1.0, theta=0.0
% INFO    : Bus 17768	: V=0.9523878, theta=-43.616549 -> V=1.0, theta=0.0
% INFO    : Bus 17769	: V=0.962216, theta=-42.240522 -> V=1.0, theta=0.0
% INFO    : Bus 17770	: V=0.9546383, theta=-43.279498 -> V=1.0, theta=0.0
% INFO    : Bus 17771	: V=0.967409, theta=-41.862651 -> V=1.0, theta=0.0
% INFO    : Bus 17772	: V=0.962777, theta=-42.199657 -> V=1.0, theta=0.0
% INFO    : Bus 17773	: V=0.9648937, theta=-42.030401 -> V=1.0, theta=0.0
% INFO    : Bus 17774	: V=0.9554223, theta=-43.169399 -> V=1.0, theta=0.0
% INFO    : Bus 17775	: V=0.9545869, theta=-43.291597 -> V=1.0, theta=0.0
% INFO    : Bus 17776	: V=0.95416, theta=-43.309442 -> V=1.0, theta=0.0
% INFO    : Bus 17777	: V=0.9592234, theta=-43.129639 -> V=1.0, theta=0.0
% INFO    : Bus 17778	: V=0.9669951, theta=-41.903113 -> V=1.0, theta=0.0
% INFO    : Bus 17779	: V=0.9576358, theta=-43.227081 -> V=1.0, theta=0.0
% INFO    : Bus 17780	: V=0.9615004, theta=-42.925203 -> V=1.0, theta=0.0
% INFO    : Bus 17781	: V=0.9625281, theta=-42.908883 -> V=1.0, theta=0.0
% INFO    : Bus 17782	: V=0.9558218, theta=-43.410025 -> V=1.0, theta=0.0
% INFO    : Bus 17783	: V=0.9633815, theta=-42.345833 -> V=1.0, theta=0.0
% INFO    : Bus 17784	: V=0.9529704, theta=-43.620693 -> V=1.0, theta=0.0
% INFO    : Bus 17785	: V=0.9623534, theta=-42.422277 -> V=1.0, theta=0.0
% INFO    : Bus 17786	: V=0.9512677, theta=-43.873987 -> V=1.0, theta=0.0
% INFO    : Bus 17787	: V=0.9528902, theta=-43.7098 -> V=1.0, theta=0.0
% INFO    : Bus 17788	: V=0.953606, theta=-43.511532 -> V=1.0, theta=0.0
% INFO    : Bus 17789	: V=0.9522284, theta=-43.663707 -> V=1.0, theta=0.0
% INFO    : Bus 17790	: V=0.9599962, theta=-42.603148 -> V=1.0, theta=0.0
% INFO    : Bus 17791	: V=0.9647678, theta=-42.063672 -> V=1.0, theta=0.0
% INFO    : Bus 17792	: V=0.9632978, theta=-42.255887 -> V=1.0, theta=0.0
% INFO    : Bus 17793	: V=0.9582045, theta=-42.976285 -> V=1.0, theta=0.0
% INFO    : Bus 17794	: V=0.9543344, theta=-43.041497 -> V=1.0, theta=0.0
% INFO    : Bus 17795	: V=0.9738109, theta=-41.043083 -> V=1.0, theta=0.0
% INFO    : Bus 17796	: V=0.9659554, theta=-41.908328 -> V=1.0, theta=0.0
% INFO    : Bus 17797	: V=0.9689542, theta=-41.454781 -> V=1.0, theta=0.0
% INFO    : Bus 17798	: V=0.9627786, theta=-41.749903 -> V=1.0, theta=0.0
% INFO    : Bus 17799	: V=0.9633366, theta=-42.201322 -> V=1.0, theta=0.0
% INFO    : Bus 17800	: V=0.9693261, theta=-41.350145 -> V=1.0, theta=0.0
% INFO    : Bus 17801	: V=0.9593596, theta=-42.774687 -> V=1.0, theta=0.0
% INFO    : Bus 17802	: V=0.9618083, theta=-42.573009 -> V=1.0, theta=0.0
% INFO    : Bus 17803	: V=0.9660524, theta=-42.137143 -> V=1.0, theta=0.0
% INFO    : Bus 17804	: V=0.9640483, theta=-42.158297 -> V=1.0, theta=0.0
% INFO    : Bus 17805	: V=0.9638561, theta=-42.214989 -> V=1.0, theta=0.0
% INFO    : Bus 17806	: V=0.9626781, theta=-42.252968 -> V=1.0, theta=0.0
% INFO    : Bus 17807	: V=0.9969796, theta=-38.585655 -> V=1.0, theta=0.0
% INFO    : Bus 17808	: V=0.9775345, theta=-40.923416 -> V=1.0, theta=0.0
% INFO    : Bus 17809	: V=0.9784987, theta=-40.856395 -> V=1.0, theta=0.0
% INFO    : Bus 17810	: V=0.975922, theta=-40.894717 -> V=1.0, theta=0.0
% INFO    : Bus 17811	: V=0.9829548, theta=-40.06209 -> V=1.0, theta=0.0
% INFO    : Bus 17812	: V=0.9702702, theta=-41.428472 -> V=1.0, theta=0.0
% INFO    : Bus 17813	: V=0.9719376, theta=-41.163094 -> V=1.0, theta=0.0
% INFO    : Bus 17814	: V=0.9714817, theta=-41.319105 -> V=1.0, theta=0.0
% INFO    : Bus 17815	: V=0.9776196, theta=-40.744901 -> V=1.0, theta=0.0
% INFO    : Bus 17816	: V=0.9849383, theta=-40.169198 -> V=1.0, theta=0.0
% INFO    : Bus 17817	: V=0.9848104, theta=-40.210872 -> V=1.0, theta=0.0
% INFO    : Bus 17818	: V=0.9743405, theta=-41.096173 -> V=1.0, theta=0.0
% INFO    : Bus 17819	: V=0.9851668, theta=-40.125904 -> V=1.0, theta=0.0
% INFO    : Bus 17820	: V=0.9859501, theta=-40.025494 -> V=1.0, theta=0.0
% INFO    : Bus 17821	: V=0.9909366, theta=-39.657028 -> V=1.0, theta=0.0
% INFO    : Bus 17822	: V=0.965586, theta=-42.211576 -> V=1.0, theta=0.0
% INFO    : Bus 17823	: V=0.9574374, theta=-42.644382 -> V=1.0, theta=0.0
% INFO    : Bus 17824	: V=0.9580792, theta=-42.60709 -> V=1.0, theta=0.0
% INFO    : Bus 17825	: V=0.9599709, theta=-42.783271 -> V=1.0, theta=0.0
% INFO    : Bus 17826	: V=0.9621386, theta=-42.590291 -> V=1.0, theta=0.0
% INFO    : Bus 17827	: V=0.9717894, theta=-41.858843 -> V=1.0, theta=0.0
% INFO    : Bus 17828	: V=0.9905785, theta=-39.793863 -> V=1.0, theta=0.0
% INFO    : Bus 17829	: V=0.9870095, theta=-40.145126 -> V=1.0, theta=0.0
% INFO    : Bus 17830	: V=0.9701352, theta=-41.894304 -> V=1.0, theta=0.0
% INFO    : Bus 17831	: V=0.969584, theta=-41.915536 -> V=1.0, theta=0.0
% INFO    : Bus 17832	: V=0.9815835, theta=-40.509122 -> V=1.0, theta=0.0
% INFO    : Bus 17833	: V=0.9647081, theta=-42.275252 -> V=1.0, theta=0.0
% INFO    : Bus 17834	: V=0.9792513, theta=-40.719744 -> V=1.0, theta=0.0
% INFO    : Bus 17835	: V=1.0000363, theta=-38.160042 -> V=1.0, theta=0.0
% INFO    : Bus 17836	: V=0.9738992, theta=-41.280095 -> V=1.0, theta=0.0
% INFO    : Bus 17837	: V=0.9564353, theta=-42.717503 -> V=1.0, theta=0.0
% INFO    : Bus 17838	: V=0.9563038, theta=-42.804309 -> V=1.0, theta=0.0
% INFO    : Bus 17839	: V=0.954856, theta=-42.819962 -> V=1.0, theta=0.0
% INFO    : Bus 17840	: V=0.9573656, theta=-42.652076 -> V=1.0, theta=0.0
% INFO    : Bus 17841	: V=0.9588147, theta=-42.806198 -> V=1.0, theta=0.0
% INFO    : Bus 17842	: V=0.9590097, theta=-42.764542 -> V=1.0, theta=0.0
% INFO    : Bus 17843	: V=0.9697864, theta=-41.631243 -> V=1.0, theta=0.0
% INFO    : Bus 17844	: V=0.9738641, theta=-41.291115 -> V=1.0, theta=0.0
% INFO    : Bus 17845	: V=0.9728501, theta=-41.468676 -> V=1.0, theta=0.0
% INFO    : Bus 17846	: V=0.9623772, theta=-42.603563 -> V=1.0, theta=0.0
% INFO    : Bus 17847	: V=0.9590869, theta=-42.821497 -> V=1.0, theta=0.0
% INFO    : Bus 17848	: V=0.9675509, theta=-41.829391 -> V=1.0, theta=0.0
% INFO    : Bus 17849	: V=0.9581811, theta=-42.699888 -> V=1.0, theta=0.0
% INFO    : Bus 17850	: V=0.9715358, theta=-41.485397 -> V=1.0, theta=0.0
% INFO    : Bus 17851	: V=0.9620725, theta=-42.619816 -> V=1.0, theta=0.0
% INFO    : Bus 17852	: V=0.9690047, theta=-41.744343 -> V=1.0, theta=0.0
% INFO    : Bus 17853	: V=0.9763261, theta=-41.120719 -> V=1.0, theta=0.0
% INFO    : Bus 17854	: V=0.9588885, theta=-42.622437 -> V=1.0, theta=0.0
% INFO    : Bus 17855	: V=0.9629819, theta=-42.566529 -> V=1.0, theta=0.0
% INFO    : Bus 17856	: V=0.9560598, theta=-42.7649 -> V=1.0, theta=0.0
% INFO    : Bus 17857	: V=0.9572694, theta=-42.844935 -> V=1.0, theta=0.0
% INFO    : Bus 17858	: V=0.9591315, theta=-42.738907 -> V=1.0, theta=0.0
% INFO    : Bus 17859	: V=0.958766, theta=-42.486143 -> V=1.0, theta=0.0
% INFO    : Bus 17860	: V=0.9580262, theta=-42.549522 -> V=1.0, theta=0.0
% INFO    : Bus 17861	: V=0.9577455, theta=-42.600327 -> V=1.0, theta=0.0
% INFO    : Bus 17862	: V=0.9578398, theta=-42.610088 -> V=1.0, theta=0.0
% INFO    : Bus 17863	: V=0.9680463, theta=-42.025087 -> V=1.0, theta=0.0
% INFO    : Bus 17864	: V=0.977817, theta=-41.13672 -> V=1.0, theta=0.0
% INFO    : Bus 17865	: V=0.984877, theta=-40.292438 -> V=1.0, theta=0.0
% INFO    : Bus 17866	: V=0.9830812, theta=-40.710202 -> V=1.0, theta=0.0
% INFO    : Bus 17867	: V=0.9695543, theta=-41.822606 -> V=1.0, theta=0.0
% INFO    : Bus 17868	: V=0.9756936, theta=-41.290649 -> V=1.0, theta=0.0
% INFO    : Bus 17869	: V=0.9751824, theta=-41.42207 -> V=1.0, theta=0.0
% INFO    : Bus 17870	: V=0.9730198, theta=-41.629503 -> V=1.0, theta=0.0
% INFO    : Bus 17871	: V=0.9732058, theta=-41.512856 -> V=1.0, theta=0.0
% INFO    : Bus 17872	: V=0.9725547, theta=-41.560529 -> V=1.0, theta=0.0
% INFO    : Bus 17873	: V=0.9614713, theta=-42.96656 -> V=1.0, theta=0.0
% INFO    : Bus 17874	: V=0.9670781, theta=-42.048424 -> V=1.0, theta=0.0
% INFO    : Bus 17875	: V=0.9980682, theta=-38.722747 -> V=1.0, theta=0.0
% INFO    : Bus 17876	: V=0.9749325, theta=-41.699568 -> V=1.0, theta=0.0
% INFO    : Bus 17877	: V=0.9737845, theta=-41.810343 -> V=1.0, theta=0.0
% INFO    : Bus 17878	: V=0.9717781, theta=-42.003349 -> V=1.0, theta=0.0
% INFO    : Bus 17879	: V=0.9719865, theta=-41.723004 -> V=1.0, theta=0.0
% INFO    : Bus 17880	: V=0.9712617, theta=-41.794539 -> V=1.0, theta=0.0
% INFO    : Bus 17881	: V=0.9679537, theta=-42.009084 -> V=1.0, theta=0.0
% INFO    : Bus 17882	: V=0.9977563, theta=-38.707105 -> V=1.0, theta=0.0
% INFO    : Bus 17883	: V=0.9702859, theta=-41.858844 -> V=1.0, theta=0.0
% INFO    : Bus 17884	: V=0.9745363, theta=-41.381327 -> V=1.0, theta=0.0
% INFO    : Bus 17885	: V=0.9731909, theta=-41.637712 -> V=1.0, theta=0.0
% INFO    : Bus 17886	: V=0.9701901, theta=-42.169822 -> V=1.0, theta=0.0
% INFO    : Bus 17887	: V=0.9653249, theta=-42.784823 -> V=1.0, theta=0.0
% INFO    : Bus 17888	: V=0.9658116, theta=-42.778028 -> V=1.0, theta=0.0
% INFO    : Bus 17889	: V=0.9713665, theta=-41.776219 -> V=1.0, theta=0.0
% INFO    : Bus 17890	: V=0.962627, theta=-43.109548 -> V=1.0, theta=0.0
% INFO    : Bus 17891	: V=0.9790882, theta=-41.181365 -> V=1.0, theta=0.0
% INFO    : Bus 17892	: V=0.9647553, theta=-42.2492 -> V=1.0, theta=0.0
% INFO    : Bus 17893	: V=0.9563129, theta=-43.403761 -> V=1.0, theta=0.0
% INFO    : Bus 17894	: V=0.958059, theta=-43.145991 -> V=1.0, theta=0.0
% INFO    : Bus 17895	: V=0.9685545, theta=-42.030484 -> V=1.0, theta=0.0
% INFO    : Bus 17896	: V=0.9551712, theta=-43.611063 -> V=1.0, theta=0.0
% INFO    : Bus 17897	: V=0.9667244, theta=-42.184649 -> V=1.0, theta=0.0
% INFO    : Bus 17898	: V=0.9654335, theta=-42.298954 -> V=1.0, theta=0.0
% INFO    : Bus 17899	: V=0.9666937, theta=-42.26148 -> V=1.0, theta=0.0
% INFO    : Bus 17900	: V=0.9635863, theta=-42.468474 -> V=1.0, theta=0.0
% INFO    : Bus 17901	: V=0.9635601, theta=-42.463185 -> V=1.0, theta=0.0
% INFO    : Bus 17902	: V=0.9555903, theta=-43.523218 -> V=1.0, theta=0.0
% INFO    : Bus 17903	: V=0.9644416, theta=-42.386446 -> V=1.0, theta=0.0
% INFO    : Bus 17904	: V=0.9532529, theta=-43.697201 -> V=1.0, theta=0.0
% INFO    : Bus 17905	: V=0.9552176, theta=-43.498305 -> V=1.0, theta=0.0
% INFO    : Bus 17906	: V=0.957706, theta=-43.365338 -> V=1.0, theta=0.0
% INFO    : Bus 17907	: V=0.9732239, theta=-41.096458 -> V=1.0, theta=0.0
% INFO    : Bus 17908	: V=0.9597495, theta=-42.873494 -> V=1.0, theta=0.0
% INFO    : Bus 17909	: V=0.9574256, theta=-42.918367 -> V=1.0, theta=0.0
% INFO    : Bus 17910	: V=0.9552371, theta=-43.682312 -> V=1.0, theta=0.0
% INFO    : Bus 17911	: V=0.9553304, theta=-43.696084 -> V=1.0, theta=0.0
% INFO    : Bus 17912	: V=0.9546532, theta=-43.696769 -> V=1.0, theta=0.0
% INFO    : Bus 17913	: V=0.955577, theta=-43.613435 -> V=1.0, theta=0.0
% INFO    : Bus 17914	: V=0.9625696, theta=-42.559546 -> V=1.0, theta=0.0
% INFO    : Bus 17915	: V=0.9611507, theta=-42.712024 -> V=1.0, theta=0.0
% INFO    : Bus 17916	: V=0.9678858, theta=-42.298392 -> V=1.0, theta=0.0
% INFO    : Bus 17917	: V=0.9571337, theta=-43.53303 -> V=1.0, theta=0.0
% INFO    : Bus 17918	: V=0.9558973, theta=-43.632055 -> V=1.0, theta=0.0
% INFO    : Bus 17919	: V=0.9659549, theta=-42.413094 -> V=1.0, theta=0.0
% INFO    : Bus 17920	: V=0.9654985, theta=-42.421505 -> V=1.0, theta=0.0
% INFO    : Bus 17921	: V=0.9655039, theta=-42.395821 -> V=1.0, theta=0.0
% INFO    : Bus 17922	: V=0.9549371, theta=-43.76059 -> V=1.0, theta=0.0
% INFO    : Bus 17923	: V=0.9537438, theta=-43.902271 -> V=1.0, theta=0.0
% INFO    : Bus 17924	: V=0.9532361, theta=-43.844354 -> V=1.0, theta=0.0
% INFO    : Bus 17925	: V=0.9558658, theta=-43.767851 -> V=1.0, theta=0.0
% INFO    : Bus 17926	: V=0.9606532, theta=-42.982185 -> V=1.0, theta=0.0
% INFO    : Bus 17927	: V=0.9550955, theta=-43.670769 -> V=1.0, theta=0.0
% INFO    : Bus 17928	: V=0.9576719, theta=-43.090478 -> V=1.0, theta=0.0
% INFO    : Bus 17929	: V=0.9568433, theta=-43.18655 -> V=1.0, theta=0.0
% INFO    : Bus 17930	: V=0.962736, theta=-42.2651 -> V=1.0, theta=0.0
% INFO    : Bus 17931	: V=0.9803458, theta=-40.93593 -> V=1.0, theta=0.0
% INFO    : Bus 17932	: V=0.9774012, theta=-41.163355 -> V=1.0, theta=0.0
% INFO    : Bus 17933	: V=1.0088574, theta=-39.283866 -> V=1.0, theta=0.0
% INFO    : Bus 17934	: V=1.0118787, theta=-39.106549 -> V=1.0, theta=0.0
% INFO    : Bus 17935	: V=1.0000181, theta=-40.268649 -> V=1.0, theta=0.0
% INFO    : Bus 17936	: V=1.0035022, theta=-39.564399 -> V=1.0, theta=0.0
% INFO    : Bus 17937	: V=0.9995093, theta=-39.975182 -> V=1.0, theta=0.0
% INFO    : Bus 17938	: V=0.9954215, theta=-40.252305 -> V=1.0, theta=0.0
% INFO    : Bus 17939	: V=0.9579298, theta=-44.096762 -> V=1.0, theta=0.0
% INFO    : Bus 17940	: V=0.9576392, theta=-43.854806 -> V=1.0, theta=0.0
% INFO    : Bus 17941	: V=0.958228, theta=-43.849181 -> V=1.0, theta=0.0
% INFO    : Bus 17942	: V=0.9647323, theta=-48.526768 -> V=1.0, theta=0.0
% INFO    : Bus 17943	: V=0.9848302, theta=-46.126866 -> V=1.0, theta=0.0
% INFO    : Bus 17944	: V=0.9776221, theta=-46.853341 -> V=1.0, theta=0.0
% INFO    : Bus 17945	: V=0.9749835, theta=-47.128122 -> V=1.0, theta=0.0
% INFO    : Bus 17946	: V=0.9732766, theta=-47.289414 -> V=1.0, theta=0.0
% INFO    : Bus 17947	: V=0.9726601, theta=-47.352021 -> V=1.0, theta=0.0
% INFO    : Bus 17948	: V=0.968856, theta=-47.702417 -> V=1.0, theta=0.0
% INFO    : Bus 17949	: V=0.9626241, theta=-48.484211 -> V=1.0, theta=0.0
% INFO    : Bus 17950	: V=0.9612662, theta=-48.474499 -> V=1.0, theta=0.0
% INFO    : Bus 17951	: V=0.9640313, theta=-48.324768 -> V=1.0, theta=0.0
% INFO    : Bus 17952	: V=0.9687295, theta=-47.515031 -> V=1.0, theta=0.0
% INFO    : Bus 17953	: V=0.9731292, theta=-47.392788 -> V=1.0, theta=0.0
% INFO    : Bus 17954	: V=0.9937472, theta=-44.638297 -> V=1.0, theta=0.0
% INFO    : Bus 17955	: V=0.9852505, theta=-38.788645 -> V=1.0, theta=0.0
% INFO    : Bus 17956	: V=0.9893702, theta=-38.281468 -> V=1.0, theta=0.0
% INFO    : Bus 17957	: V=0.9797244, theta=-39.412102 -> V=1.0, theta=0.0
% INFO    : Bus 17958	: V=0.9785177, theta=-38.204777 -> V=1.0, theta=0.0
% INFO    : Bus 17959	: V=0.9764819, theta=-39.138455 -> V=1.0, theta=0.0
% INFO    : Bus 17960	: V=0.9840949, theta=-38.925467 -> V=1.0, theta=0.0
% INFO    : Bus 17961	: V=0.972827, theta=-39.289438 -> V=1.0, theta=0.0
% INFO    : Bus 17962	: V=0.9820436, theta=-38.257163 -> V=1.0, theta=0.0
% INFO    : Bus 17963	: V=0.9997857, theta=-35.859827 -> V=1.0, theta=0.0
% INFO    : Bus 17964	: V=0.9964542, theta=-36.71778 -> V=1.0, theta=0.0
% INFO    : Bus 17965	: V=0.9884661, theta=-37.168448 -> V=1.0, theta=0.0
% INFO    : Bus 17966	: V=0.9831193, theta=-37.061432 -> V=1.0, theta=0.0
% INFO    : Bus 17967	: V=0.9826774, theta=-37.177999 -> V=1.0, theta=0.0
% INFO    : Bus 17968	: V=1.0028151, theta=-36.365608 -> V=1.0, theta=0.0
% INFO    : Bus 17969	: V=0.9881229, theta=-36.915496 -> V=1.0, theta=0.0
% INFO    : Bus 17970	: V=0.9911617, theta=-37.272312 -> V=1.0, theta=0.0
% INFO    : Bus 17971	: V=1.0021301, theta=-36.546359 -> V=1.0, theta=0.0
% INFO    : Bus 17972	: V=0.9958943, theta=-37.44355 -> V=1.0, theta=0.0
% INFO    : Bus 17973	: V=0.9887897, theta=-37.604045 -> V=1.0, theta=0.0
% INFO    : Bus 17974	: V=0.9829862, theta=-38.224004 -> V=1.0, theta=0.0
% INFO    : Bus 17975	: V=0.9854433, theta=-37.890483 -> V=1.0, theta=0.0
% INFO    : Bus 17976	: V=0.9899019, theta=-37.291904 -> V=1.0, theta=0.0
% INFO    : Bus 17977	: V=0.9926215, theta=-37.229245 -> V=1.0, theta=0.0
% INFO    : Bus 17978	: V=0.9869871, theta=-37.787484 -> V=1.0, theta=0.0
% INFO    : Bus 17979	: V=0.9866509, theta=-37.643338 -> V=1.0, theta=0.0
% INFO    : Bus 17980	: V=0.9954497, theta=-37.051115 -> V=1.0, theta=0.0
% INFO    : Bus 17981	: V=0.9525388, theta=-49.614642 -> V=1.0, theta=0.0
% INFO    : Bus 17982	: V=0.9555922, theta=-49.447338 -> V=1.0, theta=0.0
% INFO    : Bus 17983	: V=0.9486968, theta=-49.459664 -> V=1.0, theta=0.0
% INFO    : Bus 17984	: V=0.961842, theta=-48.876374 -> V=1.0, theta=0.0
% INFO    : Bus 17985	: V=0.9427769, theta=-50.522592 -> V=1.0, theta=0.0
% INFO    : Bus 17986	: V=0.9428777, theta=-50.498941 -> V=1.0, theta=0.0
% INFO    : Bus 17987	: V=0.9500166, theta=-49.309075 -> V=1.0, theta=0.0
% INFO    : Bus 17988	: V=0.9539405, theta=-49.088451 -> V=1.0, theta=0.0
% INFO    : Bus 17989	: V=0.9518503, theta=-49.071292 -> V=1.0, theta=0.0
% INFO    : Bus 17990	: V=0.9557149, theta=-49.363076 -> V=1.0, theta=0.0
% INFO    : Bus 17991	: V=0.9499544, theta=-48.98561 -> V=1.0, theta=0.0
% INFO    : Bus 17992	: V=0.9379873, theta=-50.240697 -> V=1.0, theta=0.0
% INFO    : Bus 17993	: V=0.9415288, theta=-50.495835 -> V=1.0, theta=0.0
% INFO    : Bus 17994	: V=0.9437845, theta=-49.930169 -> V=1.0, theta=0.0
% INFO    : Bus 17995	: V=0.9543907, theta=-43.954702 -> V=1.0, theta=0.0
% INFO    : Bus 17996	: V=0.955549, theta=-43.78046 -> V=1.0, theta=0.0
% INFO    : Bus 17997	: V=0.9551038, theta=-43.79159 -> V=1.0, theta=0.0
% INFO    : Bus 17998	: V=0.9523993, theta=-44.053188 -> V=1.0, theta=0.0
% INFO    : Bus 17999	: V=0.9521425, theta=-44.121597 -> V=1.0, theta=0.0
% INFO    : Bus 18000	: V=0.9509044, theta=-44.185741 -> V=1.0, theta=0.0
% INFO    : Bus 18001	: V=0.9504501, theta=-44.219143 -> V=1.0, theta=0.0
% INFO    : Bus 18002	: V=0.9613629, theta=-42.791404 -> V=1.0, theta=0.0
% INFO    : Bus 18003	: V=0.9552429, theta=-43.789308 -> V=1.0, theta=0.0
% INFO    : Bus 18004	: V=0.975197, theta=-40.769866 -> V=1.0, theta=0.0
% INFO    : Bus 18005	: V=0.9631591, theta=-42.281655 -> V=1.0, theta=0.0
% INFO    : Bus 18006	: V=0.9734545, theta=-40.157772 -> V=1.0, theta=0.0
% INFO    : Bus 18007	: V=0.9600501, theta=-43.189682 -> V=1.0, theta=0.0
% INFO    : Bus 18008	: V=0.9553774, theta=-43.758957 -> V=1.0, theta=0.0
% INFO    : Bus 18009	: V=0.9503415, theta=-44.704264 -> V=1.0, theta=0.0
% INFO    : Bus 18010	: V=0.9491982, theta=-44.739719 -> V=1.0, theta=0.0
% INFO    : Bus 18011	: V=0.9458627, theta=-44.275601 -> V=1.0, theta=0.0
% INFO    : Bus 18012	: V=0.9686291, theta=-41.183705 -> V=1.0, theta=0.0
% INFO    : Bus 18013	: V=0.9669758, theta=-41.457007 -> V=1.0, theta=0.0
% INFO    : Bus 18014	: V=0.9519204, theta=-48.064995 -> V=1.0, theta=0.0
% INFO    : Bus 18015	: V=0.9491692, theta=-48.640355 -> V=1.0, theta=0.0
% INFO    : Bus 18016	: V=0.9475387, theta=-49.054425 -> V=1.0, theta=0.0
% INFO    : Bus 18017	: V=0.9546971, theta=-48.168209 -> V=1.0, theta=0.0
% INFO    : Bus 18018	: V=0.9592812, theta=-47.088625 -> V=1.0, theta=0.0
% INFO    : Bus 18019	: V=0.9603902, theta=-46.798108 -> V=1.0, theta=0.0
% INFO    : Bus 18020	: V=0.9623327, theta=-46.496319 -> V=1.0, theta=0.0
% INFO    : Bus 18021	: V=0.9607934, theta=-47.409359 -> V=1.0, theta=0.0
% INFO    : Bus 18022	: V=0.9544843, theta=-48.01962 -> V=1.0, theta=0.0
% INFO    : Bus 18023	: V=0.9525265, theta=-48.562324 -> V=1.0, theta=0.0
% INFO    : Bus 18024	: V=0.9549959, theta=-49.130204 -> V=1.0, theta=0.0
% INFO    : Bus 18025	: V=0.9549418, theta=-48.811373 -> V=1.0, theta=0.0
% INFO    : Bus 18026	: V=0.9858871, theta=-45.706373 -> V=1.0, theta=0.0
% INFO    : Bus 18027	: V=1.0147791, theta=-43.310962 -> V=1.0, theta=0.0
% INFO    : Bus 18028	: V=1.0110333, theta=-43.61808 -> V=1.0, theta=0.0
% INFO    : Bus 18029	: V=0.9998904, theta=-44.642016 -> V=1.0, theta=0.0
% INFO    : Bus 18030	: V=1.0083537, theta=-43.800192 -> V=1.0, theta=0.0
% INFO    : Bus 18031	: V=1.0078528, theta=-43.8249 -> V=1.0, theta=0.0
% INFO    : Bus 18032	: V=1.0043238, theta=-43.724418 -> V=1.0, theta=0.0
% INFO    : Bus 18033	: V=0.9963566, theta=-44.430831 -> V=1.0, theta=0.0
% INFO    : Bus 18034	: V=0.9940876, theta=-45.493822 -> V=1.0, theta=0.0
% INFO    : Bus 18035	: V=0.9949283, theta=-43.623581 -> V=1.0, theta=0.0
% INFO    : Bus 18036	: V=1.0085431, theta=-43.162251 -> V=1.0, theta=0.0
% INFO    : Bus 18037	: V=0.9927925, theta=-43.623553 -> V=1.0, theta=0.0
% INFO    : Bus 18038	: V=1.0080866, theta=-42.933541 -> V=1.0, theta=0.0
% INFO    : Bus 18039	: V=1.0196689, theta=-42.209042 -> V=1.0, theta=0.0
% INFO    : Bus 18040	: V=1.0083707, theta=-42.04603 -> V=1.0, theta=0.0
% INFO    : Bus 18041	: V=1.0193054, theta=-41.949356 -> V=1.0, theta=0.0
% INFO    : Bus 18042	: V=0.9966129, theta=-43.649748 -> V=1.0, theta=0.0
% INFO    : Bus 18043	: V=1.0054362, theta=-43.048254 -> V=1.0, theta=0.0
% INFO    : Bus 18044	: V=1.0095976, theta=-42.416932 -> V=1.0, theta=0.0
% INFO    : Bus 18045	: V=0.9940372, theta=-43.711594 -> V=1.0, theta=0.0
% INFO    : Bus 18046	: V=1.0046797, theta=-42.75442 -> V=1.0, theta=0.0
% INFO    : Bus 18047	: V=1.0035078, theta=-42.802396 -> V=1.0, theta=0.0
% INFO    : Bus 18048	: V=1.0054017, theta=-42.711845 -> V=1.0, theta=0.0
% INFO    : Bus 18049	: V=0.9884588, theta=-44.156692 -> V=1.0, theta=0.0
% INFO    : Bus 18050	: V=1.0183447, theta=-41.917881 -> V=1.0, theta=0.0
% INFO    : Bus 18051	: V=1.0052697, theta=-42.677992 -> V=1.0, theta=0.0
% INFO    : Bus 18052	: V=1.0071502, theta=-42.545111 -> V=1.0, theta=0.0
% INFO    : Bus 18053	: V=1.0079738, theta=-41.916368 -> V=1.0, theta=0.0
% INFO    : Bus 18054	: V=1.0023451, theta=-42.633249 -> V=1.0, theta=0.0
% INFO    : Bus 18055	: V=1.0056374, theta=-42.508492 -> V=1.0, theta=0.0
% INFO    : Bus 18056	: V=1.0112936, theta=-41.005857 -> V=1.0, theta=0.0
% INFO    : Bus 18057	: V=1.0019042, theta=-43.310604 -> V=1.0, theta=0.0
% INFO    : Bus 18058	: V=1.0022328, theta=-42.68792 -> V=1.0, theta=0.0
% INFO    : Bus 18059	: V=1.0065101, theta=-43.072343 -> V=1.0, theta=0.0
% INFO    : Bus 18060	: V=0.9932605, theta=-45.032169 -> V=1.0, theta=0.0
% INFO    : Bus 18061	: V=0.9948176, theta=-44.241086 -> V=1.0, theta=0.0
% INFO    : Bus 18062	: V=0.9880782, theta=-45.827023 -> V=1.0, theta=0.0
% INFO    : Bus 18063	: V=0.9974541, theta=-41.220596 -> V=1.0, theta=0.0
% INFO    : Bus 18064	: V=0.9817267, theta=-42.399431 -> V=1.0, theta=0.0
% INFO    : Bus 18065	: V=0.9834027, theta=-44.250753 -> V=1.0, theta=0.0
% INFO    : Bus 18066	: V=0.9863857, theta=-43.966777 -> V=1.0, theta=0.0
% INFO    : Bus 18067	: V=0.9772072, theta=-44.854144 -> V=1.0, theta=0.0
% INFO    : Bus 18068	: V=0.9816473, theta=-43.84072 -> V=1.0, theta=0.0
% INFO    : Bus 18069	: V=0.9848143, theta=-43.726156 -> V=1.0, theta=0.0
% INFO    : Bus 18070	: V=0.9913119, theta=-43.32719 -> V=1.0, theta=0.0
% INFO    : Bus 18071	: V=0.9903418, theta=-43.442916 -> V=1.0, theta=0.0
% INFO    : Bus 18072	: V=0.9946398, theta=-42.830357 -> V=1.0, theta=0.0
% INFO    : Bus 18073	: V=0.9959092, theta=-42.682156 -> V=1.0, theta=0.0
% INFO    : Bus 18074	: V=0.9964546, theta=-42.796142 -> V=1.0, theta=0.0
% INFO    : Bus 18075	: V=1.0003099, theta=-42.097366 -> V=1.0, theta=0.0
% INFO    : Bus 18076	: V=0.9925658, theta=-42.826457 -> V=1.0, theta=0.0
% INFO    : Bus 18077	: V=0.9486802, theta=-55.850508 -> V=1.0, theta=0.0
% INFO    : Bus 18078	: V=0.9484365, theta=-56.02405 -> V=1.0, theta=0.0
% INFO    : Bus 18079	: V=0.9497358, theta=-56.282591 -> V=1.0, theta=0.0
% INFO    : Bus 18080	: V=0.9547143, theta=-55.510053 -> V=1.0, theta=0.0
% INFO    : Bus 18081	: V=0.9549173, theta=-55.387014 -> V=1.0, theta=0.0
% INFO    : Bus 18082	: V=0.9510291, theta=-55.825603 -> V=1.0, theta=0.0
% INFO    : Bus 18083	: V=0.9554769, theta=-55.216429 -> V=1.0, theta=0.0
% INFO    : Bus 18084	: V=0.9521473, theta=-55.697038 -> V=1.0, theta=0.0
% INFO    : Bus 18085	: V=0.9555192, theta=-55.164622 -> V=1.0, theta=0.0
% INFO    : Bus 18086	: V=0.9556281, theta=-55.121935 -> V=1.0, theta=0.0
% INFO    : Bus 18087	: V=0.9558982, theta=-55.061174 -> V=1.0, theta=0.0
% INFO    : Bus 18088	: V=0.9525488, theta=-55.476996 -> V=1.0, theta=0.0
% INFO    : Bus 18089	: V=0.9573296, theta=-55.039583 -> V=1.0, theta=0.0
% INFO    : Bus 18090	: V=0.95554, theta=-55.162708 -> V=1.0, theta=0.0
% INFO    : Bus 18091	: V=0.9554396, theta=-55.192446 -> V=1.0, theta=0.0
% INFO    : Bus 18092	: V=0.9563117, theta=-55.176524 -> V=1.0, theta=0.0
% INFO    : Bus 18093	: V=0.9520889, theta=-55.670939 -> V=1.0, theta=0.0
% INFO    : Bus 18094	: V=0.9559873, theta=-55.242197 -> V=1.0, theta=0.0
% INFO    : Bus 18095	: V=0.9488104, theta=-56.178844 -> V=1.0, theta=0.0
% INFO    : Bus 18096	: V=0.9489143, theta=-56.090672 -> V=1.0, theta=0.0
% INFO    : Bus 18097	: V=0.9562458, theta=-55.269105 -> V=1.0, theta=0.0
% INFO    : Bus 18098	: V=0.9498815, theta=-55.983683 -> V=1.0, theta=0.0
% INFO    : Bus 18099	: V=0.9489737, theta=-56.15869 -> V=1.0, theta=0.0
% INFO    : Bus 18100	: V=0.9488244, theta=-56.163027 -> V=1.0, theta=0.0
% INFO    : Bus 18101	: V=0.9497316, theta=-55.933641 -> V=1.0, theta=0.0
% INFO    : Bus 18102	: V=0.9499066, theta=-55.981691 -> V=1.0, theta=0.0
% INFO    : Bus 18103	: V=0.9512884, theta=-55.761807 -> V=1.0, theta=0.0
% INFO    : Bus 18104	: V=0.9522936, theta=-55.653697 -> V=1.0, theta=0.0
% INFO    : Bus 18105	: V=0.9565998, theta=-55.138774 -> V=1.0, theta=0.0
% INFO    : Bus 18106	: V=0.9523898, theta=-55.674712 -> V=1.0, theta=0.0
% INFO    : Bus 18107	: V=0.9569727, theta=-55.095278 -> V=1.0, theta=0.0
% INFO    : Bus 18108	: V=0.955955, theta=-55.232583 -> V=1.0, theta=0.0
% INFO    : Bus 18109	: V=0.9587394, theta=-54.905248 -> V=1.0, theta=0.0
% INFO    : Bus 18110	: V=0.9542684, theta=-55.347212 -> V=1.0, theta=0.0
% INFO    : Bus 18111	: V=0.9549829, theta=-55.233633 -> V=1.0, theta=0.0
% INFO    : Bus 18112	: V=0.9515749, theta=-55.732044 -> V=1.0, theta=0.0
% INFO    : Bus 18113	: V=0.9592897, theta=-54.692867 -> V=1.0, theta=0.0
% INFO    : Bus 18114	: V=0.9594547, theta=-54.610979 -> V=1.0, theta=0.0
% INFO    : Bus 18115	: V=0.9606984, theta=-54.37064 -> V=1.0, theta=0.0
% INFO    : Bus 18116	: V=0.9597893, theta=-54.551742 -> V=1.0, theta=0.0
% INFO    : Bus 18117	: V=0.9608854, theta=-54.339645 -> V=1.0, theta=0.0
% INFO    : Bus 18118	: V=0.9601643, theta=-54.487575 -> V=1.0, theta=0.0
% INFO    : Bus 18119	: V=0.9606015, theta=-54.410744 -> V=1.0, theta=0.0
% INFO    : Bus 18120	: V=0.9559823, theta=-54.9399 -> V=1.0, theta=0.0
% INFO    : Bus 18121	: V=0.9604385, theta=-54.387831 -> V=1.0, theta=0.0
% INFO    : Bus 18122	: V=0.9537458, theta=-55.368006 -> V=1.0, theta=0.0
% INFO    : Bus 18123	: V=0.959107, theta=-54.705979 -> V=1.0, theta=0.0
% INFO    : Bus 18124	: V=0.9522083, theta=-55.622568 -> V=1.0, theta=0.0
% INFO    : Bus 18125	: V=0.9505609, theta=-55.899084 -> V=1.0, theta=0.0
% INFO    : Bus 18126	: V=0.9580318, theta=-54.760147 -> V=1.0, theta=0.0
% INFO    : Bus 18127	: V=0.951319, theta=-55.645984 -> V=1.0, theta=0.0
% INFO    : Bus 18128	: V=0.9582073, theta=-54.895641 -> V=1.0, theta=0.0
% INFO    : Bus 18129	: V=0.9511682, theta=-55.666222 -> V=1.0, theta=0.0
% INFO    : Bus 18130	: V=0.9581636, theta=-54.72236 -> V=1.0, theta=0.0
% INFO    : Bus 18131	: V=0.9580701, theta=-54.744484 -> V=1.0, theta=0.0
% INFO    : Bus 18132	: V=0.9583913, theta=-54.686068 -> V=1.0, theta=0.0
% INFO    : Bus 18133	: V=0.9588137, theta=-54.621598 -> V=1.0, theta=0.0
% INFO    : Bus 18134	: V=0.9484203, theta=-55.81139 -> V=1.0, theta=0.0
% INFO    : Bus 18135	: V=0.9513563, theta=-55.646562 -> V=1.0, theta=0.0
% INFO    : Bus 18136	: V=1.0155663, theta=-40.725069 -> V=1.0, theta=0.0
% INFO    : Bus 18137	: V=1.0050393, theta=-43.602878 -> V=1.0, theta=0.0
% INFO    : Bus 18138	: V=1.0067768, theta=-42.997743 -> V=1.0, theta=0.0
% INFO    : Bus 18139	: V=1.0110052, theta=-42.859927 -> V=1.0, theta=0.0
% INFO    : Bus 18140	: V=1.0176237, theta=-41.715212 -> V=1.0, theta=0.0
% INFO    : Bus 18141	: V=1.0160019, theta=-41.179364 -> V=1.0, theta=0.0
% INFO    : Bus 18142	: V=1.007319, theta=-42.743047 -> V=1.0, theta=0.0
% INFO    : Bus 18143	: V=1.0152156, theta=-40.90945 -> V=1.0, theta=0.0
% INFO    : Bus 18144	: V=1.0053557, theta=-42.685453 -> V=1.0, theta=0.0
% INFO    : Bus 18145	: V=1.002811, theta=-42.871886 -> V=1.0, theta=0.0
% INFO    : Bus 18146	: V=1.0050323, theta=-42.56446 -> V=1.0, theta=0.0
% INFO    : Bus 18147	: V=1.0031275, theta=-42.793959 -> V=1.0, theta=0.0
% INFO    : Bus 18148	: V=1.0029266, theta=-42.71277 -> V=1.0, theta=0.0
% INFO    : Bus 18149	: V=1.0106923, theta=-40.069283 -> V=1.0, theta=0.0
% INFO    : Bus 18150	: V=0.9672349, theta=-45.376119 -> V=1.0, theta=0.0
% INFO    : Bus 18151	: V=0.9872052, theta=-43.857361 -> V=1.0, theta=0.0
% INFO    : Bus 18152	: V=0.9885137, theta=-43.761214 -> V=1.0, theta=0.0
% INFO    : Bus 18153	: V=0.9912919, theta=-43.504405 -> V=1.0, theta=0.0
% INFO    : Bus 18154	: V=1.0048346, theta=-42.303334 -> V=1.0, theta=0.0
% INFO    : Bus 18155	: V=0.9682178, theta=-46.381195 -> V=1.0, theta=0.0
% INFO    : Bus 18156	: V=0.98906, theta=-44.119813 -> V=1.0, theta=0.0
% INFO    : Bus 18157	: V=0.9946729, theta=-43.318916 -> V=1.0, theta=0.0
% INFO    : Bus 18158	: V=1.0056034, theta=-42.181175 -> V=1.0, theta=0.0
% INFO    : Bus 18159	: V=1.0122571, theta=-41.119811 -> V=1.0, theta=0.0
% INFO    : Bus 18160	: V=0.9969569, theta=-43.015964 -> V=1.0, theta=0.0
% INFO    : Bus 18161	: V=0.9702989, theta=-46.552315 -> V=1.0, theta=0.0
% INFO    : Bus 18162	: V=0.9630647, theta=-48.05151 -> V=1.0, theta=0.0
% INFO    : Bus 18163	: V=0.9680549, theta=-47.172135 -> V=1.0, theta=0.0
% INFO    : Bus 18164	: V=0.9756855, theta=-45.956751 -> V=1.0, theta=0.0
% INFO    : Bus 18165	: V=0.9578736, theta=-48.28398 -> V=1.0, theta=0.0
% INFO    : Bus 18166	: V=0.9830032, theta=-48.443008 -> V=1.0, theta=0.0
% INFO    : Bus 18167	: V=0.9786986, theta=-47.88683 -> V=1.0, theta=0.0
% INFO    : Bus 18168	: V=0.9928932, theta=-44.508742 -> V=1.0, theta=0.0
% INFO    : Bus 18169	: V=0.9626894, theta=-47.331366 -> V=1.0, theta=0.0
% INFO    : Bus 18170	: V=0.9833389, theta=-45.783459 -> V=1.0, theta=0.0
% INFO    : Bus 18171	: V=0.9661223, theta=-48.198085 -> V=1.0, theta=0.0
% INFO    : Bus 18172	: V=0.9625023, theta=-48.410492 -> V=1.0, theta=0.0
% INFO    : Bus 18173	: V=0.9571362, theta=-49.202807 -> V=1.0, theta=0.0
% INFO    : Bus 18174	: V=0.9589722, theta=-48.757107 -> V=1.0, theta=0.0
% INFO    : Bus 18175	: V=0.9521865, theta=-49.032859 -> V=1.0, theta=0.0
% INFO    : Bus 18176	: V=1.0015662, theta=-39.954154 -> V=1.0, theta=0.0
% INFO    : Bus 18177	: V=1.0053531, theta=-39.729227 -> V=1.0, theta=0.0
% INFO    : Bus 18178	: V=1.0064496, theta=-39.628808 -> V=1.0, theta=0.0
% INFO    : Bus 18179	: V=1.007346, theta=-39.542926 -> V=1.0, theta=0.0
% INFO    : Bus 18180	: V=1.0118805, theta=-39.220089 -> V=1.0, theta=0.0
% INFO    : Bus 18181	: V=0.9459709, theta=-48.632611 -> V=1.0, theta=0.0
% INFO    : Bus 18182	: V=0.948256, theta=-48.068946 -> V=1.0, theta=0.0
% INFO    : Bus 18183	: V=0.9486627, theta=-48.824921 -> V=1.0, theta=0.0
% INFO    : Bus 18184	: V=0.9461601, theta=-50.930166 -> V=1.0, theta=0.0
% INFO    : Bus 18185	: V=0.9464703, theta=-49.563729 -> V=1.0, theta=0.0
% INFO    : Bus 18186	: V=0.952085, theta=-51.093457 -> V=1.0, theta=0.0
% INFO    : Bus 18187	: V=0.9413854, theta=-51.690687 -> V=1.0, theta=0.0
% INFO    : Bus 18188	: V=1.0132206, theta=-40.343666 -> V=1.0, theta=0.0
% INFO    : Bus 18189	: V=1.0151304, theta=-39.517934 -> V=1.0, theta=0.0
% INFO    : Bus 18190	: V=1.0080896, theta=-40.560219 -> V=1.0, theta=0.0
% INFO    : Bus 18191	: V=1.006767, theta=-41.185886 -> V=1.0, theta=0.0
% INFO    : Bus 18192	: V=0.9847435, theta=-44.085509 -> V=1.0, theta=0.0
% INFO    : Bus 18193	: V=1.0001103, theta=-42.63146 -> V=1.0, theta=0.0
% INFO    : Bus 18194	: V=0.9915769, theta=-43.479429 -> V=1.0, theta=0.0
% INFO    : Bus 18195	: V=0.9878101, theta=-43.816725 -> V=1.0, theta=0.0
% INFO    : Bus 18196	: V=0.9870389, theta=-43.858397 -> V=1.0, theta=0.0
% INFO    : Bus 18197	: V=0.9779873, theta=-44.927319 -> V=1.0, theta=0.0
% INFO    : Bus 18198	: V=0.979057, theta=-44.853042 -> V=1.0, theta=0.0
% INFO    : Bus 18199	: V=0.9988137, theta=-42.877759 -> V=1.0, theta=0.0
% INFO    : Bus 18200	: V=1.0109944, theta=-41.8338 -> V=1.0, theta=0.0
% INFO    : Bus 18201	: V=1.0175363, theta=-41.34527 -> V=1.0, theta=0.0
% INFO    : Bus 18202	: V=1.0072697, theta=-42.135502 -> V=1.0, theta=0.0
% INFO    : Bus 18203	: V=0.9982235, theta=-41.518543 -> V=1.0, theta=0.0
% INFO    : Bus 18204	: V=1.015153, theta=-43.483643 -> V=1.0, theta=0.0
% INFO    : Bus 18205	: V=1.0127462, theta=-42.269132 -> V=1.0, theta=0.0
% INFO    : Bus 18206	: V=1.002696, theta=-42.690498 -> V=1.0, theta=0.0
% INFO    : Bus 18207	: V=1.0132815, theta=-42.991119 -> V=1.0, theta=0.0
% INFO    : Bus 18208	: V=1.0106552, theta=-43.679915 -> V=1.0, theta=0.0
% INFO    : Bus 18209	: V=1.0154821, theta=-41.923815 -> V=1.0, theta=0.0
% INFO    : Bus 18210	: V=1.0142891, theta=-41.446287 -> V=1.0, theta=0.0
% INFO    : Bus 18211	: V=0.9642204, theta=-50.084841 -> V=1.0, theta=0.0
% INFO    : Bus 18212	: V=0.972318, theta=-48.916798 -> V=1.0, theta=0.0
% INFO    : Bus 18213	: V=0.9683346, theta=-49.90638 -> V=1.0, theta=0.0
% INFO    : Bus 18214	: V=0.9732115, theta=-48.727561 -> V=1.0, theta=0.0
% INFO    : Bus 18215	: V=0.9518304, theta=-51.61962 -> V=1.0, theta=0.0
% INFO    : Bus 18216	: V=0.9674623, theta=-49.199591 -> V=1.0, theta=0.0
% INFO    : Bus 18217	: V=0.9447771, theta=-51.93648 -> V=1.0, theta=0.0
% INFO    : Bus 18218	: V=1.0198129, theta=-37.504678 -> V=1.0, theta=0.0
% INFO    : Bus 18219	: V=1.0197912, theta=-37.491416 -> V=1.0, theta=0.0
% INFO    : Bus 18220	: V=1.0196421, theta=-37.418602 -> V=1.0, theta=0.0
% INFO    : Bus 18221	: V=1.0141839, theta=-38.315779 -> V=1.0, theta=0.0
% INFO    : Bus 18222	: V=1.0133462, theta=-38.302234 -> V=1.0, theta=0.0
% INFO    : Bus 18223	: V=1.0071383, theta=-38.088869 -> V=1.0, theta=0.0
% INFO    : Bus 18224	: V=0.979039, theta=-43.120715 -> V=1.0, theta=0.0
% INFO    : Bus 18225	: V=0.9803249, theta=-42.992554 -> V=1.0, theta=0.0
% INFO    : Bus 18226	: V=0.9866513, theta=-42.285182 -> V=1.0, theta=0.0
% INFO    : Bus 18227	: V=0.9842996, theta=-42.444142 -> V=1.0, theta=0.0
% INFO    : Bus 18228	: V=0.9767807, theta=-42.86291 -> V=1.0, theta=0.0
% INFO    : Bus 18229	: V=0.981618, theta=-42.652501 -> V=1.0, theta=0.0
% INFO    : Bus 18230	: V=0.9826815, theta=-42.562904 -> V=1.0, theta=0.0
% INFO    : Bus 18231	: V=1.0100594, theta=-40.327758 -> V=1.0, theta=0.0
% INFO    : Bus 18232	: V=1.0198812, theta=-37.478575 -> V=1.0, theta=0.0
% INFO    : Bus 18233	: V=1.006505, theta=-40.382218 -> V=1.0, theta=0.0
% INFO    : Bus 18234	: V=0.995865, theta=-41.734235 -> V=1.0, theta=0.0
% INFO    : Bus 18235	: V=0.9952498, theta=-41.734865 -> V=1.0, theta=0.0
% INFO    : Bus 18236	: V=1.0080358, theta=-39.944652 -> V=1.0, theta=0.0
% INFO    : Bus 18237	: V=0.9942995, theta=-41.385595 -> V=1.0, theta=0.0
% INFO    : Bus 18238	: V=0.9957044, theta=-40.559132 -> V=1.0, theta=0.0
% INFO    : Bus 18239	: V=1.0039336, theta=-39.723718 -> V=1.0, theta=0.0
% INFO    : Bus 18240	: V=1.0028959, theta=-39.824289 -> V=1.0, theta=0.0
% INFO    : Bus 18241	: V=0.9941692, theta=-40.86886 -> V=1.0, theta=0.0
% INFO    : Bus 18242	: V=0.9965337, theta=-40.550752 -> V=1.0, theta=0.0
% INFO    : Bus 18243	: V=1.0097116, theta=-39.081346 -> V=1.0, theta=0.0
% INFO    : Bus 18244	: V=1.0123146, theta=-38.236978 -> V=1.0, theta=0.0
% INFO    : Bus 18245	: V=0.9986993, theta=-39.387236 -> V=1.0, theta=0.0
% INFO    : Bus 18246	: V=0.9920167, theta=-40.807691 -> V=1.0, theta=0.0
% INFO    : Bus 18247	: V=0.9887295, theta=-40.846249 -> V=1.0, theta=0.0
% INFO    : Bus 18248	: V=0.9845486, theta=-41.508671 -> V=1.0, theta=0.0
% INFO    : Bus 18249	: V=1.0003093, theta=-40.839815 -> V=1.0, theta=0.0
% INFO    : Bus 18250	: V=0.9986513, theta=-40.928513 -> V=1.0, theta=0.0
% INFO    : Bus 18251	: V=1.0012173, theta=-40.773361 -> V=1.0, theta=0.0
% INFO    : Bus 18252	: V=0.9942942, theta=-41.749569 -> V=1.0, theta=0.0
% INFO    : Bus 18253	: V=0.979009, theta=-42.695562 -> V=1.0, theta=0.0
% INFO    : Bus 18254	: V=0.9889389, theta=-41.566808 -> V=1.0, theta=0.0
% INFO    : Bus 18255	: V=0.9904265, theta=-41.555385 -> V=1.0, theta=0.0
% INFO    : Bus 18256	: V=0.9919826, theta=-41.512731 -> V=1.0, theta=0.0
% INFO    : Bus 18257	: V=0.9907984, theta=-41.566908 -> V=1.0, theta=0.0
% INFO    : Bus 18258	: V=0.9887384, theta=-41.979939 -> V=1.0, theta=0.0
% INFO    : Bus 18259	: V=0.9956344, theta=-41.114648 -> V=1.0, theta=0.0
% INFO    : Bus 18260	: V=1.0066735, theta=-39.782095 -> V=1.0, theta=0.0
% INFO    : Bus 18261	: V=0.9778266, theta=-42.328676 -> V=1.0, theta=0.0
% INFO    : Bus 18262	: V=1.0001454, theta=-39.956468 -> V=1.0, theta=0.0
% INFO    : Bus 18263	: V=0.993449, theta=-41.166421 -> V=1.0, theta=0.0
% INFO    : Bus 18264	: V=0.9784376, theta=-43.242415 -> V=1.0, theta=0.0
% INFO    : Bus 18265	: V=0.9788706, theta=-43.137692 -> V=1.0, theta=0.0
% INFO    : Bus 18266	: V=0.9778735, theta=-42.852866 -> V=1.0, theta=0.0
% INFO    : Bus 18267	: V=0.9677661, theta=-43.326377 -> V=1.0, theta=0.0
% INFO    : Bus 18268	: V=0.9721887, theta=-43.687011 -> V=1.0, theta=0.0
% INFO    : Bus 18269	: V=0.9823568, theta=-42.016353 -> V=1.0, theta=0.0
% INFO    : Bus 18270	: V=0.9853665, theta=-42.571093 -> V=1.0, theta=0.0
% INFO    : Bus 18271	: V=0.9759745, theta=-43.389563 -> V=1.0, theta=0.0
% INFO    : Bus 18272	: V=0.988348, theta=-42.305172 -> V=1.0, theta=0.0
% INFO    : Bus 18273	: V=0.980301, theta=-42.873188 -> V=1.0, theta=0.0
% INFO    : Bus 18274	: V=0.9680383, theta=-43.962982 -> V=1.0, theta=0.0
% INFO    : Bus 18275	: V=0.9732169, theta=-43.649698 -> V=1.0, theta=0.0
% INFO    : Bus 18276	: V=0.9685344, theta=-43.491917 -> V=1.0, theta=0.0
% INFO    : Bus 18277	: V=0.9681184, theta=-43.532594 -> V=1.0, theta=0.0
% INFO    : Bus 18278	: V=0.9707162, theta=-43.542808 -> V=1.0, theta=0.0
% INFO    : Bus 18279	: V=0.9708238, theta=-43.548566 -> V=1.0, theta=0.0
% INFO    : Bus 18280	: V=0.9739856, theta=-43.522136 -> V=1.0, theta=0.0
% INFO    : Bus 18281	: V=0.975708, theta=-42.87245 -> V=1.0, theta=0.0
% INFO    : Bus 18282	: V=0.9699895, theta=-42.99387 -> V=1.0, theta=0.0
% INFO    : Bus 18283	: V=0.9708953, theta=-42.985027 -> V=1.0, theta=0.0
% INFO    : Bus 18284	: V=0.9721067, theta=-43.699857 -> V=1.0, theta=0.0
% INFO    : Bus 18285	: V=0.9718685, theta=-43.707528 -> V=1.0, theta=0.0
% INFO    : Bus 18286	: V=0.9718496, theta=-43.432712 -> V=1.0, theta=0.0
% INFO    : Bus 18287	: V=0.9783166, theta=-42.500069 -> V=1.0, theta=0.0
% INFO    : Bus 18288	: V=0.9786869, theta=-42.344675 -> V=1.0, theta=0.0
% INFO    : Bus 18289	: V=0.9782467, theta=-42.404484 -> V=1.0, theta=0.0
% INFO    : Bus 18290	: V=0.978053, theta=-42.447146 -> V=1.0, theta=0.0
% INFO    : Bus 18291	: V=0.9683881, theta=-43.008899 -> V=1.0, theta=0.0
% INFO    : Bus 18292	: V=0.9688604, theta=-43.207337 -> V=1.0, theta=0.0
% INFO    : Bus 18293	: V=0.9683633, theta=-43.159657 -> V=1.0, theta=0.0
% INFO    : Bus 18294	: V=0.9681358, theta=-43.127722 -> V=1.0, theta=0.0
% INFO    : Bus 18295	: V=0.9892594, theta=-54.704825 -> V=1.0, theta=0.0
% INFO    : Bus 18296	: V=0.9915897, theta=-54.151678 -> V=1.0, theta=0.0
% INFO    : Bus 18297	: V=0.9856926, theta=-54.623454 -> V=1.0, theta=0.0
% INFO    : Bus 18298	: V=0.9769204, theta=-47.283239 -> V=1.0, theta=0.0
% INFO    : Bus 18299	: V=0.9959419, theta=-47.363392 -> V=1.0, theta=0.0
% INFO    : Bus 18300	: V=1.0049658, theta=-46.648103 -> V=1.0, theta=0.0
% INFO    : Bus 18301	: V=1.0058378, theta=-46.334363 -> V=1.0, theta=0.0
% INFO    : Bus 18302	: V=1.0015187, theta=-46.839355 -> V=1.0, theta=0.0
% INFO    : Bus 18303	: V=1.0053966, theta=-46.405303 -> V=1.0, theta=0.0
% INFO    : Bus 18304	: V=1.0122085, theta=-45.538835 -> V=1.0, theta=0.0
% INFO    : Bus 18305	: V=1.0180386, theta=-43.567504 -> V=1.0, theta=0.0
% INFO    : Bus 18306	: V=1.0142609, theta=-44.685061 -> V=1.0, theta=0.0
% INFO    : Bus 18307	: V=1.0074774, theta=-40.515248 -> V=1.0, theta=0.0
% INFO    : Bus 18308	: V=1.006905, theta=-40.556648 -> V=1.0, theta=0.0
% INFO    : Bus 18309	: V=0.9511453, theta=-48.692944 -> V=1.0, theta=0.0
% INFO    : Bus 18310	: V=0.9536347, theta=-46.971437 -> V=1.0, theta=0.0
% INFO    : Bus 18311	: V=0.961838, theta=-46.730996 -> V=1.0, theta=0.0
% INFO    : Bus 18312	: V=0.9635733, theta=-47.566673 -> V=1.0, theta=0.0
% INFO    : Bus 18313	: V=0.9960455, theta=-40.212232 -> V=1.0, theta=0.0
% INFO    : Bus 18314	: V=0.9585565, theta=-42.789542 -> V=1.0, theta=0.0
% INFO    : Bus 18315	: V=0.970443, theta=-41.992374 -> V=1.0, theta=0.0
% INFO    : Bus 18316	: V=0.9754623, theta=-41.578474 -> V=1.0, theta=0.0
% INFO    : Bus 18317	: V=0.9932686, theta=-39.944993 -> V=1.0, theta=0.0
% INFO    : Bus 18318	: V=0.995861, theta=-40.030976 -> V=1.0, theta=0.0
% INFO    : Bus 18319	: V=1.00031, theta=-44.785147 -> V=1.0, theta=0.0
% INFO    : Bus 18320	: V=0.9818434, theta=-46.284928 -> V=1.0, theta=0.0
% INFO    : Bus 18321	: V=0.9769019, theta=-46.869724 -> V=1.0, theta=0.0
% INFO    : Bus 18322	: V=0.96364, theta=-53.566957 -> V=1.0, theta=0.0
% INFO    : Bus 18323	: V=0.9574531, theta=-54.303845 -> V=1.0, theta=0.0
% INFO    : Bus 18324	: V=0.9620637, theta=-53.563086 -> V=1.0, theta=0.0
% INFO    : Bus 18325	: V=0.9618966, theta=-53.597566 -> V=1.0, theta=0.0
% INFO    : Bus 18326	: V=0.9634321, theta=-53.500205 -> V=1.0, theta=0.0
% INFO    : Bus 18327	: V=0.975153, theta=-51.877498 -> V=1.0, theta=0.0
% INFO    : Bus 18328	: V=0.962584, theta=-53.503289 -> V=1.0, theta=0.0
% INFO    : Bus 18329	: V=0.9795007, theta=-51.5047 -> V=1.0, theta=0.0
% INFO    : Bus 18330	: V=0.9772881, theta=-51.69604 -> V=1.0, theta=0.0
% INFO    : Bus 18331	: V=0.9684117, theta=-52.828114 -> V=1.0, theta=0.0
% INFO    : Bus 18332	: V=0.9735434, theta=-52.01134 -> V=1.0, theta=0.0
% INFO    : Bus 18333	: V=0.9678036, theta=-52.839699 -> V=1.0, theta=0.0
% INFO    : Bus 18334	: V=0.9739861, theta=-51.849562 -> V=1.0, theta=0.0
% INFO    : Bus 18335	: V=0.9820875, theta=-50.7688 -> V=1.0, theta=0.0
% INFO    : Bus 18336	: V=0.9652715, theta=-53.604316 -> V=1.0, theta=0.0
% INFO    : Bus 18337	: V=0.958694, theta=-54.398809 -> V=1.0, theta=0.0
% INFO    : Bus 18338	: V=0.9587988, theta=-54.360288 -> V=1.0, theta=0.0
% INFO    : Bus 18339	: V=0.9590795, theta=-54.310762 -> V=1.0, theta=0.0
% INFO    : Bus 18340	: V=0.9642117, theta=-53.652933 -> V=1.0, theta=0.0
% INFO    : Bus 18341	: V=0.9620043, theta=-53.822947 -> V=1.0, theta=0.0
% INFO    : Bus 18342	: V=0.9571085, theta=-54.529782 -> V=1.0, theta=0.0
% INFO    : Bus 18343	: V=0.962137, theta=-53.794568 -> V=1.0, theta=0.0
% INFO    : Bus 18344	: V=0.9623712, theta=-53.754882 -> V=1.0, theta=0.0
% INFO    : Bus 18345	: V=0.9627541, theta=-53.696728 -> V=1.0, theta=0.0
% INFO    : Bus 18346	: V=0.9650437, theta=-53.550398 -> V=1.0, theta=0.0
% INFO    : Bus 18347	: V=0.9607397, theta=-54.00147 -> V=1.0, theta=0.0
% INFO    : Bus 18348	: V=0.9618299, theta=-53.442086 -> V=1.0, theta=0.0
% INFO    : Bus 18349	: V=0.9664715, theta=-53.430038 -> V=1.0, theta=0.0
% INFO    : Bus 18350	: V=0.9730058, theta=-52.247803 -> V=1.0, theta=0.0
% INFO    : Bus 18351	: V=0.9632775, theta=-53.268628 -> V=1.0, theta=0.0
% INFO    : Bus 18352	: V=0.9656375, theta=-52.945235 -> V=1.0, theta=0.0
% INFO    : Bus 18353	: V=0.9640694, theta=-53.247863 -> V=1.0, theta=0.0
% INFO    : Bus 18354	: V=0.9618279, theta=-53.463354 -> V=1.0, theta=0.0
% INFO    : Bus 18355	: V=0.9651291, theta=-53.368525 -> V=1.0, theta=0.0
% INFO    : Bus 18356	: V=0.9672413, theta=-53.086694 -> V=1.0, theta=0.0
% INFO    : Bus 18357	: V=0.9735372, theta=-52.015476 -> V=1.0, theta=0.0
% INFO    : Bus 18358	: V=0.9734445, theta=-52.023172 -> V=1.0, theta=0.0
% INFO    : Bus 18359	: V=0.9669078, theta=-53.015471 -> V=1.0, theta=0.0
% INFO    : Bus 18360	: V=0.9743154, theta=-51.928353 -> V=1.0, theta=0.0
% INFO    : Bus 18361	: V=0.9682312, theta=-52.698433 -> V=1.0, theta=0.0
% INFO    : Bus 18362	: V=0.9782731, theta=-51.486843 -> V=1.0, theta=0.0
% INFO    : Bus 18363	: V=0.9793268, theta=-51.373659 -> V=1.0, theta=0.0
% INFO    : Bus 18364	: V=0.9820928, theta=-51.020958 -> V=1.0, theta=0.0
% INFO    : Bus 18365	: V=0.9816948, theta=-51.187359 -> V=1.0, theta=0.0
% INFO    : Bus 18366	: V=0.9848904, theta=-50.738235 -> V=1.0, theta=0.0
% INFO    : Bus 18367	: V=0.9667572, theta=-53.357489 -> V=1.0, theta=0.0
% INFO    : Bus 18368	: V=0.968515, theta=-53.019842 -> V=1.0, theta=0.0
% INFO    : Bus 18369	: V=0.9615413, theta=-53.430811 -> V=1.0, theta=0.0
% INFO    : Bus 18370	: V=0.9615052, theta=-53.412864 -> V=1.0, theta=0.0
% INFO    : Bus 18371	: V=0.9584496, theta=-54.325494 -> V=1.0, theta=0.0
% INFO    : Bus 18372	: V=0.9665423, theta=-53.375537 -> V=1.0, theta=0.0
% INFO    : Bus 18373	: V=0.9616028, theta=-53.884166 -> V=1.0, theta=0.0
% INFO    : Bus 18374	: V=0.966236, theta=-53.369476 -> V=1.0, theta=0.0
% INFO    : Bus 18375	: V=0.9608363, theta=-53.939684 -> V=1.0, theta=0.0
% INFO    : Bus 18376	: V=0.9610676, theta=-53.89797 -> V=1.0, theta=0.0
% INFO    : Bus 18377	: V=0.9684478, theta=-52.83782 -> V=1.0, theta=0.0
% INFO    : Bus 18378	: V=0.9646973, theta=-53.679371 -> V=1.0, theta=0.0
% INFO    : Bus 18379	: V=0.9650708, theta=-53.645763 -> V=1.0, theta=0.0
% INFO    : Bus 18380	: V=0.9657555, theta=-53.538544 -> V=1.0, theta=0.0
% INFO    : Bus 18381	: V=0.967218, theta=-53.0394 -> V=1.0, theta=0.0
% INFO    : Bus 18382	: V=0.9665105, theta=-53.059132 -> V=1.0, theta=0.0
% INFO    : Bus 18383	: V=0.9704582, theta=-52.651558 -> V=1.0, theta=0.0
% INFO    : Bus 18384	: V=0.9661898, theta=-53.17184 -> V=1.0, theta=0.0
% INFO    : Bus 18385	: V=0.9697581, theta=-52.753373 -> V=1.0, theta=0.0
% INFO    : Bus 18386	: V=0.9706654, theta=-52.638022 -> V=1.0, theta=0.0
% INFO    : Bus 18387	: V=0.9738392, theta=-52.103226 -> V=1.0, theta=0.0
% INFO    : Bus 18388	: V=0.9684868, theta=-52.966452 -> V=1.0, theta=0.0
% INFO    : Bus 18389	: V=0.9684737, theta=-52.958992 -> V=1.0, theta=0.0
% INFO    : Bus 18390	: V=0.9776271, theta=-51.591659 -> V=1.0, theta=0.0
% INFO    : Bus 18391	: V=0.9664634, theta=-53.330472 -> V=1.0, theta=0.0
% INFO    : Bus 18392	: V=0.9651307, theta=-53.509765 -> V=1.0, theta=0.0
% INFO    : Bus 18393	: V=0.9650598, theta=-53.380644 -> V=1.0, theta=0.0
% INFO    : Bus 18394	: V=0.9677426, theta=-53.202535 -> V=1.0, theta=0.0
% INFO    : Bus 18395	: V=0.9685299, theta=-53.080642 -> V=1.0, theta=0.0
% INFO    : Bus 18396	: V=0.9618007, theta=-53.87867 -> V=1.0, theta=0.0
% INFO    : Bus 18397	: V=0.9677295, theta=-53.144894 -> V=1.0, theta=0.0
% INFO    : Bus 18398	: V=0.9783205, theta=-51.635051 -> V=1.0, theta=0.0
% INFO    : Bus 18399	: V=0.9712581, theta=-52.598381 -> V=1.0, theta=0.0
% INFO    : Bus 18400	: V=0.9722325, theta=-52.442607 -> V=1.0, theta=0.0
% INFO    : Bus 18401	: V=0.9743692, theta=-52.05672 -> V=1.0, theta=0.0
% INFO    : Bus 18402	: V=0.9708483, theta=-52.156511 -> V=1.0, theta=0.0
% INFO    : Bus 18403	: V=0.9701586, theta=-52.161762 -> V=1.0, theta=0.0
% INFO    : Bus 18404	: V=0.9720669, theta=-52.069893 -> V=1.0, theta=0.0
% INFO    : Bus 18405	: V=0.9884141, theta=-49.753276 -> V=1.0, theta=0.0
% INFO    : Bus 18406	: V=0.960212, theta=-54.33765 -> V=1.0, theta=0.0
% INFO    : Bus 18407	: V=0.9576961, theta=-54.708465 -> V=1.0, theta=0.0
% INFO    : Bus 18408	: V=0.9591017, theta=-54.46356 -> V=1.0, theta=0.0
% INFO    : Bus 18409	: V=0.9597573, theta=-54.31031 -> V=1.0, theta=0.0
% INFO    : Bus 18410	: V=0.9587963, theta=-54.207608 -> V=1.0, theta=0.0
% INFO    : Bus 18411	: V=0.956001, theta=-54.642551 -> V=1.0, theta=0.0
% INFO    : Bus 18412	: V=0.9523752, theta=-55.188858 -> V=1.0, theta=0.0
% INFO    : Bus 18413	: V=0.9635369, theta=-53.738743 -> V=1.0, theta=0.0
% INFO    : Bus 18414	: V=0.9624309, theta=-53.907133 -> V=1.0, theta=0.0
% INFO    : Bus 18415	: V=0.9616284, theta=-54.018773 -> V=1.0, theta=0.0
% INFO    : Bus 18416	: V=0.9564558, theta=-54.884428 -> V=1.0, theta=0.0
% INFO    : Bus 18417	: V=0.9567795, theta=-54.831535 -> V=1.0, theta=0.0
% INFO    : Bus 18418	: V=0.9565634, theta=-54.89027 -> V=1.0, theta=0.0
% INFO    : Bus 18419	: V=0.9569231, theta=-54.820172 -> V=1.0, theta=0.0
% INFO    : Bus 18420	: V=0.9567964, theta=-54.830353 -> V=1.0, theta=0.0
% INFO    : Bus 18421	: V=0.9574977, theta=-54.685443 -> V=1.0, theta=0.0
% INFO    : Bus 18422	: V=0.9569999, theta=-54.773558 -> V=1.0, theta=0.0
% INFO    : Bus 18423	: V=0.9592603, theta=-54.346628 -> V=1.0, theta=0.0
% INFO    : Bus 18424	: V=0.9589118, theta=-54.371655 -> V=1.0, theta=0.0
% INFO    : Bus 18425	: V=0.9538653, theta=-55.018591 -> V=1.0, theta=0.0
% INFO    : Bus 18426	: V=0.9537365, theta=-55.102178 -> V=1.0, theta=0.0
% INFO    : Bus 18427	: V=0.9546507, theta=-55.007682 -> V=1.0, theta=0.0
% INFO    : Bus 18428	: V=0.9551386, theta=-54.992715 -> V=1.0, theta=0.0
% INFO    : Bus 18429	: V=0.9547279, theta=-55.097588 -> V=1.0, theta=0.0
% INFO    : Bus 18430	: V=0.9543266, theta=-55.217849 -> V=1.0, theta=0.0
% INFO    : Bus 18431	: V=0.9523976, theta=-55.455695 -> V=1.0, theta=0.0
% INFO    : Bus 18432	: V=0.9541536, theta=-55.289851 -> V=1.0, theta=0.0
% INFO    : Bus 18433	: V=0.9686516, theta=-53.579354 -> V=1.0, theta=0.0
% INFO    : Bus 18434	: V=0.9573404, theta=-55.065403 -> V=1.0, theta=0.0
% INFO    : Bus 18435	: V=0.956629, theta=-55.087059 -> V=1.0, theta=0.0
% INFO    : Bus 18436	: V=0.9583289, theta=-54.632883 -> V=1.0, theta=0.0
% INFO    : Bus 18437	: V=0.9562011, theta=-54.788312 -> V=1.0, theta=0.0
% INFO    : Bus 18438	: V=0.9601007, theta=-54.32687 -> V=1.0, theta=0.0
% INFO    : Bus 18439	: V=0.9614872, theta=-54.10371 -> V=1.0, theta=0.0
% INFO    : Bus 18440	: V=0.9626201, theta=-53.959122 -> V=1.0, theta=0.0
% INFO    : Bus 18441	: V=0.952344, theta=-55.014859 -> V=1.0, theta=0.0
% INFO    : Bus 18442	: V=0.9526229, theta=-55.024315 -> V=1.0, theta=0.0
% INFO    : Bus 18443	: V=0.9517395, theta=-55.041445 -> V=1.0, theta=0.0
% INFO    : Bus 18444	: V=0.9637014, theta=-53.814504 -> V=1.0, theta=0.0
% INFO    : Bus 18445	: V=0.9627279, theta=-53.951406 -> V=1.0, theta=0.0
% INFO    : Bus 18446	: V=0.959402, theta=-54.376203 -> V=1.0, theta=0.0
% INFO    : Bus 18447	: V=0.9648653, theta=-53.667873 -> V=1.0, theta=0.0
% INFO    : Bus 18448	: V=0.9571815, theta=-55.00735 -> V=1.0, theta=0.0
% INFO    : Bus 18449	: V=0.9618107, theta=-54.172939 -> V=1.0, theta=0.0
% INFO    : Bus 18450	: V=0.9613485, theta=-54.274133 -> V=1.0, theta=0.0
% INFO    : Bus 18451	: V=0.9516052, theta=-56.094327 -> V=1.0, theta=0.0
% INFO    : Bus 18452	: V=0.9566747, theta=-55.233196 -> V=1.0, theta=0.0
% INFO    : Bus 18453	: V=0.9526465, theta=-55.790042 -> V=1.0, theta=0.0
% INFO    : Bus 18454	: V=0.9545754, theta=-55.540126 -> V=1.0, theta=0.0
% INFO    : Bus 18455	: V=0.9545332, theta=-55.366448 -> V=1.0, theta=0.0
% INFO    : Bus 18456	: V=0.9551763, theta=-55.196773 -> V=1.0, theta=0.0
% INFO    : Bus 18457	: V=0.9483795, theta=-55.709361 -> V=1.0, theta=0.0
% INFO    : Bus 18458	: V=0.9487708, theta=-55.744415 -> V=1.0, theta=0.0
% INFO    : Bus 18459	: V=0.9561001, theta=-55.122034 -> V=1.0, theta=0.0
% INFO    : Bus 18460	: V=0.9551663, theta=-55.302563 -> V=1.0, theta=0.0
% INFO    : Bus 18461	: V=0.95467, theta=-55.434077 -> V=1.0, theta=0.0
% INFO    : Bus 18462	: V=0.9517942, theta=-55.772258 -> V=1.0, theta=0.0
% INFO    : Bus 18463	: V=0.9568098, theta=-55.020555 -> V=1.0, theta=0.0
% INFO    : Bus 18464	: V=0.952274, theta=-55.614462 -> V=1.0, theta=0.0
% INFO    : Bus 18465	: V=0.9587076, theta=-54.541236 -> V=1.0, theta=0.0
% INFO    : Bus 18466	: V=0.9579002, theta=-54.78766 -> V=1.0, theta=0.0
% INFO    : Bus 18467	: V=0.9580146, theta=-54.771833 -> V=1.0, theta=0.0
% INFO    : Bus 18468	: V=0.9569605, theta=-54.837776 -> V=1.0, theta=0.0
% INFO    : Bus 18469	: V=0.9582996, theta=-54.756449 -> V=1.0, theta=0.0
% INFO    : Bus 18470	: V=0.9524828, theta=-55.4591 -> V=1.0, theta=0.0
% INFO    : Bus 18471	: V=0.9519682, theta=-55.479321 -> V=1.0, theta=0.0
% INFO    : Bus 18472	: V=0.9587689, theta=-54.636483 -> V=1.0, theta=0.0
% INFO    : Bus 18473	: V=0.9520622, theta=-55.416081 -> V=1.0, theta=0.0
% INFO    : Bus 18474	: V=0.9533488, theta=-55.982146 -> V=1.0, theta=0.0
% INFO    : Bus 18475	: V=0.9472747, theta=-56.44647 -> V=1.0, theta=0.0
% INFO    : Bus 18476	: V=0.9469671, theta=-56.541705 -> V=1.0, theta=0.0
% INFO    : Bus 18477	: V=0.9525815, theta=-55.927073 -> V=1.0, theta=0.0
% INFO    : Bus 18478	: V=0.9527749, theta=-55.833894 -> V=1.0, theta=0.0
% INFO    : Bus 18479	: V=0.9484859, theta=-56.273788 -> V=1.0, theta=0.0
% INFO    : Bus 18480	: V=0.9483797, theta=-56.279097 -> V=1.0, theta=0.0
% INFO    : Bus 18481	: V=0.9484946, theta=-56.142366 -> V=1.0, theta=0.0
% INFO    : Bus 18482	: V=0.9487543, theta=-56.03043 -> V=1.0, theta=0.0
% INFO    : Bus 18483	: V=0.9483288, theta=-56.124839 -> V=1.0, theta=0.0
% INFO    : Bus 18484	: V=0.9481836, theta=-56.340357 -> V=1.0, theta=0.0
% INFO    : Bus 18485	: V=0.9531949, theta=-55.719885 -> V=1.0, theta=0.0
% INFO    : Bus 18486	: V=0.9488732, theta=-56.045556 -> V=1.0, theta=0.0
% INFO    : Bus 18487	: V=0.9546416, theta=-55.23678 -> V=1.0, theta=0.0
% INFO    : Bus 18488	: V=0.9499521, theta=-55.913748 -> V=1.0, theta=0.0
% INFO    : Bus 18489	: V=0.9557013, theta=-54.993947 -> V=1.0, theta=0.0
% INFO    : Bus 18490	: V=0.9562917, theta=-54.923467 -> V=1.0, theta=0.0
% INFO    : Bus 18491	: V=0.9526149, theta=-56.666744 -> V=1.0, theta=0.0
% INFO    : Bus 18492	: V=0.9478522, theta=-56.47871 -> V=1.0, theta=0.0
% INFO    : Bus 18493	: V=0.9541149, theta=-55.555701 -> V=1.0, theta=0.0
% INFO    : Bus 18494	: V=0.9471763, theta=-56.455055 -> V=1.0, theta=0.0
% INFO    : Bus 18495	: V=0.9505506, theta=-56.278398 -> V=1.0, theta=0.0
% INFO    : Bus 18496	: V=0.9481894, theta=-56.580507 -> V=1.0, theta=0.0
% INFO    : Bus 18497	: V=0.9479514, theta=-56.741661 -> V=1.0, theta=0.0
% INFO    : Bus 18498	: V=0.9506156, theta=-56.595079 -> V=1.0, theta=0.0
% INFO    : Bus 18499	: V=0.9527891, theta=-56.309127 -> V=1.0, theta=0.0
% INFO    : Bus 18500	: V=0.9517781, theta=-56.447699 -> V=1.0, theta=0.0
% INFO    : Bus 18501	: V=0.9510602, theta=-56.456663 -> V=1.0, theta=0.0
% INFO    : Bus 18502	: V=0.9519747, theta=-56.307577 -> V=1.0, theta=0.0
% INFO    : Bus 18503	: V=0.9541742, theta=-56.208707 -> V=1.0, theta=0.0
% INFO    : Bus 18504	: V=0.9532202, theta=-56.289042 -> V=1.0, theta=0.0
% INFO    : Bus 18505	: V=0.9611177, theta=-55.489518 -> V=1.0, theta=0.0
% INFO    : Bus 18506	: V=0.9722342, theta=-54.6204 -> V=1.0, theta=0.0
% INFO    : Bus 18507	: V=0.9570581, theta=-55.838503 -> V=1.0, theta=0.0
% INFO    : Bus 18508	: V=0.9568461, theta=-55.856565 -> V=1.0, theta=0.0
% INFO    : Bus 18509	: V=0.95997, theta=-55.582317 -> V=1.0, theta=0.0
% INFO    : Bus 18510	: V=0.9632129, theta=-55.051829 -> V=1.0, theta=0.0
% INFO    : Bus 18511	: V=0.9636359, theta=-55.020505 -> V=1.0, theta=0.0
% INFO    : Bus 18512	: V=0.9594928, theta=-55.625927 -> V=1.0, theta=0.0
% INFO    : Bus 18513	: V=0.9581026, theta=-55.646278 -> V=1.0, theta=0.0
% INFO    : Bus 18514	: V=0.9619403, theta=-55.024309 -> V=1.0, theta=0.0
% INFO    : Bus 18515	: V=0.9626712, theta=-55.089123 -> V=1.0, theta=0.0
% INFO    : Bus 18516	: V=0.9621381, theta=-55.125167 -> V=1.0, theta=0.0
% INFO    : Bus 18517	: V=0.9512616, theta=-55.921599 -> V=1.0, theta=0.0
% INFO    : Bus 18518	: V=0.9515091, theta=-55.855643 -> V=1.0, theta=0.0
% INFO    : Bus 18519	: V=0.9521246, theta=-55.706464 -> V=1.0, theta=0.0
% INFO    : Bus 18520	: V=0.9628967, theta=-54.210196 -> V=1.0, theta=0.0
% INFO    : Bus 18521	: V=0.9513416, theta=-55.368617 -> V=1.0, theta=0.0
% INFO    : Bus 18522	: V=0.951454, theta=-56.435637 -> V=1.0, theta=0.0
% INFO    : Bus 18523	: V=0.9496776, theta=-56.430629 -> V=1.0, theta=0.0
% INFO    : Bus 18524	: V=0.9507063, theta=-56.402262 -> V=1.0, theta=0.0
% INFO    : Bus 18525	: V=0.9518885, theta=-56.302045 -> V=1.0, theta=0.0
% INFO    : Bus 18526	: V=0.952393, theta=-56.292767 -> V=1.0, theta=0.0
% INFO    : Bus 18527	: V=0.958832, theta=-55.456977 -> V=1.0, theta=0.0
% INFO    : Bus 18528	: V=0.9593374, theta=-55.469506 -> V=1.0, theta=0.0
% INFO    : Bus 18529	: V=0.9588943, theta=-55.337084 -> V=1.0, theta=0.0
% INFO    : Bus 18530	: V=0.9595979, theta=-55.264904 -> V=1.0, theta=0.0
% INFO    : Bus 18531	: V=0.9503816, theta=-55.956342 -> V=1.0, theta=0.0
% INFO    : Bus 18532	: V=0.9572065, theta=-55.330322 -> V=1.0, theta=0.0
% INFO    : Bus 18533	: V=0.9861424, theta=-52.965071 -> V=1.0, theta=0.0
% INFO    : Bus 18534	: V=0.9578471, theta=-55.55044 -> V=1.0, theta=0.0
% INFO    : Bus 18535	: V=0.9584842, theta=-55.598805 -> V=1.0, theta=0.0
% INFO    : Bus 18536	: V=0.9640125, theta=-54.797261 -> V=1.0, theta=0.0
% INFO    : Bus 18537	: V=0.9662761, theta=-54.558342 -> V=1.0, theta=0.0
% INFO    : Bus 18538	: V=0.9637201, theta=-54.154604 -> V=1.0, theta=0.0
% INFO    : Bus 18539	: V=0.9674869, theta=-53.830734 -> V=1.0, theta=0.0
% INFO    : Bus 18540	: V=0.9861706, theta=-52.554642 -> V=1.0, theta=0.0
% INFO    : Bus 18541	: V=0.9700981, theta=-53.329864 -> V=1.0, theta=0.0
% INFO    : Bus 18542	: V=0.9643678, theta=-53.845769 -> V=1.0, theta=0.0
% INFO    : Bus 18543	: V=0.9644505, theta=-53.996699 -> V=1.0, theta=0.0
% INFO    : Bus 18544	: V=0.9708961, theta=-53.720566 -> V=1.0, theta=0.0
% INFO    : Bus 18545	: V=0.9668398, theta=-53.929644 -> V=1.0, theta=0.0
% INFO    : Bus 18546	: V=0.9710141, theta=-53.54901 -> V=1.0, theta=0.0
% INFO    : Bus 18547	: V=0.9712452, theta=-53.466976 -> V=1.0, theta=0.0
% INFO    : Bus 18548	: V=0.968939, theta=-53.699052 -> V=1.0, theta=0.0
% INFO    : Bus 18549	: V=0.9732859, theta=-52.977793 -> V=1.0, theta=0.0
% INFO    : Bus 18550	: V=0.9720249, theta=-53.277067 -> V=1.0, theta=0.0
% INFO    : Bus 18551	: V=0.9717215, theta=-53.362746 -> V=1.0, theta=0.0
% INFO    : Bus 18552	: V=0.9707627, theta=-53.204466 -> V=1.0, theta=0.0
% INFO    : Bus 18553	: V=0.9714717, theta=-53.075999 -> V=1.0, theta=0.0
% INFO    : Bus 18554	: V=0.9709812, theta=-53.254079 -> V=1.0, theta=0.0
% INFO    : Bus 18555	: V=0.9724807, theta=-52.882591 -> V=1.0, theta=0.0
% INFO    : Bus 18556	: V=0.9718853, theta=-53.060044 -> V=1.0, theta=0.0
% INFO    : Bus 18557	: V=0.9694192, theta=-53.450837 -> V=1.0, theta=0.0
% INFO    : Bus 18558	: V=0.9660609, theta=-53.920145 -> V=1.0, theta=0.0
% INFO    : Bus 18559	: V=0.9676864, theta=-53.969339 -> V=1.0, theta=0.0
% INFO    : Bus 18560	: V=0.966227, theta=-54.024341 -> V=1.0, theta=0.0
% INFO    : Bus 18561	: V=0.963916, theta=-54.042443 -> V=1.0, theta=0.0
% INFO    : Bus 18562	: V=0.9527737, theta=-55.354122 -> V=1.0, theta=0.0
% INFO    : Bus 18563	: V=0.951678, theta=-55.318673 -> V=1.0, theta=0.0
% INFO    : Bus 18564	: V=0.9521344, theta=-55.327363 -> V=1.0, theta=0.0
% INFO    : Bus 18565	: V=0.9641861, theta=-53.964955 -> V=1.0, theta=0.0
% INFO    : Bus 18566	: V=0.9644868, theta=-54.008302 -> V=1.0, theta=0.0
% INFO    : Bus 18567	: V=0.964459, theta=-54.040552 -> V=1.0, theta=0.0
% INFO    : Bus 18568	: V=0.9645543, theta=-54.081109 -> V=1.0, theta=0.0
% INFO    : Bus 18569	: V=0.9685342, theta=-53.238955 -> V=1.0, theta=0.0
% INFO    : Bus 18570	: V=0.9799804, theta=-51.472651 -> V=1.0, theta=0.0
% INFO    : Bus 18571	: V=0.9788728, theta=-51.237457 -> V=1.0, theta=0.0
% INFO    : Bus 18572	: V=0.9760163, theta=-51.788522 -> V=1.0, theta=0.0
% INFO    : Bus 18573	: V=0.9735405, theta=-51.986514 -> V=1.0, theta=0.0
% INFO    : Bus 18574	: V=0.9773617, theta=-51.699052 -> V=1.0, theta=0.0
% INFO    : Bus 18575	: V=0.9793526, theta=-51.458756 -> V=1.0, theta=0.0
% INFO    : Bus 18576	: V=0.9678491, theta=-52.758098 -> V=1.0, theta=0.0
% INFO    : Bus 18577	: V=0.9727886, theta=-52.375039 -> V=1.0, theta=0.0
% INFO    : Bus 18578	: V=0.9677212, theta=-54.539129 -> V=1.0, theta=0.0
% INFO    : Bus 18579	: V=0.9538163, theta=-56.001775 -> V=1.0, theta=0.0
% INFO    : Bus 18580	: V=0.9805806, theta=-53.14025 -> V=1.0, theta=0.0
% INFO    : Bus 18581	: V=0.9878264, theta=-51.950937 -> V=1.0, theta=0.0
% INFO    : Bus 18582	: V=0.9877006, theta=-50.972709 -> V=1.0, theta=0.0
% INFO    : Bus 18583	: V=0.9902515, theta=-49.380338 -> V=1.0, theta=0.0
% INFO    : Bus 18584	: V=0.9954547, theta=-48.460568 -> V=1.0, theta=0.0
% INFO    : Bus 18585	: V=0.9985777, theta=-47.964958 -> V=1.0, theta=0.0
% INFO    : Bus 18586	: V=0.9881369, theta=-50.152571 -> V=1.0, theta=0.0
% INFO    : Bus 18587	: V=0.9870464, theta=-50.256095 -> V=1.0, theta=0.0
% INFO    : Bus 18588	: V=0.9815762, theta=-50.769672 -> V=1.0, theta=0.0
% INFO    : Bus 18589	: V=0.9867879, theta=-50.373647 -> V=1.0, theta=0.0
% INFO    : Bus 18590	: V=0.986689, theta=-50.33671 -> V=1.0, theta=0.0
% INFO    : Bus 18591	: V=0.9989682, theta=-48.204389 -> V=1.0, theta=0.0
% INFO    : Bus 18592	: V=1.0065846, theta=-46.177943 -> V=1.0, theta=0.0
% INFO    : Bus 18593	: V=1.0054542, theta=-46.811581 -> V=1.0, theta=0.0
% INFO    : Bus 18594	: V=1.0068115, theta=-46.915146 -> V=1.0, theta=0.0
% INFO    : Bus 18595	: V=1.0102425, theta=-46.323516 -> V=1.0, theta=0.0
% INFO    : Bus 18596	: V=1.008055, theta=-46.466221 -> V=1.0, theta=0.0
% INFO    : Bus 18597	: V=0.957586, theta=-50.049763 -> V=1.0, theta=0.0
% INFO    : Bus 18598	: V=0.9495912, theta=-49.806818 -> V=1.0, theta=0.0
% INFO    : Bus 18599	: V=0.9504334, theta=-51.729976 -> V=1.0, theta=0.0
% INFO    : Bus 18600	: V=1.0158442, theta=-40.622394 -> V=1.0, theta=0.0
% INFO    : Bus 18601	: V=1.0160248, theta=-40.357207 -> V=1.0, theta=0.0
% INFO    : Bus 18602	: V=1.0151432, theta=-40.278927 -> V=1.0, theta=0.0
% INFO    : Bus 18603	: V=1.0194086, theta=-39.345555 -> V=1.0, theta=0.0
% INFO    : Bus 18604	: V=0.9964786, theta=-43.116549 -> V=1.0, theta=0.0
% INFO    : Bus 18605	: V=0.9869205, theta=-44.561259 -> V=1.0, theta=0.0
% INFO    : Bus 18606	: V=0.9973591, theta=-42.997792 -> V=1.0, theta=0.0
% INFO    : Bus 18607	: V=0.9575046, theta=-47.980848 -> V=1.0, theta=0.0
% INFO    : Bus 18608	: V=0.9628324, theta=-47.641253 -> V=1.0, theta=0.0
% INFO    : Bus 18609	: V=0.9366137, theta=-51.356547 -> V=1.0, theta=0.0
% INFO    : Bus 18610	: V=0.9627997, theta=-47.609803 -> V=1.0, theta=0.0
% INFO    : Bus 18611	: V=0.9916489, theta=-43.634402 -> V=1.0, theta=0.0
% INFO    : Bus 18612	: V=1.0071926, theta=-41.403908 -> V=1.0, theta=0.0
% INFO    : Bus 18613	: V=0.9912491, theta=-42.918761 -> V=1.0, theta=0.0
% INFO    : Bus 18614	: V=0.9821982, theta=-56.40144 -> V=1.0, theta=0.0
% INFO    : Bus 18615	: V=0.9744225, theta=-56.490399 -> V=1.0, theta=0.0
% INFO    : Bus 18616	: V=0.9977708, theta=-55.237459 -> V=1.0, theta=0.0
% INFO    : Bus 18617	: V=1.0075967, theta=-52.885917 -> V=1.0, theta=0.0
% INFO    : Bus 18618	: V=1.005694, theta=-53.363961 -> V=1.0, theta=0.0
% INFO    : Bus 18619	: V=1.0007438, theta=-53.111888 -> V=1.0, theta=0.0
% INFO    : Bus 18620	: V=0.9962646, theta=-53.388116 -> V=1.0, theta=0.0
% INFO    : Bus 18621	: V=0.994024, theta=-53.602147 -> V=1.0, theta=0.0
% INFO    : Bus 18622	: V=0.9928722, theta=-53.734981 -> V=1.0, theta=0.0
% INFO    : Bus 18623	: V=0.9905412, theta=-54.505656 -> V=1.0, theta=0.0
% INFO    : Bus 18624	: V=0.9995685, theta=-53.722032 -> V=1.0, theta=0.0
% INFO    : Bus 18625	: V=0.9860407, theta=-55.509948 -> V=1.0, theta=0.0
% INFO    : Bus 18626	: V=0.984135, theta=-55.68879 -> V=1.0, theta=0.0
% INFO    : Bus 18627	: V=1.0045564, theta=-53.753282 -> V=1.0, theta=0.0
% INFO    : Bus 18628	: V=0.9772548, theta=-48.857444 -> V=1.0, theta=0.0
% INFO    : Bus 18629	: V=0.9858508, theta=-48.330259 -> V=1.0, theta=0.0
% INFO    : Bus 18630	: V=1.015527, theta=-45.54995 -> V=1.0, theta=0.0
% INFO    : Bus 18631	: V=0.9912415, theta=-47.940919 -> V=1.0, theta=0.0
% INFO    : Bus 18632	: V=0.9808808, theta=-43.895473 -> V=1.0, theta=0.0
% INFO    : Bus 18633	: V=0.9916086, theta=-42.623306 -> V=1.0, theta=0.0
% INFO    : Bus 18634	: V=0.9978529, theta=-41.508134 -> V=1.0, theta=0.0
% INFO    : Bus 18635	: V=0.9957762, theta=-42.024126 -> V=1.0, theta=0.0
% INFO    : Bus 18636	: V=1.0098363, theta=-40.399388 -> V=1.0, theta=0.0
% INFO    : Bus 18637	: V=0.9993422, theta=-41.512115 -> V=1.0, theta=0.0
% INFO    : Bus 18638	: V=1.0009361, theta=-41.321667 -> V=1.0, theta=0.0
% INFO    : Bus 18639	: V=1.0083643, theta=-40.760591 -> V=1.0, theta=0.0
% INFO    : Bus 18640	: V=0.9858864, theta=-43.041395 -> V=1.0, theta=0.0
% INFO    : Bus 18641	: V=0.9941182, theta=-42.68348 -> V=1.0, theta=0.0
% INFO    : Bus 18642	: V=0.9944022, theta=-42.571038 -> V=1.0, theta=0.0
% INFO    : Bus 18643	: V=1.0040331, theta=-42.188927 -> V=1.0, theta=0.0
% INFO    : Bus 18644	: V=0.9997071, theta=-42.204976 -> V=1.0, theta=0.0
% INFO    : Bus 18645	: V=0.9656882, theta=-49.962563 -> V=1.0, theta=0.0
% INFO    : Bus 18646	: V=0.9746965, theta=-48.25664 -> V=1.0, theta=0.0
% INFO    : Bus 18647	: V=0.9698249, theta=-48.765728 -> V=1.0, theta=0.0
% INFO    : Bus 18648	: V=0.9669801, theta=-48.92247 -> V=1.0, theta=0.0
% INFO    : Bus 18649	: V=0.9653556, theta=-48.839462 -> V=1.0, theta=0.0
% INFO    : Bus 18650	: V=1.0059864, theta=-44.523124 -> V=1.0, theta=0.0
% INFO    : Bus 18651	: V=1.0182976, theta=-42.335102 -> V=1.0, theta=0.0
% INFO    : Bus 18652	: V=1.0188363, theta=-42.322826 -> V=1.0, theta=0.0
% INFO    : Bus 18653	: V=1.0011678, theta=-40.146733 -> V=1.0, theta=0.0
% INFO    : Bus 18654	: V=0.9926688, theta=-41.217527 -> V=1.0, theta=0.0
% INFO    : Bus 18655	: V=1.0080795, theta=-39.668569 -> V=1.0, theta=0.0
% INFO    : Bus 18656	: V=1.011829, theta=-38.227802 -> V=1.0, theta=0.0
% INFO    : Bus 18657	: V=1.0050839, theta=-40.337406 -> V=1.0, theta=0.0
% INFO    : Bus 18658	: V=0.9881071, theta=-40.699933 -> V=1.0, theta=0.0
% INFO    : Bus 18659	: V=0.9666941, theta=-41.680539 -> V=1.0, theta=0.0
% INFO    : Bus 18660	: V=1.019766, theta=-36.003509 -> V=1.0, theta=0.0
% INFO    : Bus 18661	: V=1.0177277, theta=-37.274128 -> V=1.0, theta=0.0
% INFO    : Bus 18662	: V=1.0142276, theta=-37.991887 -> V=1.0, theta=0.0
% INFO    : Bus 18663	: V=1.0144735, theta=-37.883806 -> V=1.0, theta=0.0
% INFO    : Bus 18664	: V=1.0154286, theta=-37.742285 -> V=1.0, theta=0.0
% INFO    : Bus 18665	: V=1.0154106, theta=-41.125505 -> V=1.0, theta=0.0
% INFO    : Bus 18666	: V=0.9996382, theta=-42.481831 -> V=1.0, theta=0.0
% INFO    : Bus 18667	: V=0.9944781, theta=-42.766476 -> V=1.0, theta=0.0
% INFO    : Bus 18668	: V=0.9895408, theta=-43.178871 -> V=1.0, theta=0.0
% INFO    : Bus 18669	: V=0.9913746, theta=-43.140351 -> V=1.0, theta=0.0
% INFO    : Bus 18670	: V=1.0104304, theta=-41.084128 -> V=1.0, theta=0.0
% INFO    : Bus 18671	: V=0.9914937, theta=-43.147074 -> V=1.0, theta=0.0
% INFO    : Bus 18672	: V=0.9892122, theta=-43.043113 -> V=1.0, theta=0.0
% INFO    : Bus 18673	: V=0.9996227, theta=-42.479067 -> V=1.0, theta=0.0
% INFO    : Bus 18674	: V=1.0115865, theta=-40.498218 -> V=1.0, theta=0.0
% INFO    : Bus 18675	: V=0.9897255, theta=-42.938636 -> V=1.0, theta=0.0
% INFO    : Bus 18676	: V=1.000115, theta=-41.950278 -> V=1.0, theta=0.0
% INFO    : Bus 18677	: V=0.9991723, theta=-41.997439 -> V=1.0, theta=0.0
% INFO    : Bus 18678	: V=0.997568, theta=-42.054013 -> V=1.0, theta=0.0
% INFO    : Bus 18679	: V=0.9969889, theta=-42.05358 -> V=1.0, theta=0.0
% INFO    : Bus 18680	: V=0.9961266, theta=-42.275368 -> V=1.0, theta=0.0
% INFO    : Bus 18681	: V=0.9971088, theta=-41.972432 -> V=1.0, theta=0.0
% INFO    : Bus 18682	: V=0.9868593, theta=-42.870687 -> V=1.0, theta=0.0
% INFO    : Bus 18683	: V=0.9978345, theta=-41.883132 -> V=1.0, theta=0.0
% INFO    : Bus 18684	: V=0.9820319, theta=-43.008419 -> V=1.0, theta=0.0
% INFO    : Bus 18685	: V=0.9960825, theta=-42.538546 -> V=1.0, theta=0.0
% INFO    : Bus 18686	: V=0.9778064, theta=-43.211331 -> V=1.0, theta=0.0
% INFO    : Bus 18687	: V=0.9743508, theta=-43.240992 -> V=1.0, theta=0.0
% INFO    : Bus 18688	: V=0.9789888, theta=-43.712945 -> V=1.0, theta=0.0
% INFO    : Bus 18689	: V=0.977958, theta=-43.775977 -> V=1.0, theta=0.0
% INFO    : Bus 18690	: V=0.9834396, theta=-43.056603 -> V=1.0, theta=0.0
% INFO    : Bus 18691	: V=0.9826187, theta=-43.063643 -> V=1.0, theta=0.0
% INFO    : Bus 18692	: V=0.9826734, theta=-42.973626 -> V=1.0, theta=0.0
% INFO    : Bus 18693	: V=0.9788356, theta=-43.56862 -> V=1.0, theta=0.0
% INFO    : Bus 18694	: V=0.9818718, theta=-43.124194 -> V=1.0, theta=0.0
% INFO    : Bus 18695	: V=0.9833708, theta=-43.115009 -> V=1.0, theta=0.0
% INFO    : Bus 18696	: V=0.9850671, theta=-43.200878 -> V=1.0, theta=0.0
% INFO    : Bus 18697	: V=0.9843034, theta=-43.169696 -> V=1.0, theta=0.0
% INFO    : Bus 18698	: V=0.9840663, theta=-43.18702 -> V=1.0, theta=0.0
% INFO    : Bus 18699	: V=0.9806074, theta=-43.564241 -> V=1.0, theta=0.0
% INFO    : Bus 18700	: V=0.9789256, theta=-43.62919 -> V=1.0, theta=0.0
% INFO    : Bus 18701	: V=0.9816692, theta=-43.150414 -> V=1.0, theta=0.0
% INFO    : Bus 18702	: V=0.9779276, theta=-43.796549 -> V=1.0, theta=0.0
% INFO    : Bus 18703	: V=0.9781596, theta=-43.792096 -> V=1.0, theta=0.0
% INFO    : Bus 18704	: V=0.9835408, theta=-43.15539 -> V=1.0, theta=0.0
% INFO    : Bus 18705	: V=0.9839561, theta=-43.189975 -> V=1.0, theta=0.0
% INFO    : Bus 18706	: V=0.9878618, theta=-43.069377 -> V=1.0, theta=0.0
% INFO    : Bus 18707	: V=0.9903422, theta=-42.931848 -> V=1.0, theta=0.0
% INFO    : Bus 18708	: V=0.98487, theta=-42.925601 -> V=1.0, theta=0.0
% INFO    : Bus 18709	: V=0.9863973, theta=-42.7998 -> V=1.0, theta=0.0
% INFO    : Bus 18710	: V=0.9870672, theta=-42.979266 -> V=1.0, theta=0.0
% INFO    : Bus 18711	: V=0.9834908, theta=-43.29491 -> V=1.0, theta=0.0
% INFO    : Bus 18712	: V=0.9823931, theta=-43.480899 -> V=1.0, theta=0.0
% INFO    : Bus 18713	: V=0.9800258, theta=-43.68775 -> V=1.0, theta=0.0
% INFO    : Bus 18714	: V=0.9833456, theta=-43.385024 -> V=1.0, theta=0.0
% INFO    : Bus 18715	: V=0.9857661, theta=-43.325351 -> V=1.0, theta=0.0
% INFO    : Bus 18716	: V=0.983724, theta=-43.275285 -> V=1.0, theta=0.0
% INFO    : Bus 18717	: V=0.9800587, theta=-43.686739 -> V=1.0, theta=0.0
% INFO    : Bus 18718	: V=0.9886539, theta=-42.626495 -> V=1.0, theta=0.0
% INFO    : Bus 18719	: V=0.9800821, theta=-43.673644 -> V=1.0, theta=0.0
% INFO    : Bus 18720	: V=0.979692, theta=-43.723828 -> V=1.0, theta=0.0
% INFO    : Bus 18721	: V=0.9806129, theta=-43.612977 -> V=1.0, theta=0.0
% INFO    : Bus 18722	: V=0.9843395, theta=-43.237562 -> V=1.0, theta=0.0
% INFO    : Bus 18723	: V=0.9847534, theta=-43.253005 -> V=1.0, theta=0.0
% INFO    : Bus 18724	: V=0.9949228, theta=-42.196126 -> V=1.0, theta=0.0
% INFO    : Bus 18725	: V=0.9894315, theta=-42.564853 -> V=1.0, theta=0.0
% INFO    : Bus 18726	: V=0.9947884, theta=-42.226513 -> V=1.0, theta=0.0
% INFO    : Bus 18727	: V=0.9953884, theta=-42.184829 -> V=1.0, theta=0.0
% INFO    : Bus 18728	: V=0.9950092, theta=-42.225384 -> V=1.0, theta=0.0
% INFO    : Bus 18729	: V=0.9964022, theta=-42.138314 -> V=1.0, theta=0.0
% INFO    : Bus 18730	: V=0.9959206, theta=-42.134289 -> V=1.0, theta=0.0
% INFO    : Bus 18731	: V=0.9933914, theta=-42.397518 -> V=1.0, theta=0.0
% INFO    : Bus 18732	: V=0.9965341, theta=-42.132321 -> V=1.0, theta=0.0
% INFO    : Bus 18733	: V=0.9980489, theta=-42.049727 -> V=1.0, theta=0.0
% INFO    : Bus 18734	: V=0.995539, theta=-42.199966 -> V=1.0, theta=0.0
% INFO    : Bus 18735	: V=0.9906879, theta=-42.910673 -> V=1.0, theta=0.0
% INFO    : Bus 18736	: V=0.9978123, theta=-41.834349 -> V=1.0, theta=0.0
% INFO    : Bus 18737	: V=0.9971851, theta=-41.87184 -> V=1.0, theta=0.0
% INFO    : Bus 18738	: V=0.9991402, theta=-41.656395 -> V=1.0, theta=0.0
% INFO    : Bus 18739	: V=1.0002261, theta=-41.561459 -> V=1.0, theta=0.0
% INFO    : Bus 18740	: V=1.0026046, theta=-41.305205 -> V=1.0, theta=0.0
% INFO    : Bus 18741	: V=0.9995252, theta=-41.692208 -> V=1.0, theta=0.0
% INFO    : Bus 18742	: V=1.0009665, theta=-41.536704 -> V=1.0, theta=0.0
% INFO    : Bus 18743	: V=1.0146148, theta=-39.905101 -> V=1.0, theta=0.0
% INFO    : Bus 18744	: V=0.9878025, theta=-42.718466 -> V=1.0, theta=0.0
% INFO    : Bus 18745	: V=1.0006606, theta=-41.35508 -> V=1.0, theta=0.0
% INFO    : Bus 18746	: V=1.0040095, theta=-41.023566 -> V=1.0, theta=0.0
% INFO    : Bus 18747	: V=1.0060113, theta=-40.419098 -> V=1.0, theta=0.0
% INFO    : Bus 18748	: V=1.0087732, theta=-39.901195 -> V=1.0, theta=0.0
% INFO    : Bus 18749	: V=1.0087061, theta=-39.796567 -> V=1.0, theta=0.0
% INFO    : Bus 18750	: V=0.9989177, theta=-41.56925 -> V=1.0, theta=0.0
% INFO    : Bus 18751	: V=1.003848, theta=-40.904388 -> V=1.0, theta=0.0
% INFO    : Bus 18752	: V=0.977574, theta=-45.103358 -> V=1.0, theta=0.0
% INFO    : Bus 18753	: V=0.9788754, theta=-44.974796 -> V=1.0, theta=0.0
% INFO    : Bus 18754	: V=0.9675548, theta=-46.384961 -> V=1.0, theta=0.0
% INFO    : Bus 18755	: V=0.9849818, theta=-43.31005 -> V=1.0, theta=0.0
% INFO    : Bus 18756	: V=0.9951288, theta=-42.986875 -> V=1.0, theta=0.0
% INFO    : Bus 18757	: V=0.991922, theta=-43.365095 -> V=1.0, theta=0.0
% INFO    : Bus 18758	: V=0.9986351, theta=-42.634187 -> V=1.0, theta=0.0
% INFO    : Bus 18759	: V=0.979048, theta=-44.714239 -> V=1.0, theta=0.0
% INFO    : Bus 18760	: V=0.9773045, theta=-45.440601 -> V=1.0, theta=0.0
% INFO    : Bus 18761	: V=0.9758825, theta=-45.119374 -> V=1.0, theta=0.0
% INFO    : Bus 18762	: V=0.9755831, theta=-45.286371 -> V=1.0, theta=0.0
% INFO    : Bus 18763	: V=0.9969621, theta=-42.852054 -> V=1.0, theta=0.0
% INFO    : Bus 18764	: V=0.9751156, theta=-45.372057 -> V=1.0, theta=0.0
% INFO    : Bus 18765	: V=0.9826442, theta=-44.647263 -> V=1.0, theta=0.0
% INFO    : Bus 18766	: V=1.0098573, theta=-42.368794 -> V=1.0, theta=0.0
% INFO    : Bus 18767	: V=1.005209, theta=-39.492174 -> V=1.0, theta=0.0
% INFO    : Bus 18768	: V=0.9931307, theta=-41.393959 -> V=1.0, theta=0.0
% INFO    : Bus 18769	: V=0.9978549, theta=-40.375641 -> V=1.0, theta=0.0
% INFO    : Bus 18770	: V=1.0086015, theta=-38.818063 -> V=1.0, theta=0.0
% INFO    : Bus 18771	: V=0.9956255, theta=-40.696165 -> V=1.0, theta=0.0
% INFO    : Bus 18772	: V=0.9959642, theta=-41.001322 -> V=1.0, theta=0.0
% INFO    : Bus 18773	: V=0.9963731, theta=-41.263388 -> V=1.0, theta=0.0
% INFO    : Bus 18774	: V=1.0012288, theta=-41.228096 -> V=1.0, theta=0.0
% INFO    : Bus 18775	: V=0.9851594, theta=-41.571361 -> V=1.0, theta=0.0
% INFO    : Bus 18776	: V=0.9892564, theta=-41.507707 -> V=1.0, theta=0.0
% INFO    : Bus 18777	: V=0.9940594, theta=-40.642005 -> V=1.0, theta=0.0
% INFO    : Bus 18778	: V=0.9981772, theta=-40.019009 -> V=1.0, theta=0.0
% INFO    : Bus 18779	: V=1.0003187, theta=-40.314288 -> V=1.0, theta=0.0
% INFO    : Bus 18780	: V=1.0023756, theta=-40.153958 -> V=1.0, theta=0.0
% INFO    : Bus 18781	: V=1.0175743, theta=-37.95339 -> V=1.0, theta=0.0
% INFO    : Bus 18782	: V=0.9909075, theta=-40.964664 -> V=1.0, theta=0.0
% INFO    : Bus 18783	: V=0.9945272, theta=-40.735328 -> V=1.0, theta=0.0
% INFO    : Bus 18784	: V=1.0100314, theta=-39.678692 -> V=1.0, theta=0.0
% INFO    : Bus 18785	: V=1.0196186, theta=-37.094584 -> V=1.0, theta=0.0
% INFO    : Bus 18786	: V=0.9840178, theta=-45.833719 -> V=1.0, theta=0.0
% INFO    : Bus 18787	: V=1.0105497, theta=-41.491818 -> V=1.0, theta=0.0
% INFO    : Bus 18788	: V=1.0081549, theta=-46.916276 -> V=1.0, theta=0.0
% INFO    : Bus 18789	: V=1.0055697, theta=-46.74083 -> V=1.0, theta=0.0
% INFO    : Bus 18790	: V=1.0153633, theta=-44.709965 -> V=1.0, theta=0.0
% INFO    : Bus 18791	: V=1.0105324, theta=-45.626377 -> V=1.0, theta=0.0
% INFO    : Bus 18792	: V=1.0080425, theta=-46.087439 -> V=1.0, theta=0.0
% INFO    : Bus 18793	: V=0.9961793, theta=-42.83797 -> V=1.0, theta=0.0
% INFO    : Bus 18794	: V=0.9967049, theta=-43.264937 -> V=1.0, theta=0.0
% INFO    : Bus 18795	: V=1.0040138, theta=-41.683331 -> V=1.0, theta=0.0
% INFO    : Bus 18796	: V=1.0157152, theta=-40.770028 -> V=1.0, theta=0.0
% INFO    : Bus 18797	: V=0.9901423, theta=-44.411412 -> V=1.0, theta=0.0
% INFO    : Bus 18798	: V=0.9842807, theta=-44.730825 -> V=1.0, theta=0.0
% INFO    : Bus 18799	: V=0.9834024, theta=-44.469026 -> V=1.0, theta=0.0
% INFO    : Bus 18800	: V=0.9380869, theta=-50.649994 -> V=1.0, theta=0.0
% INFO    : Bus 18801	: V=0.9481247, theta=-49.903816 -> V=1.0, theta=0.0
% INFO    : Bus 18802	: V=0.9401727, theta=-52.219229 -> V=1.0, theta=0.0
% INFO    : Bus 18803	: V=0.9322533, theta=-52.739871 -> V=1.0, theta=0.0
% INFO    : Bus 18804	: V=0.932247, theta=-52.713494 -> V=1.0, theta=0.0
% INFO    : Bus 18805	: V=0.9493359, theta=-48.96523 -> V=1.0, theta=0.0
% INFO    : Bus 18806	: V=0.9956757, theta=-54.384382 -> V=1.0, theta=0.0
% INFO    : Bus 18807	: V=0.9949018, theta=-54.359035 -> V=1.0, theta=0.0
% INFO    : Bus 18808	: V=0.9943068, theta=-54.322752 -> V=1.0, theta=0.0
% INFO    : Bus 18809	: V=0.9867281, theta=-55.05239 -> V=1.0, theta=0.0
% INFO    : Bus 18810	: V=0.9939538, theta=-54.303892 -> V=1.0, theta=0.0
% INFO    : Bus 18811	: V=0.9708484, theta=-55.907552 -> V=1.0, theta=0.0
% INFO    : Bus 18812	: V=0.9744238, theta=-55.782617 -> V=1.0, theta=0.0
% INFO    : Bus 18813	: V=0.9730866, theta=-55.808211 -> V=1.0, theta=0.0
% INFO    : Bus 18814	: V=0.9913304, theta=-54.117421 -> V=1.0, theta=0.0
% INFO    : Bus 18815	: V=0.9902619, theta=-54.010552 -> V=1.0, theta=0.0
% INFO    : Bus 18816	: V=0.9764707, theta=-55.002459 -> V=1.0, theta=0.0
% INFO    : Bus 18817	: V=0.9918916, theta=-54.166099 -> V=1.0, theta=0.0
% INFO    : Bus 18818	: V=0.9671643, theta=-55.521117 -> V=1.0, theta=0.0
% INFO    : Bus 18819	: V=0.9726277, theta=-55.766277 -> V=1.0, theta=0.0
% INFO    : Bus 18820	: V=0.9779732, theta=-54.713267 -> V=1.0, theta=0.0
% INFO    : Bus 18821	: V=0.9855617, theta=-54.874088 -> V=1.0, theta=0.0
% INFO    : Bus 18822	: V=0.9932865, theta=-54.271229 -> V=1.0, theta=0.0
% INFO    : Bus 18823	: V=0.9925275, theta=-54.216272 -> V=1.0, theta=0.0
% INFO    : Bus 18824	: V=0.9826736, theta=-54.47315 -> V=1.0, theta=0.0
% INFO    : Bus 18825	: V=0.9756502, theta=-53.917182 -> V=1.0, theta=0.0
% INFO    : Bus 18826	: V=0.9746113, theta=-55.008 -> V=1.0, theta=0.0
% INFO    : Bus 18827	: V=0.9705102, theta=-55.366923 -> V=1.0, theta=0.0
% INFO    : Bus 18828	: V=0.9781874, theta=-54.817001 -> V=1.0, theta=0.0
% INFO    : Bus 18829	: V=0.9783868, theta=-54.854992 -> V=1.0, theta=0.0
% INFO    : Bus 18830	: V=0.9758077, theta=-55.012258 -> V=1.0, theta=0.0
% INFO    : Bus 18831	: V=0.9752916, theta=-55.012338 -> V=1.0, theta=0.0
% INFO    : Bus 18832	: V=0.9739997, theta=-55.310311 -> V=1.0, theta=0.0
% INFO    : Bus 18833	: V=0.9892516, theta=-53.890509 -> V=1.0, theta=0.0
% INFO    : Bus 18834	: V=0.9747686, theta=-55.259645 -> V=1.0, theta=0.0
% INFO    : Bus 18835	: V=0.9884818, theta=-53.780246 -> V=1.0, theta=0.0
% INFO    : Bus 18836	: V=0.9771336, theta=-54.85085 -> V=1.0, theta=0.0
% INFO    : Bus 18837	: V=0.9881024, theta=-53.716104 -> V=1.0, theta=0.0
% INFO    : Bus 18838	: V=0.978555, theta=-54.776239 -> V=1.0, theta=0.0
% INFO    : Bus 18839	: V=0.9701551, theta=-55.642864 -> V=1.0, theta=0.0
% INFO    : Bus 18840	: V=0.9778498, theta=-54.834322 -> V=1.0, theta=0.0
% INFO    : Bus 18841	: V=0.9766754, theta=-54.802186 -> V=1.0, theta=0.0
% INFO    : Bus 18842	: V=0.9612552, theta=-55.469656 -> V=1.0, theta=0.0
% INFO    : Bus 18843	: V=0.962196, theta=-55.528367 -> V=1.0, theta=0.0
% INFO    : Bus 18844	: V=0.9642892, theta=-55.57087 -> V=1.0, theta=0.0
% INFO    : Bus 18845	: V=0.9731686, theta=-54.357205 -> V=1.0, theta=0.0
% INFO    : Bus 18846	: V=0.9698332, theta=-54.23864 -> V=1.0, theta=0.0
% INFO    : Bus 18847	: V=0.9703621, theta=-55.266012 -> V=1.0, theta=0.0
% INFO    : Bus 18848	: V=0.967552, theta=-55.438627 -> V=1.0, theta=0.0
% INFO    : Bus 18849	: V=0.9570225, theta=-56.569241 -> V=1.0, theta=0.0
% INFO    : Bus 18850	: V=0.9535071, theta=-56.647718 -> V=1.0, theta=0.0
% INFO    : Bus 18851	: V=0.953799, theta=-56.598125 -> V=1.0, theta=0.0
% INFO    : Bus 18852	: V=0.966698, theta=-55.493694 -> V=1.0, theta=0.0
% INFO    : Bus 18853	: V=0.9564334, theta=-56.438122 -> V=1.0, theta=0.0
% INFO    : Bus 18854	: V=0.9569101, theta=-56.628609 -> V=1.0, theta=0.0
% INFO    : Bus 18855	: V=0.9542749, theta=-56.646749 -> V=1.0, theta=0.0
% INFO    : Bus 18856	: V=0.9533629, theta=-56.347941 -> V=1.0, theta=0.0
% INFO    : Bus 18857	: V=0.9526041, theta=-56.333362 -> V=1.0, theta=0.0
% INFO    : Bus 18858	: V=0.9648749, theta=-55.508526 -> V=1.0, theta=0.0
% INFO    : Bus 18859	: V=0.9632695, theta=-55.541923 -> V=1.0, theta=0.0
% INFO    : Bus 18860	: V=0.9607424, theta=-55.998247 -> V=1.0, theta=0.0
% INFO    : Bus 18861	: V=0.959216, theta=-56.126743 -> V=1.0, theta=0.0
% INFO    : Bus 18862	: V=0.9621768, theta=-55.478469 -> V=1.0, theta=0.0
% INFO    : Bus 18863	: V=0.9694535, theta=-53.919901 -> V=1.0, theta=0.0
% INFO    : Bus 18864	: V=0.9698109, theta=-53.667847 -> V=1.0, theta=0.0
% INFO    : Bus 18865	: V=0.9693464, theta=-53.72218 -> V=1.0, theta=0.0
% INFO    : Bus 18866	: V=0.9643173, theta=-54.622332 -> V=1.0, theta=0.0
% INFO    : Bus 18867	: V=0.9692581, theta=-53.738535 -> V=1.0, theta=0.0
% INFO    : Bus 18868	: V=0.9713519, theta=-53.188716 -> V=1.0, theta=0.0
% INFO    : Bus 18869	: V=0.968319, theta=-54.388202 -> V=1.0, theta=0.0
% INFO    : Bus 18870	: V=0.9671328, theta=-54.504713 -> V=1.0, theta=0.0
% INFO    : Bus 18871	: V=1.0130547, theta=-42.040249 -> V=1.0, theta=0.0
% INFO    : Bus 18872	: V=1.0182273, theta=-42.198226 -> V=1.0, theta=0.0
% INFO    : Bus 18873	: V=1.0167596, theta=-42.310705 -> V=1.0, theta=0.0
% INFO    : Bus 18874	: V=1.0190159, theta=-42.093862 -> V=1.0, theta=0.0
% INFO    : Bus 18875	: V=1.0122335, theta=-41.213815 -> V=1.0, theta=0.0
% INFO    : Bus 18876	: V=1.0069443, theta=-42.302154 -> V=1.0, theta=0.0
% INFO    : Bus 18877	: V=0.9989, theta=-40.465456 -> V=1.0, theta=0.0
% INFO    : Bus 18878	: V=0.999908, theta=-40.076504 -> V=1.0, theta=0.0
% INFO    : Bus 18879	: V=1.0039282, theta=-39.731612 -> V=1.0, theta=0.0
% INFO    : Bus 18880	: V=1.0018287, theta=-45.122844 -> V=1.0, theta=0.0
% INFO    : Bus 18881	: V=0.9990072, theta=-46.182371 -> V=1.0, theta=0.0
% INFO    : Bus 18882	: V=0.9876597, theta=-43.367854 -> V=1.0, theta=0.0
% INFO    : Bus 18883	: V=1.0004044, theta=-41.856454 -> V=1.0, theta=0.0
% INFO    : Bus 18884	: V=0.9974798, theta=-39.901991 -> V=1.0, theta=0.0
% INFO    : Bus 18885	: V=0.9915364, theta=-39.983977 -> V=1.0, theta=0.0
% INFO    : Bus 18886	: V=1.0110817, theta=-38.538288 -> V=1.0, theta=0.0
% INFO    : Bus 18887	: V=1.0079547, theta=-39.100227 -> V=1.0, theta=0.0
% INFO    : Bus 18888	: V=1.0058932, theta=-39.154625 -> V=1.0, theta=0.0
% INFO    : Bus 18889	: V=1.0088198, theta=-38.600598 -> V=1.0, theta=0.0
% INFO    : Bus 18890	: V=1.0071062, theta=-38.998808 -> V=1.0, theta=0.0
% INFO    : Bus 18891	: V=1.0094593, theta=-38.752336 -> V=1.0, theta=0.0
% INFO    : Bus 18892	: V=1.0179501, theta=-37.992199 -> V=1.0, theta=0.0
% INFO    : Bus 18893	: V=1.0002354, theta=-42.879819 -> V=1.0, theta=0.0
% INFO    : Bus 18894	: V=0.9725566, theta=-45.036711 -> V=1.0, theta=0.0
% INFO    : Bus 18895	: V=0.9774534, theta=-44.835018 -> V=1.0, theta=0.0
% INFO    : Bus 18896	: V=0.9850283, theta=-43.909371 -> V=1.0, theta=0.0
% INFO    : Bus 18897	: V=0.9664503, theta=-49.417705 -> V=1.0, theta=0.0
% INFO    : Bus 18898	: V=0.9633685, theta=-49.905516 -> V=1.0, theta=0.0
% INFO    : Bus 18899	: V=0.9608716, theta=-49.842558 -> V=1.0, theta=0.0
% INFO    : Bus 18900	: V=0.9676839, theta=-49.415057 -> V=1.0, theta=0.0
% INFO    : Bus 18901	: V=0.9667952, theta=-49.464557 -> V=1.0, theta=0.0
% INFO    : Bus 18902	: V=0.958226, theta=-50.155829 -> V=1.0, theta=0.0
% INFO    : Bus 18903	: V=0.9590348, theta=-50.054395 -> V=1.0, theta=0.0
% INFO    : Bus 18904	: V=0.9686951, theta=-48.294006 -> V=1.0, theta=0.0
% INFO    : Bus 18905	: V=0.9630081, theta=-49.544614 -> V=1.0, theta=0.0
% INFO    : Bus 18906	: V=0.9533059, theta=-50.739029 -> V=1.0, theta=0.0
% INFO    : Bus 18907	: V=0.9558069, theta=-50.67583 -> V=1.0, theta=0.0
% INFO    : Bus 18908	: V=0.9619765, theta=-49.724378 -> V=1.0, theta=0.0
% INFO    : Bus 18909	: V=0.9661587, theta=-50.021769 -> V=1.0, theta=0.0
% INFO    : Bus 18910	: V=0.9562091, theta=-50.216793 -> V=1.0, theta=0.0
% INFO    : Bus 18911	: V=0.9506319, theta=-50.905597 -> V=1.0, theta=0.0
% INFO    : Bus 18912	: V=0.9619413, theta=-49.931029 -> V=1.0, theta=0.0
% INFO    : Bus 18913	: V=0.9945088, theta=-42.775643 -> V=1.0, theta=0.0
% INFO    : Bus 18914	: V=1.0020759, theta=-42.624205 -> V=1.0, theta=0.0
% INFO    : Bus 18915	: V=0.9942563, theta=-43.384427 -> V=1.0, theta=0.0
% INFO    : Bus 18916	: V=0.9905842, theta=-42.852405 -> V=1.0, theta=0.0
% INFO    : Bus 18917	: V=1.0008804, theta=-41.638651 -> V=1.0, theta=0.0
% INFO    : Bus 18918	: V=1.0148059, theta=-39.737076 -> V=1.0, theta=0.0
% INFO    : Bus 18919	: V=0.9980853, theta=-43.555691 -> V=1.0, theta=0.0
% INFO    : Bus 18920	: V=0.9972611, theta=-43.240174 -> V=1.0, theta=0.0
% INFO    : Bus 18921	: V=0.9930564, theta=-43.289354 -> V=1.0, theta=0.0
% INFO    : Bus 18922	: V=0.9909904, theta=-44.228909 -> V=1.0, theta=0.0
% INFO    : Bus 18923	: V=0.9469459, theta=-49.793942 -> V=1.0, theta=0.0
% INFO    : Bus 18924	: V=0.9479358, theta=-49.550878 -> V=1.0, theta=0.0
% INFO    : Bus 18925	: V=0.9545099, theta=-48.684583 -> V=1.0, theta=0.0
% INFO    : Bus 18926	: V=0.9871407, theta=-42.021879 -> V=1.0, theta=0.0
% INFO    : Bus 18927	: V=0.9914778, theta=-41.65426 -> V=1.0, theta=0.0
% INFO    : Bus 18928	: V=0.9963475, theta=-41.222894 -> V=1.0, theta=0.0
% INFO    : Bus 18929	: V=0.9665388, theta=-43.637157 -> V=1.0, theta=0.0
% INFO    : Bus 18930	: V=1.008567, theta=-44.236061 -> V=1.0, theta=0.0
% INFO    : Bus 18931	: V=1.0052769, theta=-44.994221 -> V=1.0, theta=0.0
% INFO    : Bus 18932	: V=1.0062159, theta=-44.716424 -> V=1.0, theta=0.0
% INFO    : Bus 18933	: V=1.0186842, theta=-43.079217 -> V=1.0, theta=0.0
% INFO    : Bus 18934	: V=1.0192404, theta=-42.644202 -> V=1.0, theta=0.0
% INFO    : Bus 18935	: V=0.9898951, theta=-50.741739 -> V=1.0, theta=0.0
% INFO    : Bus 18936	: V=0.9899179, theta=-50.97825 -> V=1.0, theta=0.0
% INFO    : Bus 18937	: V=0.9875029, theta=-50.192048 -> V=1.0, theta=0.0
% INFO    : Bus 18938	: V=0.987485, theta=-49.308827 -> V=1.0, theta=0.0
% INFO    : Bus 18939	: V=0.9887825, theta=-48.527168 -> V=1.0, theta=0.0
% INFO    : Bus 18940	: V=0.946451, theta=-49.593708 -> V=1.0, theta=0.0
% INFO    : Bus 18941	: V=0.9533523, theta=-50.25387 -> V=1.0, theta=0.0
% INFO    : Bus 18942	: V=0.9561826, theta=-47.587298 -> V=1.0, theta=0.0
% INFO    : Bus 18943	: V=0.9594267, theta=-47.226816 -> V=1.0, theta=0.0
% INFO    : Bus 18944	: V=1.0051967, theta=-41.090855 -> V=1.0, theta=0.0
% INFO    : Bus 18945	: V=1.0191673, theta=-41.130043 -> V=1.0, theta=0.0
% INFO    : Bus 18946	: V=1.0136662, theta=-41.036777 -> V=1.0, theta=0.0
% INFO    : Bus 18947	: V=1.0025516, theta=-41.937583 -> V=1.0, theta=0.0
% INFO    : Bus 18948	: V=0.9965509, theta=-41.807864 -> V=1.0, theta=0.0
% INFO    : Bus 18949	: V=1.0004445, theta=-41.637156 -> V=1.0, theta=0.0
% INFO    : Bus 18950	: V=0.983108, theta=-41.728644 -> V=1.0, theta=0.0
% INFO    : Bus 18951	: V=0.9707933, theta=-43.341392 -> V=1.0, theta=0.0
% INFO    : Bus 18952	: V=0.9598501, theta=-42.965656 -> V=1.0, theta=0.0
% INFO    : Bus 18953	: V=0.9897704, theta=-42.101132 -> V=1.0, theta=0.0
% INFO    : Bus 18954	: V=0.9823923, theta=-43.484122 -> V=1.0, theta=0.0
% INFO    : Bus 18955	: V=0.9743984, theta=-43.630121 -> V=1.0, theta=0.0
% INFO    : Bus 18956	: V=0.982588, theta=-43.894205 -> V=1.0, theta=0.0
% INFO    : Bus 18957	: V=0.9635476, theta=-43.828599 -> V=1.0, theta=0.0
% INFO    : Bus 18958	: V=0.9703602, theta=-43.534095 -> V=1.0, theta=0.0
% INFO    : Bus 18959	: V=0.9673213, theta=-43.363491 -> V=1.0, theta=0.0
% INFO    : Bus 18960	: V=0.9884267, theta=-42.795778 -> V=1.0, theta=0.0
% INFO    : Bus 18961	: V=0.9912285, theta=-42.432322 -> V=1.0, theta=0.0
% INFO    : Bus 18962	: V=1.0044803, theta=-41.252832 -> V=1.0, theta=0.0
% INFO    : Bus 18963	: V=0.9945924, theta=-42.531829 -> V=1.0, theta=0.0
% INFO    : Bus 18964	: V=1.0054359, theta=-40.978012 -> V=1.0, theta=0.0
% INFO    : Bus 18965	: V=1.0073388, theta=-40.266754 -> V=1.0, theta=0.0
% INFO    : Bus 18966	: V=1.0067992, theta=-40.289379 -> V=1.0, theta=0.0
% INFO    : Bus 18967	: V=0.9961606, theta=-41.838876 -> V=1.0, theta=0.0
% INFO    : Bus 18968	: V=1.0097486, theta=-39.755647 -> V=1.0, theta=0.0
% INFO    : Bus 18969	: V=1.0116179, theta=-39.111819 -> V=1.0, theta=0.0
% INFO    : Bus 18970	: V=1.008165, theta=-38.569498 -> V=1.0, theta=0.0
% INFO    : Bus 18971	: V=1.0104547, theta=-38.313493 -> V=1.0, theta=0.0
% INFO    : Bus 18972	: V=1.010065, theta=-38.529295 -> V=1.0, theta=0.0
% INFO    : Bus 18973	: V=1.0102289, theta=-38.724258 -> V=1.0, theta=0.0
% INFO    : Bus 18974	: V=1.0006698, theta=-38.912355 -> V=1.0, theta=0.0
% INFO    : Bus 18975	: V=0.9905962, theta=-40.327252 -> V=1.0, theta=0.0
% INFO    : Bus 18976	: V=0.9991473, theta=-39.171024 -> V=1.0, theta=0.0
% INFO    : Bus 18977	: V=0.9833783, theta=-50.627906 -> V=1.0, theta=0.0
% INFO    : Bus 18978	: V=0.9869241, theta=-50.267667 -> V=1.0, theta=0.0
% INFO    : Bus 18979	: V=0.981923, theta=-50.81297 -> V=1.0, theta=0.0
% INFO    : Bus 18980	: V=0.987312, theta=-50.199213 -> V=1.0, theta=0.0
% INFO    : Bus 18981	: V=0.9809124, theta=-50.887891 -> V=1.0, theta=0.0
% INFO    : Bus 18982	: V=1.0002706, theta=-47.759906 -> V=1.0, theta=0.0
% INFO    : Bus 18983	: V=0.9907721, theta=-49.290903 -> V=1.0, theta=0.0
% INFO    : Bus 18984	: V=0.9900664, theta=-49.244346 -> V=1.0, theta=0.0
% INFO    : Bus 18985	: V=0.9909254, theta=-49.14784 -> V=1.0, theta=0.0
% INFO    : Bus 18986	: V=0.9913781, theta=-49.131253 -> V=1.0, theta=0.0
% INFO    : Bus 18987	: V=0.9914167, theta=-49.110043 -> V=1.0, theta=0.0
% INFO    : Bus 18988	: V=0.9930956, theta=-49.225453 -> V=1.0, theta=0.0
% INFO    : Bus 18989	: V=0.9887098, theta=-49.965889 -> V=1.0, theta=0.0
% INFO    : Bus 18990	: V=0.9910215, theta=-49.622326 -> V=1.0, theta=0.0
% INFO    : Bus 18991	: V=0.9979554, theta=-48.42107 -> V=1.0, theta=0.0
% INFO    : Bus 18992	: V=1.0039198, theta=-47.401093 -> V=1.0, theta=0.0
% INFO    : Bus 18993	: V=0.9998534, theta=-48.105034 -> V=1.0, theta=0.0
% INFO    : Bus 18994	: V=1.0016255, theta=-47.80871 -> V=1.0, theta=0.0
% INFO    : Bus 18995	: V=1.0007136, theta=-47.695871 -> V=1.0, theta=0.0
% INFO    : Bus 18996	: V=1.0034039, theta=-47.504862 -> V=1.0, theta=0.0
% INFO    : Bus 18997	: V=1.0030444, theta=-47.393368 -> V=1.0, theta=0.0
% INFO    : Bus 18998	: V=0.9940632, theta=-48.443253 -> V=1.0, theta=0.0
% INFO    : Bus 18999	: V=0.990546, theta=-49.156649 -> V=1.0, theta=0.0
% INFO    : Bus 19000	: V=0.9928161, theta=-48.970307 -> V=1.0, theta=0.0
% INFO    : Bus 19001	: V=0.9913144, theta=-49.026238 -> V=1.0, theta=0.0
% INFO    : Bus 19002	: V=0.9921188, theta=-48.842344 -> V=1.0, theta=0.0
% INFO    : Bus 19003	: V=0.9931874, theta=-48.887978 -> V=1.0, theta=0.0
% INFO    : Bus 19004	: V=0.9953253, theta=-48.606243 -> V=1.0, theta=0.0
% INFO    : Bus 19005	: V=1.0058087, theta=-47.063415 -> V=1.0, theta=0.0
% INFO    : Bus 19006	: V=0.9810074, theta=-50.645078 -> V=1.0, theta=0.0
% INFO    : Bus 19007	: V=0.9787232, theta=-50.983608 -> V=1.0, theta=0.0
% INFO    : Bus 19008	: V=0.9871659, theta=-50.050728 -> V=1.0, theta=0.0
% INFO    : Bus 19009	: V=0.9784235, theta=-50.863373 -> V=1.0, theta=0.0
% INFO    : Bus 19010	: V=0.9788388, theta=-50.799626 -> V=1.0, theta=0.0
% INFO    : Bus 19011	: V=0.9761832, theta=-51.171596 -> V=1.0, theta=0.0
% INFO    : Bus 19012	: V=0.9761171, theta=-51.176829 -> V=1.0, theta=0.0
% INFO    : Bus 19013	: V=0.9765394, theta=-51.214496 -> V=1.0, theta=0.0
% INFO    : Bus 19014	: V=0.983388, theta=-50.537278 -> V=1.0, theta=0.0
% INFO    : Bus 19015	: V=0.9784527, theta=-51.027524 -> V=1.0, theta=0.0
% INFO    : Bus 19016	: V=0.9786324, theta=-50.897672 -> V=1.0, theta=0.0
% INFO    : Bus 19017	: V=0.9871722, theta=-49.650095 -> V=1.0, theta=0.0
% INFO    : Bus 19018	: V=0.9881782, theta=-49.506156 -> V=1.0, theta=0.0
% INFO    : Bus 19019	: V=0.989729, theta=-49.255633 -> V=1.0, theta=0.0
% INFO    : Bus 19020	: V=0.9881141, theta=-49.522094 -> V=1.0, theta=0.0
% INFO    : Bus 19021	: V=0.9870194, theta=-49.726625 -> V=1.0, theta=0.0
% INFO    : Bus 19022	: V=0.9887024, theta=-50.89794 -> V=1.0, theta=0.0
% INFO    : Bus 19023	: V=0.9816346, theta=-51.086845 -> V=1.0, theta=0.0
% INFO    : Bus 19024	: V=0.9848374, theta=-50.352615 -> V=1.0, theta=0.0
% INFO    : Bus 19025	: V=0.9878642, theta=-49.671131 -> V=1.0, theta=0.0
% INFO    : Bus 19026	: V=0.9757825, theta=-51.084722 -> V=1.0, theta=0.0
% INFO    : Bus 19027	: V=0.9766368, theta=-51.074677 -> V=1.0, theta=0.0
% INFO    : Bus 19028	: V=0.9762379, theta=-51.135179 -> V=1.0, theta=0.0
% INFO    : Bus 19029	: V=0.9821788, theta=-50.915205 -> V=1.0, theta=0.0
% INFO    : Bus 19030	: V=0.9829134, theta=-50.743969 -> V=1.0, theta=0.0
% INFO    : Bus 19031	: V=0.9704055, theta=-51.733662 -> V=1.0, theta=0.0
% INFO    : Bus 19032	: V=0.971913, theta=-51.416869 -> V=1.0, theta=0.0
% INFO    : Bus 19033	: V=0.9816903, theta=-51.377666 -> V=1.0, theta=0.0
% INFO    : Bus 19034	: V=0.9767857, theta=-51.970608 -> V=1.0, theta=0.0
% INFO    : Bus 19035	: V=0.9811121, theta=-51.422629 -> V=1.0, theta=0.0
% INFO    : Bus 19036	: V=0.9922154, theta=-49.777962 -> V=1.0, theta=0.0
% INFO    : Bus 19037	: V=0.9892437, theta=-50.357885 -> V=1.0, theta=0.0
% INFO    : Bus 19038	: V=0.9838664, theta=-50.841953 -> V=1.0, theta=0.0
% INFO    : Bus 19039	: V=0.9816478, theta=-51.239633 -> V=1.0, theta=0.0
% INFO    : Bus 19040	: V=0.9861464, theta=-50.666832 -> V=1.0, theta=0.0
% INFO    : Bus 19041	: V=0.9908396, theta=-49.945817 -> V=1.0, theta=0.0
% INFO    : Bus 19042	: V=0.9800374, theta=-51.258042 -> V=1.0, theta=0.0
% INFO    : Bus 19043	: V=0.9790651, theta=-51.527236 -> V=1.0, theta=0.0
% INFO    : Bus 19044	: V=0.9927121, theta=-49.525256 -> V=1.0, theta=0.0
% INFO    : Bus 19045	: V=0.9753026, theta=-52.306575 -> V=1.0, theta=0.0
% INFO    : Bus 19046	: V=0.9797531, theta=-51.360992 -> V=1.0, theta=0.0
% INFO    : Bus 19047	: V=0.9803384, theta=-51.431957 -> V=1.0, theta=0.0
% INFO    : Bus 19048	: V=0.9810257, theta=-51.30134 -> V=1.0, theta=0.0
% INFO    : Bus 19049	: V=0.9814602, theta=-51.224439 -> V=1.0, theta=0.0
% INFO    : Bus 19050	: V=0.9825621, theta=-51.046769 -> V=1.0, theta=0.0
% INFO    : Bus 19051	: V=0.9771946, theta=-51.921639 -> V=1.0, theta=0.0
% INFO    : Bus 19052	: V=0.9786642, theta=-51.672627 -> V=1.0, theta=0.0
% INFO    : Bus 19053	: V=0.9777914, theta=-51.817288 -> V=1.0, theta=0.0
% INFO    : Bus 19054	: V=0.9763267, theta=-52.310583 -> V=1.0, theta=0.0
% INFO    : Bus 19055	: V=0.9749129, theta=-52.616011 -> V=1.0, theta=0.0
% INFO    : Bus 19056	: V=0.9858399, theta=-50.772898 -> V=1.0, theta=0.0
% INFO    : Bus 19057	: V=0.975653, theta=-52.335393 -> V=1.0, theta=0.0
% INFO    : Bus 19058	: V=0.9740501, theta=-52.622245 -> V=1.0, theta=0.0
% INFO    : Bus 19059	: V=0.966855, theta=-50.198005 -> V=1.0, theta=0.0
% INFO    : Bus 19060	: V=0.9696578, theta=-49.768712 -> V=1.0, theta=0.0
% INFO    : Bus 19061	: V=0.9771361, theta=-49.132038 -> V=1.0, theta=0.0
% INFO    : Bus 19062	: V=0.974405, theta=-49.323344 -> V=1.0, theta=0.0
% INFO    : Bus 19063	: V=0.9671495, theta=-49.927919 -> V=1.0, theta=0.0
% INFO    : Bus 19064	: V=0.9594361, theta=-49.956808 -> V=1.0, theta=0.0
% INFO    : Bus 19065	: V=0.9711307, theta=-49.497211 -> V=1.0, theta=0.0
% INFO    : Bus 19066	: V=0.9656674, theta=-50.198943 -> V=1.0, theta=0.0
% INFO    : Bus 19067	: V=0.9915579, theta=-50.201733 -> V=1.0, theta=0.0
% INFO    : Bus 19068	: V=0.9937376, theta=-48.473068 -> V=1.0, theta=0.0
% INFO    : Bus 19069	: V=0.9836449, theta=-46.327998 -> V=1.0, theta=0.0
% INFO    : Bus 19070	: V=0.9548881, theta=-49.272306 -> V=1.0, theta=0.0
% INFO    : Bus 19071	: V=0.9652193, theta=-48.511569 -> V=1.0, theta=0.0
% INFO    : Bus 19072	: V=0.9518566, theta=-50.422222 -> V=1.0, theta=0.0
% INFO    : Bus 19073	: V=0.947532, theta=-50.82629 -> V=1.0, theta=0.0
% INFO    : Bus 19074	: V=0.9551473, theta=-49.562788 -> V=1.0, theta=0.0
% INFO    : Bus 19075	: V=0.9593625, theta=-49.09488 -> V=1.0, theta=0.0
% INFO    : Bus 19076	: V=0.9499254, theta=-50.443606 -> V=1.0, theta=0.0
% INFO    : Bus 19077	: V=0.9515023, theta=-50.519666 -> V=1.0, theta=0.0
% INFO    : Bus 19078	: V=0.9466156, theta=-51.059514 -> V=1.0, theta=0.0
% INFO    : Bus 19079	: V=0.9507673, theta=-50.667225 -> V=1.0, theta=0.0
% INFO    : Bus 19080	: V=0.9497587, theta=-50.760087 -> V=1.0, theta=0.0
% INFO    : Bus 19081	: V=0.9489203, theta=-50.836628 -> V=1.0, theta=0.0
% INFO    : Bus 19082	: V=0.9554755, theta=-49.616519 -> V=1.0, theta=0.0
% INFO    : Bus 19083	: V=0.9429466, theta=-51.246717 -> V=1.0, theta=0.0
% INFO    : Bus 19084	: V=0.959052, theta=-48.783811 -> V=1.0, theta=0.0
% INFO    : Bus 19085	: V=0.9572885, theta=-48.863808 -> V=1.0, theta=0.0
% INFO    : Bus 19086	: V=0.9508913, theta=-49.326965 -> V=1.0, theta=0.0
% INFO    : Bus 19087	: V=0.952369, theta=-49.015415 -> V=1.0, theta=0.0
% INFO    : Bus 19088	: V=0.9563932, theta=-49.04806 -> V=1.0, theta=0.0
% INFO    : Bus 19089	: V=0.9886262, theta=-43.872654 -> V=1.0, theta=0.0
% INFO    : Bus 19090	: V=0.9994321, theta=-43.032379 -> V=1.0, theta=0.0
% INFO    : Bus 19091	: V=0.9891388, theta=-44.000448 -> V=1.0, theta=0.0
% INFO    : Bus 19092	: V=0.9749746, theta=-45.395367 -> V=1.0, theta=0.0
% INFO    : Bus 19093	: V=0.9902479, theta=-46.782998 -> V=1.0, theta=0.0
% INFO    : Bus 19094	: V=0.9995104, theta=-45.381557 -> V=1.0, theta=0.0
% INFO    : Bus 19095	: V=0.9977476, theta=-45.609787 -> V=1.0, theta=0.0
% INFO    : Bus 19096	: V=0.9864174, theta=-49.935932 -> V=1.0, theta=0.0
% INFO    : Bus 19097	: V=0.9926806, theta=-46.94828 -> V=1.0, theta=0.0
% INFO    : Bus 19098	: V=0.9951161, theta=-47.077644 -> V=1.0, theta=0.0
% INFO    : Bus 19099	: V=0.9954137, theta=-47.726858 -> V=1.0, theta=0.0
% INFO    : Bus 19100	: V=0.9955766, theta=-48.654499 -> V=1.0, theta=0.0
% INFO    : Bus 19101	: V=0.9899286, theta=-50.088917 -> V=1.0, theta=0.0
% INFO    : Bus 19102	: V=0.9881332, theta=-47.540295 -> V=1.0, theta=0.0
% INFO    : Bus 19103	: V=1.0020589, theta=-45.929384 -> V=1.0, theta=0.0
% INFO    : Bus 19104	: V=0.9966863, theta=-45.841888 -> V=1.0, theta=0.0
% INFO    : Bus 19105	: V=0.997241, theta=-45.935192 -> V=1.0, theta=0.0
% INFO    : Bus 19106	: V=0.9993341, theta=-44.994555 -> V=1.0, theta=0.0
% INFO    : Bus 19107	: V=0.9875525, theta=-45.562023 -> V=1.0, theta=0.0
% INFO    : Bus 19108	: V=1.0004281, theta=-45.026781 -> V=1.0, theta=0.0
% INFO    : Bus 19109	: V=1.0033746, theta=-44.397147 -> V=1.0, theta=0.0
% INFO    : Bus 19110	: V=0.9965721, theta=-45.815981 -> V=1.0, theta=0.0
% INFO    : Bus 19111	: V=1.0177106, theta=-42.423693 -> V=1.0, theta=0.0
% INFO    : Bus 19112	: V=0.9654289, theta=-50.196117 -> V=1.0, theta=0.0
% INFO    : Bus 19113	: V=0.9899758, theta=-45.4192 -> V=1.0, theta=0.0
% INFO    : Bus 19114	: V=0.9974768, theta=-45.067376 -> V=1.0, theta=0.0
% INFO    : Bus 19115	: V=0.9826571, theta=-46.365192 -> V=1.0, theta=0.0
% INFO    : Bus 19116	: V=0.9667107, theta=-49.955479 -> V=1.0, theta=0.0
% INFO    : Bus 19117	: V=0.9671254, theta=-48.944854 -> V=1.0, theta=0.0
% INFO    : Bus 19118	: V=1.0049226, theta=-43.482141 -> V=1.0, theta=0.0
% INFO    : Bus 19119	: V=0.9674308, theta=-46.051849 -> V=1.0, theta=0.0
% INFO    : Bus 19120	: V=0.9491298, theta=-49.058415 -> V=1.0, theta=0.0
% INFO    : Bus 19121	: V=0.9732104, theta=-46.037679 -> V=1.0, theta=0.0
% INFO    : Bus 19122	: V=0.9633331, theta=-46.921559 -> V=1.0, theta=0.0
% INFO    : Bus 19123	: V=0.9756442, theta=-46.122816 -> V=1.0, theta=0.0
% INFO    : Bus 19124	: V=0.9550082, theta=-47.821925 -> V=1.0, theta=0.0
% INFO    : Bus 19125	: V=1.0015317, theta=-52.456624 -> V=1.0, theta=0.0
% INFO    : Bus 19126	: V=0.9916268, theta=-50.417038 -> V=1.0, theta=0.0
% INFO    : Bus 19127	: V=0.9832795, theta=-53.252668 -> V=1.0, theta=0.0
% INFO    : Bus 19128	: V=0.9943532, theta=-52.418723 -> V=1.0, theta=0.0
% INFO    : Bus 19129	: V=0.9913112, theta=-52.858767 -> V=1.0, theta=0.0
% INFO    : Bus 19130	: V=1.0094326, theta=-51.853685 -> V=1.0, theta=0.0
% INFO    : Bus 19131	: V=0.9889111, theta=-52.066727 -> V=1.0, theta=0.0
% INFO    : Bus 19132	: V=0.9941936, theta=-49.600807 -> V=1.0, theta=0.0
% INFO    : Bus 19133	: V=0.978384, theta=-50.350587 -> V=1.0, theta=0.0
% INFO    : Bus 19134	: V=0.9528865, theta=-50.248418 -> V=1.0, theta=0.0
% INFO    : Bus 19135	: V=0.9542108, theta=-50.304174 -> V=1.0, theta=0.0
% INFO    : Bus 19136	: V=0.9524412, theta=-50.582266 -> V=1.0, theta=0.0
% INFO    : Bus 19137	: V=0.9564021, theta=-49.887018 -> V=1.0, theta=0.0
% INFO    : Bus 19138	: V=0.9725525, theta=-48.31741 -> V=1.0, theta=0.0
% INFO    : Bus 19139	: V=0.9679624, theta=-48.726306 -> V=1.0, theta=0.0
% INFO    : Bus 19140	: V=0.9608943, theta=-49.407855 -> V=1.0, theta=0.0
% INFO    : Bus 19141	: V=0.9622214, theta=-48.728304 -> V=1.0, theta=0.0
% INFO    : Bus 19142	: V=0.9482861, theta=-50.719922 -> V=1.0, theta=0.0
% INFO    : Bus 19143	: V=0.9984517, theta=-41.105693 -> V=1.0, theta=0.0
% INFO    : Bus 19144	: V=1.0023989, theta=-40.485463 -> V=1.0, theta=0.0
% INFO    : Bus 19145	: V=0.9894602, theta=-41.527398 -> V=1.0, theta=0.0
% INFO    : Bus 19146	: V=1.0071348, theta=-40.922706 -> V=1.0, theta=0.0
% INFO    : Bus 19147	: V=1.0041801, theta=-40.845805 -> V=1.0, theta=0.0
% INFO    : Bus 19148	: V=1.0059902, theta=-44.745357 -> V=1.0, theta=0.0
% INFO    : Bus 19149	: V=1.0051332, theta=-45.059612 -> V=1.0, theta=0.0
% INFO    : Bus 19150	: V=1.005402, theta=-45.115701 -> V=1.0, theta=0.0
% INFO    : Bus 19151	: V=1.0152732, theta=-43.932748 -> V=1.0, theta=0.0
% INFO    : Bus 19152	: V=1.0096296, theta=-44.606271 -> V=1.0, theta=0.0
% INFO    : Bus 19153	: V=0.9982978, theta=-45.315731 -> V=1.0, theta=0.0
% INFO    : Bus 19154	: V=0.9990274, theta=-45.310236 -> V=1.0, theta=0.0
% INFO    : Bus 19155	: V=1.0056797, theta=-44.8853 -> V=1.0, theta=0.0
% INFO    : Bus 19156	: V=1.0056861, theta=-44.866152 -> V=1.0, theta=0.0
% INFO    : Bus 19157	: V=1.0003276, theta=-45.262974 -> V=1.0, theta=0.0
% INFO    : Bus 19158	: V=1.0063734, theta=-44.770217 -> V=1.0, theta=0.0
% INFO    : Bus 19159	: V=1.0126344, theta=-44.176189 -> V=1.0, theta=0.0
% INFO    : Bus 19160	: V=1.0093387, theta=-44.649431 -> V=1.0, theta=0.0
% INFO    : Bus 19161	: V=1.0121364, theta=-44.211021 -> V=1.0, theta=0.0
% INFO    : Bus 19162	: V=1.0120795, theta=-44.213502 -> V=1.0, theta=0.0
% INFO    : Bus 19163	: V=1.0047016, theta=-44.465451 -> V=1.0, theta=0.0
% INFO    : Bus 19164	: V=1.0106541, theta=-44.394048 -> V=1.0, theta=0.0
% INFO    : Bus 19165	: V=1.0160284, theta=-43.485849 -> V=1.0, theta=0.0
% INFO    : Bus 19166	: V=1.0168362, theta=-43.169678 -> V=1.0, theta=0.0
% INFO    : Bus 19167	: V=1.0043308, theta=-45.078028 -> V=1.0, theta=0.0
% INFO    : Bus 19168	: V=1.0050045, theta=-44.990342 -> V=1.0, theta=0.0
% INFO    : Bus 19169	: V=1.0090105, theta=-44.463997 -> V=1.0, theta=0.0
% INFO    : Bus 19170	: V=1.0103145, theta=-44.148678 -> V=1.0, theta=0.0
% INFO    : Bus 19171	: V=1.0108175, theta=-43.874841 -> V=1.0, theta=0.0
% INFO    : Bus 19172	: V=1.0157819, theta=-42.814396 -> V=1.0, theta=0.0
% INFO    : Bus 19173	: V=1.0162968, theta=-42.541619 -> V=1.0, theta=0.0
% INFO    : Bus 19174	: V=1.0122199, theta=-43.328597 -> V=1.0, theta=0.0
% INFO    : Bus 19175	: V=1.0046958, theta=-44.516551 -> V=1.0, theta=0.0
% INFO    : Bus 19176	: V=1.0074493, theta=-44.448886 -> V=1.0, theta=0.0
% INFO    : Bus 19177	: V=1.0059352, theta=-44.801456 -> V=1.0, theta=0.0
% INFO    : Bus 19178	: V=1.0018573, theta=-46.86683 -> V=1.0, theta=0.0
% INFO    : Bus 19179	: V=1.0072138, theta=-46.119461 -> V=1.0, theta=0.0
% INFO    : Bus 19180	: V=1.0084865, theta=-45.621929 -> V=1.0, theta=0.0
% INFO    : Bus 19181	: V=1.0065784, theta=-46.443122 -> V=1.0, theta=0.0
% INFO    : Bus 19182	: V=0.9983016, theta=-47.105154 -> V=1.0, theta=0.0
% INFO    : Bus 19183	: V=0.9989799, theta=-47.534046 -> V=1.0, theta=0.0
% INFO    : Bus 19184	: V=1.001424, theta=-47.014757 -> V=1.0, theta=0.0
% INFO    : Bus 19185	: V=1.0067137, theta=-45.916613 -> V=1.0, theta=0.0
% INFO    : Bus 19186	: V=1.0017836, theta=-46.732249 -> V=1.0, theta=0.0
% INFO    : Bus 19187	: V=1.0032874, theta=-46.545739 -> V=1.0, theta=0.0
% INFO    : Bus 19188	: V=1.0064842, theta=-46.429364 -> V=1.0, theta=0.0
% INFO    : Bus 19189	: V=1.0048683, theta=-46.397794 -> V=1.0, theta=0.0
% INFO    : Bus 19190	: V=1.0064615, theta=-46.243174 -> V=1.0, theta=0.0
% INFO    : Bus 19191	: V=1.0038285, theta=-46.535172 -> V=1.0, theta=0.0
% INFO    : Bus 19192	: V=0.9983203, theta=-46.893662 -> V=1.0, theta=0.0
% INFO    : Bus 19193	: V=0.9971436, theta=-46.971997 -> V=1.0, theta=0.0
% INFO    : Bus 19194	: V=1.0037576, theta=-45.905215 -> V=1.0, theta=0.0
% INFO    : Bus 19195	: V=1.0085459, theta=-45.230862 -> V=1.0, theta=0.0
% INFO    : Bus 19196	: V=1.0068866, theta=-45.433869 -> V=1.0, theta=0.0
% INFO    : Bus 19197	: V=1.0058451, theta=-45.821652 -> V=1.0, theta=0.0
% INFO    : Bus 19198	: V=1.0009949, theta=-46.040056 -> V=1.0, theta=0.0
% INFO    : Bus 19199	: V=1.0018796, theta=-45.818862 -> V=1.0, theta=0.0
% INFO    : Bus 19200	: V=1.0089235, theta=-45.039833 -> V=1.0, theta=0.0
% INFO    : Bus 19201	: V=1.0089696, theta=-44.962394 -> V=1.0, theta=0.0
% INFO    : Bus 19202	: V=1.0027774, theta=-45.553465 -> V=1.0, theta=0.0
% INFO    : Bus 19203	: V=1.0122851, theta=-44.794527 -> V=1.0, theta=0.0
% INFO    : Bus 19204	: V=1.0160931, theta=-44.276138 -> V=1.0, theta=0.0
% INFO    : Bus 19205	: V=0.9772912, theta=-41.482667 -> V=1.0, theta=0.0
% INFO    : Bus 19206	: V=0.9788067, theta=-41.586869 -> V=1.0, theta=0.0
% INFO    : Bus 19207	: V=0.9984907, theta=-40.213501 -> V=1.0, theta=0.0
% INFO    : Bus 19208	: V=1.0035692, theta=-39.873128 -> V=1.0, theta=0.0
% INFO    : Bus 19209	: V=0.9933719, theta=-40.421913 -> V=1.0, theta=0.0
% INFO    : Bus 19210	: V=0.9952941, theta=-40.480293 -> V=1.0, theta=0.0
% INFO    : Bus 19211	: V=0.9958168, theta=-40.849375 -> V=1.0, theta=0.0
% INFO    : Bus 19212	: V=0.9509028, theta=-50.135238 -> V=1.0, theta=0.0
% INFO    : Bus 19213	: V=0.9517027, theta=-50.157736 -> V=1.0, theta=0.0
% INFO    : Bus 19214	: V=0.9391038, theta=-51.115442 -> V=1.0, theta=0.0
% INFO    : Bus 19215	: V=0.9419649, theta=-50.95024 -> V=1.0, theta=0.0
% INFO    : Bus 19216	: V=0.9510654, theta=-50.53684 -> V=1.0, theta=0.0
% INFO    : Bus 19217	: V=0.9423327, theta=-51.695368 -> V=1.0, theta=0.0
% INFO    : Bus 19218	: V=0.9488075, theta=-50.540787 -> V=1.0, theta=0.0
% INFO    : Bus 19219	: V=0.9485028, theta=-50.432378 -> V=1.0, theta=0.0
% INFO    : Bus 19220	: V=0.9456786, theta=-49.890405 -> V=1.0, theta=0.0
% INFO    : Bus 19221	: V=0.9461939, theta=-51.659551 -> V=1.0, theta=0.0
% INFO    : Bus 19222	: V=0.9481777, theta=-50.509796 -> V=1.0, theta=0.0
% INFO    : Bus 19223	: V=0.9883927, theta=-52.654253 -> V=1.0, theta=0.0
% INFO    : Bus 19224	: V=0.9901165, theta=-53.302546 -> V=1.0, theta=0.0
% INFO    : Bus 19225	: V=0.990661, theta=-52.38032 -> V=1.0, theta=0.0
% INFO    : Bus 19226	: V=0.9876016, theta=-52.703262 -> V=1.0, theta=0.0
% INFO    : Bus 19227	: V=0.9873053, theta=-52.740229 -> V=1.0, theta=0.0
% INFO    : Bus 19228	: V=0.9873425, theta=-52.746036 -> V=1.0, theta=0.0
% INFO    : Bus 19229	: V=0.985751, theta=-52.990946 -> V=1.0, theta=0.0
% INFO    : Bus 19230	: V=0.9905014, theta=-51.393453 -> V=1.0, theta=0.0
% INFO    : Bus 19231	: V=1.0056549, theta=-44.865532 -> V=1.0, theta=0.0
% INFO    : Bus 19232	: V=0.9989035, theta=-45.423713 -> V=1.0, theta=0.0
% INFO    : Bus 19233	: V=0.9974221, theta=-44.969899 -> V=1.0, theta=0.0
% INFO    : Bus 19234	: V=1.0021833, theta=-44.88601 -> V=1.0, theta=0.0
% INFO    : Bus 19235	: V=0.9982077, theta=-44.983481 -> V=1.0, theta=0.0
% INFO    : Bus 19236	: V=0.9891721, theta=-46.529449 -> V=1.0, theta=0.0
% INFO    : Bus 19237	: V=1.0122675, theta=-43.001925 -> V=1.0, theta=0.0
% INFO    : Bus 19238	: V=0.9830236, theta=-47.112032 -> V=1.0, theta=0.0
% INFO    : Bus 19239	: V=0.9716394, theta=-49.337285 -> V=1.0, theta=0.0
% INFO    : Bus 19240	: V=0.9627861, theta=-49.617932 -> V=1.0, theta=0.0
% INFO    : Bus 19241	: V=0.9682806, theta=-47.831373 -> V=1.0, theta=0.0
% INFO    : Bus 19242	: V=0.9736097, theta=-47.751513 -> V=1.0, theta=0.0
% INFO    : Bus 19243	: V=1.0106457, theta=-43.085526 -> V=1.0, theta=0.0
% INFO    : Bus 19244	: V=0.9877252, theta=-46.710448 -> V=1.0, theta=0.0
% INFO    : Bus 19245	: V=0.9768932, theta=-47.747346 -> V=1.0, theta=0.0
% INFO    : Bus 19246	: V=1.0035907, theta=-45.755086 -> V=1.0, theta=0.0
% INFO    : Bus 19247	: V=1.0132302, theta=-45.472821 -> V=1.0, theta=0.0
% INFO    : Bus 19248	: V=0.9721802, theta=-45.273765 -> V=1.0, theta=0.0
% INFO    : Bus 19249	: V=0.9656552, theta=-45.374498 -> V=1.0, theta=0.0
% INFO    : Bus 19250	: V=1.0157725, theta=-40.283811 -> V=1.0, theta=0.0
% INFO    : Bus 19251	: V=0.9845226, theta=-44.133644 -> V=1.0, theta=0.0
% INFO    : Bus 19252	: V=0.972128, theta=-44.942677 -> V=1.0, theta=0.0
% INFO    : Bus 19253	: V=0.9723798, theta=-46.387215 -> V=1.0, theta=0.0
% INFO    : Bus 19254	: V=0.9782305, theta=-44.627615 -> V=1.0, theta=0.0
% INFO    : Bus 19255	: V=0.996666, theta=-42.336735 -> V=1.0, theta=0.0
% INFO    : Bus 19256	: V=0.9833727, theta=-44.88896 -> V=1.0, theta=0.0
% INFO    : Bus 19257	: V=0.978816, theta=-45.6308 -> V=1.0, theta=0.0
% INFO    : Bus 19258	: V=0.9769901, theta=-46.129214 -> V=1.0, theta=0.0
% INFO    : Bus 19259	: V=0.9802478, theta=-48.564422 -> V=1.0, theta=0.0
% INFO    : Bus 19260	: V=1.0095581, theta=-44.539797 -> V=1.0, theta=0.0
% INFO    : Bus 19261	: V=0.9868204, theta=-47.271002 -> V=1.0, theta=0.0
% INFO    : Bus 19262	: V=0.9711179, theta=-49.449895 -> V=1.0, theta=0.0
% INFO    : Bus 19263	: V=0.968182, theta=-49.897205 -> V=1.0, theta=0.0
% INFO    : Bus 19264	: V=0.9595625, theta=-50.668742 -> V=1.0, theta=0.0
% INFO    : Bus 19265	: V=0.9974334, theta=-41.264171 -> V=1.0, theta=0.0
% INFO    : Bus 19266	: V=0.995693, theta=-41.40357 -> V=1.0, theta=0.0
% INFO    : Bus 19267	: V=0.9986063, theta=-41.200786 -> V=1.0, theta=0.0
% INFO    : Bus 19268	: V=0.9965855, theta=-41.347036 -> V=1.0, theta=0.0
% INFO    : Bus 19269	: V=1.0060915, theta=-40.608624 -> V=1.0, theta=0.0
% INFO    : Bus 19270	: V=1.0032296, theta=-40.828838 -> V=1.0, theta=0.0
% INFO    : Bus 19271	: V=1.0014554, theta=-40.787611 -> V=1.0, theta=0.0
% INFO    : Bus 19272	: V=1.0071994, theta=-40.252383 -> V=1.0, theta=0.0
% INFO    : Bus 19273	: V=1.0192811, theta=-39.670278 -> V=1.0, theta=0.0
% INFO    : Bus 19274	: V=1.0088866, theta=-40.552322 -> V=1.0, theta=0.0
% INFO    : Bus 19275	: V=1.008699, theta=-40.365773 -> V=1.0, theta=0.0
% INFO    : Bus 19276	: V=1.0023881, theta=-40.534749 -> V=1.0, theta=0.0
% INFO    : Bus 19277	: V=1.0031686, theta=-40.406753 -> V=1.0, theta=0.0
% INFO    : Bus 19278	: V=0.9992682, theta=-40.546566 -> V=1.0, theta=0.0
% INFO    : Bus 19279	: V=0.9623714, theta=-54.092147 -> V=1.0, theta=0.0
% INFO    : Bus 19280	: V=0.9634337, theta=-53.936604 -> V=1.0, theta=0.0
% INFO    : Bus 19281	: V=0.9627417, theta=-54.069828 -> V=1.0, theta=0.0
% INFO    : Bus 19282	: V=0.9619301, theta=-54.192866 -> V=1.0, theta=0.0
% INFO    : Bus 19283	: V=0.9615702, theta=-54.245449 -> V=1.0, theta=0.0
% INFO    : Bus 19284	: V=0.9610406, theta=-54.340991 -> V=1.0, theta=0.0
% INFO    : Bus 19285	: V=0.9613618, theta=-54.261536 -> V=1.0, theta=0.0
% INFO    : Bus 19286	: V=0.9573995, theta=-54.55252 -> V=1.0, theta=0.0
% INFO    : Bus 19287	: V=0.9626028, theta=-54.100755 -> V=1.0, theta=0.0
% INFO    : Bus 19288	: V=0.9632317, theta=-54.007072 -> V=1.0, theta=0.0
% INFO    : Bus 19289	: V=0.9837563, theta=-50.478085 -> V=1.0, theta=0.0
% INFO    : Bus 19290	: V=0.9648496, theta=-53.655892 -> V=1.0, theta=0.0
% INFO    : Bus 19291	: V=0.9611054, theta=-54.230668 -> V=1.0, theta=0.0
% INFO    : Bus 19292	: V=0.9839763, theta=-50.449115 -> V=1.0, theta=0.0
% INFO    : Bus 19293	: V=0.9644428, theta=-53.795319 -> V=1.0, theta=0.0
% INFO    : Bus 19294	: V=0.9607154, theta=-54.319838 -> V=1.0, theta=0.0
% INFO    : Bus 19295	: V=0.9582133, theta=-54.517558 -> V=1.0, theta=0.0
% INFO    : Bus 19296	: V=0.9637488, theta=-53.738148 -> V=1.0, theta=0.0
% INFO    : Bus 19297	: V=0.95564, theta=-54.736952 -> V=1.0, theta=0.0
% INFO    : Bus 19298	: V=0.9618885, theta=-53.856785 -> V=1.0, theta=0.0
% INFO    : Bus 19299	: V=0.9558877, theta=-54.595177 -> V=1.0, theta=0.0
% INFO    : Bus 19300	: V=0.9563296, theta=-54.568305 -> V=1.0, theta=0.0
% INFO    : Bus 19301	: V=0.9551061, theta=-54.780155 -> V=1.0, theta=0.0
% INFO    : Bus 19302	: V=0.9620984, theta=-53.919611 -> V=1.0, theta=0.0
% INFO    : Bus 19303	: V=0.9597258, theta=-54.482842 -> V=1.0, theta=0.0
% INFO    : Bus 19304	: V=0.9551511, theta=-54.939496 -> V=1.0, theta=0.0
% INFO    : Bus 19305	: V=0.9546033, theta=-54.911272 -> V=1.0, theta=0.0
% INFO    : Bus 19306	: V=0.9610433, theta=-54.053078 -> V=1.0, theta=0.0
% INFO    : Bus 19307	: V=0.9615223, theta=-54.006296 -> V=1.0, theta=0.0
% INFO    : Bus 19308	: V=0.9548779, theta=-54.811926 -> V=1.0, theta=0.0
% INFO    : Bus 19309	: V=0.9544924, theta=-54.831585 -> V=1.0, theta=0.0
% INFO    : Bus 19310	: V=0.9546209, theta=-54.817263 -> V=1.0, theta=0.0
% INFO    : Bus 19311	: V=0.954645, theta=-54.671174 -> V=1.0, theta=0.0
% INFO    : Bus 19312	: V=0.9621582, theta=-53.977876 -> V=1.0, theta=0.0
% INFO    : Bus 19313	: V=0.9544027, theta=-54.645381 -> V=1.0, theta=0.0
% INFO    : Bus 19314	: V=0.9550298, theta=-54.636655 -> V=1.0, theta=0.0
% INFO    : Bus 19315	: V=0.955246, theta=-54.593163 -> V=1.0, theta=0.0
% INFO    : Bus 19316	: V=0.9558927, theta=-54.512144 -> V=1.0, theta=0.0
% INFO    : Bus 19317	: V=1.0096445, theta=-40.527355 -> V=1.0, theta=0.0
% INFO    : Bus 19318	: V=0.9984351, theta=-45.57995 -> V=1.0, theta=0.0
% INFO    : Bus 19319	: V=1.0097557, theta=-44.438818 -> V=1.0, theta=0.0
% INFO    : Bus 19320	: V=0.995242, theta=-45.932187 -> V=1.0, theta=0.0
% INFO    : Bus 19321	: V=0.9985645, theta=-45.758133 -> V=1.0, theta=0.0
% INFO    : Bus 19322	: V=0.9830982, theta=-44.267334 -> V=1.0, theta=0.0
% INFO    : Bus 19323	: V=1.0076938, theta=-42.641546 -> V=1.0, theta=0.0
% INFO    : Bus 19324	: V=1.0109746, theta=-42.220408 -> V=1.0, theta=0.0
% INFO    : Bus 19325	: V=1.0087929, theta=-42.631348 -> V=1.0, theta=0.0
% INFO    : Bus 19326	: V=1.0069053, theta=-42.638333 -> V=1.0, theta=0.0
% INFO    : Bus 19327	: V=1.0079143, theta=-42.552379 -> V=1.0, theta=0.0
% INFO    : Bus 19328	: V=1.0066149, theta=-42.673645 -> V=1.0, theta=0.0
% INFO    : Bus 19329	: V=1.0035184, theta=-42.622469 -> V=1.0, theta=0.0
% INFO    : Bus 19330	: V=1.0048416, theta=-42.786248 -> V=1.0, theta=0.0
% INFO    : Bus 19331	: V=1.0051689, theta=-42.752032 -> V=1.0, theta=0.0
% INFO    : Bus 19332	: V=1.0104299, theta=-42.318668 -> V=1.0, theta=0.0
% INFO    : Bus 19333	: V=1.0117298, theta=-42.186579 -> V=1.0, theta=0.0
% INFO    : Bus 19334	: V=1.0189269, theta=-41.898898 -> V=1.0, theta=0.0
% INFO    : Bus 19335	: V=0.9815634, theta=-42.982615 -> V=1.0, theta=0.0
% INFO    : Bus 19336	: V=0.9858914, theta=-42.6347 -> V=1.0, theta=0.0
% INFO    : Bus 19337	: V=0.9852075, theta=-42.728289 -> V=1.0, theta=0.0
% INFO    : Bus 19338	: V=0.982184, theta=-43.363368 -> V=1.0, theta=0.0
% INFO    : Bus 19339	: V=0.9838283, theta=-43.253204 -> V=1.0, theta=0.0
% INFO    : Bus 19340	: V=0.9889837, theta=-42.337563 -> V=1.0, theta=0.0
% INFO    : Bus 19341	: V=0.9888915, theta=-42.356117 -> V=1.0, theta=0.0
% INFO    : Bus 19342	: V=0.9888806, theta=-42.367907 -> V=1.0, theta=0.0
% INFO    : Bus 19343	: V=0.9846771, theta=-43.01749 -> V=1.0, theta=0.0
% INFO    : Bus 19344	: V=0.9858398, theta=-42.764004 -> V=1.0, theta=0.0
% INFO    : Bus 19345	: V=0.9653886, theta=-44.030677 -> V=1.0, theta=0.0
% INFO    : Bus 19346	: V=1.0089124, theta=-39.893259 -> V=1.0, theta=0.0
% INFO    : Bus 19347	: V=0.985442, theta=-42.818629 -> V=1.0, theta=0.0
% INFO    : Bus 19348	: V=0.9788359, theta=-43.692496 -> V=1.0, theta=0.0
% INFO    : Bus 19349	: V=0.9829986, theta=-43.026161 -> V=1.0, theta=0.0
% INFO    : Bus 19350	: V=0.9807909, theta=-43.250933 -> V=1.0, theta=0.0
% INFO    : Bus 19351	: V=0.9904602, theta=-42.318515 -> V=1.0, theta=0.0
% INFO    : Bus 19352	: V=0.9856251, theta=-42.691218 -> V=1.0, theta=0.0
% INFO    : Bus 19353	: V=0.9881322, theta=-42.544193 -> V=1.0, theta=0.0
% INFO    : Bus 19354	: V=0.9859265, theta=-42.694502 -> V=1.0, theta=0.0
% INFO    : Bus 19355	: V=0.9549843, theta=-44.882597 -> V=1.0, theta=0.0
% INFO    : Bus 19356	: V=0.984144, theta=-42.793427 -> V=1.0, theta=0.0
% INFO    : Bus 19357	: V=0.9612742, theta=-44.56499 -> V=1.0, theta=0.0
% INFO    : Bus 19358	: V=0.9531641, theta=-44.929561 -> V=1.0, theta=0.0
% INFO    : Bus 19359	: V=0.9702909, theta=-44.289145 -> V=1.0, theta=0.0
% INFO    : Bus 19360	: V=0.9688965, theta=-44.322632 -> V=1.0, theta=0.0
% INFO    : Bus 19361	: V=0.9619117, theta=-44.325521 -> V=1.0, theta=0.0
% INFO    : Bus 19362	: V=0.9615421, theta=-44.283936 -> V=1.0, theta=0.0
% INFO    : Bus 19363	: V=0.9804332, theta=-43.029345 -> V=1.0, theta=0.0
% INFO    : Bus 19364	: V=0.9508808, theta=-45.808267 -> V=1.0, theta=0.0
% INFO    : Bus 19365	: V=0.9553458, theta=-44.902946 -> V=1.0, theta=0.0
% INFO    : Bus 19366	: V=0.9749486, theta=-43.62371 -> V=1.0, theta=0.0
% INFO    : Bus 19367	: V=0.978909, theta=-43.091776 -> V=1.0, theta=0.0
% INFO    : Bus 19368	: V=0.9767285, theta=-43.46494 -> V=1.0, theta=0.0
% INFO    : Bus 19369	: V=0.9886454, theta=-42.33628 -> V=1.0, theta=0.0
% INFO    : Bus 19370	: V=0.9865391, theta=-42.805177 -> V=1.0, theta=0.0
% INFO    : Bus 19371	: V=0.9817301, theta=-42.817759 -> V=1.0, theta=0.0
% INFO    : Bus 19372	: V=0.9653715, theta=-43.922876 -> V=1.0, theta=0.0
% INFO    : Bus 19373	: V=0.9752066, theta=-43.039121 -> V=1.0, theta=0.0
% INFO    : Bus 19374	: V=0.9728415, theta=-43.606504 -> V=1.0, theta=0.0
% INFO    : Bus 19375	: V=0.983616, theta=-42.453128 -> V=1.0, theta=0.0
% INFO    : Bus 19376	: V=1.0082369, theta=-39.115846 -> V=1.0, theta=0.0
% INFO    : Bus 19377	: V=0.9986536, theta=-40.243286 -> V=1.0, theta=0.0
% INFO    : Bus 19378	: V=0.9980686, theta=-40.318273 -> V=1.0, theta=0.0
% INFO    : Bus 19379	: V=0.9998458, theta=-39.31646 -> V=1.0, theta=0.0
% INFO    : Bus 19380	: V=0.9966559, theta=-40.501435 -> V=1.0, theta=0.0
% INFO    : Bus 19381	: V=1.000952, theta=-44.212411 -> V=1.0, theta=0.0
% INFO    : Bus 19382	: V=1.004659, theta=-43.677081 -> V=1.0, theta=0.0
% INFO    : Bus 19383	: V=0.970093, theta=-43.534595 -> V=1.0, theta=0.0
% INFO    : Bus 19384	: V=0.9793884, theta=-42.386312 -> V=1.0, theta=0.0
% INFO    : Bus 19385	: V=0.9802225, theta=-42.236077 -> V=1.0, theta=0.0
% INFO    : Bus 19386	: V=0.9668364, theta=-43.614375 -> V=1.0, theta=0.0
% INFO    : Bus 19387	: V=0.9650517, theta=-43.798973 -> V=1.0, theta=0.0
% INFO    : Bus 19388	: V=0.966396, theta=-43.750686 -> V=1.0, theta=0.0
% INFO    : Bus 19389	: V=0.9770759, theta=-42.535526 -> V=1.0, theta=0.0
% INFO    : Bus 19390	: V=0.9785739, theta=-42.534856 -> V=1.0, theta=0.0
% INFO    : Bus 19391	: V=0.9796374, theta=-42.539989 -> V=1.0, theta=0.0
% INFO    : Bus 19392	: V=0.9699997, theta=-43.573841 -> V=1.0, theta=0.0
% INFO    : Bus 19393	: V=0.9631333, theta=-43.83762 -> V=1.0, theta=0.0
% INFO    : Bus 19394	: V=0.9718354, theta=-43.415395 -> V=1.0, theta=0.0
% INFO    : Bus 19395	: V=0.9840983, theta=-41.585216 -> V=1.0, theta=0.0
% INFO    : Bus 19396	: V=0.9821581, theta=-41.910272 -> V=1.0, theta=0.0
% INFO    : Bus 19397	: V=0.9654261, theta=-43.803213 -> V=1.0, theta=0.0
% INFO    : Bus 19398	: V=0.9719692, theta=-42.970717 -> V=1.0, theta=0.0
% INFO    : Bus 19399	: V=1.0033647, theta=-40.142162 -> V=1.0, theta=0.0
% INFO    : Bus 19400	: V=0.9956339, theta=-41.04244 -> V=1.0, theta=0.0
% INFO    : Bus 19401	: V=0.9591215, theta=-54.516011 -> V=1.0, theta=0.0
% INFO    : Bus 19402	: V=0.9599476, theta=-54.459438 -> V=1.0, theta=0.0
% INFO    : Bus 19403	: V=0.986922, theta=-50.166434 -> V=1.0, theta=0.0
% INFO    : Bus 19404	: V=0.9532199, theta=-55.125361 -> V=1.0, theta=0.0
% INFO    : Bus 19405	: V=0.9550263, theta=-54.686022 -> V=1.0, theta=0.0
% INFO    : Bus 19406	: V=0.9553884, theta=-55.043826 -> V=1.0, theta=0.0
% INFO    : Bus 19407	: V=0.9554491, theta=-55.02823 -> V=1.0, theta=0.0
% INFO    : Bus 19408	: V=0.9563188, theta=-54.986647 -> V=1.0, theta=0.0
% INFO    : Bus 19409	: V=1.0062888, theta=-40.946625 -> V=1.0, theta=0.0
% INFO    : Bus 19410	: V=1.0065871, theta=-40.962864 -> V=1.0, theta=0.0
% INFO    : Bus 19411	: V=1.0096074, theta=-44.795206 -> V=1.0, theta=0.0
% INFO    : Bus 19412	: V=1.0089384, theta=-44.871464 -> V=1.0, theta=0.0
% INFO    : Bus 19413	: V=1.0148814, theta=-44.124069 -> V=1.0, theta=0.0
% INFO    : Bus 19414	: V=1.015132, theta=-43.962278 -> V=1.0, theta=0.0
% INFO    : Bus 19415	: V=1.0033292, theta=-45.482174 -> V=1.0, theta=0.0
% INFO    : Bus 19416	: V=1.0088388, theta=-44.792946 -> V=1.0, theta=0.0
% INFO    : Bus 19417	: V=1.0030656, theta=-44.742412 -> V=1.0, theta=0.0
% INFO    : Bus 19418	: V=0.9747172, theta=-48.83967 -> V=1.0, theta=0.0
% INFO    : Bus 19419	: V=0.9894975, theta=-42.007165 -> V=1.0, theta=0.0
% INFO    : Bus 19420	: V=0.979218, theta=-43.007187 -> V=1.0, theta=0.0
% INFO    : Bus 19421	: V=0.9855517, theta=-42.177628 -> V=1.0, theta=0.0
% INFO    : Bus 19422	: V=0.9864964, theta=-42.004723 -> V=1.0, theta=0.0
% INFO    : Bus 19423	: V=0.990515, theta=-41.861641 -> V=1.0, theta=0.0
% INFO    : Bus 19424	: V=0.9929335, theta=-41.576322 -> V=1.0, theta=0.0
% INFO    : Bus 19425	: V=0.9908635, theta=-41.786351 -> V=1.0, theta=0.0
% INFO    : Bus 19426	: V=0.9909339, theta=-41.783094 -> V=1.0, theta=0.0
% INFO    : Bus 19427	: V=0.9908579, theta=-41.789426 -> V=1.0, theta=0.0
% INFO    : Bus 19428	: V=0.9912482, theta=-41.752424 -> V=1.0, theta=0.0
% INFO    : Bus 19429	: V=0.9905367, theta=-41.840755 -> V=1.0, theta=0.0
% INFO    : Bus 19430	: V=0.9920422, theta=-41.682061 -> V=1.0, theta=0.0
% INFO    : Bus 19431	: V=0.9907764, theta=-41.806278 -> V=1.0, theta=0.0
% INFO    : Bus 19432	: V=1.0090168, theta=-38.889429 -> V=1.0, theta=0.0
% INFO    : Bus 19433	: V=0.9896268, theta=-41.938521 -> V=1.0, theta=0.0
% INFO    : Bus 19434	: V=0.9878374, theta=-42.100782 -> V=1.0, theta=0.0
% INFO    : Bus 19435	: V=0.9887011, theta=-42.029182 -> V=1.0, theta=0.0
% INFO    : Bus 19436	: V=0.9890597, theta=-41.98901 -> V=1.0, theta=0.0
% INFO    : Bus 19437	: V=0.98903, theta=-42.006457 -> V=1.0, theta=0.0
% INFO    : Bus 19438	: V=0.9890888, theta=-42.019541 -> V=1.0, theta=0.0
% INFO    : Bus 19439	: V=0.9820093, theta=-42.957103 -> V=1.0, theta=0.0
% INFO    : Bus 19440	: V=0.986643, theta=-42.181277 -> V=1.0, theta=0.0
% INFO    : Bus 19441	: V=0.9789919, theta=-43.03406 -> V=1.0, theta=0.0
% INFO    : Bus 19442	: V=0.9785494, theta=-43.123077 -> V=1.0, theta=0.0
% INFO    : Bus 19443	: V=0.9790894, theta=-43.053396 -> V=1.0, theta=0.0
% INFO    : Bus 19444	: V=0.9864204, theta=-42.197657 -> V=1.0, theta=0.0
% INFO    : Bus 19445	: V=0.9825387, theta=-42.916854 -> V=1.0, theta=0.0
% INFO    : Bus 19446	: V=0.9818045, theta=-42.881148 -> V=1.0, theta=0.0
% INFO    : Bus 19447	: V=0.9883251, theta=-42.079112 -> V=1.0, theta=0.0
% INFO    : Bus 19448	: V=0.988916, theta=-42.027301 -> V=1.0, theta=0.0
% INFO    : Bus 19449	: V=0.9853095, theta=-42.568447 -> V=1.0, theta=0.0
% INFO    : Bus 19450	: V=0.9831741, theta=-42.756357 -> V=1.0, theta=0.0
% INFO    : Bus 19451	: V=0.9798369, theta=-42.894461 -> V=1.0, theta=0.0
% INFO    : Bus 19452	: V=0.9948243, theta=-46.377529 -> V=1.0, theta=0.0
% INFO    : Bus 19453	: V=0.9889822, theta=-46.612374 -> V=1.0, theta=0.0
% INFO    : Bus 19454	: V=0.9988023, theta=-45.447845 -> V=1.0, theta=0.0
% INFO    : Bus 19455	: V=0.9954448, theta=-46.207463 -> V=1.0, theta=0.0
% INFO    : Bus 19456	: V=0.9967897, theta=-45.905425 -> V=1.0, theta=0.0
% INFO    : Bus 19457	: V=0.9939648, theta=-46.317935 -> V=1.0, theta=0.0
% INFO    : Bus 19458	: V=0.9967001, theta=-45.96469 -> V=1.0, theta=0.0
% INFO    : Bus 19459	: V=0.9948623, theta=-46.377369 -> V=1.0, theta=0.0
% INFO    : Bus 19460	: V=1.001964, theta=-44.909177 -> V=1.0, theta=0.0
% INFO    : Bus 19461	: V=0.9963713, theta=-46.707803 -> V=1.0, theta=0.0
% INFO    : Bus 19462	: V=0.9952236, theta=-46.377318 -> V=1.0, theta=0.0
% INFO    : Bus 19463	: V=1.0135975, theta=-38.627698 -> V=1.0, theta=0.0
% INFO    : Bus 19464	: V=1.0161331, theta=-37.733053 -> V=1.0, theta=0.0
% INFO    : Bus 19465	: V=1.0129269, theta=-38.117476 -> V=1.0, theta=0.0
% INFO    : Bus 19466	: V=1.0131684, theta=-38.067252 -> V=1.0, theta=0.0
% INFO    : Bus 19467	: V=1.013732, theta=-37.980164 -> V=1.0, theta=0.0
% INFO    : Bus 19468	: V=1.0162398, theta=-38.335947 -> V=1.0, theta=0.0
% INFO    : Bus 19469	: V=1.0153072, theta=-38.518176 -> V=1.0, theta=0.0
% INFO    : Bus 19470	: V=0.9841946, theta=-44.297953 -> V=1.0, theta=0.0
% INFO    : Bus 19471	: V=0.9763747, theta=-44.926221 -> V=1.0, theta=0.0
% INFO    : Bus 19472	: V=0.9739632, theta=-45.086221 -> V=1.0, theta=0.0
% INFO    : Bus 19473	: V=0.9763692, theta=-44.863104 -> V=1.0, theta=0.0
% INFO    : Bus 19474	: V=0.979752, theta=-44.595103 -> V=1.0, theta=0.0
% INFO    : Bus 19475	: V=0.9803256, theta=-44.619173 -> V=1.0, theta=0.0
% INFO    : Bus 19476	: V=0.9895676, theta=-43.525011 -> V=1.0, theta=0.0
% INFO    : Bus 19477	: V=0.9852612, theta=-44.146789 -> V=1.0, theta=0.0
% INFO    : Bus 19478	: V=0.9891905, theta=-43.564724 -> V=1.0, theta=0.0
% INFO    : Bus 19479	: V=0.9936088, theta=-42.907606 -> V=1.0, theta=0.0
% INFO    : Bus 19480	: V=0.9888056, theta=-43.611357 -> V=1.0, theta=0.0
% INFO    : Bus 19481	: V=0.9795738, theta=-44.664605 -> V=1.0, theta=0.0
% INFO    : Bus 19482	: V=0.9785574, theta=-44.808863 -> V=1.0, theta=0.0
% INFO    : Bus 19483	: V=0.988769, theta=-43.635779 -> V=1.0, theta=0.0
% INFO    : Bus 19484	: V=0.9847794, theta=-44.188101 -> V=1.0, theta=0.0
% INFO    : Bus 19485	: V=1.0050837, theta=-41.211738 -> V=1.0, theta=0.0
% INFO    : Bus 19486	: V=0.9878716, theta=-43.790407 -> V=1.0, theta=0.0
% INFO    : Bus 19487	: V=0.9733073, theta=-45.108015 -> V=1.0, theta=0.0
% INFO    : Bus 19488	: V=0.9750946, theta=-45.06477 -> V=1.0, theta=0.0
% INFO    : Bus 19489	: V=0.994149, theta=-42.871994 -> V=1.0, theta=0.0
% INFO    : Bus 19490	: V=0.97948, theta=-51.699887 -> V=1.0, theta=0.0
% INFO    : Bus 19491	: V=0.9785244, theta=-51.855546 -> V=1.0, theta=0.0
% INFO    : Bus 19492	: V=0.973915, theta=-52.460866 -> V=1.0, theta=0.0
% INFO    : Bus 19493	: V=0.9897185, theta=-50.527128 -> V=1.0, theta=0.0
% INFO    : Bus 19494	: V=0.9798643, theta=-51.52862 -> V=1.0, theta=0.0
% INFO    : Bus 19495	: V=0.9742856, theta=-52.284224 -> V=1.0, theta=0.0
% INFO    : Bus 19496	: V=0.9827965, theta=-50.98845 -> V=1.0, theta=0.0
% INFO    : Bus 19497	: V=0.9765767, theta=-52.180273 -> V=1.0, theta=0.0
% INFO    : Bus 19498	: V=0.9762131, theta=-52.224472 -> V=1.0, theta=0.0
% INFO    : Bus 19499	: V=0.9713626, theta=-46.008818 -> V=1.0, theta=0.0
% INFO    : Bus 19500	: V=0.9760778, theta=-45.239319 -> V=1.0, theta=0.0
% INFO    : Bus 19501	: V=0.9755214, theta=-45.299858 -> V=1.0, theta=0.0
% INFO    : Bus 19502	: V=0.975704, theta=-45.278877 -> V=1.0, theta=0.0
% INFO    : Bus 19503	: V=0.9786594, theta=-45.168199 -> V=1.0, theta=0.0
% INFO    : Bus 19504	: V=0.9968459, theta=-40.947944 -> V=1.0, theta=0.0
% INFO    : Bus 19505	: V=0.9801501, theta=-42.789387 -> V=1.0, theta=0.0
% INFO    : Bus 19506	: V=0.9884557, theta=-42.007063 -> V=1.0, theta=0.0
% INFO    : Bus 19507	: V=0.9805227, theta=-42.784522 -> V=1.0, theta=0.0
% INFO    : Bus 19508	: V=0.9801894, theta=-42.706881 -> V=1.0, theta=0.0
% INFO    : Bus 19509	: V=0.9887921, theta=-41.965293 -> V=1.0, theta=0.0
% INFO    : Bus 19510	: V=0.989136, theta=-41.932917 -> V=1.0, theta=0.0
% INFO    : Bus 19511	: V=0.9895477, theta=-41.900001 -> V=1.0, theta=0.0
% INFO    : Bus 19512	: V=0.9897543, theta=-41.875867 -> V=1.0, theta=0.0
% INFO    : Bus 19513	: V=0.9827203, theta=-42.481677 -> V=1.0, theta=0.0
% INFO    : Bus 19514	: V=0.9970479, theta=-40.959744 -> V=1.0, theta=0.0
% INFO    : Bus 19515	: V=0.996829, theta=-40.989012 -> V=1.0, theta=0.0
% INFO    : Bus 19516	: V=0.9868302, theta=-41.964084 -> V=1.0, theta=0.0
% INFO    : Bus 19517	: V=0.995475, theta=-41.371321 -> V=1.0, theta=0.0
% INFO    : Bus 19518	: V=0.9980306, theta=-41.075158 -> V=1.0, theta=0.0
% INFO    : Bus 19519	: V=0.997958, theta=-41.109655 -> V=1.0, theta=0.0
% INFO    : Bus 19520	: V=0.9892361, theta=-41.409903 -> V=1.0, theta=0.0
% INFO    : Bus 19521	: V=0.9984328, theta=-41.023835 -> V=1.0, theta=0.0
% INFO    : Bus 19522	: V=0.9991311, theta=-40.945106 -> V=1.0, theta=0.0
% INFO    : Bus 19523	: V=1.003619, theta=-40.646403 -> V=1.0, theta=0.0
% INFO    : Bus 19524	: V=1.0013923, theta=-40.754174 -> V=1.0, theta=0.0
% INFO    : Bus 19525	: V=1.0024459, theta=-40.674239 -> V=1.0, theta=0.0
% INFO    : Bus 19526	: V=0.9989878, theta=-40.923502 -> V=1.0, theta=0.0
% INFO    : Bus 19527	: V=1.0092294, theta=-39.556333 -> V=1.0, theta=0.0
% INFO    : Bus 19528	: V=1.0040912, theta=-40.548282 -> V=1.0, theta=0.0
% INFO    : Bus 19529	: V=0.9956845, theta=-41.291881 -> V=1.0, theta=0.0
% INFO    : Bus 19530	: V=0.9959579, theta=-41.38687 -> V=1.0, theta=0.0
% INFO    : Bus 19531	: V=1.0085879, theta=-39.904944 -> V=1.0, theta=0.0
% INFO    : Bus 19532	: V=1.007016, theta=-40.038279 -> V=1.0, theta=0.0
% INFO    : Bus 19533	: V=0.9998177, theta=-40.880641 -> V=1.0, theta=0.0
% INFO    : Bus 19534	: V=0.9980732, theta=-41.131109 -> V=1.0, theta=0.0
% INFO    : Bus 19535	: V=1.0073762, theta=-40.120678 -> V=1.0, theta=0.0
% INFO    : Bus 19536	: V=0.9990316, theta=-41.072389 -> V=1.0, theta=0.0
% INFO    : Bus 19537	: V=1.0003623, theta=-40.90506 -> V=1.0, theta=0.0
% INFO    : Bus 19538	: V=1.007733, theta=-40.092433 -> V=1.0, theta=0.0
% INFO    : Bus 19539	: V=1.005954, theta=-40.191519 -> V=1.0, theta=0.0
% INFO    : Bus 19540	: V=1.0106498, theta=-39.234623 -> V=1.0, theta=0.0
% INFO    : Bus 19541	: V=1.0036, theta=-40.581127 -> V=1.0, theta=0.0
% INFO    : Bus 19542	: V=1.0094412, theta=-39.68797 -> V=1.0, theta=0.0
% INFO    : Bus 19543	: V=1.0029812, theta=-40.700219 -> V=1.0, theta=0.0
% INFO    : Bus 19544	: V=1.0050576, theta=-40.326516 -> V=1.0, theta=0.0
% INFO    : Bus 19545	: V=1.0085942, theta=-39.848646 -> V=1.0, theta=0.0
% INFO    : Bus 19546	: V=1.0121063, theta=-38.926357 -> V=1.0, theta=0.0
% INFO    : Bus 19547	: V=1.0105349, theta=-39.691138 -> V=1.0, theta=0.0
% INFO    : Bus 19548	: V=0.967739, theta=-44.302244 -> V=1.0, theta=0.0
% INFO    : Bus 19549	: V=0.9701131, theta=-44.138711 -> V=1.0, theta=0.0
% INFO    : Bus 19550	: V=0.9704825, theta=-44.102133 -> V=1.0, theta=0.0
% INFO    : Bus 19551	: V=0.9771983, theta=-43.700509 -> V=1.0, theta=0.0
% INFO    : Bus 19552	: V=0.9776374, theta=-43.608158 -> V=1.0, theta=0.0
% INFO    : Bus 19553	: V=0.9825767, theta=-42.894028 -> V=1.0, theta=0.0
% INFO    : Bus 19554	: V=0.9821658, theta=-42.915837 -> V=1.0, theta=0.0
% INFO    : Bus 19555	: V=0.971908, theta=-44.016323 -> V=1.0, theta=0.0
% INFO    : Bus 19556	: V=0.9771734, theta=-43.71533 -> V=1.0, theta=0.0
% INFO    : Bus 19557	: V=0.9843389, theta=-42.735911 -> V=1.0, theta=0.0
% INFO    : Bus 19558	: V=0.9936119, theta=-41.5574 -> V=1.0, theta=0.0
% INFO    : Bus 19559	: V=0.9819952, theta=-43.363257 -> V=1.0, theta=0.0
% INFO    : Bus 19560	: V=0.9828179, theta=-42.833122 -> V=1.0, theta=0.0
% INFO    : Bus 19561	: V=0.9753446, theta=-43.877299 -> V=1.0, theta=0.0
% INFO    : Bus 19562	: V=0.9703176, theta=-44.096775 -> V=1.0, theta=0.0
% INFO    : Bus 19563	: V=0.9748998, theta=-43.88936 -> V=1.0, theta=0.0
% INFO    : Bus 19564	: V=0.9766702, theta=-43.815627 -> V=1.0, theta=0.0
% INFO    : Bus 19565	: V=0.9730312, theta=-43.96458 -> V=1.0, theta=0.0
% INFO    : Bus 19566	: V=0.9673796, theta=-44.264565 -> V=1.0, theta=0.0
% INFO    : Bus 19567	: V=0.9692611, theta=-44.175843 -> V=1.0, theta=0.0
% INFO    : Bus 19568	: V=0.9714535, theta=-44.045347 -> V=1.0, theta=0.0
% INFO    : Bus 19569	: V=0.9700997, theta=-44.028398 -> V=1.0, theta=0.0
% INFO    : Bus 19570	: V=0.9706535, theta=-44.016794 -> V=1.0, theta=0.0
% INFO    : Bus 19571	: V=0.9684329, theta=-44.296255 -> V=1.0, theta=0.0
% INFO    : Bus 19572	: V=0.9814688, theta=-42.904937 -> V=1.0, theta=0.0
% INFO    : Bus 19573	: V=0.9694039, theta=-44.266779 -> V=1.0, theta=0.0
% INFO    : Bus 19574	: V=0.9678887, theta=-44.288405 -> V=1.0, theta=0.0
% INFO    : Bus 19575	: V=0.9689703, theta=-44.226216 -> V=1.0, theta=0.0
% INFO    : Bus 19576	: V=0.9684674, theta=-44.277501 -> V=1.0, theta=0.0
% INFO    : Bus 19577	: V=0.9683571, theta=-44.273963 -> V=1.0, theta=0.0
% INFO    : Bus 19578	: V=0.9686413, theta=-44.300145 -> V=1.0, theta=0.0
% INFO    : Bus 19579	: V=0.968925, theta=-44.312561 -> V=1.0, theta=0.0
% INFO    : Bus 19580	: V=0.9686399, theta=-44.304073 -> V=1.0, theta=0.0
% INFO    : Bus 19581	: V=0.9690009, theta=-44.299646 -> V=1.0, theta=0.0
% INFO    : Bus 19582	: V=0.9694242, theta=-44.242135 -> V=1.0, theta=0.0
% INFO    : Bus 19583	: V=0.9850248, theta=-42.634374 -> V=1.0, theta=0.0
% INFO    : Bus 19584	: V=0.9855053, theta=-42.600363 -> V=1.0, theta=0.0
% INFO    : Bus 19585	: V=0.9699101, theta=-44.238581 -> V=1.0, theta=0.0
% INFO    : Bus 19586	: V=0.9692012, theta=-44.293054 -> V=1.0, theta=0.0
% INFO    : Bus 19587	: V=0.9696348, theta=-44.273925 -> V=1.0, theta=0.0
% INFO    : Bus 19588	: V=0.9685927, theta=-44.312367 -> V=1.0, theta=0.0
% INFO    : Bus 19589	: V=0.9694674, theta=-44.277579 -> V=1.0, theta=0.0
% INFO    : Bus 19590	: V=0.9697121, theta=-44.287319 -> V=1.0, theta=0.0
% INFO    : Bus 19591	: V=0.9722386, theta=-44.182086 -> V=1.0, theta=0.0
% INFO    : Bus 19592	: V=0.9713632, theta=-44.201718 -> V=1.0, theta=0.0
% INFO    : Bus 19593	: V=0.9702883, theta=-44.264266 -> V=1.0, theta=0.0
% INFO    : Bus 19594	: V=0.9692324, theta=-44.296511 -> V=1.0, theta=0.0
% INFO    : Bus 19595	: V=0.9858896, theta=-42.573684 -> V=1.0, theta=0.0
% INFO    : Bus 19596	: V=1.0053891, theta=-40.025504 -> V=1.0, theta=0.0
% INFO    : Bus 19597	: V=0.9866687, theta=-42.538319 -> V=1.0, theta=0.0
% INFO    : Bus 19598	: V=0.9737528, theta=-43.978735 -> V=1.0, theta=0.0
% INFO    : Bus 19599	: V=0.9667561, theta=-44.266903 -> V=1.0, theta=0.0
% INFO    : Bus 19600	: V=0.9679159, theta=-44.181661 -> V=1.0, theta=0.0
% INFO    : Bus 19601	: V=0.9777962, theta=-43.271767 -> V=1.0, theta=0.0
% INFO    : Bus 19602	: V=0.9673993, theta=-44.251438 -> V=1.0, theta=0.0
% INFO    : Bus 19603	: V=0.9763615, theta=-43.383708 -> V=1.0, theta=0.0
% INFO    : Bus 19604	: V=0.97605, theta=-43.438869 -> V=1.0, theta=0.0
% INFO    : Bus 19605	: V=0.9693244, theta=-44.357627 -> V=1.0, theta=0.0
% INFO    : Bus 19606	: V=0.9680838, theta=-44.411284 -> V=1.0, theta=0.0
% INFO    : Bus 19607	: V=0.9673993, theta=-44.279774 -> V=1.0, theta=0.0
% INFO    : Bus 19608	: V=0.969906, theta=-44.31522 -> V=1.0, theta=0.0
% INFO    : Bus 19609	: V=0.9671269, theta=-44.460804 -> V=1.0, theta=0.0
% INFO    : Bus 19610	: V=0.9834652, theta=-42.86531 -> V=1.0, theta=0.0
% INFO    : Bus 19611	: V=0.9647312, theta=-44.428388 -> V=1.0, theta=0.0
% INFO    : Bus 19612	: V=0.9624857, theta=-44.56374 -> V=1.0, theta=0.0
% INFO    : Bus 19613	: V=0.9666238, theta=-44.268269 -> V=1.0, theta=0.0
% INFO    : Bus 19614	: V=0.9645437, theta=-44.366189 -> V=1.0, theta=0.0
% INFO    : Bus 19615	: V=0.9638305, theta=-44.419781 -> V=1.0, theta=0.0
% INFO    : Bus 19616	: V=0.9631073, theta=-44.469589 -> V=1.0, theta=0.0
% INFO    : Bus 19617	: V=0.9637621, theta=-44.466361 -> V=1.0, theta=0.0
% INFO    : Bus 19618	: V=0.965621, theta=-44.37507 -> V=1.0, theta=0.0
% INFO    : Bus 19619	: V=0.9708196, theta=-44.276876 -> V=1.0, theta=0.0
% INFO    : Bus 19620	: V=0.9676985, theta=-44.525336 -> V=1.0, theta=0.0
% INFO    : Bus 19621	: V=0.9677883, theta=-44.564239 -> V=1.0, theta=0.0
% INFO    : Bus 19622	: V=0.9671016, theta=-44.587006 -> V=1.0, theta=0.0
% INFO    : Bus 19623	: V=0.9702221, theta=-44.373197 -> V=1.0, theta=0.0
% INFO    : Bus 19624	: V=0.9693867, theta=-44.392709 -> V=1.0, theta=0.0
% INFO    : Bus 19625	: V=0.9692118, theta=-44.118112 -> V=1.0, theta=0.0
% INFO    : Bus 19626	: V=1.0034057, theta=-40.240433 -> V=1.0, theta=0.0
% INFO    : Bus 19627	: V=0.9714008, theta=-44.261545 -> V=1.0, theta=0.0
% INFO    : Bus 19628	: V=0.997763, theta=-42.207829 -> V=1.0, theta=0.0
% INFO    : Bus 19629	: V=0.9768066, theta=-41.565625 -> V=1.0, theta=0.0
% INFO    : Bus 19630	: V=0.9968078, theta=-39.5072 -> V=1.0, theta=0.0
% INFO    : Bus 19631	: V=0.9793208, theta=-41.270588 -> V=1.0, theta=0.0
% INFO    : Bus 19632	: V=0.9776168, theta=-41.354292 -> V=1.0, theta=0.0
% INFO    : Bus 19633	: V=0.9774469, theta=-41.473098 -> V=1.0, theta=0.0
% INFO    : Bus 19634	: V=0.9781114, theta=-41.460816 -> V=1.0, theta=0.0
% INFO    : Bus 19635	: V=0.9775676, theta=-41.483522 -> V=1.0, theta=0.0
% INFO    : Bus 19636	: V=0.9731214, theta=-41.892716 -> V=1.0, theta=0.0
% INFO    : Bus 19637	: V=0.970741, theta=-42.026852 -> V=1.0, theta=0.0
% INFO    : Bus 19638	: V=0.9968401, theta=-39.433193 -> V=1.0, theta=0.0
% INFO    : Bus 19639	: V=0.9962115, theta=-39.538249 -> V=1.0, theta=0.0
% INFO    : Bus 19640	: V=0.9870963, theta=-42.119119 -> V=1.0, theta=0.0
% INFO    : Bus 19641	: V=0.9961117, theta=-41.414713 -> V=1.0, theta=0.0
% INFO    : Bus 19642	: V=0.993372, theta=-41.753294 -> V=1.0, theta=0.0
% INFO    : Bus 19643	: V=0.9884148, theta=-42.423962 -> V=1.0, theta=0.0
% INFO    : Bus 19644	: V=0.9760362, theta=-43.550078 -> V=1.0, theta=0.0
% INFO    : Bus 19645	: V=0.9757517, theta=-43.543918 -> V=1.0, theta=0.0
% INFO    : Bus 19646	: V=0.9768174, theta=-43.522011 -> V=1.0, theta=0.0
% INFO    : Bus 19647	: V=0.9803751, theta=-43.342619 -> V=1.0, theta=0.0
% INFO    : Bus 19648	: V=0.9832262, theta=-43.12715 -> V=1.0, theta=0.0
% INFO    : Bus 19649	: V=0.9811239, theta=-43.283605 -> V=1.0, theta=0.0
% INFO    : Bus 19650	: V=0.9769946, theta=-43.511452 -> V=1.0, theta=0.0
% INFO    : Bus 19651	: V=0.9762205, theta=-43.545347 -> V=1.0, theta=0.0
% INFO    : Bus 19652	: V=0.9754441, theta=-43.564588 -> V=1.0, theta=0.0
% INFO    : Bus 19653	: V=0.9790169, theta=-43.38584 -> V=1.0, theta=0.0
% INFO    : Bus 19654	: V=0.9815503, theta=-43.266358 -> V=1.0, theta=0.0
% INFO    : Bus 19655	: V=0.9816838, theta=-43.253277 -> V=1.0, theta=0.0
% INFO    : Bus 19656	: V=0.9823641, theta=-43.235148 -> V=1.0, theta=0.0
% INFO    : Bus 19657	: V=0.9835158, theta=-43.170848 -> V=1.0, theta=0.0
% INFO    : Bus 19658	: V=0.9847042, theta=-43.064955 -> V=1.0, theta=0.0
% INFO    : Bus 19659	: V=0.9818709, theta=-43.246126 -> V=1.0, theta=0.0
% INFO    : Bus 19660	: V=0.9811609, theta=-43.251445 -> V=1.0, theta=0.0
% INFO    : Bus 19661	: V=0.9796132, theta=-43.346963 -> V=1.0, theta=0.0
% INFO    : Bus 19662	: V=0.9799042, theta=-42.911421 -> V=1.0, theta=0.0
% INFO    : Bus 19663	: V=0.9790473, theta=-43.348177 -> V=1.0, theta=0.0
% INFO    : Bus 19664	: V=0.9784702, theta=-42.977747 -> V=1.0, theta=0.0
% INFO    : Bus 19665	: V=0.9772702, theta=-43.011682 -> V=1.0, theta=0.0
% INFO    : Bus 19666	: V=0.9753659, theta=-43.551944 -> V=1.0, theta=0.0
% INFO    : Bus 19667	: V=0.9878456, theta=-42.421282 -> V=1.0, theta=0.0
% INFO    : Bus 19668	: V=0.9765672, theta=-43.465951 -> V=1.0, theta=0.0
% INFO    : Bus 19669	: V=0.9836645, theta=-42.468435 -> V=1.0, theta=0.0
% INFO    : Bus 19670	: V=0.9860939, theta=-42.453401 -> V=1.0, theta=0.0
% INFO    : Bus 19671	: V=0.9854209, theta=-42.433116 -> V=1.0, theta=0.0
% INFO    : Bus 19672	: V=0.982135, theta=-43.140746 -> V=1.0, theta=0.0
% INFO    : Bus 19673	: V=0.986057, theta=-43.070716 -> V=1.0, theta=0.0
% INFO    : Bus 19674	: V=0.9688465, theta=-49.593181 -> V=1.0, theta=0.0
% INFO    : Bus 19675	: V=0.9682144, theta=-49.833541 -> V=1.0, theta=0.0
% INFO    : Bus 19676	: V=0.9701049, theta=-49.522988 -> V=1.0, theta=0.0
% INFO    : Bus 19677	: V=0.9866044, theta=-43.201189 -> V=1.0, theta=0.0
% INFO    : Bus 19678	: V=0.9959281, theta=-42.091021 -> V=1.0, theta=0.0
% INFO    : Bus 19679	: V=0.9960247, theta=-42.058543 -> V=1.0, theta=0.0
% INFO    : Bus 19680	: V=0.9965318, theta=-41.984708 -> V=1.0, theta=0.0
% INFO    : Bus 19681	: V=0.9927049, theta=-42.402854 -> V=1.0, theta=0.0
% INFO    : Bus 19682	: V=0.9965971, theta=-41.968063 -> V=1.0, theta=0.0
% INFO    : Bus 19683	: V=0.9929148, theta=-42.391804 -> V=1.0, theta=0.0
% INFO    : Bus 19684	: V=0.9931515, theta=-42.382158 -> V=1.0, theta=0.0
% INFO    : Bus 19685	: V=0.9936115, theta=-42.268418 -> V=1.0, theta=0.0
% INFO    : Bus 19686	: V=0.993603, theta=-42.144264 -> V=1.0, theta=0.0
% INFO    : Bus 19687	: V=0.9968222, theta=-41.938449 -> V=1.0, theta=0.0
% INFO    : Bus 19688	: V=0.9947088, theta=-41.981644 -> V=1.0, theta=0.0
% INFO    : Bus 19689	: V=0.9998473, theta=-41.579556 -> V=1.0, theta=0.0
% INFO    : Bus 19690	: V=1.0002505, theta=-41.536387 -> V=1.0, theta=0.0
% INFO    : Bus 19691	: V=0.9954888, theta=-41.970887 -> V=1.0, theta=0.0
% INFO    : Bus 19692	: V=0.9975101, theta=-41.804303 -> V=1.0, theta=0.0
% INFO    : Bus 19693	: V=0.997796, theta=-41.769041 -> V=1.0, theta=0.0
% INFO    : Bus 19694	: V=0.9978104, theta=-41.770152 -> V=1.0, theta=0.0
% INFO    : Bus 19695	: V=0.9972173, theta=-41.775681 -> V=1.0, theta=0.0
% INFO    : Bus 19696	: V=1.0011719, theta=-41.438541 -> V=1.0, theta=0.0
% INFO    : Bus 19697	: V=1.0017203, theta=-41.367896 -> V=1.0, theta=0.0
% INFO    : Bus 19698	: V=1.000369, theta=-41.506337 -> V=1.0, theta=0.0
% INFO    : Bus 19699	: V=1.0017212, theta=-41.34853 -> V=1.0, theta=0.0
% INFO    : Bus 19700	: V=0.9945062, theta=-42.135589 -> V=1.0, theta=0.0
% INFO    : Bus 19701	: V=0.9979014, theta=-41.812379 -> V=1.0, theta=0.0
% INFO    : Bus 19702	: V=1.0109959, theta=-39.998218 -> V=1.0, theta=0.0
% INFO    : Bus 19703	: V=1.0094677, theta=-40.272838 -> V=1.0, theta=0.0
% INFO    : Bus 19704	: V=0.9984616, theta=-41.746103 -> V=1.0, theta=0.0
% INFO    : Bus 19705	: V=0.9961401, theta=-42.00744 -> V=1.0, theta=0.0
% INFO    : Bus 19706	: V=0.9980971, theta=-41.792255 -> V=1.0, theta=0.0
% INFO    : Bus 19707	: V=0.994792, theta=-42.141637 -> V=1.0, theta=0.0
% INFO    : Bus 19708	: V=0.9925417, theta=-42.300542 -> V=1.0, theta=0.0
% INFO    : Bus 19709	: V=0.99262, theta=-42.297959 -> V=1.0, theta=0.0
% INFO    : Bus 19710	: V=0.9952996, theta=-42.109443 -> V=1.0, theta=0.0
% INFO    : Bus 19711	: V=0.9983613, theta=-41.746731 -> V=1.0, theta=0.0
% INFO    : Bus 19712	: V=0.9987041, theta=-41.688431 -> V=1.0, theta=0.0
% INFO    : Bus 19713	: V=0.9980964, theta=-41.837528 -> V=1.0, theta=0.0
% INFO    : Bus 19714	: V=1.000425, theta=-41.453102 -> V=1.0, theta=0.0
% INFO    : Bus 19715	: V=0.999232, theta=-41.590726 -> V=1.0, theta=0.0
% INFO    : Bus 19716	: V=0.9919572, theta=-42.153103 -> V=1.0, theta=0.0
% INFO    : Bus 19717	: V=0.9924327, theta=-42.304802 -> V=1.0, theta=0.0
% INFO    : Bus 19718	: V=0.9924363, theta=-42.298891 -> V=1.0, theta=0.0
% INFO    : Bus 19719	: V=0.9914751, theta=-42.483614 -> V=1.0, theta=0.0
% INFO    : Bus 19720	: V=0.9906529, theta=-42.45138 -> V=1.0, theta=0.0
% INFO    : Bus 19721	: V=0.9882272, theta=-42.657596 -> V=1.0, theta=0.0
% INFO    : Bus 19722	: V=0.9932844, theta=-42.220555 -> V=1.0, theta=0.0
% INFO    : Bus 19723	: V=1.0055516, theta=-40.82955 -> V=1.0, theta=0.0
% INFO    : Bus 19724	: V=1.0024156, theta=-41.141446 -> V=1.0, theta=0.0
% INFO    : Bus 19725	: V=1.0012269, theta=-41.279728 -> V=1.0, theta=0.0
% INFO    : Bus 19726	: V=0.9998661, theta=-41.4283 -> V=1.0, theta=0.0
% INFO    : Bus 19727	: V=1.0135977, theta=-39.680883 -> V=1.0, theta=0.0
% INFO    : Bus 19728	: V=1.0089911, theta=-40.513687 -> V=1.0, theta=0.0
% INFO    : Bus 19729	: V=1.0107268, theta=-40.371846 -> V=1.0, theta=0.0
% INFO    : Bus 19730	: V=1.0029102, theta=-41.16522 -> V=1.0, theta=0.0
% INFO    : Bus 19731	: V=0.9832753, theta=-42.855996 -> V=1.0, theta=0.0
% INFO    : Bus 19732	: V=0.9808042, theta=-42.810511 -> V=1.0, theta=0.0
% INFO    : Bus 19733	: V=0.9821252, theta=-42.7587 -> V=1.0, theta=0.0
% INFO    : Bus 19734	: V=0.9875217, theta=-42.345994 -> V=1.0, theta=0.0
% INFO    : Bus 19735	: V=0.9905993, theta=-42.155995 -> V=1.0, theta=0.0
% INFO    : Bus 19736	: V=0.9856358, theta=-42.454976 -> V=1.0, theta=0.0
% INFO    : Bus 19737	: V=0.9866286, theta=-42.348843 -> V=1.0, theta=0.0
% INFO    : Bus 19738	: V=0.9924845, theta=-42.023439 -> V=1.0, theta=0.0
% INFO    : Bus 19739	: V=1.0052165, theta=-40.748409 -> V=1.0, theta=0.0
% INFO    : Bus 19740	: V=0.9823128, theta=-42.788386 -> V=1.0, theta=0.0
% INFO    : Bus 19741	: V=0.9871633, theta=-42.371724 -> V=1.0, theta=0.0
% INFO    : Bus 19742	: V=0.9848165, theta=-42.644004 -> V=1.0, theta=0.0
% INFO    : Bus 19743	: V=0.9575477, theta=-49.376441 -> V=1.0, theta=0.0
% INFO    : Bus 19744	: V=0.9550671, theta=-49.598977 -> V=1.0, theta=0.0
% INFO    : Bus 19745	: V=0.9547983, theta=-49.548263 -> V=1.0, theta=0.0
% INFO    : Bus 19746	: V=0.9548848, theta=-49.435718 -> V=1.0, theta=0.0
% INFO    : Bus 19747	: V=0.9557551, theta=-49.240801 -> V=1.0, theta=0.0
% INFO    : Bus 19748	: V=0.9560936, theta=-49.084561 -> V=1.0, theta=0.0
% INFO    : Bus 19749	: V=0.9575568, theta=-49.382417 -> V=1.0, theta=0.0
% INFO    : Bus 19750	: V=0.9567378, theta=-49.420941 -> V=1.0, theta=0.0
% INFO    : Bus 19751	: V=0.9477348, theta=-50.841679 -> V=1.0, theta=0.0
% INFO    : Bus 19752	: V=0.9488688, theta=-50.75845 -> V=1.0, theta=0.0
% INFO    : Bus 19753	: V=0.9565999, theta=-49.417277 -> V=1.0, theta=0.0
% INFO    : Bus 19754	: V=0.9567121, theta=-49.437542 -> V=1.0, theta=0.0
% INFO    : Bus 19755	: V=0.9573232, theta=-49.474353 -> V=1.0, theta=0.0
% INFO    : Bus 19756	: V=0.9584667, theta=-49.28689 -> V=1.0, theta=0.0
% INFO    : Bus 19757	: V=0.958041, theta=-49.311008 -> V=1.0, theta=0.0
% INFO    : Bus 19758	: V=0.9539551, theta=-49.738199 -> V=1.0, theta=0.0
% INFO    : Bus 19759	: V=0.9535124, theta=-49.77398 -> V=1.0, theta=0.0
% INFO    : Bus 19760	: V=0.9470583, theta=-50.617989 -> V=1.0, theta=0.0
% INFO    : Bus 19761	: V=0.9478779, theta=-50.569654 -> V=1.0, theta=0.0
% INFO    : Bus 19762	: V=0.9575702, theta=-49.103076 -> V=1.0, theta=0.0
% INFO    : Bus 19763	: V=0.9570425, theta=-49.265739 -> V=1.0, theta=0.0
% INFO    : Bus 19764	: V=0.9565278, theta=-49.372327 -> V=1.0, theta=0.0
% INFO    : Bus 19765	: V=0.9508311, theta=-50.604886 -> V=1.0, theta=0.0
% INFO    : Bus 19766	: V=0.9590544, theta=-49.217141 -> V=1.0, theta=0.0
% INFO    : Bus 19767	: V=0.9615339, theta=-48.926845 -> V=1.0, theta=0.0
% INFO    : Bus 19768	: V=1.0017457, theta=-42.587089 -> V=1.0, theta=0.0
% INFO    : Bus 19769	: V=0.9591074, theta=-49.281058 -> V=1.0, theta=0.0
% INFO    : Bus 19770	: V=0.9538108, theta=-50.196339 -> V=1.0, theta=0.0
% INFO    : Bus 19771	: V=1.0098813, theta=-42.242089 -> V=1.0, theta=0.0
% INFO    : Bus 19772	: V=1.0101776, theta=-42.183751 -> V=1.0, theta=0.0
% INFO    : Bus 19773	: V=1.0127507, theta=-41.640992 -> V=1.0, theta=0.0
% INFO    : Bus 19774	: V=1.0024815, theta=-42.766216 -> V=1.0, theta=0.0
% INFO    : Bus 19775	: V=1.0047012, theta=-42.693535 -> V=1.0, theta=0.0
% INFO    : Bus 19776	: V=1.0154323, theta=-40.866664 -> V=1.0, theta=0.0
% INFO    : Bus 19777	: V=0.9598054, theta=-43.917727 -> V=1.0, theta=0.0
% INFO    : Bus 19778	: V=0.9625685, theta=-43.857407 -> V=1.0, theta=0.0
% INFO    : Bus 19779	: V=0.9617912, theta=-43.894197 -> V=1.0, theta=0.0
% INFO    : Bus 19780	: V=0.960442, theta=-43.927019 -> V=1.0, theta=0.0
% INFO    : Bus 19781	: V=0.9598484, theta=-43.934557 -> V=1.0, theta=0.0
% INFO    : Bus 19782	: V=0.9846188, theta=-42.396153 -> V=1.0, theta=0.0
% INFO    : Bus 19783	: V=0.9852619, theta=-42.233567 -> V=1.0, theta=0.0
% INFO    : Bus 19784	: V=0.9653393, theta=-43.685816 -> V=1.0, theta=0.0
% INFO    : Bus 19785	: V=0.9679753, theta=-43.683852 -> V=1.0, theta=0.0
% INFO    : Bus 19786	: V=0.968442, theta=-43.660652 -> V=1.0, theta=0.0
% INFO    : Bus 19787	: V=0.9687925, theta=-43.669556 -> V=1.0, theta=0.0
% INFO    : Bus 19788	: V=0.9886105, theta=-41.874963 -> V=1.0, theta=0.0
% INFO    : Bus 19789	: V=0.9811117, theta=-41.88681 -> V=1.0, theta=0.0
% INFO    : Bus 19790	: V=0.9696349, theta=-42.968345 -> V=1.0, theta=0.0
% INFO    : Bus 19791	: V=0.972455, theta=-42.673255 -> V=1.0, theta=0.0
% INFO    : Bus 19792	: V=0.9615401, theta=-43.805207 -> V=1.0, theta=0.0
% INFO    : Bus 19793	: V=0.9653608, theta=-43.729613 -> V=1.0, theta=0.0
% INFO    : Bus 19794	: V=0.9696585, theta=-43.53412 -> V=1.0, theta=0.0
% INFO    : Bus 19795	: V=0.9604121, theta=-43.885517 -> V=1.0, theta=0.0
% INFO    : Bus 19796	: V=0.9721405, theta=-43.203646 -> V=1.0, theta=0.0
% INFO    : Bus 19797	: V=0.9599843, theta=-43.946362 -> V=1.0, theta=0.0
% INFO    : Bus 19798	: V=0.9613588, theta=-43.337333 -> V=1.0, theta=0.0
% INFO    : Bus 19799	: V=0.9675854, theta=-43.311448 -> V=1.0, theta=0.0
% INFO    : Bus 19800	: V=0.9683504, theta=-43.213772 -> V=1.0, theta=0.0
% INFO    : Bus 19801	: V=0.9689767, theta=-43.176044 -> V=1.0, theta=0.0
% INFO    : Bus 19802	: V=0.9702987, theta=-43.094357 -> V=1.0, theta=0.0
% INFO    : Bus 19803	: V=0.9758577, theta=-42.623527 -> V=1.0, theta=0.0
% INFO    : Bus 19804	: V=0.9791323, theta=-42.328893 -> V=1.0, theta=0.0
% INFO    : Bus 19805	: V=0.961624, theta=-44.868798 -> V=1.0, theta=0.0
% INFO    : Bus 19806	: V=1.0023422, theta=-40.345514 -> V=1.0, theta=0.0
% INFO    : Bus 19807	: V=0.9753409, theta=-43.578333 -> V=1.0, theta=0.0
% INFO    : Bus 19808	: V=0.9708768, theta=-44.206506 -> V=1.0, theta=0.0
% INFO    : Bus 19809	: V=0.9744042, theta=-43.682409 -> V=1.0, theta=0.0
% INFO    : Bus 19810	: V=0.9632609, theta=-44.765047 -> V=1.0, theta=0.0
% INFO    : Bus 19811	: V=0.9625277, theta=-45.05449 -> V=1.0, theta=0.0
% INFO    : Bus 19812	: V=0.9641314, theta=-44.737453 -> V=1.0, theta=0.0
% INFO    : Bus 19813	: V=0.9713546, theta=-44.109888 -> V=1.0, theta=0.0
% INFO    : Bus 19814	: V=0.9619903, theta=-45.118818 -> V=1.0, theta=0.0
% INFO    : Bus 19815	: V=0.9630512, theta=-45.016231 -> V=1.0, theta=0.0
% INFO    : Bus 19816	: V=0.9600174, theta=-45.228945 -> V=1.0, theta=0.0
% INFO    : Bus 19817	: V=0.9705336, theta=-44.028519 -> V=1.0, theta=0.0
% INFO    : Bus 19818	: V=0.9611157, theta=-45.152795 -> V=1.0, theta=0.0
% INFO    : Bus 19819	: V=0.9602317, theta=-45.109785 -> V=1.0, theta=0.0
% INFO    : Bus 19820	: V=0.9597339, theta=-45.260797 -> V=1.0, theta=0.0
% INFO    : Bus 19821	: V=0.9593474, theta=-45.638161 -> V=1.0, theta=0.0
% INFO    : Bus 19822	: V=0.9607319, theta=-45.618291 -> V=1.0, theta=0.0
% INFO    : Bus 19823	: V=0.9672283, theta=-44.531976 -> V=1.0, theta=0.0
% INFO    : Bus 19824	: V=0.9680945, theta=-44.440727 -> V=1.0, theta=0.0
% INFO    : Bus 19825	: V=0.9668635, theta=-44.568923 -> V=1.0, theta=0.0
% INFO    : Bus 19826	: V=0.9641804, theta=-45.36138 -> V=1.0, theta=0.0
% INFO    : Bus 19827	: V=0.9638421, theta=-45.334236 -> V=1.0, theta=0.0
% INFO    : Bus 19828	: V=0.9589101, theta=-45.630292 -> V=1.0, theta=0.0
% INFO    : Bus 19829	: V=0.9673768, theta=-44.309157 -> V=1.0, theta=0.0
% INFO    : Bus 19830	: V=0.9665436, theta=-44.383987 -> V=1.0, theta=0.0
% INFO    : Bus 19831	: V=0.9574528, theta=-46.122883 -> V=1.0, theta=0.0
% INFO    : Bus 19832	: V=0.955626, theta=-46.427489 -> V=1.0, theta=0.0
% INFO    : Bus 19833	: V=0.9540858, theta=-46.640672 -> V=1.0, theta=0.0
% INFO    : Bus 19834	: V=0.9530925, theta=-46.78205 -> V=1.0, theta=0.0
% INFO    : Bus 19835	: V=0.9521332, theta=-46.904254 -> V=1.0, theta=0.0
% INFO    : Bus 19836	: V=0.9528298, theta=-46.926131 -> V=1.0, theta=0.0
% INFO    : Bus 19837	: V=0.9510779, theta=-46.948779 -> V=1.0, theta=0.0
% INFO    : Bus 19838	: V=0.9539234, theta=-46.852388 -> V=1.0, theta=0.0
% INFO    : Bus 19839	: V=0.9588615, theta=-45.70456 -> V=1.0, theta=0.0
% INFO    : Bus 19840	: V=0.9582555, theta=-45.751814 -> V=1.0, theta=0.0
% INFO    : Bus 19841	: V=0.9587302, theta=-45.727154 -> V=1.0, theta=0.0
% INFO    : Bus 19842	: V=0.9537134, theta=-46.802904 -> V=1.0, theta=0.0
% INFO    : Bus 19843	: V=0.9542651, theta=-46.762369 -> V=1.0, theta=0.0
% INFO    : Bus 19844	: V=0.9621134, theta=-45.394543 -> V=1.0, theta=0.0
% INFO    : Bus 19845	: V=0.963203, theta=-45.362211 -> V=1.0, theta=0.0
% INFO    : Bus 19846	: V=0.968954, theta=-44.629733 -> V=1.0, theta=0.0
% INFO    : Bus 19847	: V=0.9554755, theta=-46.521493 -> V=1.0, theta=0.0
% INFO    : Bus 19848	: V=0.961652, theta=-45.61985 -> V=1.0, theta=0.0
% INFO    : Bus 19849	: V=0.9732231, theta=-44.138514 -> V=1.0, theta=0.0
% INFO    : Bus 19850	: V=0.9823523, theta=-42.804211 -> V=1.0, theta=0.0
% INFO    : Bus 19851	: V=0.9669395, theta=-44.815574 -> V=1.0, theta=0.0
% INFO    : Bus 19852	: V=0.9516155, theta=-46.644842 -> V=1.0, theta=0.0
% INFO    : Bus 19853	: V=0.9623482, theta=-45.514685 -> V=1.0, theta=0.0
% INFO    : Bus 19854	: V=0.9620264, theta=-45.523324 -> V=1.0, theta=0.0
% INFO    : Bus 19855	: V=0.9596317, theta=-46.224338 -> V=1.0, theta=0.0
% INFO    : Bus 19856	: V=0.9533336, theta=-46.594653 -> V=1.0, theta=0.0
% INFO    : Bus 19857	: V=0.9605547, theta=-45.7165 -> V=1.0, theta=0.0
% INFO    : Bus 19858	: V=0.9610902, theta=-45.704871 -> V=1.0, theta=0.0
% INFO    : Bus 19859	: V=0.9560236, theta=-46.285949 -> V=1.0, theta=0.0
% INFO    : Bus 19860	: V=0.9569673, theta=-46.385633 -> V=1.0, theta=0.0
% INFO    : Bus 19861	: V=0.9547035, theta=-46.569953 -> V=1.0, theta=0.0
% INFO    : Bus 19862	: V=0.9551481, theta=-46.557098 -> V=1.0, theta=0.0
% INFO    : Bus 19863	: V=0.9542681, theta=-46.571621 -> V=1.0, theta=0.0
% INFO    : Bus 19864	: V=0.9561753, theta=-46.492827 -> V=1.0, theta=0.0
% INFO    : Bus 19865	: V=0.9616607, theta=-45.208296 -> V=1.0, theta=0.0
% INFO    : Bus 19866	: V=0.9614015, theta=-45.277742 -> V=1.0, theta=0.0
% INFO    : Bus 19867	: V=0.9695563, theta=-44.294587 -> V=1.0, theta=0.0
% INFO    : Bus 19868	: V=0.9619516, theta=-45.382773 -> V=1.0, theta=0.0
% INFO    : Bus 19869	: V=0.9704421, theta=-44.227305 -> V=1.0, theta=0.0
% INFO    : Bus 19870	: V=0.962392, theta=-45.434119 -> V=1.0, theta=0.0
% INFO    : Bus 19871	: V=0.9615407, theta=-45.506133 -> V=1.0, theta=0.0
% INFO    : Bus 19872	: V=0.9610495, theta=-45.407462 -> V=1.0, theta=0.0
% INFO    : Bus 19873	: V=0.9607613, theta=-45.415634 -> V=1.0, theta=0.0
% INFO    : Bus 19874	: V=0.9615491, theta=-45.564211 -> V=1.0, theta=0.0
% INFO    : Bus 19875	: V=0.9611305, theta=-45.631263 -> V=1.0, theta=0.0
% INFO    : Bus 19876	: V=0.9645396, theta=-44.740466 -> V=1.0, theta=0.0
% INFO    : Bus 19877	: V=0.9645387, theta=-44.950424 -> V=1.0, theta=0.0
% INFO    : Bus 19878	: V=0.9718126, theta=-44.101466 -> V=1.0, theta=0.0
% INFO    : Bus 19879	: V=0.9646761, theta=-44.720811 -> V=1.0, theta=0.0
% INFO    : Bus 19880	: V=0.965898, theta=-44.682867 -> V=1.0, theta=0.0
% INFO    : Bus 19881	: V=0.966466, theta=-44.888644 -> V=1.0, theta=0.0
% INFO    : Bus 19882	: V=0.9697907, theta=-44.274047 -> V=1.0, theta=0.0
% INFO    : Bus 19883	: V=0.9634132, theta=-45.363479 -> V=1.0, theta=0.0
% INFO    : Bus 19884	: V=0.9642447, theta=-45.341192 -> V=1.0, theta=0.0
% INFO    : Bus 19885	: V=0.9606346, theta=-45.793199 -> V=1.0, theta=0.0
% INFO    : Bus 19886	: V=0.9592735, theta=-45.828095 -> V=1.0, theta=0.0
% INFO    : Bus 19887	: V=0.9754787, theta=-43.818923 -> V=1.0, theta=0.0
% INFO    : Bus 19888	: V=0.9746362, theta=-43.822422 -> V=1.0, theta=0.0
% INFO    : Bus 19889	: V=0.9752699, theta=-43.987983 -> V=1.0, theta=0.0
% INFO    : Bus 19890	: V=0.965508, theta=-44.745748 -> V=1.0, theta=0.0
% INFO    : Bus 19891	: V=0.9671464, theta=-44.712801 -> V=1.0, theta=0.0
% INFO    : Bus 19892	: V=0.9773459, theta=-43.597045 -> V=1.0, theta=0.0
% INFO    : Bus 19893	: V=0.9672346, theta=-44.730137 -> V=1.0, theta=0.0
% INFO    : Bus 19894	: V=0.9666457, theta=-44.982456 -> V=1.0, theta=0.0
% INFO    : Bus 19895	: V=0.9715363, theta=-44.370552 -> V=1.0, theta=0.0
% INFO    : Bus 19896	: V=0.9822094, theta=-43.11658 -> V=1.0, theta=0.0
% INFO    : Bus 19897	: V=0.9761405, theta=-43.868796 -> V=1.0, theta=0.0
% INFO    : Bus 19898	: V=0.975461, theta=-43.924959 -> V=1.0, theta=0.0
% INFO    : Bus 19899	: V=0.9796546, theta=-43.363101 -> V=1.0, theta=0.0
% INFO    : Bus 19900	: V=0.9731189, theta=-44.151505 -> V=1.0, theta=0.0
% INFO    : Bus 19901	: V=0.9692962, theta=-44.600436 -> V=1.0, theta=0.0
% INFO    : Bus 19902	: V=0.9754559, theta=-43.790124 -> V=1.0, theta=0.0
% INFO    : Bus 19903	: V=0.941558, theta=-46.361045 -> V=1.0, theta=0.0
% INFO    : Bus 19904	: V=1.0086244, theta=-42.455935 -> V=1.0, theta=0.0
% INFO    : Bus 19905	: V=1.0084264, theta=-42.472287 -> V=1.0, theta=0.0
% INFO    : Bus 19906	: V=1.0169455, theta=-41.562487 -> V=1.0, theta=0.0
% INFO    : Bus 19907	: V=1.0167474, theta=-41.502099 -> V=1.0, theta=0.0
% INFO    : Bus 19908	: V=1.0166134, theta=-41.439419 -> V=1.0, theta=0.0
% INFO    : Bus 19909	: V=0.9867748, theta=-41.280066 -> V=1.0, theta=0.0
% INFO    : Bus 19910	: V=0.9875179, theta=-41.315736 -> V=1.0, theta=0.0
% INFO    : Bus 19911	: V=0.9994082, theta=-40.400809 -> V=1.0, theta=0.0
% INFO    : Bus 19912	: V=0.9944338, theta=-54.496055 -> V=1.0, theta=0.0
% INFO    : Bus 19913	: V=1.004703, theta=-53.648583 -> V=1.0, theta=0.0
% INFO    : Bus 19914	: V=1.004783, theta=-53.583726 -> V=1.0, theta=0.0
% INFO    : Bus 19915	: V=0.999617, theta=-53.940316 -> V=1.0, theta=0.0
% INFO    : Bus 19916	: V=0.9996502, theta=-53.792794 -> V=1.0, theta=0.0
% INFO    : Bus 19917	: V=1.0011304, theta=-48.845747 -> V=1.0, theta=0.0
% INFO    : Bus 19918	: V=0.9975641, theta=-50.272937 -> V=1.0, theta=0.0
% INFO    : Bus 19919	: V=0.9989007, theta=-49.877845 -> V=1.0, theta=0.0
% INFO    : Bus 19920	: V=0.9973857, theta=-49.074271 -> V=1.0, theta=0.0
% INFO    : Bus 19921	: V=1.0019915, theta=-55.688652 -> V=1.0, theta=0.0
% INFO    : Bus 19922	: V=1.0028067, theta=-55.735254 -> V=1.0, theta=0.0
% INFO    : Bus 19923	: V=1.0015728, theta=-55.637256 -> V=1.0, theta=0.0
% INFO    : Bus 19924	: V=1.0029713, theta=-55.650462 -> V=1.0, theta=0.0
% INFO    : Bus 19925	: V=1.0053188, theta=-54.95031 -> V=1.0, theta=0.0
% INFO    : Bus 19926	: V=0.9965552, theta=-55.666428 -> V=1.0, theta=0.0
% INFO    : Bus 19927	: V=0.9917743, theta=-56.105422 -> V=1.0, theta=0.0
% INFO    : Bus 19928	: V=0.9994897, theta=-55.437691 -> V=1.0, theta=0.0
% INFO    : Bus 19929	: V=0.9990429, theta=-55.391613 -> V=1.0, theta=0.0
% INFO    : Bus 19930	: V=0.9943528, theta=-56.090036 -> V=1.0, theta=0.0
% INFO    : Bus 19931	: V=1.0038105, theta=-54.476414 -> V=1.0, theta=0.0
% INFO    : Bus 19932	: V=1.002268, theta=-54.5098 -> V=1.0, theta=0.0
% INFO    : Bus 19933	: V=0.9846795, theta=-56.462188 -> V=1.0, theta=0.0
% INFO    : Bus 19934	: V=0.9966346, theta=-55.396283 -> V=1.0, theta=0.0
% INFO    : Bus 19935	: V=1.0125467, theta=-39.421207 -> V=1.0, theta=0.0
% INFO    : Bus 19936	: V=0.9938692, theta=-41.139184 -> V=1.0, theta=0.0
% INFO    : Bus 19937	: V=0.9972909, theta=-40.837701 -> V=1.0, theta=0.0
% INFO    : Bus 19938	: V=1.0169207, theta=-38.224614 -> V=1.0, theta=0.0
% INFO    : Bus 19939	: V=1.0166621, theta=-37.989622 -> V=1.0, theta=0.0
% INFO    : Bus 19940	: V=1.0177126, theta=-39.513937 -> V=1.0, theta=0.0
% INFO    : Bus 19941	: V=0.9941648, theta=-41.838979 -> V=1.0, theta=0.0
% INFO    : Bus 19942	: V=1.0042368, theta=-40.216113 -> V=1.0, theta=0.0
% INFO    : Bus 19943	: V=0.9799057, theta=-47.883093 -> V=1.0, theta=0.0
% INFO    : Bus 19944	: V=0.9832268, theta=-46.337774 -> V=1.0, theta=0.0
% INFO    : Bus 19945	: V=0.9600128, theta=-48.773524 -> V=1.0, theta=0.0
% INFO    : Bus 19946	: V=1.0054824, theta=-52.353571 -> V=1.0, theta=0.0
% INFO    : Bus 19947	: V=1.0006272, theta=-53.350501 -> V=1.0, theta=0.0
% INFO    : Bus 19948	: V=1.0060972, theta=-51.917434 -> V=1.0, theta=0.0
% INFO    : Bus 19949	: V=0.9986979, theta=-53.438286 -> V=1.0, theta=0.0
% INFO    : Bus 19950	: V=0.9733277, theta=-55.02694 -> V=1.0, theta=0.0
% INFO    : Bus 19951	: V=0.9774883, theta=-53.862509 -> V=1.0, theta=0.0
% INFO    : Bus 19952	: V=0.9987766, theta=-34.516979 -> V=1.0, theta=0.0
% INFO    : Bus 19953	: V=0.9989551, theta=-34.42531 -> V=1.0, theta=0.0
% INFO    : Bus 19954	: V=0.9939596, theta=-34.678819 -> V=1.0, theta=0.0
% INFO    : Bus 19955	: V=0.9935386, theta=-34.612614 -> V=1.0, theta=0.0
% INFO    : Bus 19956	: V=0.9935206, theta=-34.61651 -> V=1.0, theta=0.0
% INFO    : Bus 19957	: V=0.9950631, theta=-34.387017 -> V=1.0, theta=0.0
% INFO    : Bus 19958	: V=1.0015085, theta=-33.6734 -> V=1.0, theta=0.0
% INFO    : Bus 19959	: V=1.0001608, theta=-32.976211 -> V=1.0, theta=0.0
% INFO    : Bus 19960	: V=1.0028401, theta=-32.563637 -> V=1.0, theta=0.0
% INFO    : Bus 19961	: V=1.0015128, theta=-32.807936 -> V=1.0, theta=0.0
% INFO    : Bus 19962	: V=1.0000614, theta=-32.895518 -> V=1.0, theta=0.0
% INFO    : Bus 19963	: V=0.9973003, theta=-33.622712 -> V=1.0, theta=0.0
% INFO    : Bus 19964	: V=0.9966603, theta=-33.834552 -> V=1.0, theta=0.0
% INFO    : Bus 19965	: V=0.9962808, theta=-33.958338 -> V=1.0, theta=0.0
% INFO    : Bus 19966	: V=0.9996233, theta=-34.071559 -> V=1.0, theta=0.0
% INFO    : Bus 19967	: V=0.9997944, theta=-34.074668 -> V=1.0, theta=0.0
% INFO    : Bus 19968	: V=0.9994108, theta=-34.223938 -> V=1.0, theta=0.0
% INFO    : Bus 19969	: V=0.9949482, theta=-33.98508 -> V=1.0, theta=0.0
% INFO    : Bus 19970	: V=0.9985732, theta=-32.921244 -> V=1.0, theta=0.0
% INFO    : Bus 19971	: V=0.9880745, theta=-35.512849 -> V=1.0, theta=0.0
% INFO    : Bus 19972	: V=0.9909532, theta=-35.371678 -> V=1.0, theta=0.0
% INFO    : Bus 19973	: V=0.9903626, theta=-34.918101 -> V=1.0, theta=0.0
% INFO    : Bus 19974	: V=0.9964565, theta=-35.65892 -> V=1.0, theta=0.0
% INFO    : Bus 19975	: V=0.996427, theta=-35.461684 -> V=1.0, theta=0.0
% INFO    : Bus 19976	: V=0.9804161, theta=-36.26192 -> V=1.0, theta=0.0
% INFO    : Bus 19977	: V=0.9953427, theta=-36.27301 -> V=1.0, theta=0.0
% INFO    : Bus 19978	: V=0.9984146, theta=-35.781984 -> V=1.0, theta=0.0
% INFO    : Bus 19979	: V=0.9956412, theta=-36.715656 -> V=1.0, theta=0.0
% INFO    : Bus 19980	: V=0.9980922, theta=-33.412271 -> V=1.0, theta=0.0
% INFO    : Bus 19981	: V=0.9859741, theta=-42.616178 -> V=1.0, theta=0.0
% INFO    : Bus 19982	: V=0.98078, theta=-45.873813 -> V=1.0, theta=0.0
% INFO    : Bus 19983	: V=0.9883282, theta=-44.832822 -> V=1.0, theta=0.0
% INFO    : Bus 19984	: V=0.9913394, theta=-44.07153 -> V=1.0, theta=0.0
% INFO    : Bus 19985	: V=1.0056069, theta=-42.141386 -> V=1.0, theta=0.0
% INFO    : Bus 19986	: V=1.0073835, theta=-46.126873 -> V=1.0, theta=0.0
% INFO    : Bus 19987	: V=1.0037064, theta=-45.697127 -> V=1.0, theta=0.0
% INFO    : Bus 19988	: V=1.0103757, theta=-42.61165 -> V=1.0, theta=0.0
% INFO    : Bus 19989	: V=1.0002724, theta=-44.385476 -> V=1.0, theta=0.0
% INFO    : Bus 19990	: V=0.9992182, theta=-44.312494 -> V=1.0, theta=0.0
% INFO    : Bus 19991	: V=0.9847342, theta=-46.414628 -> V=1.0, theta=0.0
% INFO    : Bus 19992	: V=0.9865166, theta=-45.427611 -> V=1.0, theta=0.0
% INFO    : Bus 19993	: V=0.9758183, theta=-46.730481 -> V=1.0, theta=0.0
% INFO    : Bus 19994	: V=0.989497, theta=-44.914336 -> V=1.0, theta=0.0
% INFO    : Bus 19995	: V=1.0123488, theta=-41.560926 -> V=1.0, theta=0.0
% INFO    : Bus 19996	: V=1.0155022, theta=-41.52022 -> V=1.0, theta=0.0
% INFO    : Bus 19997	: V=1.0108128, theta=-42.249977 -> V=1.0, theta=0.0
% INFO    : Bus 19998	: V=0.9928997, theta=-45.232244 -> V=1.0, theta=0.0
% INFO    : Bus 19999	: V=0.9954025, theta=-45.185794 -> V=1.0, theta=0.0
% INFO    : Bus 20000	: V=0.9852532, theta=-47.2341 -> V=1.0, theta=0.0
% INFO    : Bus 20001	: V=0.9880746, theta=-46.398907 -> V=1.0, theta=0.0
% INFO    : Bus 20002	: V=1.0198052, theta=-48.853977 -> V=1.0, theta=0.0
% INFO    : Bus 20003	: V=1.0067993, theta=-50.443955 -> V=1.0, theta=0.0
% INFO    : Bus 20004	: V=1.005909, theta=-50.456222 -> V=1.0, theta=0.0
% INFO    : Bus 20005	: V=1.0088251, theta=-43.418884 -> V=1.0, theta=0.0
% INFO    : Bus 20006	: V=1.0071605, theta=-43.510954 -> V=1.0, theta=0.0
% INFO    : Bus 20007	: V=0.9926113, theta=-45.291581 -> V=1.0, theta=0.0
% INFO    : Bus 20008	: V=0.9951329, theta=-45.108573 -> V=1.0, theta=0.0
% INFO    : Bus 20009	: V=0.9928501, theta=-45.572243 -> V=1.0, theta=0.0
% INFO    : Bus 20010	: V=0.9871222, theta=-45.793203 -> V=1.0, theta=0.0
% INFO    : Bus 20011	: V=0.9851807, theta=-45.974096 -> V=1.0, theta=0.0
% INFO    : Bus 20012	: V=1.0011359, theta=-54.879749 -> V=1.0, theta=0.0
% INFO    : Bus 20013	: V=1.0048088, theta=-54.420842 -> V=1.0, theta=0.0
% INFO    : Bus 20014	: V=1.0150079, theta=-52.202384 -> V=1.0, theta=0.0
% INFO    : Bus 20015	: V=1.0133428, theta=-52.3665 -> V=1.0, theta=0.0
% INFO    : Bus 20016	: V=1.0102871, theta=-52.663903 -> V=1.0, theta=0.0
% INFO    : Bus 20017	: V=0.9964771, theta=-54.399919 -> V=1.0, theta=0.0
% INFO    : Bus 20018	: V=1.0030065, theta=-53.28326 -> V=1.0, theta=0.0
% INFO    : Bus 20019	: V=1.0033281, theta=-54.883448 -> V=1.0, theta=0.0
% INFO    : Bus 20020	: V=0.9899858, theta=-54.949811 -> V=1.0, theta=0.0
% INFO    : Bus 20021	: V=0.9925045, theta=-54.786782 -> V=1.0, theta=0.0
% INFO    : Bus 20022	: V=1.0039613, theta=-53.146876 -> V=1.0, theta=0.0
% INFO    : Bus 20023	: V=1.0038985, theta=-53.320174 -> V=1.0, theta=0.0
% INFO    : Bus 20024	: V=0.9999847, theta=-55.960898 -> V=1.0, theta=0.0
% INFO    : Bus 20025	: V=1.009074, theta=-51.446042 -> V=1.0, theta=0.0
% INFO    : Bus 20026	: V=1.0132205, theta=-50.806033 -> V=1.0, theta=0.0
% INFO    : Bus 20027	: V=1.0053831, theta=-50.591072 -> V=1.0, theta=0.0
% INFO    : Bus 20028	: V=1.0103584, theta=-47.231492 -> V=1.0, theta=0.0
% INFO    : Bus 20029	: V=1.0103968, theta=-47.178796 -> V=1.0, theta=0.0
% INFO    : Bus 20030	: V=1.0080532, theta=-47.769302 -> V=1.0, theta=0.0
% INFO    : Bus 20031	: V=1.0063739, theta=-47.670375 -> V=1.0, theta=0.0
% INFO    : Bus 20032	: V=1.0032818, theta=-48.191945 -> V=1.0, theta=0.0
% INFO    : Bus 20033	: V=1.010929, theta=-47.108735 -> V=1.0, theta=0.0
% INFO    : Bus 20034	: V=1.0105027, theta=-47.113436 -> V=1.0, theta=0.0
% INFO    : Bus 20035	: V=1.0153145, theta=-46.225179 -> V=1.0, theta=0.0
% INFO    : Bus 20036	: V=1.0107123, theta=-48.004812 -> V=1.0, theta=0.0
% INFO    : Bus 20037	: V=1.0195706, theta=-46.664379 -> V=1.0, theta=0.0
% INFO    : Bus 20038	: V=1.0074928, theta=-47.84993 -> V=1.0, theta=0.0
% INFO    : Bus 20039	: V=0.9976869, theta=-48.344828 -> V=1.0, theta=0.0
% INFO    : Bus 20040	: V=0.9960027, theta=-48.361863 -> V=1.0, theta=0.0
% INFO    : Bus 20041	: V=0.9924344, theta=-48.806202 -> V=1.0, theta=0.0
% INFO    : Bus 20042	: V=1.0151223, theta=-45.873306 -> V=1.0, theta=0.0
% INFO    : Bus 20043	: V=1.0105221, theta=-46.313978 -> V=1.0, theta=0.0
% INFO    : Bus 20044	: V=1.0103258, theta=-47.946226 -> V=1.0, theta=0.0
% INFO    : Bus 20045	: V=1.0191066, theta=-46.838452 -> V=1.0, theta=0.0
% INFO    : Bus 20046	: V=1.0129816, theta=-48.092758 -> V=1.0, theta=0.0
% INFO    : Bus 20047	: V=1.0086586, theta=-48.331971 -> V=1.0, theta=0.0
% INFO    : Bus 20048	: V=1.0023791, theta=-48.60985 -> V=1.0, theta=0.0
% INFO    : Bus 20049	: V=1.0025316, theta=-48.654764 -> V=1.0, theta=0.0
% INFO    : Bus 20050	: V=1.0075923, theta=-38.621683 -> V=1.0, theta=0.0
% INFO    : Bus 20051	: V=1.0086284, theta=-38.313147 -> V=1.0, theta=0.0
% INFO    : Bus 20052	: V=1.0148437, theta=-36.95866 -> V=1.0, theta=0.0
% INFO    : Bus 20053	: V=1.0012701, theta=-38.399326 -> V=1.0, theta=0.0
% INFO    : Bus 20054	: V=1.0133206, theta=-38.483151 -> V=1.0, theta=0.0
% INFO    : Bus 20055	: V=1.0097902, theta=-39.393698 -> V=1.0, theta=0.0
% INFO    : Bus 20056	: V=0.9959567, theta=-55.726599 -> V=1.0, theta=0.0
% INFO    : Bus 20057	: V=0.9969043, theta=-55.328935 -> V=1.0, theta=0.0
% INFO    : Bus 20058	: V=0.9972584, theta=-55.324435 -> V=1.0, theta=0.0
% INFO    : Bus 20059	: V=0.9959292, theta=-55.302262 -> V=1.0, theta=0.0
% INFO    : Bus 20060	: V=0.9951878, theta=-55.061638 -> V=1.0, theta=0.0
% INFO    : Bus 20061	: V=0.9950925, theta=-55.142295 -> V=1.0, theta=0.0
% INFO    : Bus 20062	: V=0.9859315, theta=-55.914663 -> V=1.0, theta=0.0
% INFO    : Bus 20063	: V=0.9871963, theta=-55.71136 -> V=1.0, theta=0.0
% INFO    : Bus 20064	: V=0.9924639, theta=-55.279246 -> V=1.0, theta=0.0
% INFO    : Bus 20065	: V=0.9911967, theta=-55.269195 -> V=1.0, theta=0.0
% INFO    : Bus 20066	: V=0.992395, theta=-55.219137 -> V=1.0, theta=0.0
% INFO    : Bus 20067	: V=0.9983891, theta=-54.468014 -> V=1.0, theta=0.0
% INFO    : Bus 20068	: V=0.9925413, theta=-55.176414 -> V=1.0, theta=0.0
% INFO    : Bus 20069	: V=0.9884741, theta=-55.179022 -> V=1.0, theta=0.0
% INFO    : Bus 20070	: V=0.9826648, theta=-56.080969 -> V=1.0, theta=0.0
% INFO    : Bus 20071	: V=0.9968171, theta=-42.13567 -> V=1.0, theta=0.0
% INFO    : Bus 20072	: V=0.9948476, theta=-42.259122 -> V=1.0, theta=0.0
% INFO    : Bus 20073	: V=0.9919762, theta=-42.473845 -> V=1.0, theta=0.0
% INFO    : Bus 20074	: V=0.9937177, theta=-42.445832 -> V=1.0, theta=0.0
% INFO    : Bus 20075	: V=0.9934886, theta=-42.381285 -> V=1.0, theta=0.0
% INFO    : Bus 20076	: V=0.9946753, theta=-42.308024 -> V=1.0, theta=0.0
% INFO    : Bus 20077	: V=0.9951469, theta=-42.261538 -> V=1.0, theta=0.0
% INFO    : Bus 20078	: V=0.9927993, theta=-42.580234 -> V=1.0, theta=0.0
% INFO    : Bus 20079	: V=0.9988607, theta=-41.972236 -> V=1.0, theta=0.0
% INFO    : Bus 20080	: V=0.9991768, theta=-41.895127 -> V=1.0, theta=0.0
% INFO    : Bus 20081	: V=0.9924034, theta=-42.693209 -> V=1.0, theta=0.0
% INFO    : Bus 20082	: V=0.9989282, theta=-42.018768 -> V=1.0, theta=0.0
% INFO    : Bus 20083	: V=0.9968307, theta=-42.510041 -> V=1.0, theta=0.0
% INFO    : Bus 20084	: V=0.9934418, theta=-42.775338 -> V=1.0, theta=0.0
% INFO    : Bus 20085	: V=0.9992524, theta=-41.354362 -> V=1.0, theta=0.0
% INFO    : Bus 20086	: V=0.9925097, theta=-42.174607 -> V=1.0, theta=0.0
% INFO    : Bus 20087	: V=0.9948768, theta=-42.117289 -> V=1.0, theta=0.0
% INFO    : Bus 20088	: V=1.0008998, theta=-41.638217 -> V=1.0, theta=0.0
% INFO    : Bus 20089	: V=0.994128, theta=-41.453258 -> V=1.0, theta=0.0
% INFO    : Bus 20090	: V=0.9933637, theta=-41.569538 -> V=1.0, theta=0.0
% INFO    : Bus 20091	: V=0.9923354, theta=-41.591021 -> V=1.0, theta=0.0
% INFO    : Bus 20092	: V=1.0176538, theta=-38.379187 -> V=1.0, theta=0.0
% INFO    : Bus 20093	: V=0.9976792, theta=-41.213369 -> V=1.0, theta=0.0
% INFO    : Bus 20094	: V=1.009123, theta=-39.424254 -> V=1.0, theta=0.0
% INFO    : Bus 20095	: V=1.0120228, theta=-38.654558 -> V=1.0, theta=0.0
% INFO    : Bus 20096	: V=0.9976512, theta=-41.217314 -> V=1.0, theta=0.0
% INFO    : Bus 20097	: V=1.0095145, theta=-39.083842 -> V=1.0, theta=0.0
% INFO    : Bus 20098	: V=0.9908318, theta=-40.964989 -> V=1.0, theta=0.0
% INFO    : Bus 20099	: V=0.9872876, theta=-42.57043 -> V=1.0, theta=0.0
% INFO    : Bus 20100	: V=0.9889772, theta=-42.715625 -> V=1.0, theta=0.0
% INFO    : Bus 20101	: V=0.9866893, theta=-42.614811 -> V=1.0, theta=0.0
% INFO    : Bus 20102	: V=1.0029888, theta=-41.723097 -> V=1.0, theta=0.0
% INFO    : Bus 20103	: V=0.9975613, theta=-42.323778 -> V=1.0, theta=0.0
% INFO    : Bus 20104	: V=0.9827668, theta=-43.712299 -> V=1.0, theta=0.0
% INFO    : Bus 20105	: V=0.9891804, theta=-42.832587 -> V=1.0, theta=0.0
% INFO    : Bus 20106	: V=1.0051052, theta=-41.822531 -> V=1.0, theta=0.0
% INFO    : Bus 20107	: V=1.0176799, theta=-38.811402 -> V=1.0, theta=0.0
% INFO    : Bus 20108	: V=1.0009509, theta=-42.286211 -> V=1.0, theta=0.0
% INFO    : Bus 20109	: V=1.0033959, theta=-41.031845 -> V=1.0, theta=0.0
% INFO    : Bus 20110	: V=1.0186119, theta=-39.875258 -> V=1.0, theta=0.0
% INFO    : Bus 20111	: V=1.0107695, theta=-39.569635 -> V=1.0, theta=0.0
% INFO    : Bus 20112	: V=1.0173476, theta=-38.507313 -> V=1.0, theta=0.0
% INFO    : Bus 20113	: V=1.0174633, theta=-38.492955 -> V=1.0, theta=0.0
% INFO    : Bus 20114	: V=0.9899419, theta=-41.769399 -> V=1.0, theta=0.0
% INFO    : Bus 20115	: V=0.9921429, theta=-41.558731 -> V=1.0, theta=0.0
% INFO    : Bus 20116	: V=0.9965838, theta=-41.393697 -> V=1.0, theta=0.0
% INFO    : Bus 20117	: V=1.0023845, theta=-40.837405 -> V=1.0, theta=0.0
% INFO    : Bus 20118	: V=1.0018672, theta=-40.900463 -> V=1.0, theta=0.0
% INFO    : Bus 20119	: V=1.0021086, theta=-40.79865 -> V=1.0, theta=0.0
% INFO    : Bus 20120	: V=1.0078985, theta=-39.669428 -> V=1.0, theta=0.0
% INFO    : Bus 20121	: V=0.9852173, theta=-40.997792 -> V=1.0, theta=0.0
% INFO    : Bus 20122	: V=0.9879976, theta=-40.928031 -> V=1.0, theta=0.0
% INFO    : Bus 20123	: V=1.0012221, theta=-40.603867 -> V=1.0, theta=0.0
% INFO    : Bus 20124	: V=0.992781, theta=-47.85934 -> V=1.0, theta=0.0
% INFO    : Bus 20125	: V=0.9834931, theta=-49.282542 -> V=1.0, theta=0.0
% INFO    : Bus 20126	: V=0.9956463, theta=-47.975595 -> V=1.0, theta=0.0
% INFO    : Bus 20127	: V=0.9946826, theta=-47.974353 -> V=1.0, theta=0.0
% INFO    : Bus 20128	: V=0.9783465, theta=-49.402783 -> V=1.0, theta=0.0
% INFO    : Bus 20129	: V=1.0045905, theta=-40.100315 -> V=1.0, theta=0.0
% INFO    : Bus 20130	: V=0.9698022, theta=-40.566681 -> V=1.0, theta=0.0
% INFO    : Bus 20131	: V=0.971967, theta=-39.515316 -> V=1.0, theta=0.0
% INFO    : Bus 20132	: V=0.9473555, theta=-41.020593 -> V=1.0, theta=0.0
% INFO    : Bus 20133	: V=0.9630384, theta=-40.592595 -> V=1.0, theta=0.0
% INFO    : Bus 20134	: V=0.9766646, theta=-42.263055 -> V=1.0, theta=0.0
% INFO    : Bus 20135	: V=0.9838861, theta=-41.77124 -> V=1.0, theta=0.0
% INFO    : Bus 20136	: V=0.9721204, theta=-42.551826 -> V=1.0, theta=0.0
% INFO    : Bus 20137	: V=0.9703778, theta=-44.342449 -> V=1.0, theta=0.0
% INFO    : Bus 20138	: V=0.9816865, theta=-43.587699 -> V=1.0, theta=0.0
% INFO    : Bus 20139	: V=0.9662746, theta=-44.569587 -> V=1.0, theta=0.0
% INFO    : Bus 20140	: V=0.9668972, theta=-43.65851 -> V=1.0, theta=0.0
% INFO    : Bus 20141	: V=0.9755977, theta=-43.669933 -> V=1.0, theta=0.0
% INFO    : Bus 20142	: V=0.9695395, theta=-43.902099 -> V=1.0, theta=0.0
% INFO    : Bus 20143	: V=0.9510244, theta=-50.063097 -> V=1.0, theta=0.0
% INFO    : Bus 20144	: V=0.9461541, theta=-48.887135 -> V=1.0, theta=0.0
% INFO    : Bus 20145	: V=0.9497511, theta=-47.776792 -> V=1.0, theta=0.0
% INFO    : Bus 20146	: V=0.9466586, theta=-49.046638 -> V=1.0, theta=0.0
% INFO    : Bus 20147	: V=0.9455987, theta=-49.627909 -> V=1.0, theta=0.0
% INFO    : Bus 20148	: V=0.953608, theta=-49.656731 -> V=1.0, theta=0.0
% INFO    : Bus 20149	: V=0.9564018, theta=-48.749542 -> V=1.0, theta=0.0
% INFO    : Bus 20150	: V=0.94392, theta=-49.713344 -> V=1.0, theta=0.0
% INFO    : Bus 20151	: V=1.0021835, theta=-50.871907 -> V=1.0, theta=0.0
% INFO    : Bus 20152	: V=1.0025911, theta=-50.863915 -> V=1.0, theta=0.0
% INFO    : Bus 20153	: V=1.0032517, theta=-50.703709 -> V=1.0, theta=0.0
% INFO    : Bus 20154	: V=1.0058372, theta=-50.370483 -> V=1.0, theta=0.0
% INFO    : Bus 20155	: V=1.0035101, theta=-51.444516 -> V=1.0, theta=0.0
% INFO    : Bus 20156	: V=1.002337, theta=-51.470827 -> V=1.0, theta=0.0
% INFO    : Bus 20157	: V=1.0171062, theta=-50.215054 -> V=1.0, theta=0.0
% INFO    : Bus 20158	: V=1.0007579, theta=-50.904325 -> V=1.0, theta=0.0
% INFO    : Bus 20159	: V=0.9977284, theta=-51.768875 -> V=1.0, theta=0.0
% INFO    : Bus 20160	: V=0.9967257, theta=-51.561195 -> V=1.0, theta=0.0
% INFO    : Bus 20161	: V=1.0037186, theta=-50.361995 -> V=1.0, theta=0.0
% INFO    : Bus 20162	: V=1.0073114, theta=-49.489029 -> V=1.0, theta=0.0
% INFO    : Bus 20163	: V=1.0194111, theta=-47.54007 -> V=1.0, theta=0.0
% INFO    : Bus 20164	: V=1.0095702, theta=-49.906762 -> V=1.0, theta=0.0
% INFO    : Bus 20165	: V=1.0194542, theta=-48.688591 -> V=1.0, theta=0.0
% INFO    : Bus 20166	: V=1.0138918, theta=-49.201752 -> V=1.0, theta=0.0
% INFO    : Bus 20167	: V=1.013083, theta=-49.276177 -> V=1.0, theta=0.0
% INFO    : Bus 20168	: V=1.0118903, theta=-48.9813 -> V=1.0, theta=0.0
% INFO    : Bus 20169	: V=1.0160536, theta=-45.89205 -> V=1.0, theta=0.0
% INFO    : Bus 20170	: V=0.994667, theta=-49.75401 -> V=1.0, theta=0.0
% INFO    : Bus 20171	: V=0.9971772, theta=-47.489503 -> V=1.0, theta=0.0
% INFO    : Bus 20172	: V=1.0072161, theta=-47.023888 -> V=1.0, theta=0.0
% INFO    : Bus 20173	: V=1.0005006, theta=-49.471495 -> V=1.0, theta=0.0
% INFO    : Bus 20174	: V=1.0199188, theta=-44.344689 -> V=1.0, theta=0.0
% INFO    : Bus 20175	: V=1.0057804, theta=-47.951501 -> V=1.0, theta=0.0
% INFO    : Bus 20176	: V=1.0003721, theta=-47.442244 -> V=1.0, theta=0.0
% INFO    : Bus 20177	: V=0.9932948, theta=-47.604311 -> V=1.0, theta=0.0
% INFO    : Bus 20178	: V=1.0086161, theta=-35.204398 -> V=1.0, theta=0.0
% INFO    : Bus 20179	: V=1.0135551, theta=-35.509594 -> V=1.0, theta=0.0
% INFO    : Bus 20180	: V=0.9971575, theta=-37.725554 -> V=1.0, theta=0.0
% INFO    : Bus 20181	: V=1.0106473, theta=-35.156253 -> V=1.0, theta=0.0
% INFO    : Bus 20182	: V=1.0121015, theta=-35.492084 -> V=1.0, theta=0.0
% INFO    : Bus 20183	: V=1.0101832, theta=-36.105376 -> V=1.0, theta=0.0
% INFO    : Bus 20184	: V=0.9584745, theta=-49.027867 -> V=1.0, theta=0.0
% INFO    : Bus 20185	: V=0.9573259, theta=-49.42865 -> V=1.0, theta=0.0
% INFO    : Bus 20186	: V=0.9919148, theta=-47.341375 -> V=1.0, theta=0.0
% INFO    : Bus 20187	: V=0.9606658, theta=-50.400079 -> V=1.0, theta=0.0
% INFO    : Bus 20188	: V=0.959642, theta=-50.464408 -> V=1.0, theta=0.0
% INFO    : Bus 20189	: V=0.9570634, theta=-50.560312 -> V=1.0, theta=0.0
% INFO    : Bus 20190	: V=0.9569442, theta=-49.637424 -> V=1.0, theta=0.0
% INFO    : Bus 20191	: V=0.9565813, theta=-49.656496 -> V=1.0, theta=0.0
% INFO    : Bus 20192	: V=0.95829, theta=-49.622448 -> V=1.0, theta=0.0
% INFO    : Bus 20193	: V=0.9573568, theta=-49.705449 -> V=1.0, theta=0.0
% INFO    : Bus 20194	: V=0.9533236, theta=-50.776401 -> V=1.0, theta=0.0
% INFO    : Bus 20195	: V=0.9606688, theta=-49.492617 -> V=1.0, theta=0.0
% INFO    : Bus 20196	: V=0.9622311, theta=-49.394769 -> V=1.0, theta=0.0
% INFO    : Bus 20197	: V=0.9603285, theta=-49.537253 -> V=1.0, theta=0.0
% INFO    : Bus 20198	: V=0.9522139, theta=-50.875822 -> V=1.0, theta=0.0
% INFO    : Bus 20199	: V=0.9900157, theta=-47.903162 -> V=1.0, theta=0.0
% INFO    : Bus 20200	: V=1.0137805, theta=-53.333936 -> V=1.0, theta=0.0
% INFO    : Bus 20201	: V=1.0178074, theta=-52.685438 -> V=1.0, theta=0.0
% INFO    : Bus 20202	: V=1.0153897, theta=-53.134702 -> V=1.0, theta=0.0
% INFO    : Bus 20203	: V=1.0166045, theta=-52.021049 -> V=1.0, theta=0.0
% INFO    : Bus 20204	: V=1.0179094, theta=-51.855099 -> V=1.0, theta=0.0
% INFO    : Bus 20205	: V=1.0093847, theta=-53.013009 -> V=1.0, theta=0.0
% INFO    : Bus 20206	: V=1.0191059, theta=-51.677678 -> V=1.0, theta=0.0
% INFO    : Bus 20207	: V=0.9760122, theta=-40.623638 -> V=1.0, theta=0.0
% INFO    : Bus 20208	: V=0.9548193, theta=-44.634059 -> V=1.0, theta=0.0
% INFO    : Bus 20209	: V=0.9462064, theta=-44.987165 -> V=1.0, theta=0.0
% INFO    : Bus 20210	: V=0.9454353, theta=-45.001824 -> V=1.0, theta=0.0
% INFO    : Bus 20211	: V=0.959808, theta=-45.054267 -> V=1.0, theta=0.0
% INFO    : Bus 20212	: V=0.9557525, theta=-46.086242 -> V=1.0, theta=0.0
% INFO    : Bus 20213	: V=0.9594029, theta=-45.772268 -> V=1.0, theta=0.0
% INFO    : Bus 20214	: V=1.0099471, theta=-51.834926 -> V=1.0, theta=0.0
% INFO    : Bus 20215	: V=1.0164308, theta=-51.003581 -> V=1.0, theta=0.0
% INFO    : Bus 20216	: V=1.0089209, theta=-51.900564 -> V=1.0, theta=0.0
% INFO    : Bus 20217	: V=1.0092512, theta=-51.87618 -> V=1.0, theta=0.0
% INFO    : Bus 20218	: V=1.0068429, theta=-51.958328 -> V=1.0, theta=0.0
% INFO    : Bus 20219	: V=1.0167675, theta=-50.921624 -> V=1.0, theta=0.0
% INFO    : Bus 20220	: V=1.0082929, theta=-51.883599 -> V=1.0, theta=0.0
% INFO    : Bus 20221	: V=1.0201326, theta=-50.349274 -> V=1.0, theta=0.0
% INFO    : Bus 20222	: V=1.0160578, theta=-50.996852 -> V=1.0, theta=0.0
% INFO    : Bus 20223	: V=1.0160591, theta=-51.00385 -> V=1.0, theta=0.0
% INFO    : Bus 20224	: V=1.0159769, theta=-50.951333 -> V=1.0, theta=0.0
% INFO    : Bus 20225	: V=1.0157165, theta=-50.991673 -> V=1.0, theta=0.0
% INFO    : Bus 20226	: V=1.0069429, theta=-51.895807 -> V=1.0, theta=0.0
% INFO    : Bus 20227	: V=1.0188386, theta=-49.687066 -> V=1.0, theta=0.0
% INFO    : Bus 20228	: V=1.0142549, theta=-50.015215 -> V=1.0, theta=0.0
% INFO    : Bus 20229	: V=1.0187698, theta=-50.573498 -> V=1.0, theta=0.0
% INFO    : Bus 20230	: V=1.0201644, theta=-50.245501 -> V=1.0, theta=0.0
% INFO    : Bus 20231	: V=1.0008921, theta=-52.020887 -> V=1.0, theta=0.0
% INFO    : Bus 20232	: V=1.0164596, theta=-50.972232 -> V=1.0, theta=0.0
% INFO    : Bus 20233	: V=1.0166029, theta=-50.967342 -> V=1.0, theta=0.0
% INFO    : Bus 20234	: V=1.0168305, theta=-50.933422 -> V=1.0, theta=0.0
% INFO    : Bus 20235	: V=1.0201397, theta=-50.44607 -> V=1.0, theta=0.0
% INFO    : Bus 20236	: V=1.0189434, theta=-50.11025 -> V=1.0, theta=0.0
% INFO    : Bus 20237	: V=1.0076833, theta=-51.940927 -> V=1.0, theta=0.0
% INFO    : Bus 20238	: V=0.9793824, theta=-47.465733 -> V=1.0, theta=0.0
% INFO    : Bus 20239	: V=0.9810848, theta=-47.664744 -> V=1.0, theta=0.0
% INFO    : Bus 20240	: V=0.9886583, theta=-47.620261 -> V=1.0, theta=0.0
% INFO    : Bus 20241	: V=1.00972, theta=-54.699108 -> V=1.0, theta=0.0
% INFO    : Bus 20242	: V=1.0109915, theta=-54.450735 -> V=1.0, theta=0.0
% INFO    : Bus 20243	: V=1.0081018, theta=-55.067703 -> V=1.0, theta=0.0
% INFO    : Bus 20244	: V=0.9981913, theta=-55.94597 -> V=1.0, theta=0.0
% INFO    : Bus 20245	: V=0.9664275, theta=-48.621434 -> V=1.0, theta=0.0
% INFO    : Bus 20246	: V=0.9980803, theta=-44.264777 -> V=1.0, theta=0.0
% INFO    : Bus 20247	: V=1.0074281, theta=-42.406267 -> V=1.0, theta=0.0
% INFO    : Bus 20248	: V=0.9636288, theta=-49.178064 -> V=1.0, theta=0.0
% INFO    : Bus 20249	: V=0.9504517, theta=-50.156069 -> V=1.0, theta=0.0
% INFO    : Bus 20250	: V=1.0021937, theta=-44.008802 -> V=1.0, theta=0.0
% INFO    : Bus 20251	: V=0.9982418, theta=-44.371297 -> V=1.0, theta=0.0
% INFO    : Bus 20252	: V=0.9941157, theta=-49.412802 -> V=1.0, theta=0.0
% INFO    : Bus 20253	: V=0.99228, theta=-50.368716 -> V=1.0, theta=0.0
% INFO    : Bus 20254	: V=0.9929914, theta=-50.354566 -> V=1.0, theta=0.0
% INFO    : Bus 20255	: V=0.9942873, theta=-49.91099 -> V=1.0, theta=0.0
% INFO    : Bus 20256	: V=0.9905751, theta=-50.250247 -> V=1.0, theta=0.0
% INFO    : Bus 20257	: V=0.9961916, theta=-49.093298 -> V=1.0, theta=0.0
% INFO    : Bus 20258	: V=0.9907478, theta=-50.142821 -> V=1.0, theta=0.0
% INFO    : Bus 20259	: V=0.9879592, theta=-50.556746 -> V=1.0, theta=0.0
% INFO    : Bus 20260	: V=0.985422, theta=-50.674795 -> V=1.0, theta=0.0
% INFO    : Bus 20261	: V=0.9853852, theta=-50.61082 -> V=1.0, theta=0.0
% INFO    : Bus 20262	: V=0.9846348, theta=-50.623832 -> V=1.0, theta=0.0
% INFO    : Bus 20263	: V=0.9807184, theta=-51.026666 -> V=1.0, theta=0.0
% INFO    : Bus 20264	: V=0.9859477, theta=-50.604984 -> V=1.0, theta=0.0
% INFO    : Bus 20265	: V=0.9868028, theta=-51.836357 -> V=1.0, theta=0.0
% INFO    : Bus 20266	: V=0.9811318, theta=-53.050945 -> V=1.0, theta=0.0
% INFO    : Bus 20267	: V=0.9726762, theta=-51.368713 -> V=1.0, theta=0.0
% INFO    : Bus 20268	: V=0.9913089, theta=-50.132175 -> V=1.0, theta=0.0
% INFO    : Bus 20269	: V=0.9909082, theta=-50.243566 -> V=1.0, theta=0.0
% INFO    : Bus 20270	: V=0.9982044, theta=-48.303564 -> V=1.0, theta=0.0
% INFO    : Bus 20271	: V=1.0011807, theta=-47.723484 -> V=1.0, theta=0.0
% INFO    : Bus 20272	: V=1.006701, theta=-46.531983 -> V=1.0, theta=0.0
% INFO    : Bus 20273	: V=1.0110113, theta=-44.703098 -> V=1.0, theta=0.0
% INFO    : Bus 20274	: V=1.018776, theta=-42.136036 -> V=1.0, theta=0.0
% INFO    : Bus 20275	: V=0.993366, theta=-44.231153 -> V=1.0, theta=0.0
% INFO    : Bus 20276	: V=0.9864921, theta=-45.013615 -> V=1.0, theta=0.0
% INFO    : Bus 20277	: V=1.0137701, theta=-39.786734 -> V=1.0, theta=0.0
% INFO    : Bus 20278	: V=1.0125045, theta=-41.328568 -> V=1.0, theta=0.0
% INFO    : Bus 20279	: V=1.0217265, theta=-51.203604 -> V=1.0, theta=0.0
% INFO    : Bus 20280	: V=1.0201676, theta=-50.672037 -> V=1.0, theta=0.0
% INFO    : Bus 20281	: V=1.0191363, theta=-50.809603 -> V=1.0, theta=0.0
% INFO    : Bus 20282	: V=1.0214724, theta=-51.186773 -> V=1.0, theta=0.0
% INFO    : Bus 20283	: V=1.019774, theta=-50.657766 -> V=1.0, theta=0.0
% INFO    : Bus 20284	: V=1.0188535, theta=-51.007175 -> V=1.0, theta=0.0
% INFO    : Bus 20285	: V=1.0150117, theta=-50.81549 -> V=1.0, theta=0.0
% INFO    : Bus 20286	: V=1.0121861, theta=-50.538321 -> V=1.0, theta=0.0
% INFO    : Bus 20287	: V=1.0107384, theta=-38.723265 -> V=1.0, theta=0.0
% INFO    : Bus 20288	: V=1.0058506, theta=-37.156231 -> V=1.0, theta=0.0
% INFO    : Bus 20289	: V=0.9999996, theta=-39.598293 -> V=1.0, theta=0.0
% INFO    : Bus 20290	: V=1.0108552, theta=-38.222765 -> V=1.0, theta=0.0
% INFO    : Bus 20291	: V=1.010629, theta=-38.797254 -> V=1.0, theta=0.0
% INFO    : Bus 20292	: V=0.9969557, theta=-39.717859 -> V=1.0, theta=0.0
% INFO    : Bus 20293	: V=0.9996082, theta=-37.921889 -> V=1.0, theta=0.0
% INFO    : Bus 20294	: V=0.9962404, theta=-39.23496 -> V=1.0, theta=0.0
% INFO    : Bus 20295	: V=0.9981144, theta=-37.713292 -> V=1.0, theta=0.0
% INFO    : Bus 20296	: V=0.967759, theta=-41.248116 -> V=1.0, theta=0.0
% INFO    : Bus 20297	: V=0.9697153, theta=-47.106683 -> V=1.0, theta=0.0
% INFO    : Bus 20298	: V=0.9633379, theta=-48.008198 -> V=1.0, theta=0.0
% INFO    : Bus 20299	: V=0.9632377, theta=-47.961208 -> V=1.0, theta=0.0
% INFO    : Bus 20300	: V=0.9726566, theta=-46.761959 -> V=1.0, theta=0.0
% INFO    : Bus 20301	: V=0.970893, theta=-46.957812 -> V=1.0, theta=0.0
% INFO    : Bus 20302	: V=0.9635741, theta=-47.976077 -> V=1.0, theta=0.0
% INFO    : Bus 20303	: V=0.9778212, theta=-46.849613 -> V=1.0, theta=0.0
% INFO    : Bus 20304	: V=0.9692746, theta=-47.870286 -> V=1.0, theta=0.0
% INFO    : Bus 20305	: V=0.9680541, theta=-47.283704 -> V=1.0, theta=0.0
% INFO    : Bus 20306	: V=0.9620069, theta=-48.149528 -> V=1.0, theta=0.0
% INFO    : Bus 20307	: V=0.9671189, theta=-47.353851 -> V=1.0, theta=0.0
% INFO    : Bus 20308	: V=0.9651276, theta=-47.640572 -> V=1.0, theta=0.0
% INFO    : Bus 20309	: V=0.971519, theta=-46.441573 -> V=1.0, theta=0.0
% INFO    : Bus 20310	: V=0.9726988, theta=-44.102127 -> V=1.0, theta=0.0
% INFO    : Bus 20311	: V=0.973393, theta=-46.473249 -> V=1.0, theta=0.0
% INFO    : Bus 20312	: V=0.9760045, theta=-46.350201 -> V=1.0, theta=0.0
% INFO    : Bus 20313	: V=0.9816962, theta=-46.04798 -> V=1.0, theta=0.0
% INFO    : Bus 20314	: V=0.9806924, theta=-46.176746 -> V=1.0, theta=0.0
% INFO    : Bus 20315	: V=0.9960616, theta=-49.086112 -> V=1.0, theta=0.0
% INFO    : Bus 20316	: V=0.9966774, theta=-49.282966 -> V=1.0, theta=0.0
% INFO    : Bus 20317	: V=0.9985874, theta=-49.530521 -> V=1.0, theta=0.0
% INFO    : Bus 20318	: V=0.9986811, theta=-48.732667 -> V=1.0, theta=0.0
% INFO    : Bus 20319	: V=0.9942646, theta=-48.217645 -> V=1.0, theta=0.0
% INFO    : Bus 20320	: V=0.9853098, theta=-44.497821 -> V=1.0, theta=0.0
% INFO    : Bus 20321	: V=1.0031192, theta=-44.86379 -> V=1.0, theta=0.0
% INFO    : Bus 20322	: V=0.9997801, theta=-43.639337 -> V=1.0, theta=0.0
% INFO    : Bus 20323	: V=1.000983, theta=-44.341922 -> V=1.0, theta=0.0
% INFO    : Bus 20324	: V=0.9981499, theta=-41.534637 -> V=1.0, theta=0.0
% INFO    : Bus 20325	: V=1.0025216, theta=-40.998963 -> V=1.0, theta=0.0
% INFO    : Bus 20326	: V=0.9977699, theta=-41.584903 -> V=1.0, theta=0.0
% INFO    : Bus 20327	: V=0.9995111, theta=-41.648394 -> V=1.0, theta=0.0
% INFO    : Bus 20328	: V=0.9915563, theta=-45.903911 -> V=1.0, theta=0.0
% INFO    : Bus 20329	: V=0.9786019, theta=-47.498764 -> V=1.0, theta=0.0
% INFO    : Bus 20330	: V=0.987973, theta=-46.640271 -> V=1.0, theta=0.0
% INFO    : Bus 20331	: V=0.9891911, theta=-47.030436 -> V=1.0, theta=0.0
% INFO    : Bus 20332	: V=0.981517, theta=-52.163072 -> V=1.0, theta=0.0
% INFO    : Bus 20333	: V=1.0033963, theta=-49.764517 -> V=1.0, theta=0.0
% INFO    : Bus 20334	: V=1.001222, theta=-49.882382 -> V=1.0, theta=0.0
% INFO    : Bus 20335	: V=0.9843235, theta=-51.719908 -> V=1.0, theta=0.0
% INFO    : Bus 20336	: V=1.0102643, theta=-50.060827 -> V=1.0, theta=0.0
% INFO    : Bus 20337	: V=1.010403, theta=-50.191827 -> V=1.0, theta=0.0
% INFO    : Bus 20338	: V=1.0053283, theta=-49.746164 -> V=1.0, theta=0.0
% INFO    : Bus 20339	: V=1.0039312, theta=-45.804437 -> V=1.0, theta=0.0
% INFO    : Bus 20340	: V=1.0009983, theta=-45.825717 -> V=1.0, theta=0.0
% INFO    : Bus 20341	: V=1.0113255, theta=-45.456149 -> V=1.0, theta=0.0
% INFO    : Bus 20342	: V=0.9857173, theta=-47.862205 -> V=1.0, theta=0.0
% INFO    : Bus 20343	: V=0.9703805, theta=-49.386033 -> V=1.0, theta=0.0
% INFO    : Bus 20344	: V=0.9813326, theta=-47.835658 -> V=1.0, theta=0.0
% INFO    : Bus 20345	: V=0.9661005, theta=-49.444195 -> V=1.0, theta=0.0
% INFO    : Bus 20346	: V=0.9577327, theta=-50.196426 -> V=1.0, theta=0.0
% INFO    : Bus 20347	: V=0.9802493, theta=-47.14033 -> V=1.0, theta=0.0
% INFO    : Bus 20348	: V=1.0102205, theta=-31.950794 -> V=1.0, theta=0.0
% INFO    : Bus 20349	: V=1.0106045, theta=-31.971718 -> V=1.0, theta=0.0
% INFO    : Bus 20350	: V=1.0116414, theta=-32.006107 -> V=1.0, theta=0.0
% INFO    : Bus 20351	: V=1.0112318, theta=-31.85531 -> V=1.0, theta=0.0
% INFO    : Bus 20352	: V=1.0186542, theta=-31.078232 -> V=1.0, theta=0.0
% INFO    : Bus 20353	: V=0.9838708, theta=-37.370873 -> V=1.0, theta=0.0
% INFO    : Bus 20354	: V=1.0025512, theta=-34.103472 -> V=1.0, theta=0.0
% INFO    : Bus 20355	: V=1.0016463, theta=-34.527498 -> V=1.0, theta=0.0
% INFO    : Bus 20356	: V=0.990534, theta=-36.74177 -> V=1.0, theta=0.0
% INFO    : Bus 20357	: V=0.9770561, theta=-38.655425 -> V=1.0, theta=0.0
% INFO    : Bus 20358	: V=0.9813302, theta=-38.95961 -> V=1.0, theta=0.0
% INFO    : Bus 20359	: V=0.9619923, theta=-49.33873 -> V=1.0, theta=0.0
% INFO    : Bus 20360	: V=0.9651001, theta=-48.441594 -> V=1.0, theta=0.0
% INFO    : Bus 20361	: V=0.9400556, theta=-50.470509 -> V=1.0, theta=0.0
% INFO    : Bus 20362	: V=1.0174657, theta=-44.878383 -> V=1.0, theta=0.0
% INFO    : Bus 20363	: V=1.0198733, theta=-45.211472 -> V=1.0, theta=0.0
% INFO    : Bus 20364	: V=1.0098532, theta=-48.241252 -> V=1.0, theta=0.0
% INFO    : Bus 20365	: V=1.0098987, theta=-45.646213 -> V=1.0, theta=0.0
% INFO    : Bus 20366	: V=1.0131728, theta=-45.25767 -> V=1.0, theta=0.0
% INFO    : Bus 20367	: V=1.0007032, theta=-41.162428 -> V=1.0, theta=0.0
% INFO    : Bus 20368	: V=1.0017261, theta=-42.180912 -> V=1.0, theta=0.0
% INFO    : Bus 20369	: V=1.0032557, theta=-41.829944 -> V=1.0, theta=0.0
% INFO    : Bus 20370	: V=0.9978976, theta=-42.158826 -> V=1.0, theta=0.0
% INFO    : Bus 20371	: V=1.002944, theta=-41.816254 -> V=1.0, theta=0.0
% INFO    : Bus 20372	: V=1.0027615, theta=-41.792285 -> V=1.0, theta=0.0
% INFO    : Bus 20373	: V=1.0028228, theta=-41.765986 -> V=1.0, theta=0.0
% INFO    : Bus 20374	: V=1.0028378, theta=-41.802764 -> V=1.0, theta=0.0
% INFO    : Bus 20375	: V=1.0027164, theta=-41.710125 -> V=1.0, theta=0.0
% INFO    : Bus 20376	: V=0.9950582, theta=-42.055852 -> V=1.0, theta=0.0
% INFO    : Bus 20377	: V=1.0027613, theta=-41.624942 -> V=1.0, theta=0.0
% INFO    : Bus 20378	: V=1.0030942, theta=-41.547316 -> V=1.0, theta=0.0
% INFO    : Bus 20379	: V=1.0030072, theta=-41.534081 -> V=1.0, theta=0.0
% INFO    : Bus 20380	: V=1.005094, theta=-41.902329 -> V=1.0, theta=0.0
% INFO    : Bus 20381	: V=1.0045357, theta=-41.849656 -> V=1.0, theta=0.0
% INFO    : Bus 20382	: V=1.0057094, theta=-41.191609 -> V=1.0, theta=0.0
% INFO    : Bus 20383	: V=1.0032326, theta=-41.921333 -> V=1.0, theta=0.0
% INFO    : Bus 20384	: V=0.9961423, theta=-42.518934 -> V=1.0, theta=0.0
% INFO    : Bus 20385	: V=0.9964516, theta=-42.419348 -> V=1.0, theta=0.0
% INFO    : Bus 20386	: V=1.0026395, theta=-41.903555 -> V=1.0, theta=0.0
% INFO    : Bus 20387	: V=1.0073238, theta=-41.856367 -> V=1.0, theta=0.0
% INFO    : Bus 20388	: V=1.0088402, theta=-41.976865 -> V=1.0, theta=0.0
% INFO    : Bus 20389	: V=1.0045529, theta=-42.271551 -> V=1.0, theta=0.0
% INFO    : Bus 20390	: V=1.0065943, theta=-39.571288 -> V=1.0, theta=0.0
% INFO    : Bus 20391	: V=1.0094407, theta=-38.070561 -> V=1.0, theta=0.0
% INFO    : Bus 20392	: V=1.010344, theta=-40.018845 -> V=1.0, theta=0.0
% INFO    : Bus 20393	: V=1.0040505, theta=-41.359922 -> V=1.0, theta=0.0
% INFO    : Bus 20394	: V=1.0024408, theta=-41.849822 -> V=1.0, theta=0.0
% INFO    : Bus 20395	: V=0.9708061, theta=-46.180985 -> V=1.0, theta=0.0
% INFO    : Bus 20396	: V=0.9733267, theta=-44.788114 -> V=1.0, theta=0.0
% INFO    : Bus 20397	: V=0.9709751, theta=-45.776317 -> V=1.0, theta=0.0
% INFO    : Bus 20398	: V=0.9491297, theta=-47.908941 -> V=1.0, theta=0.0
% INFO    : Bus 20399	: V=0.9626205, theta=-47.078301 -> V=1.0, theta=0.0
% INFO    : Bus 20400	: V=0.9610433, theta=-47.794536 -> V=1.0, theta=0.0
% INFO    : Bus 20401	: V=1.02, theta=-8.542693 -> V=1.0, theta=0.0
% INFO    : Bus 20402	: V=1.02, theta=-6.376788 -> V=1.0, theta=0.0
% INFO    : Bus 20403	: V=0.9754571, theta=3.570568 -> V=1.0, theta=0.0
% INFO    : Bus 20404	: V=1.02, theta=-5.295096 -> V=1.0, theta=0.0
% INFO    : Bus 20405	: V=1.02, theta=0.067469 -> V=1.0, theta=0.0
% INFO    : Bus 20406	: V=1.02, theta=-4.093334 -> V=1.0, theta=0.0
% INFO    : Bus 20407	: V=1.02, theta=-7.81395 -> V=1.0, theta=0.0
% INFO    : Bus 20408	: V=1.02, theta=-13.230331 -> V=1.0, theta=0.0
% INFO    : Bus 20409	: V=1.02, theta=-4.600478 -> V=1.0, theta=0.0
% INFO    : Bus 20410	: V=0.9870101, theta=-7.138357 -> V=1.0, theta=0.0
% INFO    : Bus 20411	: V=0.9816964, theta=5.656378 -> V=1.0, theta=0.0
% INFO    : Bus 20412	: V=0.9782934, theta=12.361138 -> V=1.0, theta=0.0
% INFO    : Bus 20413	: V=1.02, theta=-17.783112 -> V=1.0, theta=0.0
% INFO    : Bus 20414	: V=0.9963801, theta=-15.489638 -> V=1.0, theta=0.0
% INFO    : Bus 20415	: V=1.02, theta=-8.004941 -> V=1.0, theta=0.0
% INFO    : Bus 20416	: V=0.9711545, theta=7.235205 -> V=1.0, theta=0.0
% INFO    : Bus 20417	: V=1.0200336, theta=-17.758386 -> V=1.0, theta=0.0
% INFO    : Bus 20418	: V=0.9785195, theta=11.988799 -> V=1.0, theta=0.0
% INFO    : Bus 20419	: V=1.02, theta=-14.23494 -> V=1.0, theta=0.0
% INFO    : Bus 20420	: V=0.9926173, theta=4.111449 -> V=1.0, theta=0.0
% INFO    : Bus 20421	: V=1.0039972, theta=1.671285 -> V=1.0, theta=0.0
% INFO    : Bus 20422	: V=0.9793672, theta=10.913814 -> V=1.0, theta=0.0
% INFO    : Bus 20423	: V=1.02, theta=-4.622891 -> V=1.0, theta=0.0
% INFO    : Bus 20424	: V=1.0181991, theta=-5.022099 -> V=1.0, theta=0.0
% INFO    : Bus 20425	: V=1.02, theta=-6.738517 -> V=1.0, theta=0.0
% INFO    : Bus 20426	: V=0.9882288, theta=1.130728 -> V=1.0, theta=0.0
% INFO    : Bus 20427	: V=0.9572291, theta=-16.314611 -> V=1.0, theta=0.0
% INFO    : Bus 20428	: V=1.02, theta=-7.985518 -> V=1.0, theta=0.0
% INFO    : Bus 20429	: V=0.9982231, theta=-5.028202 -> V=1.0, theta=0.0
% INFO    : Bus 20430	: V=1.000692, theta=0.674213 -> V=1.0, theta=0.0
% INFO    : Bus 20431	: V=1.004712, theta=-4.076449 -> V=1.0, theta=0.0
% INFO    : Bus 20432	: V=1.0078896, theta=-3.69782 -> V=1.0, theta=0.0
% INFO    : Bus 20433	: V=0.9652001, theta=8.94311 -> V=1.0, theta=0.0
% INFO    : Bus 20434	: V=0.9654888, theta=9.029465 -> V=1.0, theta=0.0
% INFO    : Bus 20435	: V=0.9662062, theta=8.933054 -> V=1.0, theta=0.0
% INFO    : Bus 20436	: V=1.02, theta=-0.026342 -> V=1.0, theta=0.0
% INFO    : Bus 20437	: V=0.9912601, theta=-15.376958 -> V=1.0, theta=0.0
% INFO    : Bus 20438	: V=1.0144499, theta=-11.262665 -> V=1.0, theta=0.0
% INFO    : Bus 20439	: V=0.9716558, theta=3.69729 -> V=1.0, theta=0.0
% INFO    : Bus 20440	: V=0.9838303, theta=-16.676943 -> V=1.0, theta=0.0
% INFO    : Bus 20441	: V=1.0152902, theta=-8.42198 -> V=1.0, theta=0.0
% INFO    : Bus 20442	: V=0.9746282, theta=-23.737538 -> V=1.0, theta=0.0
% INFO    : Bus 20443	: V=1.015705, theta=-8.454577 -> V=1.0, theta=0.0
% INFO    : Bus 20444	: V=0.9747115, theta=3.686881 -> V=1.0, theta=0.0
% INFO    : Bus 20445	: V=1.0037737, theta=-15.74468 -> V=1.0, theta=0.0
% INFO    : Bus 20446	: V=0.9758222, theta=-24.69079 -> V=1.0, theta=0.0
% INFO    : Bus 20447	: V=0.9821983, theta=-25.718472 -> V=1.0, theta=0.0
% INFO    : Bus 20448	: V=0.9697434, theta=-20.633947 -> V=1.0, theta=0.0
% INFO    : Bus 20449	: V=1.02, theta=-7.534726 -> V=1.0, theta=0.0
% INFO    : Bus 20450	: V=0.9811727, theta=-26.783255 -> V=1.0, theta=0.0
% INFO    : Bus 20451	: V=0.9733987, theta=-8.71539 -> V=1.0, theta=0.0
% INFO    : Bus 20452	: V=0.9603811, theta=-13.270661 -> V=1.0, theta=0.0
% INFO    : Bus 20453	: V=0.9743628, theta=-9.866767 -> V=1.0, theta=0.0
% INFO    : Bus 20454	: V=0.9775913, theta=-17.757118 -> V=1.0, theta=0.0
% INFO    : Bus 20455	: V=0.9972614, theta=-11.296167 -> V=1.0, theta=0.0
% INFO    : Bus 20456	: V=0.9648503, theta=-14.588531 -> V=1.0, theta=0.0
% INFO    : Bus 20457	: V=1.02, theta=-16.78079 -> V=1.0, theta=0.0
% INFO    : Bus 20458	: V=1.02, theta=-2.66237 -> V=1.0, theta=0.0
% INFO    : Bus 20459	: V=1.02, theta=-2.787094 -> V=1.0, theta=0.0
% INFO    : Bus 20460	: V=1.02, theta=-1.44741 -> V=1.0, theta=0.0
% INFO    : Bus 20461	: V=1.02, theta=-16.69897 -> V=1.0, theta=0.0
% INFO    : Bus 20462	: V=1.02, theta=9.321494 -> V=1.0, theta=0.0
% INFO    : Bus 20463	: V=1.0060478, theta=-21.747178 -> V=1.0, theta=0.0
% INFO    : Bus 20464	: V=1.02, theta=5.071543 -> V=1.0, theta=0.0
% INFO    : Bus 20465	: V=1.02, theta=-1.382627 -> V=1.0, theta=0.0
% INFO    : Bus 20466	: V=1.02, theta=-10.129219 -> V=1.0, theta=0.0
% INFO    : Bus 20467	: V=1.02, theta=4.270001 -> V=1.0, theta=0.0
% INFO    : Bus 20468	: V=1.0049269, theta=-21.742097 -> V=1.0, theta=0.0
% INFO    : Bus 20469	: V=1.02, theta=-1.188154 -> V=1.0, theta=0.0
% INFO    : Bus 20470	: V=0.9774728, theta=-19.548147 -> V=1.0, theta=0.0
% INFO    : Bus 20471	: V=1.02, theta=-4.267753 -> V=1.0, theta=0.0
% INFO    : Bus 20472	: V=0.9965319, theta=-5.974207 -> V=1.0, theta=0.0
% INFO    : Bus 20473	: V=1.02, theta=-4.239873 -> V=1.0, theta=0.0
% INFO    : Bus 20474	: V=0.9926184, theta=-20.931819 -> V=1.0, theta=0.0
% INFO    : Bus 20475	: V=1.02, theta=-9.935784 -> V=1.0, theta=0.0
% INFO    : Bus 20476	: V=0.9994039, theta=-23.309049 -> V=1.0, theta=0.0
% INFO    : Bus 20477	: V=1.0012986, theta=-27.974586 -> V=1.0, theta=0.0
% INFO    : Bus 20478	: V=1.0307952, theta=8.695708 -> V=1.0, theta=0.0
% INFO    : Bus 20479	: V=1.0160083, theta=-17.077121 -> V=1.0, theta=0.0
% INFO    : Bus 20480	: V=1.02, theta=-9.036244 -> V=1.0, theta=0.0
% INFO    : Bus 20481	: V=0.9937222, theta=-25.298916 -> V=1.0, theta=0.0
% INFO    : Bus 20482	: V=1.0180634, theta=8.808724 -> V=1.0, theta=0.0
% INFO    : Bus 20483	: V=1.02, theta=-0.288307 -> V=1.0, theta=0.0
% INFO    : Bus 20484	: V=1.0095008, theta=4.607297 -> V=1.0, theta=0.0
% INFO    : Bus 20485	: V=1.0174634, theta=-15.708209 -> V=1.0, theta=0.0
% INFO    : Bus 20486	: V=0.9744899, theta=-8.144582 -> V=1.0, theta=0.0
% INFO    : Bus 20487	: V=1.019873, theta=-9.97436 -> V=1.0, theta=0.0
% INFO    : Bus 20488	: V=0.9822797, theta=-22.719376 -> V=1.0, theta=0.0
% INFO    : Bus 20489	: V=0.9976396, theta=-26.728943 -> V=1.0, theta=0.0
% INFO    : Bus 20490	: V=0.9834709, theta=-21.934901 -> V=1.0, theta=0.0
% INFO    : Bus 20491	: V=0.9700212, theta=-24.893603 -> V=1.0, theta=0.0
% INFO    : Bus 20492	: V=0.9796471, theta=-8.893359 -> V=1.0, theta=0.0
% INFO    : Bus 20493	: V=0.9883692, theta=-2.238045 -> V=1.0, theta=0.0
% INFO    : Bus 20494	: V=1.02, theta=-19.858851 -> V=1.0, theta=0.0
% INFO    : Bus 20495	: V=0.9927318, theta=0.741175 -> V=1.0, theta=0.0
% INFO    : Bus 20496	: V=0.9651983, theta=-19.818809 -> V=1.0, theta=0.0
% INFO    : Bus 20497	: V=0.9768639, theta=-12.363333 -> V=1.0, theta=0.0
% INFO    : Bus 20498	: V=1.0111219, theta=-5.014615 -> V=1.0, theta=0.0
% INFO    : Bus 20499	: V=0.9711667, theta=-24.761127 -> V=1.0, theta=0.0
% INFO    : Bus 20500	: V=1.02, theta=-3.026579 -> V=1.0, theta=0.0
% INFO    : Bus 20501	: V=0.9937295, theta=1.449152 -> V=1.0, theta=0.0
% INFO    : Bus 20502	: V=1.02, theta=-0.190458 -> V=1.0, theta=0.0
% INFO    : Bus 20503	: V=1.0133672, theta=5.638004 -> V=1.0, theta=0.0
% INFO    : Bus 20504	: V=0.9945189, theta=-12.119783 -> V=1.0, theta=0.0
% INFO    : Bus 20505	: V=1.0154835, theta=3.195682 -> V=1.0, theta=0.0
% INFO    : Bus 20506	: V=0.9919144, theta=-3.525282 -> V=1.0, theta=0.0
% INFO    : Bus 20507	: V=0.9718635, theta=-8.581035 -> V=1.0, theta=0.0
% INFO    : Bus 20508	: V=0.9801158, theta=-0.906598 -> V=1.0, theta=0.0
% INFO    : Bus 20509	: V=0.9914205, theta=0.951441 -> V=1.0, theta=0.0
% INFO    : Bus 20510	: V=0.9656486, theta=-22.69577 -> V=1.0, theta=0.0
% INFO    : Bus 20511	: V=0.9748736, theta=24.843733 -> V=1.0, theta=0.0
% INFO    : Bus 20512	: V=0.967239, theta=16.792992 -> V=1.0, theta=0.0
% INFO    : Bus 20513	: V=1.02, theta=0.292144 -> V=1.0, theta=0.0
% INFO    : Bus 20514	: V=1.001588, theta=1.081745 -> V=1.0, theta=0.0
% INFO    : Bus 20515	: V=1.0189546, theta=11.630324 -> V=1.0, theta=0.0
% INFO    : Bus 20516	: V=1.009997, theta=2.481633 -> V=1.0, theta=0.0
% INFO    : Bus 20517	: V=1.0169656, theta=-17.142189 -> V=1.0, theta=0.0
% INFO    : Bus 20518	: V=1.02, theta=6.40089 -> V=1.0, theta=0.0
% INFO    : Bus 20519	: V=1.013672, theta=-0.647348 -> V=1.0, theta=0.0
% INFO    : Bus 20520	: V=0.9909062, theta=22.821101 -> V=1.0, theta=0.0
% INFO    : Bus 20521	: V=0.9994638, theta=-0.144802 -> V=1.0, theta=0.0
% INFO    : Bus 20522	: V=0.993453, theta=21.272707 -> V=1.0, theta=0.0
% INFO    : Bus 20523	: V=1.0067989, theta=1.65504 -> V=1.0, theta=0.0
% INFO    : Bus 20524	: V=1.0107762, theta=2.585924 -> V=1.0, theta=0.0
% INFO    : Bus 20525	: V=0.9722021, theta=-5.391494 -> V=1.0, theta=0.0
% INFO    : Bus 20526	: V=1.0143114, theta=11.830241 -> V=1.0, theta=0.0
% INFO    : Bus 20527	: V=0.9996896, theta=3.341545 -> V=1.0, theta=0.0
% INFO    : Bus 20528	: V=0.9796855, theta=-1.497405 -> V=1.0, theta=0.0
% INFO    : Bus 20529	: V=1.02, theta=9.162265 -> V=1.0, theta=0.0
% INFO    : Bus 20530	: V=1.0096308, theta=-4.089295 -> V=1.0, theta=0.0
% INFO    : Bus 20531	: V=1.0177972, theta=-22.294043 -> V=1.0, theta=0.0
% INFO    : Bus 20532	: V=1.02, theta=-49.603218 -> V=1.0, theta=0.0
% INFO    : Bus 20533	: V=1.02, theta=-27.623164 -> V=1.0, theta=0.0
% INFO    : Bus 20534	: V=1.0063078, theta=-31.81805 -> V=1.0, theta=0.0
% INFO    : Bus 20535	: V=1.02, theta=-24.188663 -> V=1.0, theta=0.0
% INFO    : Bus 20536	: V=1.02, theta=-49.720438 -> V=1.0, theta=0.0
% INFO    : Bus 20537	: V=1.02, theta=-20.846626 -> V=1.0, theta=0.0
% INFO    : Bus 20538	: V=1.0118379, theta=-25.206607 -> V=1.0, theta=0.0
% INFO    : Bus 20539	: V=1.014867, theta=-52.344978 -> V=1.0, theta=0.0
% INFO    : Bus 20540	: V=0.9813586, theta=-50.819682 -> V=1.0, theta=0.0
% INFO    : Bus 20541	: V=1.02, theta=-32.864204 -> V=1.0, theta=0.0
% INFO    : Bus 20542	: V=1.02, theta=-28.433744 -> V=1.0, theta=0.0
% INFO    : Bus 20543	: V=1.02, theta=-33.932204 -> V=1.0, theta=0.0
% INFO    : Bus 20544	: V=0.9902152, theta=-24.447688 -> V=1.0, theta=0.0
% INFO    : Bus 20545	: V=1.02, theta=-29.854537 -> V=1.0, theta=0.0
% INFO    : Bus 20546	: V=1.02, theta=-53.488992 -> V=1.0, theta=0.0
% INFO    : Bus 20547	: V=1.02, theta=-33.423676 -> V=1.0, theta=0.0
% INFO    : Bus 20548	: V=1.0036841, theta=-29.966476 -> V=1.0, theta=0.0
% INFO    : Bus 20549	: V=1.02, theta=-22.656295 -> V=1.0, theta=0.0
% INFO    : Bus 20550	: V=1.0129819, theta=-41.158179 -> V=1.0, theta=0.0
% INFO    : Bus 20551	: V=0.9972549, theta=-29.427817 -> V=1.0, theta=0.0
% INFO    : Bus 20552	: V=0.9847701, theta=-61.270345 -> V=1.0, theta=0.0
% INFO    : Bus 20553	: V=0.9902335, theta=-29.680153 -> V=1.0, theta=0.0
% INFO    : Bus 20554	: V=1.0132359, theta=-49.320127 -> V=1.0, theta=0.0
% INFO    : Bus 20555	: V=1.0178524, theta=-23.890396 -> V=1.0, theta=0.0
% INFO    : Bus 20556	: V=0.9773504, theta=-39.159505 -> V=1.0, theta=0.0
% INFO    : Bus 20557	: V=1.02, theta=-44.864775 -> V=1.0, theta=0.0
% INFO    : Bus 20558	: V=0.9981739, theta=-27.266134 -> V=1.0, theta=0.0
% INFO    : Bus 20559	: V=0.9854984, theta=-36.847302 -> V=1.0, theta=0.0
% INFO    : Bus 20560	: V=0.9864888, theta=-30.102649 -> V=1.0, theta=0.0
% INFO    : Bus 20561	: V=1.0033504, theta=-26.62492 -> V=1.0, theta=0.0
% INFO    : Bus 20562	: V=0.9967988, theta=-45.775294 -> V=1.0, theta=0.0
% INFO    : Bus 20563	: V=0.9971509, theta=-43.978501 -> V=1.0, theta=0.0
% INFO    : Bus 20564	: V=0.9866116, theta=-30.084909 -> V=1.0, theta=0.0
% INFO    : Bus 20565	: V=0.9940892, theta=-28.527347 -> V=1.0, theta=0.0
% INFO    : Bus 20566	: V=0.970053, theta=-50.70066 -> V=1.0, theta=0.0
% INFO    : Bus 20567	: V=1.0150666, theta=-25.427531 -> V=1.0, theta=0.0
% INFO    : Bus 20568	: V=1.0160569, theta=-20.112107 -> V=1.0, theta=0.0
% INFO    : Bus 20569	: V=0.9829183, theta=-29.566697 -> V=1.0, theta=0.0
% INFO    : Bus 20570	: V=1.0073957, theta=-50.800513 -> V=1.0, theta=0.0
% INFO    : Bus 20571	: V=0.978428, theta=-26.963986 -> V=1.0, theta=0.0
% INFO    : Bus 20572	: V=0.9761023, theta=-49.311929 -> V=1.0, theta=0.0
% INFO    : Bus 20573	: V=0.9803254, theta=-28.100798 -> V=1.0, theta=0.0
% INFO    : Bus 20574	: V=0.9758282, theta=-32.468896 -> V=1.0, theta=0.0
% INFO    : Bus 20575	: V=0.9767003, theta=-49.271361 -> V=1.0, theta=0.0
% INFO    : Bus 20576	: V=0.9859374, theta=-29.196713 -> V=1.0, theta=0.0
% INFO    : Bus 20577	: V=0.9687015, theta=-50.365289 -> V=1.0, theta=0.0
% INFO    : Bus 20578	: V=0.9822666, theta=-27.324561 -> V=1.0, theta=0.0
% INFO    : Bus 20579	: V=0.9830647, theta=-32.321009 -> V=1.0, theta=0.0
% INFO    : Bus 20580	: V=1.0194261, theta=-51.989994 -> V=1.0, theta=0.0
% INFO    : Bus 20581	: V=0.9874154, theta=-28.6256 -> V=1.0, theta=0.0
% INFO    : Bus 20582	: V=0.985512, theta=-46.49399 -> V=1.0, theta=0.0
% INFO    : Bus 20583	: V=0.9765274, theta=-48.911291 -> V=1.0, theta=0.0
% INFO    : Bus 20584	: V=0.9999979, theta=-26.327038 -> V=1.0, theta=0.0
% INFO    : Bus 20585	: V=0.9943439, theta=-33.255847 -> V=1.0, theta=0.0
% INFO    : Bus 20586	: V=0.9589402, theta=-36.151719 -> V=1.0, theta=0.0
% INFO    : Bus 20587	: V=1.01122, theta=-52.757894 -> V=1.0, theta=0.0
% INFO    : Bus 20588	: V=1.02, theta=-34.595606 -> V=1.0, theta=0.0
% INFO    : Bus 20589	: V=1.0143113, theta=-25.567769 -> V=1.0, theta=0.0
% INFO    : Bus 20590	: V=0.9749702, theta=-52.748143 -> V=1.0, theta=0.0
% INFO    : Bus 20591	: V=0.9683739, theta=-61.865642 -> V=1.0, theta=0.0
% INFO    : Bus 20592	: V=0.9528704, theta=-35.412731 -> V=1.0, theta=0.0
% INFO    : Bus 20593	: V=0.9557287, theta=-27.383181 -> V=1.0, theta=0.0
% INFO    : Bus 20594	: V=0.9552198, theta=-27.492948 -> V=1.0, theta=0.0
% INFO    : Bus 20595	: V=0.9543716, theta=-27.470842 -> V=1.0, theta=0.0
% INFO    : Bus 20596	: V=0.9544111, theta=-27.323406 -> V=1.0, theta=0.0
% INFO    : Bus 20597	: V=0.9548515, theta=-26.936959 -> V=1.0, theta=0.0
% INFO    : Bus 20598	: V=0.9548417, theta=-27.212291 -> V=1.0, theta=0.0
% INFO    : Bus 20599	: V=0.9564141, theta=-26.951944 -> V=1.0, theta=0.0
% INFO    : Bus 20600	: V=0.937869, theta=-27.574709 -> V=1.0, theta=0.0
% INFO    : Bus 20601	: V=0.9387257, theta=-27.538382 -> V=1.0, theta=0.0
% INFO    : Bus 20602	: V=0.9335114, theta=-28.945271 -> V=1.0, theta=0.0
% INFO    : Bus 20603	: V=0.9277336, theta=-29.087292 -> V=1.0, theta=0.0
% INFO    : Bus 20604	: V=0.9303467, theta=-28.880365 -> V=1.0, theta=0.0
% INFO    : Bus 20605	: V=0.9263076, theta=-29.114789 -> V=1.0, theta=0.0
% INFO    : Bus 20606	: V=0.9280924, theta=-29.004059 -> V=1.0, theta=0.0
% INFO    : Bus 20607	: V=0.9259795, theta=-29.11346 -> V=1.0, theta=0.0
% INFO    : Bus 20608	: V=0.9265309, theta=-29.12901 -> V=1.0, theta=0.0
% INFO    : Bus 20609	: V=0.9274566, theta=-29.099325 -> V=1.0, theta=0.0
% INFO    : Bus 20610	: V=0.9293665, theta=-28.974539 -> V=1.0, theta=0.0
% INFO    : Bus 20611	: V=0.9300128, theta=-28.923631 -> V=1.0, theta=0.0
% INFO    : Bus 20612	: V=0.9313815, theta=-28.848862 -> V=1.0, theta=0.0
% INFO    : Bus 20613	: V=0.9557815, theta=-25.117307 -> V=1.0, theta=0.0
% INFO    : Bus 20614	: V=0.9554298, theta=-25.159849 -> V=1.0, theta=0.0
% INFO    : Bus 20615	: V=0.939196, theta=-27.450722 -> V=1.0, theta=0.0
% INFO    : Bus 20616	: V=0.9386423, theta=-27.467353 -> V=1.0, theta=0.0
% INFO    : Bus 20617	: V=0.9374771, theta=-27.556747 -> V=1.0, theta=0.0
% INFO    : Bus 20618	: V=0.9443705, theta=-27.260671 -> V=1.0, theta=0.0
% INFO    : Bus 20619	: V=0.92878, theta=-28.868046 -> V=1.0, theta=0.0
% INFO    : Bus 20620	: V=0.9296201, theta=-28.776835 -> V=1.0, theta=0.0
% INFO    : Bus 20621	: V=0.9367, theta=-28.355046 -> V=1.0, theta=0.0
% INFO    : Bus 20622	: V=0.9438724, theta=-27.678139 -> V=1.0, theta=0.0
% INFO    : Bus 20623	: V=0.9453319, theta=-27.182324 -> V=1.0, theta=0.0
% INFO    : Bus 20624	: V=0.9346145, theta=-28.737117 -> V=1.0, theta=0.0
% INFO    : Bus 20625	: V=0.9331484, theta=-28.873202 -> V=1.0, theta=0.0
% INFO    : Bus 20626	: V=0.9274786, theta=-29.556047 -> V=1.0, theta=0.0
% INFO    : Bus 20627	: V=0.9369551, theta=-27.538089 -> V=1.0, theta=0.0
% INFO    : Bus 20628	: V=0.9312202, theta=-29.213086 -> V=1.0, theta=0.0
% INFO    : Bus 20629	: V=0.9398502, theta=-27.55157 -> V=1.0, theta=0.0
% INFO    : Bus 20630	: V=0.9320717, theta=-28.964884 -> V=1.0, theta=0.0
% INFO    : Bus 20631	: V=0.9280712, theta=-29.09366 -> V=1.0, theta=0.0
% INFO    : Bus 20632	: V=0.9268276, theta=-29.700389 -> V=1.0, theta=0.0
% INFO    : Bus 20633	: V=0.9310355, theta=-28.958084 -> V=1.0, theta=0.0
% INFO    : Bus 20634	: V=0.9310261, theta=-28.996752 -> V=1.0, theta=0.0
% INFO    : Bus 20635	: V=0.9448287, theta=-27.22611 -> V=1.0, theta=0.0
% INFO    : Bus 20636	: V=0.9288452, theta=-29.436756 -> V=1.0, theta=0.0
% INFO    : Bus 20637	: V=0.9284097, theta=-29.471775 -> V=1.0, theta=0.0
% INFO    : Bus 20638	: V=0.956878, theta=-25.18353 -> V=1.0, theta=0.0
% INFO    : Bus 20639	: V=0.9399439, theta=-27.424168 -> V=1.0, theta=0.0
% INFO    : Bus 20640	: V=0.9367396, theta=-29.986822 -> V=1.0, theta=0.0
% INFO    : Bus 20641	: V=0.9282564, theta=-30.031455 -> V=1.0, theta=0.0
% INFO    : Bus 20642	: V=0.9397085, theta=-28.786005 -> V=1.0, theta=0.0
% INFO    : Bus 20643	: V=0.9289983, theta=-29.135616 -> V=1.0, theta=0.0
% INFO    : Bus 20644	: V=0.927312, theta=-29.25892 -> V=1.0, theta=0.0
% INFO    : Bus 20645	: V=0.9272306, theta=-29.873953 -> V=1.0, theta=0.0
% INFO    : Bus 20646	: V=0.9213593, theta=-30.284265 -> V=1.0, theta=0.0
% INFO    : Bus 20647	: V=0.9230942, theta=-30.175832 -> V=1.0, theta=0.0
% INFO    : Bus 20648	: V=0.9227927, theta=-29.693683 -> V=1.0, theta=0.0
% INFO    : Bus 20649	: V=0.9204436, theta=-29.308041 -> V=1.0, theta=0.0
% INFO    : Bus 20650	: V=0.9308997, theta=-28.426505 -> V=1.0, theta=0.0
% INFO    : Bus 20651	: V=0.9353403, theta=-27.022076 -> V=1.0, theta=0.0
% INFO    : Bus 20652	: V=0.9359305, theta=-27.460958 -> V=1.0, theta=0.0
% INFO    : Bus 20653	: V=0.9506464, theta=-25.671026 -> V=1.0, theta=0.0
% INFO    : Bus 20654	: V=0.9263326, theta=-29.670998 -> V=1.0, theta=0.0
% INFO    : Bus 20655	: V=0.9313996, theta=-28.736495 -> V=1.0, theta=0.0
% INFO    : Bus 20656	: V=0.9301774, theta=-28.944649 -> V=1.0, theta=0.0
% INFO    : Bus 20657	: V=0.9290994, theta=-29.511506 -> V=1.0, theta=0.0
% INFO    : Bus 20658	: V=0.9281552, theta=-29.589805 -> V=1.0, theta=0.0
% INFO    : Bus 20659	: V=0.9277168, theta=-29.632107 -> V=1.0, theta=0.0
% INFO    : Bus 20660	: V=0.9295185, theta=-29.196364 -> V=1.0, theta=0.0
% INFO    : Bus 20661	: V=0.9299056, theta=-29.180518 -> V=1.0, theta=0.0
% INFO    : Bus 20662	: V=0.945294, theta=-27.3121 -> V=1.0, theta=0.0
% INFO    : Bus 20663	: V=0.9342906, theta=-28.780022 -> V=1.0, theta=0.0
% INFO    : Bus 20664	: V=0.9283197, theta=-29.574879 -> V=1.0, theta=0.0
% INFO    : Bus 20665	: V=0.9273926, theta=-29.796694 -> V=1.0, theta=0.0
% INFO    : Bus 20666	: V=0.9272976, theta=-29.714288 -> V=1.0, theta=0.0
% INFO    : Bus 20667	: V=0.9331808, theta=-28.93703 -> V=1.0, theta=0.0
% INFO    : Bus 20668	: V=0.9299789, theta=-29.410062 -> V=1.0, theta=0.0
% INFO    : Bus 20669	: V=0.9321751, theta=-29.049346 -> V=1.0, theta=0.0
% INFO    : Bus 20670	: V=0.9569452, theta=-28.05501 -> V=1.0, theta=0.0
% INFO    : Bus 20671	: V=0.975916, theta=-24.848841 -> V=1.0, theta=0.0
% INFO    : Bus 20672	: V=0.9454963, theta=-27.281033 -> V=1.0, theta=0.0
% INFO    : Bus 20673	: V=0.9608551, theta=-25.180195 -> V=1.0, theta=0.0
% INFO    : Bus 20674	: V=0.9442437, theta=-27.932118 -> V=1.0, theta=0.0
% INFO    : Bus 20675	: V=0.9406384, theta=-28.253898 -> V=1.0, theta=0.0
% INFO    : Bus 20676	: V=0.9371018, theta=-28.470139 -> V=1.0, theta=0.0
% INFO    : Bus 20677	: V=0.940054, theta=-28.344762 -> V=1.0, theta=0.0
% INFO    : Bus 20678	: V=0.947443, theta=-27.183635 -> V=1.0, theta=0.0
% INFO    : Bus 20679	: V=0.9490067, theta=-27.181946 -> V=1.0, theta=0.0
% INFO    : Bus 20680	: V=0.9360769, theta=-27.680832 -> V=1.0, theta=0.0
% INFO    : Bus 20681	: V=0.9366685, theta=-27.299486 -> V=1.0, theta=0.0
% INFO    : Bus 20682	: V=0.9234937, theta=-29.453283 -> V=1.0, theta=0.0
% INFO    : Bus 20683	: V=0.9231549, theta=-29.376955 -> V=1.0, theta=0.0
% INFO    : Bus 20684	: V=0.9232198, theta=-29.276463 -> V=1.0, theta=0.0
% INFO    : Bus 20685	: V=0.923446, theta=-29.429057 -> V=1.0, theta=0.0
% INFO    : Bus 20686	: V=0.9319865, theta=-28.170555 -> V=1.0, theta=0.0
% INFO    : Bus 20687	: V=0.9233338, theta=-29.171071 -> V=1.0, theta=0.0
% INFO    : Bus 20688	: V=0.9227061, theta=-28.562136 -> V=1.0, theta=0.0
% INFO    : Bus 20689	: V=0.9255141, theta=-28.612378 -> V=1.0, theta=0.0
% INFO    : Bus 20690	: V=0.9582185, theta=-25.10549 -> V=1.0, theta=0.0
% INFO    : Bus 20691	: V=0.9525398, theta=-27.130286 -> V=1.0, theta=0.0
% INFO    : Bus 20692	: V=0.9593699, theta=-26.945786 -> V=1.0, theta=0.0
% INFO    : Bus 20693	: V=0.9828635, theta=-24.701378 -> V=1.0, theta=0.0
% INFO    : Bus 20694	: V=0.9324467, theta=-29.089645 -> V=1.0, theta=0.0
% INFO    : Bus 20695	: V=0.9511584, theta=-25.620978 -> V=1.0, theta=0.0
% INFO    : Bus 20696	: V=0.9830741, theta=-17.270617 -> V=1.0, theta=0.0
% INFO    : Bus 20697	: V=0.98203, theta=-17.440363 -> V=1.0, theta=0.0
% INFO    : Bus 20698	: V=0.9819344, theta=-17.455944 -> V=1.0, theta=0.0
% INFO    : Bus 20699	: V=0.9773909, theta=-18.25078 -> V=1.0, theta=0.0
% INFO    : Bus 20700	: V=0.9721386, theta=-18.739036 -> V=1.0, theta=0.0
% INFO    : Bus 20701	: V=0.9639574, theta=-19.801162 -> V=1.0, theta=0.0
% INFO    : Bus 20702	: V=0.9822934, theta=-17.398236 -> V=1.0, theta=0.0
% INFO    : Bus 20703	: V=0.9656675, theta=-19.84949 -> V=1.0, theta=0.0
% INFO    : Bus 20704	: V=0.9693947, theta=-19.516906 -> V=1.0, theta=0.0
% INFO    : Bus 20705	: V=0.9876558, theta=-16.544689 -> V=1.0, theta=0.0
% INFO    : Bus 20706	: V=0.9658594, theta=-19.337653 -> V=1.0, theta=0.0
% INFO    : Bus 20707	: V=0.9735236, theta=-18.617275 -> V=1.0, theta=0.0
% INFO    : Bus 20708	: V=0.9537993, theta=-21.354219 -> V=1.0, theta=0.0
% INFO    : Bus 20709	: V=0.9683728, theta=-19.34203 -> V=1.0, theta=0.0
% INFO    : Bus 20710	: V=0.9889077, theta=-16.368745 -> V=1.0, theta=0.0
% INFO    : Bus 20711	: V=0.9906075, theta=-2.048827 -> V=1.0, theta=0.0
% INFO    : Bus 20712	: V=0.9964252, theta=1.050765 -> V=1.0, theta=0.0
% INFO    : Bus 20713	: V=0.9909492, theta=2.83412 -> V=1.0, theta=0.0
% INFO    : Bus 20714	: V=0.9571133, theta=-24.547248 -> V=1.0, theta=0.0
% INFO    : Bus 20715	: V=0.9543175, theta=-24.342424 -> V=1.0, theta=0.0
% INFO    : Bus 20716	: V=0.9535636, theta=-24.224942 -> V=1.0, theta=0.0
% INFO    : Bus 20717	: V=0.9353274, theta=-25.493196 -> V=1.0, theta=0.0
% INFO    : Bus 20718	: V=0.9658262, theta=-15.418359 -> V=1.0, theta=0.0
% INFO    : Bus 20719	: V=0.9622973, theta=-13.165801 -> V=1.0, theta=0.0
% INFO    : Bus 20720	: V=0.9878865, theta=-12.093693 -> V=1.0, theta=0.0
% INFO    : Bus 20721	: V=0.947109, theta=-16.264549 -> V=1.0, theta=0.0
% INFO    : Bus 20722	: V=0.9473283, theta=-16.390156 -> V=1.0, theta=0.0
% INFO    : Bus 20723	: V=0.9765598, theta=-15.777362 -> V=1.0, theta=0.0
% INFO    : Bus 20724	: V=0.9917883, theta=-14.743997 -> V=1.0, theta=0.0
% INFO    : Bus 20725	: V=0.9778016, theta=-16.922311 -> V=1.0, theta=0.0
% INFO    : Bus 20726	: V=0.9908032, theta=-15.142775 -> V=1.0, theta=0.0
% INFO    : Bus 20727	: V=0.9517681, theta=-17.596905 -> V=1.0, theta=0.0
% INFO    : Bus 20728	: V=0.9764943, theta=-17.57004 -> V=1.0, theta=0.0
% INFO    : Bus 20729	: V=0.9745347, theta=-16.706661 -> V=1.0, theta=0.0
% INFO    : Bus 20730	: V=0.9750484, theta=-17.545468 -> V=1.0, theta=0.0
% INFO    : Bus 20731	: V=0.9745047, theta=-17.37589 -> V=1.0, theta=0.0
% INFO    : Bus 20732	: V=0.9747819, theta=-11.120697 -> V=1.0, theta=0.0
% INFO    : Bus 20733	: V=0.9643973, theta=-8.312671 -> V=1.0, theta=0.0
% INFO    : Bus 20734	: V=0.9695689, theta=-8.217674 -> V=1.0, theta=0.0
% INFO    : Bus 20735	: V=0.9769517, theta=-9.264082 -> V=1.0, theta=0.0
% INFO    : Bus 20736	: V=0.9705161, theta=-11.532407 -> V=1.0, theta=0.0
% INFO    : Bus 20737	: V=0.9757139, theta=-10.34365 -> V=1.0, theta=0.0
% INFO    : Bus 20738	: V=0.9610863, theta=-13.329709 -> V=1.0, theta=0.0
% INFO    : Bus 20739	: V=0.9497732, theta=-13.763108 -> V=1.0, theta=0.0
% INFO    : Bus 20740	: V=0.9615714, theta=-11.967654 -> V=1.0, theta=0.0
% INFO    : Bus 20741	: V=0.9672993, theta=-10.375641 -> V=1.0, theta=0.0
% INFO    : Bus 20742	: V=0.9550531, theta=-13.642766 -> V=1.0, theta=0.0
% INFO    : Bus 20743	: V=0.9560813, theta=-13.559517 -> V=1.0, theta=0.0
% INFO    : Bus 20744	: V=0.9715263, theta=-11.806465 -> V=1.0, theta=0.0
% INFO    : Bus 20745	: V=0.9593904, theta=-13.341498 -> V=1.0, theta=0.0
% INFO    : Bus 20746	: V=0.9535061, theta=-13.691827 -> V=1.0, theta=0.0
% INFO    : Bus 20747	: V=0.9731762, theta=-12.572205 -> V=1.0, theta=0.0
% INFO    : Bus 20748	: V=1.0049099, theta=-8.50677 -> V=1.0, theta=0.0
% INFO    : Bus 20749	: V=0.9682781, theta=-13.085531 -> V=1.0, theta=0.0
% INFO    : Bus 20750	: V=0.9905177, theta=-18.134077 -> V=1.0, theta=0.0
% INFO    : Bus 20751	: V=1.018329, theta=-14.580061 -> V=1.0, theta=0.0
% INFO    : Bus 20752	: V=1.0181837, theta=-14.626916 -> V=1.0, theta=0.0
% INFO    : Bus 20753	: V=0.9985953, theta=-17.533904 -> V=1.0, theta=0.0
% INFO    : Bus 20754	: V=0.9955336, theta=-17.705586 -> V=1.0, theta=0.0
% INFO    : Bus 20755	: V=0.9928858, theta=-17.914311 -> V=1.0, theta=0.0
% INFO    : Bus 20756	: V=0.9900792, theta=-17.983259 -> V=1.0, theta=0.0
% INFO    : Bus 20757	: V=0.9931197, theta=-17.821303 -> V=1.0, theta=0.0
% INFO    : Bus 20758	: V=0.9936361, theta=-17.780937 -> V=1.0, theta=0.0
% INFO    : Bus 20759	: V=1.0019727, theta=-16.804752 -> V=1.0, theta=0.0
% INFO    : Bus 20760	: V=1.0009545, theta=-16.945683 -> V=1.0, theta=0.0
% INFO    : Bus 20761	: V=1.0001071, theta=-17.045368 -> V=1.0, theta=0.0
% INFO    : Bus 20762	: V=1.0177894, theta=-14.736355 -> V=1.0, theta=0.0
% INFO    : Bus 20763	: V=0.9991465, theta=-17.305692 -> V=1.0, theta=0.0
% INFO    : Bus 20764	: V=0.9991918, theta=-17.19657 -> V=1.0, theta=0.0
% INFO    : Bus 20765	: V=0.9950102, theta=-17.6366 -> V=1.0, theta=0.0
% INFO    : Bus 20766	: V=1.0173117, theta=-14.970657 -> V=1.0, theta=0.0
% INFO    : Bus 20767	: V=1.0040276, theta=-16.665085 -> V=1.0, theta=0.0
% INFO    : Bus 20768	: V=0.9955945, theta=-17.518517 -> V=1.0, theta=0.0
% INFO    : Bus 20769	: V=0.9966842, theta=-16.450796 -> V=1.0, theta=0.0
% INFO    : Bus 20770	: V=0.9949748, theta=-16.787812 -> V=1.0, theta=0.0
% INFO    : Bus 20771	: V=0.9944326, theta=-16.858816 -> V=1.0, theta=0.0
% INFO    : Bus 20772	: V=1.0053539, theta=-16.449946 -> V=1.0, theta=0.0
% INFO    : Bus 20773	: V=1.0168193, theta=-15.336812 -> V=1.0, theta=0.0
% INFO    : Bus 20774	: V=0.9979946, theta=-17.193116 -> V=1.0, theta=0.0
% INFO    : Bus 20775	: V=1.0039456, theta=-16.376312 -> V=1.0, theta=0.0
% INFO    : Bus 20776	: V=0.9880175, theta=-10.026634 -> V=1.0, theta=0.0
% INFO    : Bus 20777	: V=0.9838221, theta=-10.631153 -> V=1.0, theta=0.0
% INFO    : Bus 20778	: V=0.9816863, theta=-11.061549 -> V=1.0, theta=0.0
% INFO    : Bus 20779	: V=0.990176, theta=-9.760645 -> V=1.0, theta=0.0
% INFO    : Bus 20780	: V=0.9915524, theta=-10.16983 -> V=1.0, theta=0.0
% INFO    : Bus 20781	: V=1.0010619, theta=-9.421756 -> V=1.0, theta=0.0
% INFO    : Bus 20782	: V=0.9539247, theta=-17.534533 -> V=1.0, theta=0.0
% INFO    : Bus 20783	: V=0.9559976, theta=-13.98227 -> V=1.0, theta=0.0
% INFO    : Bus 20784	: V=0.9448131, theta=-11.453587 -> V=1.0, theta=0.0
% INFO    : Bus 20785	: V=0.9524234, theta=-14.812834 -> V=1.0, theta=0.0
% INFO    : Bus 20786	: V=0.9532331, theta=-14.785161 -> V=1.0, theta=0.0
% INFO    : Bus 20787	: V=0.95434, theta=-14.597755 -> V=1.0, theta=0.0
% INFO    : Bus 20788	: V=0.9544354, theta=-14.733887 -> V=1.0, theta=0.0
% INFO    : Bus 20789	: V=0.9458674, theta=-15.313848 -> V=1.0, theta=0.0
% INFO    : Bus 20790	: V=1.0001881, theta=-14.167301 -> V=1.0, theta=0.0
% INFO    : Bus 20791	: V=0.9904323, theta=-13.491285 -> V=1.0, theta=0.0
% INFO    : Bus 20792	: V=1.0135072, theta=-12.002713 -> V=1.0, theta=0.0
% INFO    : Bus 20793	: V=1.004098, theta=-9.234421 -> V=1.0, theta=0.0
% INFO    : Bus 20794	: V=1.0032903, theta=-7.979672 -> V=1.0, theta=0.0
% INFO    : Bus 20795	: V=1.0017747, theta=-8.436201 -> V=1.0, theta=0.0
% INFO    : Bus 20796	: V=1.0177857, theta=-3.882878 -> V=1.0, theta=0.0
% INFO    : Bus 20797	: V=1.0140158, theta=-6.178559 -> V=1.0, theta=0.0
% INFO    : Bus 20798	: V=1.0134204, theta=-6.185927 -> V=1.0, theta=0.0
% INFO    : Bus 20799	: V=1.0131564, theta=-6.175987 -> V=1.0, theta=0.0
% INFO    : Bus 20800	: V=0.973073, theta=-23.660493 -> V=1.0, theta=0.0
% INFO    : Bus 20801	: V=0.9999324, theta=-21.841008 -> V=1.0, theta=0.0
% INFO    : Bus 20802	: V=0.995551, theta=-21.920526 -> V=1.0, theta=0.0
% INFO    : Bus 20803	: V=0.9760394, theta=-24.007189 -> V=1.0, theta=0.0
% INFO    : Bus 20804	: V=0.9803544, theta=-24.22806 -> V=1.0, theta=0.0
% INFO    : Bus 20805	: V=1.016573, theta=-19.587817 -> V=1.0, theta=0.0
% INFO    : Bus 20806	: V=1.0088711, theta=-20.309204 -> V=1.0, theta=0.0
% INFO    : Bus 20807	: V=1.0081796, theta=-20.339889 -> V=1.0, theta=0.0
% INFO    : Bus 20808	: V=1.0031594, theta=-20.145203 -> V=1.0, theta=0.0
% INFO    : Bus 20809	: V=0.9859581, theta=-22.37172 -> V=1.0, theta=0.0
% INFO    : Bus 20810	: V=0.9535634, theta=-23.73901 -> V=1.0, theta=0.0
% INFO    : Bus 20811	: V=0.9573329, theta=-22.818571 -> V=1.0, theta=0.0
% INFO    : Bus 20812	: V=0.9541567, theta=-23.286706 -> V=1.0, theta=0.0
% INFO    : Bus 20813	: V=0.9506808, theta=-23.965835 -> V=1.0, theta=0.0
% INFO    : Bus 20814	: V=0.9501742, theta=-24.055592 -> V=1.0, theta=0.0
% INFO    : Bus 20815	: V=0.9646997, theta=-21.734944 -> V=1.0, theta=0.0
% INFO    : Bus 20816	: V=0.9283091, theta=-29.033305 -> V=1.0, theta=0.0
% INFO    : Bus 20817	: V=0.9284177, theta=-28.846834 -> V=1.0, theta=0.0
% INFO    : Bus 20818	: V=0.9420014, theta=-29.323278 -> V=1.0, theta=0.0
% INFO    : Bus 20819	: V=0.931059, theta=-29.136096 -> V=1.0, theta=0.0
% INFO    : Bus 20820	: V=0.9411303, theta=-26.026551 -> V=1.0, theta=0.0
% INFO    : Bus 20821	: V=0.919873, theta=-28.250146 -> V=1.0, theta=0.0
% INFO    : Bus 20822	: V=0.9243577, theta=-29.261003 -> V=1.0, theta=0.0
% INFO    : Bus 20823	: V=0.9250686, theta=-29.326381 -> V=1.0, theta=0.0
% INFO    : Bus 20824	: V=0.9412581, theta=-29.051313 -> V=1.0, theta=0.0
% INFO    : Bus 20825	: V=0.9588563, theta=-22.902279 -> V=1.0, theta=0.0
% INFO    : Bus 20826	: V=0.9555136, theta=-23.578649 -> V=1.0, theta=0.0
% INFO    : Bus 20827	: V=0.9605604, theta=-22.373611 -> V=1.0, theta=0.0
% INFO    : Bus 20828	: V=0.9555612, theta=-23.541788 -> V=1.0, theta=0.0
% INFO    : Bus 20829	: V=0.9520832, theta=-24.146492 -> V=1.0, theta=0.0
% INFO    : Bus 20830	: V=0.9553974, theta=-23.487874 -> V=1.0, theta=0.0
% INFO    : Bus 20831	: V=0.9589391, theta=-22.631757 -> V=1.0, theta=0.0
% INFO    : Bus 20832	: V=0.9516038, theta=-24.051233 -> V=1.0, theta=0.0
% INFO    : Bus 20833	: V=0.9550762, theta=-23.517003 -> V=1.0, theta=0.0
% INFO    : Bus 20834	: V=0.9534436, theta=-23.944543 -> V=1.0, theta=0.0
% INFO    : Bus 20835	: V=0.956059, theta=-23.460782 -> V=1.0, theta=0.0
% INFO    : Bus 20836	: V=0.956083, theta=-23.476334 -> V=1.0, theta=0.0
% INFO    : Bus 20837	: V=0.9588693, theta=-23.017095 -> V=1.0, theta=0.0
% INFO    : Bus 20838	: V=0.9485313, theta=-24.591942 -> V=1.0, theta=0.0
% INFO    : Bus 20839	: V=0.9497319, theta=-24.561895 -> V=1.0, theta=0.0
% INFO    : Bus 20840	: V=0.9554047, theta=-23.614165 -> V=1.0, theta=0.0
% INFO    : Bus 20841	: V=0.96031, theta=-22.382617 -> V=1.0, theta=0.0
% INFO    : Bus 20842	: V=0.9591746, theta=-23.228117 -> V=1.0, theta=0.0
% INFO    : Bus 20843	: V=0.9475407, theta=-24.646059 -> V=1.0, theta=0.0
% INFO    : Bus 20844	: V=0.9515243, theta=-24.719847 -> V=1.0, theta=0.0
% INFO    : Bus 20845	: V=0.9466387, theta=-24.818112 -> V=1.0, theta=0.0
% INFO    : Bus 20846	: V=0.9639296, theta=-22.53922 -> V=1.0, theta=0.0
% INFO    : Bus 20847	: V=0.9621679, theta=-22.208785 -> V=1.0, theta=0.0
% INFO    : Bus 20848	: V=0.9528705, theta=-23.670524 -> V=1.0, theta=0.0
% INFO    : Bus 20849	: V=0.9546661, theta=-22.27169 -> V=1.0, theta=0.0
% INFO    : Bus 20850	: V=0.9546955, theta=-23.858096 -> V=1.0, theta=0.0
% INFO    : Bus 20851	: V=0.9532694, theta=-23.43405 -> V=1.0, theta=0.0
% INFO    : Bus 20852	: V=0.960597, theta=-23.893217 -> V=1.0, theta=0.0
% INFO    : Bus 20853	: V=0.9521706, theta=-24.159424 -> V=1.0, theta=0.0
% INFO    : Bus 20854	: V=0.9555962, theta=-23.571308 -> V=1.0, theta=0.0
% INFO    : Bus 20855	: V=1.0013665, theta=-10.035562 -> V=1.0, theta=0.0
% INFO    : Bus 20856	: V=1.0008988, theta=-10.739064 -> V=1.0, theta=0.0
% INFO    : Bus 20857	: V=1.0111203, theta=-9.389633 -> V=1.0, theta=0.0
% INFO    : Bus 20858	: V=1.0003031, theta=-10.676271 -> V=1.0, theta=0.0
% INFO    : Bus 20859	: V=0.9953661, theta=-11.980656 -> V=1.0, theta=0.0
% INFO    : Bus 20860	: V=1.0096409, theta=-9.635667 -> V=1.0, theta=0.0
% INFO    : Bus 20861	: V=1.0093929, theta=-9.668589 -> V=1.0, theta=0.0
% INFO    : Bus 20862	: V=0.928492, theta=-15.645874 -> V=1.0, theta=0.0
% INFO    : Bus 20863	: V=0.9153722, theta=-18.555016 -> V=1.0, theta=0.0
% INFO    : Bus 20864	: V=0.9447406, theta=-15.236714 -> V=1.0, theta=0.0
% INFO    : Bus 20865	: V=0.9456619, theta=-14.949087 -> V=1.0, theta=0.0
% INFO    : Bus 20866	: V=0.9281478, theta=-15.702932 -> V=1.0, theta=0.0
% INFO    : Bus 20867	: V=0.9316851, theta=-15.26907 -> V=1.0, theta=0.0
% INFO    : Bus 20868	: V=0.929871, theta=-15.490686 -> V=1.0, theta=0.0
% INFO    : Bus 20869	: V=0.9219379, theta=-17.641656 -> V=1.0, theta=0.0
% INFO    : Bus 20870	: V=0.9318077, theta=-15.596693 -> V=1.0, theta=0.0
% INFO    : Bus 20871	: V=0.9254442, theta=-17.503518 -> V=1.0, theta=0.0
% INFO    : Bus 20872	: V=0.9263125, theta=-17.107904 -> V=1.0, theta=0.0
% INFO    : Bus 20873	: V=0.943168, theta=-15.774453 -> V=1.0, theta=0.0
% INFO    : Bus 20874	: V=0.9292663, theta=-15.635714 -> V=1.0, theta=0.0
% INFO    : Bus 20875	: V=0.9485705, theta=-11.972053 -> V=1.0, theta=0.0
% INFO    : Bus 20876	: V=0.9364756, theta=-14.60059 -> V=1.0, theta=0.0
% INFO    : Bus 20877	: V=0.9400529, theta=-14.067293 -> V=1.0, theta=0.0
% INFO    : Bus 20878	: V=0.9947976, theta=-7.098811 -> V=1.0, theta=0.0
% INFO    : Bus 20879	: V=0.9422081, theta=-13.267922 -> V=1.0, theta=0.0
% INFO    : Bus 20880	: V=0.9399454, theta=-13.440225 -> V=1.0, theta=0.0
% INFO    : Bus 20881	: V=0.9385471, theta=-13.959423 -> V=1.0, theta=0.0
% INFO    : Bus 20882	: V=0.9563476, theta=-11.636534 -> V=1.0, theta=0.0
% INFO    : Bus 20883	: V=0.9398093, theta=-13.702272 -> V=1.0, theta=0.0
% INFO    : Bus 20884	: V=0.9387959, theta=-13.937584 -> V=1.0, theta=0.0
% INFO    : Bus 20885	: V=0.9392632, theta=-13.202212 -> V=1.0, theta=0.0
% INFO    : Bus 20886	: V=0.9286481, theta=-15.660392 -> V=1.0, theta=0.0
% INFO    : Bus 20887	: V=0.9378342, theta=-14.224254 -> V=1.0, theta=0.0
% INFO    : Bus 20888	: V=0.9560925, theta=-11.719607 -> V=1.0, theta=0.0
% INFO    : Bus 20889	: V=0.9356376, theta=-14.703732 -> V=1.0, theta=0.0
% INFO    : Bus 20890	: V=0.9267578, theta=-15.723655 -> V=1.0, theta=0.0
% INFO    : Bus 20891	: V=0.9390639, theta=-14.087797 -> V=1.0, theta=0.0
% INFO    : Bus 20892	: V=0.9415847, theta=-13.815517 -> V=1.0, theta=0.0
% INFO    : Bus 20893	: V=0.9588124, theta=-11.40566 -> V=1.0, theta=0.0
% INFO    : Bus 20894	: V=0.9404941, theta=-13.774106 -> V=1.0, theta=0.0
% INFO    : Bus 20895	: V=0.9288478, theta=-15.340139 -> V=1.0, theta=0.0
% INFO    : Bus 20896	: V=0.9283139, theta=-15.348531 -> V=1.0, theta=0.0
% INFO    : Bus 20897	: V=0.9389286, theta=-14.047255 -> V=1.0, theta=0.0
% INFO    : Bus 20898	: V=0.9610841, theta=-25.627288 -> V=1.0, theta=0.0
% INFO    : Bus 20899	: V=0.973347, theta=-24.956543 -> V=1.0, theta=0.0
% INFO    : Bus 20900	: V=0.9721413, theta=-24.886649 -> V=1.0, theta=0.0
% INFO    : Bus 20901	: V=0.973185, theta=-24.890145 -> V=1.0, theta=0.0
% INFO    : Bus 20902	: V=0.9717076, theta=-24.844188 -> V=1.0, theta=0.0
% INFO    : Bus 20903	: V=0.9700458, theta=-24.841363 -> V=1.0, theta=0.0
% INFO    : Bus 20904	: V=0.9671963, theta=-24.691765 -> V=1.0, theta=0.0
% INFO    : Bus 20905	: V=0.9950781, theta=-17.440638 -> V=1.0, theta=0.0
% INFO    : Bus 20906	: V=1.0025017, theta=-16.732281 -> V=1.0, theta=0.0
% INFO    : Bus 20907	: V=1.0040307, theta=-16.51621 -> V=1.0, theta=0.0
% INFO    : Bus 20908	: V=1.0046545, theta=-16.444805 -> V=1.0, theta=0.0
% INFO    : Bus 20909	: V=1.0052173, theta=-16.373967 -> V=1.0, theta=0.0
% INFO    : Bus 20910	: V=1.0191283, theta=-14.240202 -> V=1.0, theta=0.0
% INFO    : Bus 20911	: V=0.9979211, theta=-17.088019 -> V=1.0, theta=0.0
% INFO    : Bus 20912	: V=1.005664, theta=-16.338758 -> V=1.0, theta=0.0
% INFO    : Bus 20913	: V=1.017857, theta=-14.491708 -> V=1.0, theta=0.0
% INFO    : Bus 20914	: V=1.0038918, theta=-16.626802 -> V=1.0, theta=0.0
% INFO    : Bus 20915	: V=1.0037172, theta=-16.571157 -> V=1.0, theta=0.0
% INFO    : Bus 20916	: V=0.9975468, theta=-16.547944 -> V=1.0, theta=0.0
% INFO    : Bus 20917	: V=0.997164, theta=-15.813615 -> V=1.0, theta=0.0
% INFO    : Bus 20918	: V=1.0037046, theta=-16.674965 -> V=1.0, theta=0.0
% INFO    : Bus 20919	: V=1.0022325, theta=-16.851486 -> V=1.0, theta=0.0
% INFO    : Bus 20920	: V=1.0006041, theta=-17.027775 -> V=1.0, theta=0.0
% INFO    : Bus 20921	: V=1.0094998, theta=-14.670456 -> V=1.0, theta=0.0
% INFO    : Bus 20922	: V=1.0025883, theta=-16.229614 -> V=1.0, theta=0.0
% INFO    : Bus 20923	: V=1.0062294, theta=-16.067747 -> V=1.0, theta=0.0
% INFO    : Bus 20924	: V=1.0187839, theta=-14.061615 -> V=1.0, theta=0.0
% INFO    : Bus 20925	: V=0.9964652, theta=-3.757139 -> V=1.0, theta=0.0
% INFO    : Bus 20926	: V=0.9912768, theta=-2.01922 -> V=1.0, theta=0.0
% INFO    : Bus 20927	: V=0.9989496, theta=-1.823597 -> V=1.0, theta=0.0
% INFO    : Bus 20928	: V=1.002863, theta=-2.697396 -> V=1.0, theta=0.0
% INFO    : Bus 20929	: V=1.0109029, theta=-1.498941 -> V=1.0, theta=0.0
% INFO    : Bus 20930	: V=0.9483995, theta=-25.532212 -> V=1.0, theta=0.0
% INFO    : Bus 20931	: V=0.9853597, theta=-23.663198 -> V=1.0, theta=0.0
% INFO    : Bus 20932	: V=0.9659105, theta=-25.418895 -> V=1.0, theta=0.0
% INFO    : Bus 20933	: V=0.9594536, theta=-25.409939 -> V=1.0, theta=0.0
% INFO    : Bus 20934	: V=0.9554242, theta=-25.545041 -> V=1.0, theta=0.0
% INFO    : Bus 20935	: V=0.9335808, theta=-13.255892 -> V=1.0, theta=0.0
% INFO    : Bus 20936	: V=0.9489942, theta=-13.42135 -> V=1.0, theta=0.0
% INFO    : Bus 20937	: V=0.926795, theta=-15.140945 -> V=1.0, theta=0.0
% INFO    : Bus 20938	: V=0.9568192, theta=-12.108967 -> V=1.0, theta=0.0
% INFO    : Bus 20939	: V=0.9519731, theta=-12.951386 -> V=1.0, theta=0.0
% INFO    : Bus 20940	: V=0.9569638, theta=-12.496416 -> V=1.0, theta=0.0
% INFO    : Bus 20941	: V=1.0006013, theta=-8.409157 -> V=1.0, theta=0.0
% INFO    : Bus 20942	: V=0.9763323, theta=-11.870977 -> V=1.0, theta=0.0
% INFO    : Bus 20943	: V=0.9987879, theta=-8.866005 -> V=1.0, theta=0.0
% INFO    : Bus 20944	: V=1.0002196, theta=-8.416747 -> V=1.0, theta=0.0
% INFO    : Bus 20945	: V=1.0003117, theta=-8.653258 -> V=1.0, theta=0.0
% INFO    : Bus 20946	: V=1.0026335, theta=-8.402704 -> V=1.0, theta=0.0
% INFO    : Bus 20947	: V=0.9900138, theta=-10.696653 -> V=1.0, theta=0.0
% INFO    : Bus 20948	: V=0.9417722, theta=-22.701322 -> V=1.0, theta=0.0
% INFO    : Bus 20949	: V=0.9495398, theta=-20.964519 -> V=1.0, theta=0.0
% INFO    : Bus 20950	: V=0.9421462, theta=-23.024143 -> V=1.0, theta=0.0
% INFO    : Bus 20951	: V=0.9353892, theta=-22.999939 -> V=1.0, theta=0.0
% INFO    : Bus 20952	: V=0.948606, theta=-20.948385 -> V=1.0, theta=0.0
% INFO    : Bus 20953	: V=0.9384958, theta=-22.766667 -> V=1.0, theta=0.0
% INFO    : Bus 20954	: V=0.9588919, theta=-18.644308 -> V=1.0, theta=0.0
% INFO    : Bus 20955	: V=0.9443253, theta=-22.015252 -> V=1.0, theta=0.0
% INFO    : Bus 20956	: V=0.93008, theta=-23.808861 -> V=1.0, theta=0.0
% INFO    : Bus 20957	: V=0.9445067, theta=-21.021072 -> V=1.0, theta=0.0
% INFO    : Bus 20958	: V=0.9521086, theta=-21.364598 -> V=1.0, theta=0.0
% INFO    : Bus 20959	: V=0.9554954, theta=-20.396642 -> V=1.0, theta=0.0
% INFO    : Bus 20960	: V=0.9554511, theta=-20.143488 -> V=1.0, theta=0.0
% INFO    : Bus 20961	: V=0.9508765, theta=-20.936363 -> V=1.0, theta=0.0
% INFO    : Bus 20962	: V=0.9450298, theta=-24.482994 -> V=1.0, theta=0.0
% INFO    : Bus 20963	: V=0.9483371, theta=-20.978765 -> V=1.0, theta=0.0
% INFO    : Bus 20964	: V=0.9935044, theta=-11.23645 -> V=1.0, theta=0.0
% INFO    : Bus 20965	: V=0.9883974, theta=-12.27647 -> V=1.0, theta=0.0
% INFO    : Bus 20966	: V=1.0119283, theta=-8.861569 -> V=1.0, theta=0.0
% INFO    : Bus 20967	: V=1.0144098, theta=-7.889575 -> V=1.0, theta=0.0
% INFO    : Bus 20968	: V=0.9996878, theta=-9.444189 -> V=1.0, theta=0.0
% INFO    : Bus 20969	: V=1.0119408, theta=-8.404986 -> V=1.0, theta=0.0
% INFO    : Bus 20970	: V=1.0119698, theta=-8.412849 -> V=1.0, theta=0.0
% INFO    : Bus 20971	: V=0.9941047, theta=-9.976223 -> V=1.0, theta=0.0
% INFO    : Bus 20972	: V=1.0023214, theta=-10.110715 -> V=1.0, theta=0.0
% INFO    : Bus 20973	: V=0.9817198, theta=-16.679373 -> V=1.0, theta=0.0
% INFO    : Bus 20974	: V=0.969473, theta=-17.344275 -> V=1.0, theta=0.0
% INFO    : Bus 20975	: V=0.9717548, theta=-17.437884 -> V=1.0, theta=0.0
% INFO    : Bus 20976	: V=0.9795454, theta=-15.866605 -> V=1.0, theta=0.0
% INFO    : Bus 20977	: V=0.965993, theta=-18.181091 -> V=1.0, theta=0.0
% INFO    : Bus 20978	: V=0.9784044, theta=-17.027351 -> V=1.0, theta=0.0
% INFO    : Bus 20979	: V=0.9788954, theta=-16.996389 -> V=1.0, theta=0.0
% INFO    : Bus 20980	: V=0.9749297, theta=-17.904312 -> V=1.0, theta=0.0
% INFO    : Bus 20981	: V=0.9717322, theta=-18.245707 -> V=1.0, theta=0.0
% INFO    : Bus 20982	: V=0.9814061, theta=-16.901143 -> V=1.0, theta=0.0
% INFO    : Bus 20983	: V=0.9743554, theta=-17.889009 -> V=1.0, theta=0.0
% INFO    : Bus 20984	: V=0.975526, theta=-17.685096 -> V=1.0, theta=0.0
% INFO    : Bus 20985	: V=0.9819895, theta=-16.852153 -> V=1.0, theta=0.0
% INFO    : Bus 20986	: V=0.9749812, theta=-17.442567 -> V=1.0, theta=0.0
% INFO    : Bus 20987	: V=0.9737428, theta=-18.036284 -> V=1.0, theta=0.0
% INFO    : Bus 20988	: V=0.9735292, theta=-18.074983 -> V=1.0, theta=0.0
% INFO    : Bus 20989	: V=0.9679443, theta=-19.525389 -> V=1.0, theta=0.0
% INFO    : Bus 20990	: V=0.9656519, theta=-19.068516 -> V=1.0, theta=0.0
% INFO    : Bus 20991	: V=0.9702061, theta=-18.62437 -> V=1.0, theta=0.0
% INFO    : Bus 20992	: V=0.9791116, theta=-17.126608 -> V=1.0, theta=0.0
% INFO    : Bus 20993	: V=0.9780592, theta=-17.276387 -> V=1.0, theta=0.0
% INFO    : Bus 20994	: V=0.9716159, theta=-18.332729 -> V=1.0, theta=0.0
% INFO    : Bus 20995	: V=0.9732915, theta=-18.011038 -> V=1.0, theta=0.0
% INFO    : Bus 20996	: V=0.9743568, theta=-17.579101 -> V=1.0, theta=0.0
% INFO    : Bus 20997	: V=0.9725799, theta=-18.232829 -> V=1.0, theta=0.0
% INFO    : Bus 20998	: V=0.9851584, theta=-16.117665 -> V=1.0, theta=0.0
% INFO    : Bus 20999	: V=0.9780684, theta=-17.168184 -> V=1.0, theta=0.0
% INFO    : Bus 21000	: V=0.9790672, theta=-17.005272 -> V=1.0, theta=0.0
% INFO    : Bus 21001	: V=0.9852478, theta=-16.104731 -> V=1.0, theta=0.0
% INFO    : Bus 21002	: V=0.9851949, theta=-16.107022 -> V=1.0, theta=0.0
% INFO    : Bus 21003	: V=0.9805679, theta=-16.967506 -> V=1.0, theta=0.0
% INFO    : Bus 21004	: V=0.983537, theta=-16.368028 -> V=1.0, theta=0.0
% INFO    : Bus 21005	: V=0.9752027, theta=-17.67442 -> V=1.0, theta=0.0
% INFO    : Bus 21006	: V=0.9759746, theta=-17.589966 -> V=1.0, theta=0.0
% INFO    : Bus 21007	: V=0.9742946, theta=-17.622449 -> V=1.0, theta=0.0
% INFO    : Bus 21008	: V=0.9857104, theta=-16.044461 -> V=1.0, theta=0.0
% INFO    : Bus 21009	: V=0.9798419, theta=-16.909971 -> V=1.0, theta=0.0
% INFO    : Bus 21010	: V=0.9804352, theta=-16.95127 -> V=1.0, theta=0.0
% INFO    : Bus 21011	: V=0.9817238, theta=-16.674694 -> V=1.0, theta=0.0
% INFO    : Bus 21012	: V=0.9447978, theta=-23.55931 -> V=1.0, theta=0.0
% INFO    : Bus 21013	: V=0.9505775, theta=-20.838071 -> V=1.0, theta=0.0
% INFO    : Bus 21014	: V=0.97202, theta=-19.237046 -> V=1.0, theta=0.0
% INFO    : Bus 21015	: V=0.9457597, theta=-23.470763 -> V=1.0, theta=0.0
% INFO    : Bus 21016	: V=0.9319351, theta=-24.787652 -> V=1.0, theta=0.0
% INFO    : Bus 21017	: V=0.935919, theta=-24.560421 -> V=1.0, theta=0.0
% INFO    : Bus 21018	: V=0.9347806, theta=-25.304749 -> V=1.0, theta=0.0
% INFO    : Bus 21019	: V=0.9434142, theta=-21.165805 -> V=1.0, theta=0.0
% INFO    : Bus 21020	: V=0.9393979, theta=-21.429908 -> V=1.0, theta=0.0
% INFO    : Bus 21021	: V=0.9397096, theta=-21.421758 -> V=1.0, theta=0.0
% INFO    : Bus 21022	: V=0.9997609, theta=-15.136349 -> V=1.0, theta=0.0
% INFO    : Bus 21023	: V=1.0154094, theta=-13.586441 -> V=1.0, theta=0.0
% INFO    : Bus 21024	: V=1.0150398, theta=-13.055455 -> V=1.0, theta=0.0
% INFO    : Bus 21025	: V=1.0160022, theta=-13.437985 -> V=1.0, theta=0.0
% INFO    : Bus 21026	: V=1.0169337, theta=-13.665784 -> V=1.0, theta=0.0
% INFO    : Bus 21027	: V=0.9993055, theta=-15.290487 -> V=1.0, theta=0.0
% INFO    : Bus 21028	: V=0.9916359, theta=-14.756532 -> V=1.0, theta=0.0
% INFO    : Bus 21029	: V=0.9860325, theta=-14.90531 -> V=1.0, theta=0.0
% INFO    : Bus 21030	: V=1.0073564, theta=-12.045006 -> V=1.0, theta=0.0
% INFO    : Bus 21031	: V=0.9706579, theta=-17.038324 -> V=1.0, theta=0.0
% INFO    : Bus 21032	: V=0.9735458, theta=-16.891429 -> V=1.0, theta=0.0
% INFO    : Bus 21033	: V=0.96523, theta=-16.598692 -> V=1.0, theta=0.0
% INFO    : Bus 21034	: V=0.9570626, theta=-15.161525 -> V=1.0, theta=0.0
% INFO    : Bus 21035	: V=0.9631165, theta=-16.576098 -> V=1.0, theta=0.0
% INFO    : Bus 21036	: V=0.9636333, theta=-16.658907 -> V=1.0, theta=0.0
% INFO    : Bus 21037	: V=0.9566565, theta=-17.933964 -> V=1.0, theta=0.0
% INFO    : Bus 21038	: V=0.9801226, theta=-16.622162 -> V=1.0, theta=0.0
% INFO    : Bus 21039	: V=0.9489297, theta=-19.098845 -> V=1.0, theta=0.0
% INFO    : Bus 21040	: V=0.9780905, theta=-16.801871 -> V=1.0, theta=0.0
% INFO    : Bus 21041	: V=0.9714267, theta=-17.379093 -> V=1.0, theta=0.0
% INFO    : Bus 21042	: V=0.9856025, theta=-17.241974 -> V=1.0, theta=0.0
% INFO    : Bus 21043	: V=0.966916, theta=-17.462279 -> V=1.0, theta=0.0
% INFO    : Bus 21044	: V=0.968042, theta=-17.390612 -> V=1.0, theta=0.0
% INFO    : Bus 21045	: V=0.9687784, theta=-17.344888 -> V=1.0, theta=0.0
% INFO    : Bus 21046	: V=0.9536971, theta=-18.828493 -> V=1.0, theta=0.0
% INFO    : Bus 21047	: V=0.957031, theta=-17.8925 -> V=1.0, theta=0.0
% INFO    : Bus 21048	: V=0.9636044, theta=-15.92056 -> V=1.0, theta=0.0
% INFO    : Bus 21049	: V=0.9381772, theta=-26.007141 -> V=1.0, theta=0.0
% INFO    : Bus 21050	: V=0.9335748, theta=-26.212127 -> V=1.0, theta=0.0
% INFO    : Bus 21051	: V=0.9539593, theta=-23.067741 -> V=1.0, theta=0.0
% INFO    : Bus 21052	: V=0.9565161, theta=-22.435581 -> V=1.0, theta=0.0
% INFO    : Bus 21053	: V=0.9642757, theta=-20.654243 -> V=1.0, theta=0.0
% INFO    : Bus 21054	: V=0.9415456, theta=-25.805971 -> V=1.0, theta=0.0
% INFO    : Bus 21055	: V=0.9431178, theta=-25.71069 -> V=1.0, theta=0.0
% INFO    : Bus 21056	: V=0.9444239, theta=-25.585365 -> V=1.0, theta=0.0
% INFO    : Bus 21057	: V=0.947619, theta=-25.233686 -> V=1.0, theta=0.0
% INFO    : Bus 21058	: V=0.9460368, theta=-25.434656 -> V=1.0, theta=0.0
% INFO    : Bus 21059	: V=0.9510812, theta=-24.117149 -> V=1.0, theta=0.0
% INFO    : Bus 21060	: V=0.9377484, theta=-25.513105 -> V=1.0, theta=0.0
% INFO    : Bus 21061	: V=0.9497178, theta=-25.73621 -> V=1.0, theta=0.0
% INFO    : Bus 21062	: V=0.969064, theta=-14.908485 -> V=1.0, theta=0.0
% INFO    : Bus 21063	: V=0.9503258, theta=-17.490109 -> V=1.0, theta=0.0
% INFO    : Bus 21064	: V=0.9609574, theta=-15.585793 -> V=1.0, theta=0.0
% INFO    : Bus 21065	: V=0.9589917, theta=-16.16958 -> V=1.0, theta=0.0
% INFO    : Bus 21066	: V=0.959579, theta=-15.981432 -> V=1.0, theta=0.0
% INFO    : Bus 21067	: V=0.9442412, theta=-17.991741 -> V=1.0, theta=0.0
% INFO    : Bus 21068	: V=0.9464664, theta=-17.720601 -> V=1.0, theta=0.0
% INFO    : Bus 21069	: V=0.9586199, theta=-16.357367 -> V=1.0, theta=0.0
% INFO    : Bus 21070	: V=0.9476066, theta=-17.791529 -> V=1.0, theta=0.0
% INFO    : Bus 21071	: V=0.9490157, theta=-17.687787 -> V=1.0, theta=0.0
% INFO    : Bus 21072	: V=0.9690658, theta=-15.318227 -> V=1.0, theta=0.0
% INFO    : Bus 21073	: V=0.9518664, theta=-17.772295 -> V=1.0, theta=0.0
% INFO    : Bus 21074	: V=0.9582975, theta=-16.745919 -> V=1.0, theta=0.0
% INFO    : Bus 21075	: V=0.9586964, theta=-16.84341 -> V=1.0, theta=0.0
% INFO    : Bus 21076	: V=0.9469328, theta=-19.420372 -> V=1.0, theta=0.0
% INFO    : Bus 21077	: V=0.9565268, theta=-16.775626 -> V=1.0, theta=0.0
% INFO    : Bus 21078	: V=0.9612833, theta=-15.483263 -> V=1.0, theta=0.0
% INFO    : Bus 21079	: V=0.9522812, theta=-15.617725 -> V=1.0, theta=0.0
% INFO    : Bus 21080	: V=0.9478694, theta=-17.195564 -> V=1.0, theta=0.0
% INFO    : Bus 21081	: V=0.9462213, theta=-17.624494 -> V=1.0, theta=0.0
% INFO    : Bus 21082	: V=0.9284288, theta=-25.357315 -> V=1.0, theta=0.0
% INFO    : Bus 21083	: V=0.9401677, theta=-22.069269 -> V=1.0, theta=0.0
% INFO    : Bus 21084	: V=0.938835, theta=-22.414661 -> V=1.0, theta=0.0
% INFO    : Bus 21085	: V=0.9379827, theta=-22.642624 -> V=1.0, theta=0.0
% INFO    : Bus 21086	: V=0.9403275, theta=-24.388886 -> V=1.0, theta=0.0
% INFO    : Bus 21087	: V=0.9412917, theta=-22.752322 -> V=1.0, theta=0.0
% INFO    : Bus 21088	: V=0.9474395, theta=-18.661684 -> V=1.0, theta=0.0
% INFO    : Bus 21089	: V=0.9471139, theta=-18.812125 -> V=1.0, theta=0.0
% INFO    : Bus 21090	: V=0.9462178, theta=-20.736166 -> V=1.0, theta=0.0
% INFO    : Bus 21091	: V=0.9599765, theta=-19.766185 -> V=1.0, theta=0.0
% INFO    : Bus 21092	: V=0.9600772, theta=-19.646408 -> V=1.0, theta=0.0
% INFO    : Bus 21093	: V=0.9618693, theta=-19.292633 -> V=1.0, theta=0.0
% INFO    : Bus 21094	: V=0.9612534, theta=-19.431993 -> V=1.0, theta=0.0
% INFO    : Bus 21095	: V=0.9587149, theta=-19.761381 -> V=1.0, theta=0.0
% INFO    : Bus 21096	: V=0.9619466, theta=-19.298628 -> V=1.0, theta=0.0
% INFO    : Bus 21097	: V=0.9772712, theta=-16.839225 -> V=1.0, theta=0.0
% INFO    : Bus 21098	: V=0.9704255, theta=-17.657546 -> V=1.0, theta=0.0
% INFO    : Bus 21099	: V=0.9729035, theta=-17.319719 -> V=1.0, theta=0.0
% INFO    : Bus 21100	: V=0.9564448, theta=-19.044197 -> V=1.0, theta=0.0
% INFO    : Bus 21101	: V=0.9624556, theta=1.590421 -> V=1.0, theta=0.0
% INFO    : Bus 21102	: V=0.9681294, theta=-0.950222 -> V=1.0, theta=0.0
% INFO    : Bus 21103	: V=0.9840198, theta=0.030094 -> V=1.0, theta=0.0
% INFO    : Bus 21104	: V=0.9614401, theta=1.22769 -> V=1.0, theta=0.0
% INFO    : Bus 21105	: V=0.970254, theta=1.22163 -> V=1.0, theta=0.0
% INFO    : Bus 21106	: V=0.9928507, theta=0.775706 -> V=1.0, theta=0.0
% INFO    : Bus 21107	: V=0.9771461, theta=-1.820675 -> V=1.0, theta=0.0
% INFO    : Bus 21108	: V=0.994931, theta=0.727357 -> V=1.0, theta=0.0
% INFO    : Bus 21109	: V=0.9641366, theta=-24.894052 -> V=1.0, theta=0.0
% INFO    : Bus 21110	: V=0.9697851, theta=-25.00218 -> V=1.0, theta=0.0
% INFO    : Bus 21111	: V=0.9479725, theta=-27.637486 -> V=1.0, theta=0.0
% INFO    : Bus 21112	: V=0.9551079, theta=-26.881139 -> V=1.0, theta=0.0
% INFO    : Bus 21113	: V=0.9625696, theta=-25.116035 -> V=1.0, theta=0.0
% INFO    : Bus 21114	: V=0.9622287, theta=-25.104831 -> V=1.0, theta=0.0
% INFO    : Bus 21115	: V=0.9591856, theta=-24.900279 -> V=1.0, theta=0.0
% INFO    : Bus 21116	: V=1.0027498, theta=-17.341969 -> V=1.0, theta=0.0
% INFO    : Bus 21117	: V=1.011967, theta=-14.110225 -> V=1.0, theta=0.0
% INFO    : Bus 21118	: V=1.0031438, theta=-16.114924 -> V=1.0, theta=0.0
% INFO    : Bus 21119	: V=1.0058606, theta=-15.801803 -> V=1.0, theta=0.0
% INFO    : Bus 21120	: V=1.018659, theta=-13.395667 -> V=1.0, theta=0.0
% INFO    : Bus 21121	: V=1.0060706, theta=-16.335455 -> V=1.0, theta=0.0
% INFO    : Bus 21122	: V=1.0054393, theta=-15.672485 -> V=1.0, theta=0.0
% INFO    : Bus 21123	: V=0.9835211, theta=-20.05197 -> V=1.0, theta=0.0
% INFO    : Bus 21124	: V=0.9508046, theta=-22.160204 -> V=1.0, theta=0.0
% INFO    : Bus 21125	: V=0.9493598, theta=-22.19133 -> V=1.0, theta=0.0
% INFO    : Bus 21126	: V=0.9606388, theta=-19.713696 -> V=1.0, theta=0.0
% INFO    : Bus 21127	: V=0.9516276, theta=-21.936815 -> V=1.0, theta=0.0
% INFO    : Bus 21128	: V=0.9720334, theta=-18.794559 -> V=1.0, theta=0.0
% INFO    : Bus 21129	: V=0.9691051, theta=-18.776059 -> V=1.0, theta=0.0
% INFO    : Bus 21130	: V=0.9631533, theta=-19.634135 -> V=1.0, theta=0.0
% INFO    : Bus 21131	: V=0.9618816, theta=-19.790679 -> V=1.0, theta=0.0
% INFO    : Bus 21132	: V=0.9882335, theta=-16.071639 -> V=1.0, theta=0.0
% INFO    : Bus 21133	: V=0.9728548, theta=-18.34564 -> V=1.0, theta=0.0
% INFO    : Bus 21134	: V=0.9643679, theta=-19.37036 -> V=1.0, theta=0.0
% INFO    : Bus 21135	: V=0.9726358, theta=-18.406203 -> V=1.0, theta=0.0
% INFO    : Bus 21136	: V=0.9549689, theta=-20.513308 -> V=1.0, theta=0.0
% INFO    : Bus 21137	: V=0.9753855, theta=-18.19795 -> V=1.0, theta=0.0
% INFO    : Bus 21138	: V=0.9771882, theta=-18.081301 -> V=1.0, theta=0.0
% INFO    : Bus 21139	: V=0.9734278, theta=-18.340316 -> V=1.0, theta=0.0
% INFO    : Bus 21140	: V=0.9745031, theta=-18.249156 -> V=1.0, theta=0.0
% INFO    : Bus 21141	: V=0.9754429, theta=-18.180175 -> V=1.0, theta=0.0
% INFO    : Bus 21142	: V=0.9774795, theta=-17.984536 -> V=1.0, theta=0.0
% INFO    : Bus 21143	: V=0.9573165, theta=-20.116502 -> V=1.0, theta=0.0
% INFO    : Bus 21144	: V=0.9553318, theta=-20.757641 -> V=1.0, theta=0.0
% INFO    : Bus 21145	: V=0.9582281, theta=-20.487779 -> V=1.0, theta=0.0
% INFO    : Bus 21146	: V=0.9604276, theta=-20.288068 -> V=1.0, theta=0.0
% INFO    : Bus 21147	: V=0.9600806, theta=-20.270339 -> V=1.0, theta=0.0
% INFO    : Bus 21148	: V=0.9598993, theta=-20.175509 -> V=1.0, theta=0.0
% INFO    : Bus 21149	: V=0.9460302, theta=-20.973996 -> V=1.0, theta=0.0
% INFO    : Bus 21150	: V=0.9720403, theta=-18.983311 -> V=1.0, theta=0.0
% INFO    : Bus 21151	: V=1.0194919, theta=-6.958179 -> V=1.0, theta=0.0
% INFO    : Bus 21152	: V=1.0176228, theta=-7.80051 -> V=1.0, theta=0.0
% INFO    : Bus 21153	: V=0.9803076, theta=-9.038962 -> V=1.0, theta=0.0
% INFO    : Bus 21154	: V=0.9787177, theta=-9.567511 -> V=1.0, theta=0.0
% INFO    : Bus 21155	: V=0.9792749, theta=-9.530587 -> V=1.0, theta=0.0
% INFO    : Bus 21156	: V=0.989882, theta=-8.679725 -> V=1.0, theta=0.0
% INFO    : Bus 21157	: V=0.9806492, theta=-9.468611 -> V=1.0, theta=0.0
% INFO    : Bus 21158	: V=0.9838075, theta=-9.212293 -> V=1.0, theta=0.0
% INFO    : Bus 21159	: V=1.0089777, theta=-7.208391 -> V=1.0, theta=0.0
% INFO    : Bus 21160	: V=0.9968038, theta=-8.324604 -> V=1.0, theta=0.0
% INFO    : Bus 21161	: V=0.9258979, theta=-20.060485 -> V=1.0, theta=0.0
% INFO    : Bus 21162	: V=0.9306483, theta=-18.723826 -> V=1.0, theta=0.0
% INFO    : Bus 21163	: V=0.9318298, theta=-15.183196 -> V=1.0, theta=0.0
% INFO    : Bus 21164	: V=0.9197035, theta=-19.910477 -> V=1.0, theta=0.0
% INFO    : Bus 21165	: V=0.928501, theta=-21.945976 -> V=1.0, theta=0.0
% INFO    : Bus 21166	: V=0.9268937, theta=-20.885908 -> V=1.0, theta=0.0
% INFO    : Bus 21167	: V=0.9267757, theta=-21.071362 -> V=1.0, theta=0.0
% INFO    : Bus 21168	: V=0.9282447, theta=-21.176635 -> V=1.0, theta=0.0
% INFO    : Bus 21169	: V=0.9346852, theta=-19.479328 -> V=1.0, theta=0.0
% INFO    : Bus 21170	: V=0.9362082, theta=-18.755147 -> V=1.0, theta=0.0
% INFO    : Bus 21171	: V=0.9375963, theta=-19.126305 -> V=1.0, theta=0.0
% INFO    : Bus 21172	: V=0.9382429, theta=-19.382612 -> V=1.0, theta=0.0
% INFO    : Bus 21173	: V=0.9352937, theta=-19.531346 -> V=1.0, theta=0.0
% INFO    : Bus 21174	: V=0.9327715, theta=-19.90381 -> V=1.0, theta=0.0
% INFO    : Bus 21175	: V=0.9396017, theta=-18.769687 -> V=1.0, theta=0.0
% INFO    : Bus 21176	: V=0.9292558, theta=-19.967039 -> V=1.0, theta=0.0
% INFO    : Bus 21177	: V=0.9428978, theta=-16.200414 -> V=1.0, theta=0.0
% INFO    : Bus 21178	: V=0.953028, theta=-15.494072 -> V=1.0, theta=0.0
% INFO    : Bus 21179	: V=0.9421799, theta=-17.611461 -> V=1.0, theta=0.0
% INFO    : Bus 21180	: V=0.9192063, theta=-21.100296 -> V=1.0, theta=0.0
% INFO    : Bus 21181	: V=0.920085, theta=-19.707312 -> V=1.0, theta=0.0
% INFO    : Bus 21182	: V=0.9176833, theta=-19.770728 -> V=1.0, theta=0.0
% INFO    : Bus 21183	: V=0.9238656, theta=-18.201218 -> V=1.0, theta=0.0
% INFO    : Bus 21184	: V=0.9263948, theta=-18.712672 -> V=1.0, theta=0.0
% INFO    : Bus 21185	: V=0.9196062, theta=-23.856428 -> V=1.0, theta=0.0
% INFO    : Bus 21186	: V=0.9193121, theta=-24.482987 -> V=1.0, theta=0.0
% INFO    : Bus 21187	: V=0.9197663, theta=-25.688796 -> V=1.0, theta=0.0
% INFO    : Bus 21188	: V=0.9567587, theta=3.447833 -> V=1.0, theta=0.0
% INFO    : Bus 21189	: V=0.9564226, theta=3.675118 -> V=1.0, theta=0.0
% INFO    : Bus 21190	: V=0.9777931, theta=9.933803 -> V=1.0, theta=0.0
% INFO    : Bus 21191	: V=0.976796, theta=8.794599 -> V=1.0, theta=0.0
% INFO    : Bus 21192	: V=0.9536639, theta=5.912836 -> V=1.0, theta=0.0
% INFO    : Bus 21193	: V=0.9786669, theta=10.813428 -> V=1.0, theta=0.0
% INFO    : Bus 21194	: V=0.96591, theta=7.294258 -> V=1.0, theta=0.0
% INFO    : Bus 21195	: V=0.9667568, theta=7.051889 -> V=1.0, theta=0.0
% INFO    : Bus 21196	: V=0.967062, theta=6.990537 -> V=1.0, theta=0.0
% INFO    : Bus 21197	: V=0.9599742, theta=5.932643 -> V=1.0, theta=0.0
% INFO    : Bus 21198	: V=0.9572578, theta=5.87373 -> V=1.0, theta=0.0
% INFO    : Bus 21199	: V=0.9561744, theta=5.801711 -> V=1.0, theta=0.0
% INFO    : Bus 21200	: V=0.9585288, theta=5.845362 -> V=1.0, theta=0.0
% INFO    : Bus 21201	: V=0.9601171, theta=5.697368 -> V=1.0, theta=0.0
% INFO    : Bus 21202	: V=0.9621079, theta=4.453899 -> V=1.0, theta=0.0
% INFO    : Bus 21203	: V=0.9624657, theta=4.336755 -> V=1.0, theta=0.0
% INFO    : Bus 21204	: V=0.9620988, theta=4.492961 -> V=1.0, theta=0.0
% INFO    : Bus 21205	: V=0.9598992, theta=5.497781 -> V=1.0, theta=0.0
% INFO    : Bus 21206	: V=0.9594831, theta=5.746771 -> V=1.0, theta=0.0
% INFO    : Bus 21207	: V=0.9579461, theta=5.516513 -> V=1.0, theta=0.0
% INFO    : Bus 21208	: V=0.9565228, theta=5.437521 -> V=1.0, theta=0.0
% INFO    : Bus 21209	: V=0.9586115, theta=5.415973 -> V=1.0, theta=0.0
% INFO    : Bus 21210	: V=0.9590798, theta=5.359218 -> V=1.0, theta=0.0
% INFO    : Bus 21211	: V=0.9549591, theta=5.066287 -> V=1.0, theta=0.0
% INFO    : Bus 21212	: V=0.954259, theta=5.262841 -> V=1.0, theta=0.0
% INFO    : Bus 21213	: V=0.9532309, theta=5.105826 -> V=1.0, theta=0.0
% INFO    : Bus 21214	: V=0.9537564, theta=5.068379 -> V=1.0, theta=0.0
% INFO    : Bus 21215	: V=0.9518212, theta=5.07863 -> V=1.0, theta=0.0
% INFO    : Bus 21216	: V=0.9662188, theta=7.164312 -> V=1.0, theta=0.0
% INFO    : Bus 21217	: V=0.9628243, theta=8.124405 -> V=1.0, theta=0.0
% INFO    : Bus 21218	: V=0.9647342, theta=8.728045 -> V=1.0, theta=0.0
% INFO    : Bus 21219	: V=0.9622786, theta=8.204697 -> V=1.0, theta=0.0
% INFO    : Bus 21220	: V=0.9593118, theta=7.997928 -> V=1.0, theta=0.0
% INFO    : Bus 21221	: V=0.9575249, theta=7.351286 -> V=1.0, theta=0.0
% INFO    : Bus 21222	: V=0.9502617, theta=6.511243 -> V=1.0, theta=0.0
% INFO    : Bus 21223	: V=0.9491125, theta=6.193544 -> V=1.0, theta=0.0
% INFO    : Bus 21224	: V=0.9570118, theta=7.153182 -> V=1.0, theta=0.0
% INFO    : Bus 21225	: V=0.9553028, theta=6.801109 -> V=1.0, theta=0.0
% INFO    : Bus 21226	: V=0.9585856, theta=7.292448 -> V=1.0, theta=0.0
% INFO    : Bus 21227	: V=0.9512644, theta=5.916893 -> V=1.0, theta=0.0
% INFO    : Bus 21228	: V=0.9504136, theta=5.925086 -> V=1.0, theta=0.0
% INFO    : Bus 21229	: V=0.9493256, theta=5.967821 -> V=1.0, theta=0.0
% INFO    : Bus 21230	: V=0.9476248, theta=5.922367 -> V=1.0, theta=0.0
% INFO    : Bus 21231	: V=0.9463392, theta=5.756127 -> V=1.0, theta=0.0
% INFO    : Bus 21232	: V=0.9455523, theta=5.653689 -> V=1.0, theta=0.0
% INFO    : Bus 21233	: V=0.9491506, theta=5.820518 -> V=1.0, theta=0.0
% INFO    : Bus 21234	: V=0.9534258, theta=6.162077 -> V=1.0, theta=0.0
% INFO    : Bus 21235	: V=0.9515857, theta=5.999559 -> V=1.0, theta=0.0
% INFO    : Bus 21236	: V=0.9627475, theta=7.851474 -> V=1.0, theta=0.0
% INFO    : Bus 21237	: V=0.9589202, theta=7.832568 -> V=1.0, theta=0.0
% INFO    : Bus 21238	: V=0.9781823, theta=11.877183 -> V=1.0, theta=0.0
% INFO    : Bus 21239	: V=0.9779704, theta=12.083697 -> V=1.0, theta=0.0
% INFO    : Bus 21240	: V=0.9592271, theta=7.844524 -> V=1.0, theta=0.0
% INFO    : Bus 21241	: V=0.958069, theta=7.538387 -> V=1.0, theta=0.0
% INFO    : Bus 21242	: V=0.9587763, theta=7.417198 -> V=1.0, theta=0.0
% INFO    : Bus 21243	: V=0.9591869, theta=7.551294 -> V=1.0, theta=0.0
% INFO    : Bus 21244	: V=0.9600993, theta=7.630463 -> V=1.0, theta=0.0
% INFO    : Bus 21245	: V=0.9618089, theta=7.791278 -> V=1.0, theta=0.0
% INFO    : Bus 21246	: V=0.9643346, theta=8.245283 -> V=1.0, theta=0.0
% INFO    : Bus 21247	: V=0.9629085, theta=8.116355 -> V=1.0, theta=0.0
% INFO    : Bus 21248	: V=0.9443445, theta=5.331698 -> V=1.0, theta=0.0
% INFO    : Bus 21249	: V=0.9449625, theta=5.457756 -> V=1.0, theta=0.0
% INFO    : Bus 21250	: V=0.9565145, theta=6.61695 -> V=1.0, theta=0.0
% INFO    : Bus 21251	: V=0.9441753, theta=5.351019 -> V=1.0, theta=0.0
% INFO    : Bus 21252	: V=0.9569027, theta=6.757434 -> V=1.0, theta=0.0
% INFO    : Bus 21253	: V=0.9575016, theta=6.735476 -> V=1.0, theta=0.0
% INFO    : Bus 21254	: V=0.9563958, theta=6.80114 -> V=1.0, theta=0.0
% INFO    : Bus 21255	: V=0.9510157, theta=5.794939 -> V=1.0, theta=0.0
% INFO    : Bus 21256	: V=0.9517211, theta=5.767891 -> V=1.0, theta=0.0
% INFO    : Bus 21257	: V=0.9507607, theta=5.74528 -> V=1.0, theta=0.0
% INFO    : Bus 21258	: V=0.9754739, theta=10.017945 -> V=1.0, theta=0.0
% INFO    : Bus 21259	: V=0.9524864, theta=5.773188 -> V=1.0, theta=0.0
% INFO    : Bus 21260	: V=0.9547067, theta=5.976449 -> V=1.0, theta=0.0
% INFO    : Bus 21261	: V=0.9525361, theta=5.809223 -> V=1.0, theta=0.0
% INFO    : Bus 21262	: V=0.9545058, theta=5.740052 -> V=1.0, theta=0.0
% INFO    : Bus 21263	: V=0.9547759, theta=5.744671 -> V=1.0, theta=0.0
% INFO    : Bus 21264	: V=0.9610011, theta=6.554541 -> V=1.0, theta=0.0
% INFO    : Bus 21265	: V=0.9528284, theta=5.098379 -> V=1.0, theta=0.0
% INFO    : Bus 21266	: V=0.9490383, theta=3.928635 -> V=1.0, theta=0.0
% INFO    : Bus 21267	: V=0.9546606, theta=3.793545 -> V=1.0, theta=0.0
% INFO    : Bus 21268	: V=0.9520895, theta=3.240146 -> V=1.0, theta=0.0
% INFO    : Bus 21269	: V=0.946142, theta=2.664303 -> V=1.0, theta=0.0
% INFO    : Bus 21270	: V=0.9456857, theta=2.792553 -> V=1.0, theta=0.0
% INFO    : Bus 21271	: V=0.9474569, theta=3.859224 -> V=1.0, theta=0.0
% INFO    : Bus 21272	: V=0.9469018, theta=3.875987 -> V=1.0, theta=0.0
% INFO    : Bus 21273	: V=0.9382408, theta=2.265354 -> V=1.0, theta=0.0
% INFO    : Bus 21274	: V=0.9592725, theta=6.191611 -> V=1.0, theta=0.0
% INFO    : Bus 21275	: V=0.9561626, theta=5.779628 -> V=1.0, theta=0.0
% INFO    : Bus 21276	: V=0.9554475, theta=5.687764 -> V=1.0, theta=0.0
% INFO    : Bus 21277	: V=0.9488403, theta=4.833117 -> V=1.0, theta=0.0
% INFO    : Bus 21278	: V=0.9506406, theta=4.837043 -> V=1.0, theta=0.0
% INFO    : Bus 21279	: V=0.9544863, theta=5.221102 -> V=1.0, theta=0.0
% INFO    : Bus 21280	: V=0.954403, theta=5.353348 -> V=1.0, theta=0.0
% INFO    : Bus 21281	: V=0.9582572, theta=6.418039 -> V=1.0, theta=0.0
% INFO    : Bus 21282	: V=0.9472369, theta=5.069394 -> V=1.0, theta=0.0
% INFO    : Bus 21283	: V=0.9467504, theta=4.87409 -> V=1.0, theta=0.0
% INFO    : Bus 21284	: V=0.9461883, theta=4.91666 -> V=1.0, theta=0.0
% INFO    : Bus 21285	: V=0.9444296, theta=5.300108 -> V=1.0, theta=0.0
% INFO    : Bus 21286	: V=0.9470614, theta=5.376926 -> V=1.0, theta=0.0
% INFO    : Bus 21287	: V=0.9593025, theta=6.611719 -> V=1.0, theta=0.0
% INFO    : Bus 21288	: V=0.9590894, theta=6.739827 -> V=1.0, theta=0.0
% INFO    : Bus 21289	: V=0.9758978, theta=10.343983 -> V=1.0, theta=0.0
% INFO    : Bus 21290	: V=0.9575084, theta=6.678376 -> V=1.0, theta=0.0
% INFO    : Bus 21291	: V=0.9436277, theta=5.151131 -> V=1.0, theta=0.0
% INFO    : Bus 21292	: V=0.9539121, theta=4.4204 -> V=1.0, theta=0.0
% INFO    : Bus 21293	: V=0.9447477, theta=4.110627 -> V=1.0, theta=0.0
% INFO    : Bus 21294	: V=0.9545519, theta=5.095879 -> V=1.0, theta=0.0
% INFO    : Bus 21295	: V=0.9458125, theta=3.709552 -> V=1.0, theta=0.0
% INFO    : Bus 21296	: V=0.9553634, theta=5.006755 -> V=1.0, theta=0.0
% INFO    : Bus 21297	: V=0.9540178, theta=4.899915 -> V=1.0, theta=0.0
% INFO    : Bus 21298	: V=0.9549911, theta=4.447915 -> V=1.0, theta=0.0
% INFO    : Bus 21299	: V=0.9441315, theta=2.89905 -> V=1.0, theta=0.0
% INFO    : Bus 21300	: V=0.9473561, theta=2.198221 -> V=1.0, theta=0.0
% INFO    : Bus 21301	: V=0.9584484, theta=3.574288 -> V=1.0, theta=0.0
% INFO    : Bus 21302	: V=0.9565413, theta=3.371066 -> V=1.0, theta=0.0
% INFO    : Bus 21303	: V=0.9430915, theta=1.475081 -> V=1.0, theta=0.0
% INFO    : Bus 21304	: V=0.9436102, theta=1.063325 -> V=1.0, theta=0.0
% INFO    : Bus 21305	: V=0.9751044, theta=3.902555 -> V=1.0, theta=0.0
% INFO    : Bus 21306	: V=0.9685281, theta=1.534494 -> V=1.0, theta=0.0
% INFO    : Bus 21307	: V=0.9705644, theta=2.321601 -> V=1.0, theta=0.0
% INFO    : Bus 21308	: V=0.9699253, theta=2.134701 -> V=1.0, theta=0.0
% INFO    : Bus 21309	: V=0.9688709, theta=1.79221 -> V=1.0, theta=0.0
% INFO    : Bus 21310	: V=0.9670859, theta=1.251873 -> V=1.0, theta=0.0
% INFO    : Bus 21311	: V=0.9676585, theta=1.371901 -> V=1.0, theta=0.0
% INFO    : Bus 21312	: V=0.9694115, theta=1.762848 -> V=1.0, theta=0.0
% INFO    : Bus 21313	: V=0.9734096, theta=2.438598 -> V=1.0, theta=0.0
% INFO    : Bus 21314	: V=0.9721034, theta=1.924446 -> V=1.0, theta=0.0
% INFO    : Bus 21315	: V=0.9687001, theta=1.596381 -> V=1.0, theta=0.0
% INFO    : Bus 21316	: V=0.9691923, theta=1.923119 -> V=1.0, theta=0.0
% INFO    : Bus 21317	: V=0.9675631, theta=1.592665 -> V=1.0, theta=0.0
% INFO    : Bus 21318	: V=0.9627724, theta=-0.474476 -> V=1.0, theta=0.0
% INFO    : Bus 21319	: V=0.9595769, theta=-2.731156 -> V=1.0, theta=0.0
% INFO    : Bus 21320	: V=0.94828, theta=-3.073356 -> V=1.0, theta=0.0
% INFO    : Bus 21321	: V=0.9518066, theta=-5.049763 -> V=1.0, theta=0.0
% INFO    : Bus 21322	: V=0.95518, theta=-1.677171 -> V=1.0, theta=0.0
% INFO    : Bus 21323	: V=0.966489, theta=-0.724786 -> V=1.0, theta=0.0
% INFO    : Bus 21324	: V=0.954322, theta=-2.776588 -> V=1.0, theta=0.0
% INFO    : Bus 21325	: V=0.9669494, theta=-0.430554 -> V=1.0, theta=0.0
% INFO    : Bus 21326	: V=0.9618864, theta=1.122055 -> V=1.0, theta=0.0
% INFO    : Bus 21327	: V=0.9642087, theta=0.499608 -> V=1.0, theta=0.0
% INFO    : Bus 21328	: V=0.9629428, theta=1.350966 -> V=1.0, theta=0.0
% INFO    : Bus 21329	: V=0.948511, theta=-3.718905 -> V=1.0, theta=0.0
% INFO    : Bus 21330	: V=0.950527, theta=-1.769473 -> V=1.0, theta=0.0
% INFO    : Bus 21331	: V=0.9785579, theta=-2.004216 -> V=1.0, theta=0.0
% INFO    : Bus 21332	: V=0.9705206, theta=1.814726 -> V=1.0, theta=0.0
% INFO    : Bus 21333	: V=0.9721779, theta=-14.841297 -> V=1.0, theta=0.0
% INFO    : Bus 21334	: V=0.9875667, theta=-14.671793 -> V=1.0, theta=0.0
% INFO    : Bus 21335	: V=0.9816279, theta=-13.035002 -> V=1.0, theta=0.0
% INFO    : Bus 21336	: V=0.9871799, theta=-14.657705 -> V=1.0, theta=0.0
% INFO    : Bus 21337	: V=0.9789252, theta=-14.865701 -> V=1.0, theta=0.0
% INFO    : Bus 21338	: V=0.9831598, theta=-14.492425 -> V=1.0, theta=0.0
% INFO    : Bus 21339	: V=1.0124388, theta=-11.151926 -> V=1.0, theta=0.0
% INFO    : Bus 21340	: V=0.9811252, theta=-14.808712 -> V=1.0, theta=0.0
% INFO    : Bus 21341	: V=0.9899232, theta=-15.234607 -> V=1.0, theta=0.0
% INFO    : Bus 21342	: V=0.9873672, theta=-14.853815 -> V=1.0, theta=0.0
% INFO    : Bus 21343	: V=0.9645358, theta=-21.005615 -> V=1.0, theta=0.0
% INFO    : Bus 21344	: V=0.9614221, theta=-21.268864 -> V=1.0, theta=0.0
% INFO    : Bus 21345	: V=0.9654888, theta=-21.067855 -> V=1.0, theta=0.0
% INFO    : Bus 21346	: V=0.9644142, theta=-21.183822 -> V=1.0, theta=0.0
% INFO    : Bus 21347	: V=0.964217, theta=-21.239524 -> V=1.0, theta=0.0
% INFO    : Bus 21348	: V=0.9637714, theta=-21.361375 -> V=1.0, theta=0.0
% INFO    : Bus 21349	: V=0.9630748, theta=-21.377102 -> V=1.0, theta=0.0
% INFO    : Bus 21350	: V=0.9614324, theta=-21.943138 -> V=1.0, theta=0.0
% INFO    : Bus 21351	: V=0.9625616, theta=-21.36166 -> V=1.0, theta=0.0
% INFO    : Bus 21352	: V=0.9632094, theta=-21.306499 -> V=1.0, theta=0.0
% INFO    : Bus 21353	: V=0.9650354, theta=-20.789892 -> V=1.0, theta=0.0
% INFO    : Bus 21354	: V=0.9634476, theta=-20.954558 -> V=1.0, theta=0.0
% INFO    : Bus 21355	: V=0.9623535, theta=-21.134081 -> V=1.0, theta=0.0
% INFO    : Bus 21356	: V=0.9670508, theta=-20.9538 -> V=1.0, theta=0.0
% INFO    : Bus 21357	: V=0.9657348, theta=-21.121553 -> V=1.0, theta=0.0
% INFO    : Bus 21358	: V=0.9645521, theta=-21.274583 -> V=1.0, theta=0.0
% INFO    : Bus 21359	: V=0.9577437, theta=-20.419699 -> V=1.0, theta=0.0
% INFO    : Bus 21360	: V=0.9635268, theta=-19.522912 -> V=1.0, theta=0.0
% INFO    : Bus 21361	: V=0.9633349, theta=-19.627414 -> V=1.0, theta=0.0
% INFO    : Bus 21362	: V=0.9631527, theta=-19.859687 -> V=1.0, theta=0.0
% INFO    : Bus 21363	: V=0.9569219, theta=-21.488927 -> V=1.0, theta=0.0
% INFO    : Bus 21364	: V=0.958661, theta=-21.024873 -> V=1.0, theta=0.0
% INFO    : Bus 21365	: V=0.9600348, theta=-21.436598 -> V=1.0, theta=0.0
% INFO    : Bus 21366	: V=0.9595506, theta=-21.095978 -> V=1.0, theta=0.0
% INFO    : Bus 21367	: V=0.9625209, theta=-20.105329 -> V=1.0, theta=0.0
% INFO    : Bus 21368	: V=0.9668118, theta=-19.455286 -> V=1.0, theta=0.0
% INFO    : Bus 21369	: V=0.967781, theta=-19.883254 -> V=1.0, theta=0.0
% INFO    : Bus 21370	: V=0.9627188, theta=-21.757232 -> V=1.0, theta=0.0
% INFO    : Bus 21371	: V=0.9624475, theta=-21.941007 -> V=1.0, theta=0.0
% INFO    : Bus 21372	: V=0.9599242, theta=-21.683484 -> V=1.0, theta=0.0
% INFO    : Bus 21373	: V=0.968256, theta=-20.619318 -> V=1.0, theta=0.0
% INFO    : Bus 21374	: V=0.9636254, theta=-20.929861 -> V=1.0, theta=0.0
% INFO    : Bus 21375	: V=0.9661395, theta=-20.439306 -> V=1.0, theta=0.0
% INFO    : Bus 21376	: V=0.9672461, theta=-20.542233 -> V=1.0, theta=0.0
% INFO    : Bus 21377	: V=0.9666251, theta=-20.093783 -> V=1.0, theta=0.0
% INFO    : Bus 21378	: V=0.9644344, theta=-21.08637 -> V=1.0, theta=0.0
% INFO    : Bus 21379	: V=0.9647524, theta=-21.148957 -> V=1.0, theta=0.0
% INFO    : Bus 21380	: V=0.9795646, theta=-16.888579 -> V=1.0, theta=0.0
% INFO    : Bus 21381	: V=1.0060614, theta=-12.352796 -> V=1.0, theta=0.0
% INFO    : Bus 21382	: V=0.9911892, theta=-15.380569 -> V=1.0, theta=0.0
% INFO    : Bus 21383	: V=0.9824124, theta=-16.605782 -> V=1.0, theta=0.0
% INFO    : Bus 21384	: V=0.9819021, theta=-16.72376 -> V=1.0, theta=0.0
% INFO    : Bus 21385	: V=0.9809726, theta=-16.768717 -> V=1.0, theta=0.0
% INFO    : Bus 21386	: V=0.9818879, theta=-16.663756 -> V=1.0, theta=0.0
% INFO    : Bus 21387	: V=0.990555, theta=-15.454367 -> V=1.0, theta=0.0
% INFO    : Bus 21388	: V=0.9791016, theta=-16.974548 -> V=1.0, theta=0.0
% INFO    : Bus 21389	: V=0.9777487, theta=-17.174225 -> V=1.0, theta=0.0
% INFO    : Bus 21390	: V=0.9804054, theta=-16.834418 -> V=1.0, theta=0.0
% INFO    : Bus 21391	: V=0.989363, theta=-15.569256 -> V=1.0, theta=0.0
% INFO    : Bus 21392	: V=0.9785422, theta=-17.056906 -> V=1.0, theta=0.0
% INFO    : Bus 21393	: V=0.9790207, theta=-16.976595 -> V=1.0, theta=0.0
% INFO    : Bus 21394	: V=0.9739336, theta=-17.523352 -> V=1.0, theta=0.0
% INFO    : Bus 21395	: V=0.9713274, theta=-17.82519 -> V=1.0, theta=0.0
% INFO    : Bus 21396	: V=0.9791765, theta=-16.965328 -> V=1.0, theta=0.0
% INFO    : Bus 21397	: V=0.9819558, theta=-16.648164 -> V=1.0, theta=0.0
% INFO    : Bus 21398	: V=0.9817808, theta=-16.666712 -> V=1.0, theta=0.0
% INFO    : Bus 21399	: V=0.9795126, theta=-17.058262 -> V=1.0, theta=0.0
% INFO    : Bus 21400	: V=0.9882261, theta=-15.689485 -> V=1.0, theta=0.0
% INFO    : Bus 21401	: V=0.979922, theta=-17.004983 -> V=1.0, theta=0.0
% INFO    : Bus 21402	: V=0.976129, theta=-17.466606 -> V=1.0, theta=0.0
% INFO    : Bus 21403	: V=0.9793347, theta=-17.077341 -> V=1.0, theta=0.0
% INFO    : Bus 21404	: V=0.9792511, theta=-17.084323 -> V=1.0, theta=0.0
% INFO    : Bus 21405	: V=0.9750974, theta=-17.634299 -> V=1.0, theta=0.0
% INFO    : Bus 21406	: V=0.9697011, theta=-18.625012 -> V=1.0, theta=0.0
% INFO    : Bus 21407	: V=0.9742881, theta=-17.81556 -> V=1.0, theta=0.0
% INFO    : Bus 21408	: V=0.9723353, theta=-17.989702 -> V=1.0, theta=0.0
% INFO    : Bus 21409	: V=0.9701911, theta=-18.278839 -> V=1.0, theta=0.0
% INFO    : Bus 21410	: V=0.9719483, theta=-17.965745 -> V=1.0, theta=0.0
% INFO    : Bus 21411	: V=0.9730126, theta=-17.952113 -> V=1.0, theta=0.0
% INFO    : Bus 21412	: V=0.9780749, theta=-17.222792 -> V=1.0, theta=0.0
% INFO    : Bus 21413	: V=0.9765576, theta=-17.349829 -> V=1.0, theta=0.0
% INFO    : Bus 21414	: V=0.9762036, theta=-17.469889 -> V=1.0, theta=0.0
% INFO    : Bus 21415	: V=0.9770364, theta=-17.283242 -> V=1.0, theta=0.0
% INFO    : Bus 21416	: V=0.9698525, theta=-18.062749 -> V=1.0, theta=0.0
% INFO    : Bus 21417	: V=0.9710659, theta=-17.968202 -> V=1.0, theta=0.0
% INFO    : Bus 21418	: V=0.9701298, theta=-18.107808 -> V=1.0, theta=0.0
% INFO    : Bus 21419	: V=0.9760551, theta=-17.381897 -> V=1.0, theta=0.0
% INFO    : Bus 21420	: V=0.9720407, theta=-18.091809 -> V=1.0, theta=0.0
% INFO    : Bus 21421	: V=0.9722401, theta=-17.946833 -> V=1.0, theta=0.0
% INFO    : Bus 21422	: V=0.9723536, theta=-17.90342 -> V=1.0, theta=0.0
% INFO    : Bus 21423	: V=0.972932, theta=-17.796523 -> V=1.0, theta=0.0
% INFO    : Bus 21424	: V=0.9752989, theta=-17.478466 -> V=1.0, theta=0.0
% INFO    : Bus 21425	: V=0.9742726, theta=-17.615883 -> V=1.0, theta=0.0
% INFO    : Bus 21426	: V=0.9750418, theta=-17.550032 -> V=1.0, theta=0.0
% INFO    : Bus 21427	: V=0.970679, theta=-18.308819 -> V=1.0, theta=0.0
% INFO    : Bus 21428	: V=0.9745911, theta=-17.573018 -> V=1.0, theta=0.0
% INFO    : Bus 21429	: V=0.9748314, theta=-17.539693 -> V=1.0, theta=0.0
% INFO    : Bus 21430	: V=0.9696842, theta=-18.298637 -> V=1.0, theta=0.0
% INFO    : Bus 21431	: V=0.9697709, theta=-18.289145 -> V=1.0, theta=0.0
% INFO    : Bus 21432	: V=0.9724784, theta=-17.893238 -> V=1.0, theta=0.0
% INFO    : Bus 21433	: V=0.9701096, theta=-18.220437 -> V=1.0, theta=0.0
% INFO    : Bus 21434	: V=0.9803819, theta=-16.931104 -> V=1.0, theta=0.0
% INFO    : Bus 21435	: V=0.9816082, theta=-16.748147 -> V=1.0, theta=0.0
% INFO    : Bus 21436	: V=0.9655492, theta=-19.063076 -> V=1.0, theta=0.0
% INFO    : Bus 21437	: V=0.9621858, theta=-19.358141 -> V=1.0, theta=0.0
% INFO    : Bus 21438	: V=0.9614237, theta=-19.374605 -> V=1.0, theta=0.0
% INFO    : Bus 21439	: V=0.9648994, theta=-19.135922 -> V=1.0, theta=0.0
% INFO    : Bus 21440	: V=0.9451272, theta=-20.825881 -> V=1.0, theta=0.0
% INFO    : Bus 21441	: V=0.957439, theta=-19.714616 -> V=1.0, theta=0.0
% INFO    : Bus 21442	: V=0.962402, theta=-18.884147 -> V=1.0, theta=0.0
% INFO    : Bus 21443	: V=0.9557696, theta=-19.755113 -> V=1.0, theta=0.0
% INFO    : Bus 21444	: V=0.9544693, theta=-19.935149 -> V=1.0, theta=0.0
% INFO    : Bus 21445	: V=0.947912, theta=-20.390273 -> V=1.0, theta=0.0
% INFO    : Bus 21446	: V=0.9714415, theta=-18.132597 -> V=1.0, theta=0.0
% INFO    : Bus 21447	: V=0.9698909, theta=-18.254432 -> V=1.0, theta=0.0
% INFO    : Bus 21448	: V=0.9650564, theta=-18.689967 -> V=1.0, theta=0.0
% INFO    : Bus 21449	: V=0.9535867, theta=-20.162932 -> V=1.0, theta=0.0
% INFO    : Bus 21450	: V=0.9503009, theta=-20.428343 -> V=1.0, theta=0.0
% INFO    : Bus 21451	: V=0.9513511, theta=-20.328509 -> V=1.0, theta=0.0
% INFO    : Bus 21452	: V=0.9664325, theta=-18.575674 -> V=1.0, theta=0.0
% INFO    : Bus 21453	: V=0.9502638, theta=-20.477628 -> V=1.0, theta=0.0
% INFO    : Bus 21454	: V=0.9692012, theta=-18.315888 -> V=1.0, theta=0.0
% INFO    : Bus 21455	: V=0.9696981, theta=-18.270104 -> V=1.0, theta=0.0
% INFO    : Bus 21456	: V=0.9832165, theta=-16.430411 -> V=1.0, theta=0.0
% INFO    : Bus 21457	: V=0.9908208, theta=-15.10829 -> V=1.0, theta=0.0
% INFO    : Bus 21458	: V=0.9894741, theta=-15.476557 -> V=1.0, theta=0.0
% INFO    : Bus 21459	: V=0.9798944, theta=-16.927352 -> V=1.0, theta=0.0
% INFO    : Bus 21460	: V=0.9897424, theta=-15.362398 -> V=1.0, theta=0.0
% INFO    : Bus 21461	: V=0.9829275, theta=-16.521704 -> V=1.0, theta=0.0
% INFO    : Bus 21462	: V=0.9900706, theta=-15.258544 -> V=1.0, theta=0.0
% INFO    : Bus 21463	: V=0.9836944, theta=-16.375575 -> V=1.0, theta=0.0
% INFO    : Bus 21464	: V=0.9905543, theta=-15.106067 -> V=1.0, theta=0.0
% INFO    : Bus 21465	: V=0.9893183, theta=-15.542803 -> V=1.0, theta=0.0
% INFO    : Bus 21466	: V=0.9795718, theta=-16.953429 -> V=1.0, theta=0.0
% INFO    : Bus 21467	: V=0.979497, theta=-16.987106 -> V=1.0, theta=0.0
% INFO    : Bus 21468	: V=0.9717156, theta=-17.995537 -> V=1.0, theta=0.0
% INFO    : Bus 21469	: V=0.9764499, theta=-17.37687 -> V=1.0, theta=0.0
% INFO    : Bus 21470	: V=0.9696761, theta=-18.064569 -> V=1.0, theta=0.0
% INFO    : Bus 21471	: V=0.97772, theta=-17.25289 -> V=1.0, theta=0.0
% INFO    : Bus 21472	: V=0.979129, theta=-17.077584 -> V=1.0, theta=0.0
% INFO    : Bus 21473	: V=0.9771466, theta=-17.110774 -> V=1.0, theta=0.0
% INFO    : Bus 21474	: V=0.9797946, theta=-16.911361 -> V=1.0, theta=0.0
% INFO    : Bus 21475	: V=0.9789163, theta=-17.133874 -> V=1.0, theta=0.0
% INFO    : Bus 21476	: V=0.9740323, theta=-17.976572 -> V=1.0, theta=0.0
% INFO    : Bus 21477	: V=0.981898, theta=-16.942041 -> V=1.0, theta=0.0
% INFO    : Bus 21478	: V=0.9880169, theta=-15.948606 -> V=1.0, theta=0.0
% INFO    : Bus 21479	: V=0.9798073, theta=-17.031106 -> V=1.0, theta=0.0
% INFO    : Bus 21480	: V=0.9770084, theta=-17.236152 -> V=1.0, theta=0.0
% INFO    : Bus 21481	: V=0.9803958, theta=-16.821447 -> V=1.0, theta=0.0
% INFO    : Bus 21482	: V=0.9762639, theta=-17.283929 -> V=1.0, theta=0.0
% INFO    : Bus 21483	: V=1.0097598, theta=-11.489604 -> V=1.0, theta=0.0
% INFO    : Bus 21484	: V=0.9909069, theta=-15.257016 -> V=1.0, theta=0.0
% INFO    : Bus 21485	: V=0.9808621, theta=-16.815172 -> V=1.0, theta=0.0
% INFO    : Bus 21486	: V=0.9761879, theta=-17.659964 -> V=1.0, theta=0.0
% INFO    : Bus 21487	: V=1.0089264, theta=-12.187422 -> V=1.0, theta=0.0
% INFO    : Bus 21488	: V=0.9809848, theta=-16.877542 -> V=1.0, theta=0.0
% INFO    : Bus 21489	: V=0.9900377, theta=-15.608154 -> V=1.0, theta=0.0
% INFO    : Bus 21490	: V=0.9762745, theta=-17.420612 -> V=1.0, theta=0.0
% INFO    : Bus 21491	: V=0.97125, theta=-18.289011 -> V=1.0, theta=0.0
% INFO    : Bus 21492	: V=0.9703501, theta=-18.350325 -> V=1.0, theta=0.0
% INFO    : Bus 21493	: V=0.9730946, theta=-17.851632 -> V=1.0, theta=0.0
% INFO    : Bus 21494	: V=0.9709148, theta=-18.151977 -> V=1.0, theta=0.0
% INFO    : Bus 21495	: V=0.9717733, theta=-18.086065 -> V=1.0, theta=0.0
% INFO    : Bus 21496	: V=0.9736299, theta=-17.817998 -> V=1.0, theta=0.0
% INFO    : Bus 21497	: V=0.9743528, theta=-17.767984 -> V=1.0, theta=0.0
% INFO    : Bus 21498	: V=0.9752887, theta=-17.703334 -> V=1.0, theta=0.0
% INFO    : Bus 21499	: V=0.9773915, theta=-17.377114 -> V=1.0, theta=0.0
% INFO    : Bus 21500	: V=0.9729188, theta=-18.295002 -> V=1.0, theta=0.0
% INFO    : Bus 21501	: V=0.9852362, theta=-16.386982 -> V=1.0, theta=0.0
% INFO    : Bus 21502	: V=0.9750491, theta=-17.808956 -> V=1.0, theta=0.0
% INFO    : Bus 21503	: V=0.9726737, theta=-18.015152 -> V=1.0, theta=0.0
% INFO    : Bus 21504	: V=0.9723777, theta=-18.056677 -> V=1.0, theta=0.0
% INFO    : Bus 21505	: V=0.9713588, theta=-18.149063 -> V=1.0, theta=0.0
% INFO    : Bus 21506	: V=0.9651317, theta=-19.095974 -> V=1.0, theta=0.0
% INFO    : Bus 21507	: V=0.9660582, theta=-19.081053 -> V=1.0, theta=0.0
% INFO    : Bus 21508	: V=0.9654097, theta=-19.063717 -> V=1.0, theta=0.0
% INFO    : Bus 21509	: V=0.9654068, theta=-19.013131 -> V=1.0, theta=0.0
% INFO    : Bus 21510	: V=0.9738503, theta=-17.923264 -> V=1.0, theta=0.0
% INFO    : Bus 21511	: V=0.9853225, theta=-16.376687 -> V=1.0, theta=0.0
% INFO    : Bus 21512	: V=0.978227, theta=-17.422458 -> V=1.0, theta=0.0
% INFO    : Bus 21513	: V=0.9791294, theta=-17.263809 -> V=1.0, theta=0.0
% INFO    : Bus 21514	: V=0.976304, theta=-17.748332 -> V=1.0, theta=0.0
% INFO    : Bus 21515	: V=0.975682, theta=-17.812049 -> V=1.0, theta=0.0
% INFO    : Bus 21516	: V=0.975249, theta=-17.853166 -> V=1.0, theta=0.0
% INFO    : Bus 21517	: V=0.9751404, theta=-17.867743 -> V=1.0, theta=0.0
% INFO    : Bus 21518	: V=0.9683543, theta=-18.985934 -> V=1.0, theta=0.0
% INFO    : Bus 21519	: V=0.97521, theta=-17.878841 -> V=1.0, theta=0.0
% INFO    : Bus 21520	: V=0.9751369, theta=-17.875011 -> V=1.0, theta=0.0
% INFO    : Bus 21521	: V=0.9846846, theta=-16.477243 -> V=1.0, theta=0.0
% INFO    : Bus 21522	: V=0.9844236, theta=-16.513407 -> V=1.0, theta=0.0
% INFO    : Bus 21523	: V=0.9700407, theta=-18.908271 -> V=1.0, theta=0.0
% INFO    : Bus 21524	: V=0.9701637, theta=-19.19384 -> V=1.0, theta=0.0
% INFO    : Bus 21525	: V=0.9850829, theta=-16.423971 -> V=1.0, theta=0.0
% INFO    : Bus 21526	: V=0.9790076, theta=-17.561604 -> V=1.0, theta=0.0
% INFO    : Bus 21527	: V=0.9796038, theta=-17.50902 -> V=1.0, theta=0.0
% INFO    : Bus 21528	: V=0.9758635, theta=-18.103179 -> V=1.0, theta=0.0
% INFO    : Bus 21529	: V=0.983666, theta=-16.714543 -> V=1.0, theta=0.0
% INFO    : Bus 21530	: V=0.9723646, theta=-18.345809 -> V=1.0, theta=0.0
% INFO    : Bus 21531	: V=0.9804772, theta=-17.426744 -> V=1.0, theta=0.0
% INFO    : Bus 21532	: V=0.9720277, theta=-18.400648 -> V=1.0, theta=0.0
% INFO    : Bus 21533	: V=0.9708802, theta=-18.490809 -> V=1.0, theta=0.0
% INFO    : Bus 21534	: V=0.9701747, theta=-18.490928 -> V=1.0, theta=0.0
% INFO    : Bus 21535	: V=0.9675693, theta=-19.314889 -> V=1.0, theta=0.0
% INFO    : Bus 21536	: V=0.9865917, theta=-16.363857 -> V=1.0, theta=0.0
% INFO    : Bus 21537	: V=0.9696952, theta=-18.516534 -> V=1.0, theta=0.0
% INFO    : Bus 21538	: V=0.9866206, theta=-16.216333 -> V=1.0, theta=0.0
% INFO    : Bus 21539	: V=0.9810925, theta=-17.377887 -> V=1.0, theta=0.0
% INFO    : Bus 21540	: V=0.9911581, theta=-15.772365 -> V=1.0, theta=0.0
% INFO    : Bus 21541	: V=0.9892927, theta=-15.849224 -> V=1.0, theta=0.0
% INFO    : Bus 21542	: V=0.9706566, theta=-18.217441 -> V=1.0, theta=0.0
% INFO    : Bus 21543	: V=0.9699406, theta=-18.261317 -> V=1.0, theta=0.0
% INFO    : Bus 21544	: V=0.9682335, theta=-18.408108 -> V=1.0, theta=0.0
% INFO    : Bus 21545	: V=0.9681439, theta=-18.40838 -> V=1.0, theta=0.0
% INFO    : Bus 21546	: V=0.9508724, theta=-20.484681 -> V=1.0, theta=0.0
% INFO    : Bus 21547	: V=0.9833019, theta=-16.583799 -> V=1.0, theta=0.0
% INFO    : Bus 21548	: V=0.948038, theta=-20.588315 -> V=1.0, theta=0.0
% INFO    : Bus 21549	: V=0.9650001, theta=-18.724112 -> V=1.0, theta=0.0
% INFO    : Bus 21550	: V=0.9461864, theta=-20.732081 -> V=1.0, theta=0.0
% INFO    : Bus 21551	: V=0.9445975, theta=-20.79308 -> V=1.0, theta=0.0
% INFO    : Bus 21552	: V=0.9466593, theta=-20.598782 -> V=1.0, theta=0.0
% INFO    : Bus 21553	: V=0.952139, theta=-20.376204 -> V=1.0, theta=0.0
% INFO    : Bus 21554	: V=0.9544161, theta=-20.2738 -> V=1.0, theta=0.0
% INFO    : Bus 21555	: V=0.9681739, theta=-18.396641 -> V=1.0, theta=0.0
% INFO    : Bus 21556	: V=0.9716167, theta=-18.157083 -> V=1.0, theta=0.0
% INFO    : Bus 21557	: V=0.9697768, theta=-18.291774 -> V=1.0, theta=0.0
% INFO    : Bus 21558	: V=0.9838437, theta=-16.556214 -> V=1.0, theta=0.0
% INFO    : Bus 21559	: V=0.9748937, theta=-17.897022 -> V=1.0, theta=0.0
% INFO    : Bus 21560	: V=0.9736382, theta=-17.996759 -> V=1.0, theta=0.0
% INFO    : Bus 21561	: V=0.9849607, theta=-16.48737 -> V=1.0, theta=0.0
% INFO    : Bus 21562	: V=0.9591873, theta=-19.923428 -> V=1.0, theta=0.0
% INFO    : Bus 21563	: V=0.9715733, theta=-18.154376 -> V=1.0, theta=0.0
% INFO    : Bus 21564	: V=0.9514554, theta=-20.445877 -> V=1.0, theta=0.0
% INFO    : Bus 21565	: V=0.9817532, theta=-17.018533 -> V=1.0, theta=0.0
% INFO    : Bus 21566	: V=0.9770612, theta=-17.733217 -> V=1.0, theta=0.0
% INFO    : Bus 21567	: V=0.982462, theta=-17.403396 -> V=1.0, theta=0.0
% INFO    : Bus 21568	: V=0.9809106, theta=-17.457805 -> V=1.0, theta=0.0
% INFO    : Bus 21569	: V=0.9802651, theta=-17.444569 -> V=1.0, theta=0.0
% INFO    : Bus 21570	: V=0.9957494, theta=-15.55444 -> V=1.0, theta=0.0
% INFO    : Bus 21571	: V=0.9781881, theta=-17.689945 -> V=1.0, theta=0.0
% INFO    : Bus 21572	: V=0.9676399, theta=-18.737916 -> V=1.0, theta=0.0
% INFO    : Bus 21573	: V=0.9754072, theta=-17.922691 -> V=1.0, theta=0.0
% INFO    : Bus 21574	: V=0.9764713, theta=-17.839923 -> V=1.0, theta=0.0
% INFO    : Bus 21575	: V=0.9688676, theta=-18.723579 -> V=1.0, theta=0.0
% INFO    : Bus 21576	: V=0.9696736, theta=-18.63224 -> V=1.0, theta=0.0
% INFO    : Bus 21577	: V=0.9803492, theta=-17.59746 -> V=1.0, theta=0.0
% INFO    : Bus 21578	: V=0.9792936, theta=-17.664974 -> V=1.0, theta=0.0
% INFO    : Bus 21579	: V=0.9782804, theta=-17.719232 -> V=1.0, theta=0.0
% INFO    : Bus 21580	: V=0.9648348, theta=-19.062512 -> V=1.0, theta=0.0
% INFO    : Bus 21581	: V=0.9640513, theta=-19.074047 -> V=1.0, theta=0.0
% INFO    : Bus 21582	: V=0.9752093, theta=-18.096186 -> V=1.0, theta=0.0
% INFO    : Bus 21583	: V=0.9666403, theta=-18.976948 -> V=1.0, theta=0.0
% INFO    : Bus 21584	: V=0.9671535, theta=-18.967483 -> V=1.0, theta=0.0
% INFO    : Bus 21585	: V=0.9672681, theta=-18.94648 -> V=1.0, theta=0.0
% INFO    : Bus 21586	: V=0.9741682, theta=-18.26679 -> V=1.0, theta=0.0
% INFO    : Bus 21587	: V=0.9742916, theta=-18.191794 -> V=1.0, theta=0.0
% INFO    : Bus 21588	: V=0.9737176, theta=-18.251033 -> V=1.0, theta=0.0
% INFO    : Bus 21589	: V=0.9609676, theta=-19.808871 -> V=1.0, theta=0.0
% INFO    : Bus 21590	: V=0.9665346, theta=-18.97773 -> V=1.0, theta=0.0
% INFO    : Bus 21591	: V=0.9881576, theta=-16.232344 -> V=1.0, theta=0.0
% INFO    : Bus 21592	: V=0.9618371, theta=-19.12798 -> V=1.0, theta=0.0
% INFO    : Bus 21593	: V=0.9520089, theta=-20.360091 -> V=1.0, theta=0.0
% INFO    : Bus 21594	: V=0.9665463, theta=-18.89858 -> V=1.0, theta=0.0
% INFO    : Bus 21595	: V=0.9558169, theta=-20.211 -> V=1.0, theta=0.0
% INFO    : Bus 21596	: V=0.966531, theta=-18.981573 -> V=1.0, theta=0.0
% INFO    : Bus 21597	: V=0.9677402, theta=-18.810838 -> V=1.0, theta=0.0
% INFO    : Bus 21598	: V=0.9762602, theta=-17.444706 -> V=1.0, theta=0.0
% INFO    : Bus 21599	: V=0.9636613, theta=-18.802826 -> V=1.0, theta=0.0
% INFO    : Bus 21600	: V=0.9882576, theta=-15.910142 -> V=1.0, theta=0.0
% INFO    : Bus 21601	: V=0.9808598, theta=-16.901019 -> V=1.0, theta=0.0
% INFO    : Bus 21602	: V=0.9765574, theta=-17.648487 -> V=1.0, theta=0.0
% INFO    : Bus 21603	: V=0.9874102, theta=-16.056763 -> V=1.0, theta=0.0
% INFO    : Bus 21604	: V=0.953614, theta=-11.133124 -> V=1.0, theta=0.0
% INFO    : Bus 21605	: V=0.9422876, theta=-13.448175 -> V=1.0, theta=0.0
% INFO    : Bus 21606	: V=0.9399835, theta=-10.894852 -> V=1.0, theta=0.0
% INFO    : Bus 21607	: V=0.9543474, theta=-6.792794 -> V=1.0, theta=0.0
% INFO    : Bus 21608	: V=0.9579734, theta=-6.706436 -> V=1.0, theta=0.0
% INFO    : Bus 21609	: V=0.9616902, theta=-6.376392 -> V=1.0, theta=0.0
% INFO    : Bus 21610	: V=0.9418929, theta=-10.834794 -> V=1.0, theta=0.0
% INFO    : Bus 21611	: V=0.9406857, theta=-10.686792 -> V=1.0, theta=0.0
% INFO    : Bus 21612	: V=0.9435089, theta=-10.090367 -> V=1.0, theta=0.0
% INFO    : Bus 21613	: V=0.9378431, theta=-10.850074 -> V=1.0, theta=0.0
% INFO    : Bus 21614	: V=0.9185946, theta=-19.320846 -> V=1.0, theta=0.0
% INFO    : Bus 21615	: V=0.9356533, theta=-11.352564 -> V=1.0, theta=0.0
% INFO    : Bus 21616	: V=0.9897949, theta=-10.769782 -> V=1.0, theta=0.0
% INFO    : Bus 21617	: V=0.997419, theta=-9.522928 -> V=1.0, theta=0.0
% INFO    : Bus 21618	: V=0.99206, theta=-10.820495 -> V=1.0, theta=0.0
% INFO    : Bus 21619	: V=0.9593635, theta=-13.90577 -> V=1.0, theta=0.0
% INFO    : Bus 21620	: V=0.9639203, theta=-13.95373 -> V=1.0, theta=0.0
% INFO    : Bus 21621	: V=0.9652175, theta=-13.654362 -> V=1.0, theta=0.0
% INFO    : Bus 21622	: V=0.9651146, theta=-14.491576 -> V=1.0, theta=0.0
% INFO    : Bus 21623	: V=0.9647893, theta=-14.589252 -> V=1.0, theta=0.0
% INFO    : Bus 21624	: V=0.9638415, theta=-14.109149 -> V=1.0, theta=0.0
% INFO    : Bus 21625	: V=0.957041, theta=-16.17951 -> V=1.0, theta=0.0
% INFO    : Bus 21626	: V=0.9582588, theta=-15.40778 -> V=1.0, theta=0.0
% INFO    : Bus 21627	: V=0.9652545, theta=-13.998117 -> V=1.0, theta=0.0
% INFO    : Bus 21628	: V=0.9661182, theta=-13.327053 -> V=1.0, theta=0.0
% INFO    : Bus 21629	: V=0.9607724, theta=-15.594143 -> V=1.0, theta=0.0
% INFO    : Bus 21630	: V=0.9604151, theta=-15.709807 -> V=1.0, theta=0.0
% INFO    : Bus 21631	: V=0.9681725, theta=-14.499577 -> V=1.0, theta=0.0
% INFO    : Bus 21632	: V=0.9622684, theta=-15.522153 -> V=1.0, theta=0.0
% INFO    : Bus 21633	: V=0.9610935, theta=-15.570111 -> V=1.0, theta=0.0
% INFO    : Bus 21634	: V=0.9711073, theta=-14.832898 -> V=1.0, theta=0.0
% INFO    : Bus 21635	: V=0.9645418, theta=-15.311814 -> V=1.0, theta=0.0
% INFO    : Bus 21636	: V=0.9724631, theta=-14.782302 -> V=1.0, theta=0.0
% INFO    : Bus 21637	: V=0.9687625, theta=-14.969778 -> V=1.0, theta=0.0
% INFO    : Bus 21638	: V=0.9618958, theta=-15.533485 -> V=1.0, theta=0.0
% INFO    : Bus 21639	: V=0.9608196, theta=-15.556423 -> V=1.0, theta=0.0
% INFO    : Bus 21640	: V=0.9838291, theta=-14.213747 -> V=1.0, theta=0.0
% INFO    : Bus 21641	: V=0.9808368, theta=-14.607083 -> V=1.0, theta=0.0
% INFO    : Bus 21642	: V=0.9626645, theta=-15.69659 -> V=1.0, theta=0.0
% INFO    : Bus 21643	: V=0.9661295, theta=-15.60337 -> V=1.0, theta=0.0
% INFO    : Bus 21644	: V=0.9761276, theta=-14.748172 -> V=1.0, theta=0.0
% INFO    : Bus 21645	: V=0.9755251, theta=-14.7007 -> V=1.0, theta=0.0
% INFO    : Bus 21646	: V=0.9756046, theta=-14.636713 -> V=1.0, theta=0.0
% INFO    : Bus 21647	: V=0.9690158, theta=-14.431987 -> V=1.0, theta=0.0
% INFO    : Bus 21648	: V=0.9703719, theta=-14.298516 -> V=1.0, theta=0.0
% INFO    : Bus 21649	: V=0.9725187, theta=-14.096437 -> V=1.0, theta=0.0
% INFO    : Bus 21650	: V=0.9781035, theta=-13.51665 -> V=1.0, theta=0.0
% INFO    : Bus 21651	: V=1.0012618, theta=-11.231896 -> V=1.0, theta=0.0
% INFO    : Bus 21652	: V=0.9893983, theta=-13.522125 -> V=1.0, theta=0.0
% INFO    : Bus 21653	: V=0.9871616, theta=-13.93839 -> V=1.0, theta=0.0
% INFO    : Bus 21654	: V=0.9779562, theta=-14.713278 -> V=1.0, theta=0.0
% INFO    : Bus 21655	: V=0.9862053, theta=-15.11344 -> V=1.0, theta=0.0
% INFO    : Bus 21656	: V=0.9754076, theta=-14.87687 -> V=1.0, theta=0.0
% INFO    : Bus 21657	: V=0.9770698, theta=-14.365779 -> V=1.0, theta=0.0
% INFO    : Bus 21658	: V=0.9790974, theta=-14.027224 -> V=1.0, theta=0.0
% INFO    : Bus 21659	: V=0.9597272, theta=-15.666338 -> V=1.0, theta=0.0
% INFO    : Bus 21660	: V=0.9671132, theta=-11.506668 -> V=1.0, theta=0.0
% INFO    : Bus 21661	: V=0.9776729, theta=-7.561525 -> V=1.0, theta=0.0
% INFO    : Bus 21662	: V=0.9828612, theta=-6.666603 -> V=1.0, theta=0.0
% INFO    : Bus 21663	: V=0.9735314, theta=-9.857331 -> V=1.0, theta=0.0
% INFO    : Bus 21664	: V=0.9723291, theta=-9.877237 -> V=1.0, theta=0.0
% INFO    : Bus 21665	: V=0.9732629, theta=-9.91758 -> V=1.0, theta=0.0
% INFO    : Bus 21666	: V=0.9842197, theta=-6.92047 -> V=1.0, theta=0.0
% INFO    : Bus 21667	: V=1.0003152, theta=-3.012531 -> V=1.0, theta=0.0
% INFO    : Bus 21668	: V=0.9655984, theta=-12.098732 -> V=1.0, theta=0.0
% INFO    : Bus 21669	: V=0.9753538, theta=-18.359734 -> V=1.0, theta=0.0
% INFO    : Bus 21670	: V=0.9730231, theta=-18.210567 -> V=1.0, theta=0.0
% INFO    : Bus 21671	: V=0.9892826, theta=-17.042045 -> V=1.0, theta=0.0
% INFO    : Bus 21672	: V=0.9887556, theta=-17.009052 -> V=1.0, theta=0.0
% INFO    : Bus 21673	: V=0.9700532, theta=-16.252869 -> V=1.0, theta=0.0
% INFO    : Bus 21674	: V=0.9609653, theta=-17.009671 -> V=1.0, theta=0.0
% INFO    : Bus 21675	: V=0.9890312, theta=-17.107054 -> V=1.0, theta=0.0
% INFO    : Bus 21676	: V=0.9865081, theta=-17.099276 -> V=1.0, theta=0.0
% INFO    : Bus 21677	: V=0.9927804, theta=-15.515652 -> V=1.0, theta=0.0
% INFO    : Bus 21678	: V=0.9991623, theta=-15.729624 -> V=1.0, theta=0.0
% INFO    : Bus 21679	: V=0.9960688, theta=-15.66315 -> V=1.0, theta=0.0
% INFO    : Bus 21680	: V=0.9889546, theta=-16.131081 -> V=1.0, theta=0.0
% INFO    : Bus 21681	: V=0.9988642, theta=-14.852064 -> V=1.0, theta=0.0
% INFO    : Bus 21682	: V=0.9656148, theta=2.625753 -> V=1.0, theta=0.0
% INFO    : Bus 21683	: V=0.9757073, theta=1.884929 -> V=1.0, theta=0.0
% INFO    : Bus 21684	: V=0.9825977, theta=0.706654 -> V=1.0, theta=0.0
% INFO    : Bus 21685	: V=0.9941859, theta=2.947921 -> V=1.0, theta=0.0
% INFO    : Bus 21686	: V=0.9364499, theta=-25.730043 -> V=1.0, theta=0.0
% INFO    : Bus 21687	: V=0.9229719, theta=-26.317873 -> V=1.0, theta=0.0
% INFO    : Bus 21688	: V=0.9371431, theta=-25.703354 -> V=1.0, theta=0.0
% INFO    : Bus 21689	: V=0.9198675, theta=-25.309932 -> V=1.0, theta=0.0
% INFO    : Bus 21690	: V=0.9412499, theta=-16.494601 -> V=1.0, theta=0.0
% INFO    : Bus 21691	: V=0.9415362, theta=-16.498897 -> V=1.0, theta=0.0
% INFO    : Bus 21692	: V=0.924666, theta=-21.690478 -> V=1.0, theta=0.0
% INFO    : Bus 21693	: V=0.9302561, theta=-22.900513 -> V=1.0, theta=0.0
% INFO    : Bus 21694	: V=0.9195713, theta=-27.457994 -> V=1.0, theta=0.0
% INFO    : Bus 21695	: V=0.9280342, theta=-24.185011 -> V=1.0, theta=0.0
% INFO    : Bus 21696	: V=0.9951325, theta=-20.080317 -> V=1.0, theta=0.0
% INFO    : Bus 21697	: V=1.0017077, theta=-20.000733 -> V=1.0, theta=0.0
% INFO    : Bus 21698	: V=0.9798285, theta=-15.395054 -> V=1.0, theta=0.0
% INFO    : Bus 21699	: V=0.9809137, theta=-13.977133 -> V=1.0, theta=0.0
% INFO    : Bus 21700	: V=0.9880979, theta=-11.959338 -> V=1.0, theta=0.0
% INFO    : Bus 21701	: V=0.9893719, theta=-13.439862 -> V=1.0, theta=0.0
% INFO    : Bus 21702	: V=0.9866858, theta=-14.200047 -> V=1.0, theta=0.0
% INFO    : Bus 21703	: V=0.9725561, theta=-14.616752 -> V=1.0, theta=0.0
% INFO    : Bus 21704	: V=0.9953732, theta=-13.80352 -> V=1.0, theta=0.0
% INFO    : Bus 21705	: V=0.9873346, theta=-12.069735 -> V=1.0, theta=0.0
% INFO    : Bus 21706	: V=0.9998694, theta=-10.605395 -> V=1.0, theta=0.0
% INFO    : Bus 21707	: V=0.9954406, theta=-12.910337 -> V=1.0, theta=0.0
% INFO    : Bus 21708	: V=1.0047209, theta=-10.369041 -> V=1.0, theta=0.0
% INFO    : Bus 21709	: V=0.9941693, theta=-6.395136 -> V=1.0, theta=0.0
% INFO    : Bus 21710	: V=0.9994574, theta=-6.455528 -> V=1.0, theta=0.0
% INFO    : Bus 21711	: V=0.9962956, theta=-6.49588 -> V=1.0, theta=0.0
% INFO    : Bus 21712	: V=0.9705967, theta=-9.639806 -> V=1.0, theta=0.0
% INFO    : Bus 21713	: V=0.9878166, theta=-13.236474 -> V=1.0, theta=0.0
% INFO    : Bus 21714	: V=1.0159584, theta=-11.109575 -> V=1.0, theta=0.0
% INFO    : Bus 21715	: V=1.0103172, theta=-11.016014 -> V=1.0, theta=0.0
% INFO    : Bus 21716	: V=0.9958638, theta=-12.699336 -> V=1.0, theta=0.0
% INFO    : Bus 21717	: V=0.9964695, theta=-12.786606 -> V=1.0, theta=0.0
% INFO    : Bus 21718	: V=1.0037305, theta=-8.792863 -> V=1.0, theta=0.0
% INFO    : Bus 21719	: V=1.0159639, theta=-6.813947 -> V=1.0, theta=0.0
% INFO    : Bus 21720	: V=0.9960386, theta=-8.033562 -> V=1.0, theta=0.0
% INFO    : Bus 21721	: V=0.996781, theta=-9.026316 -> V=1.0, theta=0.0
% INFO    : Bus 21722	: V=0.9737545, theta=2.949076 -> V=1.0, theta=0.0
% INFO    : Bus 21723	: V=0.9745138, theta=3.513776 -> V=1.0, theta=0.0
% INFO    : Bus 21724	: V=0.9742654, theta=3.352762 -> V=1.0, theta=0.0
% INFO    : Bus 21725	: V=0.9769815, theta=4.302251 -> V=1.0, theta=0.0
% INFO    : Bus 21726	: V=0.9796999, theta=5.100534 -> V=1.0, theta=0.0
% INFO    : Bus 21727	: V=0.9674616, theta=3.341576 -> V=1.0, theta=0.0
% INFO    : Bus 21728	: V=0.9583118, theta=3.009442 -> V=1.0, theta=0.0
% INFO    : Bus 21729	: V=0.9675725, theta=3.777247 -> V=1.0, theta=0.0
% INFO    : Bus 21730	: V=0.9492631, theta=2.217574 -> V=1.0, theta=0.0
% INFO    : Bus 21731	: V=0.9620734, theta=3.082825 -> V=1.0, theta=0.0
% INFO    : Bus 21732	: V=0.946507, theta=1.801576 -> V=1.0, theta=0.0
% INFO    : Bus 21733	: V=0.9493661, theta=2.149284 -> V=1.0, theta=0.0
% INFO    : Bus 21734	: V=0.9640554, theta=3.177007 -> V=1.0, theta=0.0
% INFO    : Bus 21735	: V=0.9475463, theta=2.123422 -> V=1.0, theta=0.0
% INFO    : Bus 21736	: V=0.946652, theta=2.084448 -> V=1.0, theta=0.0
% INFO    : Bus 21737	: V=0.9700083, theta=1.9265 -> V=1.0, theta=0.0
% INFO    : Bus 21738	: V=0.9500959, theta=0.6841 -> V=1.0, theta=0.0
% INFO    : Bus 21739	: V=0.9515738, theta=0.067462 -> V=1.0, theta=0.0
% INFO    : Bus 21740	: V=0.9685377, theta=1.629357 -> V=1.0, theta=0.0
% INFO    : Bus 21741	: V=0.951454, theta=0.13772 -> V=1.0, theta=0.0
% INFO    : Bus 21742	: V=0.9513815, theta=0.215502 -> V=1.0, theta=0.0
% INFO    : Bus 21743	: V=0.9491133, theta=-0.08346 -> V=1.0, theta=0.0
% INFO    : Bus 21744	: V=0.9496909, theta=0.011157 -> V=1.0, theta=0.0
% INFO    : Bus 21745	: V=0.9694957, theta=1.07164 -> V=1.0, theta=0.0
% INFO    : Bus 21746	: V=0.9350476, theta=1.624048 -> V=1.0, theta=0.0
% INFO    : Bus 21747	: V=0.9401369, theta=1.760951 -> V=1.0, theta=0.0
% INFO    : Bus 21748	: V=0.9489641, theta=2.17657 -> V=1.0, theta=0.0
% INFO    : Bus 21749	: V=0.951493, theta=2.241972 -> V=1.0, theta=0.0
% INFO    : Bus 21750	: V=0.9554762, theta=2.365755 -> V=1.0, theta=0.0
% INFO    : Bus 21751	: V=0.9983431, theta=1.190162 -> V=1.0, theta=0.0
% INFO    : Bus 21752	: V=0.972042, theta=3.620768 -> V=1.0, theta=0.0
% INFO    : Bus 21753	: V=0.974438, theta=3.74118 -> V=1.0, theta=0.0
% INFO    : Bus 21754	: V=0.9630894, theta=-10.524128 -> V=1.0, theta=0.0
% INFO    : Bus 21755	: V=0.9727573, theta=-13.071141 -> V=1.0, theta=0.0
% INFO    : Bus 21756	: V=0.9804691, theta=-12.410462 -> V=1.0, theta=0.0
% INFO    : Bus 21757	: V=1.0009123, theta=-10.520435 -> V=1.0, theta=0.0
% INFO    : Bus 21758	: V=1.0149064, theta=-8.432921 -> V=1.0, theta=0.0
% INFO    : Bus 21759	: V=0.9880663, theta=-12.195018 -> V=1.0, theta=0.0
% INFO    : Bus 21760	: V=0.9895044, theta=-11.954363 -> V=1.0, theta=0.0
% INFO    : Bus 21761	: V=0.9617672, theta=-6.234946 -> V=1.0, theta=0.0
% INFO    : Bus 21762	: V=0.9692675, theta=-5.700488 -> V=1.0, theta=0.0
% INFO    : Bus 21763	: V=0.9712748, theta=-3.928584 -> V=1.0, theta=0.0
% INFO    : Bus 21764	: V=0.9788387, theta=-4.172342 -> V=1.0, theta=0.0
% INFO    : Bus 21765	: V=0.9545689, theta=-11.293307 -> V=1.0, theta=0.0
% INFO    : Bus 21766	: V=0.9497554, theta=-12.258621 -> V=1.0, theta=0.0
% INFO    : Bus 21767	: V=0.9673196, theta=-13.70602 -> V=1.0, theta=0.0
% INFO    : Bus 21768	: V=0.9665818, theta=-14.196204 -> V=1.0, theta=0.0
% INFO    : Bus 21769	: V=0.9640078, theta=-14.97355 -> V=1.0, theta=0.0
% INFO    : Bus 21770	: V=0.9753348, theta=-13.660849 -> V=1.0, theta=0.0
% INFO    : Bus 21771	: V=0.974306, theta=-12.520169 -> V=1.0, theta=0.0
% INFO    : Bus 21772	: V=0.9443013, theta=-27.622386 -> V=1.0, theta=0.0
% INFO    : Bus 21773	: V=0.9402621, theta=-27.156515 -> V=1.0, theta=0.0
% INFO    : Bus 21774	: V=0.9454354, theta=-27.990447 -> V=1.0, theta=0.0
% INFO    : Bus 21775	: V=0.9437405, theta=-27.039282 -> V=1.0, theta=0.0
% INFO    : Bus 21776	: V=0.9438566, theta=-26.802684 -> V=1.0, theta=0.0
% INFO    : Bus 21777	: V=0.9465899, theta=-25.988136 -> V=1.0, theta=0.0
% INFO    : Bus 21778	: V=0.9772889, theta=-28.690463 -> V=1.0, theta=0.0
% INFO    : Bus 21779	: V=0.9458211, theta=-26.172355 -> V=1.0, theta=0.0
% INFO    : Bus 21780	: V=0.9636688, theta=-23.359829 -> V=1.0, theta=0.0
% INFO    : Bus 21781	: V=0.9648369, theta=-23.063013 -> V=1.0, theta=0.0
% INFO    : Bus 21782	: V=0.970622, theta=-22.265346 -> V=1.0, theta=0.0
% INFO    : Bus 21783	: V=0.9825531, theta=-20.541795 -> V=1.0, theta=0.0
% INFO    : Bus 21784	: V=0.9817873, theta=-20.886369 -> V=1.0, theta=0.0
% INFO    : Bus 21785	: V=0.9977579, theta=-20.025283 -> V=1.0, theta=0.0
% INFO    : Bus 21786	: V=0.9611176, theta=-24.064414 -> V=1.0, theta=0.0
% INFO    : Bus 21787	: V=0.9479526, theta=-24.215284 -> V=1.0, theta=0.0
% INFO    : Bus 21788	: V=0.9599434, theta=-23.482866 -> V=1.0, theta=0.0
% INFO    : Bus 21789	: V=0.9597682, theta=-23.842377 -> V=1.0, theta=0.0
% INFO    : Bus 21790	: V=0.9631215, theta=-22.221919 -> V=1.0, theta=0.0
% INFO    : Bus 21791	: V=0.9460247, theta=-9.952145 -> V=1.0, theta=0.0
% INFO    : Bus 21792	: V=0.9393182, theta=-11.165399 -> V=1.0, theta=0.0
% INFO    : Bus 21793	: V=0.9379791, theta=-11.214151 -> V=1.0, theta=0.0
% INFO    : Bus 21794	: V=0.9428849, theta=-10.234795 -> V=1.0, theta=0.0
% INFO    : Bus 21795	: V=0.9407303, theta=-11.063349 -> V=1.0, theta=0.0
% INFO    : Bus 21796	: V=0.9441981, theta=-10.180676 -> V=1.0, theta=0.0
% INFO    : Bus 21797	: V=0.940126, theta=-11.222176 -> V=1.0, theta=0.0
% INFO    : Bus 21798	: V=0.9391433, theta=-11.279435 -> V=1.0, theta=0.0
% INFO    : Bus 21799	: V=0.9378858, theta=-11.494267 -> V=1.0, theta=0.0
% INFO    : Bus 21800	: V=0.935551, theta=-11.857543 -> V=1.0, theta=0.0
% INFO    : Bus 21801	: V=0.9363463, theta=-11.711097 -> V=1.0, theta=0.0
% INFO    : Bus 21802	: V=0.9335967, theta=-12.248017 -> V=1.0, theta=0.0
% INFO    : Bus 21803	: V=0.9346393, theta=-12.023772 -> V=1.0, theta=0.0
% INFO    : Bus 21804	: V=0.9341763, theta=-12.100171 -> V=1.0, theta=0.0
% INFO    : Bus 21805	: V=0.9353962, theta=-12.024047 -> V=1.0, theta=0.0
% INFO    : Bus 21806	: V=0.9361322, theta=-11.927911 -> V=1.0, theta=0.0
% INFO    : Bus 21807	: V=0.934924, theta=-11.955642 -> V=1.0, theta=0.0
% INFO    : Bus 21808	: V=0.9457036, theta=-10.301633 -> V=1.0, theta=0.0
% INFO    : Bus 21809	: V=0.9410427, theta=-11.155994 -> V=1.0, theta=0.0
% INFO    : Bus 21810	: V=0.9419588, theta=-11.037695 -> V=1.0, theta=0.0
% INFO    : Bus 21811	: V=0.9447559, theta=-10.139506 -> V=1.0, theta=0.0
% INFO    : Bus 21812	: V=0.9456352, theta=-10.053392 -> V=1.0, theta=0.0
% INFO    : Bus 21813	: V=0.946565, theta=-9.89148 -> V=1.0, theta=0.0
% INFO    : Bus 21814	: V=0.9465195, theta=-10.202737 -> V=1.0, theta=0.0
% INFO    : Bus 21815	: V=0.9477686, theta=-9.546978 -> V=1.0, theta=0.0
% INFO    : Bus 21816	: V=0.9479322, theta=-9.347855 -> V=1.0, theta=0.0
% INFO    : Bus 21817	: V=0.9595017, theta=-8.49981 -> V=1.0, theta=0.0
% INFO    : Bus 21818	: V=0.9467897, theta=-9.512838 -> V=1.0, theta=0.0
% INFO    : Bus 21819	: V=0.9452968, theta=-10.332627 -> V=1.0, theta=0.0
% INFO    : Bus 21820	: V=0.9368165, theta=-11.780097 -> V=1.0, theta=0.0
% INFO    : Bus 21821	: V=0.9365537, theta=-11.800791 -> V=1.0, theta=0.0
% INFO    : Bus 21822	: V=0.9375394, theta=-11.544475 -> V=1.0, theta=0.0
% INFO    : Bus 21823	: V=0.9362608, theta=-11.796071 -> V=1.0, theta=0.0
% INFO    : Bus 21824	: V=0.9446253, theta=-10.069774 -> V=1.0, theta=0.0
% INFO    : Bus 21825	: V=0.9410664, theta=-10.737906 -> V=1.0, theta=0.0
% INFO    : Bus 21826	: V=0.9448794, theta=-10.845699 -> V=1.0, theta=0.0
% INFO    : Bus 21827	: V=0.9449873, theta=-11.036902 -> V=1.0, theta=0.0
% INFO    : Bus 21828	: V=0.9453226, theta=-11.167147 -> V=1.0, theta=0.0
% INFO    : Bus 21829	: V=0.9577182, theta=-10.061133 -> V=1.0, theta=0.0
% INFO    : Bus 21830	: V=0.93974, theta=-13.070811 -> V=1.0, theta=0.0
% INFO    : Bus 21831	: V=0.9359387, theta=-12.70079 -> V=1.0, theta=0.0
% INFO    : Bus 21832	: V=0.9446155, theta=-10.9977 -> V=1.0, theta=0.0
% INFO    : Bus 21833	: V=0.9630148, theta=-4.490648 -> V=1.0, theta=0.0
% INFO    : Bus 21834	: V=0.9640819, theta=-6.0244 -> V=1.0, theta=0.0
% INFO    : Bus 21835	: V=0.9422359, theta=-10.217979 -> V=1.0, theta=0.0
% INFO    : Bus 21836	: V=0.9496473, theta=-9.055748 -> V=1.0, theta=0.0
% INFO    : Bus 21837	: V=0.9362659, theta=-11.639662 -> V=1.0, theta=0.0
% INFO    : Bus 21838	: V=0.9353912, theta=-11.771631 -> V=1.0, theta=0.0
% INFO    : Bus 21839	: V=0.9327821, theta=-12.457654 -> V=1.0, theta=0.0
% INFO    : Bus 21840	: V=0.9388346, theta=-10.701843 -> V=1.0, theta=0.0
% INFO    : Bus 21841	: V=0.9397086, theta=-10.571068 -> V=1.0, theta=0.0
% INFO    : Bus 21842	: V=0.9345642, theta=-12.223377 -> V=1.0, theta=0.0
% INFO    : Bus 21843	: V=0.9335541, theta=-12.333086 -> V=1.0, theta=0.0
% INFO    : Bus 21844	: V=0.9347967, theta=-12.51598 -> V=1.0, theta=0.0
% INFO    : Bus 21845	: V=0.9434973, theta=-12.452447 -> V=1.0, theta=0.0
% INFO    : Bus 21846	: V=0.9426594, theta=-12.668308 -> V=1.0, theta=0.0
% INFO    : Bus 21847	: V=0.940837, theta=-13.193278 -> V=1.0, theta=0.0
% INFO    : Bus 21848	: V=0.9420245, theta=-12.903784 -> V=1.0, theta=0.0
% INFO    : Bus 21849	: V=0.9330969, theta=-12.437381 -> V=1.0, theta=0.0
% INFO    : Bus 21850	: V=0.947626, theta=-11.423938 -> V=1.0, theta=0.0
% INFO    : Bus 21851	: V=0.9314536, theta=-13.590359 -> V=1.0, theta=0.0
% INFO    : Bus 21852	: V=0.9316286, theta=-13.024997 -> V=1.0, theta=0.0
% INFO    : Bus 21853	: V=0.9318386, theta=-12.659114 -> V=1.0, theta=0.0
% INFO    : Bus 21854	: V=0.931413, theta=-14.06679 -> V=1.0, theta=0.0
% INFO    : Bus 21855	: V=0.9566998, theta=-10.587215 -> V=1.0, theta=0.0
% INFO    : Bus 21856	: V=0.9577083, theta=-10.408752 -> V=1.0, theta=0.0
% INFO    : Bus 21857	: V=0.9426573, theta=-10.524262 -> V=1.0, theta=0.0
% INFO    : Bus 21858	: V=0.9450291, theta=-9.820482 -> V=1.0, theta=0.0
% INFO    : Bus 21859	: V=0.9440999, theta=-10.137322 -> V=1.0, theta=0.0
% INFO    : Bus 21860	: V=0.9461932, theta=-9.037402 -> V=1.0, theta=0.0
% INFO    : Bus 21861	: V=0.9463153, theta=-7.809433 -> V=1.0, theta=0.0
% INFO    : Bus 21862	: V=0.9650012, theta=-1.335332 -> V=1.0, theta=0.0
% INFO    : Bus 21863	: V=0.9651163, theta=-1.359388 -> V=1.0, theta=0.0
% INFO    : Bus 21864	: V=0.9495801, theta=-7.542903 -> V=1.0, theta=0.0
% INFO    : Bus 21865	: V=0.9455055, theta=-12.825343 -> V=1.0, theta=0.0
% INFO    : Bus 21866	: V=0.9698465, theta=-18.619763 -> V=1.0, theta=0.0
% INFO    : Bus 21867	: V=0.9810049, theta=-17.517871 -> V=1.0, theta=0.0
% INFO    : Bus 21868	: V=0.9827458, theta=-17.297212 -> V=1.0, theta=0.0
% INFO    : Bus 21869	: V=0.9840273, theta=-17.348844 -> V=1.0, theta=0.0
% INFO    : Bus 21870	: V=0.9942667, theta=-16.886341 -> V=1.0, theta=0.0
% INFO    : Bus 21871	: V=0.9603289, theta=-21.333846 -> V=1.0, theta=0.0
% INFO    : Bus 21872	: V=0.9494659, theta=-22.036042 -> V=1.0, theta=0.0
% INFO    : Bus 21873	: V=0.973742, theta=-18.899104 -> V=1.0, theta=0.0
% INFO    : Bus 21874	: V=0.9683266, theta=-19.895397 -> V=1.0, theta=0.0
% INFO    : Bus 21875	: V=0.9750621, theta=-18.651876 -> V=1.0, theta=0.0
% INFO    : Bus 21876	: V=0.9686993, theta=-19.998833 -> V=1.0, theta=0.0
% INFO    : Bus 21877	: V=0.9688725, theta=-19.964909 -> V=1.0, theta=0.0
% INFO    : Bus 21878	: V=0.9759339, theta=-18.47485 -> V=1.0, theta=0.0
% INFO    : Bus 21879	: V=0.9775933, theta=-18.176106 -> V=1.0, theta=0.0
% INFO    : Bus 21880	: V=0.9788452, theta=-17.985021 -> V=1.0, theta=0.0
% INFO    : Bus 21881	: V=1.0093417, theta=-9.932979 -> V=1.0, theta=0.0
% INFO    : Bus 21882	: V=1.0128655, theta=-9.580602 -> V=1.0, theta=0.0
% INFO    : Bus 21883	: V=1.0124141, theta=-9.54782 -> V=1.0, theta=0.0
% INFO    : Bus 21884	: V=1.0003357, theta=-10.337496 -> V=1.0, theta=0.0
% INFO    : Bus 21885	: V=1.0107099, theta=-9.314661 -> V=1.0, theta=0.0
% INFO    : Bus 21886	: V=0.9668807, theta=-3.901803 -> V=1.0, theta=0.0
% INFO    : Bus 21887	: V=0.9695908, theta=-3.911929 -> V=1.0, theta=0.0
% INFO    : Bus 21888	: V=0.9647991, theta=-5.450998 -> V=1.0, theta=0.0
% INFO    : Bus 21889	: V=0.9696366, theta=-3.279316 -> V=1.0, theta=0.0
% INFO    : Bus 21890	: V=0.9726696, theta=-3.828342 -> V=1.0, theta=0.0
% INFO    : Bus 21891	: V=0.979167, theta=-2.850531 -> V=1.0, theta=0.0
% INFO    : Bus 21892	: V=0.979278, theta=-1.730278 -> V=1.0, theta=0.0
% INFO    : Bus 21893	: V=0.9375891, theta=-28.190597 -> V=1.0, theta=0.0
% INFO    : Bus 21894	: V=0.9295814, theta=-25.979981 -> V=1.0, theta=0.0
% INFO    : Bus 21895	: V=0.9177601, theta=-28.552812 -> V=1.0, theta=0.0
% INFO    : Bus 21896	: V=0.9241752, theta=-27.046974 -> V=1.0, theta=0.0
% INFO    : Bus 21897	: V=0.9395607, theta=-28.628293 -> V=1.0, theta=0.0
% INFO    : Bus 21898	: V=0.9334219, theta=-28.825555 -> V=1.0, theta=0.0
% INFO    : Bus 21899	: V=0.9236111, theta=-28.683248 -> V=1.0, theta=0.0
% INFO    : Bus 21900	: V=0.9201805, theta=-26.382952 -> V=1.0, theta=0.0
% INFO    : Bus 21901	: V=0.9290832, theta=-28.889918 -> V=1.0, theta=0.0
% INFO    : Bus 21902	: V=1.0079109, theta=-7.171746 -> V=1.0, theta=0.0
% INFO    : Bus 21903	: V=1.0151699, theta=-6.85972 -> V=1.0, theta=0.0
% INFO    : Bus 21904	: V=1.0130572, theta=-6.762221 -> V=1.0, theta=0.0
% INFO    : Bus 21905	: V=1.0017119, theta=-8.596948 -> V=1.0, theta=0.0
% INFO    : Bus 21906	: V=1.0130471, theta=-8.213307 -> V=1.0, theta=0.0
% INFO    : Bus 21907	: V=1.0156765, theta=-17.2131 -> V=1.0, theta=0.0
% INFO    : Bus 21908	: V=0.9884136, theta=-18.57901 -> V=1.0, theta=0.0
% INFO    : Bus 21909	: V=0.9992617, theta=-18.330356 -> V=1.0, theta=0.0
% INFO    : Bus 21910	: V=0.9704007, theta=-9.062967 -> V=1.0, theta=0.0
% INFO    : Bus 21911	: V=0.9698582, theta=-9.086322 -> V=1.0, theta=0.0
% INFO    : Bus 21912	: V=0.9730357, theta=-8.505893 -> V=1.0, theta=0.0
% INFO    : Bus 21913	: V=0.973485, theta=-8.324412 -> V=1.0, theta=0.0
% INFO    : Bus 21914	: V=0.9722688, theta=-8.620916 -> V=1.0, theta=0.0
% INFO    : Bus 21915	: V=0.9717171, theta=-8.711803 -> V=1.0, theta=0.0
% INFO    : Bus 21916	: V=0.9680288, theta=-9.223175 -> V=1.0, theta=0.0
% INFO    : Bus 21917	: V=0.9682682, theta=-9.218902 -> V=1.0, theta=0.0
% INFO    : Bus 21918	: V=0.9672007, theta=-9.372995 -> V=1.0, theta=0.0
% INFO    : Bus 21919	: V=0.9735496, theta=-8.227646 -> V=1.0, theta=0.0
% INFO    : Bus 21920	: V=0.9735784, theta=-8.216094 -> V=1.0, theta=0.0
% INFO    : Bus 21921	: V=0.9713193, theta=-8.741826 -> V=1.0, theta=0.0
% INFO    : Bus 21922	: V=0.9737467, theta=-8.190627 -> V=1.0, theta=0.0
% INFO    : Bus 21923	: V=0.9741789, theta=-8.110301 -> V=1.0, theta=0.0
% INFO    : Bus 21924	: V=0.9824317, theta=-7.459431 -> V=1.0, theta=0.0
% INFO    : Bus 21925	: V=0.9719292, theta=-8.729898 -> V=1.0, theta=0.0
% INFO    : Bus 21926	: V=0.9817277, theta=-7.139812 -> V=1.0, theta=0.0
% INFO    : Bus 21927	: V=0.9769642, theta=-7.697709 -> V=1.0, theta=0.0
% INFO    : Bus 21928	: V=0.9759407, theta=-7.878385 -> V=1.0, theta=0.0
% INFO    : Bus 21929	: V=0.9749773, theta=-8.025461 -> V=1.0, theta=0.0
% INFO    : Bus 21930	: V=0.9714495, theta=-8.678301 -> V=1.0, theta=0.0
% INFO    : Bus 21931	: V=0.9742656, theta=-8.157678 -> V=1.0, theta=0.0
% INFO    : Bus 21932	: V=0.9728659, theta=-8.710735 -> V=1.0, theta=0.0
% INFO    : Bus 21933	: V=0.9795829, theta=-8.116143 -> V=1.0, theta=0.0
% INFO    : Bus 21934	: V=0.9796985, theta=-6.858168 -> V=1.0, theta=0.0
% INFO    : Bus 21935	: V=0.9704459, theta=-7.942451 -> V=1.0, theta=0.0
% INFO    : Bus 21936	: V=0.9795266, theta=-7.381739 -> V=1.0, theta=0.0
% INFO    : Bus 21937	: V=0.9693941, theta=-8.619792 -> V=1.0, theta=0.0
% INFO    : Bus 21938	: V=0.9698854, theta=-8.678439 -> V=1.0, theta=0.0
% INFO    : Bus 21939	: V=0.9694723, theta=-8.684319 -> V=1.0, theta=0.0
% INFO    : Bus 21940	: V=0.9899484, theta=-5.336649 -> V=1.0, theta=0.0
% INFO    : Bus 21941	: V=0.9709946, theta=-8.743107 -> V=1.0, theta=0.0
% INFO    : Bus 21942	: V=0.9816651, theta=-7.15103 -> V=1.0, theta=0.0
% INFO    : Bus 21943	: V=0.9645597, theta=-9.214336 -> V=1.0, theta=0.0
% INFO    : Bus 21944	: V=0.9548246, theta=-10.923881 -> V=1.0, theta=0.0
% INFO    : Bus 21945	: V=0.9729685, theta=-8.375097 -> V=1.0, theta=0.0
% INFO    : Bus 21946	: V=0.9741604, theta=-8.194378 -> V=1.0, theta=0.0
% INFO    : Bus 21947	: V=0.9577315, theta=-20.009559 -> V=1.0, theta=0.0
% INFO    : Bus 21948	: V=0.9603282, theta=-17.066033 -> V=1.0, theta=0.0
% INFO    : Bus 21949	: V=0.9641558, theta=-17.335718 -> V=1.0, theta=0.0
% INFO    : Bus 21950	: V=0.975879, theta=-16.123822 -> V=1.0, theta=0.0
% INFO    : Bus 21951	: V=0.9578728, theta=-27.444467 -> V=1.0, theta=0.0
% INFO    : Bus 21952	: V=0.9594521, theta=-27.167265 -> V=1.0, theta=0.0
% INFO    : Bus 21953	: V=0.986965, theta=-12.379264 -> V=1.0, theta=0.0
% INFO    : Bus 21954	: V=0.9992025, theta=-11.080439 -> V=1.0, theta=0.0
% INFO    : Bus 21955	: V=1.0003969, theta=-10.81953 -> V=1.0, theta=0.0
% INFO    : Bus 21956	: V=1.0007184, theta=-10.788617 -> V=1.0, theta=0.0
% INFO    : Bus 21957	: V=0.9884628, theta=-12.052602 -> V=1.0, theta=0.0
% INFO    : Bus 21958	: V=0.9923776, theta=-10.890802 -> V=1.0, theta=0.0
% INFO    : Bus 21959	: V=0.9878181, theta=-11.976239 -> V=1.0, theta=0.0
% INFO    : Bus 21960	: V=0.9874855, theta=-11.979912 -> V=1.0, theta=0.0
% INFO    : Bus 21961	: V=0.9864002, theta=-12.052508 -> V=1.0, theta=0.0
% INFO    : Bus 21962	: V=0.9874661, theta=-11.947989 -> V=1.0, theta=0.0
% INFO    : Bus 21963	: V=0.9898989, theta=-11.851976 -> V=1.0, theta=0.0
% INFO    : Bus 21964	: V=0.9905239, theta=-12.306414 -> V=1.0, theta=0.0
% INFO    : Bus 21965	: V=0.9895523, theta=-12.314856 -> V=1.0, theta=0.0
% INFO    : Bus 21966	: V=0.9889859, theta=-12.329401 -> V=1.0, theta=0.0
% INFO    : Bus 21967	: V=0.9891028, theta=-12.325418 -> V=1.0, theta=0.0
% INFO    : Bus 21968	: V=0.991885, theta=-12.285932 -> V=1.0, theta=0.0
% INFO    : Bus 21969	: V=0.99337, theta=-12.195069 -> V=1.0, theta=0.0
% INFO    : Bus 21970	: V=1.0154262, theta=-8.527711 -> V=1.0, theta=0.0
% INFO    : Bus 21971	: V=0.9920249, theta=-12.228442 -> V=1.0, theta=0.0
% INFO    : Bus 21972	: V=1.0018483, theta=-10.716825 -> V=1.0, theta=0.0
% INFO    : Bus 21973	: V=0.9876032, theta=-12.460439 -> V=1.0, theta=0.0
% INFO    : Bus 21974	: V=0.9882355, theta=-12.383879 -> V=1.0, theta=0.0
% INFO    : Bus 21975	: V=0.9898622, theta=-12.338119 -> V=1.0, theta=0.0
% INFO    : Bus 21976	: V=1.0045508, theta=-10.509697 -> V=1.0, theta=0.0
% INFO    : Bus 21977	: V=1.0056013, theta=-10.464756 -> V=1.0, theta=0.0
% INFO    : Bus 21978	: V=1.0085535, theta=-10.266359 -> V=1.0, theta=0.0
% INFO    : Bus 21979	: V=0.991125, theta=-12.233248 -> V=1.0, theta=0.0
% INFO    : Bus 21980	: V=1.0096383, theta=-10.140184 -> V=1.0, theta=0.0
% INFO    : Bus 21981	: V=1.0096096, theta=-10.117247 -> V=1.0, theta=0.0
% INFO    : Bus 21982	: V=0.9868441, theta=-12.470647 -> V=1.0, theta=0.0
% INFO    : Bus 21983	: V=0.9844937, theta=-12.493388 -> V=1.0, theta=0.0
% INFO    : Bus 21984	: V=0.9881554, theta=-12.35884 -> V=1.0, theta=0.0
% INFO    : Bus 21985	: V=0.9850115, theta=-12.084801 -> V=1.0, theta=0.0
% INFO    : Bus 21986	: V=0.9885358, theta=-12.000953 -> V=1.0, theta=0.0
% INFO    : Bus 21987	: V=0.9927986, theta=-10.847708 -> V=1.0, theta=0.0
% INFO    : Bus 21988	: V=0.9937852, theta=-10.760289 -> V=1.0, theta=0.0
% INFO    : Bus 21989	: V=0.9950759, theta=-10.6529 -> V=1.0, theta=0.0
% INFO    : Bus 21990	: V=0.987078, theta=-12.011306 -> V=1.0, theta=0.0
% INFO    : Bus 21991	: V=0.9852677, theta=-12.487315 -> V=1.0, theta=0.0
% INFO    : Bus 21992	: V=1.016146, theta=-8.556062 -> V=1.0, theta=0.0
% INFO    : Bus 21993	: V=0.9784564, theta=-12.86086 -> V=1.0, theta=0.0
% INFO    : Bus 21994	: V=0.9959472, theta=-11.412668 -> V=1.0, theta=0.0
% INFO    : Bus 21995	: V=1.015895, theta=-8.466606 -> V=1.0, theta=0.0
% INFO    : Bus 21996	: V=1.0000733, theta=-10.87312 -> V=1.0, theta=0.0
% INFO    : Bus 21997	: V=1.0172854, theta=-8.097124 -> V=1.0, theta=0.0
% INFO    : Bus 21998	: V=0.9903442, theta=-12.148694 -> V=1.0, theta=0.0
% INFO    : Bus 21999	: V=0.9858627, theta=-12.210787 -> V=1.0, theta=0.0
% INFO    : Bus 22000	: V=0.9857634, theta=-12.109139 -> V=1.0, theta=0.0
% INFO    : Bus 22001	: V=0.984106, theta=-12.100715 -> V=1.0, theta=0.0
% INFO    : Bus 22002	: V=1.0075121, theta=-1.496265 -> V=1.0, theta=0.0
% INFO    : Bus 22003	: V=1.0121104, theta=-2.277293 -> V=1.0, theta=0.0
% INFO    : Bus 22004	: V=1.010711, theta=-4.560037 -> V=1.0, theta=0.0
% INFO    : Bus 22005	: V=1.0117402, theta=-5.244384 -> V=1.0, theta=0.0
% INFO    : Bus 22006	: V=1.0040175, theta=-6.43441 -> V=1.0, theta=0.0
% INFO    : Bus 22007	: V=1.0008956, theta=-7.66028 -> V=1.0, theta=0.0
% INFO    : Bus 22008	: V=1.0097319, theta=-6.796366 -> V=1.0, theta=0.0
% INFO    : Bus 22009	: V=1.0096503, theta=-6.797433 -> V=1.0, theta=0.0
% INFO    : Bus 22010	: V=1.0095786, theta=-6.795943 -> V=1.0, theta=0.0
% INFO    : Bus 22011	: V=1.0095581, theta=-6.787061 -> V=1.0, theta=0.0
% INFO    : Bus 22012	: V=1.0113112, theta=-6.587871 -> V=1.0, theta=0.0
% INFO    : Bus 22013	: V=1.0122089, theta=-6.538123 -> V=1.0, theta=0.0
% INFO    : Bus 22014	: V=1.0107746, theta=-6.684957 -> V=1.0, theta=0.0
% INFO    : Bus 22015	: V=1.0091712, theta=-6.875858 -> V=1.0, theta=0.0
% INFO    : Bus 22016	: V=1.0090563, theta=-6.901046 -> V=1.0, theta=0.0
% INFO    : Bus 22017	: V=1.0075579, theta=-6.995299 -> V=1.0, theta=0.0
% INFO    : Bus 22018	: V=1.0052892, theta=-7.391858 -> V=1.0, theta=0.0
% INFO    : Bus 22019	: V=1.0066636, theta=-7.063618 -> V=1.0, theta=0.0
% INFO    : Bus 22020	: V=1.0172458, theta=-5.248684 -> V=1.0, theta=0.0
% INFO    : Bus 22021	: V=1.0098905, theta=-6.714878 -> V=1.0, theta=0.0
% INFO    : Bus 22022	: V=1.0104425, theta=-6.638862 -> V=1.0, theta=0.0
% INFO    : Bus 22023	: V=0.9897955, theta=-8.067362 -> V=1.0, theta=0.0
% INFO    : Bus 22024	: V=1.0085366, theta=-6.431817 -> V=1.0, theta=0.0
% INFO    : Bus 22025	: V=0.9936838, theta=-7.848393 -> V=1.0, theta=0.0
% INFO    : Bus 22026	: V=1.0128059, theta=-5.972289 -> V=1.0, theta=0.0
% INFO    : Bus 22027	: V=1.0133081, theta=-6.042305 -> V=1.0, theta=0.0
% INFO    : Bus 22028	: V=1.0115325, theta=-6.397256 -> V=1.0, theta=0.0
% INFO    : Bus 22029	: V=0.9985347, theta=-8.794897 -> V=1.0, theta=0.0
% INFO    : Bus 22030	: V=1.0051236, theta=-7.19255 -> V=1.0, theta=0.0
% INFO    : Bus 22031	: V=1.0043967, theta=-7.315862 -> V=1.0, theta=0.0
% INFO    : Bus 22032	: V=1.0187535, theta=-5.071907 -> V=1.0, theta=0.0
% INFO    : Bus 22033	: V=1.0106458, theta=-6.596344 -> V=1.0, theta=0.0
% INFO    : Bus 22034	: V=1.0183767, theta=-5.265388 -> V=1.0, theta=0.0
% INFO    : Bus 22035	: V=0.955051, theta=-15.632729 -> V=1.0, theta=0.0
% INFO    : Bus 22036	: V=0.9549699, theta=-15.670577 -> V=1.0, theta=0.0
% INFO    : Bus 22037	: V=0.9588401, theta=-15.381308 -> V=1.0, theta=0.0
% INFO    : Bus 22038	: V=0.9531684, theta=-17.262384 -> V=1.0, theta=0.0
% INFO    : Bus 22039	: V=0.956712, theta=-16.480897 -> V=1.0, theta=0.0
% INFO    : Bus 22040	: V=0.9602958, theta=-16.120847 -> V=1.0, theta=0.0
% INFO    : Bus 22041	: V=0.9572863, theta=-16.474935 -> V=1.0, theta=0.0
% INFO    : Bus 22042	: V=0.9571914, theta=-17.503901 -> V=1.0, theta=0.0
% INFO    : Bus 22043	: V=0.9930665, theta=-1.050047 -> V=1.0, theta=0.0
% INFO    : Bus 22044	: V=0.9654566, theta=-4.807237 -> V=1.0, theta=0.0
% INFO    : Bus 22045	: V=0.9962389, theta=-10.181906 -> V=1.0, theta=0.0
% INFO    : Bus 22046	: V=1.0012117, theta=-9.202764 -> V=1.0, theta=0.0
% INFO    : Bus 22047	: V=0.9764565, theta=-12.867628 -> V=1.0, theta=0.0
% INFO    : Bus 22048	: V=0.9814523, theta=-12.261522 -> V=1.0, theta=0.0
% INFO    : Bus 22049	: V=1.0063784, theta=-9.43189 -> V=1.0, theta=0.0
% INFO    : Bus 22050	: V=1.004627, theta=-9.452111 -> V=1.0, theta=0.0
% INFO    : Bus 22051	: V=0.9976146, theta=-10.455067 -> V=1.0, theta=0.0
% INFO    : Bus 22052	: V=1.002667, theta=-10.035391 -> V=1.0, theta=0.0
% INFO    : Bus 22053	: V=1.0068025, theta=-9.687128 -> V=1.0, theta=0.0
% INFO    : Bus 22054	: V=0.9862868, theta=-12.160392 -> V=1.0, theta=0.0
% INFO    : Bus 22055	: V=1.0001094, theta=-10.258869 -> V=1.0, theta=0.0
% INFO    : Bus 22056	: V=0.9819627, theta=-16.996171 -> V=1.0, theta=0.0
% INFO    : Bus 22057	: V=0.9779109, theta=-16.855603 -> V=1.0, theta=0.0
% INFO    : Bus 22058	: V=0.9878885, theta=-15.432432 -> V=1.0, theta=0.0
% INFO    : Bus 22059	: V=0.9827829, theta=-16.381299 -> V=1.0, theta=0.0
% INFO    : Bus 22060	: V=0.9820516, theta=-16.595245 -> V=1.0, theta=0.0
% INFO    : Bus 22061	: V=0.995291, theta=-15.165136 -> V=1.0, theta=0.0
% INFO    : Bus 22062	: V=0.9791077, theta=-26.984411 -> V=1.0, theta=0.0
% INFO    : Bus 22063	: V=0.9675397, theta=-28.551888 -> V=1.0, theta=0.0
% INFO    : Bus 22064	: V=0.969036, theta=-28.475911 -> V=1.0, theta=0.0
% INFO    : Bus 22065	: V=0.9821056, theta=-25.702252 -> V=1.0, theta=0.0
% INFO    : Bus 22066	: V=0.9817401, theta=-26.437082 -> V=1.0, theta=0.0
% INFO    : Bus 22067	: V=0.9807688, theta=-26.758535 -> V=1.0, theta=0.0
% INFO    : Bus 22068	: V=0.9809037, theta=-26.813412 -> V=1.0, theta=0.0
% INFO    : Bus 22069	: V=0.9694122, theta=-28.398866 -> V=1.0, theta=0.0
% INFO    : Bus 22070	: V=0.9791419, theta=-27.307373 -> V=1.0, theta=0.0
% INFO    : Bus 22071	: V=0.9794604, theta=-27.07987 -> V=1.0, theta=0.0
% INFO    : Bus 22072	: V=0.9785299, theta=-27.651827 -> V=1.0, theta=0.0
% INFO    : Bus 22073	: V=0.9361222, theta=-27.459959 -> V=1.0, theta=0.0
% INFO    : Bus 22074	: V=0.9364095, theta=-27.411251 -> V=1.0, theta=0.0
% INFO    : Bus 22075	: V=0.9652275, theta=-26.575768 -> V=1.0, theta=0.0
% INFO    : Bus 22076	: V=0.9539062, theta=-26.597346 -> V=1.0, theta=0.0
% INFO    : Bus 22077	: V=0.9839962, theta=-25.614191 -> V=1.0, theta=0.0
% INFO    : Bus 22078	: V=0.982236, theta=-25.523009 -> V=1.0, theta=0.0
% INFO    : Bus 22079	: V=0.9268398, theta=-29.735799 -> V=1.0, theta=0.0
% INFO    : Bus 22080	: V=0.9467214, theta=-24.930547 -> V=1.0, theta=0.0
% INFO    : Bus 22081	: V=0.9570387, theta=-25.903963 -> V=1.0, theta=0.0
% INFO    : Bus 22082	: V=0.9558416, theta=-25.18617 -> V=1.0, theta=0.0
% INFO    : Bus 22083	: V=0.9579196, theta=-25.486217 -> V=1.0, theta=0.0
% INFO    : Bus 22084	: V=0.9663106, theta=-24.441683 -> V=1.0, theta=0.0
% INFO    : Bus 22085	: V=0.9583565, theta=-24.867274 -> V=1.0, theta=0.0
% INFO    : Bus 22086	: V=0.9699266, theta=-7.639957 -> V=1.0, theta=0.0
% INFO    : Bus 22087	: V=0.9857154, theta=-4.11607 -> V=1.0, theta=0.0
% INFO    : Bus 22088	: V=1.0024215, theta=-3.869927 -> V=1.0, theta=0.0
% INFO    : Bus 22089	: V=0.9764682, theta=-6.548759 -> V=1.0, theta=0.0
% INFO    : Bus 22090	: V=0.9739995, theta=-7.292865 -> V=1.0, theta=0.0
% INFO    : Bus 22091	: V=0.9772387, theta=-8.002388 -> V=1.0, theta=0.0
% INFO    : Bus 22092	: V=0.9729283, theta=-8.461089 -> V=1.0, theta=0.0
% INFO    : Bus 22093	: V=0.9800726, theta=-7.727631 -> V=1.0, theta=0.0
% INFO    : Bus 22094	: V=0.9270663, theta=-25.351583 -> V=1.0, theta=0.0
% INFO    : Bus 22095	: V=0.9267527, theta=-23.89483 -> V=1.0, theta=0.0
% INFO    : Bus 22096	: V=0.9356538, theta=-20.564007 -> V=1.0, theta=0.0
% INFO    : Bus 22097	: V=0.9275932, theta=-23.869874 -> V=1.0, theta=0.0
% INFO    : Bus 22098	: V=0.9300403, theta=-22.855779 -> V=1.0, theta=0.0
% INFO    : Bus 22099	: V=0.9254079, theta=-25.075417 -> V=1.0, theta=0.0
% INFO    : Bus 22100	: V=0.9230935, theta=-26.681927 -> V=1.0, theta=0.0
% INFO    : Bus 22101	: V=0.9885235, theta=-6.466701 -> V=1.0, theta=0.0
% INFO    : Bus 22102	: V=0.9842097, theta=-6.848888 -> V=1.0, theta=0.0
% INFO    : Bus 22103	: V=0.9731537, theta=-7.147737 -> V=1.0, theta=0.0
% INFO    : Bus 22104	: V=0.9723595, theta=-6.424957 -> V=1.0, theta=0.0
% INFO    : Bus 22105	: V=0.9713587, theta=-7.711319 -> V=1.0, theta=0.0
% INFO    : Bus 22106	: V=1.05, theta=6.313273 -> V=1.0, theta=0.0
% INFO    : Bus 22107	: V=0.9740272, theta=13.015226 -> V=1.0, theta=0.0
% INFO    : Bus 22108	: V=0.9796823, theta=13.37796 -> V=1.0, theta=0.0
% INFO    : Bus 22109	: V=1.0051937, theta=1.631284 -> V=1.0, theta=0.0
% INFO    : Bus 22110	: V=1.0139653, theta=3.284509 -> V=1.0, theta=0.0
% INFO    : Bus 22111	: V=0.9846877, theta=-0.648747 -> V=1.0, theta=0.0
% INFO    : Bus 22112	: V=0.9770747, theta=-1.903628 -> V=1.0, theta=0.0
% INFO    : Bus 22113	: V=0.9821096, theta=-2.147976 -> V=1.0, theta=0.0
% INFO    : Bus 22114	: V=0.9889079, theta=-1.912325 -> V=1.0, theta=0.0
% INFO    : Bus 22115	: V=1.0041092, theta=0.563545 -> V=1.0, theta=0.0
% INFO    : Bus 22116	: V=0.9910966, theta=-1.364442 -> V=1.0, theta=0.0
% INFO    : Bus 22117	: V=1.0007366, theta=0.806001 -> V=1.0, theta=0.0
% INFO    : Bus 22118	: V=1.0009722, theta=0.57533 -> V=1.0, theta=0.0
% INFO    : Bus 22119	: V=0.9976758, theta=-1.667928 -> V=1.0, theta=0.0
% INFO    : Bus 22120	: V=0.9925837, theta=-0.862949 -> V=1.0, theta=0.0
% INFO    : Bus 22121	: V=0.9899401, theta=-1.703149 -> V=1.0, theta=0.0
% INFO    : Bus 22122	: V=0.9985709, theta=-1.008026 -> V=1.0, theta=0.0
% INFO    : Bus 22123	: V=0.9758504, theta=-4.157292 -> V=1.0, theta=0.0
% INFO    : Bus 22124	: V=0.977351, theta=-4.159853 -> V=1.0, theta=0.0
% INFO    : Bus 22125	: V=0.9745158, theta=-5.232965 -> V=1.0, theta=0.0
% INFO    : Bus 22126	: V=0.9723499, theta=-5.379492 -> V=1.0, theta=0.0
% INFO    : Bus 22127	: V=0.9706895, theta=-5.384978 -> V=1.0, theta=0.0
% INFO    : Bus 22128	: V=0.9692623, theta=-5.912615 -> V=1.0, theta=0.0
% INFO    : Bus 22129	: V=1.0075183, theta=2.109996 -> V=1.0, theta=0.0
% INFO    : Bus 22130	: V=1.014815, theta=3.063849 -> V=1.0, theta=0.0
% INFO    : Bus 22131	: V=1.0014645, theta=1.156948 -> V=1.0, theta=0.0
% INFO    : Bus 22132	: V=1.0054333, theta=1.757397 -> V=1.0, theta=0.0
% INFO    : Bus 22133	: V=1.004792, theta=-4.358884 -> V=1.0, theta=0.0
% INFO    : Bus 22134	: V=1.0073788, theta=-3.480982 -> V=1.0, theta=0.0
% INFO    : Bus 22135	: V=1.0051644, theta=-5.253436 -> V=1.0, theta=0.0
% INFO    : Bus 22136	: V=1.0081868, theta=-5.123888 -> V=1.0, theta=0.0
% INFO    : Bus 22137	: V=1.0061981, theta=-5.088977 -> V=1.0, theta=0.0
% INFO    : Bus 22138	: V=1.006248, theta=-5.122007 -> V=1.0, theta=0.0
% INFO    : Bus 22139	: V=1.0047642, theta=-5.015203 -> V=1.0, theta=0.0
% INFO    : Bus 22140	: V=1.0063782, theta=-5.102874 -> V=1.0, theta=0.0
% INFO    : Bus 22141	: V=0.9943558, theta=-5.964736 -> V=1.0, theta=0.0
% INFO    : Bus 22142	: V=0.9501277, theta=-2.169449 -> V=1.0, theta=0.0
% INFO    : Bus 22143	: V=0.962537, theta=-2.466462 -> V=1.0, theta=0.0
% INFO    : Bus 22144	: V=0.9517958, theta=-2.200654 -> V=1.0, theta=0.0
% INFO    : Bus 22145	: V=0.9589657, theta=-2.689564 -> V=1.0, theta=0.0
% INFO    : Bus 22146	: V=0.956497, theta=-2.460998 -> V=1.0, theta=0.0
% INFO    : Bus 22147	: V=0.9560504, theta=-2.120134 -> V=1.0, theta=0.0
% INFO    : Bus 22148	: V=0.9805418, theta=-2.32784 -> V=1.0, theta=0.0
% INFO    : Bus 22149	: V=0.9569731, theta=-7.643968 -> V=1.0, theta=0.0
% INFO    : Bus 22150	: V=0.9703196, theta=-6.761713 -> V=1.0, theta=0.0
% INFO    : Bus 22151	: V=0.9720222, theta=-6.978274 -> V=1.0, theta=0.0
% INFO    : Bus 22152	: V=0.9600808, theta=-7.406738 -> V=1.0, theta=0.0
% INFO    : Bus 22153	: V=0.988887, theta=-6.065487 -> V=1.0, theta=0.0
% INFO    : Bus 22154	: V=0.982252, theta=9.053189 -> V=1.0, theta=0.0
% INFO    : Bus 22155	: V=0.9635036, theta=8.546725 -> V=1.0, theta=0.0
% INFO    : Bus 22156	: V=0.9601969, theta=-5.033399 -> V=1.0, theta=0.0
% INFO    : Bus 22157	: V=0.9653691, theta=-3.751912 -> V=1.0, theta=0.0
% INFO    : Bus 22158	: V=0.965227, theta=-2.744744 -> V=1.0, theta=0.0
% INFO    : Bus 22159	: V=0.9673706, theta=-5.230358 -> V=1.0, theta=0.0
% INFO    : Bus 22160	: V=0.9771482, theta=-2.741011 -> V=1.0, theta=0.0
% INFO    : Bus 22161	: V=0.9628254, theta=-6.749508 -> V=1.0, theta=0.0
% INFO    : Bus 22162	: V=0.9605117, theta=-7.541267 -> V=1.0, theta=0.0
% INFO    : Bus 22163	: V=0.9588236, theta=-8.127627 -> V=1.0, theta=0.0
% INFO    : Bus 22164	: V=0.9582772, theta=-8.719638 -> V=1.0, theta=0.0
% INFO    : Bus 22165	: V=0.9580532, theta=-5.211579 -> V=1.0, theta=0.0
% INFO    : Bus 22166	: V=0.9724482, theta=-3.302924 -> V=1.0, theta=0.0
% INFO    : Bus 22167	: V=1.0010819, theta=-6.48198 -> V=1.0, theta=0.0
% INFO    : Bus 22168	: V=1.0066001, theta=-5.698305 -> V=1.0, theta=0.0
% INFO    : Bus 22169	: V=1.0081701, theta=-5.604967 -> V=1.0, theta=0.0
% INFO    : Bus 22170	: V=1.0070904, theta=-5.669606 -> V=1.0, theta=0.0
% INFO    : Bus 22171	: V=0.9973542, theta=-6.686401 -> V=1.0, theta=0.0
% INFO    : Bus 22172	: V=0.9974923, theta=-6.701241 -> V=1.0, theta=0.0
% INFO    : Bus 22173	: V=0.9963213, theta=-6.825771 -> V=1.0, theta=0.0
% INFO    : Bus 22174	: V=0.9988484, theta=-6.514567 -> V=1.0, theta=0.0
% INFO    : Bus 22175	: V=1.0053964, theta=-5.741339 -> V=1.0, theta=0.0
% INFO    : Bus 22176	: V=1.0100408, theta=-5.48063 -> V=1.0, theta=0.0
% INFO    : Bus 22177	: V=1.007173, theta=-5.937304 -> V=1.0, theta=0.0
% INFO    : Bus 22178	: V=1.0194718, theta=-4.301281 -> V=1.0, theta=0.0
% INFO    : Bus 22179	: V=1.0076494, theta=-5.876447 -> V=1.0, theta=0.0
% INFO    : Bus 22180	: V=0.9953036, theta=-6.826691 -> V=1.0, theta=0.0
% INFO    : Bus 22181	: V=1.003578, theta=-5.793242 -> V=1.0, theta=0.0
% INFO    : Bus 22182	: V=0.9986995, theta=-5.324878 -> V=1.0, theta=0.0
% INFO    : Bus 22183	: V=0.9953225, theta=-6.490932 -> V=1.0, theta=0.0
% INFO    : Bus 22184	: V=1.0043346, theta=-5.802642 -> V=1.0, theta=0.0
% INFO    : Bus 22185	: V=1.0192371, theta=-4.307686 -> V=1.0, theta=0.0
% INFO    : Bus 22186	: V=0.9997639, theta=-6.203426 -> V=1.0, theta=0.0
% INFO    : Bus 22187	: V=0.9963889, theta=-5.547735 -> V=1.0, theta=0.0
% INFO    : Bus 22188	: V=0.9859629, theta=-6.258943 -> V=1.0, theta=0.0
% INFO    : Bus 22189	: V=0.9930806, theta=-5.890931 -> V=1.0, theta=0.0
% INFO    : Bus 22190	: V=0.9811227, theta=-6.360014 -> V=1.0, theta=0.0
% INFO    : Bus 22191	: V=1.0064181, theta=-5.702079 -> V=1.0, theta=0.0
% INFO    : Bus 22192	: V=0.9989202, theta=-6.507277 -> V=1.0, theta=0.0
% INFO    : Bus 22193	: V=0.9669898, theta=0.580162 -> V=1.0, theta=0.0
% INFO    : Bus 22194	: V=0.9705131, theta=1.085602 -> V=1.0, theta=0.0
% INFO    : Bus 22195	: V=0.9672289, theta=1.01299 -> V=1.0, theta=0.0
% INFO    : Bus 22196	: V=0.9683704, theta=1.115049 -> V=1.0, theta=0.0
% INFO    : Bus 22197	: V=0.976596, theta=1.838253 -> V=1.0, theta=0.0
% INFO    : Bus 22198	: V=0.981628, theta=-5.212196 -> V=1.0, theta=0.0
% INFO    : Bus 22199	: V=1.0046118, theta=-3.079998 -> V=1.0, theta=0.0
% INFO    : Bus 22200	: V=0.9813181, theta=-5.187865 -> V=1.0, theta=0.0
% INFO    : Bus 22201	: V=0.9815524, theta=-5.18614 -> V=1.0, theta=0.0
% INFO    : Bus 22202	: V=0.9813458, theta=-5.172914 -> V=1.0, theta=0.0
% INFO    : Bus 22203	: V=0.9885576, theta=-4.582796 -> V=1.0, theta=0.0
% INFO    : Bus 22204	: V=1.0028286, theta=-3.309375 -> V=1.0, theta=0.0
% INFO    : Bus 22205	: V=0.9879885, theta=-4.608253 -> V=1.0, theta=0.0
% INFO    : Bus 22206	: V=0.982183, theta=-5.108268 -> V=1.0, theta=0.0
% INFO    : Bus 22207	: V=0.9928794, theta=-4.147748 -> V=1.0, theta=0.0
% INFO    : Bus 22208	: V=0.9795133, theta=-5.03844 -> V=1.0, theta=0.0
% INFO    : Bus 22209	: V=1.0006821, theta=-3.610574 -> V=1.0, theta=0.0
% INFO    : Bus 22210	: V=0.9809209, theta=-4.933297 -> V=1.0, theta=0.0
% INFO    : Bus 22211	: V=0.9821482, theta=-4.855417 -> V=1.0, theta=0.0
% INFO    : Bus 22212	: V=0.9778638, theta=-5.048621 -> V=1.0, theta=0.0
% INFO    : Bus 22213	: V=0.9841063, theta=-4.921683 -> V=1.0, theta=0.0
% INFO    : Bus 22214	: V=0.9793686, theta=-5.337256 -> V=1.0, theta=0.0
% INFO    : Bus 22215	: V=0.9871821, theta=-4.70423 -> V=1.0, theta=0.0
% INFO    : Bus 22216	: V=0.9802839, theta=-5.234719 -> V=1.0, theta=0.0
% INFO    : Bus 22217	: V=0.9794381, theta=-5.216109 -> V=1.0, theta=0.0
% INFO    : Bus 22218	: V=0.9747049, theta=-5.797967 -> V=1.0, theta=0.0
% INFO    : Bus 22219	: V=0.9790846, theta=-5.187766 -> V=1.0, theta=0.0
% INFO    : Bus 22220	: V=0.9813204, theta=-4.863483 -> V=1.0, theta=0.0
% INFO    : Bus 22221	: V=0.9905419, theta=-4.501362 -> V=1.0, theta=0.0
% INFO    : Bus 22222	: V=1.0030321, theta=-3.214067 -> V=1.0, theta=0.0
% INFO    : Bus 22223	: V=0.9780638, theta=-6.074157 -> V=1.0, theta=0.0
% INFO    : Bus 22224	: V=0.9729963, theta=-5.251778 -> V=1.0, theta=0.0
% INFO    : Bus 22225	: V=0.9792328, theta=-5.439681 -> V=1.0, theta=0.0
% INFO    : Bus 22226	: V=0.9838546, theta=-4.822177 -> V=1.0, theta=0.0
% INFO    : Bus 22227	: V=0.994605, theta=-4.039991 -> V=1.0, theta=0.0
% INFO    : Bus 22228	: V=0.979006, theta=-2.864381 -> V=1.0, theta=0.0
% INFO    : Bus 22229	: V=0.9724646, theta=1.296801 -> V=1.0, theta=0.0
% INFO    : Bus 22230	: V=0.971387, theta=0.581686 -> V=1.0, theta=0.0
% INFO    : Bus 22231	: V=0.9687361, theta=-5.338771 -> V=1.0, theta=0.0
% INFO    : Bus 22232	: V=0.975685, theta=-4.752796 -> V=1.0, theta=0.0
% INFO    : Bus 22233	: V=0.9663438, theta=-7.447375 -> V=1.0, theta=0.0
% INFO    : Bus 22234	: V=0.9700045, theta=-7.255936 -> V=1.0, theta=0.0
% INFO    : Bus 22235	: V=0.9509843, theta=-9.337401 -> V=1.0, theta=0.0
% INFO    : Bus 22236	: V=0.9733959, theta=-6.74976 -> V=1.0, theta=0.0
% INFO    : Bus 22237	: V=0.9352958, theta=-11.860513 -> V=1.0, theta=0.0
% INFO    : Bus 22238	: V=0.9698291, theta=-7.229953 -> V=1.0, theta=0.0
% INFO    : Bus 22239	: V=0.9682523, theta=-7.438522 -> V=1.0, theta=0.0
% INFO    : Bus 22240	: V=0.949373, theta=-11.276188 -> V=1.0, theta=0.0
% INFO    : Bus 22241	: V=0.9502081, theta=-11.221044 -> V=1.0, theta=0.0
% INFO    : Bus 22242	: V=0.9481704, theta=-11.54435 -> V=1.0, theta=0.0
% INFO    : Bus 22243	: V=0.9357251, theta=-12.01595 -> V=1.0, theta=0.0
% INFO    : Bus 22244	: V=0.9823183, theta=-5.141503 -> V=1.0, theta=0.0
% INFO    : Bus 22245	: V=0.9847314, theta=-4.973022 -> V=1.0, theta=0.0
% INFO    : Bus 22246	: V=0.950251, theta=-18.332155 -> V=1.0, theta=0.0
% INFO    : Bus 22247	: V=0.9488159, theta=-13.183538 -> V=1.0, theta=0.0
% INFO    : Bus 22248	: V=0.9433073, theta=-14.20206 -> V=1.0, theta=0.0
% INFO    : Bus 22249	: V=0.9444303, theta=-22.443825 -> V=1.0, theta=0.0
% INFO    : Bus 22250	: V=0.9433326, theta=-19.802904 -> V=1.0, theta=0.0
% INFO    : Bus 22251	: V=0.94194, theta=-22.868348 -> V=1.0, theta=0.0
% INFO    : Bus 22252	: V=0.9356903, theta=-24.375865 -> V=1.0, theta=0.0
% INFO    : Bus 22253	: V=0.930541, theta=-17.089591 -> V=1.0, theta=0.0
% INFO    : Bus 22254	: V=0.9458856, theta=-19.692383 -> V=1.0, theta=0.0
% INFO    : Bus 22255	: V=0.9485752, theta=-17.225222 -> V=1.0, theta=0.0
% INFO    : Bus 22256	: V=0.9478549, theta=-18.966603 -> V=1.0, theta=0.0
% INFO    : Bus 22257	: V=0.967567, theta=-14.772553 -> V=1.0, theta=0.0
% INFO    : Bus 22258	: V=0.9526019, theta=-11.352647 -> V=1.0, theta=0.0
% INFO    : Bus 22259	: V=0.9561519, theta=-10.141076 -> V=1.0, theta=0.0
% INFO    : Bus 22260	: V=0.9530573, theta=-11.246262 -> V=1.0, theta=0.0
% INFO    : Bus 22261	: V=0.9524582, theta=-11.276371 -> V=1.0, theta=0.0
% INFO    : Bus 22262	: V=0.9521582, theta=-11.516583 -> V=1.0, theta=0.0
% INFO    : Bus 22263	: V=0.9533442, theta=-11.032608 -> V=1.0, theta=0.0
% INFO    : Bus 22264	: V=0.9541388, theta=-11.009632 -> V=1.0, theta=0.0
% INFO    : Bus 22265	: V=0.9568334, theta=-10.052148 -> V=1.0, theta=0.0
% INFO    : Bus 22266	: V=0.9579108, theta=-9.888091 -> V=1.0, theta=0.0
% INFO    : Bus 22267	: V=0.9561699, theta=-10.692033 -> V=1.0, theta=0.0
% INFO    : Bus 22268	: V=0.9535376, theta=-11.167822 -> V=1.0, theta=0.0
% INFO    : Bus 22269	: V=0.959587, theta=-9.933257 -> V=1.0, theta=0.0
% INFO    : Bus 22270	: V=0.9517284, theta=-11.756831 -> V=1.0, theta=0.0
% INFO    : Bus 22271	: V=0.9529936, theta=-11.423901 -> V=1.0, theta=0.0
% INFO    : Bus 22272	: V=0.9521251, theta=-11.446454 -> V=1.0, theta=0.0
% INFO    : Bus 22273	: V=0.9514484, theta=-12.135074 -> V=1.0, theta=0.0
% INFO    : Bus 22274	: V=0.9507925, theta=-11.896594 -> V=1.0, theta=0.0
% INFO    : Bus 22275	: V=0.9505631, theta=-12.135559 -> V=1.0, theta=0.0
% INFO    : Bus 22276	: V=0.9516698, theta=-11.608182 -> V=1.0, theta=0.0
% INFO    : Bus 22277	: V=0.9526238, theta=-11.050362 -> V=1.0, theta=0.0
% INFO    : Bus 22278	: V=0.9514592, theta=-11.088555 -> V=1.0, theta=0.0
% INFO    : Bus 22279	: V=0.9538543, theta=-10.843876 -> V=1.0, theta=0.0
% INFO    : Bus 22280	: V=0.9596822, theta=-9.317746 -> V=1.0, theta=0.0
% INFO    : Bus 22281	: V=0.9706629, theta=-8.56636 -> V=1.0, theta=0.0
% INFO    : Bus 22282	: V=0.9493773, theta=-12.846729 -> V=1.0, theta=0.0
% INFO    : Bus 22283	: V=0.9545439, theta=-12.23415 -> V=1.0, theta=0.0
% INFO    : Bus 22284	: V=0.9506955, theta=-15.445934 -> V=1.0, theta=0.0
% INFO    : Bus 22285	: V=0.9527934, theta=-16.307597 -> V=1.0, theta=0.0
% INFO    : Bus 22286	: V=0.9599618, theta=-18.742557 -> V=1.0, theta=0.0
% INFO    : Bus 22287	: V=0.9546133, theta=-16.787828 -> V=1.0, theta=0.0
% INFO    : Bus 22288	: V=0.9564721, theta=-16.700196 -> V=1.0, theta=0.0
% INFO    : Bus 22289	: V=0.9550445, theta=-16.738724 -> V=1.0, theta=0.0
% INFO    : Bus 22290	: V=0.9585689, theta=-16.98531 -> V=1.0, theta=0.0
% INFO    : Bus 22291	: V=0.9541542, theta=-15.064691 -> V=1.0, theta=0.0
% INFO    : Bus 22292	: V=0.9585528, theta=-11.159503 -> V=1.0, theta=0.0
% INFO    : Bus 22293	: V=0.9547904, theta=-12.758391 -> V=1.0, theta=0.0
% INFO    : Bus 22294	: V=0.9532193, theta=-13.679805 -> V=1.0, theta=0.0
% INFO    : Bus 22295	: V=0.9533066, theta=-13.840678 -> V=1.0, theta=0.0
% INFO    : Bus 22296	: V=0.9596038, theta=-10.024853 -> V=1.0, theta=0.0
% INFO    : Bus 22297	: V=0.9292295, theta=-15.747368 -> V=1.0, theta=0.0
% INFO    : Bus 22298	: V=0.9321397, theta=-15.381374 -> V=1.0, theta=0.0
% INFO    : Bus 22299	: V=0.9377624, theta=-14.229053 -> V=1.0, theta=0.0
% INFO    : Bus 22300	: V=0.9474587, theta=-11.637406 -> V=1.0, theta=0.0
% INFO    : Bus 22301	: V=0.9514736, theta=-10.759833 -> V=1.0, theta=0.0
% INFO    : Bus 22302	: V=0.9503447, theta=-10.63022 -> V=1.0, theta=0.0
% INFO    : Bus 22303	: V=0.9442673, theta=-12.343765 -> V=1.0, theta=0.0
% INFO    : Bus 22304	: V=0.9719522, theta=-7.312604 -> V=1.0, theta=0.0
% INFO    : Bus 22305	: V=0.9653166, theta=-8.483341 -> V=1.0, theta=0.0
% INFO    : Bus 22306	: V=0.9520058, theta=-10.634488 -> V=1.0, theta=0.0
% INFO    : Bus 22307	: V=0.9351755, theta=-10.587206 -> V=1.0, theta=0.0
% INFO    : Bus 22308	: V=0.994052, theta=-0.72403 -> V=1.0, theta=0.0
% INFO    : Bus 22309	: V=0.9842663, theta=-0.741268 -> V=1.0, theta=0.0
% INFO    : Bus 22310	: V=0.954052, theta=-2.090359 -> V=1.0, theta=0.0
% INFO    : Bus 22311	: V=0.9665662, theta=-0.324852 -> V=1.0, theta=0.0
% INFO    : Bus 22312	: V=0.9780998, theta=3.98948 -> V=1.0, theta=0.0
% INFO    : Bus 22313	: V=0.9505235, theta=-1.947633 -> V=1.0, theta=0.0
% INFO    : Bus 22314	: V=0.9534175, theta=-1.749479 -> V=1.0, theta=0.0
% INFO    : Bus 22315	: V=0.9475772, theta=-2.386096 -> V=1.0, theta=0.0
% INFO    : Bus 22316	: V=0.9483823, theta=-2.362482 -> V=1.0, theta=0.0
% INFO    : Bus 22317	: V=0.9578989, theta=-2.183497 -> V=1.0, theta=0.0
% INFO    : Bus 22318	: V=0.9527665, theta=-2.348549 -> V=1.0, theta=0.0
% INFO    : Bus 22319	: V=0.9518946, theta=-2.365182 -> V=1.0, theta=0.0
% INFO    : Bus 22320	: V=0.9676509, theta=0.205945 -> V=1.0, theta=0.0
% INFO    : Bus 22321	: V=0.9654044, theta=-1.780881 -> V=1.0, theta=0.0
% INFO    : Bus 22322	: V=0.9565685, theta=-1.980516 -> V=1.0, theta=0.0
% INFO    : Bus 22323	: V=0.9586955, theta=-2.059431 -> V=1.0, theta=0.0
% INFO    : Bus 22324	: V=0.9763041, theta=-1.872049 -> V=1.0, theta=0.0
% INFO    : Bus 22325	: V=0.9758927, theta=-1.607428 -> V=1.0, theta=0.0
% INFO    : Bus 22326	: V=0.9712759, theta=-1.852888 -> V=1.0, theta=0.0
% INFO    : Bus 22327	: V=1.0003864, theta=-0.960161 -> V=1.0, theta=0.0
% INFO    : Bus 22328	: V=0.9979047, theta=-1.508699 -> V=1.0, theta=0.0
% INFO    : Bus 22329	: V=1.0128182, theta=6.293914 -> V=1.0, theta=0.0
% INFO    : Bus 22330	: V=1.0171854, theta=6.303034 -> V=1.0, theta=0.0
% INFO    : Bus 22331	: V=1.0190441, theta=6.372988 -> V=1.0, theta=0.0
% INFO    : Bus 22332	: V=1.0184417, theta=6.373563 -> V=1.0, theta=0.0
% INFO    : Bus 22333	: V=1.0123119, theta=5.741462 -> V=1.0, theta=0.0
% INFO    : Bus 22334	: V=0.9932251, theta=3.963688 -> V=1.0, theta=0.0
% INFO    : Bus 22335	: V=0.9959368, theta=4.64412 -> V=1.0, theta=0.0
% INFO    : Bus 22336	: V=0.9777643, theta=3.290848 -> V=1.0, theta=0.0
% INFO    : Bus 22337	: V=1.0016147, theta=5.074398 -> V=1.0, theta=0.0
% INFO    : Bus 22338	: V=0.9765087, theta=1.683917 -> V=1.0, theta=0.0
% INFO    : Bus 22339	: V=0.9676644, theta=1.491104 -> V=1.0, theta=0.0
% INFO    : Bus 22340	: V=0.9881271, theta=3.313671 -> V=1.0, theta=0.0
% INFO    : Bus 22341	: V=0.9661767, theta=-4.393595 -> V=1.0, theta=0.0
% INFO    : Bus 22342	: V=0.9648815, theta=-3.273082 -> V=1.0, theta=0.0
% INFO    : Bus 22343	: V=0.9686397, theta=-3.186382 -> V=1.0, theta=0.0
% INFO    : Bus 22344	: V=0.9877274, theta=-1.864103 -> V=1.0, theta=0.0
% INFO    : Bus 22345	: V=0.9855437, theta=-1.867077 -> V=1.0, theta=0.0
% INFO    : Bus 22346	: V=0.9739409, theta=-3.527816 -> V=1.0, theta=0.0
% INFO    : Bus 22347	: V=0.9765736, theta=-2.449725 -> V=1.0, theta=0.0
% INFO    : Bus 22348	: V=0.9783823, theta=-4.610971 -> V=1.0, theta=0.0
% INFO    : Bus 22349	: V=0.9651503, theta=-4.260855 -> V=1.0, theta=0.0
% INFO    : Bus 22350	: V=0.9645499, theta=-3.794725 -> V=1.0, theta=0.0
% INFO    : Bus 22351	: V=0.9654725, theta=-4.105433 -> V=1.0, theta=0.0
% INFO    : Bus 22352	: V=0.9839257, theta=-7.369141 -> V=1.0, theta=0.0
% INFO    : Bus 22353	: V=0.9907573, theta=-5.948867 -> V=1.0, theta=0.0
% INFO    : Bus 22354	: V=0.9899219, theta=-6.038294 -> V=1.0, theta=0.0
% INFO    : Bus 22355	: V=0.9902713, theta=-6.01355 -> V=1.0, theta=0.0
% INFO    : Bus 22356	: V=0.9786142, theta=-7.579051 -> V=1.0, theta=0.0
% INFO    : Bus 22357	: V=0.9796142, theta=-7.570122 -> V=1.0, theta=0.0
% INFO    : Bus 22358	: V=0.9901512, theta=-6.049145 -> V=1.0, theta=0.0
% INFO    : Bus 22359	: V=0.9870655, theta=-5.840279 -> V=1.0, theta=0.0
% INFO    : Bus 22360	: V=0.970527, theta=-5.93766 -> V=1.0, theta=0.0
% INFO    : Bus 22361	: V=0.9873341, theta=-4.903615 -> V=1.0, theta=0.0
% INFO    : Bus 22362	: V=1.0027478, theta=-3.8335 -> V=1.0, theta=0.0
% INFO    : Bus 22363	: V=1.0018135, theta=-4.431351 -> V=1.0, theta=0.0
% INFO    : Bus 22364	: V=0.9876357, theta=-6.430433 -> V=1.0, theta=0.0
% INFO    : Bus 22365	: V=1.0161619, theta=-2.599065 -> V=1.0, theta=0.0
% INFO    : Bus 22366	: V=0.9999863, theta=-4.891615 -> V=1.0, theta=0.0
% INFO    : Bus 22367	: V=0.9945051, theta=-5.693686 -> V=1.0, theta=0.0
% INFO    : Bus 22368	: V=0.9940619, theta=-5.551535 -> V=1.0, theta=0.0
% INFO    : Bus 22369	: V=0.9923793, theta=-6.009336 -> V=1.0, theta=0.0
% INFO    : Bus 22370	: V=0.9870343, theta=-6.608316 -> V=1.0, theta=0.0
% INFO    : Bus 22371	: V=0.9828216, theta=-7.10079 -> V=1.0, theta=0.0
% INFO    : Bus 22372	: V=0.9817689, theta=-7.209822 -> V=1.0, theta=0.0
% INFO    : Bus 22373	: V=0.9775864, theta=-7.943873 -> V=1.0, theta=0.0
% INFO    : Bus 22374	: V=0.9888, theta=-3.794424 -> V=1.0, theta=0.0
% INFO    : Bus 22375	: V=0.9805734, theta=-3.019188 -> V=1.0, theta=0.0
% INFO    : Bus 22376	: V=0.9846862, theta=-3.833159 -> V=1.0, theta=0.0
% INFO    : Bus 22377	: V=0.9845035, theta=-4.053459 -> V=1.0, theta=0.0
% INFO    : Bus 22378	: V=0.9858411, theta=-2.35853 -> V=1.0, theta=0.0
% INFO    : Bus 22379	: V=0.982514, theta=16.606208 -> V=1.0, theta=0.0
% INFO    : Bus 22380	: V=0.9888385, theta=18.41604 -> V=1.0, theta=0.0
% INFO    : Bus 22381	: V=0.9870336, theta=18.274032 -> V=1.0, theta=0.0
% INFO    : Bus 22382	: V=0.9909079, theta=21.700449 -> V=1.0, theta=0.0
% INFO    : Bus 22383	: V=0.9760632, theta=24.202408 -> V=1.0, theta=0.0
% INFO    : Bus 22384	: V=0.9869436, theta=21.818571 -> V=1.0, theta=0.0
% INFO    : Bus 22385	: V=0.9744745, theta=22.460855 -> V=1.0, theta=0.0
% INFO    : Bus 22386	: V=0.9866813, theta=22.663766 -> V=1.0, theta=0.0
% INFO    : Bus 22387	: V=0.9824957, theta=22.641312 -> V=1.0, theta=0.0
% INFO    : Bus 22388	: V=0.9820642, theta=22.640709 -> V=1.0, theta=0.0
% INFO    : Bus 22389	: V=0.9799339, theta=22.689068 -> V=1.0, theta=0.0
% INFO    : Bus 22390	: V=0.9396296, theta=17.573992 -> V=1.0, theta=0.0
% INFO    : Bus 22391	: V=0.9567152, theta=17.788372 -> V=1.0, theta=0.0
% INFO    : Bus 22392	: V=0.9720283, theta=17.786994 -> V=1.0, theta=0.0
% INFO    : Bus 22393	: V=0.959046, theta=16.018437 -> V=1.0, theta=0.0
% INFO    : Bus 22394	: V=0.9561519, theta=15.737494 -> V=1.0, theta=0.0
% INFO    : Bus 22395	: V=0.9547918, theta=15.671603 -> V=1.0, theta=0.0
% INFO    : Bus 22396	: V=0.9556663, theta=15.419136 -> V=1.0, theta=0.0
% INFO    : Bus 22397	: V=0.9798724, theta=-7.235253 -> V=1.0, theta=0.0
% INFO    : Bus 22398	: V=0.9781524, theta=-7.39724 -> V=1.0, theta=0.0
% INFO    : Bus 22399	: V=0.9786902, theta=-7.319318 -> V=1.0, theta=0.0
% INFO    : Bus 22400	: V=0.9792616, theta=-7.421651 -> V=1.0, theta=0.0
% INFO    : Bus 22401	: V=0.977727, theta=-7.39654 -> V=1.0, theta=0.0
% INFO    : Bus 22402	: V=0.994241, theta=-6.114718 -> V=1.0, theta=0.0
% INFO    : Bus 22403	: V=0.973388, theta=-7.128679 -> V=1.0, theta=0.0
% INFO    : Bus 22404	: V=0.9774777, theta=-7.361017 -> V=1.0, theta=0.0
% INFO    : Bus 22405	: V=0.9762116, theta=-7.41352 -> V=1.0, theta=0.0
% INFO    : Bus 22406	: V=0.9705406, theta=-6.987006 -> V=1.0, theta=0.0
% INFO    : Bus 22407	: V=0.9697641, theta=-6.987592 -> V=1.0, theta=0.0
% INFO    : Bus 22408	: V=0.9706174, theta=-6.869686 -> V=1.0, theta=0.0
% INFO    : Bus 22409	: V=0.9728589, theta=-6.262732 -> V=1.0, theta=0.0
% INFO    : Bus 22410	: V=0.9723391, theta=-7.883804 -> V=1.0, theta=0.0
% INFO    : Bus 22411	: V=0.9728636, theta=-6.85082 -> V=1.0, theta=0.0
% INFO    : Bus 22412	: V=0.9720833, theta=-5.795288 -> V=1.0, theta=0.0
% INFO    : Bus 22413	: V=0.9590698, theta=-9.26996 -> V=1.0, theta=0.0
% INFO    : Bus 22414	: V=0.9737211, theta=-7.402828 -> V=1.0, theta=0.0
% INFO    : Bus 22415	: V=0.9721229, theta=-7.65372 -> V=1.0, theta=0.0
% INFO    : Bus 22416	: V=0.9665265, theta=-8.403069 -> V=1.0, theta=0.0
% INFO    : Bus 22417	: V=0.9654755, theta=-8.624955 -> V=1.0, theta=0.0
% INFO    : Bus 22418	: V=0.9648789, theta=-9.287059 -> V=1.0, theta=0.0
% INFO    : Bus 22419	: V=0.9650898, theta=-8.868126 -> V=1.0, theta=0.0
% INFO    : Bus 22420	: V=0.9607364, theta=-10.50527 -> V=1.0, theta=0.0
% INFO    : Bus 22421	: V=0.9628288, theta=-9.437204 -> V=1.0, theta=0.0
% INFO    : Bus 22422	: V=0.9616201, theta=-9.746741 -> V=1.0, theta=0.0
% INFO    : Bus 22423	: V=0.9895863, theta=-6.396442 -> V=1.0, theta=0.0
% INFO    : Bus 22424	: V=0.9746855, theta=-8.055395 -> V=1.0, theta=0.0
% INFO    : Bus 22425	: V=0.9707778, theta=-1.642758 -> V=1.0, theta=0.0
% INFO    : Bus 22426	: V=0.9640047, theta=-1.770864 -> V=1.0, theta=0.0
% INFO    : Bus 22427	: V=0.9616555, theta=-1.696842 -> V=1.0, theta=0.0
% INFO    : Bus 22428	: V=0.9607887, theta=-1.837652 -> V=1.0, theta=0.0
% INFO    : Bus 22429	: V=0.9696178, theta=-2.125523 -> V=1.0, theta=0.0
% INFO    : Bus 22430	: V=0.9742858, theta=-0.750663 -> V=1.0, theta=0.0
% INFO    : Bus 22431	: V=0.9633566, theta=-1.774876 -> V=1.0, theta=0.0
% INFO    : Bus 22432	: V=0.9548293, theta=-1.728349 -> V=1.0, theta=0.0
% INFO    : Bus 22433	: V=0.9839481, theta=-12.196276 -> V=1.0, theta=0.0
% INFO    : Bus 22434	: V=0.9845807, theta=-12.273356 -> V=1.0, theta=0.0
% INFO    : Bus 22435	: V=0.9853766, theta=-12.057434 -> V=1.0, theta=0.0
% INFO    : Bus 22436	: V=0.9845495, theta=-12.301824 -> V=1.0, theta=0.0
% INFO    : Bus 22437	: V=0.9838574, theta=-12.236256 -> V=1.0, theta=0.0
% INFO    : Bus 22438	: V=0.9901639, theta=-12.268483 -> V=1.0, theta=0.0
% INFO    : Bus 22439	: V=0.9847324, theta=-12.183452 -> V=1.0, theta=0.0
% INFO    : Bus 22440	: V=0.9837787, theta=-12.387318 -> V=1.0, theta=0.0
% INFO    : Bus 22441	: V=0.9843107, theta=-12.281435 -> V=1.0, theta=0.0
% INFO    : Bus 22442	: V=0.9841452, theta=-12.360584 -> V=1.0, theta=0.0
% INFO    : Bus 22443	: V=0.9840618, theta=-12.412169 -> V=1.0, theta=0.0
% INFO    : Bus 22444	: V=0.9767075, theta=-12.733448 -> V=1.0, theta=0.0
% INFO    : Bus 22445	: V=0.9775784, theta=-12.420239 -> V=1.0, theta=0.0
% INFO    : Bus 22446	: V=0.9815524, theta=-12.565482 -> V=1.0, theta=0.0
% INFO    : Bus 22447	: V=0.9767647, theta=-12.553221 -> V=1.0, theta=0.0
% INFO    : Bus 22448	: V=0.9772038, theta=-12.483769 -> V=1.0, theta=0.0
% INFO    : Bus 22449	: V=0.9933927, theta=-12.121691 -> V=1.0, theta=0.0
% INFO    : Bus 22450	: V=0.9907654, theta=-12.394838 -> V=1.0, theta=0.0
% INFO    : Bus 22451	: V=0.990832, theta=-12.396523 -> V=1.0, theta=0.0
% INFO    : Bus 22452	: V=0.9904663, theta=-12.269287 -> V=1.0, theta=0.0
% INFO    : Bus 22453	: V=0.9869726, theta=-12.46946 -> V=1.0, theta=0.0
% INFO    : Bus 22454	: V=0.982048, theta=-12.740162 -> V=1.0, theta=0.0
% INFO    : Bus 22455	: V=0.9906544, theta=-12.39163 -> V=1.0, theta=0.0
% INFO    : Bus 22456	: V=0.9841055, theta=-12.584894 -> V=1.0, theta=0.0
% INFO    : Bus 22457	: V=0.9884002, theta=-12.576739 -> V=1.0, theta=0.0
% INFO    : Bus 22458	: V=0.9763692, theta=-12.59505 -> V=1.0, theta=0.0
% INFO    : Bus 22459	: V=0.9788295, theta=-12.941537 -> V=1.0, theta=0.0
% INFO    : Bus 22460	: V=0.9821216, theta=-12.786926 -> V=1.0, theta=0.0
% INFO    : Bus 22461	: V=0.9856238, theta=-12.982502 -> V=1.0, theta=0.0
% INFO    : Bus 22462	: V=0.9800049, theta=-12.994554 -> V=1.0, theta=0.0
% INFO    : Bus 22463	: V=0.9786672, theta=-13.200505 -> V=1.0, theta=0.0
% INFO    : Bus 22464	: V=0.9738706, theta=-13.590893 -> V=1.0, theta=0.0
% INFO    : Bus 22465	: V=0.9774314, theta=-13.35717 -> V=1.0, theta=0.0
% INFO    : Bus 22466	: V=0.9750072, theta=-12.925002 -> V=1.0, theta=0.0
% INFO    : Bus 22467	: V=0.9762714, theta=-12.922653 -> V=1.0, theta=0.0
% INFO    : Bus 22468	: V=0.9761879, theta=-12.629201 -> V=1.0, theta=0.0
% INFO    : Bus 22469	: V=0.974812, theta=-13.299223 -> V=1.0, theta=0.0
% INFO    : Bus 22470	: V=0.9907527, theta=-10.604057 -> V=1.0, theta=0.0
% INFO    : Bus 22471	: V=0.9917086, theta=-10.264084 -> V=1.0, theta=0.0
% INFO    : Bus 22472	: V=0.990511, theta=-10.583031 -> V=1.0, theta=0.0
% INFO    : Bus 22473	: V=0.9900398, theta=-10.83362 -> V=1.0, theta=0.0
% INFO    : Bus 22474	: V=0.9876779, theta=-10.659526 -> V=1.0, theta=0.0
% INFO    : Bus 22475	: V=0.9888835, theta=-11.115028 -> V=1.0, theta=0.0
% INFO    : Bus 22476	: V=0.9900043, theta=-10.25538 -> V=1.0, theta=0.0
% INFO    : Bus 22477	: V=0.9868945, theta=-10.660874 -> V=1.0, theta=0.0
% INFO    : Bus 22478	: V=0.9860504, theta=-11.861369 -> V=1.0, theta=0.0
% INFO    : Bus 22479	: V=0.9865438, theta=-11.688296 -> V=1.0, theta=0.0
% INFO    : Bus 22480	: V=0.9784746, theta=-12.10035 -> V=1.0, theta=0.0
% INFO    : Bus 22481	: V=0.9791897, theta=-11.857854 -> V=1.0, theta=0.0
% INFO    : Bus 22482	: V=0.9839183, theta=-11.392044 -> V=1.0, theta=0.0
% INFO    : Bus 22483	: V=0.9873398, theta=-11.503199 -> V=1.0, theta=0.0
% INFO    : Bus 22484	: V=0.9808878, theta=-11.531668 -> V=1.0, theta=0.0
% INFO    : Bus 22485	: V=0.9758335, theta=-12.342256 -> V=1.0, theta=0.0
% INFO    : Bus 22486	: V=0.9830317, theta=-11.082824 -> V=1.0, theta=0.0
% INFO    : Bus 22487	: V=0.9740067, theta=-11.179289 -> V=1.0, theta=0.0
% INFO    : Bus 22488	: V=0.9768697, theta=-12.256804 -> V=1.0, theta=0.0
% INFO    : Bus 22489	: V=0.9783837, theta=-12.467168 -> V=1.0, theta=0.0
% INFO    : Bus 22490	: V=0.977976, theta=-12.312979 -> V=1.0, theta=0.0
% INFO    : Bus 22491	: V=0.9746836, theta=-12.647899 -> V=1.0, theta=0.0
% INFO    : Bus 22492	: V=0.9698605, theta=-13.066447 -> V=1.0, theta=0.0
% INFO    : Bus 22493	: V=0.9732494, theta=-12.915318 -> V=1.0, theta=0.0
% INFO    : Bus 22494	: V=0.9728046, theta=-13.01068 -> V=1.0, theta=0.0
% INFO    : Bus 22495	: V=0.9711493, theta=-13.666005 -> V=1.0, theta=0.0
% INFO    : Bus 22496	: V=0.9733103, theta=-15.205855 -> V=1.0, theta=0.0
% INFO    : Bus 22497	: V=0.9701244, theta=-15.130808 -> V=1.0, theta=0.0
% INFO    : Bus 22498	: V=0.9756469, theta=-14.689281 -> V=1.0, theta=0.0
% INFO    : Bus 22499	: V=0.9699649, theta=-14.905394 -> V=1.0, theta=0.0
% INFO    : Bus 22500	: V=0.9717176, theta=-14.530127 -> V=1.0, theta=0.0
% INFO    : Bus 22501	: V=0.9727747, theta=-14.17692 -> V=1.0, theta=0.0
% INFO    : Bus 22502	: V=0.9781357, theta=-14.213287 -> V=1.0, theta=0.0
% INFO    : Bus 22503	: V=0.9691731, theta=-15.020139 -> V=1.0, theta=0.0
% INFO    : Bus 22504	: V=0.9740874, theta=-13.831491 -> V=1.0, theta=0.0
% INFO    : Bus 22505	: V=0.9756653, theta=-13.605205 -> V=1.0, theta=0.0
% INFO    : Bus 22506	: V=0.9810275, theta=-13.674918 -> V=1.0, theta=0.0
% INFO    : Bus 22507	: V=0.9763094, theta=-13.656654 -> V=1.0, theta=0.0
% INFO    : Bus 22508	: V=0.9803394, theta=-13.512917 -> V=1.0, theta=0.0
% INFO    : Bus 22509	: V=0.9792586, theta=-13.513231 -> V=1.0, theta=0.0
% INFO    : Bus 22510	: V=0.9829693, theta=-13.213703 -> V=1.0, theta=0.0
% INFO    : Bus 22511	: V=0.9793112, theta=-13.495908 -> V=1.0, theta=0.0
% INFO    : Bus 22512	: V=0.973043, theta=-14.561305 -> V=1.0, theta=0.0
% INFO    : Bus 22513	: V=0.9764303, theta=-14.030833 -> V=1.0, theta=0.0
% INFO    : Bus 22514	: V=0.9773834, theta=-13.926152 -> V=1.0, theta=0.0
% INFO    : Bus 22515	: V=0.9783615, theta=-13.917809 -> V=1.0, theta=0.0
% INFO    : Bus 22516	: V=0.9795016, theta=-13.761096 -> V=1.0, theta=0.0
% INFO    : Bus 22517	: V=0.97819, theta=-13.938072 -> V=1.0, theta=0.0
% INFO    : Bus 22518	: V=0.9804562, theta=-13.82737 -> V=1.0, theta=0.0
% INFO    : Bus 22519	: V=0.9843755, theta=-13.564839 -> V=1.0, theta=0.0
% INFO    : Bus 22520	: V=0.9914913, theta=-12.998847 -> V=1.0, theta=0.0
% INFO    : Bus 22521	: V=0.9818218, theta=-13.440642 -> V=1.0, theta=0.0
% INFO    : Bus 22522	: V=1.0059984, theta=-11.273987 -> V=1.0, theta=0.0
% INFO    : Bus 22523	: V=0.9927379, theta=-12.214761 -> V=1.0, theta=0.0
% INFO    : Bus 22524	: V=0.9987523, theta=-11.779527 -> V=1.0, theta=0.0
% INFO    : Bus 22525	: V=0.9954867, theta=-12.234942 -> V=1.0, theta=0.0
% INFO    : Bus 22526	: V=0.9974667, theta=-12.120096 -> V=1.0, theta=0.0
% INFO    : Bus 22527	: V=1.0113128, theta=-10.839611 -> V=1.0, theta=0.0
% INFO    : Bus 22528	: V=0.989495, theta=-11.819295 -> V=1.0, theta=0.0
% INFO    : Bus 22529	: V=0.9961997, theta=-11.96074 -> V=1.0, theta=0.0
% INFO    : Bus 22530	: V=0.9900402, theta=-11.649489 -> V=1.0, theta=0.0
% INFO    : Bus 22531	: V=0.9897075, theta=-11.725513 -> V=1.0, theta=0.0
% INFO    : Bus 22532	: V=0.9884717, theta=-11.897891 -> V=1.0, theta=0.0
% INFO    : Bus 22533	: V=0.9861789, theta=-12.330969 -> V=1.0, theta=0.0
% INFO    : Bus 22534	: V=1.0011474, theta=-11.503776 -> V=1.0, theta=0.0
% INFO    : Bus 22535	: V=0.9984669, theta=-11.14844 -> V=1.0, theta=0.0
% INFO    : Bus 22536	: V=0.9924919, theta=-11.137158 -> V=1.0, theta=0.0
% INFO    : Bus 22537	: V=0.9935526, theta=-9.114698 -> V=1.0, theta=0.0
% INFO    : Bus 22538	: V=0.9902832, theta=-9.437524 -> V=1.0, theta=0.0
% INFO    : Bus 22539	: V=0.9915179, theta=-9.679842 -> V=1.0, theta=0.0
% INFO    : Bus 22540	: V=0.9612577, theta=-13.536975 -> V=1.0, theta=0.0
% INFO    : Bus 22541	: V=0.9703885, theta=-12.803628 -> V=1.0, theta=0.0
% INFO    : Bus 22542	: V=0.972694, theta=-12.77918 -> V=1.0, theta=0.0
% INFO    : Bus 22543	: V=0.9597882, theta=-13.559159 -> V=1.0, theta=0.0
% INFO    : Bus 22544	: V=0.9661501, theta=-14.041767 -> V=1.0, theta=0.0
% INFO    : Bus 22545	: V=0.9689801, theta=-13.64278 -> V=1.0, theta=0.0
% INFO    : Bus 22546	: V=0.9698191, theta=-13.789194 -> V=1.0, theta=0.0
% INFO    : Bus 22547	: V=0.9669695, theta=-14.386243 -> V=1.0, theta=0.0
% INFO    : Bus 22548	: V=0.9671434, theta=-14.116348 -> V=1.0, theta=0.0
% INFO    : Bus 22549	: V=0.9596204, theta=-14.962048 -> V=1.0, theta=0.0
% INFO    : Bus 22550	: V=0.9621994, theta=-15.034397 -> V=1.0, theta=0.0
% INFO    : Bus 22551	: V=0.9649195, theta=-14.529858 -> V=1.0, theta=0.0
% INFO    : Bus 22552	: V=0.9633567, theta=-14.836929 -> V=1.0, theta=0.0
% INFO    : Bus 22553	: V=0.9593137, theta=-15.524219 -> V=1.0, theta=0.0
% INFO    : Bus 22554	: V=0.9623581, theta=-15.056866 -> V=1.0, theta=0.0
% INFO    : Bus 22555	: V=0.962004, theta=-15.285017 -> V=1.0, theta=0.0
% INFO    : Bus 22556	: V=0.9612017, theta=-15.479124 -> V=1.0, theta=0.0
% INFO    : Bus 22557	: V=0.9641726, theta=-14.888091 -> V=1.0, theta=0.0
% INFO    : Bus 22558	: V=0.9680986, theta=-15.328432 -> V=1.0, theta=0.0
% INFO    : Bus 22559	: V=0.9672694, theta=-15.520448 -> V=1.0, theta=0.0
% INFO    : Bus 22560	: V=0.9739391, theta=-13.30386 -> V=1.0, theta=0.0
% INFO    : Bus 22561	: V=0.9840059, theta=-12.478769 -> V=1.0, theta=0.0
% INFO    : Bus 22562	: V=0.9717366, theta=-13.236123 -> V=1.0, theta=0.0
% INFO    : Bus 22563	: V=0.9895734, theta=-12.349912 -> V=1.0, theta=0.0
% INFO    : Bus 22564	: V=0.9682256, theta=-5.416994 -> V=1.0, theta=0.0
% INFO    : Bus 22565	: V=0.970838, theta=-5.90967 -> V=1.0, theta=0.0
% INFO    : Bus 22566	: V=0.973407, theta=-6.023666 -> V=1.0, theta=0.0
% INFO    : Bus 22567	: V=0.9681843, theta=-5.154883 -> V=1.0, theta=0.0
% INFO    : Bus 22568	: V=0.9684137, theta=-5.710659 -> V=1.0, theta=0.0
% INFO    : Bus 22569	: V=0.9720907, theta=-5.873496 -> V=1.0, theta=0.0
% INFO    : Bus 22570	: V=0.9674052, theta=-5.436827 -> V=1.0, theta=0.0
% INFO    : Bus 22571	: V=0.981398, theta=-4.821844 -> V=1.0, theta=0.0
% INFO    : Bus 22572	: V=0.9784445, theta=-5.954379 -> V=1.0, theta=0.0
% INFO    : Bus 22573	: V=0.9651607, theta=8.731606 -> V=1.0, theta=0.0
% INFO    : Bus 22574	: V=0.9909298, theta=8.404923 -> V=1.0, theta=0.0
% INFO    : Bus 22575	: V=0.9645806, theta=6.623377 -> V=1.0, theta=0.0
% INFO    : Bus 22576	: V=0.981597, theta=7.801095 -> V=1.0, theta=0.0
% INFO    : Bus 22577	: V=0.961873, theta=6.663603 -> V=1.0, theta=0.0
% INFO    : Bus 22578	: V=0.9600303, theta=6.64523 -> V=1.0, theta=0.0
% INFO    : Bus 22579	: V=0.9744485, theta=6.969044 -> V=1.0, theta=0.0
% INFO    : Bus 22580	: V=0.9697362, theta=-0.830881 -> V=1.0, theta=0.0
% INFO    : Bus 22581	: V=0.9611553, theta=-1.275833 -> V=1.0, theta=0.0
% INFO    : Bus 22582	: V=0.9734976, theta=-1.454746 -> V=1.0, theta=0.0
% INFO    : Bus 22583	: V=0.9588426, theta=-0.459224 -> V=1.0, theta=0.0
% INFO    : Bus 22584	: V=0.9548219, theta=-0.941061 -> V=1.0, theta=0.0
% INFO    : Bus 22585	: V=0.9552982, theta=-0.669856 -> V=1.0, theta=0.0
% INFO    : Bus 22586	: V=0.9606388, theta=-0.589752 -> V=1.0, theta=0.0
% INFO    : Bus 22587	: V=0.9634846, theta=-0.069137 -> V=1.0, theta=0.0
% INFO    : Bus 22588	: V=0.9574825, theta=-0.865608 -> V=1.0, theta=0.0
% INFO    : Bus 22589	: V=0.9558614, theta=-1.437292 -> V=1.0, theta=0.0
% INFO    : Bus 22590	: V=0.962296, theta=-0.457724 -> V=1.0, theta=0.0
% INFO    : Bus 22591	: V=0.9890135, theta=3.161518 -> V=1.0, theta=0.0
% INFO    : Bus 22592	: V=0.9737974, theta=0.748792 -> V=1.0, theta=0.0
% INFO    : Bus 22593	: V=0.9628543, theta=-0.204777 -> V=1.0, theta=0.0
% INFO    : Bus 22594	: V=0.9629803, theta=-0.160269 -> V=1.0, theta=0.0
% INFO    : Bus 22595	: V=0.9597366, theta=-0.549943 -> V=1.0, theta=0.0
% INFO    : Bus 22596	: V=0.9830793, theta=-3.689065 -> V=1.0, theta=0.0
% INFO    : Bus 22597	: V=0.9921627, theta=-4.062339 -> V=1.0, theta=0.0
% INFO    : Bus 22598	: V=0.9920263, theta=-4.019246 -> V=1.0, theta=0.0
% INFO    : Bus 22599	: V=0.9923355, theta=-4.044239 -> V=1.0, theta=0.0
% INFO    : Bus 22600	: V=0.9923243, theta=-3.892312 -> V=1.0, theta=0.0
% INFO    : Bus 22601	: V=0.98323, theta=-4.349048 -> V=1.0, theta=0.0
% INFO    : Bus 22602	: V=0.9956611, theta=-4.375172 -> V=1.0, theta=0.0
% INFO    : Bus 22603	: V=1.0045835, theta=-3.230943 -> V=1.0, theta=0.0
% INFO    : Bus 22604	: V=0.9919409, theta=-5.432254 -> V=1.0, theta=0.0
% INFO    : Bus 22605	: V=0.9982569, theta=-4.228656 -> V=1.0, theta=0.0
% INFO    : Bus 22606	: V=0.9748179, theta=-24.071464 -> V=1.0, theta=0.0
% INFO    : Bus 22607	: V=0.9745694, theta=-22.720955 -> V=1.0, theta=0.0
% INFO    : Bus 22608	: V=0.9621713, theta=-19.722444 -> V=1.0, theta=0.0
% INFO    : Bus 22609	: V=0.9491292, theta=-24.682379 -> V=1.0, theta=0.0
% INFO    : Bus 22610	: V=0.9730784, theta=-23.171099 -> V=1.0, theta=0.0
% INFO    : Bus 22611	: V=0.9600831, theta=-25.768379 -> V=1.0, theta=0.0
% INFO    : Bus 22612	: V=0.9570649, theta=-24.242593 -> V=1.0, theta=0.0
% INFO    : Bus 22613	: V=0.9554149, theta=-24.449794 -> V=1.0, theta=0.0
% INFO    : Bus 22614	: V=0.9492289, theta=-25.172567 -> V=1.0, theta=0.0
% INFO    : Bus 22615	: V=0.9528664, theta=-27.087094 -> V=1.0, theta=0.0
% INFO    : Bus 22616	: V=0.9516725, theta=-28.272066 -> V=1.0, theta=0.0
% INFO    : Bus 22617	: V=0.9245897, theta=-31.094687 -> V=1.0, theta=0.0
% INFO    : Bus 22618	: V=0.9520671, theta=6.695945 -> V=1.0, theta=0.0
% INFO    : Bus 22619	: V=0.9496969, theta=6.195066 -> V=1.0, theta=0.0
% INFO    : Bus 22620	: V=0.9569003, theta=6.31535 -> V=1.0, theta=0.0
% INFO    : Bus 22621	: V=0.9643063, theta=7.663614 -> V=1.0, theta=0.0
% INFO    : Bus 22622	: V=0.9551168, theta=6.812251 -> V=1.0, theta=0.0
% INFO    : Bus 22623	: V=0.9583607, theta=7.067721 -> V=1.0, theta=0.0
% INFO    : Bus 22624	: V=0.9738388, theta=7.57875 -> V=1.0, theta=0.0
% INFO    : Bus 22625	: V=0.9538546, theta=6.831975 -> V=1.0, theta=0.0
% INFO    : Bus 22626	: V=0.9662894, theta=7.933731 -> V=1.0, theta=0.0
% INFO    : Bus 22627	: V=0.9739717, theta=8.330029 -> V=1.0, theta=0.0
% INFO    : Bus 22628	: V=0.9907702, theta=-10.574106 -> V=1.0, theta=0.0
% INFO    : Bus 22629	: V=1.0069102, theta=-10.810999 -> V=1.0, theta=0.0
% INFO    : Bus 22630	: V=0.982689, theta=-11.175514 -> V=1.0, theta=0.0
% INFO    : Bus 22631	: V=0.9681231, theta=-11.537594 -> V=1.0, theta=0.0
% INFO    : Bus 22632	: V=0.969181, theta=-11.523776 -> V=1.0, theta=0.0
% INFO    : Bus 22633	: V=0.9761015, theta=-12.213275 -> V=1.0, theta=0.0
% INFO    : Bus 22634	: V=0.968826, theta=-12.704089 -> V=1.0, theta=0.0
% INFO    : Bus 22635	: V=0.9622201, theta=-11.801551 -> V=1.0, theta=0.0
% INFO    : Bus 22636	: V=0.9956081, theta=-11.918917 -> V=1.0, theta=0.0
% INFO    : Bus 22637	: V=0.9855925, theta=-11.898896 -> V=1.0, theta=0.0
% INFO    : Bus 22638	: V=0.9815565, theta=-12.018478 -> V=1.0, theta=0.0
% INFO    : Bus 22639	: V=1.0156342, theta=-10.424778 -> V=1.0, theta=0.0
% INFO    : Bus 22640	: V=0.9793725, theta=-7.624425 -> V=1.0, theta=0.0
% INFO    : Bus 22641	: V=0.9826803, theta=-7.394903 -> V=1.0, theta=0.0
% INFO    : Bus 22642	: V=0.9833169, theta=-7.4184 -> V=1.0, theta=0.0
% INFO    : Bus 22643	: V=0.9820636, theta=-7.487345 -> V=1.0, theta=0.0
% INFO    : Bus 22644	: V=0.9804099, theta=-7.624743 -> V=1.0, theta=0.0
% INFO    : Bus 22645	: V=0.9798628, theta=-7.788929 -> V=1.0, theta=0.0
% INFO    : Bus 22646	: V=0.9828155, theta=-7.556726 -> V=1.0, theta=0.0
% INFO    : Bus 22647	: V=0.9843928, theta=-7.370913 -> V=1.0, theta=0.0
% INFO    : Bus 22648	: V=0.9956847, theta=-6.02857 -> V=1.0, theta=0.0
% INFO    : Bus 22649	: V=0.9841725, theta=-7.500304 -> V=1.0, theta=0.0
% INFO    : Bus 22650	: V=0.987285, theta=-7.445146 -> V=1.0, theta=0.0
% INFO    : Bus 22651	: V=0.9951484, theta=-6.143705 -> V=1.0, theta=0.0
% INFO    : Bus 22652	: V=0.9951884, theta=-6.164771 -> V=1.0, theta=0.0
% INFO    : Bus 22653	: V=0.9953516, theta=-6.188311 -> V=1.0, theta=0.0
% INFO    : Bus 22654	: V=0.9955858, theta=-6.207851 -> V=1.0, theta=0.0
% INFO    : Bus 22655	: V=0.9866739, theta=-7.526934 -> V=1.0, theta=0.0
% INFO    : Bus 22656	: V=0.9866537, theta=-7.539169 -> V=1.0, theta=0.0
% INFO    : Bus 22657	: V=0.9788886, theta=-7.778749 -> V=1.0, theta=0.0
% INFO    : Bus 22658	: V=0.9801232, theta=-7.555811 -> V=1.0, theta=0.0
% INFO    : Bus 22659	: V=0.9905833, theta=-6.13475 -> V=1.0, theta=0.0
% INFO    : Bus 22660	: V=0.9829852, theta=-7.065512 -> V=1.0, theta=0.0
% INFO    : Bus 22661	: V=0.9834096, theta=-7.183946 -> V=1.0, theta=0.0
% INFO    : Bus 22662	: V=0.9811018, theta=-7.421965 -> V=1.0, theta=0.0
% INFO    : Bus 22663	: V=0.9838034, theta=-7.426349 -> V=1.0, theta=0.0
% INFO    : Bus 22664	: V=0.9838264, theta=-7.425964 -> V=1.0, theta=0.0
% INFO    : Bus 22665	: V=0.9840657, theta=-7.418842 -> V=1.0, theta=0.0
% INFO    : Bus 22666	: V=0.9781378, theta=-7.784232 -> V=1.0, theta=0.0
% INFO    : Bus 22667	: V=0.978141, theta=-7.940363 -> V=1.0, theta=0.0
% INFO    : Bus 22668	: V=0.9789271, theta=-8.166274 -> V=1.0, theta=0.0
% INFO    : Bus 22669	: V=0.9795025, theta=-8.267149 -> V=1.0, theta=0.0
% INFO    : Bus 22670	: V=0.977786, theta=-7.94342 -> V=1.0, theta=0.0
% INFO    : Bus 22671	: V=0.9833084, theta=-8.123223 -> V=1.0, theta=0.0
% INFO    : Bus 22672	: V=0.9788589, theta=-8.335708 -> V=1.0, theta=0.0
% INFO    : Bus 22673	: V=0.9772727, theta=-9.219837 -> V=1.0, theta=0.0
% INFO    : Bus 22674	: V=0.9882915, theta=-7.7056 -> V=1.0, theta=0.0
% INFO    : Bus 22675	: V=0.9780014, theta=-8.015819 -> V=1.0, theta=0.0
% INFO    : Bus 22676	: V=0.979144, theta=-8.937052 -> V=1.0, theta=0.0
% INFO    : Bus 22677	: V=0.9781223, theta=-9.078288 -> V=1.0, theta=0.0
% INFO    : Bus 22678	: V=0.9777934, theta=-7.977904 -> V=1.0, theta=0.0
% INFO    : Bus 22679	: V=0.9777903, theta=-9.135249 -> V=1.0, theta=0.0
% INFO    : Bus 22680	: V=0.9775784, theta=-9.171767 -> V=1.0, theta=0.0
% INFO    : Bus 22681	: V=0.9784357, theta=-8.03624 -> V=1.0, theta=0.0
% INFO    : Bus 22682	: V=0.9774571, theta=-8.449501 -> V=1.0, theta=0.0
% INFO    : Bus 22683	: V=0.9782739, theta=-8.221083 -> V=1.0, theta=0.0
% INFO    : Bus 22684	: V=0.9753057, theta=-8.92979 -> V=1.0, theta=0.0
% INFO    : Bus 22685	: V=0.9743223, theta=-8.929071 -> V=1.0, theta=0.0
% INFO    : Bus 22686	: V=0.9750601, theta=-9.67171 -> V=1.0, theta=0.0
% INFO    : Bus 22687	: V=0.9771195, theta=-8.390833 -> V=1.0, theta=0.0
% INFO    : Bus 22688	: V=0.9791775, theta=-8.662051 -> V=1.0, theta=0.0
% INFO    : Bus 22689	: V=0.9708198, theta=-10.095199 -> V=1.0, theta=0.0
% INFO    : Bus 22690	: V=0.9810172, theta=-7.931862 -> V=1.0, theta=0.0
% INFO    : Bus 22691	: V=0.9800497, theta=-8.072909 -> V=1.0, theta=0.0
% INFO    : Bus 22692	: V=0.9798582, theta=-7.931209 -> V=1.0, theta=0.0
% INFO    : Bus 22693	: V=0.9875192, theta=-7.2676 -> V=1.0, theta=0.0
% INFO    : Bus 22694	: V=0.9813695, theta=-7.912926 -> V=1.0, theta=0.0
% INFO    : Bus 22695	: V=1.0178459, theta=-3.252478 -> V=1.0, theta=0.0
% INFO    : Bus 22696	: V=0.9862866, theta=-7.363099 -> V=1.0, theta=0.0
% INFO    : Bus 22697	: V=0.9870829, theta=-7.360648 -> V=1.0, theta=0.0
% INFO    : Bus 22698	: V=0.9774569, theta=-9.165817 -> V=1.0, theta=0.0
% INFO    : Bus 22699	: V=0.9909668, theta=-6.954862 -> V=1.0, theta=0.0
% INFO    : Bus 22700	: V=0.9824948, theta=-7.55452 -> V=1.0, theta=0.0
% INFO    : Bus 22701	: V=0.9694963, theta=-10.215765 -> V=1.0, theta=0.0
% INFO    : Bus 22702	: V=0.966897, theta=-10.895404 -> V=1.0, theta=0.0
% INFO    : Bus 22703	: V=0.9666592, theta=-12.024279 -> V=1.0, theta=0.0
% INFO    : Bus 22704	: V=0.9718489, theta=-14.843921 -> V=1.0, theta=0.0
% INFO    : Bus 22705	: V=0.9646053, theta=-15.426693 -> V=1.0, theta=0.0
% INFO    : Bus 22706	: V=0.9689878, theta=-13.629906 -> V=1.0, theta=0.0
% INFO    : Bus 22707	: V=0.9738632, theta=-11.278885 -> V=1.0, theta=0.0
% INFO    : Bus 22708	: V=0.9861632, theta=-7.896582 -> V=1.0, theta=0.0
% INFO    : Bus 22709	: V=0.9850256, theta=-8.117283 -> V=1.0, theta=0.0
% INFO    : Bus 22710	: V=0.9740588, theta=-10.585287 -> V=1.0, theta=0.0
% INFO    : Bus 22711	: V=0.968041, theta=-12.372119 -> V=1.0, theta=0.0
% INFO    : Bus 22712	: V=0.9811837, theta=-7.631698 -> V=1.0, theta=0.0
% INFO    : Bus 22713	: V=0.9822507, theta=-7.487365 -> V=1.0, theta=0.0
% INFO    : Bus 22714	: V=0.9850131, theta=-7.363987 -> V=1.0, theta=0.0
% INFO    : Bus 22715	: V=0.9915595, theta=-6.130104 -> V=1.0, theta=0.0
% INFO    : Bus 22716	: V=0.9853995, theta=-7.367452 -> V=1.0, theta=0.0
% INFO    : Bus 22717	: V=0.9850447, theta=-7.97038 -> V=1.0, theta=0.0
% INFO    : Bus 22718	: V=0.9871758, theta=-7.525681 -> V=1.0, theta=0.0
% INFO    : Bus 22719	: V=0.9822637, theta=-7.413412 -> V=1.0, theta=0.0
% INFO    : Bus 22720	: V=0.9724511, theta=-12.984242 -> V=1.0, theta=0.0
% INFO    : Bus 22721	: V=0.9885507, theta=-3.837566 -> V=1.0, theta=0.0
% INFO    : Bus 22722	: V=0.960605, theta=-3.374521 -> V=1.0, theta=0.0
% INFO    : Bus 22723	: V=0.9593259, theta=-3.387636 -> V=1.0, theta=0.0
% INFO    : Bus 22724	: V=0.9662616, theta=-3.776622 -> V=1.0, theta=0.0
% INFO    : Bus 22725	: V=0.9700879, theta=-4.804217 -> V=1.0, theta=0.0
% INFO    : Bus 22726	: V=0.9719017, theta=-3.331653 -> V=1.0, theta=0.0
% INFO    : Bus 22727	: V=0.9788739, theta=-4.894795 -> V=1.0, theta=0.0
% INFO    : Bus 22728	: V=0.9753899, theta=-5.52548 -> V=1.0, theta=0.0
% INFO    : Bus 22729	: V=0.9828279, theta=-3.664581 -> V=1.0, theta=0.0
% INFO    : Bus 22730	: V=0.981099, theta=-3.598539 -> V=1.0, theta=0.0
% INFO    : Bus 22731	: V=0.9800106, theta=-3.315719 -> V=1.0, theta=0.0
% INFO    : Bus 22732	: V=0.9740554, theta=-4.002179 -> V=1.0, theta=0.0
% INFO    : Bus 22733	: V=0.9743229, theta=-3.932467 -> V=1.0, theta=0.0
% INFO    : Bus 22734	: V=0.9685367, theta=-7.266238 -> V=1.0, theta=0.0
% INFO    : Bus 22735	: V=0.9590753, theta=-8.451539 -> V=1.0, theta=0.0
% INFO    : Bus 22736	: V=0.9711939, theta=-8.052655 -> V=1.0, theta=0.0
% INFO    : Bus 22737	: V=0.9713894, theta=-8.416572 -> V=1.0, theta=0.0
% INFO    : Bus 22738	: V=0.9561553, theta=-8.910042 -> V=1.0, theta=0.0
% INFO    : Bus 22739	: V=0.9570154, theta=-7.94454 -> V=1.0, theta=0.0
% INFO    : Bus 22740	: V=0.9619017, theta=-7.156468 -> V=1.0, theta=0.0
% INFO    : Bus 22741	: V=0.9572937, theta=-7.0246 -> V=1.0, theta=0.0
% INFO    : Bus 22742	: V=0.9620694, theta=-7.527101 -> V=1.0, theta=0.0
% INFO    : Bus 22743	: V=0.9835578, theta=11.411861 -> V=1.0, theta=0.0
% INFO    : Bus 22744	: V=0.9534033, theta=10.309621 -> V=1.0, theta=0.0
% INFO    : Bus 22745	: V=0.9513277, theta=10.965826 -> V=1.0, theta=0.0
% INFO    : Bus 22746	: V=0.9558686, theta=11.629469 -> V=1.0, theta=0.0
% INFO    : Bus 22747	: V=0.9606632, theta=12.851858 -> V=1.0, theta=0.0
% INFO    : Bus 22748	: V=0.9801336, theta=-3.073043 -> V=1.0, theta=0.0
% INFO    : Bus 22749	: V=0.9768313, theta=-2.398129 -> V=1.0, theta=0.0
% INFO    : Bus 22750	: V=0.9733158, theta=-3.613327 -> V=1.0, theta=0.0
% INFO    : Bus 22751	: V=0.9797738, theta=-3.498958 -> V=1.0, theta=0.0
% INFO    : Bus 22752	: V=0.9821753, theta=-3.581137 -> V=1.0, theta=0.0
% INFO    : Bus 22753	: V=0.982692, theta=-3.599244 -> V=1.0, theta=0.0
% INFO    : Bus 22754	: V=0.9925046, theta=-2.962957 -> V=1.0, theta=0.0
% INFO    : Bus 22755	: V=0.9813735, theta=-3.594414 -> V=1.0, theta=0.0
% INFO    : Bus 22756	: V=0.9916389, theta=-3.360742 -> V=1.0, theta=0.0
% INFO    : Bus 22757	: V=0.9802584, theta=-3.407658 -> V=1.0, theta=0.0
% INFO    : Bus 22758	: V=0.9846387, theta=-4.312999 -> V=1.0, theta=0.0
% INFO    : Bus 22759	: V=1.0073219, theta=-1.461109 -> V=1.0, theta=0.0
% INFO    : Bus 22760	: V=0.9836854, theta=-3.502384 -> V=1.0, theta=0.0
% INFO    : Bus 22761	: V=0.9826596, theta=-3.572165 -> V=1.0, theta=0.0
% INFO    : Bus 22762	: V=0.9779511, theta=-3.183055 -> V=1.0, theta=0.0
% INFO    : Bus 22763	: V=1.0148878, theta=-19.909026 -> V=1.0, theta=0.0
% INFO    : Bus 22764	: V=1.0157406, theta=-19.899914 -> V=1.0, theta=0.0
% INFO    : Bus 22765	: V=1.0070272, theta=-20.548289 -> V=1.0, theta=0.0
% INFO    : Bus 22766	: V=1.0008822, theta=-20.346448 -> V=1.0, theta=0.0
% INFO    : Bus 22767	: V=1.0040469, theta=-20.728619 -> V=1.0, theta=0.0
% INFO    : Bus 22768	: V=1.0042744, theta=-20.958353 -> V=1.0, theta=0.0
% INFO    : Bus 22769	: V=1.0024537, theta=-20.813406 -> V=1.0, theta=0.0
% INFO    : Bus 22770	: V=1.002465, theta=-20.877254 -> V=1.0, theta=0.0
% INFO    : Bus 22771	: V=1.0023793, theta=-20.925638 -> V=1.0, theta=0.0
% INFO    : Bus 22772	: V=1.0181201, theta=-20.022551 -> V=1.0, theta=0.0
% INFO    : Bus 22773	: V=1.0027655, theta=-20.971324 -> V=1.0, theta=0.0
% INFO    : Bus 22774	: V=1.0164028, theta=-20.108444 -> V=1.0, theta=0.0
% INFO    : Bus 22775	: V=1.0034084, theta=-20.945273 -> V=1.0, theta=0.0
% INFO    : Bus 22776	: V=1.0015927, theta=-20.995674 -> V=1.0, theta=0.0
% INFO    : Bus 22777	: V=0.9996368, theta=-20.52079 -> V=1.0, theta=0.0
% INFO    : Bus 22778	: V=0.9988414, theta=-20.52236 -> V=1.0, theta=0.0
% INFO    : Bus 22779	: V=1.0054749, theta=-19.799954 -> V=1.0, theta=0.0
% INFO    : Bus 22780	: V=1.0116826, theta=-19.895941 -> V=1.0, theta=0.0
% INFO    : Bus 22781	: V=0.9923494, theta=-18.910002 -> V=1.0, theta=0.0
% INFO    : Bus 22782	: V=1.0139255, theta=-19.845315 -> V=1.0, theta=0.0
% INFO    : Bus 22783	: V=1.0017151, theta=-20.092479 -> V=1.0, theta=0.0
% INFO    : Bus 22784	: V=1.017729, theta=-19.878351 -> V=1.0, theta=0.0
% INFO    : Bus 22785	: V=0.9981447, theta=-21.349242 -> V=1.0, theta=0.0
% INFO    : Bus 22786	: V=1.0101321, theta=-20.797564 -> V=1.0, theta=0.0
% INFO    : Bus 22787	: V=1.0052343, theta=-21.417995 -> V=1.0, theta=0.0
% INFO    : Bus 22788	: V=1.0008153, theta=-21.109357 -> V=1.0, theta=0.0
% INFO    : Bus 22789	: V=0.9983923, theta=-22.152984 -> V=1.0, theta=0.0
% INFO    : Bus 22790	: V=0.9908889, theta=-24.374439 -> V=1.0, theta=0.0
% INFO    : Bus 22791	: V=0.9706298, theta=-18.369738 -> V=1.0, theta=0.0
% INFO    : Bus 22792	: V=0.9714686, theta=-20.009593 -> V=1.0, theta=0.0
% INFO    : Bus 22793	: V=0.9585926, theta=-14.757214 -> V=1.0, theta=0.0
% INFO    : Bus 22794	: V=0.9597833, theta=-12.703658 -> V=1.0, theta=0.0
% INFO    : Bus 22795	: V=0.9761554, theta=-16.203998 -> V=1.0, theta=0.0
% INFO    : Bus 22796	: V=0.9841879, theta=-20.620486 -> V=1.0, theta=0.0
% INFO    : Bus 22797	: V=0.9711262, theta=-20.919742 -> V=1.0, theta=0.0
% INFO    : Bus 22798	: V=0.9810277, theta=-25.799975 -> V=1.0, theta=0.0
% INFO    : Bus 22799	: V=0.9995603, theta=-21.561774 -> V=1.0, theta=0.0
% INFO    : Bus 22800	: V=1.0041016, theta=-20.726504 -> V=1.0, theta=0.0
% INFO    : Bus 22801	: V=0.9570806, theta=-9.046716 -> V=1.0, theta=0.0
% INFO    : Bus 22802	: V=0.9564284, theta=-9.056795 -> V=1.0, theta=0.0
% INFO    : Bus 22803	: V=0.9570657, theta=-8.989411 -> V=1.0, theta=0.0
% INFO    : Bus 22804	: V=0.9648091, theta=-8.156221 -> V=1.0, theta=0.0
% INFO    : Bus 22805	: V=0.9567403, theta=-8.952292 -> V=1.0, theta=0.0
% INFO    : Bus 22806	: V=0.9550701, theta=-9.090645 -> V=1.0, theta=0.0
% INFO    : Bus 22807	: V=0.9654813, theta=-8.495582 -> V=1.0, theta=0.0
% INFO    : Bus 22808	: V=0.9659999, theta=-8.566432 -> V=1.0, theta=0.0
% INFO    : Bus 22809	: V=0.9546881, theta=-9.164826 -> V=1.0, theta=0.0
% INFO    : Bus 22810	: V=0.9541627, theta=-9.202573 -> V=1.0, theta=0.0
% INFO    : Bus 22811	: V=0.9551275, theta=-8.949497 -> V=1.0, theta=0.0
% INFO    : Bus 22812	: V=0.96504, theta=-7.831609 -> V=1.0, theta=0.0
% INFO    : Bus 22813	: V=0.9559771, theta=-8.504533 -> V=1.0, theta=0.0
% INFO    : Bus 22814	: V=0.9558571, theta=-8.954925 -> V=1.0, theta=0.0
% INFO    : Bus 22815	: V=0.9547512, theta=-9.118815 -> V=1.0, theta=0.0
% INFO    : Bus 22816	: V=0.9568676, theta=-8.563077 -> V=1.0, theta=0.0
% INFO    : Bus 22817	: V=0.9566376, theta=-8.743314 -> V=1.0, theta=0.0
% INFO    : Bus 22818	: V=0.9567347, theta=-8.787296 -> V=1.0, theta=0.0
% INFO    : Bus 22819	: V=0.9573432, theta=-8.838488 -> V=1.0, theta=0.0
% INFO    : Bus 22820	: V=0.9581151, theta=-8.881395 -> V=1.0, theta=0.0
% INFO    : Bus 22821	: V=0.9542155, theta=-9.239051 -> V=1.0, theta=0.0
% INFO    : Bus 22822	: V=0.9552592, theta=-9.263959 -> V=1.0, theta=0.0
% INFO    : Bus 22823	: V=0.9760506, theta=-7.907415 -> V=1.0, theta=0.0
% INFO    : Bus 22824	: V=0.9597683, theta=-9.348967 -> V=1.0, theta=0.0
% INFO    : Bus 22825	: V=0.9658556, theta=-8.569295 -> V=1.0, theta=0.0
% INFO    : Bus 22826	: V=0.9768547, theta=-7.851177 -> V=1.0, theta=0.0
% INFO    : Bus 22827	: V=0.9676364, theta=-9.068564 -> V=1.0, theta=0.0
% INFO    : Bus 22828	: V=0.9553879, theta=-9.184067 -> V=1.0, theta=0.0
% INFO    : Bus 22829	: V=0.9796949, theta=-7.020098 -> V=1.0, theta=0.0
% INFO    : Bus 22830	: V=0.956635, theta=-9.030459 -> V=1.0, theta=0.0
% INFO    : Bus 22831	: V=0.9553188, theta=-9.11314 -> V=1.0, theta=0.0
% INFO    : Bus 22832	: V=0.9551718, theta=-9.155277 -> V=1.0, theta=0.0
% INFO    : Bus 22833	: V=0.9782982, theta=-7.397578 -> V=1.0, theta=0.0
% INFO    : Bus 22834	: V=0.9672236, theta=-9.430336 -> V=1.0, theta=0.0
% INFO    : Bus 22835	: V=0.9638152, theta=-8.936645 -> V=1.0, theta=0.0
% INFO    : Bus 22836	: V=0.9621412, theta=-8.792365 -> V=1.0, theta=0.0
% INFO    : Bus 22837	: V=0.9619244, theta=-8.489048 -> V=1.0, theta=0.0
% INFO    : Bus 22838	: V=0.9650434, theta=-7.460316 -> V=1.0, theta=0.0
% INFO    : Bus 22839	: V=0.9661071, theta=-6.911884 -> V=1.0, theta=0.0
% INFO    : Bus 22840	: V=0.9564867, theta=-8.537238 -> V=1.0, theta=0.0
% INFO    : Bus 22841	: V=0.9698829, theta=-6.307013 -> V=1.0, theta=0.0
% INFO    : Bus 22842	: V=0.9571456, theta=-8.460556 -> V=1.0, theta=0.0
% INFO    : Bus 22843	: V=0.9619932, theta=-7.783961 -> V=1.0, theta=0.0
% INFO    : Bus 22844	: V=0.9639898, theta=-8.232642 -> V=1.0, theta=0.0
% INFO    : Bus 22845	: V=0.9730747, theta=-6.828228 -> V=1.0, theta=0.0
% INFO    : Bus 22846	: V=0.9836005, theta=-6.01754 -> V=1.0, theta=0.0
% INFO    : Bus 22847	: V=0.9813817, theta=-6.577321 -> V=1.0, theta=0.0
% INFO    : Bus 22848	: V=0.9761678, theta=-7.953173 -> V=1.0, theta=0.0
% INFO    : Bus 22849	: V=0.9574181, theta=-10.231165 -> V=1.0, theta=0.0
% INFO    : Bus 22850	: V=0.9660814, theta=-9.026887 -> V=1.0, theta=0.0
% INFO    : Bus 22851	: V=0.9541143, theta=-9.011173 -> V=1.0, theta=0.0
% INFO    : Bus 22852	: V=0.953935, theta=-9.034065 -> V=1.0, theta=0.0
% INFO    : Bus 22853	: V=0.9593416, theta=-10.290084 -> V=1.0, theta=0.0
% INFO    : Bus 22854	: V=0.9579041, theta=-10.212459 -> V=1.0, theta=0.0
% INFO    : Bus 22855	: V=0.9537486, theta=-10.684639 -> V=1.0, theta=0.0
% INFO    : Bus 22856	: V=0.964897, theta=-9.395043 -> V=1.0, theta=0.0
% INFO    : Bus 22857	: V=0.9690782, theta=-8.981717 -> V=1.0, theta=0.0
% INFO    : Bus 22858	: V=0.9688113, theta=-2.964302 -> V=1.0, theta=0.0
% INFO    : Bus 22859	: V=0.9831707, theta=-2.212732 -> V=1.0, theta=0.0
% INFO    : Bus 22860	: V=0.9823202, theta=-1.842518 -> V=1.0, theta=0.0
% INFO    : Bus 22861	: V=0.9756978, theta=-2.526844 -> V=1.0, theta=0.0
% INFO    : Bus 22862	: V=0.9808666, theta=-2.426116 -> V=1.0, theta=0.0
% INFO    : Bus 22863	: V=0.9648828, theta=-0.816796 -> V=1.0, theta=0.0
% INFO    : Bus 22864	: V=0.964886, theta=-0.827207 -> V=1.0, theta=0.0
% INFO    : Bus 22865	: V=0.964404, theta=-1.123862 -> V=1.0, theta=0.0
% INFO    : Bus 22866	: V=0.9648555, theta=-0.832995 -> V=1.0, theta=0.0
% INFO    : Bus 22867	: V=0.9653536, theta=-0.83624 -> V=1.0, theta=0.0
% INFO    : Bus 22868	: V=0.9733253, theta=-0.392901 -> V=1.0, theta=0.0
% INFO    : Bus 22869	: V=0.9687251, theta=-0.764746 -> V=1.0, theta=0.0
% INFO    : Bus 22870	: V=0.9774668, theta=0.098772 -> V=1.0, theta=0.0
% INFO    : Bus 22871	: V=0.9766745, theta=0.043307 -> V=1.0, theta=0.0
% INFO    : Bus 22872	: V=0.9687729, theta=-0.828624 -> V=1.0, theta=0.0
% INFO    : Bus 22873	: V=0.9671921, theta=-1.052088 -> V=1.0, theta=0.0
% INFO    : Bus 22874	: V=0.9665563, theta=-1.051784 -> V=1.0, theta=0.0
% INFO    : Bus 22875	: V=0.9708878, theta=-0.814729 -> V=1.0, theta=0.0
% INFO    : Bus 22876	: V=0.9761919, theta=0.011144 -> V=1.0, theta=0.0
% INFO    : Bus 22877	: V=0.9891764, theta=1.2119 -> V=1.0, theta=0.0
% INFO    : Bus 22878	: V=0.9894803, theta=1.259645 -> V=1.0, theta=0.0
% INFO    : Bus 22879	: V=0.9787948, theta=0.172664 -> V=1.0, theta=0.0
% INFO    : Bus 22880	: V=0.9794218, theta=0.227649 -> V=1.0, theta=0.0
% INFO    : Bus 22881	: V=0.9803454, theta=0.307337 -> V=1.0, theta=0.0
% INFO    : Bus 22882	: V=0.9713647, theta=-0.742348 -> V=1.0, theta=0.0
% INFO    : Bus 22883	: V=0.9702175, theta=-0.817777 -> V=1.0, theta=0.0
% INFO    : Bus 22884	: V=0.9701414, theta=-0.821935 -> V=1.0, theta=0.0
% INFO    : Bus 22885	: V=0.9775911, theta=-0.309612 -> V=1.0, theta=0.0
% INFO    : Bus 22886	: V=0.9654988, theta=-1.147604 -> V=1.0, theta=0.0
% INFO    : Bus 22887	: V=0.9771332, theta=-0.380032 -> V=1.0, theta=0.0
% INFO    : Bus 22888	: V=0.9709346, theta=-0.857653 -> V=1.0, theta=0.0
% INFO    : Bus 22889	: V=0.9881351, theta=1.11638 -> V=1.0, theta=0.0
% INFO    : Bus 22890	: V=0.9669939, theta=-0.866002 -> V=1.0, theta=0.0
% INFO    : Bus 22891	: V=0.9726963, theta=-0.692974 -> V=1.0, theta=0.0
% INFO    : Bus 22892	: V=0.9707997, theta=-0.820588 -> V=1.0, theta=0.0
% INFO    : Bus 22893	: V=0.9712753, theta=-0.816847 -> V=1.0, theta=0.0
% INFO    : Bus 22894	: V=0.9719268, theta=-0.758232 -> V=1.0, theta=0.0
% INFO    : Bus 22895	: V=0.970119, theta=-0.93813 -> V=1.0, theta=0.0
% INFO    : Bus 22896	: V=0.9697079, theta=-0.985499 -> V=1.0, theta=0.0
% INFO    : Bus 22897	: V=0.9671362, theta=-1.089161 -> V=1.0, theta=0.0
% INFO    : Bus 22898	: V=0.968163, theta=-1.087835 -> V=1.0, theta=0.0
% INFO    : Bus 22899	: V=0.987847, theta=1.090751 -> V=1.0, theta=0.0
% INFO    : Bus 22900	: V=0.9764226, theta=-0.084154 -> V=1.0, theta=0.0
% INFO    : Bus 22901	: V=0.970423, theta=-0.720783 -> V=1.0, theta=0.0
% INFO    : Bus 22902	: V=0.9712545, theta=-0.684017 -> V=1.0, theta=0.0
% INFO    : Bus 22903	: V=0.9699944, theta=-0.721461 -> V=1.0, theta=0.0
% INFO    : Bus 22904	: V=0.976284, theta=-0.073913 -> V=1.0, theta=0.0
% INFO    : Bus 22905	: V=0.9678375, theta=-1.157383 -> V=1.0, theta=0.0
% INFO    : Bus 22906	: V=0.9672346, theta=-1.207388 -> V=1.0, theta=0.0
% INFO    : Bus 22907	: V=0.9778388, theta=-0.513688 -> V=1.0, theta=0.0
% INFO    : Bus 22908	: V=0.9661699, theta=-1.288286 -> V=1.0, theta=0.0
% INFO    : Bus 22909	: V=0.9658784, theta=-1.268611 -> V=1.0, theta=0.0
% INFO    : Bus 22910	: V=0.9646024, theta=-1.688373 -> V=1.0, theta=0.0
% INFO    : Bus 22911	: V=0.9665534, theta=-2.375875 -> V=1.0, theta=0.0
% INFO    : Bus 22912	: V=0.96933, theta=-0.106813 -> V=1.0, theta=0.0
% INFO    : Bus 22913	: V=0.9742758, theta=0.568407 -> V=1.0, theta=0.0
% INFO    : Bus 22914	: V=0.9710723, theta=0.165149 -> V=1.0, theta=0.0
% INFO    : Bus 22915	: V=0.9738908, theta=0.492648 -> V=1.0, theta=0.0
% INFO    : Bus 22916	: V=0.9725025, theta=0.334604 -> V=1.0, theta=0.0
% INFO    : Bus 22917	: V=0.9644638, theta=-0.712402 -> V=1.0, theta=0.0
% INFO    : Bus 22918	: V=0.9686208, theta=-0.208687 -> V=1.0, theta=0.0
% INFO    : Bus 22919	: V=0.9640129, theta=-1.39419 -> V=1.0, theta=0.0
% INFO    : Bus 22920	: V=0.9651, theta=-2.209471 -> V=1.0, theta=0.0
% INFO    : Bus 22921	: V=0.9630541, theta=-1.860285 -> V=1.0, theta=0.0
% INFO    : Bus 22922	: V=0.9629162, theta=-1.435889 -> V=1.0, theta=0.0
% INFO    : Bus 22923	: V=0.9627662, theta=-1.524305 -> V=1.0, theta=0.0
% INFO    : Bus 22924	: V=0.9604469, theta=-1.188735 -> V=1.0, theta=0.0
% INFO    : Bus 22925	: V=0.9613868, theta=-1.149829 -> V=1.0, theta=0.0
% INFO    : Bus 22926	: V=0.9580659, theta=-1.290329 -> V=1.0, theta=0.0
% INFO    : Bus 22927	: V=0.9595938, theta=-1.223463 -> V=1.0, theta=0.0
% INFO    : Bus 22928	: V=0.9627143, theta=-0.983763 -> V=1.0, theta=0.0
% INFO    : Bus 22929	: V=0.9609665, theta=-1.090621 -> V=1.0, theta=0.0
% INFO    : Bus 22930	: V=0.9599272, theta=-1.168472 -> V=1.0, theta=0.0
% INFO    : Bus 22931	: V=0.9672934, theta=-0.422942 -> V=1.0, theta=0.0
% INFO    : Bus 22932	: V=0.9709671, theta=-0.219138 -> V=1.0, theta=0.0
% INFO    : Bus 22933	: V=0.9658228, theta=-0.699942 -> V=1.0, theta=0.0
% INFO    : Bus 22934	: V=0.9656283, theta=-0.762504 -> V=1.0, theta=0.0
% INFO    : Bus 22935	: V=0.9910134, theta=1.470456 -> V=1.0, theta=0.0
% INFO    : Bus 22936	: V=0.9937357, theta=1.794626 -> V=1.0, theta=0.0
% INFO    : Bus 22937	: V=0.9770884, theta=-0.044939 -> V=1.0, theta=0.0
% INFO    : Bus 22938	: V=0.9732829, theta=-0.274474 -> V=1.0, theta=0.0
% INFO    : Bus 22939	: V=0.961011, theta=-1.152945 -> V=1.0, theta=0.0
% INFO    : Bus 22940	: V=0.9644007, theta=-1.205873 -> V=1.0, theta=0.0
% INFO    : Bus 22941	: V=0.9699551, theta=-1.203822 -> V=1.0, theta=0.0
% INFO    : Bus 22942	: V=0.9790572, theta=-0.94252 -> V=1.0, theta=0.0
% INFO    : Bus 22943	: V=0.9754994, theta=-1.307189 -> V=1.0, theta=0.0
% INFO    : Bus 22944	: V=0.9794345, theta=-1.265074 -> V=1.0, theta=0.0
% INFO    : Bus 22945	: V=0.9775082, theta=-2.059567 -> V=1.0, theta=0.0
% INFO    : Bus 22946	: V=0.9804153, theta=-1.944563 -> V=1.0, theta=0.0
% INFO    : Bus 22947	: V=0.976896, theta=-1.266628 -> V=1.0, theta=0.0
% INFO    : Bus 22948	: V=0.9777784, theta=-1.364703 -> V=1.0, theta=0.0
% INFO    : Bus 22949	: V=0.9918192, theta=1.162821 -> V=1.0, theta=0.0
% INFO    : Bus 22950	: V=0.9687722, theta=-1.133856 -> V=1.0, theta=0.0
% INFO    : Bus 22951	: V=0.9770907, theta=-0.43457 -> V=1.0, theta=0.0
% INFO    : Bus 22952	: V=0.969653, theta=-1.117069 -> V=1.0, theta=0.0
% INFO    : Bus 22953	: V=0.9794089, theta=-0.874758 -> V=1.0, theta=0.0
% INFO    : Bus 22954	: V=0.9701392, theta=-1.309171 -> V=1.0, theta=0.0
% INFO    : Bus 22955	: V=0.970908, theta=-1.306552 -> V=1.0, theta=0.0
% INFO    : Bus 22956	: V=0.9679769, theta=-1.35584 -> V=1.0, theta=0.0
% INFO    : Bus 22957	: V=0.9908911, theta=1.204816 -> V=1.0, theta=0.0
% INFO    : Bus 22958	: V=0.9653064, theta=-1.280431 -> V=1.0, theta=0.0
% INFO    : Bus 22959	: V=0.9645548, theta=-1.284292 -> V=1.0, theta=0.0
% INFO    : Bus 22960	: V=0.964262, theta=-1.187488 -> V=1.0, theta=0.0
% INFO    : Bus 22961	: V=0.965339, theta=-1.227882 -> V=1.0, theta=0.0
% INFO    : Bus 22962	: V=0.9657579, theta=-1.180904 -> V=1.0, theta=0.0
% INFO    : Bus 22963	: V=0.9645513, theta=-1.223904 -> V=1.0, theta=0.0
% INFO    : Bus 22964	: V=0.9806085, theta=0.407288 -> V=1.0, theta=0.0
% INFO    : Bus 22965	: V=0.9809516, theta=0.455605 -> V=1.0, theta=0.0
% INFO    : Bus 22966	: V=0.9796309, theta=0.305969 -> V=1.0, theta=0.0
% INFO    : Bus 22967	: V=0.9791534, theta=0.192042 -> V=1.0, theta=0.0
% INFO    : Bus 22968	: V=0.9789725, theta=0.22018 -> V=1.0, theta=0.0
% INFO    : Bus 22969	: V=0.9783854, theta=0.143346 -> V=1.0, theta=0.0
% INFO    : Bus 22970	: V=0.9764513, theta=-0.046135 -> V=1.0, theta=0.0
% INFO    : Bus 22971	: V=0.9773023, theta=0.051757 -> V=1.0, theta=0.0
% INFO    : Bus 22972	: V=0.9783107, theta=0.168242 -> V=1.0, theta=0.0
% INFO    : Bus 22973	: V=0.9778635, theta=0.118891 -> V=1.0, theta=0.0
% INFO    : Bus 22974	: V=0.9715626, theta=-0.517868 -> V=1.0, theta=0.0
% INFO    : Bus 22975	: V=0.969417, theta=-0.970225 -> V=1.0, theta=0.0
% INFO    : Bus 22976	: V=0.9674776, theta=-1.091223 -> V=1.0, theta=0.0
% INFO    : Bus 22977	: V=0.9761625, theta=-0.059837 -> V=1.0, theta=0.0
% INFO    : Bus 22978	: V=0.9779732, theta=0.052044 -> V=1.0, theta=0.0
% INFO    : Bus 22979	: V=0.9740183, theta=-0.424074 -> V=1.0, theta=0.0
% INFO    : Bus 22980	: V=0.967669, theta=-0.904015 -> V=1.0, theta=0.0
% INFO    : Bus 22981	: V=0.9716068, theta=-0.651096 -> V=1.0, theta=0.0
% INFO    : Bus 22982	: V=0.9853215, theta=0.721909 -> V=1.0, theta=0.0
% INFO    : Bus 22983	: V=0.9636629, theta=-1.29595 -> V=1.0, theta=0.0
% INFO    : Bus 22984	: V=0.9631536, theta=-1.321935 -> V=1.0, theta=0.0
% INFO    : Bus 22985	: V=0.9618641, theta=-1.442065 -> V=1.0, theta=0.0
% INFO    : Bus 22986	: V=0.9580226, theta=-1.793231 -> V=1.0, theta=0.0
% INFO    : Bus 22987	: V=0.9570074, theta=-2.248949 -> V=1.0, theta=0.0
% INFO    : Bus 22988	: V=0.9595045, theta=-1.780912 -> V=1.0, theta=0.0
% INFO    : Bus 22989	: V=0.9711382, theta=-2.100473 -> V=1.0, theta=0.0
% INFO    : Bus 22990	: V=0.9790656, theta=-1.035097 -> V=1.0, theta=0.0
% INFO    : Bus 22991	: V=0.9412991, theta=6.098394 -> V=1.0, theta=0.0
% INFO    : Bus 22992	: V=0.9627666, theta=6.157836 -> V=1.0, theta=0.0
% INFO    : Bus 22993	: V=1.0030458, theta=3.711503 -> V=1.0, theta=0.0
% INFO    : Bus 22994	: V=0.9945339, theta=2.845198 -> V=1.0, theta=0.0
% INFO    : Bus 22995	: V=0.9968428, theta=4.700524 -> V=1.0, theta=0.0
% INFO    : Bus 22996	: V=0.9976468, theta=2.640916 -> V=1.0, theta=0.0
% INFO    : Bus 22997	: V=0.9636596, theta=-14.085012 -> V=1.0, theta=0.0
% INFO    : Bus 22998	: V=0.9713865, theta=-13.093302 -> V=1.0, theta=0.0
% INFO    : Bus 22999	: V=0.979226, theta=-13.524899 -> V=1.0, theta=0.0
% INFO    : Bus 23000	: V=0.981457, theta=-12.869968 -> V=1.0, theta=0.0
% INFO    : Bus 23001	: V=0.9717623, theta=-13.805992 -> V=1.0, theta=0.0
% INFO    : Bus 23002	: V=0.9693152, theta=-14.043819 -> V=1.0, theta=0.0
% INFO    : Bus 23003	: V=0.9676374, theta=-14.357774 -> V=1.0, theta=0.0
% INFO    : Bus 23004	: V=0.9776492, theta=-14.43462 -> V=1.0, theta=0.0
% INFO    : Bus 23005	: V=0.9784326, theta=-14.034289 -> V=1.0, theta=0.0
% INFO    : Bus 23006	: V=0.9792686, theta=-13.714604 -> V=1.0, theta=0.0
% INFO    : Bus 23007	: V=0.9744081, theta=-15.606706 -> V=1.0, theta=0.0
% INFO    : Bus 23008	: V=0.9733277, theta=-14.989995 -> V=1.0, theta=0.0
% INFO    : Bus 23009	: V=0.9766033, theta=-15.135618 -> V=1.0, theta=0.0
% INFO    : Bus 23010	: V=0.9860038, theta=-13.565488 -> V=1.0, theta=0.0
% INFO    : Bus 23011	: V=0.9726187, theta=-15.728017 -> V=1.0, theta=0.0
% INFO    : Bus 23012	: V=0.9729707, theta=-16.268335 -> V=1.0, theta=0.0
% INFO    : Bus 23013	: V=0.9735725, theta=-16.718694 -> V=1.0, theta=0.0
% INFO    : Bus 23014	: V=0.9797789, theta=-15.983241 -> V=1.0, theta=0.0
% INFO    : Bus 23015	: V=0.9782232, theta=-17.249703 -> V=1.0, theta=0.0
% INFO    : Bus 23016	: V=0.9779687, theta=-17.44838 -> V=1.0, theta=0.0
% INFO    : Bus 23017	: V=0.9704533, theta=-17.651787 -> V=1.0, theta=0.0
% INFO    : Bus 23018	: V=0.9717118, theta=-16.672583 -> V=1.0, theta=0.0
% INFO    : Bus 23019	: V=0.9715002, theta=-16.245319 -> V=1.0, theta=0.0
% INFO    : Bus 23020	: V=0.9811525, theta=-13.522208 -> V=1.0, theta=0.0
% INFO    : Bus 23021	: V=0.9449258, theta=-2.403141 -> V=1.0, theta=0.0
% INFO    : Bus 23022	: V=0.9496466, theta=-2.240277 -> V=1.0, theta=0.0
% INFO    : Bus 23023	: V=0.9471451, theta=-2.303778 -> V=1.0, theta=0.0
% INFO    : Bus 23024	: V=0.9566085, theta=0.455509 -> V=1.0, theta=0.0
% INFO    : Bus 23025	: V=0.9502811, theta=-2.094179 -> V=1.0, theta=0.0
% INFO    : Bus 23026	: V=0.9576534, theta=-1.57965 -> V=1.0, theta=0.0
% INFO    : Bus 23027	: V=0.9564637, theta=-29.398196 -> V=1.0, theta=0.0
% INFO    : Bus 23028	: V=0.9692893, theta=-27.811371 -> V=1.0, theta=0.0
% INFO    : Bus 23029	: V=0.9792457, theta=-26.944637 -> V=1.0, theta=0.0
% INFO    : Bus 23030	: V=0.9834691, theta=-26.369907 -> V=1.0, theta=0.0
% INFO    : Bus 23031	: V=0.961154, theta=-28.413319 -> V=1.0, theta=0.0
% INFO    : Bus 23032	: V=0.9640729, theta=-29.387543 -> V=1.0, theta=0.0
% INFO    : Bus 23033	: V=0.9586784, theta=-30.267611 -> V=1.0, theta=0.0
% INFO    : Bus 23034	: V=0.9636093, theta=-29.311032 -> V=1.0, theta=0.0
% INFO    : Bus 23035	: V=0.9573049, theta=-29.300631 -> V=1.0, theta=0.0
% INFO    : Bus 23036	: V=0.9558182, theta=-30.617339 -> V=1.0, theta=0.0
% INFO    : Bus 23037	: V=0.9798764, theta=-29.365591 -> V=1.0, theta=0.0
% INFO    : Bus 23038	: V=0.9552556, theta=-30.554863 -> V=1.0, theta=0.0
% INFO    : Bus 23039	: V=0.961213, theta=-30.193492 -> V=1.0, theta=0.0
% INFO    : Bus 23040	: V=0.9639341, theta=-29.633448 -> V=1.0, theta=0.0
% INFO    : Bus 23041	: V=0.9642053, theta=-29.65958 -> V=1.0, theta=0.0
% INFO    : Bus 23042	: V=0.9515606, theta=-30.641818 -> V=1.0, theta=0.0
% INFO    : Bus 23043	: V=0.966247, theta=-29.087642 -> V=1.0, theta=0.0
% INFO    : Bus 23044	: V=0.9707249, theta=-28.970459 -> V=1.0, theta=0.0
% INFO    : Bus 23045	: V=0.9652529, theta=-29.971222 -> V=1.0, theta=0.0
% INFO    : Bus 23046	: V=0.9556094, theta=-30.722446 -> V=1.0, theta=0.0
% INFO    : Bus 23047	: V=0.9622381, theta=-29.888916 -> V=1.0, theta=0.0
% INFO    : Bus 23048	: V=0.9592871, theta=-29.108419 -> V=1.0, theta=0.0
% INFO    : Bus 23049	: V=0.9618958, theta=-28.663176 -> V=1.0, theta=0.0
% INFO    : Bus 23050	: V=0.9608612, theta=-15.870773 -> V=1.0, theta=0.0
% INFO    : Bus 23051	: V=0.9549688, theta=-16.04273 -> V=1.0, theta=0.0
% INFO    : Bus 23052	: V=0.9604928, theta=-16.215495 -> V=1.0, theta=0.0
% INFO    : Bus 23053	: V=0.9601237, theta=-16.726643 -> V=1.0, theta=0.0
% INFO    : Bus 23054	: V=0.9580155, theta=-15.720018 -> V=1.0, theta=0.0
% INFO    : Bus 23055	: V=0.9580551, theta=-16.288639 -> V=1.0, theta=0.0
% INFO    : Bus 23056	: V=0.9572067, theta=-17.017606 -> V=1.0, theta=0.0
% INFO    : Bus 23057	: V=0.9572898, theta=-16.793513 -> V=1.0, theta=0.0
% INFO    : Bus 23058	: V=0.9563893, theta=-17.698774 -> V=1.0, theta=0.0
% INFO    : Bus 23059	: V=0.9595291, theta=-17.449655 -> V=1.0, theta=0.0
% INFO    : Bus 23060	: V=0.9573181, theta=-17.296677 -> V=1.0, theta=0.0
% INFO    : Bus 23061	: V=0.9581306, theta=-17.675526 -> V=1.0, theta=0.0
% INFO    : Bus 23062	: V=0.9569896, theta=-17.855662 -> V=1.0, theta=0.0
% INFO    : Bus 23063	: V=0.9531833, theta=-13.452687 -> V=1.0, theta=0.0
% INFO    : Bus 23064	: V=0.9604347, theta=-14.77718 -> V=1.0, theta=0.0
% INFO    : Bus 23065	: V=0.9637004, theta=-13.200711 -> V=1.0, theta=0.0
% INFO    : Bus 23066	: V=0.9632156, theta=-13.432733 -> V=1.0, theta=0.0
% INFO    : Bus 23067	: V=0.9614805, theta=-14.68582 -> V=1.0, theta=0.0
% INFO    : Bus 23068	: V=0.9609274, theta=-14.645451 -> V=1.0, theta=0.0
% INFO    : Bus 23069	: V=0.9583166, theta=-15.056766 -> V=1.0, theta=0.0
% INFO    : Bus 23070	: V=0.9588788, theta=-15.9376 -> V=1.0, theta=0.0
% INFO    : Bus 23071	: V=0.9574457, theta=-16.967689 -> V=1.0, theta=0.0
% INFO    : Bus 23072	: V=0.9599188, theta=-15.710984 -> V=1.0, theta=0.0
% INFO    : Bus 23073	: V=0.9600464, theta=-16.436002 -> V=1.0, theta=0.0
% INFO    : Bus 23074	: V=0.9589036, theta=-16.197298 -> V=1.0, theta=0.0
% INFO    : Bus 23075	: V=0.9614818, theta=-17.668464 -> V=1.0, theta=0.0
% INFO    : Bus 23076	: V=0.9606936, theta=-15.878253 -> V=1.0, theta=0.0
% INFO    : Bus 23077	: V=0.9637058, theta=-17.444555 -> V=1.0, theta=0.0
% INFO    : Bus 23078	: V=0.9642414, theta=-19.47114 -> V=1.0, theta=0.0
% INFO    : Bus 23079	: V=0.9656688, theta=-19.345477 -> V=1.0, theta=0.0
% INFO    : Bus 23080	: V=0.9649627, theta=-19.451554 -> V=1.0, theta=0.0
% INFO    : Bus 23081	: V=0.9545377, theta=-19.407665 -> V=1.0, theta=0.0
% INFO    : Bus 23082	: V=0.9563186, theta=-17.985891 -> V=1.0, theta=0.0
% INFO    : Bus 23083	: V=0.9538183, theta=-19.187789 -> V=1.0, theta=0.0
% INFO    : Bus 23084	: V=0.9557062, theta=-18.084101 -> V=1.0, theta=0.0
% INFO    : Bus 23085	: V=0.9553261, theta=-19.206254 -> V=1.0, theta=0.0
% INFO    : Bus 23086	: V=0.9533961, theta=-19.590378 -> V=1.0, theta=0.0
% INFO    : Bus 23087	: V=0.9539226, theta=-19.305868 -> V=1.0, theta=0.0
% INFO    : Bus 23088	: V=0.9564502, theta=-17.88467 -> V=1.0, theta=0.0
% INFO    : Bus 23089	: V=0.9541541, theta=-19.567928 -> V=1.0, theta=0.0
% INFO    : Bus 23090	: V=0.9534212, theta=-19.629093 -> V=1.0, theta=0.0
% INFO    : Bus 23091	: V=0.9566577, theta=-17.476327 -> V=1.0, theta=0.0
% INFO    : Bus 23092	: V=0.9531645, theta=-19.206496 -> V=1.0, theta=0.0
% INFO    : Bus 23093	: V=0.9575158, theta=-17.588023 -> V=1.0, theta=0.0
% INFO    : Bus 23094	: V=0.956895, theta=-17.128948 -> V=1.0, theta=0.0
% INFO    : Bus 23095	: V=0.9578639, theta=-16.769345 -> V=1.0, theta=0.0
% INFO    : Bus 23096	: V=0.9573827, theta=-17.155407 -> V=1.0, theta=0.0
% INFO    : Bus 23097	: V=0.9568814, theta=-17.574602 -> V=1.0, theta=0.0
% INFO    : Bus 23098	: V=0.9528167, theta=-19.647138 -> V=1.0, theta=0.0
% INFO    : Bus 23099	: V=0.9615106, theta=-18.945673 -> V=1.0, theta=0.0
% INFO    : Bus 23100	: V=0.9617187, theta=-19.579017 -> V=1.0, theta=0.0
% INFO    : Bus 23101	: V=0.9571148, theta=-20.559305 -> V=1.0, theta=0.0
% INFO    : Bus 23102	: V=0.9583555, theta=-20.52273 -> V=1.0, theta=0.0
% INFO    : Bus 23103	: V=0.9617162, theta=-20.446942 -> V=1.0, theta=0.0
% INFO    : Bus 23104	: V=0.9611302, theta=-19.917545 -> V=1.0, theta=0.0
% INFO    : Bus 23105	: V=0.9585825, theta=-18.868578 -> V=1.0, theta=0.0
% INFO    : Bus 23106	: V=0.9524954, theta=-19.650699 -> V=1.0, theta=0.0
% INFO    : Bus 23107	: V=0.9587752, theta=-20.533475 -> V=1.0, theta=0.0
% INFO    : Bus 23108	: V=0.9587492, theta=-20.568504 -> V=1.0, theta=0.0
% INFO    : Bus 23109	: V=0.9593991, theta=-21.084043 -> V=1.0, theta=0.0
% INFO    : Bus 23110	: V=0.9604052, theta=-21.075457 -> V=1.0, theta=0.0
% INFO    : Bus 23111	: V=1.0029442, theta=5.997677 -> V=1.0, theta=0.0
% INFO    : Bus 23112	: V=0.9962487, theta=5.206677 -> V=1.0, theta=0.0
% INFO    : Bus 23113	: V=0.965928, theta=0.521257 -> V=1.0, theta=0.0
% INFO    : Bus 23114	: V=0.9826683, theta=1.763202 -> V=1.0, theta=0.0
% INFO    : Bus 23115	: V=0.9922587, theta=7.678875 -> V=1.0, theta=0.0
% INFO    : Bus 23116	: V=0.9682672, theta=-1.536547 -> V=1.0, theta=0.0
% INFO    : Bus 23117	: V=0.955418, theta=-1.181644 -> V=1.0, theta=0.0
% INFO    : Bus 23118	: V=0.9753335, theta=-18.992613 -> V=1.0, theta=0.0
% INFO    : Bus 23119	: V=0.9909238, theta=-17.395197 -> V=1.0, theta=0.0
% INFO    : Bus 23120	: V=0.9982378, theta=-18.512641 -> V=1.0, theta=0.0
% INFO    : Bus 23121	: V=0.9828836, theta=-18.272366 -> V=1.0, theta=0.0
% INFO    : Bus 23122	: V=0.9776414, theta=-18.360238 -> V=1.0, theta=0.0
% INFO    : Bus 23123	: V=0.9691345, theta=-18.610308 -> V=1.0, theta=0.0
% INFO    : Bus 23124	: V=0.9734257, theta=-19.421497 -> V=1.0, theta=0.0
% INFO    : Bus 23125	: V=0.9698418, theta=-19.775129 -> V=1.0, theta=0.0
% INFO    : Bus 23126	: V=0.9622518, theta=-20.023111 -> V=1.0, theta=0.0
% INFO    : Bus 23127	: V=0.9720931, theta=-20.104039 -> V=1.0, theta=0.0
% INFO    : Bus 23128	: V=0.9688838, theta=-20.434228 -> V=1.0, theta=0.0
% INFO    : Bus 23129	: V=0.9983022, theta=-18.567371 -> V=1.0, theta=0.0
% INFO    : Bus 23130	: V=0.987619, theta=-19.356633 -> V=1.0, theta=0.0
% INFO    : Bus 23131	: V=0.9995968, theta=-18.606513 -> V=1.0, theta=0.0
% INFO    : Bus 23132	: V=0.9984124, theta=-18.75328 -> V=1.0, theta=0.0
% INFO    : Bus 23133	: V=0.9922753, theta=-19.560429 -> V=1.0, theta=0.0
% INFO    : Bus 23134	: V=0.9820406, theta=-20.205432 -> V=1.0, theta=0.0
% INFO    : Bus 23135	: V=0.9668188, theta=-21.464094 -> V=1.0, theta=0.0
% INFO    : Bus 23136	: V=0.9873348, theta=-19.635666 -> V=1.0, theta=0.0
% INFO    : Bus 23137	: V=0.9837092, theta=-20.079196 -> V=1.0, theta=0.0
% INFO    : Bus 23138	: V=0.9966909, theta=-18.971008 -> V=1.0, theta=0.0
% INFO    : Bus 23139	: V=0.9872928, theta=-19.740184 -> V=1.0, theta=0.0
% INFO    : Bus 23140	: V=0.9802159, theta=-20.369603 -> V=1.0, theta=0.0
% INFO    : Bus 23141	: V=0.9911728, theta=-19.732285 -> V=1.0, theta=0.0
% INFO    : Bus 23142	: V=0.9624337, theta=-21.454277 -> V=1.0, theta=0.0
% INFO    : Bus 23143	: V=0.9566645, theta=-21.795621 -> V=1.0, theta=0.0
% INFO    : Bus 23144	: V=0.9565128, theta=-21.85259 -> V=1.0, theta=0.0
% INFO    : Bus 23145	: V=0.9576926, theta=-21.889611 -> V=1.0, theta=0.0
% INFO    : Bus 23146	: V=0.989947, theta=-19.928211 -> V=1.0, theta=0.0
% INFO    : Bus 23147	: V=0.9893532, theta=-20.02576 -> V=1.0, theta=0.0
% INFO    : Bus 23148	: V=0.9589475, theta=-22.007622 -> V=1.0, theta=0.0
% INFO    : Bus 23149	: V=0.9582779, theta=-21.976973 -> V=1.0, theta=0.0
% INFO    : Bus 23150	: V=0.9600852, theta=-22.047178 -> V=1.0, theta=0.0
% INFO    : Bus 23151	: V=0.9594005, theta=-22.031151 -> V=1.0, theta=0.0
% INFO    : Bus 23152	: V=0.9607727, theta=-21.127651 -> V=1.0, theta=0.0
% INFO    : Bus 23153	: V=0.9592008, theta=-21.250632 -> V=1.0, theta=0.0
% INFO    : Bus 23154	: V=0.9599037, theta=-21.130697 -> V=1.0, theta=0.0
% INFO    : Bus 23155	: V=0.9673823, theta=-20.15551 -> V=1.0, theta=0.0
% INFO    : Bus 23156	: V=0.9585405, theta=-21.004091 -> V=1.0, theta=0.0
% INFO    : Bus 23157	: V=0.9570114, theta=-21.929359 -> V=1.0, theta=0.0
% INFO    : Bus 23158	: V=0.9608217, theta=-21.973498 -> V=1.0, theta=0.0
% INFO    : Bus 23159	: V=0.9590107, theta=-21.964583 -> V=1.0, theta=0.0
% INFO    : Bus 23160	: V=0.9553699, theta=-21.836421 -> V=1.0, theta=0.0
% INFO    : Bus 23161	: V=0.9534791, theta=-21.874766 -> V=1.0, theta=0.0
% INFO    : Bus 23162	: V=0.9713951, theta=-20.586627 -> V=1.0, theta=0.0
% INFO    : Bus 23163	: V=0.9707268, theta=-20.758451 -> V=1.0, theta=0.0
% INFO    : Bus 23164	: V=0.9706204, theta=-20.841038 -> V=1.0, theta=0.0
% INFO    : Bus 23165	: V=0.956963, theta=-22.062548 -> V=1.0, theta=0.0
% INFO    : Bus 23166	: V=0.9576215, theta=-22.085246 -> V=1.0, theta=0.0
% INFO    : Bus 23167	: V=0.9578446, theta=-22.099644 -> V=1.0, theta=0.0
% INFO    : Bus 23168	: V=0.9589691, theta=-22.075576 -> V=1.0, theta=0.0
% INFO    : Bus 23169	: V=0.9597457, theta=-22.109249 -> V=1.0, theta=0.0
% INFO    : Bus 23170	: V=0.9636051, theta=-22.043536 -> V=1.0, theta=0.0
% INFO    : Bus 23171	: V=0.9581652, theta=-22.106996 -> V=1.0, theta=0.0
% INFO    : Bus 23172	: V=0.9593279, theta=-22.067462 -> V=1.0, theta=0.0
% INFO    : Bus 23173	: V=0.9735816, theta=-21.111276 -> V=1.0, theta=0.0
% INFO    : Bus 23174	: V=0.9634418, theta=-21.935181 -> V=1.0, theta=0.0
% INFO    : Bus 23175	: V=0.9666625, theta=-21.831509 -> V=1.0, theta=0.0
% INFO    : Bus 23176	: V=0.9679882, theta=-21.884436 -> V=1.0, theta=0.0
% INFO    : Bus 23177	: V=0.9782382, theta=-21.27406 -> V=1.0, theta=0.0
% INFO    : Bus 23178	: V=0.9651548, theta=-22.038959 -> V=1.0, theta=0.0
% INFO    : Bus 23179	: V=0.9875361, theta=-20.448686 -> V=1.0, theta=0.0
% INFO    : Bus 23180	: V=0.9781564, theta=-21.323566 -> V=1.0, theta=0.0
% INFO    : Bus 23181	: V=0.9872773, theta=-20.482753 -> V=1.0, theta=0.0
% INFO    : Bus 23182	: V=0.9871268, theta=-20.517334 -> V=1.0, theta=0.0
% INFO    : Bus 23183	: V=0.9871626, theta=-20.52555 -> V=1.0, theta=0.0
% INFO    : Bus 23184	: V=0.9765773, theta=-21.471996 -> V=1.0, theta=0.0
% INFO    : Bus 23185	: V=0.9782331, theta=-21.400923 -> V=1.0, theta=0.0
% INFO    : Bus 23186	: V=0.9743406, theta=-21.693628 -> V=1.0, theta=0.0
% INFO    : Bus 23187	: V=0.9730985, theta=-21.755132 -> V=1.0, theta=0.0
% INFO    : Bus 23188	: V=0.9700855, theta=-22.023754 -> V=1.0, theta=0.0
% INFO    : Bus 23189	: V=0.9761522, theta=-21.530198 -> V=1.0, theta=0.0
% INFO    : Bus 23190	: V=0.9877678, theta=-20.510023 -> V=1.0, theta=0.0
% INFO    : Bus 23191	: V=0.9780091, theta=-21.527058 -> V=1.0, theta=0.0
% INFO    : Bus 23192	: V=0.9750942, theta=-21.654787 -> V=1.0, theta=0.0
% INFO    : Bus 23193	: V=0.9632789, theta=-22.046092 -> V=1.0, theta=0.0
% INFO    : Bus 23194	: V=0.9636061, theta=-22.04495 -> V=1.0, theta=0.0
% INFO    : Bus 23195	: V=0.9776982, theta=-20.931191 -> V=1.0, theta=0.0
% INFO    : Bus 23196	: V=0.9623856, theta=-22.033657 -> V=1.0, theta=0.0
% INFO    : Bus 23197	: V=0.9743407, theta=-21.374943 -> V=1.0, theta=0.0
% INFO    : Bus 23198	: V=0.9757491, theta=-21.357916 -> V=1.0, theta=0.0
% INFO    : Bus 23199	: V=0.9734814, theta=-21.394974 -> V=1.0, theta=0.0
% INFO    : Bus 23200	: V=0.9732308, theta=-21.396305 -> V=1.0, theta=0.0
% INFO    : Bus 23201	: V=0.9730887, theta=-21.393913 -> V=1.0, theta=0.0
% INFO    : Bus 23202	: V=0.9687957, theta=-21.948492 -> V=1.0, theta=0.0
% INFO    : Bus 23203	: V=0.9741807, theta=-21.304812 -> V=1.0, theta=0.0
% INFO    : Bus 23204	: V=0.9730156, theta=-21.383805 -> V=1.0, theta=0.0
% INFO    : Bus 23205	: V=0.9678119, theta=-22.050715 -> V=1.0, theta=0.0
% INFO    : Bus 23206	: V=0.9678159, theta=-22.111468 -> V=1.0, theta=0.0
% INFO    : Bus 23207	: V=0.9690637, theta=-22.064477 -> V=1.0, theta=0.0
% INFO    : Bus 23208	: V=0.9662029, theta=-22.234675 -> V=1.0, theta=0.0
% INFO    : Bus 23209	: V=0.9675122, theta=-22.008053 -> V=1.0, theta=0.0
% INFO    : Bus 23210	: V=0.9734821, theta=-21.434096 -> V=1.0, theta=0.0
% INFO    : Bus 23211	: V=0.973662, theta=-21.382326 -> V=1.0, theta=0.0
% INFO    : Bus 23212	: V=0.9735306, theta=-21.334721 -> V=1.0, theta=0.0
% INFO    : Bus 23213	: V=0.9681343, theta=-21.765058 -> V=1.0, theta=0.0
% INFO    : Bus 23214	: V=0.974547, theta=-21.265674 -> V=1.0, theta=0.0
% INFO    : Bus 23215	: V=0.9756923, theta=-21.188148 -> V=1.0, theta=0.0
% INFO    : Bus 23216	: V=0.9889985, theta=-20.052124 -> V=1.0, theta=0.0
% INFO    : Bus 23217	: V=0.9646061, theta=-22.032367 -> V=1.0, theta=0.0
% INFO    : Bus 23218	: V=0.9757473, theta=-21.129732 -> V=1.0, theta=0.0
% INFO    : Bus 23219	: V=0.9672231, theta=-21.800158 -> V=1.0, theta=0.0
% INFO    : Bus 23220	: V=0.9765813, theta=-21.101344 -> V=1.0, theta=0.0
% INFO    : Bus 23221	: V=0.9740704, theta=-21.293211 -> V=1.0, theta=0.0
% INFO    : Bus 23222	: V=0.9746811, theta=-21.250486 -> V=1.0, theta=0.0
% INFO    : Bus 23223	: V=0.9771224, theta=-20.966393 -> V=1.0, theta=0.0
% INFO    : Bus 23224	: V=0.9715791, theta=-21.488236 -> V=1.0, theta=0.0
% INFO    : Bus 23225	: V=0.9700887, theta=-21.402756 -> V=1.0, theta=0.0
% INFO    : Bus 23226	: V=0.9726626, theta=-21.407205 -> V=1.0, theta=0.0
% INFO    : Bus 23227	: V=0.9693916, theta=-21.635032 -> V=1.0, theta=0.0
% INFO    : Bus 23228	: V=0.9685818, theta=-21.708168 -> V=1.0, theta=0.0
% INFO    : Bus 23229	: V=0.9681076, theta=-21.734402 -> V=1.0, theta=0.0
% INFO    : Bus 23230	: V=0.9619491, theta=-22.435025 -> V=1.0, theta=0.0
% INFO    : Bus 23231	: V=0.9621288, theta=-22.434302 -> V=1.0, theta=0.0
% INFO    : Bus 23232	: V=0.9625823, theta=-22.432175 -> V=1.0, theta=0.0
% INFO    : Bus 23233	: V=0.9636769, theta=-22.29968 -> V=1.0, theta=0.0
% INFO    : Bus 23234	: V=0.9621879, theta=-22.561791 -> V=1.0, theta=0.0
% INFO    : Bus 23235	: V=0.962038, theta=-22.545235 -> V=1.0, theta=0.0
% INFO    : Bus 23236	: V=0.9620749, theta=-22.521946 -> V=1.0, theta=0.0
% INFO    : Bus 23237	: V=0.9614468, theta=-22.600559 -> V=1.0, theta=0.0
% INFO    : Bus 23238	: V=0.9618543, theta=-22.628603 -> V=1.0, theta=0.0
% INFO    : Bus 23239	: V=0.9614847, theta=-22.651803 -> V=1.0, theta=0.0
% INFO    : Bus 23240	: V=0.9610543, theta=-22.642645 -> V=1.0, theta=0.0
% INFO    : Bus 23241	: V=0.960703, theta=-22.680195 -> V=1.0, theta=0.0
% INFO    : Bus 23242	: V=0.9604314, theta=-22.714238 -> V=1.0, theta=0.0
% INFO    : Bus 23243	: V=0.9607227, theta=-22.702164 -> V=1.0, theta=0.0
% INFO    : Bus 23244	: V=0.9610945, theta=-22.686425 -> V=1.0, theta=0.0
% INFO    : Bus 23245	: V=0.9605611, theta=-22.863074 -> V=1.0, theta=0.0
% INFO    : Bus 23246	: V=0.9603165, theta=-22.747832 -> V=1.0, theta=0.0
% INFO    : Bus 23247	: V=0.960509, theta=-22.772109 -> V=1.0, theta=0.0
% INFO    : Bus 23248	: V=0.9596062, theta=-22.78706 -> V=1.0, theta=0.0
% INFO    : Bus 23249	: V=0.9595854, theta=-22.777042 -> V=1.0, theta=0.0
% INFO    : Bus 23250	: V=0.9602587, theta=-22.780144 -> V=1.0, theta=0.0
% INFO    : Bus 23251	: V=0.9593577, theta=-22.777982 -> V=1.0, theta=0.0
% INFO    : Bus 23252	: V=0.9605042, theta=-22.787527 -> V=1.0, theta=0.0
% INFO    : Bus 23253	: V=0.9862819, theta=-20.605033 -> V=1.0, theta=0.0
% INFO    : Bus 23254	: V=0.9673933, theta=-22.198 -> V=1.0, theta=0.0
% INFO    : Bus 23255	: V=0.969556, theta=-22.054977 -> V=1.0, theta=0.0
% INFO    : Bus 23256	: V=0.9735736, theta=-21.656758 -> V=1.0, theta=0.0
% INFO    : Bus 23257	: V=0.9671226, theta=-22.036458 -> V=1.0, theta=0.0
% INFO    : Bus 23258	: V=0.962713, theta=-22.587914 -> V=1.0, theta=0.0
% INFO    : Bus 23259	: V=0.972735, theta=-21.745555 -> V=1.0, theta=0.0
% INFO    : Bus 23260	: V=0.9636469, theta=-22.592116 -> V=1.0, theta=0.0
% INFO    : Bus 23261	: V=0.9632797, theta=-22.633648 -> V=1.0, theta=0.0
% INFO    : Bus 23262	: V=0.9630941, theta=-22.69613 -> V=1.0, theta=0.0
% INFO    : Bus 23263	: V=0.9633697, theta=-22.631193 -> V=1.0, theta=0.0
% INFO    : Bus 23264	: V=0.9616661, theta=-22.705916 -> V=1.0, theta=0.0
% INFO    : Bus 23265	: V=0.9620833, theta=-22.703338 -> V=1.0, theta=0.0
% INFO    : Bus 23266	: V=0.9631697, theta=-22.67889 -> V=1.0, theta=0.0
% INFO    : Bus 23267	: V=0.9747386, theta=-21.999074 -> V=1.0, theta=0.0
% INFO    : Bus 23268	: V=0.9750188, theta=-21.990314 -> V=1.0, theta=0.0
% INFO    : Bus 23269	: V=0.9629954, theta=-22.724526 -> V=1.0, theta=0.0
% INFO    : Bus 23270	: V=0.9623594, theta=-22.773896 -> V=1.0, theta=0.0
% INFO    : Bus 23271	: V=0.9619554, theta=-22.731826 -> V=1.0, theta=0.0
% INFO    : Bus 23272	: V=0.9618748, theta=-22.766539 -> V=1.0, theta=0.0
% INFO    : Bus 23273	: V=0.9618571, theta=-22.812815 -> V=1.0, theta=0.0
% INFO    : Bus 23274	: V=0.9636931, theta=-22.757583 -> V=1.0, theta=0.0
% INFO    : Bus 23275	: V=0.975302, theta=-21.981803 -> V=1.0, theta=0.0
% INFO    : Bus 23276	: V=0.9609202, theta=-22.860125 -> V=1.0, theta=0.0
% INFO    : Bus 23277	: V=0.9619988, theta=-22.852299 -> V=1.0, theta=0.0
% INFO    : Bus 23278	: V=0.9646584, theta=-22.793021 -> V=1.0, theta=0.0
% INFO    : Bus 23279	: V=0.9653521, theta=-22.812714 -> V=1.0, theta=0.0
% INFO    : Bus 23280	: V=0.9621324, theta=-22.866552 -> V=1.0, theta=0.0
% INFO    : Bus 23281	: V=0.9609145, theta=-22.867671 -> V=1.0, theta=0.0
% INFO    : Bus 23282	: V=0.961166, theta=-22.867044 -> V=1.0, theta=0.0
% INFO    : Bus 23283	: V=0.9637024, theta=-22.881697 -> V=1.0, theta=0.0
% INFO    : Bus 23284	: V=0.9650504, theta=-22.88933 -> V=1.0, theta=0.0
% INFO    : Bus 23285	: V=0.9660131, theta=-22.838459 -> V=1.0, theta=0.0
% INFO    : Bus 23286	: V=0.9704519, theta=-22.155296 -> V=1.0, theta=0.0
% INFO    : Bus 23287	: V=0.9751284, theta=-21.701567 -> V=1.0, theta=0.0
% INFO    : Bus 23288	: V=0.9725919, theta=-22.169174 -> V=1.0, theta=0.0
% INFO    : Bus 23289	: V=0.9723305, theta=-22.168868 -> V=1.0, theta=0.0
% INFO    : Bus 23290	: V=0.9736292, theta=-22.001471 -> V=1.0, theta=0.0
% INFO    : Bus 23291	: V=0.9778464, theta=-21.605931 -> V=1.0, theta=0.0
% INFO    : Bus 23292	: V=0.9777902, theta=-21.661309 -> V=1.0, theta=0.0
% INFO    : Bus 23293	: V=0.9740635, theta=-21.786553 -> V=1.0, theta=0.0
% INFO    : Bus 23294	: V=0.9721736, theta=-22.271416 -> V=1.0, theta=0.0
% INFO    : Bus 23295	: V=0.9769729, theta=-21.775979 -> V=1.0, theta=0.0
% INFO    : Bus 23296	: V=0.9786135, theta=-21.658698 -> V=1.0, theta=0.0
% INFO    : Bus 23297	: V=0.9723065, theta=-22.243879 -> V=1.0, theta=0.0
% INFO    : Bus 23298	: V=0.9721343, theta=-22.301898 -> V=1.0, theta=0.0
% INFO    : Bus 23299	: V=0.971742, theta=-22.139651 -> V=1.0, theta=0.0
% INFO    : Bus 23300	: V=0.9753066, theta=-21.807118 -> V=1.0, theta=0.0
% INFO    : Bus 23301	: V=0.9753872, theta=-21.851782 -> V=1.0, theta=0.0
% INFO    : Bus 23302	: V=0.9723156, theta=-22.320791 -> V=1.0, theta=0.0
% INFO    : Bus 23303	: V=0.9726469, theta=-22.340123 -> V=1.0, theta=0.0
% INFO    : Bus 23304	: V=0.9702135, theta=-22.581244 -> V=1.0, theta=0.0
% INFO    : Bus 23305	: V=0.9709275, theta=-22.504075 -> V=1.0, theta=0.0
% INFO    : Bus 23306	: V=0.9784701, theta=-21.675342 -> V=1.0, theta=0.0
% INFO    : Bus 23307	: V=0.9760606, theta=-21.912148 -> V=1.0, theta=0.0
% INFO    : Bus 23308	: V=0.9756181, theta=-21.981116 -> V=1.0, theta=0.0
% INFO    : Bus 23309	: V=0.970047, theta=-22.611948 -> V=1.0, theta=0.0
% INFO    : Bus 23310	: V=0.9756269, theta=-21.941757 -> V=1.0, theta=0.0
% INFO    : Bus 23311	: V=0.9689371, theta=-22.729167 -> V=1.0, theta=0.0
% INFO    : Bus 23312	: V=0.9733656, theta=-22.360579 -> V=1.0, theta=0.0
% INFO    : Bus 23313	: V=0.9757636, theta=-21.967062 -> V=1.0, theta=0.0
% INFO    : Bus 23314	: V=0.9768562, theta=-22.020601 -> V=1.0, theta=0.0
% INFO    : Bus 23315	: V=0.9672842, theta=-22.969558 -> V=1.0, theta=0.0
% INFO    : Bus 23316	: V=0.9679975, theta=-22.901017 -> V=1.0, theta=0.0
% INFO    : Bus 23317	: V=0.9690841, theta=-22.756395 -> V=1.0, theta=0.0
% INFO    : Bus 23318	: V=0.9670306, theta=-23.136841 -> V=1.0, theta=0.0
% INFO    : Bus 23319	: V=0.9681777, theta=-23.045831 -> V=1.0, theta=0.0
% INFO    : Bus 23320	: V=0.9823245, theta=-21.964974 -> V=1.0, theta=0.0
% INFO    : Bus 23321	: V=0.9729984, theta=-22.729826 -> V=1.0, theta=0.0
% INFO    : Bus 23322	: V=0.9735277, theta=-22.724809 -> V=1.0, theta=0.0
% INFO    : Bus 23323	: V=0.9668929, theta=-22.857918 -> V=1.0, theta=0.0
% INFO    : Bus 23324	: V=0.9755165, theta=-21.901721 -> V=1.0, theta=0.0
% INFO    : Bus 23325	: V=0.9681054, theta=-22.808293 -> V=1.0, theta=0.0
% INFO    : Bus 23326	: V=0.9673539, theta=-22.890784 -> V=1.0, theta=0.0
% INFO    : Bus 23327	: V=0.9934655, theta=-19.400111 -> V=1.0, theta=0.0
% INFO    : Bus 23328	: V=0.9790222, theta=-22.16788 -> V=1.0, theta=0.0
% INFO    : Bus 23329	: V=0.9902299, theta=-21.023957 -> V=1.0, theta=0.0
% INFO    : Bus 23330	: V=1.0018563, theta=-19.364813 -> V=1.0, theta=0.0
% INFO    : Bus 23331	: V=0.9784116, theta=-20.815581 -> V=1.0, theta=0.0
% INFO    : Bus 23332	: V=0.9693334, theta=-22.967929 -> V=1.0, theta=0.0
% INFO    : Bus 23333	: V=0.9883528, theta=-20.788801 -> V=1.0, theta=0.0
% INFO    : Bus 23334	: V=0.9806539, theta=2.764786 -> V=1.0, theta=0.0
% INFO    : Bus 23335	: V=0.9812859, theta=2.4546 -> V=1.0, theta=0.0
% INFO    : Bus 23336	: V=0.9850144, theta=2.956115 -> V=1.0, theta=0.0
% INFO    : Bus 23337	: V=0.9899146, theta=3.603179 -> V=1.0, theta=0.0
% INFO    : Bus 23338	: V=0.9896923, theta=3.369794 -> V=1.0, theta=0.0
% INFO    : Bus 23339	: V=1.0014854, theta=3.668594 -> V=1.0, theta=0.0
% INFO    : Bus 23340	: V=1.0048919, theta=5.83779 -> V=1.0, theta=0.0
% INFO    : Bus 23341	: V=0.9925079, theta=4.44699 -> V=1.0, theta=0.0
% INFO    : Bus 23342	: V=0.9944902, theta=4.291286 -> V=1.0, theta=0.0
% INFO    : Bus 23343	: V=1.0148616, theta=11.647003 -> V=1.0, theta=0.0
% INFO    : Bus 23344	: V=1.0149893, theta=11.641714 -> V=1.0, theta=0.0
% INFO    : Bus 23345	: V=1.0148043, theta=11.794218 -> V=1.0, theta=0.0
% INFO    : Bus 23346	: V=1.0152553, theta=11.76679 -> V=1.0, theta=0.0
% INFO    : Bus 23347	: V=1.015655, theta=11.746352 -> V=1.0, theta=0.0
% INFO    : Bus 23348	: V=1.0165527, theta=11.707752 -> V=1.0, theta=0.0
% INFO    : Bus 23349	: V=1.0163297, theta=11.617685 -> V=1.0, theta=0.0
% INFO    : Bus 23350	: V=1.014637, theta=11.677753 -> V=1.0, theta=0.0
% INFO    : Bus 23351	: V=0.9769915, theta=12.599453 -> V=1.0, theta=0.0
% INFO    : Bus 23352	: V=0.9976347, theta=11.702218 -> V=1.0, theta=0.0
% INFO    : Bus 23353	: V=0.9999391, theta=10.780276 -> V=1.0, theta=0.0
% INFO    : Bus 23354	: V=0.9966561, theta=10.716758 -> V=1.0, theta=0.0
% INFO    : Bus 23355	: V=0.9941348, theta=10.710999 -> V=1.0, theta=0.0
% INFO    : Bus 23356	: V=0.9932821, theta=10.568711 -> V=1.0, theta=0.0
% INFO    : Bus 23357	: V=0.9914758, theta=10.641774 -> V=1.0, theta=0.0
% INFO    : Bus 23358	: V=0.9918668, theta=10.742445 -> V=1.0, theta=0.0
% INFO    : Bus 23359	: V=0.9899675, theta=10.504523 -> V=1.0, theta=0.0
% INFO    : Bus 23360	: V=0.9865915, theta=10.678007 -> V=1.0, theta=0.0
% INFO    : Bus 23361	: V=0.982751, theta=9.857227 -> V=1.0, theta=0.0
% INFO    : Bus 23362	: V=0.9863015, theta=12.564582 -> V=1.0, theta=0.0
% INFO    : Bus 23363	: V=0.9828127, theta=12.550512 -> V=1.0, theta=0.0
% INFO    : Bus 23364	: V=0.990352, theta=14.262916 -> V=1.0, theta=0.0
% INFO    : Bus 23365	: V=1.013048, theta=11.573029 -> V=1.0, theta=0.0
% INFO    : Bus 23366	: V=0.9979484, theta=10.258285 -> V=1.0, theta=0.0
% INFO    : Bus 23367	: V=1.0079399, theta=4.768858 -> V=1.0, theta=0.0
% INFO    : Bus 23368	: V=1.0122636, theta=6.493032 -> V=1.0, theta=0.0
% INFO    : Bus 23369	: V=1.009042, theta=7.051757 -> V=1.0, theta=0.0
% INFO    : Bus 23370	: V=1.0176741, theta=8.110604 -> V=1.0, theta=0.0
% INFO    : Bus 23371	: V=1.0197101, theta=9.205488 -> V=1.0, theta=0.0
% INFO    : Bus 23372	: V=1.0160871, theta=8.155669 -> V=1.0, theta=0.0
% INFO    : Bus 23373	: V=1.0036281, theta=5.975157 -> V=1.0, theta=0.0
% INFO    : Bus 23374	: V=1.0112798, theta=7.90115 -> V=1.0, theta=0.0
% INFO    : Bus 23375	: V=0.9700971, theta=-0.661761 -> V=1.0, theta=0.0
% INFO    : Bus 23376	: V=0.9727496, theta=-0.639336 -> V=1.0, theta=0.0
% INFO    : Bus 23377	: V=0.9739634, theta=0.026286 -> V=1.0, theta=0.0
% INFO    : Bus 23378	: V=0.9767651, theta=-0.113911 -> V=1.0, theta=0.0
% INFO    : Bus 23379	: V=0.9802714, theta=-0.005884 -> V=1.0, theta=0.0
% INFO    : Bus 23380	: V=0.9787148, theta=0.063938 -> V=1.0, theta=0.0
% INFO    : Bus 23381	: V=0.9846455, theta=1.336077 -> V=1.0, theta=0.0
% INFO    : Bus 23382	: V=0.9772799, theta=-0.35497 -> V=1.0, theta=0.0
% INFO    : Bus 23383	: V=0.9811398, theta=0.369628 -> V=1.0, theta=0.0
% INFO    : Bus 23384	: V=0.9751416, theta=-1.216512 -> V=1.0, theta=0.0
% INFO    : Bus 23385	: V=0.9773966, theta=0.058704 -> V=1.0, theta=0.0
% INFO    : Bus 23386	: V=0.9642804, theta=19.986353 -> V=1.0, theta=0.0
% INFO    : Bus 23387	: V=0.9699324, theta=22.09853 -> V=1.0, theta=0.0
% INFO    : Bus 23388	: V=0.9603875, theta=25.271788 -> V=1.0, theta=0.0
% INFO    : Bus 23389	: V=0.9513517, theta=31.0837 -> V=1.0, theta=0.0
% INFO    : Bus 23390	: V=0.9519953, theta=35.598641 -> V=1.0, theta=0.0
% INFO    : Bus 23391	: V=0.9595958, theta=37.614244 -> V=1.0, theta=0.0
% INFO    : Bus 23392	: V=0.9705149, theta=41.20393 -> V=1.0, theta=0.0
% INFO    : Bus 23393	: V=1.0041602, theta=-4.480463 -> V=1.0, theta=0.0
% INFO    : Bus 23394	: V=1.004535, theta=-4.565644 -> V=1.0, theta=0.0
% INFO    : Bus 23395	: V=1.0037296, theta=-4.549094 -> V=1.0, theta=0.0
% INFO    : Bus 23396	: V=0.9953052, theta=-5.026234 -> V=1.0, theta=0.0
% INFO    : Bus 23397	: V=1.0063408, theta=-4.342951 -> V=1.0, theta=0.0
% INFO    : Bus 23398	: V=1.0203144, theta=-2.699602 -> V=1.0, theta=0.0
% INFO    : Bus 23399	: V=1.0005155, theta=-4.653122 -> V=1.0, theta=0.0
% INFO    : Bus 23400	: V=1.0035782, theta=-4.674948 -> V=1.0, theta=0.0
% INFO    : Bus 23401	: V=1.0034121, theta=-4.614285 -> V=1.0, theta=0.0
% INFO    : Bus 23402	: V=0.9938554, theta=-5.093197 -> V=1.0, theta=0.0
% INFO    : Bus 23403	: V=0.9832639, theta=-5.768003 -> V=1.0, theta=0.0
% INFO    : Bus 23404	: V=0.993895, theta=-5.085405 -> V=1.0, theta=0.0
% INFO    : Bus 23405	: V=1.0011004, theta=-4.44405 -> V=1.0, theta=0.0
% INFO    : Bus 23406	: V=1.0039317, theta=-4.336279 -> V=1.0, theta=0.0
% INFO    : Bus 23407	: V=0.9958322, theta=-4.267629 -> V=1.0, theta=0.0
% INFO    : Bus 23408	: V=0.9984105, theta=-4.374789 -> V=1.0, theta=0.0
% INFO    : Bus 23409	: V=0.979315, theta=-5.264 -> V=1.0, theta=0.0
% INFO    : Bus 23410	: V=0.9831701, theta=-5.212588 -> V=1.0, theta=0.0
% INFO    : Bus 23411	: V=0.9863665, theta=-4.947962 -> V=1.0, theta=0.0
% INFO    : Bus 23412	: V=0.9750774, theta=-1.468773 -> V=1.0, theta=0.0
% INFO    : Bus 23413	: V=0.9899091, theta=0.073541 -> V=1.0, theta=0.0
% INFO    : Bus 23414	: V=0.9883997, theta=-0.53601 -> V=1.0, theta=0.0
% INFO    : Bus 23415	: V=0.9752009, theta=-1.962182 -> V=1.0, theta=0.0
% INFO    : Bus 23416	: V=0.9867677, theta=-24.460546 -> V=1.0, theta=0.0
% INFO    : Bus 23417	: V=0.9858723, theta=-24.644672 -> V=1.0, theta=0.0
% INFO    : Bus 23418	: V=0.9869406, theta=-26.044521 -> V=1.0, theta=0.0
% INFO    : Bus 23419	: V=0.9729784, theta=-27.299043 -> V=1.0, theta=0.0
% INFO    : Bus 23420	: V=0.97357, theta=-27.418674 -> V=1.0, theta=0.0
% INFO    : Bus 23421	: V=0.960778, theta=-28.008909 -> V=1.0, theta=0.0
% INFO    : Bus 23422	: V=0.9530428, theta=-29.182557 -> V=1.0, theta=0.0
% INFO    : Bus 23423	: V=0.9529909, theta=-30.38674 -> V=1.0, theta=0.0
% INFO    : Bus 23424	: V=0.9695289, theta=-28.389904 -> V=1.0, theta=0.0
% INFO    : Bus 23425	: V=0.967613, theta=-29.029854 -> V=1.0, theta=0.0
% INFO    : Bus 23426	: V=0.9716991, theta=-28.583426 -> V=1.0, theta=0.0
% INFO    : Bus 23427	: V=0.9923207, theta=-26.785038 -> V=1.0, theta=0.0
% INFO    : Bus 23428	: V=0.9910299, theta=-27.103098 -> V=1.0, theta=0.0
% INFO    : Bus 23429	: V=0.9716067, theta=-28.648559 -> V=1.0, theta=0.0
% INFO    : Bus 23430	: V=0.975671, theta=-28.564819 -> V=1.0, theta=0.0
% INFO    : Bus 23431	: V=0.977508, theta=-28.475553 -> V=1.0, theta=0.0
% INFO    : Bus 23432	: V=0.9969864, theta=-26.546502 -> V=1.0, theta=0.0
% INFO    : Bus 23433	: V=0.9778671, theta=-28.700418 -> V=1.0, theta=0.0
% INFO    : Bus 23434	: V=0.9746022, theta=-28.722231 -> V=1.0, theta=0.0
% INFO    : Bus 23435	: V=0.9732906, theta=-28.723282 -> V=1.0, theta=0.0
% INFO    : Bus 23436	: V=0.9731088, theta=-28.704476 -> V=1.0, theta=0.0
% INFO    : Bus 23437	: V=0.9729305, theta=-28.745428 -> V=1.0, theta=0.0
% INFO    : Bus 23438	: V=0.9723729, theta=-28.76537 -> V=1.0, theta=0.0
% INFO    : Bus 23439	: V=0.9867407, theta=-28.628308 -> V=1.0, theta=0.0
% INFO    : Bus 23440	: V=0.9764033, theta=-29.065469 -> V=1.0, theta=0.0
% INFO    : Bus 23441	: V=0.9812339, theta=-29.362437 -> V=1.0, theta=0.0
% INFO    : Bus 23442	: V=0.9798159, theta=-29.36435 -> V=1.0, theta=0.0
% INFO    : Bus 23443	: V=0.9635265, theta=-30.126568 -> V=1.0, theta=0.0
% INFO    : Bus 23444	: V=0.9550791, theta=-30.467365 -> V=1.0, theta=0.0
% INFO    : Bus 23445	: V=0.9472482, theta=-34.562067 -> V=1.0, theta=0.0
% INFO    : Bus 23446	: V=0.968558, theta=-31.52855 -> V=1.0, theta=0.0
% INFO    : Bus 23447	: V=0.9746342, theta=-30.807491 -> V=1.0, theta=0.0
% INFO    : Bus 23448	: V=0.962341, theta=-32.469056 -> V=1.0, theta=0.0
% INFO    : Bus 23449	: V=0.9810648, theta=-30.585478 -> V=1.0, theta=0.0
% INFO    : Bus 23450	: V=1.0003826, theta=-28.062488 -> V=1.0, theta=0.0
% INFO    : Bus 23451	: V=0.9905559, theta=-29.307299 -> V=1.0, theta=0.0
% INFO    : Bus 23452	: V=0.9715478, theta=-31.523117 -> V=1.0, theta=0.0
% INFO    : Bus 23453	: V=0.9685675, theta=-31.943838 -> V=1.0, theta=0.0
% INFO    : Bus 23454	: V=0.9791876, theta=-3.381803 -> V=1.0, theta=0.0
% INFO    : Bus 23455	: V=0.9781125, theta=-2.979975 -> V=1.0, theta=0.0
% INFO    : Bus 23456	: V=0.9742705, theta=-2.713304 -> V=1.0, theta=0.0
% INFO    : Bus 23457	: V=0.9752015, theta=-2.276623 -> V=1.0, theta=0.0
% INFO    : Bus 23458	: V=0.966378, theta=-1.197015 -> V=1.0, theta=0.0
% INFO    : Bus 23459	: V=0.965497, theta=-1.551227 -> V=1.0, theta=0.0
% INFO    : Bus 23460	: V=0.9672591, theta=-2.344723 -> V=1.0, theta=0.0
% INFO    : Bus 23461	: V=0.9777283, theta=-3.08553 -> V=1.0, theta=0.0
% INFO    : Bus 23462	: V=0.9841736, theta=-3.307789 -> V=1.0, theta=0.0
% INFO    : Bus 23463	: V=0.9969787, theta=-2.846355 -> V=1.0, theta=0.0
% INFO    : Bus 23464	: V=0.9816245, theta=-2.589672 -> V=1.0, theta=0.0
% INFO    : Bus 23465	: V=0.9783386, theta=-2.288178 -> V=1.0, theta=0.0
% INFO    : Bus 23466	: V=0.9769056, theta=-2.46383 -> V=1.0, theta=0.0
% INFO    : Bus 23467	: V=1.0054226, theta=-3.736377 -> V=1.0, theta=0.0
% INFO    : Bus 23468	: V=1.0018144, theta=-2.556004 -> V=1.0, theta=0.0
% INFO    : Bus 23469	: V=0.991116, theta=-4.018928 -> V=1.0, theta=0.0
% INFO    : Bus 23470	: V=0.9942896, theta=-3.258904 -> V=1.0, theta=0.0
% INFO    : Bus 23471	: V=0.9946081, theta=-3.131243 -> V=1.0, theta=0.0
% INFO    : Bus 23472	: V=0.9815667, theta=2.397098 -> V=1.0, theta=0.0
% INFO    : Bus 23473	: V=0.981429, theta=2.406143 -> V=1.0, theta=0.0
% INFO    : Bus 23474	: V=0.9818153, theta=2.408422 -> V=1.0, theta=0.0
% INFO    : Bus 23475	: V=1.0051755, theta=4.849486 -> V=1.0, theta=0.0
% INFO    : Bus 23476	: V=0.9820968, theta=2.423388 -> V=1.0, theta=0.0
% INFO    : Bus 23477	: V=0.9810306, theta=2.379104 -> V=1.0, theta=0.0
% INFO    : Bus 23478	: V=0.9810677, theta=2.396887 -> V=1.0, theta=0.0
% INFO    : Bus 23479	: V=0.9926613, theta=3.4974 -> V=1.0, theta=0.0
% INFO    : Bus 23480	: V=0.9923546, theta=3.511152 -> V=1.0, theta=0.0
% INFO    : Bus 23481	: V=0.9896214, theta=3.060584 -> V=1.0, theta=0.0
% INFO    : Bus 23482	: V=0.9901941, theta=3.090626 -> V=1.0, theta=0.0
% INFO    : Bus 23483	: V=0.9816137, theta=2.415545 -> V=1.0, theta=0.0
% INFO    : Bus 23484	: V=0.9800316, theta=2.426133 -> V=1.0, theta=0.0
% INFO    : Bus 23485	: V=0.9913809, theta=3.644309 -> V=1.0, theta=0.0
% INFO    : Bus 23486	: V=0.9811308, theta=2.651567 -> V=1.0, theta=0.0
% INFO    : Bus 23487	: V=0.9920426, theta=3.435365 -> V=1.0, theta=0.0
% INFO    : Bus 23488	: V=0.9805555, theta=2.307108 -> V=1.0, theta=0.0
% INFO    : Bus 23489	: V=0.9829887, theta=2.446079 -> V=1.0, theta=0.0
% INFO    : Bus 23490	: V=0.9838249, theta=2.623976 -> V=1.0, theta=0.0
% INFO    : Bus 23491	: V=0.981041, theta=2.38726 -> V=1.0, theta=0.0
% INFO    : Bus 23492	: V=0.9931366, theta=3.487317 -> V=1.0, theta=0.0
% INFO    : Bus 23493	: V=0.9826712, theta=2.389483 -> V=1.0, theta=0.0
% INFO    : Bus 23494	: V=0.9841548, theta=2.55846 -> V=1.0, theta=0.0
% INFO    : Bus 23495	: V=0.9966509, theta=3.606912 -> V=1.0, theta=0.0
% INFO    : Bus 23496	: V=0.985492, theta=2.569501 -> V=1.0, theta=0.0
% INFO    : Bus 23497	: V=1.0066548, theta=4.657509 -> V=1.0, theta=0.0
% INFO    : Bus 23498	: V=0.983619, theta=2.571663 -> V=1.0, theta=0.0
% INFO    : Bus 23499	: V=0.9883612, theta=2.888939 -> V=1.0, theta=0.0
% INFO    : Bus 23500	: V=0.9783194, theta=2.433458 -> V=1.0, theta=0.0
% INFO    : Bus 23501	: V=0.975924, theta=1.185027 -> V=1.0, theta=0.0
% INFO    : Bus 23502	: V=0.9870818, theta=2.623121 -> V=1.0, theta=0.0
% INFO    : Bus 23503	: V=0.9765039, theta=2.239556 -> V=1.0, theta=0.0
% INFO    : Bus 23504	: V=0.9832487, theta=2.308967 -> V=1.0, theta=0.0
% INFO    : Bus 23505	: V=0.9919489, theta=3.586525 -> V=1.0, theta=0.0
% INFO    : Bus 23506	: V=0.9927892, theta=3.977766 -> V=1.0, theta=0.0
% INFO    : Bus 23507	: V=0.9924711, theta=3.78563 -> V=1.0, theta=0.0
% INFO    : Bus 23508	: V=0.9938972, theta=4.245748 -> V=1.0, theta=0.0
% INFO    : Bus 23509	: V=0.9804128, theta=3.204046 -> V=1.0, theta=0.0
% INFO    : Bus 23510	: V=0.9833714, theta=3.50398 -> V=1.0, theta=0.0
% INFO    : Bus 23511	: V=0.9935612, theta=4.108258 -> V=1.0, theta=0.0
% INFO    : Bus 23512	: V=0.9801228, theta=2.423723 -> V=1.0, theta=0.0
% INFO    : Bus 23513	: V=0.9823147, theta=2.417266 -> V=1.0, theta=0.0
% INFO    : Bus 23514	: V=0.9917047, theta=3.240137 -> V=1.0, theta=0.0
% INFO    : Bus 23515	: V=0.9784048, theta=2.131827 -> V=1.0, theta=0.0
% INFO    : Bus 23516	: V=0.9746598, theta=1.252298 -> V=1.0, theta=0.0
% INFO    : Bus 23517	: V=0.9815506, theta=1.784204 -> V=1.0, theta=0.0
% INFO    : Bus 23518	: V=0.9770983, theta=1.516724 -> V=1.0, theta=0.0
% INFO    : Bus 23519	: V=0.9852947, theta=1.345827 -> V=1.0, theta=0.0
% INFO    : Bus 23520	: V=0.9906362, theta=0.945008 -> V=1.0, theta=0.0
% INFO    : Bus 23521	: V=0.978766, theta=1.014004 -> V=1.0, theta=0.0
% INFO    : Bus 23522	: V=0.9679306, theta=0.711634 -> V=1.0, theta=0.0
% INFO    : Bus 23523	: V=0.9736059, theta=0.753621 -> V=1.0, theta=0.0
% INFO    : Bus 23524	: V=0.9779452, theta=1.150037 -> V=1.0, theta=0.0
% INFO    : Bus 23525	: V=0.960598, theta=-18.5939 -> V=1.0, theta=0.0
% INFO    : Bus 23526	: V=0.9629959, theta=-18.589879 -> V=1.0, theta=0.0
% INFO    : Bus 23527	: V=0.9820619, theta=-16.457422 -> V=1.0, theta=0.0
% INFO    : Bus 23528	: V=0.968785, theta=-17.675281 -> V=1.0, theta=0.0
% INFO    : Bus 23529	: V=0.9696587, theta=-18.865332 -> V=1.0, theta=0.0
% INFO    : Bus 23530	: V=0.9651211, theta=-19.087495 -> V=1.0, theta=0.0
% INFO    : Bus 23531	: V=0.9646853, theta=-19.347513 -> V=1.0, theta=0.0
% INFO    : Bus 23532	: V=0.9693718, theta=-16.710196 -> V=1.0, theta=0.0
% INFO    : Bus 23533	: V=0.9663358, theta=-18.179896 -> V=1.0, theta=0.0
% INFO    : Bus 23534	: V=0.9658561, theta=-18.091838 -> V=1.0, theta=0.0
% INFO    : Bus 23535	: V=0.9686371, theta=-16.853091 -> V=1.0, theta=0.0
% INFO    : Bus 23536	: V=0.959355, theta=-16.828857 -> V=1.0, theta=0.0
% INFO    : Bus 23537	: V=0.9678755, theta=-17.012111 -> V=1.0, theta=0.0
% INFO    : Bus 23538	: V=0.9647169, theta=-16.385567 -> V=1.0, theta=0.0
% INFO    : Bus 23539	: V=0.9663774, theta=-16.507517 -> V=1.0, theta=0.0
% INFO    : Bus 23540	: V=0.9626908, theta=-17.368978 -> V=1.0, theta=0.0
% INFO    : Bus 23541	: V=0.9629586, theta=-17.547289 -> V=1.0, theta=0.0
% INFO    : Bus 23542	: V=0.9636562, theta=-18.483033 -> V=1.0, theta=0.0
% INFO    : Bus 23543	: V=0.9664736, theta=-18.3009 -> V=1.0, theta=0.0
% INFO    : Bus 23544	: V=0.9660934, theta=-18.45393 -> V=1.0, theta=0.0
% INFO    : Bus 23545	: V=0.9656895, theta=-18.646884 -> V=1.0, theta=0.0
% INFO    : Bus 23546	: V=0.9600442, theta=-18.251027 -> V=1.0, theta=0.0
% INFO    : Bus 23547	: V=0.9645383, theta=-18.69059 -> V=1.0, theta=0.0
% INFO    : Bus 23548	: V=0.9591628, theta=-19.67206 -> V=1.0, theta=0.0
% INFO    : Bus 23549	: V=0.9639052, theta=-19.134686 -> V=1.0, theta=0.0
% INFO    : Bus 23550	: V=0.9592295, theta=-19.921778 -> V=1.0, theta=0.0
% INFO    : Bus 23551	: V=0.9603754, theta=-19.669262 -> V=1.0, theta=0.0
% INFO    : Bus 23552	: V=0.9594654, theta=-20.162468 -> V=1.0, theta=0.0
% INFO    : Bus 23553	: V=0.9586444, theta=-20.323058 -> V=1.0, theta=0.0
% INFO    : Bus 23554	: V=0.9643125, theta=-19.578107 -> V=1.0, theta=0.0
% INFO    : Bus 23555	: V=0.9643102, theta=-19.448096 -> V=1.0, theta=0.0
% INFO    : Bus 23556	: V=0.9627291, theta=-19.916325 -> V=1.0, theta=0.0
% INFO    : Bus 23557	: V=0.9578568, theta=-20.391669 -> V=1.0, theta=0.0
% INFO    : Bus 23558	: V=0.9662494, theta=-19.607382 -> V=1.0, theta=0.0
% INFO    : Bus 23559	: V=0.9671274, theta=-19.359511 -> V=1.0, theta=0.0
% INFO    : Bus 23560	: V=0.9636541, theta=-19.57853 -> V=1.0, theta=0.0
% INFO    : Bus 23561	: V=0.9612228, theta=-20.023552 -> V=1.0, theta=0.0
% INFO    : Bus 23562	: V=0.9573775, theta=-20.523048 -> V=1.0, theta=0.0
% INFO    : Bus 23563	: V=0.9663218, theta=-19.519793 -> V=1.0, theta=0.0
% INFO    : Bus 23564	: V=0.9676277, theta=-19.252307 -> V=1.0, theta=0.0
% INFO    : Bus 23565	: V=0.964931, theta=-19.248683 -> V=1.0, theta=0.0
% INFO    : Bus 23566	: V=0.9647848, theta=-19.003549 -> V=1.0, theta=0.0
% INFO    : Bus 23567	: V=0.9613861, theta=-18.673553 -> V=1.0, theta=0.0
% INFO    : Bus 23568	: V=0.9606217, theta=-19.646835 -> V=1.0, theta=0.0
% INFO    : Bus 23569	: V=0.965389, theta=-19.45 -> V=1.0, theta=0.0
% INFO    : Bus 23570	: V=0.9613266, theta=-19.634942 -> V=1.0, theta=0.0
% INFO    : Bus 23571	: V=0.963172, theta=-20.076742 -> V=1.0, theta=0.0
% INFO    : Bus 23572	: V=0.9667804, theta=-19.543913 -> V=1.0, theta=0.0
% INFO    : Bus 23573	: V=0.961557, theta=-18.141239 -> V=1.0, theta=0.0
% INFO    : Bus 23574	: V=0.9609623, theta=-18.46575 -> V=1.0, theta=0.0
% INFO    : Bus 23575	: V=0.9613311, theta=-18.25385 -> V=1.0, theta=0.0
% INFO    : Bus 23576	: V=0.9619776, theta=-17.955349 -> V=1.0, theta=0.0
% INFO    : Bus 23577	: V=0.9614027, theta=-17.797115 -> V=1.0, theta=0.0
% INFO    : Bus 23578	: V=0.9604174, theta=-17.970554 -> V=1.0, theta=0.0
% INFO    : Bus 23579	: V=0.9609347, theta=-19.185221 -> V=1.0, theta=0.0
% INFO    : Bus 23580	: V=0.9605824, theta=-19.753271 -> V=1.0, theta=0.0
% INFO    : Bus 23581	: V=0.9530938, theta=-19.704476 -> V=1.0, theta=0.0
% INFO    : Bus 23582	: V=0.9610381, theta=-18.908963 -> V=1.0, theta=0.0
% INFO    : Bus 23583	: V=0.9613255, theta=-20.276926 -> V=1.0, theta=0.0
% INFO    : Bus 23584	: V=0.9597024, theta=-19.49896 -> V=1.0, theta=0.0
% INFO    : Bus 23585	: V=0.9595735, theta=-20.908831 -> V=1.0, theta=0.0
% INFO    : Bus 23586	: V=0.9782755, theta=-19.470654 -> V=1.0, theta=0.0
% INFO    : Bus 23587	: V=0.9633645, theta=-20.096675 -> V=1.0, theta=0.0
% INFO    : Bus 23588	: V=0.9611367, theta=-20.663158 -> V=1.0, theta=0.0
% INFO    : Bus 23589	: V=0.9699836, theta=-19.677527 -> V=1.0, theta=0.0
% INFO    : Bus 23590	: V=0.9730433, theta=-19.67952 -> V=1.0, theta=0.0
% INFO    : Bus 23591	: V=0.9596967, theta=-20.768304 -> V=1.0, theta=0.0
% INFO    : Bus 23592	: V=0.9617136, theta=-21.080573 -> V=1.0, theta=0.0
% INFO    : Bus 23593	: V=0.9671577, theta=-21.184674 -> V=1.0, theta=0.0
% INFO    : Bus 23594	: V=0.9619494, theta=-21.249007 -> V=1.0, theta=0.0
% INFO    : Bus 23595	: V=0.960094, theta=-19.412559 -> V=1.0, theta=0.0
% INFO    : Bus 23596	: V=0.9610647, theta=-20.346415 -> V=1.0, theta=0.0
% INFO    : Bus 23597	: V=0.9589186, theta=-20.840321 -> V=1.0, theta=0.0
% INFO    : Bus 23598	: V=0.96063, theta=-19.982307 -> V=1.0, theta=0.0
% INFO    : Bus 23599	: V=0.9611106, theta=-22.185281 -> V=1.0, theta=0.0
% INFO    : Bus 23600	: V=0.968057, theta=-22.16337 -> V=1.0, theta=0.0
% INFO    : Bus 23601	: V=0.9597228, theta=-21.117391 -> V=1.0, theta=0.0
% INFO    : Bus 23602	: V=0.9579118, theta=-22.841638 -> V=1.0, theta=0.0
% INFO    : Bus 23603	: V=0.9588115, theta=-23.01352 -> V=1.0, theta=0.0
% INFO    : Bus 23604	: V=0.9685833, theta=-22.324662 -> V=1.0, theta=0.0
% INFO    : Bus 23605	: V=0.9584441, theta=-23.03523 -> V=1.0, theta=0.0
% INFO    : Bus 23606	: V=0.963542, theta=-21.569623 -> V=1.0, theta=0.0
% INFO    : Bus 23607	: V=0.9626011, theta=-21.595855 -> V=1.0, theta=0.0
% INFO    : Bus 23608	: V=0.962287, theta=-22.342636 -> V=1.0, theta=0.0
% INFO    : Bus 23609	: V=0.9595034, theta=-22.797639 -> V=1.0, theta=0.0
% INFO    : Bus 23610	: V=0.961034, theta=-22.719952 -> V=1.0, theta=0.0
% INFO    : Bus 23611	: V=0.9597754, theta=-21.867546 -> V=1.0, theta=0.0
% INFO    : Bus 23612	: V=0.9570335, theta=-21.45003 -> V=1.0, theta=0.0
% INFO    : Bus 23613	: V=0.9617754, theta=-20.413349 -> V=1.0, theta=0.0
% INFO    : Bus 23614	: V=0.9630081, theta=-20.234841 -> V=1.0, theta=0.0
% INFO    : Bus 23615	: V=0.9608158, theta=-20.538233 -> V=1.0, theta=0.0
% INFO    : Bus 23616	: V=0.9591597, theta=-21.41485 -> V=1.0, theta=0.0
% INFO    : Bus 23617	: V=0.9835057, theta=-18.971011 -> V=1.0, theta=0.0
% INFO    : Bus 23618	: V=0.9622632, theta=-20.754322 -> V=1.0, theta=0.0
% INFO    : Bus 23619	: V=0.9830223, theta=-18.078531 -> V=1.0, theta=0.0
% INFO    : Bus 23620	: V=0.9654957, theta=-19.990994 -> V=1.0, theta=0.0
% INFO    : Bus 23621	: V=0.9591143, theta=-21.570387 -> V=1.0, theta=0.0
% INFO    : Bus 23622	: V=0.9594345, theta=-21.556959 -> V=1.0, theta=0.0
% INFO    : Bus 23623	: V=0.966656, theta=-20.998071 -> V=1.0, theta=0.0
% INFO    : Bus 23624	: V=0.9616159, theta=-20.278632 -> V=1.0, theta=0.0
% INFO    : Bus 23625	: V=0.957337, theta=-20.826557 -> V=1.0, theta=0.0
% INFO    : Bus 23626	: V=0.9572491, theta=-20.802039 -> V=1.0, theta=0.0
% INFO    : Bus 23627	: V=0.9573098, theta=-20.78616 -> V=1.0, theta=0.0
% INFO    : Bus 23628	: V=0.95735, theta=-20.812481 -> V=1.0, theta=0.0
% INFO    : Bus 23629	: V=0.9628846, theta=-20.26776 -> V=1.0, theta=0.0
% INFO    : Bus 23630	: V=0.959383, theta=-21.029283 -> V=1.0, theta=0.0
% INFO    : Bus 23631	: V=0.9620645, theta=-20.351769 -> V=1.0, theta=0.0
% INFO    : Bus 23632	: V=0.9581828, theta=-21.196042 -> V=1.0, theta=0.0
% INFO    : Bus 23633	: V=0.9589416, theta=-21.222123 -> V=1.0, theta=0.0
% INFO    : Bus 23634	: V=0.9587701, theta=-21.227131 -> V=1.0, theta=0.0
% INFO    : Bus 23635	: V=0.9617084, theta=-20.395069 -> V=1.0, theta=0.0
% INFO    : Bus 23636	: V=0.9663077, theta=-21.205976 -> V=1.0, theta=0.0
% INFO    : Bus 23637	: V=0.9581396, theta=-21.399081 -> V=1.0, theta=0.0
% INFO    : Bus 23638	: V=0.9582517, theta=-21.368511 -> V=1.0, theta=0.0
% INFO    : Bus 23639	: V=0.9588698, theta=-21.28773 -> V=1.0, theta=0.0
% INFO    : Bus 23640	: V=0.9572255, theta=-21.680511 -> V=1.0, theta=0.0
% INFO    : Bus 23641	: V=0.9585116, theta=-20.347675 -> V=1.0, theta=0.0
% INFO    : Bus 23642	: V=0.9628252, theta=-19.491523 -> V=1.0, theta=0.0
% INFO    : Bus 23643	: V=0.9636502, theta=-19.374723 -> V=1.0, theta=0.0
% INFO    : Bus 23644	: V=0.9636263, theta=-19.528457 -> V=1.0, theta=0.0
% INFO    : Bus 23645	: V=0.9628439, theta=-19.718226 -> V=1.0, theta=0.0
% INFO    : Bus 23646	: V=0.9589263, theta=-20.697338 -> V=1.0, theta=0.0
% INFO    : Bus 23647	: V=0.9599252, theta=-20.848217 -> V=1.0, theta=0.0
% INFO    : Bus 23648	: V=0.9593622, theta=-20.905777 -> V=1.0, theta=0.0
% INFO    : Bus 23649	: V=0.9614025, theta=-20.048834 -> V=1.0, theta=0.0
% INFO    : Bus 23650	: V=0.9599673, theta=-20.733495 -> V=1.0, theta=0.0
% INFO    : Bus 23651	: V=0.9601196, theta=-20.797105 -> V=1.0, theta=0.0
% INFO    : Bus 23652	: V=0.9611018, theta=-21.227011 -> V=1.0, theta=0.0
% INFO    : Bus 23653	: V=0.9609644, theta=-21.072546 -> V=1.0, theta=0.0
% INFO    : Bus 23654	: V=0.9612829, theta=-20.178365 -> V=1.0, theta=0.0
% INFO    : Bus 23655	: V=0.9592307, theta=-20.821475 -> V=1.0, theta=0.0
% INFO    : Bus 23656	: V=0.9599406, theta=-20.800948 -> V=1.0, theta=0.0
% INFO    : Bus 23657	: V=0.961243, theta=-20.630666 -> V=1.0, theta=0.0
% INFO    : Bus 23658	: V=0.962004, theta=-19.964071 -> V=1.0, theta=0.0
% INFO    : Bus 23659	: V=0.9591883, theta=-20.984292 -> V=1.0, theta=0.0
% INFO    : Bus 23660	: V=0.9660944, theta=-21.180899 -> V=1.0, theta=0.0
% INFO    : Bus 23661	: V=0.957126, theta=-21.691852 -> V=1.0, theta=0.0
% INFO    : Bus 23662	: V=0.9565796, theta=-22.093225 -> V=1.0, theta=0.0
% INFO    : Bus 23663	: V=0.9589242, theta=-21.821206 -> V=1.0, theta=0.0
% INFO    : Bus 23664	: V=0.9656825, theta=-21.33896 -> V=1.0, theta=0.0
% INFO    : Bus 23665	: V=0.9650737, theta=-21.618043 -> V=1.0, theta=0.0
% INFO    : Bus 23666	: V=0.9570296, theta=-22.285406 -> V=1.0, theta=0.0
% INFO    : Bus 23667	: V=0.9580547, theta=-22.530247 -> V=1.0, theta=0.0
% INFO    : Bus 23668	: V=0.9574325, theta=-22.567704 -> V=1.0, theta=0.0
% INFO    : Bus 23669	: V=0.9584713, theta=-22.558037 -> V=1.0, theta=0.0
% INFO    : Bus 23670	: V=0.9624649, theta=-22.121581 -> V=1.0, theta=0.0
% INFO    : Bus 23671	: V=0.963741, theta=-21.765952 -> V=1.0, theta=0.0
% INFO    : Bus 23672	: V=0.9588969, theta=-22.539479 -> V=1.0, theta=0.0
% INFO    : Bus 23673	: V=0.9621893, theta=-22.266959 -> V=1.0, theta=0.0
% INFO    : Bus 23674	: V=0.9582236, theta=-22.75258 -> V=1.0, theta=0.0
% INFO    : Bus 23675	: V=0.9596083, theta=-22.646428 -> V=1.0, theta=0.0
% INFO    : Bus 23676	: V=0.9592747, theta=-22.55348 -> V=1.0, theta=0.0
% INFO    : Bus 23677	: V=0.9576223, theta=-22.885929 -> V=1.0, theta=0.0
% INFO    : Bus 23678	: V=0.9579867, theta=-22.883365 -> V=1.0, theta=0.0
% INFO    : Bus 23679	: V=0.9586801, theta=-21.412526 -> V=1.0, theta=0.0
% INFO    : Bus 23680	: V=0.9615184, theta=-20.678347 -> V=1.0, theta=0.0
% INFO    : Bus 23681	: V=0.9585616, theta=-21.512336 -> V=1.0, theta=0.0
% INFO    : Bus 23682	: V=0.9612833, theta=-21.689803 -> V=1.0, theta=0.0
% INFO    : Bus 23683	: V=0.9612332, theta=-21.445826 -> V=1.0, theta=0.0
% INFO    : Bus 23684	: V=0.9587617, theta=-21.708724 -> V=1.0, theta=0.0
% INFO    : Bus 23685	: V=0.9629729, theta=-20.611768 -> V=1.0, theta=0.0
% INFO    : Bus 23686	: V=0.9658037, theta=-20.408897 -> V=1.0, theta=0.0
% INFO    : Bus 23687	: V=0.9597943, theta=-21.790747 -> V=1.0, theta=0.0
% INFO    : Bus 23688	: V=0.9604135, theta=-21.913263 -> V=1.0, theta=0.0
% INFO    : Bus 23689	: V=0.9633768, theta=-22.004927 -> V=1.0, theta=0.0
% INFO    : Bus 23690	: V=0.9612853, theta=-22.393494 -> V=1.0, theta=0.0
% INFO    : Bus 23691	: V=0.9594071, theta=-22.468629 -> V=1.0, theta=0.0
% INFO    : Bus 23692	: V=0.9608187, theta=-22.178788 -> V=1.0, theta=0.0
% INFO    : Bus 23693	: V=0.9760144, theta=-19.762683 -> V=1.0, theta=0.0
% INFO    : Bus 23694	: V=0.9666584, theta=-21.364285 -> V=1.0, theta=0.0
% INFO    : Bus 23695	: V=0.9743025, theta=-19.95992 -> V=1.0, theta=0.0
% INFO    : Bus 23696	: V=0.9749913, theta=-19.870545 -> V=1.0, theta=0.0
% INFO    : Bus 23697	: V=0.9737195, theta=-19.995848 -> V=1.0, theta=0.0
% INFO    : Bus 23698	: V=0.965682, theta=-21.989999 -> V=1.0, theta=0.0
% INFO    : Bus 23699	: V=0.9623658, theta=-22.305891 -> V=1.0, theta=0.0
% INFO    : Bus 23700	: V=0.9610689, theta=-22.173207 -> V=1.0, theta=0.0
% INFO    : Bus 23701	: V=0.9560768, theta=-23.228653 -> V=1.0, theta=0.0
% INFO    : Bus 23702	: V=0.9618917, theta=-22.400898 -> V=1.0, theta=0.0
% INFO    : Bus 23703	: V=0.9578979, theta=-22.985357 -> V=1.0, theta=0.0
% INFO    : Bus 23704	: V=0.9572524, theta=-22.931049 -> V=1.0, theta=0.0
% INFO    : Bus 23705	: V=0.9557356, theta=-23.475119 -> V=1.0, theta=0.0
% INFO    : Bus 23706	: V=0.9565091, theta=-23.316912 -> V=1.0, theta=0.0
% INFO    : Bus 23707	: V=0.9572702, theta=-23.189414 -> V=1.0, theta=0.0
% INFO    : Bus 23708	: V=0.9568089, theta=-23.100459 -> V=1.0, theta=0.0
% INFO    : Bus 23709	: V=0.9616074, theta=-22.533815 -> V=1.0, theta=0.0
% INFO    : Bus 23710	: V=0.9560095, theta=-23.482801 -> V=1.0, theta=0.0
% INFO    : Bus 23711	: V=0.9555912, theta=-23.386446 -> V=1.0, theta=0.0
% INFO    : Bus 23712	: V=0.9561963, theta=-23.169859 -> V=1.0, theta=0.0
% INFO    : Bus 23713	: V=0.9560941, theta=-23.397677 -> V=1.0, theta=0.0
% INFO    : Bus 23714	: V=0.9553567, theta=-23.405052 -> V=1.0, theta=0.0
% INFO    : Bus 23715	: V=0.9562071, theta=-23.47759 -> V=1.0, theta=0.0
% INFO    : Bus 23716	: V=0.9558616, theta=-23.454203 -> V=1.0, theta=0.0
% INFO    : Bus 23717	: V=0.9562019, theta=-23.640776 -> V=1.0, theta=0.0
% INFO    : Bus 23718	: V=0.954714, theta=-23.794848 -> V=1.0, theta=0.0
% INFO    : Bus 23719	: V=0.9615141, theta=-22.793919 -> V=1.0, theta=0.0
% INFO    : Bus 23720	: V=0.9568883, theta=-23.472658 -> V=1.0, theta=0.0
% INFO    : Bus 23721	: V=0.9623394, theta=-23.037508 -> V=1.0, theta=0.0
% INFO    : Bus 23722	: V=0.9571922, theta=-23.575586 -> V=1.0, theta=0.0
% INFO    : Bus 23723	: V=0.9554272, theta=-23.776846 -> V=1.0, theta=0.0
% INFO    : Bus 23724	: V=0.955505, theta=-23.829978 -> V=1.0, theta=0.0
% INFO    : Bus 23725	: V=0.9559464, theta=-23.825817 -> V=1.0, theta=0.0
% INFO    : Bus 23726	: V=0.9557268, theta=-23.856197 -> V=1.0, theta=0.0
% INFO    : Bus 23727	: V=0.9572016, theta=-23.673789 -> V=1.0, theta=0.0
% INFO    : Bus 23728	: V=0.9627457, theta=-23.015687 -> V=1.0, theta=0.0
% INFO    : Bus 23729	: V=0.9590102, theta=-23.15402 -> V=1.0, theta=0.0
% INFO    : Bus 23730	: V=0.9594459, theta=-23.233844 -> V=1.0, theta=0.0
% INFO    : Bus 23731	: V=0.9607129, theta=-22.900817 -> V=1.0, theta=0.0
% INFO    : Bus 23732	: V=0.9610989, theta=-22.641696 -> V=1.0, theta=0.0
% INFO    : Bus 23733	: V=0.9615801, theta=-22.491086 -> V=1.0, theta=0.0
% INFO    : Bus 23734	: V=0.9643725, theta=-22.261232 -> V=1.0, theta=0.0
% INFO    : Bus 23735	: V=0.962966, theta=-22.528644 -> V=1.0, theta=0.0
% INFO    : Bus 23736	: V=0.9606193, theta=-22.680413 -> V=1.0, theta=0.0
% INFO    : Bus 23737	: V=0.9591305, theta=-22.883435 -> V=1.0, theta=0.0
% INFO    : Bus 23738	: V=0.9586273, theta=-23.041908 -> V=1.0, theta=0.0
% INFO    : Bus 23739	: V=0.9582589, theta=-23.329668 -> V=1.0, theta=0.0
% INFO    : Bus 23740	: V=0.9587205, theta=-23.139351 -> V=1.0, theta=0.0
% INFO    : Bus 23741	: V=0.960558, theta=-22.867365 -> V=1.0, theta=0.0
% INFO    : Bus 23742	: V=0.9686093, theta=-23.042467 -> V=1.0, theta=0.0
% INFO    : Bus 23743	: V=0.9590665, theta=-23.393732 -> V=1.0, theta=0.0
% INFO    : Bus 23744	: V=0.9676739, theta=-23.0539 -> V=1.0, theta=0.0
% INFO    : Bus 23745	: V=0.9648725, theta=-21.651523 -> V=1.0, theta=0.0
% INFO    : Bus 23746	: V=0.9661736, theta=-21.92187 -> V=1.0, theta=0.0
% INFO    : Bus 23747	: V=0.9642048, theta=-22.07751 -> V=1.0, theta=0.0
% INFO    : Bus 23748	: V=0.9700663, theta=-22.868462 -> V=1.0, theta=0.0
% INFO    : Bus 23749	: V=0.960458, theta=-23.011955 -> V=1.0, theta=0.0
% INFO    : Bus 23750	: V=0.9598437, theta=-23.211009 -> V=1.0, theta=0.0
% INFO    : Bus 23751	: V=0.9626244, theta=-22.373753 -> V=1.0, theta=0.0
% INFO    : Bus 23752	: V=0.962864, theta=-22.447738 -> V=1.0, theta=0.0
% INFO    : Bus 23753	: V=0.9617084, theta=-22.738758 -> V=1.0, theta=0.0
% INFO    : Bus 23754	: V=0.9573721, theta=-23.29166 -> V=1.0, theta=0.0
% INFO    : Bus 23755	: V=0.9569664, theta=-23.229278 -> V=1.0, theta=0.0
% INFO    : Bus 23756	: V=0.9567189, theta=-23.330283 -> V=1.0, theta=0.0
% INFO    : Bus 23757	: V=0.9565632, theta=-23.41684 -> V=1.0, theta=0.0
% INFO    : Bus 23758	: V=0.9568804, theta=-23.379369 -> V=1.0, theta=0.0
% INFO    : Bus 23759	: V=0.9564526, theta=-23.514336 -> V=1.0, theta=0.0
% INFO    : Bus 23760	: V=0.9598037, theta=-23.501192 -> V=1.0, theta=0.0
% INFO    : Bus 23761	: V=0.959581, theta=-23.501754 -> V=1.0, theta=0.0
% INFO    : Bus 23762	: V=0.9593391, theta=-23.503489 -> V=1.0, theta=0.0
% INFO    : Bus 23763	: V=0.9564421, theta=-23.72427 -> V=1.0, theta=0.0
% INFO    : Bus 23764	: V=0.9574632, theta=-23.722252 -> V=1.0, theta=0.0
% INFO    : Bus 23765	: V=0.9682753, theta=-23.310666 -> V=1.0, theta=0.0
% INFO    : Bus 23766	: V=0.9563233, theta=-23.517609 -> V=1.0, theta=0.0
% INFO    : Bus 23767	: V=0.9606088, theta=-23.620985 -> V=1.0, theta=0.0
% INFO    : Bus 23768	: V=0.987427, theta=-21.12157 -> V=1.0, theta=0.0
% INFO    : Bus 23769	: V=0.9662196, theta=-22.867448 -> V=1.0, theta=0.0
% INFO    : Bus 23770	: V=0.9636137, theta=-23.222632 -> V=1.0, theta=0.0
% INFO    : Bus 23771	: V=0.9621349, theta=-23.473188 -> V=1.0, theta=0.0
% INFO    : Bus 23772	: V=0.9642134, theta=-23.285917 -> V=1.0, theta=0.0
% INFO    : Bus 23773	: V=0.9672458, theta=-22.979327 -> V=1.0, theta=0.0
% INFO    : Bus 23774	: V=0.9880416, theta=-21.256788 -> V=1.0, theta=0.0
% INFO    : Bus 23775	: V=0.9643655, theta=-23.226333 -> V=1.0, theta=0.0
% INFO    : Bus 23776	: V=0.9648489, theta=-23.22382 -> V=1.0, theta=0.0
% INFO    : Bus 23777	: V=0.9659322, theta=-23.179201 -> V=1.0, theta=0.0
% INFO    : Bus 23778	: V=0.9756421, theta=-22.177323 -> V=1.0, theta=0.0
% INFO    : Bus 23779	: V=0.9606817, theta=-22.708616 -> V=1.0, theta=0.0
% INFO    : Bus 23780	: V=0.9603415, theta=-22.805278 -> V=1.0, theta=0.0
% INFO    : Bus 23781	: V=0.9623601, theta=-22.644885 -> V=1.0, theta=0.0
% INFO    : Bus 23782	: V=0.9600591, theta=-22.881241 -> V=1.0, theta=0.0
% INFO    : Bus 23783	: V=0.9729853, theta=-21.928606 -> V=1.0, theta=0.0
% INFO    : Bus 23784	: V=0.9723122, theta=-22.018417 -> V=1.0, theta=0.0
% INFO    : Bus 23785	: V=0.9727081, theta=-21.957652 -> V=1.0, theta=0.0
% INFO    : Bus 23786	: V=0.9707313, theta=-22.51743 -> V=1.0, theta=0.0
% INFO    : Bus 23787	: V=0.9699082, theta=-22.581384 -> V=1.0, theta=0.0
% INFO    : Bus 23788	: V=0.9686441, theta=-22.666599 -> V=1.0, theta=0.0
% INFO    : Bus 23789	: V=0.9756858, theta=-22.03547 -> V=1.0, theta=0.0
% INFO    : Bus 23790	: V=0.9583923, theta=-22.957815 -> V=1.0, theta=0.0
% INFO    : Bus 23791	: V=0.9617235, theta=-22.64581 -> V=1.0, theta=0.0
% INFO    : Bus 23792	: V=0.9598448, theta=-22.977542 -> V=1.0, theta=0.0
% INFO    : Bus 23793	: V=0.9576206, theta=-23.052382 -> V=1.0, theta=0.0
% INFO    : Bus 23794	: V=0.9571937, theta=-23.059332 -> V=1.0, theta=0.0
% INFO    : Bus 23795	: V=0.9572063, theta=-23.126737 -> V=1.0, theta=0.0
% INFO    : Bus 23796	: V=0.957901, theta=-23.203487 -> V=1.0, theta=0.0
% INFO    : Bus 23797	: V=0.9595184, theta=-23.115335 -> V=1.0, theta=0.0
% INFO    : Bus 23798	: V=0.9614818, theta=-23.085287 -> V=1.0, theta=0.0
% INFO    : Bus 23799	: V=0.9614659, theta=-23.10247 -> V=1.0, theta=0.0
% INFO    : Bus 23800	: V=0.9597626, theta=-23.161499 -> V=1.0, theta=0.0
% INFO    : Bus 23801	: V=0.9600687, theta=-23.209747 -> V=1.0, theta=0.0
% INFO    : Bus 23802	: V=0.9618981, theta=-23.115478 -> V=1.0, theta=0.0
% INFO    : Bus 23803	: V=0.9691003, theta=-22.620591 -> V=1.0, theta=0.0
% INFO    : Bus 23804	: V=0.9633315, theta=-23.137954 -> V=1.0, theta=0.0
% INFO    : Bus 23805	: V=0.9614077, theta=-23.277083 -> V=1.0, theta=0.0
% INFO    : Bus 23806	: V=0.9637682, theta=-23.134659 -> V=1.0, theta=0.0
% INFO    : Bus 23807	: V=0.9677373, theta=-22.752273 -> V=1.0, theta=0.0
% INFO    : Bus 23808	: V=0.9636092, theta=-23.185713 -> V=1.0, theta=0.0
% INFO    : Bus 23809	: V=0.9605331, theta=-23.388949 -> V=1.0, theta=0.0
% INFO    : Bus 23810	: V=0.9560908, theta=-23.524767 -> V=1.0, theta=0.0
% INFO    : Bus 23811	: V=0.9654308, theta=-19.519137 -> V=1.0, theta=0.0
% INFO    : Bus 23812	: V=0.9661396, theta=-19.446781 -> V=1.0, theta=0.0
% INFO    : Bus 23813	: V=0.962049, theta=-20.443833 -> V=1.0, theta=0.0
% INFO    : Bus 23814	: V=0.964877, theta=-19.681852 -> V=1.0, theta=0.0
% INFO    : Bus 23815	: V=0.963781, theta=-19.818298 -> V=1.0, theta=0.0
% INFO    : Bus 23816	: V=0.9592688, theta=-20.909139 -> V=1.0, theta=0.0
% INFO    : Bus 23817	: V=0.9589177, theta=-20.896061 -> V=1.0, theta=0.0
% INFO    : Bus 23818	: V=0.9579855, theta=-20.96615 -> V=1.0, theta=0.0
% INFO    : Bus 23819	: V=0.9590726, theta=-20.990288 -> V=1.0, theta=0.0
% INFO    : Bus 23820	: V=0.960163, theta=-20.783668 -> V=1.0, theta=0.0
% INFO    : Bus 23821	: V=0.963109, theta=-19.901286 -> V=1.0, theta=0.0
% INFO    : Bus 23822	: V=0.9626086, theta=-19.977045 -> V=1.0, theta=0.0
% INFO    : Bus 23823	: V=0.9614057, theta=-20.644106 -> V=1.0, theta=0.0
% INFO    : Bus 23824	: V=0.9619497, theta=-20.640611 -> V=1.0, theta=0.0
% INFO    : Bus 23825	: V=0.9663226, theta=-20.384128 -> V=1.0, theta=0.0
% INFO    : Bus 23826	: V=0.9609438, theta=-20.79159 -> V=1.0, theta=0.0
% INFO    : Bus 23827	: V=0.962104, theta=-20.047459 -> V=1.0, theta=0.0
% INFO    : Bus 23828	: V=0.9593912, theta=-21.08265 -> V=1.0, theta=0.0
% INFO    : Bus 23829	: V=0.9580301, theta=-21.448559 -> V=1.0, theta=0.0
% INFO    : Bus 23830	: V=0.9570175, theta=-21.115757 -> V=1.0, theta=0.0
% INFO    : Bus 23831	: V=0.9572692, theta=-21.867435 -> V=1.0, theta=0.0
% INFO    : Bus 23832	: V=0.9596626, theta=-21.895832 -> V=1.0, theta=0.0
% INFO    : Bus 23833	: V=0.9579573, theta=-21.464256 -> V=1.0, theta=0.0
% INFO    : Bus 23834	: V=0.9585415, theta=-21.613355 -> V=1.0, theta=0.0
% INFO    : Bus 23835	: V=0.9593937, theta=-21.074352 -> V=1.0, theta=0.0
% INFO    : Bus 23836	: V=0.9662795, theta=-20.633902 -> V=1.0, theta=0.0
% INFO    : Bus 23837	: V=0.9663886, theta=-20.952103 -> V=1.0, theta=0.0
% INFO    : Bus 23838	: V=0.9663363, theta=-20.840545 -> V=1.0, theta=0.0
% INFO    : Bus 23839	: V=0.9594028, theta=-21.604441 -> V=1.0, theta=0.0
% INFO    : Bus 23840	: V=0.9623401, theta=-21.925068 -> V=1.0, theta=0.0
% INFO    : Bus 23841	: V=0.9624068, theta=-21.881678 -> V=1.0, theta=0.0
% INFO    : Bus 23842	: V=0.9609113, theta=-21.82953 -> V=1.0, theta=0.0
% INFO    : Bus 23843	: V=0.9605335, theta=-21.708192 -> V=1.0, theta=0.0
% INFO    : Bus 23844	: V=0.966477, theta=-21.074957 -> V=1.0, theta=0.0
% INFO    : Bus 23845	: V=0.9667419, theta=-21.213106 -> V=1.0, theta=0.0
% INFO    : Bus 23846	: V=0.9597442, theta=-22.271169 -> V=1.0, theta=0.0
% INFO    : Bus 23847	: V=0.965136, theta=-21.754814 -> V=1.0, theta=0.0
% INFO    : Bus 23848	: V=0.9675723, theta=-21.393461 -> V=1.0, theta=0.0
% INFO    : Bus 23849	: V=0.9689967, theta=-21.442276 -> V=1.0, theta=0.0
% INFO    : Bus 23850	: V=0.9705656, theta=-21.478696 -> V=1.0, theta=0.0
% INFO    : Bus 23851	: V=0.966541, theta=-22.030474 -> V=1.0, theta=0.0
% INFO    : Bus 23852	: V=0.9724915, theta=-21.507941 -> V=1.0, theta=0.0
% INFO    : Bus 23853	: V=0.9749045, theta=-21.539921 -> V=1.0, theta=0.0
% INFO    : Bus 23854	: V=0.9723726, theta=-21.80566 -> V=1.0, theta=0.0
% INFO    : Bus 23855	: V=0.9642061, theta=-22.40145 -> V=1.0, theta=0.0
% INFO    : Bus 23856	: V=0.9683622, theta=-21.897833 -> V=1.0, theta=0.0
% INFO    : Bus 23857	: V=0.9655094, theta=-21.843888 -> V=1.0, theta=0.0
% INFO    : Bus 23858	: V=0.9663035, theta=-21.896728 -> V=1.0, theta=0.0
% INFO    : Bus 23859	: V=0.9663425, theta=-21.947168 -> V=1.0, theta=0.0
% INFO    : Bus 23860	: V=0.9745055, theta=-21.478969 -> V=1.0, theta=0.0
% INFO    : Bus 23861	: V=0.9741234, theta=-21.657662 -> V=1.0, theta=0.0
% INFO    : Bus 23862	: V=0.9976781, theta=5.195835 -> V=1.0, theta=0.0
% INFO    : Bus 23863	: V=1.0080752, theta=6.807471 -> V=1.0, theta=0.0
% INFO    : Bus 23864	: V=1.0034475, theta=5.695905 -> V=1.0, theta=0.0
% INFO    : Bus 23865	: V=0.9846831, theta=3.33741 -> V=1.0, theta=0.0
% INFO    : Bus 23866	: V=1.0106191, theta=7.264043 -> V=1.0, theta=0.0
% INFO    : Bus 23867	: V=0.9958129, theta=4.844867 -> V=1.0, theta=0.0
% INFO    : Bus 23868	: V=1.0010285, theta=5.517133 -> V=1.0, theta=0.0
% INFO    : Bus 23869	: V=0.9707844, theta=-5.566558 -> V=1.0, theta=0.0
% INFO    : Bus 23870	: V=0.9718031, theta=-5.73612 -> V=1.0, theta=0.0
% INFO    : Bus 23871	: V=0.9598772, theta=-6.995425 -> V=1.0, theta=0.0
% INFO    : Bus 23872	: V=0.9645213, theta=-6.930955 -> V=1.0, theta=0.0
% INFO    : Bus 23873	: V=0.9794957, theta=-6.391497 -> V=1.0, theta=0.0
% INFO    : Bus 23874	: V=0.9715993, theta=-6.330494 -> V=1.0, theta=0.0
% INFO    : Bus 23875	: V=0.9629624, theta=-7.052812 -> V=1.0, theta=0.0
% INFO    : Bus 23876	: V=0.9926294, theta=8.330596 -> V=1.0, theta=0.0
% INFO    : Bus 23877	: V=1.0250873, theta=10.656131 -> V=1.0, theta=0.0
% INFO    : Bus 23878	: V=1.009348, theta=8.559649 -> V=1.0, theta=0.0
% INFO    : Bus 23879	: V=0.9679257, theta=-2.272987 -> V=1.0, theta=0.0
% INFO    : Bus 23880	: V=0.9928367, theta=1.596638 -> V=1.0, theta=0.0
% INFO    : Bus 23881	: V=0.9922792, theta=0.67559 -> V=1.0, theta=0.0
% INFO    : Bus 23882	: V=0.9747469, theta=-1.283788 -> V=1.0, theta=0.0
% INFO    : Bus 23883	: V=0.991819, theta=-0.534435 -> V=1.0, theta=0.0
% INFO    : Bus 23884	: V=0.9951329, theta=1.423768 -> V=1.0, theta=0.0
% INFO    : Bus 23885	: V=0.9874336, theta=-3.829408 -> V=1.0, theta=0.0
% INFO    : Bus 23886	: V=0.9793562, theta=-5.048634 -> V=1.0, theta=0.0
% INFO    : Bus 23887	: V=0.974672, theta=-5.097172 -> V=1.0, theta=0.0
% INFO    : Bus 23888	: V=0.9822052, theta=-4.38888 -> V=1.0, theta=0.0
% INFO    : Bus 23889	: V=0.9775595, theta=-4.681809 -> V=1.0, theta=0.0
% INFO    : Bus 23890	: V=1.0150136, theta=-0.810923 -> V=1.0, theta=0.0
% INFO    : Bus 23891	: V=1.0152449, theta=-0.404585 -> V=1.0, theta=0.0
% INFO    : Bus 23892	: V=1.0196305, theta=-0.306958 -> V=1.0, theta=0.0
% INFO    : Bus 23893	: V=1.0072283, theta=-1.516342 -> V=1.0, theta=0.0
% INFO    : Bus 23894	: V=1.0079905, theta=-0.904155 -> V=1.0, theta=0.0
% INFO    : Bus 23895	: V=1.0040674, theta=-0.889703 -> V=1.0, theta=0.0
% INFO    : Bus 23896	: V=0.9797693, theta=1.107952 -> V=1.0, theta=0.0
% INFO    : Bus 23897	: V=0.9870049, theta=1.689191 -> V=1.0, theta=0.0
% INFO    : Bus 23898	: V=0.9957891, theta=2.883804 -> V=1.0, theta=0.0
% INFO    : Bus 23899	: V=1.0004555, theta=3.504149 -> V=1.0, theta=0.0
% INFO    : Bus 23900	: V=0.9953437, theta=3.293293 -> V=1.0, theta=0.0
% INFO    : Bus 23901	: V=1.005553, theta=3.970676 -> V=1.0, theta=0.0
% INFO    : Bus 23902	: V=1.0089563, theta=4.61065 -> V=1.0, theta=0.0
% INFO    : Bus 23903	: V=1.004904, theta=3.834039 -> V=1.0, theta=0.0
% INFO    : Bus 23904	: V=1.0083457, theta=4.132985 -> V=1.0, theta=0.0
% INFO    : Bus 23905	: V=1.0024144, theta=3.693191 -> V=1.0, theta=0.0
% INFO    : Bus 23906	: V=1.0069485, theta=3.859992 -> V=1.0, theta=0.0
% INFO    : Bus 23907	: V=1.0114955, theta=4.632588 -> V=1.0, theta=0.0
% INFO    : Bus 23908	: V=0.9965826, theta=2.78401 -> V=1.0, theta=0.0
% INFO    : Bus 23909	: V=0.9995603, theta=2.836628 -> V=1.0, theta=0.0
% INFO    : Bus 23910	: V=1.0151283, theta=4.786217 -> V=1.0, theta=0.0
% INFO    : Bus 23911	: V=0.9792736, theta=0.283674 -> V=1.0, theta=0.0
% INFO    : Bus 23912	: V=0.9808557, theta=0.435279 -> V=1.0, theta=0.0
% INFO    : Bus 23913	: V=0.9835515, theta=0.743325 -> V=1.0, theta=0.0
% INFO    : Bus 23914	: V=0.9873919, theta=1.131165 -> V=1.0, theta=0.0
% INFO    : Bus 23915	: V=0.9853593, theta=0.976726 -> V=1.0, theta=0.0
% INFO    : Bus 23916	: V=0.984441, theta=0.841323 -> V=1.0, theta=0.0
% INFO    : Bus 23917	: V=0.988791, theta=1.234004 -> V=1.0, theta=0.0
% INFO    : Bus 23918	: V=0.9920907, theta=1.491404 -> V=1.0, theta=0.0
% INFO    : Bus 23919	: V=0.990531, theta=1.371758 -> V=1.0, theta=0.0
% INFO    : Bus 23920	: V=0.9868804, theta=1.215506 -> V=1.0, theta=0.0
% INFO    : Bus 23921	: V=0.9991913, theta=2.105852 -> V=1.0, theta=0.0
% INFO    : Bus 23922	: V=1.0070568, theta=3.016976 -> V=1.0, theta=0.0
% INFO    : Bus 23923	: V=1.011845, theta=3.387586 -> V=1.0, theta=0.0
% INFO    : Bus 23924	: V=1.0093413, theta=2.781014 -> V=1.0, theta=0.0
% INFO    : Bus 23925	: V=1.0094481, theta=2.521625 -> V=1.0, theta=0.0
% INFO    : Bus 23926	: V=1.0097117, theta=2.779957 -> V=1.0, theta=0.0
% INFO    : Bus 23927	: V=1.0026506, theta=1.739174 -> V=1.0, theta=0.0
% INFO    : Bus 23928	: V=1.0032615, theta=1.787624 -> V=1.0, theta=0.0
% INFO    : Bus 23929	: V=1.008177, theta=2.027831 -> V=1.0, theta=0.0
% INFO    : Bus 23930	: V=1.0057683, theta=1.65639 -> V=1.0, theta=0.0
% INFO    : Bus 23931	: V=1.0057464, theta=1.813424 -> V=1.0, theta=0.0
% INFO    : Bus 23932	: V=1.0190388, theta=4.126039 -> V=1.0, theta=0.0
% INFO    : Bus 23933	: V=0.985551, theta=1.03556 -> V=1.0, theta=0.0
% INFO    : Bus 23934	: V=1.015926, theta=3.62342 -> V=1.0, theta=0.0
% INFO    : Bus 23935	: V=1.0076194, theta=2.559603 -> V=1.0, theta=0.0
% INFO    : Bus 23936	: V=0.9887295, theta=1.951756 -> V=1.0, theta=0.0
% INFO    : Bus 23937	: V=0.9855268, theta=0.996736 -> V=1.0, theta=0.0
% INFO    : Bus 23938	: V=0.9865476, theta=1.036123 -> V=1.0, theta=0.0
% INFO    : Bus 23939	: V=0.987106, theta=1.449577 -> V=1.0, theta=0.0
% INFO    : Bus 23940	: V=0.9937929, theta=1.886171 -> V=1.0, theta=0.0
% INFO    : Bus 23941	: V=0.988916, theta=1.4805 -> V=1.0, theta=0.0
% INFO    : Bus 23942	: V=0.9869915, theta=1.21441 -> V=1.0, theta=0.0
% INFO    : Bus 23943	: V=1.0097106, theta=2.44259 -> V=1.0, theta=0.0
% INFO    : Bus 23944	: V=1.0171088, theta=3.854158 -> V=1.0, theta=0.0
% INFO    : Bus 23945	: V=1.0051403, theta=1.618876 -> V=1.0, theta=0.0
% INFO    : Bus 23946	: V=1.0058107, theta=1.650099 -> V=1.0, theta=0.0
% INFO    : Bus 23947	: V=1.0084275, theta=2.272562 -> V=1.0, theta=0.0
% INFO    : Bus 23948	: V=1.008929, theta=2.381616 -> V=1.0, theta=0.0
% INFO    : Bus 23949	: V=1.0150411, theta=0.266203 -> V=1.0, theta=0.0
% INFO    : Bus 23950	: V=0.9981247, theta=-2.393315 -> V=1.0, theta=0.0
% INFO    : Bus 23951	: V=0.9976688, theta=-1.403585 -> V=1.0, theta=0.0
% INFO    : Bus 23952	: V=1.0054057, theta=-0.635051 -> V=1.0, theta=0.0
% INFO    : Bus 23953	: V=0.9832017, theta=-2.389679 -> V=1.0, theta=0.0
% INFO    : Bus 23954	: V=0.9795527, theta=-2.415909 -> V=1.0, theta=0.0
% INFO    : Bus 23955	: V=0.9717235, theta=-4.933109 -> V=1.0, theta=0.0
% INFO    : Bus 23956	: V=0.9714945, theta=-5.33148 -> V=1.0, theta=0.0
% INFO    : Bus 23957	: V=0.9732453, theta=-4.438864 -> V=1.0, theta=0.0
% INFO    : Bus 23958	: V=0.9771137, theta=-3.95624 -> V=1.0, theta=0.0
% INFO    : Bus 23959	: V=0.9717137, theta=-3.98473 -> V=1.0, theta=0.0
% INFO    : Bus 23960	: V=0.9690399, theta=-3.993073 -> V=1.0, theta=0.0
% INFO    : Bus 23961	: V=0.9730866, theta=-4.350482 -> V=1.0, theta=0.0
% INFO    : Bus 23962	: V=0.9684871, theta=-3.934067 -> V=1.0, theta=0.0
% INFO    : Bus 23963	: V=0.9681759, theta=-4.708004 -> V=1.0, theta=0.0
% INFO    : Bus 23964	: V=0.9659025, theta=-3.975673 -> V=1.0, theta=0.0
% INFO    : Bus 23965	: V=1.0052559, theta=-6.167846 -> V=1.0, theta=0.0
% INFO    : Bus 23966	: V=0.9941542, theta=-7.402987 -> V=1.0, theta=0.0
% INFO    : Bus 23967	: V=0.9979389, theta=-7.243271 -> V=1.0, theta=0.0
% INFO    : Bus 23968	: V=0.9977586, theta=-7.224906 -> V=1.0, theta=0.0
% INFO    : Bus 23969	: V=0.99742, theta=-7.352251 -> V=1.0, theta=0.0
% INFO    : Bus 23970	: V=0.9947284, theta=-7.684038 -> V=1.0, theta=0.0
% INFO    : Bus 23971	: V=0.9969312, theta=-7.45596 -> V=1.0, theta=0.0
% INFO    : Bus 23972	: V=0.997227, theta=-7.43471 -> V=1.0, theta=0.0
% INFO    : Bus 23973	: V=0.994812, theta=-7.647696 -> V=1.0, theta=0.0
% INFO    : Bus 23974	: V=0.9949848, theta=-7.458691 -> V=1.0, theta=0.0
% INFO    : Bus 23975	: V=0.9978515, theta=-7.114212 -> V=1.0, theta=0.0
% INFO    : Bus 23976	: V=0.9980091, theta=-7.046789 -> V=1.0, theta=0.0
% INFO    : Bus 23977	: V=0.9993626, theta=-6.981878 -> V=1.0, theta=0.0
% INFO    : Bus 23978	: V=0.9988518, theta=-7.061345 -> V=1.0, theta=0.0
% INFO    : Bus 23979	: V=0.9984538, theta=-7.118956 -> V=1.0, theta=0.0
% INFO    : Bus 23980	: V=0.9983826, theta=-7.140757 -> V=1.0, theta=0.0
% INFO    : Bus 23981	: V=0.9958938, theta=-7.410668 -> V=1.0, theta=0.0
% INFO    : Bus 23982	: V=0.9993329, theta=-6.987531 -> V=1.0, theta=0.0
% INFO    : Bus 23983	: V=1.0045342, theta=-6.01128 -> V=1.0, theta=0.0
% INFO    : Bus 23984	: V=1.0077882, theta=-4.977659 -> V=1.0, theta=0.0
% INFO    : Bus 23985	: V=0.9942514, theta=-7.097223 -> V=1.0, theta=0.0
% INFO    : Bus 23986	: V=1.0058709, theta=-5.552158 -> V=1.0, theta=0.0
% INFO    : Bus 23987	: V=0.9957268, theta=-7.184201 -> V=1.0, theta=0.0
% INFO    : Bus 23988	: V=0.9990425, theta=-6.793999 -> V=1.0, theta=0.0
% INFO    : Bus 23989	: V=0.9958972, theta=-7.300316 -> V=1.0, theta=0.0
% INFO    : Bus 23990	: V=1.0047544, theta=-5.924137 -> V=1.0, theta=0.0
% INFO    : Bus 23991	: V=1.0051562, theta=-5.773451 -> V=1.0, theta=0.0
% INFO    : Bus 23992	: V=0.9982513, theta=-6.983506 -> V=1.0, theta=0.0
% INFO    : Bus 23993	: V=0.9987259, theta=-6.835032 -> V=1.0, theta=0.0
% INFO    : Bus 23994	: V=0.9954979, theta=-7.299229 -> V=1.0, theta=0.0
% INFO    : Bus 23995	: V=0.9990726, theta=-6.795501 -> V=1.0, theta=0.0
% INFO    : Bus 23996	: V=1.0061909, theta=-6.082243 -> V=1.0, theta=0.0
% INFO    : Bus 23997	: V=1.0029644, theta=-6.647469 -> V=1.0, theta=0.0
% INFO    : Bus 23998	: V=0.9953216, theta=-7.4365 -> V=1.0, theta=0.0
% INFO    : Bus 23999	: V=1.0044317, theta=-6.770028 -> V=1.0, theta=0.0
% INFO    : Bus 24000	: V=1.0035457, theta=-7.232925 -> V=1.0, theta=0.0
% INFO    : Bus 24001	: V=0.9969272, theta=-7.675569 -> V=1.0, theta=0.0
% INFO    : Bus 24002	: V=1.0012729, theta=-7.224249 -> V=1.0, theta=0.0
% INFO    : Bus 24003	: V=0.9925557, theta=-7.714881 -> V=1.0, theta=0.0
% INFO    : Bus 24004	: V=0.9941228, theta=-8.287537 -> V=1.0, theta=0.0
% INFO    : Bus 24005	: V=0.98952, theta=-7.667804 -> V=1.0, theta=0.0
% INFO    : Bus 24006	: V=0.9954484, theta=-7.041901 -> V=1.0, theta=0.0
% INFO    : Bus 24007	: V=0.9940342, theta=-7.126813 -> V=1.0, theta=0.0
% INFO    : Bus 24008	: V=0.9977282, theta=-6.903477 -> V=1.0, theta=0.0
% INFO    : Bus 24009	: V=0.9996232, theta=-6.178397 -> V=1.0, theta=0.0
% INFO    : Bus 24010	: V=0.9945979, theta=-6.982212 -> V=1.0, theta=0.0
% INFO    : Bus 24011	: V=0.9967833, theta=-6.156459 -> V=1.0, theta=0.0
% INFO    : Bus 24012	: V=0.9995298, theta=-4.367169 -> V=1.0, theta=0.0
% INFO    : Bus 24013	: V=0.9922745, theta=-6.587155 -> V=1.0, theta=0.0
% INFO    : Bus 24014	: V=0.9881637, theta=-6.985079 -> V=1.0, theta=0.0
% INFO    : Bus 24015	: V=0.9845696, theta=-7.311651 -> V=1.0, theta=0.0
% INFO    : Bus 24016	: V=0.9863486, theta=-8.103423 -> V=1.0, theta=0.0
% INFO    : Bus 24017	: V=0.9794341, theta=-9.020168 -> V=1.0, theta=0.0
% INFO    : Bus 24018	: V=0.9862468, theta=-8.73487 -> V=1.0, theta=0.0
% INFO    : Bus 24019	: V=0.9937388, theta=-9.056738 -> V=1.0, theta=0.0
% INFO    : Bus 24020	: V=0.994153, theta=-9.518288 -> V=1.0, theta=0.0
% INFO    : Bus 24021	: V=1.0130726, theta=-15.612786 -> V=1.0, theta=0.0
% INFO    : Bus 24022	: V=0.9970773, theta=-16.92452 -> V=1.0, theta=0.0
% INFO    : Bus 24023	: V=0.9954329, theta=-16.956846 -> V=1.0, theta=0.0
% INFO    : Bus 24024	: V=0.99358, theta=-16.974722 -> V=1.0, theta=0.0
% INFO    : Bus 24025	: V=0.9978824, theta=-16.939016 -> V=1.0, theta=0.0
% INFO    : Bus 24026	: V=0.9973013, theta=-16.939614 -> V=1.0, theta=0.0
% INFO    : Bus 24027	: V=0.9915248, theta=-16.943196 -> V=1.0, theta=0.0
% INFO    : Bus 24028	: V=0.9910233, theta=-16.94474 -> V=1.0, theta=0.0
% INFO    : Bus 24029	: V=0.9901415, theta=-16.836308 -> V=1.0, theta=0.0
% INFO    : Bus 24030	: V=0.9892433, theta=-16.840975 -> V=1.0, theta=0.0
% INFO    : Bus 24031	: V=0.9923954, theta=-16.187638 -> V=1.0, theta=0.0
% INFO    : Bus 24032	: V=0.992811, theta=-16.207226 -> V=1.0, theta=0.0
% INFO    : Bus 24033	: V=0.9942112, theta=-15.919593 -> V=1.0, theta=0.0
% INFO    : Bus 24034	: V=0.9912946, theta=-16.478336 -> V=1.0, theta=0.0
% INFO    : Bus 24035	: V=0.998671, theta=-15.135517 -> V=1.0, theta=0.0
% INFO    : Bus 24036	: V=0.9934485, theta=-15.914794 -> V=1.0, theta=0.0
% INFO    : Bus 24037	: V=0.9943865, theta=-15.656052 -> V=1.0, theta=0.0
% INFO    : Bus 24038	: V=0.9938054, theta=-17.138558 -> V=1.0, theta=0.0
% INFO    : Bus 24039	: V=0.9938119, theta=-16.90774 -> V=1.0, theta=0.0
% INFO    : Bus 24040	: V=0.9926879, theta=-16.444735 -> V=1.0, theta=0.0
% INFO    : Bus 24041	: V=1.0111911, theta=-15.391501 -> V=1.0, theta=0.0
% INFO    : Bus 24042	: V=1.0071141, theta=-16.705187 -> V=1.0, theta=0.0
% INFO    : Bus 24043	: V=1.0079888, theta=-16.587347 -> V=1.0, theta=0.0
% INFO    : Bus 24044	: V=1.0123161, theta=-16.466049 -> V=1.0, theta=0.0
% INFO    : Bus 24045	: V=1.012276, theta=-16.678424 -> V=1.0, theta=0.0
% INFO    : Bus 24046	: V=1.0046029, theta=-17.339875 -> V=1.0, theta=0.0
% INFO    : Bus 24047	: V=1.0015439, theta=-17.409884 -> V=1.0, theta=0.0
% INFO    : Bus 24048	: V=1.0120592, theta=-17.420617 -> V=1.0, theta=0.0
% INFO    : Bus 24049	: V=1.0124832, theta=-16.887615 -> V=1.0, theta=0.0
% INFO    : Bus 24050	: V=1.013369, theta=-17.253749 -> V=1.0, theta=0.0
% INFO    : Bus 24051	: V=1.0096721, theta=-17.366978 -> V=1.0, theta=0.0
% INFO    : Bus 24052	: V=1.0018563, theta=-17.825487 -> V=1.0, theta=0.0
% INFO    : Bus 24053	: V=1.0048953, theta=-17.620404 -> V=1.0, theta=0.0
% INFO    : Bus 24054	: V=0.9931725, theta=-18.964981 -> V=1.0, theta=0.0
% INFO    : Bus 24055	: V=0.9948441, theta=-18.411695 -> V=1.0, theta=0.0
% INFO    : Bus 24056	: V=0.9943147, theta=-18.437928 -> V=1.0, theta=0.0
% INFO    : Bus 24057	: V=1.0037692, theta=-18.208268 -> V=1.0, theta=0.0
% INFO    : Bus 24058	: V=0.9943785, theta=-19.014386 -> V=1.0, theta=0.0
% INFO    : Bus 24059	: V=1.0020715, theta=-17.647929 -> V=1.0, theta=0.0
% INFO    : Bus 24060	: V=0.9995813, theta=-17.797295 -> V=1.0, theta=0.0
% INFO    : Bus 24061	: V=0.9985779, theta=-16.752127 -> V=1.0, theta=0.0
% INFO    : Bus 24062	: V=1.0055249, theta=-13.175584 -> V=1.0, theta=0.0
% INFO    : Bus 24063	: V=0.9930496, theta=-15.095029 -> V=1.0, theta=0.0
% INFO    : Bus 24064	: V=0.9849853, theta=-14.77803 -> V=1.0, theta=0.0
% INFO    : Bus 24065	: V=1.0069147, theta=-13.167606 -> V=1.0, theta=0.0
% INFO    : Bus 24066	: V=0.9790943, theta=-16.593956 -> V=1.0, theta=0.0
% INFO    : Bus 24067	: V=0.9770634, theta=-16.835273 -> V=1.0, theta=0.0
% INFO    : Bus 24068	: V=0.9861167, theta=-15.603991 -> V=1.0, theta=0.0
% INFO    : Bus 24069	: V=0.9916562, theta=-16.648851 -> V=1.0, theta=0.0
% INFO    : Bus 24070	: V=0.9227722, theta=-14.145418 -> V=1.0, theta=0.0
% INFO    : Bus 24071	: V=0.9275527, theta=-14.577382 -> V=1.0, theta=0.0
% INFO    : Bus 24072	: V=0.9359442, theta=-13.792192 -> V=1.0, theta=0.0
% INFO    : Bus 24073	: V=0.9208796, theta=-14.204542 -> V=1.0, theta=0.0
% INFO    : Bus 24074	: V=0.9233187, theta=-18.987581 -> V=1.0, theta=0.0
% INFO    : Bus 24075	: V=0.9332925, theta=-17.179556 -> V=1.0, theta=0.0
% INFO    : Bus 24076	: V=0.9342711, theta=-17.083591 -> V=1.0, theta=0.0
% INFO    : Bus 24077	: V=0.9251993, theta=-18.482464 -> V=1.0, theta=0.0
% INFO    : Bus 24078	: V=0.9330688, theta=-12.907491 -> V=1.0, theta=0.0
% INFO    : Bus 24079	: V=0.9425005, theta=-13.793706 -> V=1.0, theta=0.0
% INFO    : Bus 24080	: V=0.9281272, theta=-15.824129 -> V=1.0, theta=0.0
% INFO    : Bus 24081	: V=0.9401362, theta=-12.992989 -> V=1.0, theta=0.0
% INFO    : Bus 24082	: V=0.0, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 24083	: V=0.9347071, theta=-15.48395 -> V=1.0, theta=0.0
% INFO    : Bus 24084	: V=0.9291381, theta=-15.955036 -> V=1.0, theta=0.0
% INFO    : Bus 24085	: V=0.9403928, theta=-16.24445 -> V=1.0, theta=0.0
% INFO    : Bus 24086	: V=0.9261872, theta=-17.378327 -> V=1.0, theta=0.0
% INFO    : Bus 24087	: V=1.0100951, theta=-11.268013 -> V=1.0, theta=0.0
% INFO    : Bus 24088	: V=0.9944813, theta=-12.308913 -> V=1.0, theta=0.0
% INFO    : Bus 24089	: V=0.9880499, theta=-12.32475 -> V=1.0, theta=0.0
% INFO    : Bus 24090	: V=1.0052741, theta=-11.92552 -> V=1.0, theta=0.0
% INFO    : Bus 24091	: V=0.9906766, theta=-13.184374 -> V=1.0, theta=0.0
% INFO    : Bus 24092	: V=0.9868495, theta=-13.479762 -> V=1.0, theta=0.0
% INFO    : Bus 24093	: V=0.9964958, theta=-15.147559 -> V=1.0, theta=0.0
% INFO    : Bus 24094	: V=0.9857794, theta=-13.595081 -> V=1.0, theta=0.0
% INFO    : Bus 24095	: V=0.9890918, theta=-13.165544 -> V=1.0, theta=0.0
% INFO    : Bus 24096	: V=0.9986903, theta=-11.336239 -> V=1.0, theta=0.0
% INFO    : Bus 24097	: V=0.972393, theta=-13.61345 -> V=1.0, theta=0.0
% INFO    : Bus 24098	: V=0.9876737, theta=-13.868875 -> V=1.0, theta=0.0
% INFO    : Bus 24099	: V=1.0074334, theta=6.707149 -> V=1.0, theta=0.0
% INFO    : Bus 24100	: V=0.9779847, theta=14.568444 -> V=1.0, theta=0.0
% INFO    : Bus 24101	: V=0.9880845, theta=13.3943 -> V=1.0, theta=0.0
% INFO    : Bus 24102	: V=0.9601047, theta=-11.248761 -> V=1.0, theta=0.0
% INFO    : Bus 24103	: V=0.9809255, theta=-7.653511 -> V=1.0, theta=0.0
% INFO    : Bus 24104	: V=0.9760702, theta=-8.617754 -> V=1.0, theta=0.0
% INFO    : Bus 24105	: V=0.9632745, theta=-11.31188 -> V=1.0, theta=0.0
% INFO    : Bus 24106	: V=0.9631893, theta=-11.360197 -> V=1.0, theta=0.0
% INFO    : Bus 24107	: V=0.9637814, theta=-11.258994 -> V=1.0, theta=0.0
% INFO    : Bus 24108	: V=0.9634872, theta=-11.278595 -> V=1.0, theta=0.0
% INFO    : Bus 24109	: V=0.9633644, theta=-11.300445 -> V=1.0, theta=0.0
% INFO    : Bus 24110	: V=0.9610529, theta=-13.568456 -> V=1.0, theta=0.0
% INFO    : Bus 24111	: V=0.9590339, theta=-12.397614 -> V=1.0, theta=0.0
% INFO    : Bus 24112	: V=0.9665591, theta=-10.409679 -> V=1.0, theta=0.0
% INFO    : Bus 24113	: V=0.9719942, theta=-9.750961 -> V=1.0, theta=0.0
% INFO    : Bus 24114	: V=0.9650501, theta=-11.070136 -> V=1.0, theta=0.0
% INFO    : Bus 24115	: V=0.9665406, theta=-11.499627 -> V=1.0, theta=0.0
% INFO    : Bus 24116	: V=0.9688723, theta=-10.971152 -> V=1.0, theta=0.0
% INFO    : Bus 24117	: V=0.9631245, theta=-12.632572 -> V=1.0, theta=0.0
% INFO    : Bus 24118	: V=0.959279, theta=-13.270621 -> V=1.0, theta=0.0
% INFO    : Bus 24119	: V=0.9682053, theta=-12.152465 -> V=1.0, theta=0.0
% INFO    : Bus 24120	: V=0.9813549, theta=-10.403312 -> V=1.0, theta=0.0
% INFO    : Bus 24121	: V=0.9990559, theta=-7.621842 -> V=1.0, theta=0.0
% INFO    : Bus 24122	: V=0.9707084, theta=-11.84548 -> V=1.0, theta=0.0
% INFO    : Bus 24123	: V=0.9772116, theta=-11.523496 -> V=1.0, theta=0.0
% INFO    : Bus 24124	: V=0.9950319, theta=-8.482685 -> V=1.0, theta=0.0
% INFO    : Bus 24125	: V=0.9925204, theta=-8.892581 -> V=1.0, theta=0.0
% INFO    : Bus 24126	: V=0.9942784, theta=-7.241335 -> V=1.0, theta=0.0
% INFO    : Bus 24127	: V=0.9795812, theta=-11.029693 -> V=1.0, theta=0.0
% INFO    : Bus 24128	: V=0.9880832, theta=-10.324791 -> V=1.0, theta=0.0
% INFO    : Bus 24129	: V=0.973156, theta=-12.386888 -> V=1.0, theta=0.0
% INFO    : Bus 24130	: V=0.985504, theta=-11.472592 -> V=1.0, theta=0.0
% INFO    : Bus 24131	: V=0.9843165, theta=-11.090495 -> V=1.0, theta=0.0
% INFO    : Bus 24132	: V=0.9711674, theta=-5.978937 -> V=1.0, theta=0.0
% INFO    : Bus 24133	: V=0.9927342, theta=-2.35244 -> V=1.0, theta=0.0
% INFO    : Bus 24134	: V=1.0019521, theta=-1.963114 -> V=1.0, theta=0.0
% INFO    : Bus 24135	: V=1.0033381, theta=-2.043907 -> V=1.0, theta=0.0
% INFO    : Bus 24136	: V=0.9887276, theta=-2.829531 -> V=1.0, theta=0.0
% INFO    : Bus 24137	: V=1.0060562, theta=-3.372773 -> V=1.0, theta=0.0
% INFO    : Bus 24138	: V=0.9660031, theta=-6.923478 -> V=1.0, theta=0.0
% INFO    : Bus 24139	: V=0.9879101, theta=-5.081271 -> V=1.0, theta=0.0
% INFO    : Bus 24140	: V=0.982659, theta=-5.573766 -> V=1.0, theta=0.0
% INFO    : Bus 24141	: V=0.989928, theta=-3.917445 -> V=1.0, theta=0.0
% INFO    : Bus 24142	: V=0.9740938, theta=-6.921544 -> V=1.0, theta=0.0
% INFO    : Bus 24143	: V=0.9612867, theta=-8.367054 -> V=1.0, theta=0.0
% INFO    : Bus 24144	: V=0.9939043, theta=-3.868481 -> V=1.0, theta=0.0
% INFO    : Bus 24145	: V=0.9755085, theta=-6.503839 -> V=1.0, theta=0.0
% INFO    : Bus 24146	: V=0.9928128, theta=-4.155857 -> V=1.0, theta=0.0
% INFO    : Bus 24147	: V=0.9715998, theta=-24.710446 -> V=1.0, theta=0.0
% INFO    : Bus 24148	: V=0.9703018, theta=-25.672751 -> V=1.0, theta=0.0
% INFO    : Bus 24149	: V=0.969154, theta=-25.704654 -> V=1.0, theta=0.0
% INFO    : Bus 24150	: V=0.9678273, theta=-25.761365 -> V=1.0, theta=0.0
% INFO    : Bus 24151	: V=0.9680415, theta=-25.692583 -> V=1.0, theta=0.0
% INFO    : Bus 24152	: V=0.9678837, theta=-25.651829 -> V=1.0, theta=0.0
% INFO    : Bus 24153	: V=0.9685341, theta=-25.548345 -> V=1.0, theta=0.0
% INFO    : Bus 24154	: V=0.9700037, theta=-25.617924 -> V=1.0, theta=0.0
% INFO    : Bus 24155	: V=0.9693913, theta=-25.692428 -> V=1.0, theta=0.0
% INFO    : Bus 24156	: V=0.9693698, theta=-25.696425 -> V=1.0, theta=0.0
% INFO    : Bus 24157	: V=0.9684696, theta=-25.841586 -> V=1.0, theta=0.0
% INFO    : Bus 24158	: V=0.9683052, theta=-25.709918 -> V=1.0, theta=0.0
% INFO    : Bus 24159	: V=0.9705013, theta=-24.752343 -> V=1.0, theta=0.0
% INFO    : Bus 24160	: V=0.9671321, theta=-25.728535 -> V=1.0, theta=0.0
% INFO    : Bus 24161	: V=0.967798, theta=-25.501716 -> V=1.0, theta=0.0
% INFO    : Bus 24162	: V=0.9679813, theta=-25.496655 -> V=1.0, theta=0.0
% INFO    : Bus 24163	: V=0.9733235, theta=-24.344118 -> V=1.0, theta=0.0
% INFO    : Bus 24164	: V=0.96766, theta=-25.50935 -> V=1.0, theta=0.0
% INFO    : Bus 24165	: V=0.9676753, theta=-25.512253 -> V=1.0, theta=0.0
% INFO    : Bus 24166	: V=0.9673029, theta=-25.73563 -> V=1.0, theta=0.0
% INFO    : Bus 24167	: V=0.9681614, theta=-25.730834 -> V=1.0, theta=0.0
% INFO    : Bus 24168	: V=0.9675415, theta=-25.589663 -> V=1.0, theta=0.0
% INFO    : Bus 24169	: V=0.9675067, theta=-25.557655 -> V=1.0, theta=0.0
% INFO    : Bus 24170	: V=0.9671983, theta=-25.650285 -> V=1.0, theta=0.0
% INFO    : Bus 24171	: V=0.9667128, theta=-25.695778 -> V=1.0, theta=0.0
% INFO    : Bus 24172	: V=0.965919, theta=-25.766489 -> V=1.0, theta=0.0
% INFO    : Bus 24173	: V=0.9659742, theta=-25.859618 -> V=1.0, theta=0.0
% INFO    : Bus 24174	: V=0.9689031, theta=-26.402657 -> V=1.0, theta=0.0
% INFO    : Bus 24175	: V=0.9667182, theta=-25.954286 -> V=1.0, theta=0.0
% INFO    : Bus 24176	: V=0.9682712, theta=-25.905518 -> V=1.0, theta=0.0
% INFO    : Bus 24177	: V=0.9671451, theta=-26.041331 -> V=1.0, theta=0.0
% INFO    : Bus 24178	: V=0.968914, theta=-26.381357 -> V=1.0, theta=0.0
% INFO    : Bus 24179	: V=0.9635369, theta=-26.177678 -> V=1.0, theta=0.0
% INFO    : Bus 24180	: V=0.967222, theta=-25.81034 -> V=1.0, theta=0.0
% INFO    : Bus 24181	: V=0.9713334, theta=-24.389379 -> V=1.0, theta=0.0
% INFO    : Bus 24182	: V=0.9654308, theta=-25.698351 -> V=1.0, theta=0.0
% INFO    : Bus 24183	: V=0.9633091, theta=-25.866499 -> V=1.0, theta=0.0
% INFO    : Bus 24184	: V=0.9714411, theta=-25.77379 -> V=1.0, theta=0.0
% INFO    : Bus 24185	: V=0.9699423, theta=-24.858934 -> V=1.0, theta=0.0
% INFO    : Bus 24186	: V=0.9667668, theta=-26.019295 -> V=1.0, theta=0.0
% INFO    : Bus 24187	: V=0.9673666, theta=-26.067654 -> V=1.0, theta=0.0
% INFO    : Bus 24188	: V=0.9663739, theta=-26.099267 -> V=1.0, theta=0.0
% INFO    : Bus 24189	: V=0.965443, theta=-26.115455 -> V=1.0, theta=0.0
% INFO    : Bus 24190	: V=0.9648693, theta=-26.112564 -> V=1.0, theta=0.0
% INFO    : Bus 24191	: V=0.9647463, theta=-26.093671 -> V=1.0, theta=0.0
% INFO    : Bus 24192	: V=0.9645167, theta=-26.094833 -> V=1.0, theta=0.0
% INFO    : Bus 24193	: V=0.9673055, theta=-25.962365 -> V=1.0, theta=0.0
% INFO    : Bus 24194	: V=0.9676399, theta=-25.961947 -> V=1.0, theta=0.0
% INFO    : Bus 24195	: V=0.9672811, theta=-25.965932 -> V=1.0, theta=0.0
% INFO    : Bus 24196	: V=0.9676386, theta=-26.166515 -> V=1.0, theta=0.0
% INFO    : Bus 24197	: V=0.9637728, theta=-25.961043 -> V=1.0, theta=0.0
% INFO    : Bus 24198	: V=0.9651317, theta=-26.083767 -> V=1.0, theta=0.0
% INFO    : Bus 24199	: V=0.9639424, theta=-25.864808 -> V=1.0, theta=0.0
% INFO    : Bus 24200	: V=0.9666405, theta=-26.121271 -> V=1.0, theta=0.0
% INFO    : Bus 24201	: V=0.965547, theta=-26.136679 -> V=1.0, theta=0.0
% INFO    : Bus 24202	: V=0.9700409, theta=-26.234453 -> V=1.0, theta=0.0
% INFO    : Bus 24203	: V=0.9657045, theta=-26.137441 -> V=1.0, theta=0.0
% INFO    : Bus 24204	: V=0.9871152, theta=-25.29004 -> V=1.0, theta=0.0
% INFO    : Bus 24205	: V=0.9705438, theta=-26.374296 -> V=1.0, theta=0.0
% INFO    : Bus 24206	: V=0.9717476, theta=-26.434526 -> V=1.0, theta=0.0
% INFO    : Bus 24207	: V=0.9852015, theta=-25.614935 -> V=1.0, theta=0.0
% INFO    : Bus 24208	: V=0.9699909, theta=-25.920622 -> V=1.0, theta=0.0
% INFO    : Bus 24209	: V=0.9693848, theta=-26.009398 -> V=1.0, theta=0.0
% INFO    : Bus 24210	: V=0.9689585, theta=-26.371105 -> V=1.0, theta=0.0
% INFO    : Bus 24211	: V=0.968958, theta=-26.367647 -> V=1.0, theta=0.0
% INFO    : Bus 24212	: V=0.9647913, theta=-25.855321 -> V=1.0, theta=0.0
% INFO    : Bus 24213	: V=0.9654216, theta=-25.792921 -> V=1.0, theta=0.0
% INFO    : Bus 24214	: V=0.9681708, theta=-26.341983 -> V=1.0, theta=0.0
% INFO    : Bus 24215	: V=0.9614826, theta=-26.233115 -> V=1.0, theta=0.0
% INFO    : Bus 24216	: V=0.9729204, theta=-26.376101 -> V=1.0, theta=0.0
% INFO    : Bus 24217	: V=0.9640477, theta=-25.931694 -> V=1.0, theta=0.0
% INFO    : Bus 24218	: V=0.9840029, theta=-25.642982 -> V=1.0, theta=0.0
% INFO    : Bus 24219	: V=0.9644189, theta=-26.934106 -> V=1.0, theta=0.0
% INFO    : Bus 24220	: V=0.9697121, theta=-26.802031 -> V=1.0, theta=0.0
% INFO    : Bus 24221	: V=0.9616276, theta=-27.475474 -> V=1.0, theta=0.0
% INFO    : Bus 24222	: V=0.9532495, theta=-29.051205 -> V=1.0, theta=0.0
% INFO    : Bus 24223	: V=0.9513151, theta=-28.035249 -> V=1.0, theta=0.0
% INFO    : Bus 24224	: V=0.9538904, theta=-27.906109 -> V=1.0, theta=0.0
% INFO    : Bus 24225	: V=0.9611192, theta=-27.238025 -> V=1.0, theta=0.0
% INFO    : Bus 24226	: V=0.9697027, theta=-26.694194 -> V=1.0, theta=0.0
% INFO    : Bus 24227	: V=0.957802, theta=-28.070295 -> V=1.0, theta=0.0
% INFO    : Bus 24228	: V=0.9646544, theta=-25.749115 -> V=1.0, theta=0.0
% INFO    : Bus 24229	: V=0.9585351, theta=-28.321243 -> V=1.0, theta=0.0
% INFO    : Bus 24230	: V=0.9706708, theta=-27.444574 -> V=1.0, theta=0.0
% INFO    : Bus 24231	: V=0.9661689, theta=-28.103792 -> V=1.0, theta=0.0
% INFO    : Bus 24232	: V=0.9643188, theta=-21.048576 -> V=1.0, theta=0.0
% INFO    : Bus 24233	: V=0.9681978, theta=-18.934275 -> V=1.0, theta=0.0
% INFO    : Bus 24234	: V=0.9831, theta=-22.753444 -> V=1.0, theta=0.0
% INFO    : Bus 24235	: V=0.9696597, theta=-22.617963 -> V=1.0, theta=0.0
% INFO    : Bus 24236	: V=0.9884766, theta=-22.411628 -> V=1.0, theta=0.0
% INFO    : Bus 24237	: V=0.9674996, theta=-22.958817 -> V=1.0, theta=0.0
% INFO    : Bus 24238	: V=0.965837, theta=-25.479672 -> V=1.0, theta=0.0
% INFO    : Bus 24239	: V=0.963724, theta=-23.618951 -> V=1.0, theta=0.0
% INFO    : Bus 24240	: V=0.9767834, theta=-23.881093 -> V=1.0, theta=0.0
% INFO    : Bus 24241	: V=0.9743163, theta=-24.243213 -> V=1.0, theta=0.0
% INFO    : Bus 24242	: V=0.9650487, theta=-21.566534 -> V=1.0, theta=0.0
% INFO    : Bus 24243	: V=0.9619171, theta=-22.494146 -> V=1.0, theta=0.0
% INFO    : Bus 24244	: V=0.9619723, theta=-21.68235 -> V=1.0, theta=0.0
% INFO    : Bus 24245	: V=0.9616613, theta=-21.956539 -> V=1.0, theta=0.0
% INFO    : Bus 24246	: V=0.9670187, theta=-26.122054 -> V=1.0, theta=0.0
% INFO    : Bus 24247	: V=0.9659051, theta=-22.882542 -> V=1.0, theta=0.0
% INFO    : Bus 24248	: V=0.967211, theta=-22.874252 -> V=1.0, theta=0.0
% INFO    : Bus 24249	: V=0.9681891, theta=-22.860868 -> V=1.0, theta=0.0
% INFO    : Bus 24250	: V=0.9705147, theta=-22.905314 -> V=1.0, theta=0.0
% INFO    : Bus 24251	: V=0.969638, theta=-22.740783 -> V=1.0, theta=0.0
% INFO    : Bus 24252	: V=0.968152, theta=-22.807026 -> V=1.0, theta=0.0
% INFO    : Bus 24253	: V=0.966964, theta=-22.803794 -> V=1.0, theta=0.0
% INFO    : Bus 24254	: V=0.9679263, theta=-22.758586 -> V=1.0, theta=0.0
% INFO    : Bus 24255	: V=0.9682313, theta=-22.75783 -> V=1.0, theta=0.0
% INFO    : Bus 24256	: V=0.9680355, theta=-22.758992 -> V=1.0, theta=0.0
% INFO    : Bus 24257	: V=0.9714178, theta=-22.642976 -> V=1.0, theta=0.0
% INFO    : Bus 24258	: V=0.9727833, theta=-22.572897 -> V=1.0, theta=0.0
% INFO    : Bus 24259	: V=0.9883022, theta=-21.368165 -> V=1.0, theta=0.0
% INFO    : Bus 24260	: V=0.9750476, theta=-22.358223 -> V=1.0, theta=0.0
% INFO    : Bus 24261	: V=0.9763238, theta=-22.207713 -> V=1.0, theta=0.0
% INFO    : Bus 24262	: V=0.971104, theta=-22.104446 -> V=1.0, theta=0.0
% INFO    : Bus 24263	: V=0.9785766, theta=-22.135944 -> V=1.0, theta=0.0
% INFO    : Bus 24264	: V=0.9808935, theta=-22.042791 -> V=1.0, theta=0.0
% INFO    : Bus 24265	: V=0.9817583, theta=-22.031882 -> V=1.0, theta=0.0
% INFO    : Bus 24266	: V=0.9888125, theta=-21.347693 -> V=1.0, theta=0.0
% INFO    : Bus 24267	: V=0.967349, theta=-22.865905 -> V=1.0, theta=0.0
% INFO    : Bus 24268	: V=0.9787682, theta=-22.252817 -> V=1.0, theta=0.0
% INFO    : Bus 24269	: V=0.9701274, theta=-22.902887 -> V=1.0, theta=0.0
% INFO    : Bus 24270	: V=0.9683216, theta=-22.881887 -> V=1.0, theta=0.0
% INFO    : Bus 24271	: V=0.978934, theta=-22.381827 -> V=1.0, theta=0.0
% INFO    : Bus 24272	: V=0.979123, theta=-22.375839 -> V=1.0, theta=0.0
% INFO    : Bus 24273	: V=0.9756221, theta=-22.578159 -> V=1.0, theta=0.0
% INFO    : Bus 24274	: V=0.9754791, theta=-22.578051 -> V=1.0, theta=0.0
% INFO    : Bus 24275	: V=0.9715521, theta=-22.660339 -> V=1.0, theta=0.0
% INFO    : Bus 24276	: V=0.9754392, theta=-22.565674 -> V=1.0, theta=0.0
% INFO    : Bus 24277	: V=0.9757035, theta=-22.566504 -> V=1.0, theta=0.0
% INFO    : Bus 24278	: V=0.9754644, theta=-22.568393 -> V=1.0, theta=0.0
% INFO    : Bus 24279	: V=0.9750129, theta=-23.056799 -> V=1.0, theta=0.0
% INFO    : Bus 24280	: V=0.980515, theta=-22.487737 -> V=1.0, theta=0.0
% INFO    : Bus 24281	: V=0.9716216, theta=-23.014939 -> V=1.0, theta=0.0
% INFO    : Bus 24282	: V=0.9704208, theta=-23.012607 -> V=1.0, theta=0.0
% INFO    : Bus 24283	: V=0.9704542, theta=-23.052323 -> V=1.0, theta=0.0
% INFO    : Bus 24284	: V=0.9799426, theta=-22.449114 -> V=1.0, theta=0.0
% INFO    : Bus 24285	: V=0.9794385, theta=-22.408733 -> V=1.0, theta=0.0
% INFO    : Bus 24286	: V=0.9815072, theta=-22.534098 -> V=1.0, theta=0.0
% INFO    : Bus 24287	: V=0.9825767, theta=-22.005307 -> V=1.0, theta=0.0
% INFO    : Bus 24288	: V=0.9701717, theta=-23.132264 -> V=1.0, theta=0.0
% INFO    : Bus 24289	: V=0.9691953, theta=-23.198589 -> V=1.0, theta=0.0
% INFO    : Bus 24290	: V=0.980024, theta=-22.592314 -> V=1.0, theta=0.0
% INFO    : Bus 24291	: V=0.9696229, theta=-23.152238 -> V=1.0, theta=0.0
% INFO    : Bus 24292	: V=0.9695233, theta=-23.107266 -> V=1.0, theta=0.0
% INFO    : Bus 24293	: V=0.969711, theta=-23.058337 -> V=1.0, theta=0.0
% INFO    : Bus 24294	: V=0.9670239, theta=-23.157637 -> V=1.0, theta=0.0
% INFO    : Bus 24295	: V=0.967386, theta=-23.172801 -> V=1.0, theta=0.0
% INFO    : Bus 24296	: V=0.9682112, theta=-23.190224 -> V=1.0, theta=0.0
% INFO    : Bus 24297	: V=0.9642571, theta=-23.489071 -> V=1.0, theta=0.0
% INFO    : Bus 24298	: V=0.9647232, theta=-23.497575 -> V=1.0, theta=0.0
% INFO    : Bus 24299	: V=0.9638245, theta=-23.503465 -> V=1.0, theta=0.0
% INFO    : Bus 24300	: V=0.9640144, theta=-23.474991 -> V=1.0, theta=0.0
% INFO    : Bus 24301	: V=0.9636868, theta=-23.476291 -> V=1.0, theta=0.0
% INFO    : Bus 24302	: V=0.9639821, theta=-23.521761 -> V=1.0, theta=0.0
% INFO    : Bus 24303	: V=0.9635325, theta=-23.572472 -> V=1.0, theta=0.0
% INFO    : Bus 24304	: V=0.9633224, theta=-23.47448 -> V=1.0, theta=0.0
% INFO    : Bus 24305	: V=0.9643368, theta=-23.421113 -> V=1.0, theta=0.0
% INFO    : Bus 24306	: V=0.9659593, theta=-23.492119 -> V=1.0, theta=0.0
% INFO    : Bus 24307	: V=0.9678626, theta=-23.479618 -> V=1.0, theta=0.0
% INFO    : Bus 24308	: V=0.9706874, theta=-23.24642 -> V=1.0, theta=0.0
% INFO    : Bus 24309	: V=0.9715933, theta=-23.28633 -> V=1.0, theta=0.0
% INFO    : Bus 24310	: V=0.9955499, theta=-21.524584 -> V=1.0, theta=0.0
% INFO    : Bus 24311	: V=0.9727647, theta=-23.245651 -> V=1.0, theta=0.0
% INFO    : Bus 24312	: V=0.9701093, theta=-23.225212 -> V=1.0, theta=0.0
% INFO    : Bus 24313	: V=0.9688285, theta=-23.477659 -> V=1.0, theta=0.0
% INFO    : Bus 24314	: V=0.9732492, theta=-23.249361 -> V=1.0, theta=0.0
% INFO    : Bus 24315	: V=0.974851, theta=-22.500508 -> V=1.0, theta=0.0
% INFO    : Bus 24316	: V=0.9784288, theta=-22.438075 -> V=1.0, theta=0.0
% INFO    : Bus 24317	: V=0.9813822, theta=-22.293889 -> V=1.0, theta=0.0
% INFO    : Bus 24318	: V=0.9893237, theta=-21.325243 -> V=1.0, theta=0.0
% INFO    : Bus 24319	: V=0.9848609, theta=-21.901679 -> V=1.0, theta=0.0
% INFO    : Bus 24320	: V=0.990672, theta=-21.248985 -> V=1.0, theta=0.0
% INFO    : Bus 24321	: V=1.002565, theta=-20.38672 -> V=1.0, theta=0.0
% INFO    : Bus 24322	: V=1.0048893, theta=-20.223521 -> V=1.0, theta=0.0
% INFO    : Bus 24323	: V=0.9912547, theta=-21.228384 -> V=1.0, theta=0.0
% INFO    : Bus 24324	: V=0.9925285, theta=-20.936656 -> V=1.0, theta=0.0
% INFO    : Bus 24325	: V=0.9822572, theta=-22.43157 -> V=1.0, theta=0.0
% INFO    : Bus 24326	: V=0.9799972, theta=-22.571472 -> V=1.0, theta=0.0
% INFO    : Bus 24327	: V=0.9768583, theta=-22.896726 -> V=1.0, theta=0.0
% INFO    : Bus 24328	: V=0.9767834, theta=-22.562672 -> V=1.0, theta=0.0
% INFO    : Bus 24329	: V=0.9784029, theta=-22.724828 -> V=1.0, theta=0.0
% INFO    : Bus 24330	: V=0.9796817, theta=-22.737497 -> V=1.0, theta=0.0
% INFO    : Bus 24331	: V=0.9816784, theta=-22.608964 -> V=1.0, theta=0.0
% INFO    : Bus 24332	: V=0.9820081, theta=-22.545494 -> V=1.0, theta=0.0
% INFO    : Bus 24333	: V=0.9822339, theta=-22.508783 -> V=1.0, theta=0.0
% INFO    : Bus 24334	: V=0.9880662, theta=-22.148731 -> V=1.0, theta=0.0
% INFO    : Bus 24335	: V=0.9759044, theta=-22.99049 -> V=1.0, theta=0.0
% INFO    : Bus 24336	: V=0.9734415, theta=-23.103491 -> V=1.0, theta=0.0
% INFO    : Bus 24337	: V=0.9816942, theta=-22.66853 -> V=1.0, theta=0.0
% INFO    : Bus 24338	: V=0.9740869, theta=-23.096521 -> V=1.0, theta=0.0
% INFO    : Bus 24339	: V=0.9780685, theta=-22.83277 -> V=1.0, theta=0.0
% INFO    : Bus 24340	: V=0.9832284, theta=-22.571235 -> V=1.0, theta=0.0
% INFO    : Bus 24341	: V=0.9814368, theta=-22.808076 -> V=1.0, theta=0.0
% INFO    : Bus 24342	: V=0.9808238, theta=-22.835347 -> V=1.0, theta=0.0
% INFO    : Bus 24343	: V=0.980917, theta=-22.809676 -> V=1.0, theta=0.0
% INFO    : Bus 24344	: V=0.9765134, theta=-22.938391 -> V=1.0, theta=0.0
% INFO    : Bus 24345	: V=0.9799356, theta=-22.896167 -> V=1.0, theta=0.0
% INFO    : Bus 24346	: V=0.9794706, theta=-22.939604 -> V=1.0, theta=0.0
% INFO    : Bus 24347	: V=0.9793835, theta=-22.939628 -> V=1.0, theta=0.0
% INFO    : Bus 24348	: V=0.9793733, theta=-22.990113 -> V=1.0, theta=0.0
% INFO    : Bus 24349	: V=0.9793102, theta=-23.046797 -> V=1.0, theta=0.0
% INFO    : Bus 24350	: V=0.9835781, theta=-22.81312 -> V=1.0, theta=0.0
% INFO    : Bus 24351	: V=0.9808404, theta=-22.681653 -> V=1.0, theta=0.0
% INFO    : Bus 24352	: V=0.9822254, theta=-22.729154 -> V=1.0, theta=0.0
% INFO    : Bus 24353	: V=0.9819429, theta=-22.697699 -> V=1.0, theta=0.0
% INFO    : Bus 24354	: V=0.9747723, theta=-23.051143 -> V=1.0, theta=0.0
% INFO    : Bus 24355	: V=0.974875, theta=-23.050205 -> V=1.0, theta=0.0
% INFO    : Bus 24356	: V=0.9775672, theta=-22.730337 -> V=1.0, theta=0.0
% INFO    : Bus 24357	: V=0.979823, theta=-22.88151 -> V=1.0, theta=0.0
% INFO    : Bus 24358	: V=0.9841375, theta=-22.846369 -> V=1.0, theta=0.0
% INFO    : Bus 24359	: V=0.984371, theta=-22.854277 -> V=1.0, theta=0.0
% INFO    : Bus 24360	: V=0.9847537, theta=-22.885245 -> V=1.0, theta=0.0
% INFO    : Bus 24361	: V=0.9851683, theta=-22.900297 -> V=1.0, theta=0.0
% INFO    : Bus 24362	: V=0.9864939, theta=-22.904234 -> V=1.0, theta=0.0
% INFO    : Bus 24363	: V=0.9867739, theta=-22.835076 -> V=1.0, theta=0.0
% INFO    : Bus 24364	: V=0.9804848, theta=-23.124783 -> V=1.0, theta=0.0
% INFO    : Bus 24365	: V=0.9852769, theta=-22.879384 -> V=1.0, theta=0.0
% INFO    : Bus 24366	: V=0.9797989, theta=-22.975312 -> V=1.0, theta=0.0
% INFO    : Bus 24367	: V=0.9778189, theta=-23.081635 -> V=1.0, theta=0.0
% INFO    : Bus 24368	: V=0.9853842, theta=-22.835838 -> V=1.0, theta=0.0
% INFO    : Bus 24369	: V=0.9837822, theta=-23.234038 -> V=1.0, theta=0.0
% INFO    : Bus 24370	: V=0.9829845, theta=-23.253805 -> V=1.0, theta=0.0
% INFO    : Bus 24371	: V=0.9837582, theta=-22.831308 -> V=1.0, theta=0.0
% INFO    : Bus 24372	: V=0.9751177, theta=-23.247918 -> V=1.0, theta=0.0
% INFO    : Bus 24373	: V=0.9844064, theta=-22.867743 -> V=1.0, theta=0.0
% INFO    : Bus 24374	: V=0.9884081, theta=-22.821506 -> V=1.0, theta=0.0
% INFO    : Bus 24375	: V=0.9852883, theta=-23.121612 -> V=1.0, theta=0.0
% INFO    : Bus 24376	: V=0.9840508, theta=-23.149571 -> V=1.0, theta=0.0
% INFO    : Bus 24377	: V=0.9826122, theta=-23.153028 -> V=1.0, theta=0.0
% INFO    : Bus 24378	: V=0.9878032, theta=-23.067286 -> V=1.0, theta=0.0
% INFO    : Bus 24379	: V=1.0000164, theta=-21.808273 -> V=1.0, theta=0.0
% INFO    : Bus 24380	: V=0.9859822, theta=-23.2667 -> V=1.0, theta=0.0
% INFO    : Bus 24381	: V=1.0007981, theta=-21.814503 -> V=1.0, theta=0.0
% INFO    : Bus 24382	: V=0.9931219, theta=-22.727176 -> V=1.0, theta=0.0
% INFO    : Bus 24383	: V=1.0046324, theta=-21.817205 -> V=1.0, theta=0.0
% INFO    : Bus 24384	: V=0.9853729, theta=-23.474236 -> V=1.0, theta=0.0
% INFO    : Bus 24385	: V=0.9847052, theta=-23.499629 -> V=1.0, theta=0.0
% INFO    : Bus 24386	: V=1.0052229, theta=-21.768882 -> V=1.0, theta=0.0
% INFO    : Bus 24387	: V=1.0025694, theta=-21.818658 -> V=1.0, theta=0.0
% INFO    : Bus 24388	: V=0.9848938, theta=-23.207265 -> V=1.0, theta=0.0
% INFO    : Bus 24389	: V=0.985082, theta=-23.206812 -> V=1.0, theta=0.0
% INFO    : Bus 24390	: V=0.9896317, theta=-22.774886 -> V=1.0, theta=0.0
% INFO    : Bus 24391	: V=0.9900572, theta=-22.722652 -> V=1.0, theta=0.0
% INFO    : Bus 24392	: V=0.9890281, theta=-22.743539 -> V=1.0, theta=0.0
% INFO    : Bus 24393	: V=1.0009486, theta=-21.774947 -> V=1.0, theta=0.0
% INFO    : Bus 24394	: V=0.9862641, theta=-23.12912 -> V=1.0, theta=0.0
% INFO    : Bus 24395	: V=0.9860578, theta=-23.127401 -> V=1.0, theta=0.0
% INFO    : Bus 24396	: V=0.9993055, theta=-21.742867 -> V=1.0, theta=0.0
% INFO    : Bus 24397	: V=0.9879409, theta=-22.763319 -> V=1.0, theta=0.0
% INFO    : Bus 24398	: V=0.9857642, theta=-22.808533 -> V=1.0, theta=0.0
% INFO    : Bus 24399	: V=0.9820897, theta=-23.303736 -> V=1.0, theta=0.0
% INFO    : Bus 24400	: V=0.9832771, theta=-23.266518 -> V=1.0, theta=0.0
% INFO    : Bus 24401	: V=0.9634251, theta=-23.735046 -> V=1.0, theta=0.0
% INFO    : Bus 24402	: V=0.9622483, theta=-23.772262 -> V=1.0, theta=0.0
% INFO    : Bus 24403	: V=0.9639459, theta=-23.768689 -> V=1.0, theta=0.0
% INFO    : Bus 24404	: V=0.9649015, theta=-23.741884 -> V=1.0, theta=0.0
% INFO    : Bus 24405	: V=0.9648494, theta=-23.750425 -> V=1.0, theta=0.0
% INFO    : Bus 24406	: V=0.9723532, theta=-23.567173 -> V=1.0, theta=0.0
% INFO    : Bus 24407	: V=0.9722919, theta=-23.564035 -> V=1.0, theta=0.0
% INFO    : Bus 24408	: V=0.9737324, theta=-23.45293 -> V=1.0, theta=0.0
% INFO    : Bus 24409	: V=0.9700364, theta=-23.513364 -> V=1.0, theta=0.0
% INFO    : Bus 24410	: V=0.971995, theta=-23.560682 -> V=1.0, theta=0.0
% INFO    : Bus 24411	: V=0.9721319, theta=-23.562828 -> V=1.0, theta=0.0
% INFO    : Bus 24412	: V=0.9661017, theta=-23.685635 -> V=1.0, theta=0.0
% INFO    : Bus 24413	: V=0.9648772, theta=-23.731563 -> V=1.0, theta=0.0
% INFO    : Bus 24414	: V=0.9635762, theta=-23.770786 -> V=1.0, theta=0.0
% INFO    : Bus 24415	: V=0.9659483, theta=-23.656277 -> V=1.0, theta=0.0
% INFO    : Bus 24416	: V=0.9660029, theta=-23.630916 -> V=1.0, theta=0.0
% INFO    : Bus 24417	: V=0.9679624, theta=-23.537706 -> V=1.0, theta=0.0
% INFO    : Bus 24418	: V=0.969136, theta=-23.500505 -> V=1.0, theta=0.0
% INFO    : Bus 24419	: V=0.970536, theta=-23.452397 -> V=1.0, theta=0.0
% INFO    : Bus 24420	: V=0.9821663, theta=-22.802537 -> V=1.0, theta=0.0
% INFO    : Bus 24421	: V=0.9719957, theta=-23.431239 -> V=1.0, theta=0.0
% INFO    : Bus 24422	: V=0.9827879, theta=-22.820524 -> V=1.0, theta=0.0
% INFO    : Bus 24423	: V=0.9735976, theta=-23.440513 -> V=1.0, theta=0.0
% INFO    : Bus 24424	: V=0.9752238, theta=-23.448628 -> V=1.0, theta=0.0
% INFO    : Bus 24425	: V=0.9750449, theta=-23.448658 -> V=1.0, theta=0.0
% INFO    : Bus 24426	: V=0.9761795, theta=-23.463093 -> V=1.0, theta=0.0
% INFO    : Bus 24427	: V=0.9773, theta=-23.478704 -> V=1.0, theta=0.0
% INFO    : Bus 24428	: V=0.9806946, theta=-23.348995 -> V=1.0, theta=0.0
% INFO    : Bus 24429	: V=0.9868261, theta=-22.811104 -> V=1.0, theta=0.0
% INFO    : Bus 24430	: V=0.9819896, theta=-22.768328 -> V=1.0, theta=0.0
% INFO    : Bus 24431	: V=0.9721857, theta=-23.687024 -> V=1.0, theta=0.0
% INFO    : Bus 24432	: V=0.9687667, theta=-23.773944 -> V=1.0, theta=0.0
% INFO    : Bus 24433	: V=0.9683994, theta=-23.821701 -> V=1.0, theta=0.0
% INFO    : Bus 24434	: V=0.9693989, theta=-23.81822 -> V=1.0, theta=0.0
% INFO    : Bus 24435	: V=0.9822544, theta=-22.904505 -> V=1.0, theta=0.0
% INFO    : Bus 24436	: V=0.9842393, theta=-22.849631 -> V=1.0, theta=0.0
% INFO    : Bus 24437	: V=0.9732621, theta=-23.697329 -> V=1.0, theta=0.0
% INFO    : Bus 24438	: V=0.9792221, theta=-23.100113 -> V=1.0, theta=0.0
% INFO    : Bus 24439	: V=0.9682786, theta=-23.849142 -> V=1.0, theta=0.0
% INFO    : Bus 24440	: V=0.9668579, theta=-23.880202 -> V=1.0, theta=0.0
% INFO    : Bus 24441	: V=0.9666088, theta=-23.906902 -> V=1.0, theta=0.0
% INFO    : Bus 24442	: V=0.9682993, theta=-23.881349 -> V=1.0, theta=0.0
% INFO    : Bus 24443	: V=0.9703674, theta=-23.825358 -> V=1.0, theta=0.0
% INFO    : Bus 24444	: V=0.9794925, theta=-23.10208 -> V=1.0, theta=0.0
% INFO    : Bus 24445	: V=0.9707433, theta=-23.792562 -> V=1.0, theta=0.0
% INFO    : Bus 24446	: V=0.9618968, theta=-23.80429 -> V=1.0, theta=0.0
% INFO    : Bus 24447	: V=0.9615439, theta=-23.84944 -> V=1.0, theta=0.0
% INFO    : Bus 24448	: V=0.9628399, theta=-23.809003 -> V=1.0, theta=0.0
% INFO    : Bus 24449	: V=0.9640359, theta=-23.793571 -> V=1.0, theta=0.0
% INFO    : Bus 24450	: V=0.965156, theta=-23.750318 -> V=1.0, theta=0.0
% INFO    : Bus 24451	: V=0.9775094, theta=-22.9855 -> V=1.0, theta=0.0
% INFO    : Bus 24452	: V=0.9657191, theta=-23.743985 -> V=1.0, theta=0.0
% INFO    : Bus 24453	: V=0.9616614, theta=-23.87674 -> V=1.0, theta=0.0
% INFO    : Bus 24454	: V=0.9616619, theta=-23.914438 -> V=1.0, theta=0.0
% INFO    : Bus 24455	: V=0.9621094, theta=-23.911289 -> V=1.0, theta=0.0
% INFO    : Bus 24456	: V=0.9630707, theta=-23.903521 -> V=1.0, theta=0.0
% INFO    : Bus 24457	: V=0.9650356, theta=-23.931988 -> V=1.0, theta=0.0
% INFO    : Bus 24458	: V=0.9621773, theta=-23.951346 -> V=1.0, theta=0.0
% INFO    : Bus 24459	: V=0.9609957, theta=-23.951838 -> V=1.0, theta=0.0
% INFO    : Bus 24460	: V=0.958428, theta=-23.880256 -> V=1.0, theta=0.0
% INFO    : Bus 24461	: V=0.9613558, theta=-23.944498 -> V=1.0, theta=0.0
% INFO    : Bus 24462	: V=0.961966, theta=-23.938241 -> V=1.0, theta=0.0
% INFO    : Bus 24463	: V=0.9619057, theta=-23.566728 -> V=1.0, theta=0.0
% INFO    : Bus 24464	: V=0.9617103, theta=-23.568381 -> V=1.0, theta=0.0
% INFO    : Bus 24465	: V=0.9630867, theta=-23.631019 -> V=1.0, theta=0.0
% INFO    : Bus 24466	: V=0.9621918, theta=-23.707943 -> V=1.0, theta=0.0
% INFO    : Bus 24467	: V=0.9609908, theta=-23.768659 -> V=1.0, theta=0.0
% INFO    : Bus 24468	: V=0.9600744, theta=-23.729814 -> V=1.0, theta=0.0
% INFO    : Bus 24469	: V=0.9588058, theta=-23.738345 -> V=1.0, theta=0.0
% INFO    : Bus 24470	: V=0.9596071, theta=-23.696314 -> V=1.0, theta=0.0
% INFO    : Bus 24471	: V=0.9601633, theta=-23.694282 -> V=1.0, theta=0.0
% INFO    : Bus 24472	: V=0.9605454, theta=-23.649259 -> V=1.0, theta=0.0
% INFO    : Bus 24473	: V=0.9601348, theta=-23.664047 -> V=1.0, theta=0.0
% INFO    : Bus 24474	: V=0.9578443, theta=-23.74095 -> V=1.0, theta=0.0
% INFO    : Bus 24475	: V=0.9582543, theta=-23.748003 -> V=1.0, theta=0.0
% INFO    : Bus 24476	: V=0.9580976, theta=-23.799931 -> V=1.0, theta=0.0
% INFO    : Bus 24477	: V=0.958434, theta=-23.852138 -> V=1.0, theta=0.0
% INFO    : Bus 24478	: V=0.9578539, theta=-23.839629 -> V=1.0, theta=0.0
% INFO    : Bus 24479	: V=0.9577195, theta=-23.797921 -> V=1.0, theta=0.0
% INFO    : Bus 24480	: V=0.9564998, theta=-23.865455 -> V=1.0, theta=0.0
% INFO    : Bus 24481	: V=0.9570996, theta=-23.886195 -> V=1.0, theta=0.0
% INFO    : Bus 24482	: V=0.9578437, theta=-23.882804 -> V=1.0, theta=0.0
% INFO    : Bus 24483	: V=0.958245, theta=-23.902339 -> V=1.0, theta=0.0
% INFO    : Bus 24484	: V=0.9581198, theta=-23.875315 -> V=1.0, theta=0.0
% INFO    : Bus 24485	: V=0.9584925, theta=-23.864368 -> V=1.0, theta=0.0
% INFO    : Bus 24486	: V=0.9573073, theta=-23.878254 -> V=1.0, theta=0.0
% INFO    : Bus 24487	: V=0.9565268, theta=-23.873908 -> V=1.0, theta=0.0
% INFO    : Bus 24488	: V=0.9578548, theta=-23.744759 -> V=1.0, theta=0.0
% INFO    : Bus 24489	: V=0.9578158, theta=-23.764923 -> V=1.0, theta=0.0
% INFO    : Bus 24490	: V=0.9583429, theta=-23.831391 -> V=1.0, theta=0.0
% INFO    : Bus 24491	: V=0.9583709, theta=-23.794316 -> V=1.0, theta=0.0
% INFO    : Bus 24492	: V=0.9600084, theta=-23.689982 -> V=1.0, theta=0.0
% INFO    : Bus 24493	: V=0.9588681, theta=-23.74606 -> V=1.0, theta=0.0
% INFO    : Bus 24494	: V=0.9579738, theta=-23.681326 -> V=1.0, theta=0.0
% INFO    : Bus 24495	: V=0.9579066, theta=-23.64662 -> V=1.0, theta=0.0
% INFO    : Bus 24496	: V=0.9581733, theta=-23.634637 -> V=1.0, theta=0.0
% INFO    : Bus 24497	: V=0.9590128, theta=-23.92092 -> V=1.0, theta=0.0
% INFO    : Bus 24498	: V=0.9605959, theta=-23.961548 -> V=1.0, theta=0.0
% INFO    : Bus 24499	: V=0.9609406, theta=-23.959871 -> V=1.0, theta=0.0
% INFO    : Bus 24500	: V=0.9618334, theta=-23.961625 -> V=1.0, theta=0.0
% INFO    : Bus 24501	: V=0.9633661, theta=-23.917572 -> V=1.0, theta=0.0
% INFO    : Bus 24502	: V=0.9628178, theta=-23.947339 -> V=1.0, theta=0.0
% INFO    : Bus 24503	: V=0.9742607, theta=-23.254566 -> V=1.0, theta=0.0
% INFO    : Bus 24504	: V=0.9636227, theta=-23.917453 -> V=1.0, theta=0.0
% INFO    : Bus 24505	: V=0.9609655, theta=-23.908525 -> V=1.0, theta=0.0
% INFO    : Bus 24506	: V=0.9597824, theta=-23.923159 -> V=1.0, theta=0.0
% INFO    : Bus 24507	: V=0.9591433, theta=-23.90205 -> V=1.0, theta=0.0
% INFO    : Bus 24508	: V=0.9608309, theta=-23.817273 -> V=1.0, theta=0.0
% INFO    : Bus 24509	: V=0.961052, theta=-23.896541 -> V=1.0, theta=0.0
% INFO    : Bus 24510	: V=0.9613725, theta=-23.875965 -> V=1.0, theta=0.0
% INFO    : Bus 24511	: V=0.9621352, theta=-23.876182 -> V=1.0, theta=0.0
% INFO    : Bus 24512	: V=0.9637154, theta=-23.917522 -> V=1.0, theta=0.0
% INFO    : Bus 24513	: V=0.9624681, theta=-23.899116 -> V=1.0, theta=0.0
% INFO    : Bus 24514	: V=0.9630632, theta=-23.921859 -> V=1.0, theta=0.0
% INFO    : Bus 24515	: V=0.9637372, theta=-23.888982 -> V=1.0, theta=0.0
% INFO    : Bus 24516	: V=0.9632355, theta=-23.857064 -> V=1.0, theta=0.0
% INFO    : Bus 24517	: V=0.9618861, theta=-23.830984 -> V=1.0, theta=0.0
% INFO    : Bus 24518	: V=0.9621859, theta=-23.653529 -> V=1.0, theta=0.0
% INFO    : Bus 24519	: V=0.9637174, theta=-23.938939 -> V=1.0, theta=0.0
% INFO    : Bus 24520	: V=0.9648236, theta=-23.931873 -> V=1.0, theta=0.0
% INFO    : Bus 24521	: V=0.9668609, theta=-23.908155 -> V=1.0, theta=0.0
% INFO    : Bus 24522	: V=0.968391, theta=-23.900127 -> V=1.0, theta=0.0
% INFO    : Bus 24523	: V=0.9686764, theta=-23.925482 -> V=1.0, theta=0.0
% INFO    : Bus 24524	: V=0.9705787, theta=-23.90777 -> V=1.0, theta=0.0
% INFO    : Bus 24525	: V=0.9663268, theta=-24.008006 -> V=1.0, theta=0.0
% INFO    : Bus 24526	: V=0.9654501, theta=-23.988211 -> V=1.0, theta=0.0
% INFO    : Bus 24527	: V=0.9641024, theta=-23.994634 -> V=1.0, theta=0.0
% INFO    : Bus 24528	: V=0.96357, theta=-23.983973 -> V=1.0, theta=0.0
% INFO    : Bus 24529	: V=0.9634128, theta=-24.023017 -> V=1.0, theta=0.0
% INFO    : Bus 24530	: V=0.9633037, theta=-24.042774 -> V=1.0, theta=0.0
% INFO    : Bus 24531	: V=0.9638701, theta=-23.997085 -> V=1.0, theta=0.0
% INFO    : Bus 24532	: V=0.9631816, theta=-23.939194 -> V=1.0, theta=0.0
% INFO    : Bus 24533	: V=0.9630504, theta=-23.971649 -> V=1.0, theta=0.0
% INFO    : Bus 24534	: V=0.9631048, theta=-24.003652 -> V=1.0, theta=0.0
% INFO    : Bus 24535	: V=0.9634178, theta=-23.972407 -> V=1.0, theta=0.0
% INFO    : Bus 24536	: V=0.9638112, theta=-23.955389 -> V=1.0, theta=0.0
% INFO    : Bus 24537	: V=0.9637649, theta=-23.939632 -> V=1.0, theta=0.0
% INFO    : Bus 24538	: V=1.0000181, theta=-20.565956 -> V=1.0, theta=0.0
% INFO    : Bus 24539	: V=0.9967715, theta=-20.796873 -> V=1.0, theta=0.0
% INFO    : Bus 24540	: V=0.9836692, theta=-21.929267 -> V=1.0, theta=0.0
% INFO    : Bus 24541	: V=0.9812902, theta=-22.079255 -> V=1.0, theta=0.0
% INFO    : Bus 24542	: V=0.9803964, theta=-22.112499 -> V=1.0, theta=0.0
% INFO    : Bus 24543	: V=0.9768593, theta=-22.16233 -> V=1.0, theta=0.0
% INFO    : Bus 24544	: V=0.9776361, theta=-22.161465 -> V=1.0, theta=0.0
% INFO    : Bus 24545	: V=0.977294, theta=-22.162592 -> V=1.0, theta=0.0
% INFO    : Bus 24546	: V=0.9624141, theta=-22.754725 -> V=1.0, theta=0.0
% INFO    : Bus 24547	: V=0.9704965, theta=-22.078024 -> V=1.0, theta=0.0
% INFO    : Bus 24548	: V=0.9622981, theta=-22.795738 -> V=1.0, theta=0.0
% INFO    : Bus 24549	: V=0.962126, theta=-22.807386 -> V=1.0, theta=0.0
% INFO    : Bus 24550	: V=0.9622956, theta=-22.82847 -> V=1.0, theta=0.0
% INFO    : Bus 24551	: V=0.9638623, theta=-22.818031 -> V=1.0, theta=0.0
% INFO    : Bus 24552	: V=0.9650956, theta=-22.815424 -> V=1.0, theta=0.0
% INFO    : Bus 24553	: V=0.9612537, theta=-22.794129 -> V=1.0, theta=0.0
% INFO    : Bus 24554	: V=0.9601612, theta=-22.79343 -> V=1.0, theta=0.0
% INFO    : Bus 24555	: V=0.9706463, theta=-23.339829 -> V=1.0, theta=0.0
% INFO    : Bus 24556	: V=0.96927, theta=-23.442181 -> V=1.0, theta=0.0
% INFO    : Bus 24557	: V=0.9700758, theta=-23.395696 -> V=1.0, theta=0.0
% INFO    : Bus 24558	: V=0.9709464, theta=-23.339707 -> V=1.0, theta=0.0
% INFO    : Bus 24559	: V=0.9719134, theta=-23.283886 -> V=1.0, theta=0.0
% INFO    : Bus 24560	: V=0.9718799, theta=-23.268608 -> V=1.0, theta=0.0
% INFO    : Bus 24561	: V=0.9643102, theta=-23.569866 -> V=1.0, theta=0.0
% INFO    : Bus 24562	: V=0.963689, theta=-23.707248 -> V=1.0, theta=0.0
% INFO    : Bus 24563	: V=0.9637873, theta=-23.707061 -> V=1.0, theta=0.0
% INFO    : Bus 24564	: V=0.9662831, theta=-23.60253 -> V=1.0, theta=0.0
% INFO    : Bus 24565	: V=0.9648368, theta=-23.621174 -> V=1.0, theta=0.0
% INFO    : Bus 24566	: V=0.9679596, theta=-23.525047 -> V=1.0, theta=0.0
% INFO    : Bus 24567	: V=0.966698, theta=-23.574023 -> V=1.0, theta=0.0
% INFO    : Bus 24568	: V=0.963755, theta=-23.042066 -> V=1.0, theta=0.0
% INFO    : Bus 24569	: V=0.9646073, theta=-23.050725 -> V=1.0, theta=0.0
% INFO    : Bus 24570	: V=0.960702, theta=-23.594274 -> V=1.0, theta=0.0
% INFO    : Bus 24571	: V=0.9601768, theta=-23.655083 -> V=1.0, theta=0.0
% INFO    : Bus 24572	: V=0.9727174, theta=-23.243369 -> V=1.0, theta=0.0
% INFO    : Bus 24573	: V=0.965932, theta=-23.488087 -> V=1.0, theta=0.0
% INFO    : Bus 24574	: V=0.9679136, theta=-23.480725 -> V=1.0, theta=0.0
% INFO    : Bus 24575	: V=0.9732716, theta=-23.244922 -> V=1.0, theta=0.0
% INFO    : Bus 24576	: V=0.9821892, theta=-22.354718 -> V=1.0, theta=0.0
% INFO    : Bus 24577	: V=0.9730736, theta=-23.323291 -> V=1.0, theta=0.0
% INFO    : Bus 24578	: V=0.9739715, theta=-23.237958 -> V=1.0, theta=0.0
% INFO    : Bus 24579	: V=0.964416, theta=-23.926487 -> V=1.0, theta=0.0
% INFO    : Bus 24580	: V=0.9647321, theta=-23.978398 -> V=1.0, theta=0.0
% INFO    : Bus 24581	: V=0.967496, theta=-23.76926 -> V=1.0, theta=0.0
% INFO    : Bus 24582	: V=0.9606533, theta=-23.45411 -> V=1.0, theta=0.0
% INFO    : Bus 24583	: V=0.9618895, theta=-23.443378 -> V=1.0, theta=0.0
% INFO    : Bus 24584	: V=0.9602926, theta=-23.468008 -> V=1.0, theta=0.0
% INFO    : Bus 24585	: V=0.9611458, theta=-23.279069 -> V=1.0, theta=0.0
% INFO    : Bus 24586	: V=0.972458, theta=-22.911894 -> V=1.0, theta=0.0
% INFO    : Bus 24587	: V=0.9631726, theta=-23.313471 -> V=1.0, theta=0.0
% INFO    : Bus 24588	: V=0.9635967, theta=-23.382974 -> V=1.0, theta=0.0
% INFO    : Bus 24589	: V=0.9618866, theta=-23.427142 -> V=1.0, theta=0.0
% INFO    : Bus 24590	: V=0.9642514, theta=-23.386385 -> V=1.0, theta=0.0
% INFO    : Bus 24591	: V=0.9665719, theta=-23.056814 -> V=1.0, theta=0.0
% INFO    : Bus 24592	: V=0.9683804, theta=-23.025109 -> V=1.0, theta=0.0
% INFO    : Bus 24593	: V=0.9702016, theta=-22.971695 -> V=1.0, theta=0.0
% INFO    : Bus 24594	: V=0.9678455, theta=-23.246556 -> V=1.0, theta=0.0
% INFO    : Bus 24595	: V=0.9653926, theta=-23.328859 -> V=1.0, theta=0.0
% INFO    : Bus 24596	: V=0.9724102, theta=-22.947208 -> V=1.0, theta=0.0
% INFO    : Bus 24597	: V=0.9646222, theta=-23.358732 -> V=1.0, theta=0.0
% INFO    : Bus 24598	: V=0.965022, theta=-23.392034 -> V=1.0, theta=0.0
% INFO    : Bus 24599	: V=0.9731511, theta=-22.928845 -> V=1.0, theta=0.0
% INFO    : Bus 24600	: V=0.9815344, theta=-21.848366 -> V=1.0, theta=0.0
% INFO    : Bus 24601	: V=0.9686205, theta=-23.28937 -> V=1.0, theta=0.0
% INFO    : Bus 24602	: V=0.9684904, theta=-23.362838 -> V=1.0, theta=0.0
% INFO    : Bus 24603	: V=0.9884007, theta=-19.868631 -> V=1.0, theta=0.0
% INFO    : Bus 24604	: V=0.9744278, theta=-23.069609 -> V=1.0, theta=0.0
% INFO    : Bus 24605	: V=0.9810563, theta=-21.946457 -> V=1.0, theta=0.0
% INFO    : Bus 24606	: V=0.9719845, theta=-23.321656 -> V=1.0, theta=0.0
% INFO    : Bus 24607	: V=0.972476, theta=-23.318851 -> V=1.0, theta=0.0
% INFO    : Bus 24608	: V=0.9717386, theta=-23.413018 -> V=1.0, theta=0.0
% INFO    : Bus 24609	: V=0.973926, theta=-23.065442 -> V=1.0, theta=0.0
% INFO    : Bus 24610	: V=0.9710491, theta=-23.55986 -> V=1.0, theta=0.0
% INFO    : Bus 24611	: V=0.9737428, theta=-23.140327 -> V=1.0, theta=0.0
% INFO    : Bus 24612	: V=0.9684213, theta=-23.743211 -> V=1.0, theta=0.0
% INFO    : Bus 24613	: V=0.9603512, theta=-22.838273 -> V=1.0, theta=0.0
% INFO    : Bus 24614	: V=0.9592643, theta=-23.132934 -> V=1.0, theta=0.0
% INFO    : Bus 24615	: V=0.9590581, theta=-23.303273 -> V=1.0, theta=0.0
% INFO    : Bus 24616	: V=0.960196, theta=-23.435807 -> V=1.0, theta=0.0
% INFO    : Bus 24617	: V=0.9632552, theta=-22.784076 -> V=1.0, theta=0.0
% INFO    : Bus 24618	: V=0.9608704, theta=-23.095377 -> V=1.0, theta=0.0
% INFO    : Bus 24619	: V=0.972689, theta=-23.080966 -> V=1.0, theta=0.0
% INFO    : Bus 24620	: V=0.9660545, theta=-23.319401 -> V=1.0, theta=0.0
% INFO    : Bus 24621	: V=0.9660429, theta=-23.592754 -> V=1.0, theta=0.0
% INFO    : Bus 24622	: V=0.9653406, theta=-23.314395 -> V=1.0, theta=0.0
% INFO    : Bus 24623	: V=0.9637389, theta=-23.754335 -> V=1.0, theta=0.0
% INFO    : Bus 24624	: V=0.972937, theta=-23.111237 -> V=1.0, theta=0.0
% INFO    : Bus 24625	: V=0.9656051, theta=-23.516509 -> V=1.0, theta=0.0
% INFO    : Bus 24626	: V=0.9651739, theta=-23.760092 -> V=1.0, theta=0.0
% INFO    : Bus 24627	: V=0.9740967, theta=-23.118063 -> V=1.0, theta=0.0
% INFO    : Bus 24628	: V=0.974065, theta=-23.148228 -> V=1.0, theta=0.0
% INFO    : Bus 24629	: V=0.967124, theta=-23.801051 -> V=1.0, theta=0.0
% INFO    : Bus 24630	: V=0.982054, theta=-22.239497 -> V=1.0, theta=0.0
% INFO    : Bus 24631	: V=0.9746138, theta=-23.260401 -> V=1.0, theta=0.0
% INFO    : Bus 24632	: V=0.97992, theta=-22.170362 -> V=1.0, theta=0.0
% INFO    : Bus 24633	: V=0.9676669, theta=-24.217055 -> V=1.0, theta=0.0
% INFO    : Bus 24634	: V=0.9664433, theta=-24.282632 -> V=1.0, theta=0.0
% INFO    : Bus 24635	: V=0.9661603, theta=-24.282655 -> V=1.0, theta=0.0
% INFO    : Bus 24636	: V=0.9675014, theta=-24.080499 -> V=1.0, theta=0.0
% INFO    : Bus 24637	: V=0.9657761, theta=-24.104856 -> V=1.0, theta=0.0
% INFO    : Bus 24638	: V=0.9667076, theta=-24.195905 -> V=1.0, theta=0.0
% INFO    : Bus 24639	: V=0.967095, theta=-24.274458 -> V=1.0, theta=0.0
% INFO    : Bus 24640	: V=0.9667506, theta=-24.27551 -> V=1.0, theta=0.0
% INFO    : Bus 24641	: V=0.9798078, theta=-22.19221 -> V=1.0, theta=0.0
% INFO    : Bus 24642	: V=0.969676, theta=-24.389756 -> V=1.0, theta=0.0
% INFO    : Bus 24643	: V=0.9684399, theta=-24.633313 -> V=1.0, theta=0.0
% INFO    : Bus 24644	: V=0.9682144, theta=-24.659666 -> V=1.0, theta=0.0
% INFO    : Bus 24645	: V=0.9665508, theta=-25.046247 -> V=1.0, theta=0.0
% INFO    : Bus 24646	: V=0.9665804, theta=-25.06964 -> V=1.0, theta=0.0
% INFO    : Bus 24647	: V=0.967293, theta=-24.606287 -> V=1.0, theta=0.0
% INFO    : Bus 24648	: V=0.9647014, theta=-24.273087 -> V=1.0, theta=0.0
% INFO    : Bus 24649	: V=0.9656295, theta=-24.780363 -> V=1.0, theta=0.0
% INFO    : Bus 24650	: V=0.9737064, theta=-24.474475 -> V=1.0, theta=0.0
% INFO    : Bus 24651	: V=0.9635642, theta=-24.35796 -> V=1.0, theta=0.0
% INFO    : Bus 24652	: V=0.9722677, theta=-23.661747 -> V=1.0, theta=0.0
% INFO    : Bus 24653	: V=0.9665622, theta=-23.776645 -> V=1.0, theta=0.0
% INFO    : Bus 24654	: V=0.9740966, theta=-23.054688 -> V=1.0, theta=0.0
% INFO    : Bus 24655	: V=0.9718305, theta=-23.854608 -> V=1.0, theta=0.0
% INFO    : Bus 24656	: V=0.963507, theta=-24.3609 -> V=1.0, theta=0.0
% INFO    : Bus 24657	: V=0.9634198, theta=-24.36257 -> V=1.0, theta=0.0
% INFO    : Bus 24658	: V=0.9635764, theta=-24.281212 -> V=1.0, theta=0.0
% INFO    : Bus 24659	: V=0.9612741, theta=-24.464767 -> V=1.0, theta=0.0
% INFO    : Bus 24660	: V=0.9621746, theta=-24.427339 -> V=1.0, theta=0.0
% INFO    : Bus 24661	: V=0.9718335, theta=-24.089857 -> V=1.0, theta=0.0
% INFO    : Bus 24662	: V=0.9839732, theta=-22.535122 -> V=1.0, theta=0.0
% INFO    : Bus 24663	: V=0.9607249, theta=-24.597065 -> V=1.0, theta=0.0
% INFO    : Bus 24664	: V=0.9601545, theta=-24.605428 -> V=1.0, theta=0.0
% INFO    : Bus 24665	: V=0.9603412, theta=-24.66448 -> V=1.0, theta=0.0
% INFO    : Bus 24666	: V=0.9678479, theta=-23.788218 -> V=1.0, theta=0.0
% INFO    : Bus 24667	: V=0.970416, theta=-23.653406 -> V=1.0, theta=0.0
% INFO    : Bus 24668	: V=0.970237, theta=-23.679861 -> V=1.0, theta=0.0
% INFO    : Bus 24669	: V=0.9729421, theta=-23.242174 -> V=1.0, theta=0.0
% INFO    : Bus 24670	: V=0.9688033, theta=-23.571456 -> V=1.0, theta=0.0
% INFO    : Bus 24671	: V=0.9677951, theta=-23.946669 -> V=1.0, theta=0.0
% INFO    : Bus 24672	: V=0.9660601, theta=-24.023547 -> V=1.0, theta=0.0
% INFO    : Bus 24673	: V=0.9654239, theta=-24.084577 -> V=1.0, theta=0.0
% INFO    : Bus 24674	: V=0.9635267, theta=-24.255138 -> V=1.0, theta=0.0
% INFO    : Bus 24675	: V=0.9627807, theta=-24.365306 -> V=1.0, theta=0.0
% INFO    : Bus 24676	: V=0.9632971, theta=-24.272814 -> V=1.0, theta=0.0
% INFO    : Bus 24677	: V=0.9618541, theta=-24.462763 -> V=1.0, theta=0.0
% INFO    : Bus 24678	: V=0.9620328, theta=-24.462589 -> V=1.0, theta=0.0
% INFO    : Bus 24679	: V=0.9661595, theta=-23.740938 -> V=1.0, theta=0.0
% INFO    : Bus 24680	: V=0.9661215, theta=-23.983733 -> V=1.0, theta=0.0
% INFO    : Bus 24681	: V=0.96729, theta=-23.813567 -> V=1.0, theta=0.0
% INFO    : Bus 24682	: V=0.9656646, theta=-24.11417 -> V=1.0, theta=0.0
% INFO    : Bus 24683	: V=0.9714964, theta=-23.542992 -> V=1.0, theta=0.0
% INFO    : Bus 24684	: V=0.9721469, theta=-23.415693 -> V=1.0, theta=0.0
% INFO    : Bus 24685	: V=0.9663325, theta=-24.084065 -> V=1.0, theta=0.0
% INFO    : Bus 24686	: V=0.9656155, theta=-24.154754 -> V=1.0, theta=0.0
% INFO    : Bus 24687	: V=0.9711645, theta=-23.605443 -> V=1.0, theta=0.0
% INFO    : Bus 24688	: V=0.9656049, theta=-24.119329 -> V=1.0, theta=0.0
% INFO    : Bus 24689	: V=0.9633742, theta=-24.44363 -> V=1.0, theta=0.0
% INFO    : Bus 24690	: V=0.9704484, theta=-23.79209 -> V=1.0, theta=0.0
% INFO    : Bus 24691	: V=0.9616046, theta=-24.523961 -> V=1.0, theta=0.0
% INFO    : Bus 24692	: V=0.961644, theta=-24.537971 -> V=1.0, theta=0.0
% INFO    : Bus 24693	: V=0.9709053, theta=-23.682186 -> V=1.0, theta=0.0
% INFO    : Bus 24694	: V=0.9608797, theta=-24.634148 -> V=1.0, theta=0.0
% INFO    : Bus 24695	: V=0.9602911, theta=-24.621531 -> V=1.0, theta=0.0
% INFO    : Bus 24696	: V=0.9707906, theta=-23.873595 -> V=1.0, theta=0.0
% INFO    : Bus 24697	: V=0.9595555, theta=-24.641508 -> V=1.0, theta=0.0
% INFO    : Bus 24698	: V=0.9636064, theta=-24.110134 -> V=1.0, theta=0.0
% INFO    : Bus 24699	: V=0.9632001, theta=-24.130352 -> V=1.0, theta=0.0
% INFO    : Bus 24700	: V=0.9638048, theta=-24.067133 -> V=1.0, theta=0.0
% INFO    : Bus 24701	: V=0.9644667, theta=-24.018147 -> V=1.0, theta=0.0
% INFO    : Bus 24702	: V=0.9660749, theta=-23.906154 -> V=1.0, theta=0.0
% INFO    : Bus 24703	: V=0.9638536, theta=-24.071149 -> V=1.0, theta=0.0
% INFO    : Bus 24704	: V=0.962863, theta=-24.152568 -> V=1.0, theta=0.0
% INFO    : Bus 24705	: V=0.9712419, theta=-23.608582 -> V=1.0, theta=0.0
% INFO    : Bus 24706	: V=0.9621127, theta=-24.465334 -> V=1.0, theta=0.0
% INFO    : Bus 24707	: V=0.9714473, theta=-23.907098 -> V=1.0, theta=0.0
% INFO    : Bus 24708	: V=0.9631767, theta=-24.550134 -> V=1.0, theta=0.0
% INFO    : Bus 24709	: V=0.9621465, theta=-24.569131 -> V=1.0, theta=0.0
% INFO    : Bus 24710	: V=0.9642563, theta=-24.636446 -> V=1.0, theta=0.0
% INFO    : Bus 24711	: V=0.9644466, theta=-24.631299 -> V=1.0, theta=0.0
% INFO    : Bus 24712	: V=0.9708397, theta=-23.683195 -> V=1.0, theta=0.0
% INFO    : Bus 24713	: V=0.9706099, theta=-23.725022 -> V=1.0, theta=0.0
% INFO    : Bus 24714	: V=0.9748142, theta=-23.791393 -> V=1.0, theta=0.0
% INFO    : Bus 24715	: V=0.9759402, theta=-23.80162 -> V=1.0, theta=0.0
% INFO    : Bus 24716	: V=1.0029757, theta=-21.772999 -> V=1.0, theta=0.0
% INFO    : Bus 24717	: V=1.0025506, theta=-21.794154 -> V=1.0, theta=0.0
% INFO    : Bus 24718	: V=0.9725018, theta=-23.763564 -> V=1.0, theta=0.0
% INFO    : Bus 24719	: V=0.9733654, theta=-23.616062 -> V=1.0, theta=0.0
% INFO    : Bus 24720	: V=0.98065, theta=-23.107987 -> V=1.0, theta=0.0
% INFO    : Bus 24721	: V=0.9815216, theta=-23.095556 -> V=1.0, theta=0.0
% INFO    : Bus 24722	: V=0.9837761, theta=-23.050912 -> V=1.0, theta=0.0
% INFO    : Bus 24723	: V=0.9770534, theta=-23.742957 -> V=1.0, theta=0.0
% INFO    : Bus 24724	: V=0.9805376, theta=-23.727876 -> V=1.0, theta=0.0
% INFO    : Bus 24725	: V=0.9752796, theta=-23.84377 -> V=1.0, theta=0.0
% INFO    : Bus 24726	: V=0.9623832, theta=-24.235965 -> V=1.0, theta=0.0
% INFO    : Bus 24727	: V=0.961688, theta=-24.241174 -> V=1.0, theta=0.0
% INFO    : Bus 24728	: V=0.9627935, theta=-24.296609 -> V=1.0, theta=0.0
% INFO    : Bus 24729	: V=0.9638259, theta=-24.350458 -> V=1.0, theta=0.0
% INFO    : Bus 24730	: V=0.9635494, theta=-24.34496 -> V=1.0, theta=0.0
% INFO    : Bus 24731	: V=0.9626893, theta=-24.423503 -> V=1.0, theta=0.0
% INFO    : Bus 24732	: V=0.9625231, theta=-24.48183 -> V=1.0, theta=0.0
% INFO    : Bus 24733	: V=0.9621905, theta=-24.487103 -> V=1.0, theta=0.0
% INFO    : Bus 24734	: V=0.9824257, theta=-23.321147 -> V=1.0, theta=0.0
% INFO    : Bus 24735	: V=0.9725584, theta=-24.114403 -> V=1.0, theta=0.0
% INFO    : Bus 24736	: V=0.9726431, theta=-24.112202 -> V=1.0, theta=0.0
% INFO    : Bus 24737	: V=0.9863637, theta=-23.289925 -> V=1.0, theta=0.0
% INFO    : Bus 24738	: V=0.9760768, theta=-24.411488 -> V=1.0, theta=0.0
% INFO    : Bus 24739	: V=0.9721483, theta=-24.426362 -> V=1.0, theta=0.0
% INFO    : Bus 24740	: V=0.9726883, theta=-24.462332 -> V=1.0, theta=0.0
% INFO    : Bus 24741	: V=0.9740192, theta=-24.442085 -> V=1.0, theta=0.0
% INFO    : Bus 24742	: V=0.9774927, theta=-24.390105 -> V=1.0, theta=0.0
% INFO    : Bus 24743	: V=0.976514, theta=-24.435768 -> V=1.0, theta=0.0
% INFO    : Bus 24744	: V=0.9759188, theta=-24.43511 -> V=1.0, theta=0.0
% INFO    : Bus 24745	: V=0.9840349, theta=-24.090556 -> V=1.0, theta=0.0
% INFO    : Bus 24746	: V=0.981014, theta=-24.198266 -> V=1.0, theta=0.0
% INFO    : Bus 24747	: V=0.979988, theta=-24.219439 -> V=1.0, theta=0.0
% INFO    : Bus 24748	: V=0.9779475, theta=-24.391397 -> V=1.0, theta=0.0
% INFO    : Bus 24749	: V=0.9793262, theta=-24.325733 -> V=1.0, theta=0.0
% INFO    : Bus 24750	: V=0.981579, theta=-24.244191 -> V=1.0, theta=0.0
% INFO    : Bus 24751	: V=0.987352, theta=-23.576109 -> V=1.0, theta=0.0
% INFO    : Bus 24752	: V=0.9834825, theta=-24.206707 -> V=1.0, theta=0.0
% INFO    : Bus 24753	: V=0.9788767, theta=-24.372045 -> V=1.0, theta=0.0
% INFO    : Bus 24754	: V=0.9804818, theta=-24.362649 -> V=1.0, theta=0.0
% INFO    : Bus 24755	: V=0.9836083, theta=-24.233384 -> V=1.0, theta=0.0
% INFO    : Bus 24756	: V=1.0044425, theta=-21.808938 -> V=1.0, theta=0.0
% INFO    : Bus 24757	: V=0.9905419, theta=-23.060204 -> V=1.0, theta=0.0
% INFO    : Bus 24758	: V=0.9874513, theta=-23.387988 -> V=1.0, theta=0.0
% INFO    : Bus 24759	: V=0.9867773, theta=-23.422156 -> V=1.0, theta=0.0
% INFO    : Bus 24760	: V=0.9876313, theta=-23.484875 -> V=1.0, theta=0.0
% INFO    : Bus 24761	: V=0.9900257, theta=-23.252409 -> V=1.0, theta=0.0
% INFO    : Bus 24762	: V=0.9876981, theta=-23.489439 -> V=1.0, theta=0.0
% INFO    : Bus 24763	: V=0.9878595, theta=-23.494615 -> V=1.0, theta=0.0
% INFO    : Bus 24764	: V=0.988578, theta=-23.41123 -> V=1.0, theta=0.0
% INFO    : Bus 24765	: V=0.9793809, theta=-23.313165 -> V=1.0, theta=0.0
% INFO    : Bus 24766	: V=1.0022205, theta=-22.444378 -> V=1.0, theta=0.0
% INFO    : Bus 24767	: V=0.9850219, theta=-24.125785 -> V=1.0, theta=0.0
% INFO    : Bus 24768	: V=0.9846985, theta=-24.217981 -> V=1.0, theta=0.0
% INFO    : Bus 24769	: V=0.9830514, theta=-24.266086 -> V=1.0, theta=0.0
% INFO    : Bus 24770	: V=0.9819497, theta=-24.318893 -> V=1.0, theta=0.0
% INFO    : Bus 24771	: V=0.9830126, theta=-24.274165 -> V=1.0, theta=0.0
% INFO    : Bus 24772	: V=0.9840539, theta=-24.270828 -> V=1.0, theta=0.0
% INFO    : Bus 24773	: V=0.9822093, theta=-24.331861 -> V=1.0, theta=0.0
% INFO    : Bus 24774	: V=0.9863918, theta=-23.884727 -> V=1.0, theta=0.0
% INFO    : Bus 24775	: V=0.9778163, theta=-24.489672 -> V=1.0, theta=0.0
% INFO    : Bus 24776	: V=0.9799142, theta=-24.420392 -> V=1.0, theta=0.0
% INFO    : Bus 24777	: V=0.9814784, theta=-24.328515 -> V=1.0, theta=0.0
% INFO    : Bus 24778	: V=0.9755685, theta=-24.498814 -> V=1.0, theta=0.0
% INFO    : Bus 24779	: V=0.9796285, theta=-24.431528 -> V=1.0, theta=0.0
% INFO    : Bus 24780	: V=0.9807137, theta=-24.363773 -> V=1.0, theta=0.0
% INFO    : Bus 24781	: V=0.9806483, theta=-24.401131 -> V=1.0, theta=0.0
% INFO    : Bus 24782	: V=0.9862051, theta=-24.049381 -> V=1.0, theta=0.0
% INFO    : Bus 24783	: V=0.9641626, theta=-24.636528 -> V=1.0, theta=0.0
% INFO    : Bus 24784	: V=0.9721513, theta=-23.926515 -> V=1.0, theta=0.0
% INFO    : Bus 24785	: V=0.9741411, theta=-24.023473 -> V=1.0, theta=0.0
% INFO    : Bus 24786	: V=0.9634167, theta=-24.678861 -> V=1.0, theta=0.0
% INFO    : Bus 24787	: V=0.9709238, theta=-24.490929 -> V=1.0, theta=0.0
% INFO    : Bus 24788	: V=0.9714171, theta=-24.534318 -> V=1.0, theta=0.0
% INFO    : Bus 24789	: V=0.9644459, theta=-24.683703 -> V=1.0, theta=0.0
% INFO    : Bus 24790	: V=0.9878792, theta=-23.238983 -> V=1.0, theta=0.0
% INFO    : Bus 24791	: V=0.9735928, theta=-24.458702 -> V=1.0, theta=0.0
% INFO    : Bus 24792	: V=0.9692252, theta=-24.653054 -> V=1.0, theta=0.0
% INFO    : Bus 24793	: V=0.9705869, theta=-24.594321 -> V=1.0, theta=0.0
% INFO    : Bus 24794	: V=0.9709931, theta=-24.626862 -> V=1.0, theta=0.0
% INFO    : Bus 24795	: V=0.9687146, theta=-24.709542 -> V=1.0, theta=0.0
% INFO    : Bus 24796	: V=0.9894589, theta=-23.377963 -> V=1.0, theta=0.0
% INFO    : Bus 24797	: V=0.9738404, theta=-24.562605 -> V=1.0, theta=0.0
% INFO    : Bus 24798	: V=0.9779998, theta=-24.242357 -> V=1.0, theta=0.0
% INFO    : Bus 24799	: V=0.9726125, theta=-24.688839 -> V=1.0, theta=0.0
% INFO    : Bus 24800	: V=0.9745266, theta=-24.582296 -> V=1.0, theta=0.0
% INFO    : Bus 24801	: V=0.9694745, theta=-24.781365 -> V=1.0, theta=0.0
% INFO    : Bus 24802	: V=0.9589971, theta=-24.801127 -> V=1.0, theta=0.0
% INFO    : Bus 24803	: V=0.9606146, theta=-24.687663 -> V=1.0, theta=0.0
% INFO    : Bus 24804	: V=0.9617917, theta=-24.882926 -> V=1.0, theta=0.0
% INFO    : Bus 24805	: V=0.9678115, theta=-24.157535 -> V=1.0, theta=0.0
% INFO    : Bus 24806	: V=0.9667549, theta=-24.247508 -> V=1.0, theta=0.0
% INFO    : Bus 24807	: V=0.9897963, theta=-23.34491 -> V=1.0, theta=0.0
% INFO    : Bus 24808	: V=0.9616486, theta=-25.384809 -> V=1.0, theta=0.0
% INFO    : Bus 24809	: V=0.9839911, theta=-25.115797 -> V=1.0, theta=0.0
% INFO    : Bus 24810	: V=0.9764623, theta=-24.853989 -> V=1.0, theta=0.0
% INFO    : Bus 24811	: V=0.9662541, theta=-25.335956 -> V=1.0, theta=0.0
% INFO    : Bus 24812	: V=0.9771346, theta=-24.914115 -> V=1.0, theta=0.0
% INFO    : Bus 24813	: V=0.9724228, theta=-25.8627 -> V=1.0, theta=0.0
% INFO    : Bus 24814	: V=0.9775993, theta=-25.88404 -> V=1.0, theta=0.0
% INFO    : Bus 24815	: V=0.9634646, theta=-25.422244 -> V=1.0, theta=0.0
% INFO    : Bus 24816	: V=0.9737732, theta=-26.693382 -> V=1.0, theta=0.0
% INFO    : Bus 24817	: V=0.9780992, theta=-26.540959 -> V=1.0, theta=0.0
% INFO    : Bus 24818	: V=0.9673042, theta=-25.793655 -> V=1.0, theta=0.0
% INFO    : Bus 24819	: V=0.9623738, theta=-26.071376 -> V=1.0, theta=0.0
% INFO    : Bus 24820	: V=0.9722102, theta=-25.476856 -> V=1.0, theta=0.0
% INFO    : Bus 24821	: V=0.9764208, theta=-24.605625 -> V=1.0, theta=0.0
% INFO    : Bus 24822	: V=0.9926554, theta=-23.785564 -> V=1.0, theta=0.0
% INFO    : Bus 24823	: V=0.9719485, theta=-24.758413 -> V=1.0, theta=0.0
% INFO    : Bus 24824	: V=0.9765875, theta=-25.198859 -> V=1.0, theta=0.0
% INFO    : Bus 24825	: V=0.9846618, theta=-24.556188 -> V=1.0, theta=0.0
% INFO    : Bus 24826	: V=0.9825107, theta=-25.039456 -> V=1.0, theta=0.0
% INFO    : Bus 24827	: V=0.9807199, theta=-24.87906 -> V=1.0, theta=0.0
% INFO    : Bus 24828	: V=0.9945949, theta=-23.963616 -> V=1.0, theta=0.0
% INFO    : Bus 24829	: V=0.9798743, theta=-24.960305 -> V=1.0, theta=0.0
% INFO    : Bus 24830	: V=0.9802943, theta=-24.982003 -> V=1.0, theta=0.0
% INFO    : Bus 24831	: V=0.9824777, theta=-24.527183 -> V=1.0, theta=0.0
% INFO    : Bus 24832	: V=0.9886393, theta=-24.057814 -> V=1.0, theta=0.0
% INFO    : Bus 24833	: V=0.9834482, theta=-24.473387 -> V=1.0, theta=0.0
% INFO    : Bus 24834	: V=0.9848698, theta=-24.468708 -> V=1.0, theta=0.0
% INFO    : Bus 24835	: V=0.9981689, theta=-23.477182 -> V=1.0, theta=0.0
% INFO    : Bus 24836	: V=0.996534, theta=-23.698126 -> V=1.0, theta=0.0
% INFO    : Bus 24837	: V=0.98663, theta=-23.954705 -> V=1.0, theta=0.0
% INFO    : Bus 24838	: V=0.986328, theta=-24.104818 -> V=1.0, theta=0.0
% INFO    : Bus 24839	: V=0.9869618, theta=-24.141296 -> V=1.0, theta=0.0
% INFO    : Bus 24840	: V=0.9885572, theta=-24.440821 -> V=1.0, theta=0.0
% INFO    : Bus 24841	: V=0.9866954, theta=-24.35661 -> V=1.0, theta=0.0
% INFO    : Bus 24842	: V=0.984743, theta=-24.453683 -> V=1.0, theta=0.0
% INFO    : Bus 24843	: V=0.9896532, theta=-24.113557 -> V=1.0, theta=0.0
% INFO    : Bus 24844	: V=0.987715, theta=-24.326333 -> V=1.0, theta=0.0
% INFO    : Bus 24845	: V=0.9850891, theta=-25.136459 -> V=1.0, theta=0.0
% INFO    : Bus 24846	: V=0.9853393, theta=-25.317118 -> V=1.0, theta=0.0
% INFO    : Bus 24847	: V=0.9875198, theta=-22.785151 -> V=1.0, theta=0.0
% INFO    : Bus 24848	: V=0.9728896, theta=-23.220704 -> V=1.0, theta=0.0
% INFO    : Bus 24849	: V=0.9847149, theta=-22.265254 -> V=1.0, theta=0.0
% INFO    : Bus 24850	: V=0.981225, theta=-23.148774 -> V=1.0, theta=0.0
% INFO    : Bus 24851	: V=0.9644507, theta=-24.983674 -> V=1.0, theta=0.0
% INFO    : Bus 24852	: V=0.9880664, theta=-22.148749 -> V=1.0, theta=0.0
% INFO    : Bus 24853	: V=1.0057572, theta=-21.759566 -> V=1.0, theta=0.0
% INFO    : Bus 24854	: V=1.0046215, theta=-21.774908 -> V=1.0, theta=0.0
% INFO    : Bus 24855	: V=0.9822823, theta=-22.419796 -> V=1.0, theta=0.0
% INFO    : Bus 24856	: V=0.9846552, theta=0.886481 -> V=1.0, theta=0.0
% INFO    : Bus 24857	: V=0.965646, theta=0.008596 -> V=1.0, theta=0.0
% INFO    : Bus 24858	: V=0.9963683, theta=2.368616 -> V=1.0, theta=0.0
% INFO    : Bus 24859	: V=0.9943742, theta=1.704663 -> V=1.0, theta=0.0
% INFO    : Bus 24860	: V=0.9929736, theta=1.094734 -> V=1.0, theta=0.0
% INFO    : Bus 24861	: V=0.9927019, theta=0.776578 -> V=1.0, theta=0.0
% INFO    : Bus 24862	: V=0.9975338, theta=3.222379 -> V=1.0, theta=0.0
% INFO    : Bus 24863	: V=0.9934191, theta=1.414799 -> V=1.0, theta=0.0
% INFO    : Bus 24864	: V=1.005493, theta=-28.271046 -> V=1.0, theta=0.0
% INFO    : Bus 24865	: V=1.0026498, theta=-28.973821 -> V=1.0, theta=0.0
% INFO    : Bus 24866	: V=0.9912083, theta=-25.690277 -> V=1.0, theta=0.0
% INFO    : Bus 24867	: V=1.0059522, theta=-25.374731 -> V=1.0, theta=0.0
% INFO    : Bus 24868	: V=1.0075824, theta=-26.385502 -> V=1.0, theta=0.0
% INFO    : Bus 24869	: V=1.0190252, theta=-23.808471 -> V=1.0, theta=0.0
% INFO    : Bus 24870	: V=0.9689833, theta=-32.312463 -> V=1.0, theta=0.0
% INFO    : Bus 24871	: V=0.9648048, theta=-31.42237 -> V=1.0, theta=0.0
% INFO    : Bus 24872	: V=0.9731138, theta=-29.925901 -> V=1.0, theta=0.0
% INFO    : Bus 24873	: V=0.9905478, theta=-27.048095 -> V=1.0, theta=0.0
% INFO    : Bus 24874	: V=0.9750057, theta=-29.650971 -> V=1.0, theta=0.0
% INFO    : Bus 24875	: V=0.9858064, theta=-28.963221 -> V=1.0, theta=0.0
% INFO    : Bus 24876	: V=0.9757857, theta=-29.903849 -> V=1.0, theta=0.0
% INFO    : Bus 24877	: V=0.9906759, theta=-27.866123 -> V=1.0, theta=0.0
% INFO    : Bus 24878	: V=0.9793509, theta=-29.990698 -> V=1.0, theta=0.0
% INFO    : Bus 24879	: V=0.9706272, theta=-30.720479 -> V=1.0, theta=0.0
% INFO    : Bus 24880	: V=0.9853257, theta=-29.376925 -> V=1.0, theta=0.0
% INFO    : Bus 24881	: V=0.9768482, theta=-30.434114 -> V=1.0, theta=0.0
% INFO    : Bus 24882	: V=1.0084852, theta=-24.192833 -> V=1.0, theta=0.0
% INFO    : Bus 24883	: V=0.9920533, theta=-27.71898 -> V=1.0, theta=0.0
% INFO    : Bus 24884	: V=0.9861079, theta=-28.969039 -> V=1.0, theta=0.0
% INFO    : Bus 24885	: V=0.9820158, theta=-29.943701 -> V=1.0, theta=0.0
% INFO    : Bus 24886	: V=0.9778699, theta=-29.724934 -> V=1.0, theta=0.0
% INFO    : Bus 24887	: V=0.9824981, theta=-29.431015 -> V=1.0, theta=0.0
% INFO    : Bus 24888	: V=0.9818401, theta=-29.515972 -> V=1.0, theta=0.0
% INFO    : Bus 24889	: V=0.9905952, theta=-27.957118 -> V=1.0, theta=0.0
% INFO    : Bus 24890	: V=0.9812436, theta=-29.563612 -> V=1.0, theta=0.0
% INFO    : Bus 24891	: V=0.9830332, theta=-29.361832 -> V=1.0, theta=0.0
% INFO    : Bus 24892	: V=0.9842391, theta=-29.192674 -> V=1.0, theta=0.0
% INFO    : Bus 24893	: V=0.9828217, theta=-29.365947 -> V=1.0, theta=0.0
% INFO    : Bus 24894	: V=0.9834199, theta=-29.357211 -> V=1.0, theta=0.0
% INFO    : Bus 24895	: V=0.9817716, theta=-29.492863 -> V=1.0, theta=0.0
% INFO    : Bus 24896	: V=0.9914104, theta=-27.798784 -> V=1.0, theta=0.0
% INFO    : Bus 24897	: V=0.9903603, theta=-28.009669 -> V=1.0, theta=0.0
% INFO    : Bus 24898	: V=0.9831175, theta=-29.431604 -> V=1.0, theta=0.0
% INFO    : Bus 24899	: V=0.9902934, theta=-28.045832 -> V=1.0, theta=0.0
% INFO    : Bus 24900	: V=0.9689641, theta=-29.916053 -> V=1.0, theta=0.0
% INFO    : Bus 24901	: V=0.9695458, theta=-29.898711 -> V=1.0, theta=0.0
% INFO    : Bus 24902	: V=0.9822038, theta=-29.471235 -> V=1.0, theta=0.0
% INFO    : Bus 24903	: V=0.9659282, theta=-51.880676 -> V=1.0, theta=0.0
% INFO    : Bus 24904	: V=0.9692889, theta=-50.029753 -> V=1.0, theta=0.0
% INFO    : Bus 24905	: V=0.9665525, theta=-51.248565 -> V=1.0, theta=0.0
% INFO    : Bus 24906	: V=0.9777197, theta=-49.139016 -> V=1.0, theta=0.0
% INFO    : Bus 24907	: V=0.9699056, theta=-51.095722 -> V=1.0, theta=0.0
% INFO    : Bus 24908	: V=0.9679582, theta=-51.047368 -> V=1.0, theta=0.0
% INFO    : Bus 24909	: V=0.9694955, theta=-50.993659 -> V=1.0, theta=0.0
% INFO    : Bus 24910	: V=0.9712715, theta=-50.223991 -> V=1.0, theta=0.0
% INFO    : Bus 24911	: V=0.9728352, theta=-49.885936 -> V=1.0, theta=0.0
% INFO    : Bus 24912	: V=0.971826, theta=-49.124457 -> V=1.0, theta=0.0
% INFO    : Bus 24913	: V=0.9723648, theta=-48.003916 -> V=1.0, theta=0.0
% INFO    : Bus 24914	: V=0.9860783, theta=-55.340503 -> V=1.0, theta=0.0
% INFO    : Bus 24915	: V=0.9849761, theta=-55.379338 -> V=1.0, theta=0.0
% INFO    : Bus 24916	: V=0.9990648, theta=-53.824806 -> V=1.0, theta=0.0
% INFO    : Bus 24917	: V=0.994367, theta=-54.542719 -> V=1.0, theta=0.0
% INFO    : Bus 24918	: V=1.0142719, theta=-52.534478 -> V=1.0, theta=0.0
% INFO    : Bus 24919	: V=1.0124555, theta=-52.486044 -> V=1.0, theta=0.0
% INFO    : Bus 24920	: V=1.0057358, theta=-53.084409 -> V=1.0, theta=0.0
% INFO    : Bus 24921	: V=1.0142118, theta=-52.28236 -> V=1.0, theta=0.0
% INFO    : Bus 24922	: V=1.0066248, theta=-53.055867 -> V=1.0, theta=0.0
% INFO    : Bus 24923	: V=1.0099944, theta=-51.672195 -> V=1.0, theta=0.0
% INFO    : Bus 24924	: V=1.0098303, theta=-52.595909 -> V=1.0, theta=0.0
% INFO    : Bus 24925	: V=1.0091131, theta=-51.788153 -> V=1.0, theta=0.0
% INFO    : Bus 24926	: V=1.0069963, theta=-52.935738 -> V=1.0, theta=0.0
% INFO    : Bus 24927	: V=1.0043551, theta=-53.198253 -> V=1.0, theta=0.0
% INFO    : Bus 24928	: V=1.0108976, theta=-51.427251 -> V=1.0, theta=0.0
% INFO    : Bus 24929	: V=1.0099817, theta=-51.47049 -> V=1.0, theta=0.0
% INFO    : Bus 24930	: V=1.0119147, theta=-51.178723 -> V=1.0, theta=0.0
% INFO    : Bus 24931	: V=0.972362, theta=-56.37568 -> V=1.0, theta=0.0
% INFO    : Bus 24932	: V=1.0056199, theta=-51.792474 -> V=1.0, theta=0.0
% INFO    : Bus 24933	: V=0.9824051, theta=-54.931894 -> V=1.0, theta=0.0
% INFO    : Bus 24934	: V=0.9996838, theta=-53.275333 -> V=1.0, theta=0.0
% INFO    : Bus 24935	: V=0.9827685, theta=-55.021917 -> V=1.0, theta=0.0
% INFO    : Bus 24936	: V=0.9642936, theta=-60.399763 -> V=1.0, theta=0.0
% INFO    : Bus 24937	: V=0.9711287, theta=-58.251504 -> V=1.0, theta=0.0
% INFO    : Bus 24938	: V=0.9609002, theta=-57.769856 -> V=1.0, theta=0.0
% INFO    : Bus 24939	: V=1.011216, theta=-32.175719 -> V=1.0, theta=0.0
% INFO    : Bus 24940	: V=1.0124763, theta=-31.868891 -> V=1.0, theta=0.0
% INFO    : Bus 24941	: V=1.0031846, theta=-33.856162 -> V=1.0, theta=0.0
% INFO    : Bus 24942	: V=1.0139301, theta=-31.509964 -> V=1.0, theta=0.0
% INFO    : Bus 24943	: V=1.0015919, theta=-33.702998 -> V=1.0, theta=0.0
% INFO    : Bus 24944	: V=1.0086271, theta=-32.650996 -> V=1.0, theta=0.0
% INFO    : Bus 24945	: V=1.0076882, theta=-32.498863 -> V=1.0, theta=0.0
% INFO    : Bus 24946	: V=1.0100138, theta=-32.712781 -> V=1.0, theta=0.0
% INFO    : Bus 24947	: V=1.0017938, theta=-34.082765 -> V=1.0, theta=0.0
% INFO    : Bus 24948	: V=1.0103169, theta=-33.510669 -> V=1.0, theta=0.0
% INFO    : Bus 24949	: V=1.0172565, theta=-34.727567 -> V=1.0, theta=0.0
% INFO    : Bus 24950	: V=1.0120278, theta=-32.228762 -> V=1.0, theta=0.0
% INFO    : Bus 24951	: V=1.0073972, theta=-32.463489 -> V=1.0, theta=0.0
% INFO    : Bus 24952	: V=1.0085289, theta=-32.698162 -> V=1.0, theta=0.0
% INFO    : Bus 24953	: V=1.0026112, theta=-33.694671 -> V=1.0, theta=0.0
% INFO    : Bus 24954	: V=0.9668505, theta=-32.177842 -> V=1.0, theta=0.0
% INFO    : Bus 24955	: V=0.9648321, theta=-31.38467 -> V=1.0, theta=0.0
% INFO    : Bus 24956	: V=0.9619325, theta=-31.608667 -> V=1.0, theta=0.0
% INFO    : Bus 24957	: V=0.9581797, theta=-32.124715 -> V=1.0, theta=0.0
% INFO    : Bus 24958	: V=0.9663067, theta=-30.163372 -> V=1.0, theta=0.0
% INFO    : Bus 24959	: V=0.957614, theta=-31.495448 -> V=1.0, theta=0.0
% INFO    : Bus 24960	: V=0.9583011, theta=-31.478972 -> V=1.0, theta=0.0
% INFO    : Bus 24961	: V=0.9559666, theta=-31.958634 -> V=1.0, theta=0.0
% INFO    : Bus 24962	: V=0.9579742, theta=-32.330184 -> V=1.0, theta=0.0
% INFO    : Bus 24963	: V=0.9533891, theta=-31.86211 -> V=1.0, theta=0.0
% INFO    : Bus 24964	: V=0.9574611, theta=-31.133126 -> V=1.0, theta=0.0
% INFO    : Bus 24965	: V=0.9895372, theta=-50.728358 -> V=1.0, theta=0.0
% INFO    : Bus 24966	: V=1.0167944, theta=-47.22489 -> V=1.0, theta=0.0
% INFO    : Bus 24967	: V=1.0040203, theta=-49.440368 -> V=1.0, theta=0.0
% INFO    : Bus 24968	: V=0.9949328, theta=-46.29334 -> V=1.0, theta=0.0
% INFO    : Bus 24969	: V=0.9966177, theta=-45.22617 -> V=1.0, theta=0.0
% INFO    : Bus 24970	: V=0.9956765, theta=-46.345299 -> V=1.0, theta=0.0
% INFO    : Bus 24971	: V=0.9985913, theta=-44.018496 -> V=1.0, theta=0.0
% INFO    : Bus 24972	: V=0.9827082, theta=-45.527265 -> V=1.0, theta=0.0
% INFO    : Bus 24973	: V=0.9939167, theta=-46.84909 -> V=1.0, theta=0.0
% INFO    : Bus 24974	: V=1.0118806, theta=-46.863255 -> V=1.0, theta=0.0
% INFO    : Bus 24975	: V=1.0095599, theta=-47.586477 -> V=1.0, theta=0.0
% INFO    : Bus 24976	: V=0.9975328, theta=-49.421556 -> V=1.0, theta=0.0
% INFO    : Bus 24977	: V=0.9961187, theta=-49.582889 -> V=1.0, theta=0.0
% INFO    : Bus 24978	: V=0.9956913, theta=-49.587628 -> V=1.0, theta=0.0
% INFO    : Bus 24979	: V=1.0043917, theta=-49.025188 -> V=1.0, theta=0.0
% INFO    : Bus 24980	: V=1.0034284, theta=-49.40052 -> V=1.0, theta=0.0
% INFO    : Bus 24981	: V=1.0032147, theta=-49.302634 -> V=1.0, theta=0.0
% INFO    : Bus 24982	: V=1.0018718, theta=-47.394654 -> V=1.0, theta=0.0
% INFO    : Bus 24983	: V=0.9969599, theta=-47.972885 -> V=1.0, theta=0.0
% INFO    : Bus 24984	: V=0.9993764, theta=-48.393927 -> V=1.0, theta=0.0
% INFO    : Bus 24985	: V=0.9781809, theta=-29.293804 -> V=1.0, theta=0.0
% INFO    : Bus 24986	: V=0.9831351, theta=-28.907871 -> V=1.0, theta=0.0
% INFO    : Bus 24987	: V=0.9726985, theta=-28.51904 -> V=1.0, theta=0.0
% INFO    : Bus 24988	: V=0.9997282, theta=-26.122675 -> V=1.0, theta=0.0
% INFO    : Bus 24989	: V=1.0037072, theta=-25.209814 -> V=1.0, theta=0.0
% INFO    : Bus 24990	: V=1.0106781, theta=-24.4463 -> V=1.0, theta=0.0
% INFO    : Bus 24991	: V=1.0017141, theta=-25.614615 -> V=1.0, theta=0.0
% INFO    : Bus 24992	: V=1.0046228, theta=-25.057576 -> V=1.0, theta=0.0
% INFO    : Bus 24993	: V=0.9929968, theta=-26.573603 -> V=1.0, theta=0.0
% INFO    : Bus 24994	: V=0.9810701, theta=-27.306303 -> V=1.0, theta=0.0
% INFO    : Bus 24995	: V=0.9799621, theta=-27.32389 -> V=1.0, theta=0.0
% INFO    : Bus 24996	: V=0.9838539, theta=-27.319601 -> V=1.0, theta=0.0
% INFO    : Bus 24997	: V=0.9848261, theta=-27.30797 -> V=1.0, theta=0.0
% INFO    : Bus 24998	: V=0.9839133, theta=-27.321317 -> V=1.0, theta=0.0
% INFO    : Bus 24999	: V=0.9993897, theta=-26.443655 -> V=1.0, theta=0.0
% INFO    : Bus 25000	: V=0.9927187, theta=-26.865342 -> V=1.0, theta=0.0
% INFO    : Bus 25001	: V=0.9906167, theta=-26.848024 -> V=1.0, theta=0.0
% INFO    : Bus 25002	: V=0.9986875, theta=-26.262726 -> V=1.0, theta=0.0
% INFO    : Bus 25003	: V=0.9980098, theta=-26.195056 -> V=1.0, theta=0.0
% INFO    : Bus 25004	: V=0.9803861, theta=-26.293726 -> V=1.0, theta=0.0
% INFO    : Bus 25005	: V=0.9781298, theta=-26.305852 -> V=1.0, theta=0.0
% INFO    : Bus 25006	: V=0.9922747, theta=-24.639453 -> V=1.0, theta=0.0
% INFO    : Bus 25007	: V=0.9904353, theta=-24.834666 -> V=1.0, theta=0.0
% INFO    : Bus 25008	: V=0.982489, theta=-26.376182 -> V=1.0, theta=0.0
% INFO    : Bus 25009	: V=0.9976276, theta=-24.533068 -> V=1.0, theta=0.0
% INFO    : Bus 25010	: V=1.00106, theta=-23.329543 -> V=1.0, theta=0.0
% INFO    : Bus 25011	: V=0.9871697, theta=-27.569456 -> V=1.0, theta=0.0
% INFO    : Bus 25012	: V=0.9768495, theta=-26.447295 -> V=1.0, theta=0.0
% INFO    : Bus 25013	: V=0.9928399, theta=-26.981011 -> V=1.0, theta=0.0
% INFO    : Bus 25014	: V=0.9936117, theta=-27.083938 -> V=1.0, theta=0.0
% INFO    : Bus 25015	: V=0.9963791, theta=-25.656245 -> V=1.0, theta=0.0
% INFO    : Bus 25016	: V=0.9781726, theta=-27.313622 -> V=1.0, theta=0.0
% INFO    : Bus 25017	: V=0.9813044, theta=-26.628839 -> V=1.0, theta=0.0
% INFO    : Bus 25018	: V=0.9805655, theta=-26.74425 -> V=1.0, theta=0.0
% INFO    : Bus 25019	: V=0.9800844, theta=-26.78487 -> V=1.0, theta=0.0
% INFO    : Bus 25020	: V=0.9826682, theta=-26.754323 -> V=1.0, theta=0.0
% INFO    : Bus 25021	: V=0.9822039, theta=-26.988898 -> V=1.0, theta=0.0
% INFO    : Bus 25022	: V=0.9820308, theta=-27.243374 -> V=1.0, theta=0.0
% INFO    : Bus 25023	: V=0.9819222, theta=-26.521023 -> V=1.0, theta=0.0
% INFO    : Bus 25024	: V=0.9787982, theta=-26.617702 -> V=1.0, theta=0.0
% INFO    : Bus 25025	: V=0.9987317, theta=-26.659318 -> V=1.0, theta=0.0
% INFO    : Bus 25026	: V=0.9829541, theta=-27.596268 -> V=1.0, theta=0.0
% INFO    : Bus 25027	: V=0.9811705, theta=-27.391184 -> V=1.0, theta=0.0
% INFO    : Bus 25028	: V=0.9753366, theta=-28.512256 -> V=1.0, theta=0.0
% INFO    : Bus 25029	: V=0.9719074, theta=-28.743457 -> V=1.0, theta=0.0
% INFO    : Bus 25030	: V=0.9713029, theta=-28.767356 -> V=1.0, theta=0.0
% INFO    : Bus 25031	: V=0.9941157, theta=-25.751147 -> V=1.0, theta=0.0
% INFO    : Bus 25032	: V=0.9822945, theta=-27.853571 -> V=1.0, theta=0.0
% INFO    : Bus 25033	: V=0.9950305, theta=-26.189469 -> V=1.0, theta=0.0
% INFO    : Bus 25034	: V=0.9770175, theta=-28.462916 -> V=1.0, theta=0.0
% INFO    : Bus 25035	: V=0.9881105, theta=-27.57724 -> V=1.0, theta=0.0
% INFO    : Bus 25036	: V=0.9954904, theta=-27.527576 -> V=1.0, theta=0.0
% INFO    : Bus 25037	: V=0.9848835, theta=-27.228496 -> V=1.0, theta=0.0
% INFO    : Bus 25038	: V=0.9942024, theta=-25.376179 -> V=1.0, theta=0.0
% INFO    : Bus 25039	: V=0.9735658, theta=-28.539647 -> V=1.0, theta=0.0
% INFO    : Bus 25040	: V=0.985017, theta=-27.528208 -> V=1.0, theta=0.0
% INFO    : Bus 25041	: V=0.9806752, theta=-28.108973 -> V=1.0, theta=0.0
% INFO    : Bus 25042	: V=0.9829013, theta=-27.408476 -> V=1.0, theta=0.0
% INFO    : Bus 25043	: V=0.9844115, theta=-27.287814 -> V=1.0, theta=0.0
% INFO    : Bus 25044	: V=0.968336, theta=-28.798769 -> V=1.0, theta=0.0
% INFO    : Bus 25045	: V=0.9802773, theta=-27.682287 -> V=1.0, theta=0.0
% INFO    : Bus 25046	: V=0.9961556, theta=-27.475326 -> V=1.0, theta=0.0
% INFO    : Bus 25047	: V=0.9997694, theta=-27.032321 -> V=1.0, theta=0.0
% INFO    : Bus 25048	: V=0.9955788, theta=-27.687572 -> V=1.0, theta=0.0
% INFO    : Bus 25049	: V=0.992017, theta=-28.38055 -> V=1.0, theta=0.0
% INFO    : Bus 25050	: V=0.9974793, theta=-27.21611 -> V=1.0, theta=0.0
% INFO    : Bus 25051	: V=0.9923361, theta=-28.350063 -> V=1.0, theta=0.0
% INFO    : Bus 25052	: V=0.9904205, theta=-28.569684 -> V=1.0, theta=0.0
% INFO    : Bus 25053	: V=0.9912528, theta=-28.384309 -> V=1.0, theta=0.0
% INFO    : Bus 25054	: V=0.9927075, theta=-28.240658 -> V=1.0, theta=0.0
% INFO    : Bus 25055	: V=0.9930015, theta=-28.160014 -> V=1.0, theta=0.0
% INFO    : Bus 25056	: V=0.995249, theta=-27.702109 -> V=1.0, theta=0.0
% INFO    : Bus 25057	: V=0.9968669, theta=-27.420662 -> V=1.0, theta=0.0
% INFO    : Bus 25058	: V=0.9913971, theta=-28.536816 -> V=1.0, theta=0.0
% INFO    : Bus 25059	: V=0.9928153, theta=-28.150714 -> V=1.0, theta=0.0
% INFO    : Bus 25060	: V=0.9927957, theta=-28.141993 -> V=1.0, theta=0.0
% INFO    : Bus 25061	: V=0.9928877, theta=-28.117481 -> V=1.0, theta=0.0
% INFO    : Bus 25062	: V=0.9920609, theta=-28.215244 -> V=1.0, theta=0.0
% INFO    : Bus 25063	: V=0.9971068, theta=-27.404717 -> V=1.0, theta=0.0
% INFO    : Bus 25064	: V=0.9952385, theta=-27.708428 -> V=1.0, theta=0.0
% INFO    : Bus 25065	: V=0.9979131, theta=-27.299749 -> V=1.0, theta=0.0
% INFO    : Bus 25066	: V=0.9930105, theta=-28.016368 -> V=1.0, theta=0.0
% INFO    : Bus 25067	: V=0.9966477, theta=-27.495 -> V=1.0, theta=0.0
% INFO    : Bus 25068	: V=0.9960233, theta=-26.779441 -> V=1.0, theta=0.0
% INFO    : Bus 25069	: V=0.9992324, theta=-26.300893 -> V=1.0, theta=0.0
% INFO    : Bus 25070	: V=0.9912905, theta=-26.829913 -> V=1.0, theta=0.0
% INFO    : Bus 25071	: V=0.9974593, theta=-26.056315 -> V=1.0, theta=0.0
% INFO    : Bus 25072	: V=0.9834251, theta=-26.812101 -> V=1.0, theta=0.0
% INFO    : Bus 25073	: V=1.0025804, theta=-26.703 -> V=1.0, theta=0.0
% INFO    : Bus 25074	: V=0.9824022, theta=-54.651847 -> V=1.0, theta=0.0
% INFO    : Bus 25075	: V=0.9747968, theta=-52.822225 -> V=1.0, theta=0.0
% INFO    : Bus 25076	: V=0.9752011, theta=-53.961224 -> V=1.0, theta=0.0
% INFO    : Bus 25077	: V=0.9796626, theta=-53.904996 -> V=1.0, theta=0.0
% INFO    : Bus 25078	: V=0.9855913, theta=-54.051837 -> V=1.0, theta=0.0
% INFO    : Bus 25079	: V=0.9899865, theta=-54.067975 -> V=1.0, theta=0.0
% INFO    : Bus 25080	: V=0.9762563, theta=-52.221723 -> V=1.0, theta=0.0
% INFO    : Bus 25081	: V=0.9425649, theta=-40.657816 -> V=1.0, theta=0.0
% INFO    : Bus 25082	: V=0.934572, theta=-37.967762 -> V=1.0, theta=0.0
% INFO    : Bus 25083	: V=0.9454724, theta=-38.140334 -> V=1.0, theta=0.0
% INFO    : Bus 25084	: V=0.9406568, theta=-38.566071 -> V=1.0, theta=0.0
% INFO    : Bus 25085	: V=0.9476032, theta=-38.098536 -> V=1.0, theta=0.0
% INFO    : Bus 25086	: V=0.9405239, theta=-37.889234 -> V=1.0, theta=0.0
% INFO    : Bus 25087	: V=0.9443671, theta=-38.1422 -> V=1.0, theta=0.0
% INFO    : Bus 25088	: V=0.9515243, theta=-37.744696 -> V=1.0, theta=0.0
% INFO    : Bus 25089	: V=0.9477065, theta=-37.997989 -> V=1.0, theta=0.0
% INFO    : Bus 25090	: V=0.9473733, theta=-40.618561 -> V=1.0, theta=0.0
% INFO    : Bus 25091	: V=0.9578073, theta=-36.525331 -> V=1.0, theta=0.0
% INFO    : Bus 25092	: V=0.9574756, theta=-36.698673 -> V=1.0, theta=0.0
% INFO    : Bus 25093	: V=0.9571954, theta=-36.788121 -> V=1.0, theta=0.0
% INFO    : Bus 25094	: V=0.9574515, theta=-36.217745 -> V=1.0, theta=0.0
% INFO    : Bus 25095	: V=0.9577502, theta=-36.161604 -> V=1.0, theta=0.0
% INFO    : Bus 25096	: V=0.9578255, theta=-36.182907 -> V=1.0, theta=0.0
% INFO    : Bus 25097	: V=0.9580848, theta=-36.191614 -> V=1.0, theta=0.0
% INFO    : Bus 25098	: V=0.9595361, theta=-35.884043 -> V=1.0, theta=0.0
% INFO    : Bus 25099	: V=0.9589624, theta=-35.813956 -> V=1.0, theta=0.0
% INFO    : Bus 25100	: V=0.9580004, theta=-36.423806 -> V=1.0, theta=0.0
% INFO    : Bus 25101	: V=0.9591921, theta=-35.441407 -> V=1.0, theta=0.0
% INFO    : Bus 25102	: V=0.9560912, theta=-36.817181 -> V=1.0, theta=0.0
% INFO    : Bus 25103	: V=0.9595277, theta=-35.885556 -> V=1.0, theta=0.0
% INFO    : Bus 25104	: V=0.9570927, theta=-36.873409 -> V=1.0, theta=0.0
% INFO    : Bus 25105	: V=0.9561855, theta=-36.938536 -> V=1.0, theta=0.0
% INFO    : Bus 25106	: V=0.9574857, theta=-36.885845 -> V=1.0, theta=0.0
% INFO    : Bus 25107	: V=0.9541973, theta=-37.192529 -> V=1.0, theta=0.0
% INFO    : Bus 25108	: V=0.9578891, theta=-36.020813 -> V=1.0, theta=0.0
% INFO    : Bus 25109	: V=0.9628403, theta=-35.696122 -> V=1.0, theta=0.0
% INFO    : Bus 25110	: V=0.9593915, theta=-35.365655 -> V=1.0, theta=0.0
% INFO    : Bus 25111	: V=0.9718531, theta=-35.147143 -> V=1.0, theta=0.0
% INFO    : Bus 25112	: V=0.9503736, theta=-37.931297 -> V=1.0, theta=0.0
% INFO    : Bus 25113	: V=0.9532907, theta=-37.320033 -> V=1.0, theta=0.0
% INFO    : Bus 25114	: V=0.9574998, theta=-36.347622 -> V=1.0, theta=0.0
% INFO    : Bus 25115	: V=0.9531201, theta=-37.333487 -> V=1.0, theta=0.0
% INFO    : Bus 25116	: V=0.95045, theta=-37.374684 -> V=1.0, theta=0.0
% INFO    : Bus 25117	: V=0.9424927, theta=-37.06132 -> V=1.0, theta=0.0
% INFO    : Bus 25118	: V=0.946724, theta=-37.677034 -> V=1.0, theta=0.0
% INFO    : Bus 25119	: V=0.9714236, theta=-34.745275 -> V=1.0, theta=0.0
% INFO    : Bus 25120	: V=0.9518744, theta=-37.521427 -> V=1.0, theta=0.0
% INFO    : Bus 25121	: V=0.9441495, theta=-36.53154 -> V=1.0, theta=0.0
% INFO    : Bus 25122	: V=0.9471363, theta=-36.341845 -> V=1.0, theta=0.0
% INFO    : Bus 25123	: V=0.9567032, theta=-35.760622 -> V=1.0, theta=0.0
% INFO    : Bus 25124	: V=0.953057, theta=-35.672677 -> V=1.0, theta=0.0
% INFO    : Bus 25125	: V=0.9606627, theta=-34.362955 -> V=1.0, theta=0.0
% INFO    : Bus 25126	: V=0.9616982, theta=-34.547351 -> V=1.0, theta=0.0
% INFO    : Bus 25127	: V=0.9600666, theta=-35.12706 -> V=1.0, theta=0.0
% INFO    : Bus 25128	: V=0.9610822, theta=-34.766014 -> V=1.0, theta=0.0
% INFO    : Bus 25129	: V=0.9606737, theta=-34.910782 -> V=1.0, theta=0.0
% INFO    : Bus 25130	: V=0.9621527, theta=-34.999206 -> V=1.0, theta=0.0
% INFO    : Bus 25131	: V=0.9507138, theta=-37.407045 -> V=1.0, theta=0.0
% INFO    : Bus 25132	: V=0.9504168, theta=-36.905286 -> V=1.0, theta=0.0
% INFO    : Bus 25133	: V=0.9580289, theta=-36.196935 -> V=1.0, theta=0.0
% INFO    : Bus 25134	: V=0.9576408, theta=-36.226758 -> V=1.0, theta=0.0
% INFO    : Bus 25135	: V=0.9871471, theta=-27.739609 -> V=1.0, theta=0.0
% INFO    : Bus 25136	: V=0.9862811, theta=-27.87288 -> V=1.0, theta=0.0
% INFO    : Bus 25137	: V=0.9856026, theta=-28.006517 -> V=1.0, theta=0.0
% INFO    : Bus 25138	: V=0.9870089, theta=-27.789789 -> V=1.0, theta=0.0
% INFO    : Bus 25139	: V=0.9838748, theta=-28.076477 -> V=1.0, theta=0.0
% INFO    : Bus 25140	: V=0.9810198, theta=-27.857114 -> V=1.0, theta=0.0
% INFO    : Bus 25141	: V=0.9825125, theta=-27.751696 -> V=1.0, theta=0.0
% INFO    : Bus 25142	: V=0.9873385, theta=-27.575361 -> V=1.0, theta=0.0
% INFO    : Bus 25143	: V=0.9887275, theta=-26.859617 -> V=1.0, theta=0.0
% INFO    : Bus 25144	: V=0.9878591, theta=-27.343069 -> V=1.0, theta=0.0
% INFO    : Bus 25145	: V=0.9835467, theta=-27.74048 -> V=1.0, theta=0.0
% INFO    : Bus 25146	: V=0.9799668, theta=-27.99802 -> V=1.0, theta=0.0
% INFO    : Bus 25147	: V=0.9907047, theta=-27.08572 -> V=1.0, theta=0.0
% INFO    : Bus 25148	: V=0.9883872, theta=-27.182231 -> V=1.0, theta=0.0
% INFO    : Bus 25149	: V=0.9879102, theta=-27.340157 -> V=1.0, theta=0.0
% INFO    : Bus 25150	: V=0.9794685, theta=-27.808493 -> V=1.0, theta=0.0
% INFO    : Bus 25151	: V=0.9812941, theta=-27.747091 -> V=1.0, theta=0.0
% INFO    : Bus 25152	: V=0.9929719, theta=-26.859923 -> V=1.0, theta=0.0
% INFO    : Bus 25153	: V=0.9799951, theta=-27.987504 -> V=1.0, theta=0.0
% INFO    : Bus 25154	: V=0.9842023, theta=-27.750276 -> V=1.0, theta=0.0
% INFO    : Bus 25155	: V=0.9979789, theta=-26.282838 -> V=1.0, theta=0.0
% INFO    : Bus 25156	: V=1.0006397, theta=-25.941903 -> V=1.0, theta=0.0
% INFO    : Bus 25157	: V=1.0087536, theta=-25.023809 -> V=1.0, theta=0.0
% INFO    : Bus 25158	: V=0.9958555, theta=-26.543747 -> V=1.0, theta=0.0
% INFO    : Bus 25159	: V=0.990957, theta=-27.331892 -> V=1.0, theta=0.0
% INFO    : Bus 25160	: V=0.9944224, theta=-26.789435 -> V=1.0, theta=0.0
% INFO    : Bus 25161	: V=0.9966509, theta=-26.507308 -> V=1.0, theta=0.0
% INFO    : Bus 25162	: V=0.9941685, theta=-26.755832 -> V=1.0, theta=0.0
% INFO    : Bus 25163	: V=0.9922129, theta=-26.804677 -> V=1.0, theta=0.0
% INFO    : Bus 25164	: V=0.9986794, theta=-26.267152 -> V=1.0, theta=0.0
% INFO    : Bus 25165	: V=0.9941361, theta=-26.757956 -> V=1.0, theta=0.0
% INFO    : Bus 25166	: V=0.9924241, theta=-26.924724 -> V=1.0, theta=0.0
% INFO    : Bus 25167	: V=1.0057668, theta=-25.234967 -> V=1.0, theta=0.0
% INFO    : Bus 25168	: V=1.0028656, theta=-25.665729 -> V=1.0, theta=0.0
% INFO    : Bus 25169	: V=1.0167495, theta=-23.988861 -> V=1.0, theta=0.0
% INFO    : Bus 25170	: V=1.0040812, theta=-25.00961 -> V=1.0, theta=0.0
% INFO    : Bus 25171	: V=1.0154768, theta=-24.088785 -> V=1.0, theta=0.0
% INFO    : Bus 25172	: V=0.9870426, theta=-27.256266 -> V=1.0, theta=0.0
% INFO    : Bus 25173	: V=0.9892237, theta=-27.003145 -> V=1.0, theta=0.0
% INFO    : Bus 25174	: V=1.0041977, theta=-24.896616 -> V=1.0, theta=0.0
% INFO    : Bus 25175	: V=0.9580668, theta=-32.782376 -> V=1.0, theta=0.0
% INFO    : Bus 25176	: V=0.9866015, theta=-29.498052 -> V=1.0, theta=0.0
% INFO    : Bus 25177	: V=0.9876336, theta=-29.360753 -> V=1.0, theta=0.0
% INFO    : Bus 25178	: V=0.9746608, theta=-31.79944 -> V=1.0, theta=0.0
% INFO    : Bus 25179	: V=0.9889423, theta=-29.167776 -> V=1.0, theta=0.0
% INFO    : Bus 25180	: V=0.9861725, theta=-28.793238 -> V=1.0, theta=0.0
% INFO    : Bus 25181	: V=0.9879297, theta=-28.633343 -> V=1.0, theta=0.0
% INFO    : Bus 25182	: V=0.9756112, theta=-30.18937 -> V=1.0, theta=0.0
% INFO    : Bus 25183	: V=0.9845006, theta=-29.918386 -> V=1.0, theta=0.0
% INFO    : Bus 25184	: V=0.9820482, theta=-59.683818 -> V=1.0, theta=0.0
% INFO    : Bus 25185	: V=0.986057, theta=-57.545804 -> V=1.0, theta=0.0
% INFO    : Bus 25186	: V=0.9864312, theta=-57.494821 -> V=1.0, theta=0.0
% INFO    : Bus 25187	: V=0.9803837, theta=-57.916864 -> V=1.0, theta=0.0
% INFO    : Bus 25188	: V=0.9783716, theta=-57.871823 -> V=1.0, theta=0.0
% INFO    : Bus 25189	: V=0.9745767, theta=-58.530503 -> V=1.0, theta=0.0
% INFO    : Bus 25190	: V=0.9880887, theta=-57.227836 -> V=1.0, theta=0.0
% INFO    : Bus 25191	: V=0.9760968, theta=-57.941195 -> V=1.0, theta=0.0
% INFO    : Bus 25192	: V=0.9705254, theta=-56.957379 -> V=1.0, theta=0.0
% INFO    : Bus 25193	: V=0.960533, theta=-59.261437 -> V=1.0, theta=0.0
% INFO    : Bus 25194	: V=0.9811775, theta=-56.877865 -> V=1.0, theta=0.0
% INFO    : Bus 25195	: V=0.986891, theta=-55.622752 -> V=1.0, theta=0.0
% INFO    : Bus 25196	: V=0.9943502, theta=-55.959456 -> V=1.0, theta=0.0
% INFO    : Bus 25197	: V=0.9935976, theta=-57.154228 -> V=1.0, theta=0.0
% INFO    : Bus 25198	: V=0.9871405, theta=-59.14526 -> V=1.0, theta=0.0
% INFO    : Bus 25199	: V=0.9960699, theta=-57.427878 -> V=1.0, theta=0.0
% INFO    : Bus 25200	: V=1.0145458, theta=-54.251735 -> V=1.0, theta=0.0
% INFO    : Bus 25201	: V=1.0163931, theta=-54.080146 -> V=1.0, theta=0.0
% INFO    : Bus 25202	: V=1.0147874, theta=-54.427019 -> V=1.0, theta=0.0
% INFO    : Bus 25203	: V=1.0141772, theta=-54.556853 -> V=1.0, theta=0.0
% INFO    : Bus 25204	: V=1.0020563, theta=-56.064539 -> V=1.0, theta=0.0
% INFO    : Bus 25205	: V=1.013027, theta=-54.808542 -> V=1.0, theta=0.0
% INFO    : Bus 25206	: V=1.013488, theta=-54.701971 -> V=1.0, theta=0.0
% INFO    : Bus 25207	: V=0.9965989, theta=-56.909017 -> V=1.0, theta=0.0
% INFO    : Bus 25208	: V=0.9973523, theta=-44.096491 -> V=1.0, theta=0.0
% INFO    : Bus 25209	: V=0.9937373, theta=-44.837094 -> V=1.0, theta=0.0
% INFO    : Bus 25210	: V=0.9996164, theta=-42.716933 -> V=1.0, theta=0.0
% INFO    : Bus 25211	: V=1.0117632, theta=-41.350219 -> V=1.0, theta=0.0
% INFO    : Bus 25212	: V=1.0049834, theta=-42.338278 -> V=1.0, theta=0.0
% INFO    : Bus 25213	: V=1.0068337, theta=-42.097616 -> V=1.0, theta=0.0
% INFO    : Bus 25214	: V=1.0066461, theta=-42.187288 -> V=1.0, theta=0.0
% INFO    : Bus 25215	: V=1.0082526, theta=-41.923941 -> V=1.0, theta=0.0
% INFO    : Bus 25216	: V=1.0041867, theta=-42.634997 -> V=1.0, theta=0.0
% INFO    : Bus 25217	: V=1.0025622, theta=-41.539747 -> V=1.0, theta=0.0
% INFO    : Bus 25218	: V=0.9491234, theta=-47.753429 -> V=1.0, theta=0.0
% INFO    : Bus 25219	: V=0.9430472, theta=-45.791877 -> V=1.0, theta=0.0
% INFO    : Bus 25220	: V=0.9431552, theta=-46.769439 -> V=1.0, theta=0.0
% INFO    : Bus 25221	: V=0.9440018, theta=-47.689793 -> V=1.0, theta=0.0
% INFO    : Bus 25222	: V=0.9423767, theta=-47.768145 -> V=1.0, theta=0.0
% INFO    : Bus 25223	: V=0.9498293, theta=-46.189521 -> V=1.0, theta=0.0
% INFO    : Bus 25224	: V=0.9528534, theta=-46.610343 -> V=1.0, theta=0.0
% INFO    : Bus 25225	: V=0.9578878, theta=-47.437715 -> V=1.0, theta=0.0
% INFO    : Bus 25226	: V=0.9591614, theta=-47.754417 -> V=1.0, theta=0.0
% INFO    : Bus 25227	: V=0.9730864, theta=-49.688395 -> V=1.0, theta=0.0
% INFO    : Bus 25228	: V=0.9730803, theta=-49.317117 -> V=1.0, theta=0.0
% INFO    : Bus 25229	: V=0.9706988, theta=-49.429125 -> V=1.0, theta=0.0
% INFO    : Bus 25230	: V=0.9608406, theta=-48.052734 -> V=1.0, theta=0.0
% INFO    : Bus 25231	: V=0.9638304, theta=-51.197584 -> V=1.0, theta=0.0
% INFO    : Bus 25232	: V=0.9650058, theta=-51.083086 -> V=1.0, theta=0.0
% INFO    : Bus 25233	: V=0.9660803, theta=-50.900039 -> V=1.0, theta=0.0
% INFO    : Bus 25234	: V=0.9647059, theta=-51.147289 -> V=1.0, theta=0.0
% INFO    : Bus 25235	: V=0.9646944, theta=-51.036207 -> V=1.0, theta=0.0
% INFO    : Bus 25236	: V=0.9648797, theta=-50.976691 -> V=1.0, theta=0.0
% INFO    : Bus 25237	: V=0.9650718, theta=-50.928781 -> V=1.0, theta=0.0
% INFO    : Bus 25238	: V=0.9655009, theta=-50.880646 -> V=1.0, theta=0.0
% INFO    : Bus 25239	: V=0.9645223, theta=-51.189901 -> V=1.0, theta=0.0
% INFO    : Bus 25240	: V=0.9689119, theta=-48.871457 -> V=1.0, theta=0.0
% INFO    : Bus 25241	: V=0.9640121, theta=-52.236896 -> V=1.0, theta=0.0
% INFO    : Bus 25242	: V=0.963543, theta=-51.11786 -> V=1.0, theta=0.0
% INFO    : Bus 25243	: V=0.9639115, theta=-51.059129 -> V=1.0, theta=0.0
% INFO    : Bus 25244	: V=0.9642301, theta=-51.006009 -> V=1.0, theta=0.0
% INFO    : Bus 25245	: V=0.9645372, theta=-50.956649 -> V=1.0, theta=0.0
% INFO    : Bus 25246	: V=0.9649796, theta=-50.891797 -> V=1.0, theta=0.0
% INFO    : Bus 25247	: V=0.9657594, theta=-50.712186 -> V=1.0, theta=0.0
% INFO    : Bus 25248	: V=0.9664242, theta=-50.581369 -> V=1.0, theta=0.0
% INFO    : Bus 25249	: V=0.967924, theta=-48.907313 -> V=1.0, theta=0.0
% INFO    : Bus 25250	: V=0.9635607, theta=-51.404148 -> V=1.0, theta=0.0
% INFO    : Bus 25251	: V=0.9626041, theta=-51.589021 -> V=1.0, theta=0.0
% INFO    : Bus 25252	: V=0.9655996, theta=-51.113345 -> V=1.0, theta=0.0
% INFO    : Bus 25253	: V=0.9685145, theta=-48.892383 -> V=1.0, theta=0.0
% INFO    : Bus 25254	: V=0.9669168, theta=-50.843343 -> V=1.0, theta=0.0
% INFO    : Bus 25255	: V=0.9685026, theta=-50.380355 -> V=1.0, theta=0.0
% INFO    : Bus 25256	: V=0.9679998, theta=-50.418797 -> V=1.0, theta=0.0
% INFO    : Bus 25257	: V=0.9677002, theta=-50.441136 -> V=1.0, theta=0.0
% INFO    : Bus 25258	: V=0.9672772, theta=-48.926914 -> V=1.0, theta=0.0
% INFO    : Bus 25259	: V=0.9677961, theta=-50.711748 -> V=1.0, theta=0.0
% INFO    : Bus 25260	: V=0.9674247, theta=-50.636709 -> V=1.0, theta=0.0
% INFO    : Bus 25261	: V=0.9679076, theta=-48.916399 -> V=1.0, theta=0.0
% INFO    : Bus 25262	: V=0.967353, theta=-48.849731 -> V=1.0, theta=0.0
% INFO    : Bus 25263	: V=0.9645069, theta=-51.281569 -> V=1.0, theta=0.0
% INFO    : Bus 25264	: V=0.9622526, theta=-51.602438 -> V=1.0, theta=0.0
% INFO    : Bus 25265	: V=0.965743, theta=-50.686722 -> V=1.0, theta=0.0
% INFO    : Bus 25266	: V=0.9658235, theta=-50.661648 -> V=1.0, theta=0.0
% INFO    : Bus 25267	: V=0.9627047, theta=-51.595947 -> V=1.0, theta=0.0
% INFO    : Bus 25268	: V=0.9661652, theta=-50.604535 -> V=1.0, theta=0.0
% INFO    : Bus 25269	: V=0.9613745, theta=-51.467689 -> V=1.0, theta=0.0
% INFO    : Bus 25270	: V=0.9610871, theta=-51.604329 -> V=1.0, theta=0.0
% INFO    : Bus 25271	: V=0.959508, theta=-52.16866 -> V=1.0, theta=0.0
% INFO    : Bus 25272	: V=0.9602029, theta=-52.136067 -> V=1.0, theta=0.0
% INFO    : Bus 25273	: V=0.9623112, theta=-51.88602 -> V=1.0, theta=0.0
% INFO    : Bus 25274	: V=0.961353, theta=-52.024688 -> V=1.0, theta=0.0
% INFO    : Bus 25275	: V=0.9605934, theta=-52.204484 -> V=1.0, theta=0.0
% INFO    : Bus 25276	: V=0.9608074, theta=-51.671165 -> V=1.0, theta=0.0
% INFO    : Bus 25277	: V=0.9613318, theta=-52.002446 -> V=1.0, theta=0.0
% INFO    : Bus 25278	: V=0.9612813, theta=-51.528388 -> V=1.0, theta=0.0
% INFO    : Bus 25279	: V=0.9615641, theta=-51.43364 -> V=1.0, theta=0.0
% INFO    : Bus 25280	: V=0.9615353, theta=-51.847594 -> V=1.0, theta=0.0
% INFO    : Bus 25281	: V=0.9629862, theta=-51.679564 -> V=1.0, theta=0.0
% INFO    : Bus 25282	: V=0.9720393, theta=-50.911408 -> V=1.0, theta=0.0
% INFO    : Bus 25283	: V=0.9763286, theta=-50.97887 -> V=1.0, theta=0.0
% INFO    : Bus 25284	: V=0.9642005, theta=-52.10204 -> V=1.0, theta=0.0
% INFO    : Bus 25285	: V=0.9637464, theta=-52.131141 -> V=1.0, theta=0.0
% INFO    : Bus 25286	: V=0.9639426, theta=-52.001818 -> V=1.0, theta=0.0
% INFO    : Bus 25287	: V=0.9640561, theta=-51.874648 -> V=1.0, theta=0.0
% INFO    : Bus 25288	: V=0.9632161, theta=-51.96363 -> V=1.0, theta=0.0
% INFO    : Bus 25289	: V=0.9616059, theta=-51.424467 -> V=1.0, theta=0.0
% INFO    : Bus 25290	: V=0.9616306, theta=-51.398161 -> V=1.0, theta=0.0
% INFO    : Bus 25291	: V=0.9615692, theta=-51.365237 -> V=1.0, theta=0.0
% INFO    : Bus 25292	: V=0.9615481, theta=-51.316342 -> V=1.0, theta=0.0
% INFO    : Bus 25293	: V=0.9808715, theta=-50.870205 -> V=1.0, theta=0.0
% INFO    : Bus 25294	: V=0.9705955, theta=-52.263534 -> V=1.0, theta=0.0
% INFO    : Bus 25295	: V=0.9673529, theta=-52.261094 -> V=1.0, theta=0.0
% INFO    : Bus 25296	: V=0.9685034, theta=-52.250482 -> V=1.0, theta=0.0
% INFO    : Bus 25297	: V=0.9802162, theta=-50.930072 -> V=1.0, theta=0.0
% INFO    : Bus 25298	: V=0.967778, theta=-52.315043 -> V=1.0, theta=0.0
% INFO    : Bus 25299	: V=0.968181, theta=-52.329082 -> V=1.0, theta=0.0
% INFO    : Bus 25300	: V=0.9666699, theta=-52.26282 -> V=1.0, theta=0.0
% INFO    : Bus 25301	: V=0.9667771, theta=-52.346125 -> V=1.0, theta=0.0
% INFO    : Bus 25302	: V=0.9651138, theta=-52.193183 -> V=1.0, theta=0.0
% INFO    : Bus 25303	: V=0.9659469, theta=-52.233622 -> V=1.0, theta=0.0
% INFO    : Bus 25304	: V=0.9654064, theta=-52.377776 -> V=1.0, theta=0.0
% INFO    : Bus 25305	: V=0.9655345, theta=-52.422849 -> V=1.0, theta=0.0
% INFO    : Bus 25306	: V=0.9644219, theta=-52.35279 -> V=1.0, theta=0.0
% INFO    : Bus 25307	: V=0.9637072, theta=-52.328823 -> V=1.0, theta=0.0
% INFO    : Bus 25308	: V=0.9623014, theta=-52.3654 -> V=1.0, theta=0.0
% INFO    : Bus 25309	: V=0.9620157, theta=-52.427497 -> V=1.0, theta=0.0
% INFO    : Bus 25310	: V=0.9624226, theta=-52.131472 -> V=1.0, theta=0.0
% INFO    : Bus 25311	: V=0.9627744, theta=-52.271011 -> V=1.0, theta=0.0
% INFO    : Bus 25312	: V=0.9604783, theta=-52.107943 -> V=1.0, theta=0.0
% INFO    : Bus 25313	: V=0.9606779, theta=-51.662042 -> V=1.0, theta=0.0
% INFO    : Bus 25314	: V=0.9617061, theta=-51.346541 -> V=1.0, theta=0.0
% INFO    : Bus 25315	: V=0.9604537, theta=-52.108367 -> V=1.0, theta=0.0
% INFO    : Bus 25316	: V=0.9617587, theta=-51.317376 -> V=1.0, theta=0.0
% INFO    : Bus 25317	: V=0.9606907, theta=-51.788886 -> V=1.0, theta=0.0
% INFO    : Bus 25318	: V=0.9618417, theta=-51.281256 -> V=1.0, theta=0.0
% INFO    : Bus 25319	: V=0.960752, theta=-51.84352 -> V=1.0, theta=0.0
% INFO    : Bus 25320	: V=0.9619419, theta=-51.241051 -> V=1.0, theta=0.0
% INFO    : Bus 25321	: V=0.9620707, theta=-51.199412 -> V=1.0, theta=0.0
% INFO    : Bus 25322	: V=0.9613248, theta=-52.103951 -> V=1.0, theta=0.0
% INFO    : Bus 25323	: V=0.9608529, theta=-52.206565 -> V=1.0, theta=0.0
% INFO    : Bus 25324	: V=0.9698094, theta=-52.380201 -> V=1.0, theta=0.0
% INFO    : Bus 25325	: V=0.9697506, theta=-52.431403 -> V=1.0, theta=0.0
% INFO    : Bus 25326	: V=0.969751, theta=-52.472409 -> V=1.0, theta=0.0
% INFO    : Bus 25327	: V=0.9693757, theta=-52.318 -> V=1.0, theta=0.0
% INFO    : Bus 25328	: V=0.9688804, theta=-52.472388 -> V=1.0, theta=0.0
% INFO    : Bus 25329	: V=0.9683004, theta=-52.530746 -> V=1.0, theta=0.0
% INFO    : Bus 25330	: V=0.9769056, theta=-52.075989 -> V=1.0, theta=0.0
% INFO    : Bus 25331	: V=0.9685814, theta=-52.565515 -> V=1.0, theta=0.0
% INFO    : Bus 25332	: V=0.9698403, theta=-52.622819 -> V=1.0, theta=0.0
% INFO    : Bus 25333	: V=0.9788975, theta=-51.95742 -> V=1.0, theta=0.0
% INFO    : Bus 25334	: V=0.9782327, theta=-51.995994 -> V=1.0, theta=0.0
% INFO    : Bus 25335	: V=0.9771384, theta=-52.238779 -> V=1.0, theta=0.0
% INFO    : Bus 25336	: V=0.9800215, theta=-51.881466 -> V=1.0, theta=0.0
% INFO    : Bus 25337	: V=0.9774716, theta=-52.045941 -> V=1.0, theta=0.0
% INFO    : Bus 25338	: V=0.9733518, theta=-52.457634 -> V=1.0, theta=0.0
% INFO    : Bus 25339	: V=0.9696881, theta=-52.704269 -> V=1.0, theta=0.0
% INFO    : Bus 25340	: V=0.9967799, theta=-50.256427 -> V=1.0, theta=0.0
% INFO    : Bus 25341	: V=0.9969281, theta=-50.243376 -> V=1.0, theta=0.0
% INFO    : Bus 25342	: V=0.9965685, theta=-50.264772 -> V=1.0, theta=0.0
% INFO    : Bus 25343	: V=0.9792462, theta=-51.927209 -> V=1.0, theta=0.0
% INFO    : Bus 25344	: V=0.9681929, theta=-52.378815 -> V=1.0, theta=0.0
% INFO    : Bus 25345	: V=0.9675647, theta=-52.465576 -> V=1.0, theta=0.0
% INFO    : Bus 25346	: V=0.9669511, theta=-52.446259 -> V=1.0, theta=0.0
% INFO    : Bus 25347	: V=0.9673826, theta=-52.537549 -> V=1.0, theta=0.0
% INFO    : Bus 25348	: V=0.9661199, theta=-52.566876 -> V=1.0, theta=0.0
% INFO    : Bus 25349	: V=0.9662853, theta=-52.414494 -> V=1.0, theta=0.0
% INFO    : Bus 25350	: V=0.9641688, theta=-52.608381 -> V=1.0, theta=0.0
% INFO    : Bus 25351	: V=0.9637761, theta=-52.683174 -> V=1.0, theta=0.0
% INFO    : Bus 25352	: V=0.9648047, theta=-52.521792 -> V=1.0, theta=0.0
% INFO    : Bus 25353	: V=0.9622853, theta=-52.63143 -> V=1.0, theta=0.0
% INFO    : Bus 25354	: V=0.9619823, theta=-52.589879 -> V=1.0, theta=0.0
% INFO    : Bus 25355	: V=0.9607074, theta=-51.765596 -> V=1.0, theta=0.0
% INFO    : Bus 25356	: V=0.9613361, theta=-52.593223 -> V=1.0, theta=0.0
% INFO    : Bus 25357	: V=0.960732, theta=-52.507345 -> V=1.0, theta=0.0
% INFO    : Bus 25358	: V=0.9607419, theta=-52.626921 -> V=1.0, theta=0.0
% INFO    : Bus 25359	: V=0.960837, theta=-52.573792 -> V=1.0, theta=0.0
% INFO    : Bus 25360	: V=0.9608118, theta=-52.291117 -> V=1.0, theta=0.0
% INFO    : Bus 25361	: V=0.9604085, theta=-52.411098 -> V=1.0, theta=0.0
% INFO    : Bus 25362	: V=0.9606938, theta=-52.407818 -> V=1.0, theta=0.0
% INFO    : Bus 25363	: V=0.9576972, theta=-52.717596 -> V=1.0, theta=0.0
% INFO    : Bus 25364	: V=0.9601668, theta=-51.795003 -> V=1.0, theta=0.0
% INFO    : Bus 25365	: V=0.9608572, theta=-52.09797 -> V=1.0, theta=0.0
% INFO    : Bus 25366	: V=0.9617171, theta=-50.965555 -> V=1.0, theta=0.0
% INFO    : Bus 25367	: V=0.9603683, theta=-52.274971 -> V=1.0, theta=0.0
% INFO    : Bus 25368	: V=0.9594918, theta=-52.413504 -> V=1.0, theta=0.0
% INFO    : Bus 25369	: V=0.9647322, theta=-48.936384 -> V=1.0, theta=0.0
% INFO    : Bus 25370	: V=0.9586384, theta=-52.654221 -> V=1.0, theta=0.0
% INFO    : Bus 25371	: V=0.9577559, theta=-52.789028 -> V=1.0, theta=0.0
% INFO    : Bus 25372	: V=0.9579886, theta=-52.78596 -> V=1.0, theta=0.0
% INFO    : Bus 25373	: V=0.9589863, theta=-52.546884 -> V=1.0, theta=0.0
% INFO    : Bus 25374	: V=0.9589755, theta=-52.586332 -> V=1.0, theta=0.0
% INFO    : Bus 25375	: V=0.9615273, theta=-51.055128 -> V=1.0, theta=0.0
% INFO    : Bus 25376	: V=0.9604796, theta=-51.483667 -> V=1.0, theta=0.0
% INFO    : Bus 25377	: V=0.9607187, theta=-51.383957 -> V=1.0, theta=0.0
% INFO    : Bus 25378	: V=0.9602259, theta=-51.618449 -> V=1.0, theta=0.0
% INFO    : Bus 25379	: V=0.9580594, theta=-53.032665 -> V=1.0, theta=0.0
% INFO    : Bus 25380	: V=0.958064, theta=-53.131281 -> V=1.0, theta=0.0
% INFO    : Bus 25381	: V=0.9600181, theta=-51.723356 -> V=1.0, theta=0.0
% INFO    : Bus 25382	: V=0.95846, theta=-53.184363 -> V=1.0, theta=0.0
% INFO    : Bus 25383	: V=0.9596175, theta=-51.804728 -> V=1.0, theta=0.0
% INFO    : Bus 25384	: V=0.9593977, theta=-51.867083 -> V=1.0, theta=0.0
% INFO    : Bus 25385	: V=0.9622796, theta=-52.717084 -> V=1.0, theta=0.0
% INFO    : Bus 25386	: V=0.962665, theta=-52.698997 -> V=1.0, theta=0.0
% INFO    : Bus 25387	: V=0.9642545, theta=-51.225427 -> V=1.0, theta=0.0
% INFO    : Bus 25388	: V=0.9707583, theta=-48.665274 -> V=1.0, theta=0.0
% INFO    : Bus 25389	: V=0.9645608, theta=-51.174172 -> V=1.0, theta=0.0
% INFO    : Bus 25390	: V=0.9623856, theta=-52.81987 -> V=1.0, theta=0.0
% INFO    : Bus 25391	: V=0.9632552, theta=-52.802381 -> V=1.0, theta=0.0
% INFO    : Bus 25392	: V=0.9628821, theta=-52.738865 -> V=1.0, theta=0.0
% INFO    : Bus 25393	: V=0.9616948, theta=-52.328421 -> V=1.0, theta=0.0
% INFO    : Bus 25394	: V=0.9623735, theta=-52.905581 -> V=1.0, theta=0.0
% INFO    : Bus 25395	: V=0.9630324, theta=-52.661009 -> V=1.0, theta=0.0
% INFO    : Bus 25396	: V=0.96315, theta=-52.500524 -> V=1.0, theta=0.0
% INFO    : Bus 25397	: V=0.962408, theta=-52.79911 -> V=1.0, theta=0.0
% INFO    : Bus 25398	: V=0.9619287, theta=-52.884404 -> V=1.0, theta=0.0
% INFO    : Bus 25399	: V=0.9624377, theta=-52.675146 -> V=1.0, theta=0.0
% INFO    : Bus 25400	: V=0.9609793, theta=-52.407049 -> V=1.0, theta=0.0
% INFO    : Bus 25401	: V=0.9611039, theta=-52.3799 -> V=1.0, theta=0.0
% INFO    : Bus 25402	: V=0.9704161, theta=-52.732221 -> V=1.0, theta=0.0
% INFO    : Bus 25403	: V=0.9648705, theta=-48.892035 -> V=1.0, theta=0.0
% INFO    : Bus 25404	: V=0.9763241, theta=-49.352465 -> V=1.0, theta=0.0
% INFO    : Bus 25405	: V=0.9749405, theta=-49.691069 -> V=1.0, theta=0.0
% INFO    : Bus 25406	: V=0.9736147, theta=-50.013378 -> V=1.0, theta=0.0
% INFO    : Bus 25407	: V=0.9678241, theta=-51.96351 -> V=1.0, theta=0.0
% INFO    : Bus 25408	: V=0.9658465, theta=-53.155168 -> V=1.0, theta=0.0
% INFO    : Bus 25409	: V=0.9596241, theta=-53.329486 -> V=1.0, theta=0.0
% INFO    : Bus 25410	: V=0.9600527, theta=-53.389087 -> V=1.0, theta=0.0
% INFO    : Bus 25411	: V=0.9608128, theta=-52.592012 -> V=1.0, theta=0.0
% INFO    : Bus 25412	: V=0.9606214, theta=-52.648148 -> V=1.0, theta=0.0
% INFO    : Bus 25413	: V=0.9608411, theta=-52.342381 -> V=1.0, theta=0.0
% INFO    : Bus 25414	: V=0.9607118, theta=-52.522591 -> V=1.0, theta=0.0
% INFO    : Bus 25415	: V=0.9588875, theta=-53.754489 -> V=1.0, theta=0.0
% INFO    : Bus 25416	: V=0.9628359, theta=-53.413652 -> V=1.0, theta=0.0
% INFO    : Bus 25417	: V=0.9629716, theta=-52.104923 -> V=1.0, theta=0.0
% INFO    : Bus 25418	: V=0.96346, theta=-52.766451 -> V=1.0, theta=0.0
% INFO    : Bus 25419	: V=0.9622947, theta=-52.969248 -> V=1.0, theta=0.0
% INFO    : Bus 25420	: V=0.9613207, theta=-53.08047 -> V=1.0, theta=0.0
% INFO    : Bus 25421	: V=0.9604315, theta=-53.229775 -> V=1.0, theta=0.0
% INFO    : Bus 25422	: V=0.9603494, theta=-53.219781 -> V=1.0, theta=0.0
% INFO    : Bus 25423	: V=0.9607337, theta=-53.263955 -> V=1.0, theta=0.0
% INFO    : Bus 25424	: V=0.960513, theta=-52.251477 -> V=1.0, theta=0.0
% INFO    : Bus 25425	: V=0.9630302, theta=-52.28387 -> V=1.0, theta=0.0
% INFO    : Bus 25426	: V=0.9581711, theta=-54.149279 -> V=1.0, theta=0.0
% INFO    : Bus 25427	: V=0.9589564, theta=-53.381026 -> V=1.0, theta=0.0
% INFO    : Bus 25428	: V=0.9587763, theta=-53.910609 -> V=1.0, theta=0.0
% INFO    : Bus 25429	: V=0.962888, theta=-51.903695 -> V=1.0, theta=0.0
% INFO    : Bus 25430	: V=0.9599322, theta=-51.846782 -> V=1.0, theta=0.0
% INFO    : Bus 25431	: V=0.960022, theta=-51.824987 -> V=1.0, theta=0.0
% INFO    : Bus 25432	: V=0.9601986, theta=-51.793783 -> V=1.0, theta=0.0
% INFO    : Bus 25433	: V=0.9641977, theta=-51.933135 -> V=1.0, theta=0.0
% INFO    : Bus 25434	: V=0.9584606, theta=-53.41541 -> V=1.0, theta=0.0
% INFO    : Bus 25435	: V=0.9610239, theta=-53.149134 -> V=1.0, theta=0.0
% INFO    : Bus 25436	: V=0.9595502, theta=-53.273978 -> V=1.0, theta=0.0
% INFO    : Bus 25437	: V=0.963033, theta=-50.231441 -> V=1.0, theta=0.0
% INFO    : Bus 25438	: V=0.9613854, theta=-52.309198 -> V=1.0, theta=0.0
% INFO    : Bus 25439	: V=0.9685088, theta=-52.793069 -> V=1.0, theta=0.0
% INFO    : Bus 25440	: V=0.9667529, theta=-52.824913 -> V=1.0, theta=0.0
% INFO    : Bus 25441	: V=0.9657808, theta=-52.892566 -> V=1.0, theta=0.0
% INFO    : Bus 25442	: V=0.9639371, theta=-53.004686 -> V=1.0, theta=0.0
% INFO    : Bus 25443	: V=0.9639122, theta=-53.09342 -> V=1.0, theta=0.0
% INFO    : Bus 25444	: V=0.9620037, theta=-52.88354 -> V=1.0, theta=0.0
% INFO    : Bus 25445	: V=0.9628091, theta=-52.972603 -> V=1.0, theta=0.0
% INFO    : Bus 25446	: V=0.9618951, theta=-52.927147 -> V=1.0, theta=0.0
% INFO    : Bus 25447	: V=0.9627313, theta=-53.018494 -> V=1.0, theta=0.0
% INFO    : Bus 25448	: V=0.9620071, theta=-53.008751 -> V=1.0, theta=0.0
% INFO    : Bus 25449	: V=0.9635073, theta=-52.758307 -> V=1.0, theta=0.0
% INFO    : Bus 25450	: V=0.9624652, theta=-52.770663 -> V=1.0, theta=0.0
% INFO    : Bus 25451	: V=0.9621434, theta=-52.75723 -> V=1.0, theta=0.0
% INFO    : Bus 25452	: V=0.961555, theta=-52.672982 -> V=1.0, theta=0.0
% INFO    : Bus 25453	: V=0.9618559, theta=-52.727887 -> V=1.0, theta=0.0
% INFO    : Bus 25454	: V=0.9611304, theta=-52.821875 -> V=1.0, theta=0.0
% INFO    : Bus 25455	: V=0.9611098, theta=-52.84289 -> V=1.0, theta=0.0
% INFO    : Bus 25456	: V=0.9614003, theta=-52.876123 -> V=1.0, theta=0.0
% INFO    : Bus 25457	: V=0.9611656, theta=-52.859495 -> V=1.0, theta=0.0
% INFO    : Bus 25458	: V=0.969049, theta=-52.631873 -> V=1.0, theta=0.0
% INFO    : Bus 25459	: V=0.9683015, theta=-52.610042 -> V=1.0, theta=0.0
% INFO    : Bus 25460	: V=0.9681225, theta=-52.63567 -> V=1.0, theta=0.0
% INFO    : Bus 25461	: V=0.9683792, theta=-52.698829 -> V=1.0, theta=0.0
% INFO    : Bus 25462	: V=0.9779266, theta=-52.014285 -> V=1.0, theta=0.0
% INFO    : Bus 25463	: V=0.9676767, theta=-52.670027 -> V=1.0, theta=0.0
% INFO    : Bus 25464	: V=0.9679891, theta=-52.665409 -> V=1.0, theta=0.0
% INFO    : Bus 25465	: V=0.9675772, theta=-52.628004 -> V=1.0, theta=0.0
% INFO    : Bus 25466	: V=0.9633113, theta=-52.760859 -> V=1.0, theta=0.0
% INFO    : Bus 25467	: V=0.9666774, theta=-52.601631 -> V=1.0, theta=0.0
% INFO    : Bus 25468	: V=0.9673168, theta=-52.592569 -> V=1.0, theta=0.0
% INFO    : Bus 25469	: V=0.9868155, theta=-51.637235 -> V=1.0, theta=0.0
% INFO    : Bus 25470	: V=0.9988018, theta=-50.151454 -> V=1.0, theta=0.0
% INFO    : Bus 25471	: V=0.9873217, theta=-51.634806 -> V=1.0, theta=0.0
% INFO    : Bus 25472	: V=1.0000961, theta=-50.108233 -> V=1.0, theta=0.0
% INFO    : Bus 25473	: V=0.9866399, theta=-51.886824 -> V=1.0, theta=0.0
% INFO    : Bus 25474	: V=0.987011, theta=-51.881221 -> V=1.0, theta=0.0
% INFO    : Bus 25475	: V=1.0011964, theta=-50.06786 -> V=1.0, theta=0.0
% INFO    : Bus 25476	: V=0.9822222, theta=-51.947747 -> V=1.0, theta=0.0
% INFO    : Bus 25477	: V=0.9981278, theta=-50.165249 -> V=1.0, theta=0.0
% INFO    : Bus 25478	: V=0.9977583, theta=-50.166705 -> V=1.0, theta=0.0
% INFO    : Bus 25479	: V=0.9973414, theta=-50.203195 -> V=1.0, theta=0.0
% INFO    : Bus 25480	: V=0.9783304, theta=-52.26715 -> V=1.0, theta=0.0
% INFO    : Bus 25481	: V=0.9745992, theta=-52.572806 -> V=1.0, theta=0.0
% INFO    : Bus 25482	: V=0.9725666, theta=-52.665262 -> V=1.0, theta=0.0
% INFO    : Bus 25483	: V=0.9778264, theta=-52.291724 -> V=1.0, theta=0.0
% INFO    : Bus 25484	: V=0.9637855, theta=-52.659608 -> V=1.0, theta=0.0
% INFO    : Bus 25485	: V=0.9653764, theta=-52.539778 -> V=1.0, theta=0.0
% INFO    : Bus 25486	: V=0.9635852, theta=-52.549545 -> V=1.0, theta=0.0
% INFO    : Bus 25487	: V=0.9648525, theta=-52.612515 -> V=1.0, theta=0.0
% INFO    : Bus 25488	: V=0.9639531, theta=-52.699505 -> V=1.0, theta=0.0
% INFO    : Bus 25489	: V=0.9606207, theta=-52.247111 -> V=1.0, theta=0.0
% INFO    : Bus 25490	: V=0.9605643, theta=-52.25461 -> V=1.0, theta=0.0
% INFO    : Bus 25491	: V=0.9608048, theta=-52.219042 -> V=1.0, theta=0.0
% INFO    : Bus 25492	: V=0.9601558, theta=-52.276694 -> V=1.0, theta=0.0
% INFO    : Bus 25493	: V=0.9615445, theta=-51.547332 -> V=1.0, theta=0.0
% INFO    : Bus 25494	: V=0.9607288, theta=-52.717418 -> V=1.0, theta=0.0
% INFO    : Bus 25495	: V=0.9657103, theta=-49.05583 -> V=1.0, theta=0.0
% INFO    : Bus 25496	: V=0.9614722, theta=-52.627495 -> V=1.0, theta=0.0
% INFO    : Bus 25497	: V=0.9615422, theta=-51.937542 -> V=1.0, theta=0.0
% INFO    : Bus 25498	: V=0.9602592, theta=-52.641443 -> V=1.0, theta=0.0
% INFO    : Bus 25499	: V=0.9790288, theta=-52.453455 -> V=1.0, theta=0.0
% INFO    : Bus 25500	: V=0.9666217, theta=-53.561133 -> V=1.0, theta=0.0
% INFO    : Bus 25501	: V=0.9616357, theta=-51.738733 -> V=1.0, theta=0.0
% INFO    : Bus 25502	: V=0.9611828, theta=-52.055679 -> V=1.0, theta=0.0
% INFO    : Bus 25503	: V=0.9626489, theta=-52.548281 -> V=1.0, theta=0.0
% INFO    : Bus 25504	: V=0.9628424, theta=-52.539762 -> V=1.0, theta=0.0
% INFO    : Bus 25505	: V=0.9625964, theta=-52.529111 -> V=1.0, theta=0.0
% INFO    : Bus 25506	: V=0.9625823, theta=-52.509676 -> V=1.0, theta=0.0
% INFO    : Bus 25507	: V=0.9631775, theta=-52.447207 -> V=1.0, theta=0.0
% INFO    : Bus 25508	: V=0.9631919, theta=-52.388701 -> V=1.0, theta=0.0
% INFO    : Bus 25509	: V=0.9636064, theta=-52.372719 -> V=1.0, theta=0.0
% INFO    : Bus 25510	: V=0.9630794, theta=-52.567223 -> V=1.0, theta=0.0
% INFO    : Bus 25511	: V=0.9629333, theta=-52.56116 -> V=1.0, theta=0.0
% INFO    : Bus 25512	: V=0.9627223, theta=-52.543613 -> V=1.0, theta=0.0
% INFO    : Bus 25513	: V=0.9632203, theta=-52.510714 -> V=1.0, theta=0.0
% INFO    : Bus 25514	: V=0.9638321, theta=-51.37846 -> V=1.0, theta=0.0
% INFO    : Bus 25515	: V=0.9639048, theta=-51.367139 -> V=1.0, theta=0.0
% INFO    : Bus 25516	: V=0.964091, theta=-51.335186 -> V=1.0, theta=0.0
% INFO    : Bus 25517	: V=0.9642856, theta=-51.290451 -> V=1.0, theta=0.0
% INFO    : Bus 25518	: V=0.9645356, theta=-51.225647 -> V=1.0, theta=0.0
% INFO    : Bus 25519	: V=0.9645114, theta=-51.211788 -> V=1.0, theta=0.0
% INFO    : Bus 25520	: V=0.9645121, theta=-51.196187 -> V=1.0, theta=0.0
% INFO    : Bus 25521	: V=0.9641594, theta=-52.259442 -> V=1.0, theta=0.0
% INFO    : Bus 25522	: V=0.9640491, theta=-53.391495 -> V=1.0, theta=0.0
% INFO    : Bus 25523	: V=0.964558, theta=-53.543548 -> V=1.0, theta=0.0
% INFO    : Bus 25524	: V=0.9683638, theta=-53.035261 -> V=1.0, theta=0.0
% INFO    : Bus 25525	: V=0.9692158, theta=-53.006361 -> V=1.0, theta=0.0
% INFO    : Bus 25526	: V=0.9609816, theta=-52.422153 -> V=1.0, theta=0.0
% INFO    : Bus 25527	: V=0.9612971, theta=-52.17903 -> V=1.0, theta=0.0
% INFO    : Bus 25528	: V=0.9589072, theta=-53.491405 -> V=1.0, theta=0.0
% INFO    : Bus 25529	: V=0.9617393, theta=-51.928921 -> V=1.0, theta=0.0
% INFO    : Bus 25530	: V=0.9608642, theta=-52.937231 -> V=1.0, theta=0.0
% INFO    : Bus 25531	: V=0.9604326, theta=-53.091804 -> V=1.0, theta=0.0
% INFO    : Bus 25532	: V=0.9610967, theta=-52.181249 -> V=1.0, theta=0.0
% INFO    : Bus 25533	: V=0.9651589, theta=-53.604626 -> V=1.0, theta=0.0
% INFO    : Bus 25534	: V=0.9711704, theta=-52.916941 -> V=1.0, theta=0.0
% INFO    : Bus 25535	: V=0.9665433, theta=-53.686252 -> V=1.0, theta=0.0
% INFO    : Bus 25536	: V=0.9701327, theta=-52.967202 -> V=1.0, theta=0.0
% INFO    : Bus 25537	: V=0.9603708, theta=-53.725036 -> V=1.0, theta=0.0
% INFO    : Bus 25538	: V=0.9598059, theta=-53.283371 -> V=1.0, theta=0.0
% INFO    : Bus 25539	: V=0.961741, theta=-52.244464 -> V=1.0, theta=0.0
% INFO    : Bus 25540	: V=0.9581104, theta=-53.465023 -> V=1.0, theta=0.0
% INFO    : Bus 25541	: V=0.9574401, theta=-53.527886 -> V=1.0, theta=0.0
% INFO    : Bus 25542	: V=0.9586897, theta=-53.494865 -> V=1.0, theta=0.0
% INFO    : Bus 25543	: V=0.9697875, theta=-50.662284 -> V=1.0, theta=0.0
% INFO    : Bus 25544	: V=0.9686043, theta=-51.052 -> V=1.0, theta=0.0
% INFO    : Bus 25545	: V=0.9674272, theta=-51.290474 -> V=1.0, theta=0.0
% INFO    : Bus 25546	: V=0.9668382, theta=-51.930779 -> V=1.0, theta=0.0
% INFO    : Bus 25547	: V=0.9664826, theta=-52.296114 -> V=1.0, theta=0.0
% INFO    : Bus 25548	: V=0.9690843, theta=-51.352689 -> V=1.0, theta=0.0
% INFO    : Bus 25549	: V=0.969002, theta=-50.896504 -> V=1.0, theta=0.0
% INFO    : Bus 25550	: V=0.9676848, theta=-51.822032 -> V=1.0, theta=0.0
% INFO    : Bus 25551	: V=0.9659744, theta=-51.535189 -> V=1.0, theta=0.0
% INFO    : Bus 25552	: V=0.9654199, theta=-51.685179 -> V=1.0, theta=0.0
% INFO    : Bus 25553	: V=0.9583515, theta=-52.525024 -> V=1.0, theta=0.0
% INFO    : Bus 25554	: V=0.9582666, theta=-53.516342 -> V=1.0, theta=0.0
% INFO    : Bus 25555	: V=0.9599753, theta=-52.351253 -> V=1.0, theta=0.0
% INFO    : Bus 25556	: V=0.9603733, theta=-52.269033 -> V=1.0, theta=0.0
% INFO    : Bus 25557	: V=0.9600988, theta=-52.430827 -> V=1.0, theta=0.0
% INFO    : Bus 25558	: V=0.9597528, theta=-52.43945 -> V=1.0, theta=0.0
% INFO    : Bus 25559	: V=0.9672578, theta=-51.222513 -> V=1.0, theta=0.0
% INFO    : Bus 25560	: V=0.9627728, theta=-52.824523 -> V=1.0, theta=0.0
% INFO    : Bus 25561	: V=0.9630598, theta=-50.208125 -> V=1.0, theta=0.0
% INFO    : Bus 25562	: V=0.9596811, theta=-52.879321 -> V=1.0, theta=0.0
% INFO    : Bus 25563	: V=0.9600306, theta=-52.814845 -> V=1.0, theta=0.0
% INFO    : Bus 25564	: V=0.9605011, theta=-52.752568 -> V=1.0, theta=0.0
% INFO    : Bus 25565	: V=0.9607544, theta=-52.707465 -> V=1.0, theta=0.0
% INFO    : Bus 25566	: V=0.9614874, theta=-51.82173 -> V=1.0, theta=0.0
% INFO    : Bus 25567	: V=0.9611944, theta=-51.685274 -> V=1.0, theta=0.0
% INFO    : Bus 25568	: V=0.9616417, theta=-51.712605 -> V=1.0, theta=0.0
% INFO    : Bus 25569	: V=0.9596902, theta=-52.977541 -> V=1.0, theta=0.0
% INFO    : Bus 25570	: V=0.9602203, theta=-52.996855 -> V=1.0, theta=0.0
% INFO    : Bus 25571	: V=0.9602456, theta=-52.95229 -> V=1.0, theta=0.0
% INFO    : Bus 25572	: V=0.9606097, theta=-52.778836 -> V=1.0, theta=0.0
% INFO    : Bus 25573	: V=0.9615703, theta=-52.389666 -> V=1.0, theta=0.0
% INFO    : Bus 25574	: V=0.9610448, theta=-52.021428 -> V=1.0, theta=0.0
% INFO    : Bus 25575	: V=0.9595414, theta=-53.030112 -> V=1.0, theta=0.0
% INFO    : Bus 25576	: V=0.9608364, theta=-52.16898 -> V=1.0, theta=0.0
% INFO    : Bus 25577	: V=0.9602347, theta=-52.528787 -> V=1.0, theta=0.0
% INFO    : Bus 25578	: V=0.9594813, theta=-53.363505 -> V=1.0, theta=0.0
% INFO    : Bus 25579	: V=0.9595118, theta=-52.304715 -> V=1.0, theta=0.0
% INFO    : Bus 25580	: V=0.9590871, theta=-52.390124 -> V=1.0, theta=0.0
% INFO    : Bus 25581	: V=0.9602441, theta=-52.120854 -> V=1.0, theta=0.0
% INFO    : Bus 25582	: V=0.9590655, theta=-53.17732 -> V=1.0, theta=0.0
% INFO    : Bus 25583	: V=0.9601728, theta=-53.203584 -> V=1.0, theta=0.0
% INFO    : Bus 25584	: V=0.9602314, theta=-52.894917 -> V=1.0, theta=0.0
% INFO    : Bus 25585	: V=0.9611919, theta=-52.397114 -> V=1.0, theta=0.0
% INFO    : Bus 25586	: V=0.9604619, theta=-53.083181 -> V=1.0, theta=0.0
% INFO    : Bus 25587	: V=0.9599627, theta=-53.192006 -> V=1.0, theta=0.0
% INFO    : Bus 25588	: V=0.9604666, theta=-52.495021 -> V=1.0, theta=0.0
% INFO    : Bus 25589	: V=0.9588619, theta=-53.487672 -> V=1.0, theta=0.0
% INFO    : Bus 25590	: V=0.957701, theta=-53.505845 -> V=1.0, theta=0.0
% INFO    : Bus 25591	: V=0.9777455, theta=-52.409464 -> V=1.0, theta=0.0
% INFO    : Bus 25592	: V=0.9720723, theta=-52.884361 -> V=1.0, theta=0.0
% INFO    : Bus 25593	: V=0.9707963, theta=-52.919521 -> V=1.0, theta=0.0
% INFO    : Bus 25594	: V=0.9659256, theta=-52.35144 -> V=1.0, theta=0.0
% INFO    : Bus 25595	: V=0.9662546, theta=-52.199772 -> V=1.0, theta=0.0
% INFO    : Bus 25596	: V=0.9635592, theta=-52.562357 -> V=1.0, theta=0.0
% INFO    : Bus 25597	: V=0.9647302, theta=-52.495573 -> V=1.0, theta=0.0
% INFO    : Bus 25598	: V=0.9626273, theta=-51.144393 -> V=1.0, theta=0.0
% INFO    : Bus 25599	: V=0.9618872, theta=-51.740491 -> V=1.0, theta=0.0
% INFO    : Bus 25600	: V=0.961644, theta=-51.938281 -> V=1.0, theta=0.0
% INFO    : Bus 25601	: V=0.9613581, theta=-52.135854 -> V=1.0, theta=0.0
% INFO    : Bus 25602	: V=0.9607183, theta=-52.705947 -> V=1.0, theta=0.0
% INFO    : Bus 25603	: V=0.9595338, theta=-52.928799 -> V=1.0, theta=0.0
% INFO    : Bus 25604	: V=0.9578794, theta=-53.250428 -> V=1.0, theta=0.0
% INFO    : Bus 25605	: V=0.9600829, theta=-51.854298 -> V=1.0, theta=0.0
% INFO    : Bus 25606	: V=0.9601123, theta=-51.822778 -> V=1.0, theta=0.0
% INFO    : Bus 25607	: V=0.9580782, theta=-53.22034 -> V=1.0, theta=0.0
% INFO    : Bus 25608	: V=0.958492, theta=-52.989313 -> V=1.0, theta=0.0
% INFO    : Bus 25609	: V=0.9579789, theta=-52.932703 -> V=1.0, theta=0.0
% INFO    : Bus 25610	: V=0.958057, theta=-53.023501 -> V=1.0, theta=0.0
% INFO    : Bus 25611	: V=0.9580315, theta=-53.187912 -> V=1.0, theta=0.0
% INFO    : Bus 25612	: V=0.9579894, theta=-53.093842 -> V=1.0, theta=0.0
% INFO    : Bus 25613	: V=0.9582606, theta=-54.45713 -> V=1.0, theta=0.0
% INFO    : Bus 25614	: V=0.9707459, theta=-50.177631 -> V=1.0, theta=0.0
% INFO    : Bus 25615	: V=0.9577756, theta=-54.900134 -> V=1.0, theta=0.0
% INFO    : Bus 25616	: V=0.9591963, theta=-54.834535 -> V=1.0, theta=0.0
% INFO    : Bus 25617	: V=0.9602169, theta=-53.87907 -> V=1.0, theta=0.0
% INFO    : Bus 25618	: V=0.9651773, theta=-53.038015 -> V=1.0, theta=0.0
% INFO    : Bus 25619	: V=0.963773, theta=-53.175955 -> V=1.0, theta=0.0
% INFO    : Bus 25620	: V=0.96312, theta=-53.146964 -> V=1.0, theta=0.0
% INFO    : Bus 25621	: V=0.9638381, theta=-53.247236 -> V=1.0, theta=0.0
% INFO    : Bus 25622	: V=0.9621872, theta=-53.047616 -> V=1.0, theta=0.0
% INFO    : Bus 25623	: V=0.9625604, theta=-53.094918 -> V=1.0, theta=0.0
% INFO    : Bus 25624	: V=0.9680093, theta=-53.036086 -> V=1.0, theta=0.0
% INFO    : Bus 25625	: V=0.9587338, theta=-53.559832 -> V=1.0, theta=0.0
% INFO    : Bus 25626	: V=0.9570412, theta=-53.572669 -> V=1.0, theta=0.0
% INFO    : Bus 25627	: V=0.9596435, theta=-53.391511 -> V=1.0, theta=0.0
% INFO    : Bus 25628	: V=0.956753, theta=-53.67493 -> V=1.0, theta=0.0
% INFO    : Bus 25629	: V=0.9570129, theta=-53.647582 -> V=1.0, theta=0.0
% INFO    : Bus 25630	: V=0.9611768, theta=-52.289904 -> V=1.0, theta=0.0
% INFO    : Bus 25631	: V=0.9589475, theta=-53.856797 -> V=1.0, theta=0.0
% INFO    : Bus 25632	: V=0.9586552, theta=-53.721025 -> V=1.0, theta=0.0
% INFO    : Bus 25633	: V=0.9602158, theta=-53.434414 -> V=1.0, theta=0.0
% INFO    : Bus 25634	: V=0.9630255, theta=-49.6854 -> V=1.0, theta=0.0
% INFO    : Bus 25635	: V=0.9607428, theta=-53.071436 -> V=1.0, theta=0.0
% INFO    : Bus 25636	: V=0.9594953, theta=-53.044303 -> V=1.0, theta=0.0
% INFO    : Bus 25637	: V=0.9595655, theta=-53.113484 -> V=1.0, theta=0.0
% INFO    : Bus 25638	: V=0.9593743, theta=-53.226427 -> V=1.0, theta=0.0
% INFO    : Bus 25639	: V=0.9582495, theta=-53.224954 -> V=1.0, theta=0.0
% INFO    : Bus 25640	: V=0.9586495, theta=-53.307911 -> V=1.0, theta=0.0
% INFO    : Bus 25641	: V=0.9642514, theta=-53.306229 -> V=1.0, theta=0.0
% INFO    : Bus 25642	: V=0.9639279, theta=-53.336309 -> V=1.0, theta=0.0
% INFO    : Bus 25643	: V=0.963319, theta=-53.376481 -> V=1.0, theta=0.0
% INFO    : Bus 25644	: V=0.97242, theta=-50.324383 -> V=1.0, theta=0.0
% INFO    : Bus 25645	: V=0.9718074, theta=-50.408506 -> V=1.0, theta=0.0
% INFO    : Bus 25646	: V=0.9705167, theta=-50.675339 -> V=1.0, theta=0.0
% INFO    : Bus 25647	: V=0.9695292, theta=-50.873342 -> V=1.0, theta=0.0
% INFO    : Bus 25648	: V=0.9744378, theta=-49.905598 -> V=1.0, theta=0.0
% INFO    : Bus 25649	: V=0.9723283, theta=-50.313009 -> V=1.0, theta=0.0
% INFO    : Bus 25650	: V=0.9682326, theta=-51.748668 -> V=1.0, theta=0.0
% INFO    : Bus 25651	: V=0.9644115, theta=-52.463896 -> V=1.0, theta=0.0
% INFO    : Bus 25652	: V=0.9668941, theta=-52.007271 -> V=1.0, theta=0.0
% INFO    : Bus 25653	: V=0.9688129, theta=-50.929264 -> V=1.0, theta=0.0
% INFO    : Bus 25654	: V=0.9626143, theta=-51.152464 -> V=1.0, theta=0.0
% INFO    : Bus 25655	: V=0.969415, theta=-52.52636 -> V=1.0, theta=0.0
% INFO    : Bus 25656	: V=0.9603211, theta=-52.787613 -> V=1.0, theta=0.0
% INFO    : Bus 25657	: V=0.9588969, theta=-53.413577 -> V=1.0, theta=0.0
% INFO    : Bus 25658	: V=0.9585522, theta=-53.518504 -> V=1.0, theta=0.0
% INFO    : Bus 25659	: V=0.9599937, theta=-52.668085 -> V=1.0, theta=0.0
% INFO    : Bus 25660	: V=0.9747803, theta=-52.72476 -> V=1.0, theta=0.0
% INFO    : Bus 25661	: V=0.9681209, theta=-53.78935 -> V=1.0, theta=0.0
% INFO    : Bus 25662	: V=0.9588324, theta=-53.515043 -> V=1.0, theta=0.0
% INFO    : Bus 25663	: V=0.9577465, theta=-54.049603 -> V=1.0, theta=0.0
% INFO    : Bus 25664	: V=0.960574, theta=-52.773889 -> V=1.0, theta=0.0
% INFO    : Bus 25665	: V=0.9574761, theta=-54.887633 -> V=1.0, theta=0.0
% INFO    : Bus 25666	: V=0.9565372, theta=-54.538752 -> V=1.0, theta=0.0
% INFO    : Bus 25667	: V=0.9581269, theta=-54.932591 -> V=1.0, theta=0.0
% INFO    : Bus 25668	: V=0.963721, theta=-52.921259 -> V=1.0, theta=0.0
% INFO    : Bus 25669	: V=0.9692704, theta=-39.4895 -> V=1.0, theta=0.0
% INFO    : Bus 25670	: V=0.9882203, theta=-52.011769 -> V=1.0, theta=0.0
% INFO    : Bus 25671	: V=0.9573201, theta=-54.619369 -> V=1.0, theta=0.0
% INFO    : Bus 25672	: V=0.9623203, theta=-52.651518 -> V=1.0, theta=0.0
% INFO    : Bus 25673	: V=0.9632877, theta=-52.308259 -> V=1.0, theta=0.0
% INFO    : Bus 25674	: V=0.9684691, theta=-50.797979 -> V=1.0, theta=0.0
% INFO    : Bus 25675	: V=0.9637067, theta=-51.976291 -> V=1.0, theta=0.0
% INFO    : Bus 25676	: V=0.9631967, theta=-51.982538 -> V=1.0, theta=0.0
% INFO    : Bus 25677	: V=0.9674732, theta=-30.895261 -> V=1.0, theta=0.0
% INFO    : Bus 25678	: V=0.9588255, theta=-29.407796 -> V=1.0, theta=0.0
% INFO    : Bus 25679	: V=0.972311, theta=-30.547989 -> V=1.0, theta=0.0
% INFO    : Bus 25680	: V=0.963532, theta=-31.953145 -> V=1.0, theta=0.0
% INFO    : Bus 25681	: V=0.9683533, theta=-31.678307 -> V=1.0, theta=0.0
% INFO    : Bus 25682	: V=0.9688022, theta=-29.818136 -> V=1.0, theta=0.0
% INFO    : Bus 25683	: V=0.9783882, theta=-30.056612 -> V=1.0, theta=0.0
% INFO    : Bus 25684	: V=0.981619, theta=-29.486475 -> V=1.0, theta=0.0
% INFO    : Bus 25685	: V=0.9806238, theta=-29.852578 -> V=1.0, theta=0.0
% INFO    : Bus 25686	: V=0.9624321, theta=-29.985196 -> V=1.0, theta=0.0
% INFO    : Bus 25687	: V=0.9791015, theta=-29.565076 -> V=1.0, theta=0.0
% INFO    : Bus 25688	: V=0.9784813, theta=-29.196804 -> V=1.0, theta=0.0
% INFO    : Bus 25689	: V=1.0104104, theta=-25.368344 -> V=1.0, theta=0.0
% INFO    : Bus 25690	: V=0.9516526, theta=-29.276874 -> V=1.0, theta=0.0
% INFO    : Bus 25691	: V=0.9502814, theta=-28.475853 -> V=1.0, theta=0.0
% INFO    : Bus 25692	: V=0.959802, theta=-28.930228 -> V=1.0, theta=0.0
% INFO    : Bus 25693	: V=0.9943766, theta=-27.379766 -> V=1.0, theta=0.0
% INFO    : Bus 25694	: V=0.9917423, theta=-26.986634 -> V=1.0, theta=0.0
% INFO    : Bus 25695	: V=0.9887148, theta=-27.579058 -> V=1.0, theta=0.0
% INFO    : Bus 25696	: V=0.9990575, theta=-26.795812 -> V=1.0, theta=0.0
% INFO    : Bus 25697	: V=0.983157, theta=-27.638921 -> V=1.0, theta=0.0
% INFO    : Bus 25698	: V=0.9586796, theta=-43.668977 -> V=1.0, theta=0.0
% INFO    : Bus 25699	: V=0.9583266, theta=-43.715801 -> V=1.0, theta=0.0
% INFO    : Bus 25700	: V=0.9602369, theta=-43.81786 -> V=1.0, theta=0.0
% INFO    : Bus 25701	: V=0.9615859, theta=-43.730286 -> V=1.0, theta=0.0
% INFO    : Bus 25702	: V=0.9646581, theta=-42.535449 -> V=1.0, theta=0.0
% INFO    : Bus 25703	: V=0.9726204, theta=-41.03932 -> V=1.0, theta=0.0
% INFO    : Bus 25704	: V=0.9591771, theta=-43.594338 -> V=1.0, theta=0.0
% INFO    : Bus 25705	: V=0.9546666, theta=-45.323752 -> V=1.0, theta=0.0
% INFO    : Bus 25706	: V=0.957031, theta=-46.296834 -> V=1.0, theta=0.0
% INFO    : Bus 25707	: V=0.9569804, theta=-44.334423 -> V=1.0, theta=0.0
% INFO    : Bus 25708	: V=0.9581413, theta=-43.293322 -> V=1.0, theta=0.0
% INFO    : Bus 25709	: V=0.9528669, theta=-43.468797 -> V=1.0, theta=0.0
% INFO    : Bus 25710	: V=0.9647531, theta=-42.656932 -> V=1.0, theta=0.0
% INFO    : Bus 25711	: V=0.9573669, theta=-44.275864 -> V=1.0, theta=0.0
% INFO    : Bus 25712	: V=0.9600938, theta=-43.21431 -> V=1.0, theta=0.0
% INFO    : Bus 25713	: V=0.9621513, theta=-42.794751 -> V=1.0, theta=0.0
% INFO    : Bus 25714	: V=0.958497, theta=-43.413722 -> V=1.0, theta=0.0
% INFO    : Bus 25715	: V=0.9572337, theta=-44.498502 -> V=1.0, theta=0.0
% INFO    : Bus 25716	: V=0.9545913, theta=-45.035841 -> V=1.0, theta=0.0
% INFO    : Bus 25717	: V=0.9625972, theta=-43.172041 -> V=1.0, theta=0.0
% INFO    : Bus 25718	: V=0.9582537, theta=-44.284613 -> V=1.0, theta=0.0
% INFO    : Bus 25719	: V=0.9579741, theta=-43.462423 -> V=1.0, theta=0.0
% INFO    : Bus 25720	: V=0.9552308, theta=-44.922157 -> V=1.0, theta=0.0
% INFO    : Bus 25721	: V=0.9540142, theta=-45.192972 -> V=1.0, theta=0.0
% INFO    : Bus 25722	: V=0.9556205, theta=-44.724043 -> V=1.0, theta=0.0
% INFO    : Bus 25723	: V=0.9538606, theta=-45.230748 -> V=1.0, theta=0.0
% INFO    : Bus 25724	: V=0.9543834, theta=-45.146745 -> V=1.0, theta=0.0
% INFO    : Bus 25725	: V=0.9520517, theta=-45.180573 -> V=1.0, theta=0.0
% INFO    : Bus 25726	: V=0.9559823, theta=-44.61863 -> V=1.0, theta=0.0
% INFO    : Bus 25727	: V=0.9714413, theta=-40.963161 -> V=1.0, theta=0.0
% INFO    : Bus 25728	: V=0.9563168, theta=-44.203784 -> V=1.0, theta=0.0
% INFO    : Bus 25729	: V=0.9721706, theta=-41.047227 -> V=1.0, theta=0.0
% INFO    : Bus 25730	: V=0.9597273, theta=-43.525113 -> V=1.0, theta=0.0
% INFO    : Bus 25731	: V=0.9555144, theta=-46.120526 -> V=1.0, theta=0.0
% INFO    : Bus 25732	: V=0.955864, theta=-43.882068 -> V=1.0, theta=0.0
% INFO    : Bus 25733	: V=0.982454, theta=-45.006438 -> V=1.0, theta=0.0
% INFO    : Bus 25734	: V=0.980484, theta=-44.744305 -> V=1.0, theta=0.0
% INFO    : Bus 25735	: V=0.9778596, theta=-44.322859 -> V=1.0, theta=0.0
% INFO    : Bus 25736	: V=0.989708, theta=-40.89419 -> V=1.0, theta=0.0
% INFO    : Bus 25737	: V=0.9788171, theta=-42.765804 -> V=1.0, theta=0.0
% INFO    : Bus 25738	: V=0.973964, theta=-39.954666 -> V=1.0, theta=0.0
% INFO    : Bus 25739	: V=0.9742633, theta=-41.53455 -> V=1.0, theta=0.0
% INFO    : Bus 25740	: V=0.9740001, theta=-41.275405 -> V=1.0, theta=0.0
% INFO    : Bus 25741	: V=0.9884031, theta=-38.523218 -> V=1.0, theta=0.0
% INFO    : Bus 25742	: V=0.9815995, theta=-39.993733 -> V=1.0, theta=0.0
% INFO    : Bus 25743	: V=0.9810266, theta=-40.140283 -> V=1.0, theta=0.0
% INFO    : Bus 25744	: V=0.9807858, theta=-40.335018 -> V=1.0, theta=0.0
% INFO    : Bus 25745	: V=0.9879824, theta=-39.31309 -> V=1.0, theta=0.0
% INFO    : Bus 25746	: V=0.9803399, theta=-40.671369 -> V=1.0, theta=0.0
% INFO    : Bus 25747	: V=0.9883904, theta=-39.795526 -> V=1.0, theta=0.0
% INFO    : Bus 25748	: V=0.9787213, theta=-41.374571 -> V=1.0, theta=0.0
% INFO    : Bus 25749	: V=0.9798481, theta=-39.923246 -> V=1.0, theta=0.0
% INFO    : Bus 25750	: V=0.9766884, theta=-42.427775 -> V=1.0, theta=0.0
% INFO    : Bus 25751	: V=0.9834841, theta=-40.153233 -> V=1.0, theta=0.0
% INFO    : Bus 25752	: V=0.9847276, theta=-39.294959 -> V=1.0, theta=0.0
% INFO    : Bus 25753	: V=0.9812389, theta=-40.010448 -> V=1.0, theta=0.0
% INFO    : Bus 25754	: V=0.9805275, theta=-39.946474 -> V=1.0, theta=0.0
% INFO    : Bus 25755	: V=0.9677115, theta=-41.312391 -> V=1.0, theta=0.0
% INFO    : Bus 25756	: V=0.9692094, theta=-40.809786 -> V=1.0, theta=0.0
% INFO    : Bus 25757	: V=0.9724001, theta=-40.28514 -> V=1.0, theta=0.0
% INFO    : Bus 25758	: V=0.9784479, theta=-39.443882 -> V=1.0, theta=0.0
% INFO    : Bus 25759	: V=0.9889672, theta=-38.619362 -> V=1.0, theta=0.0
% INFO    : Bus 25760	: V=0.9676726, theta=-40.043018 -> V=1.0, theta=0.0
% INFO    : Bus 25761	: V=0.9908849, theta=-37.15648 -> V=1.0, theta=0.0
% INFO    : Bus 25762	: V=0.9894858, theta=-37.925707 -> V=1.0, theta=0.0
% INFO    : Bus 25763	: V=0.9745441, theta=-39.368079 -> V=1.0, theta=0.0
% INFO    : Bus 25764	: V=0.9804364, theta=-38.769445 -> V=1.0, theta=0.0
% INFO    : Bus 25765	: V=0.9729813, theta=-39.329665 -> V=1.0, theta=0.0
% INFO    : Bus 25766	: V=0.9811516, theta=-38.545546 -> V=1.0, theta=0.0
% INFO    : Bus 25767	: V=0.974934, theta=-39.259113 -> V=1.0, theta=0.0
% INFO    : Bus 25768	: V=0.9750145, theta=-39.299099 -> V=1.0, theta=0.0
% INFO    : Bus 25769	: V=0.97573, theta=-39.191642 -> V=1.0, theta=0.0
% INFO    : Bus 25770	: V=0.9822614, theta=-38.227688 -> V=1.0, theta=0.0
% INFO    : Bus 25771	: V=0.9893042, theta=-36.820746 -> V=1.0, theta=0.0
% INFO    : Bus 25772	: V=0.9761436, theta=-37.771688 -> V=1.0, theta=0.0
% INFO    : Bus 25773	: V=0.9574134, theta=-43.410205 -> V=1.0, theta=0.0
% INFO    : Bus 25774	: V=0.963403, theta=-42.366197 -> V=1.0, theta=0.0
% INFO    : Bus 25775	: V=0.9574924, theta=-43.404088 -> V=1.0, theta=0.0
% INFO    : Bus 25776	: V=0.9670362, theta=-41.585113 -> V=1.0, theta=0.0
% INFO    : Bus 25777	: V=0.9689825, theta=-41.025045 -> V=1.0, theta=0.0
% INFO    : Bus 25778	: V=0.9672108, theta=-41.44104 -> V=1.0, theta=0.0
% INFO    : Bus 25779	: V=0.9752916, theta=-36.032677 -> V=1.0, theta=0.0
% INFO    : Bus 25780	: V=0.9743238, theta=-33.549685 -> V=1.0, theta=0.0
% INFO    : Bus 25781	: V=0.9618844, theta=-35.86136 -> V=1.0, theta=0.0
% INFO    : Bus 25782	: V=0.9636497, theta=-35.562378 -> V=1.0, theta=0.0
% INFO    : Bus 25783	: V=0.9772201, theta=-34.798604 -> V=1.0, theta=0.0
% INFO    : Bus 25784	: V=0.9797345, theta=-34.260524 -> V=1.0, theta=0.0
% INFO    : Bus 25785	: V=0.9893086, theta=-32.936384 -> V=1.0, theta=0.0
% INFO    : Bus 25786	: V=0.9561832, theta=-44.335256 -> V=1.0, theta=0.0
% INFO    : Bus 25787	: V=0.9566341, theta=-44.074875 -> V=1.0, theta=0.0
% INFO    : Bus 25788	: V=0.9559709, theta=-43.978221 -> V=1.0, theta=0.0
% INFO    : Bus 25789	: V=0.9563426, theta=-43.962373 -> V=1.0, theta=0.0
% INFO    : Bus 25790	: V=0.9582762, theta=-43.119261 -> V=1.0, theta=0.0
% INFO    : Bus 25791	: V=0.9581217, theta=-43.155524 -> V=1.0, theta=0.0
% INFO    : Bus 25792	: V=0.9583018, theta=-43.117801 -> V=1.0, theta=0.0
% INFO    : Bus 25793	: V=0.955983, theta=-43.92814 -> V=1.0, theta=0.0
% INFO    : Bus 25794	: V=0.9585894, theta=-43.055163 -> V=1.0, theta=0.0
% INFO    : Bus 25795	: V=0.9588587, theta=-43.008859 -> V=1.0, theta=0.0
% INFO    : Bus 25796	: V=0.9591105, theta=-42.965055 -> V=1.0, theta=0.0
% INFO    : Bus 25797	: V=0.9570524, theta=-43.451872 -> V=1.0, theta=0.0
% INFO    : Bus 25798	: V=0.9576518, theta=-43.446341 -> V=1.0, theta=0.0
% INFO    : Bus 25799	: V=0.9590581, theta=-42.97115 -> V=1.0, theta=0.0
% INFO    : Bus 25800	: V=0.9584638, theta=-43.089655 -> V=1.0, theta=0.0
% INFO    : Bus 25801	: V=0.957931, theta=-43.557644 -> V=1.0, theta=0.0
% INFO    : Bus 25802	: V=0.9587595, theta=-43.035178 -> V=1.0, theta=0.0
% INFO    : Bus 25803	: V=0.9576915, theta=-43.537086 -> V=1.0, theta=0.0
% INFO    : Bus 25804	: V=0.9594344, theta=-42.910073 -> V=1.0, theta=0.0
% INFO    : Bus 25805	: V=0.9572393, theta=-43.425376 -> V=1.0, theta=0.0
% INFO    : Bus 25806	: V=0.9575172, theta=-43.400475 -> V=1.0, theta=0.0
% INFO    : Bus 25807	: V=0.9610076, theta=-42.686867 -> V=1.0, theta=0.0
% INFO    : Bus 25808	: V=0.9597965, theta=-42.850971 -> V=1.0, theta=0.0
% INFO    : Bus 25809	: V=0.9601835, theta=-42.792089 -> V=1.0, theta=0.0
% INFO    : Bus 25810	: V=0.9585181, theta=-43.363457 -> V=1.0, theta=0.0
% INFO    : Bus 25811	: V=0.9595008, theta=-42.884511 -> V=1.0, theta=0.0
% INFO    : Bus 25812	: V=0.9607813, theta=-42.704178 -> V=1.0, theta=0.0
% INFO    : Bus 25813	: V=0.9580782, theta=-43.413346 -> V=1.0, theta=0.0
% INFO    : Bus 25814	: V=0.9556645, theta=-43.500028 -> V=1.0, theta=0.0
% INFO    : Bus 25815	: V=0.9560842, theta=-43.488184 -> V=1.0, theta=0.0
% INFO    : Bus 25816	: V=0.9579322, theta=-43.363257 -> V=1.0, theta=0.0
% INFO    : Bus 25817	: V=0.9622679, theta=-42.461977 -> V=1.0, theta=0.0
% INFO    : Bus 25818	: V=0.9565409, theta=-43.408281 -> V=1.0, theta=0.0
% INFO    : Bus 25819	: V=0.9574121, theta=-43.38349 -> V=1.0, theta=0.0
% INFO    : Bus 25820	: V=0.9620114, theta=-42.475571 -> V=1.0, theta=0.0
% INFO    : Bus 25821	: V=0.9599047, theta=-42.801349 -> V=1.0, theta=0.0
% INFO    : Bus 25822	: V=0.9604173, theta=-42.744203 -> V=1.0, theta=0.0
% INFO    : Bus 25823	: V=0.9607211, theta=-42.696248 -> V=1.0, theta=0.0
% INFO    : Bus 25824	: V=0.9606328, theta=-43.339705 -> V=1.0, theta=0.0
% INFO    : Bus 25825	: V=0.9568981, theta=-43.480358 -> V=1.0, theta=0.0
% INFO    : Bus 25826	: V=0.9572862, theta=-43.503332 -> V=1.0, theta=0.0
% INFO    : Bus 25827	: V=0.9572867, theta=-43.469163 -> V=1.0, theta=0.0
% INFO    : Bus 25828	: V=0.9571393, theta=-43.507721 -> V=1.0, theta=0.0
% INFO    : Bus 25829	: V=0.961718, theta=-42.725674 -> V=1.0, theta=0.0
% INFO    : Bus 25830	: V=0.957167, theta=-43.454233 -> V=1.0, theta=0.0
% INFO    : Bus 25831	: V=0.9594286, theta=-43.040877 -> V=1.0, theta=0.0
% INFO    : Bus 25832	: V=0.9592438, theta=-43.268118 -> V=1.0, theta=0.0
% INFO    : Bus 25833	: V=0.9602634, theta=-42.733125 -> V=1.0, theta=0.0
% INFO    : Bus 25834	: V=0.9682567, theta=-40.913998 -> V=1.0, theta=0.0
% INFO    : Bus 25835	: V=0.9621838, theta=-42.462991 -> V=1.0, theta=0.0
% INFO    : Bus 25836	: V=0.9606847, theta=-42.656713 -> V=1.0, theta=0.0
% INFO    : Bus 25837	: V=0.9609842, theta=-42.657229 -> V=1.0, theta=0.0
% INFO    : Bus 25838	: V=0.9610387, theta=-42.595152 -> V=1.0, theta=0.0
% INFO    : Bus 25839	: V=0.9623417, theta=-42.402237 -> V=1.0, theta=0.0
% INFO    : Bus 25840	: V=0.9571841, theta=-43.175861 -> V=1.0, theta=0.0
% INFO    : Bus 25841	: V=0.9687846, theta=-40.732065 -> V=1.0, theta=0.0
% INFO    : Bus 25842	: V=0.9598147, theta=-42.465734 -> V=1.0, theta=0.0
% INFO    : Bus 25843	: V=0.9640211, theta=-41.74412 -> V=1.0, theta=0.0
% INFO    : Bus 25844	: V=0.9609299, theta=-42.389697 -> V=1.0, theta=0.0
% INFO    : Bus 25845	: V=0.9603215, theta=-42.435555 -> V=1.0, theta=0.0
% INFO    : Bus 25846	: V=0.963605, theta=-41.817512 -> V=1.0, theta=0.0
% INFO    : Bus 25847	: V=0.9632808, theta=-41.868091 -> V=1.0, theta=0.0
% INFO    : Bus 25848	: V=0.958821, theta=-42.60172 -> V=1.0, theta=0.0
% INFO    : Bus 25849	: V=0.9572299, theta=-43.069367 -> V=1.0, theta=0.0
% INFO    : Bus 25850	: V=0.9578045, theta=-42.928114 -> V=1.0, theta=0.0
% INFO    : Bus 25851	: V=0.9623763, theta=-42.37569 -> V=1.0, theta=0.0
% INFO    : Bus 25852	: V=0.9615198, theta=-42.511164 -> V=1.0, theta=0.0
% INFO    : Bus 25853	: V=0.9613193, theta=-42.607755 -> V=1.0, theta=0.0
% INFO    : Bus 25854	: V=0.9615484, theta=-42.574363 -> V=1.0, theta=0.0
% INFO    : Bus 25855	: V=0.96191, theta=-42.522107 -> V=1.0, theta=0.0
% INFO    : Bus 25856	: V=0.962151, theta=-42.406396 -> V=1.0, theta=0.0
% INFO    : Bus 25857	: V=0.9626073, theta=-42.329717 -> V=1.0, theta=0.0
% INFO    : Bus 25858	: V=0.9625779, theta=-42.327764 -> V=1.0, theta=0.0
% INFO    : Bus 25859	: V=0.9586749, theta=-42.920627 -> V=1.0, theta=0.0
% INFO    : Bus 25860	: V=0.9629818, theta=-42.220569 -> V=1.0, theta=0.0
% INFO    : Bus 25861	: V=0.9627515, theta=-42.328534 -> V=1.0, theta=0.0
% INFO    : Bus 25862	: V=0.9630017, theta=-42.24457 -> V=1.0, theta=0.0
% INFO    : Bus 25863	: V=0.9632664, theta=-42.160434 -> V=1.0, theta=0.0
% INFO    : Bus 25864	: V=0.961815, theta=-42.278107 -> V=1.0, theta=0.0
% INFO    : Bus 25865	: V=0.9707208, theta=-40.660046 -> V=1.0, theta=0.0
% INFO    : Bus 25866	: V=0.9607031, theta=-42.613959 -> V=1.0, theta=0.0
% INFO    : Bus 25867	: V=0.9628098, theta=-42.530586 -> V=1.0, theta=0.0
% INFO    : Bus 25868	: V=0.9566558, theta=-44.001949 -> V=1.0, theta=0.0
% INFO    : Bus 25869	: V=0.9588617, theta=-43.658222 -> V=1.0, theta=0.0
% INFO    : Bus 25870	: V=0.9681977, theta=-40.868465 -> V=1.0, theta=0.0
% INFO    : Bus 25871	: V=0.9620654, theta=-42.641899 -> V=1.0, theta=0.0
% INFO    : Bus 25872	: V=0.9559596, theta=-44.190402 -> V=1.0, theta=0.0
% INFO    : Bus 25873	: V=0.9564035, theta=-44.137389 -> V=1.0, theta=0.0
% INFO    : Bus 25874	: V=0.9559167, theta=-44.206127 -> V=1.0, theta=0.0
% INFO    : Bus 25875	: V=0.9605476, theta=-42.869795 -> V=1.0, theta=0.0
% INFO    : Bus 25876	: V=0.9610272, theta=-42.793027 -> V=1.0, theta=0.0
% INFO    : Bus 25877	: V=0.9603894, theta=-42.942726 -> V=1.0, theta=0.0
% INFO    : Bus 25878	: V=0.9601471, theta=-42.958019 -> V=1.0, theta=0.0
% INFO    : Bus 25879	: V=0.9602576, theta=-42.925634 -> V=1.0, theta=0.0
% INFO    : Bus 25880	: V=0.9596211, theta=-42.953063 -> V=1.0, theta=0.0
% INFO    : Bus 25881	: V=0.9594139, theta=-43.018675 -> V=1.0, theta=0.0
% INFO    : Bus 25882	: V=0.9572673, theta=-43.98014 -> V=1.0, theta=0.0
% INFO    : Bus 25883	: V=0.9599331, theta=-42.980087 -> V=1.0, theta=0.0
% INFO    : Bus 25884	: V=0.9596923, theta=-42.998741 -> V=1.0, theta=0.0
% INFO    : Bus 25885	: V=0.9614565, theta=-42.725293 -> V=1.0, theta=0.0
% INFO    : Bus 25886	: V=0.9601279, theta=-42.847203 -> V=1.0, theta=0.0
% INFO    : Bus 25887	: V=0.9577723, theta=-43.622332 -> V=1.0, theta=0.0
% INFO    : Bus 25888	: V=0.9683102, theta=-40.841543 -> V=1.0, theta=0.0
% INFO    : Bus 25889	: V=0.9625205, theta=-42.441886 -> V=1.0, theta=0.0
% INFO    : Bus 25890	: V=0.9623695, theta=-42.454757 -> V=1.0, theta=0.0
% INFO    : Bus 25891	: V=0.9557656, theta=-44.397229 -> V=1.0, theta=0.0
% INFO    : Bus 25892	: V=0.9566681, theta=-44.220261 -> V=1.0, theta=0.0
% INFO    : Bus 25893	: V=0.9572436, theta=-43.534723 -> V=1.0, theta=0.0
% INFO    : Bus 25894	: V=0.9559328, theta=-44.384483 -> V=1.0, theta=0.0
% INFO    : Bus 25895	: V=0.9564205, theta=-44.308586 -> V=1.0, theta=0.0
% INFO    : Bus 25896	: V=0.9561456, theta=-44.3631 -> V=1.0, theta=0.0
% INFO    : Bus 25897	: V=0.9554166, theta=-44.413922 -> V=1.0, theta=0.0
% INFO    : Bus 25898	: V=0.9572089, theta=-43.456024 -> V=1.0, theta=0.0
% INFO    : Bus 25899	: V=0.9572925, theta=-43.415096 -> V=1.0, theta=0.0
% INFO    : Bus 25900	: V=0.9574709, theta=-43.351398 -> V=1.0, theta=0.0
% INFO    : Bus 25901	: V=0.9583155, theta=-44.003758 -> V=1.0, theta=0.0
% INFO    : Bus 25902	: V=0.9587854, theta=-43.883423 -> V=1.0, theta=0.0
% INFO    : Bus 25903	: V=0.9591973, theta=-43.774423 -> V=1.0, theta=0.0
% INFO    : Bus 25904	: V=0.9553469, theta=-44.653369 -> V=1.0, theta=0.0
% INFO    : Bus 25905	: V=0.9549899, theta=-44.612643 -> V=1.0, theta=0.0
% INFO    : Bus 25906	: V=0.955723, theta=-44.678573 -> V=1.0, theta=0.0
% INFO    : Bus 25907	: V=0.9577736, theta=-44.128496 -> V=1.0, theta=0.0
% INFO    : Bus 25908	: V=0.9557956, theta=-44.338437 -> V=1.0, theta=0.0
% INFO    : Bus 25909	: V=0.9552054, theta=-44.776048 -> V=1.0, theta=0.0
% INFO    : Bus 25910	: V=0.9565224, theta=-44.438279 -> V=1.0, theta=0.0
% INFO    : Bus 25911	: V=0.9556753, theta=-44.477212 -> V=1.0, theta=0.0
% INFO    : Bus 25912	: V=0.9568271, theta=-44.639906 -> V=1.0, theta=0.0
% INFO    : Bus 25913	: V=0.9544275, theta=-44.47613 -> V=1.0, theta=0.0
% INFO    : Bus 25914	: V=0.9558718, theta=-44.759919 -> V=1.0, theta=0.0
% INFO    : Bus 25915	: V=0.9564353, theta=-43.761378 -> V=1.0, theta=0.0
% INFO    : Bus 25916	: V=0.9554007, theta=-44.821672 -> V=1.0, theta=0.0
% INFO    : Bus 25917	: V=0.9572699, theta=-44.08865 -> V=1.0, theta=0.0
% INFO    : Bus 25918	: V=0.9574944, theta=-43.995258 -> V=1.0, theta=0.0
% INFO    : Bus 25919	: V=0.9569259, theta=-44.282379 -> V=1.0, theta=0.0
% INFO    : Bus 25920	: V=0.9570676, theta=-44.198895 -> V=1.0, theta=0.0
% INFO    : Bus 25921	: V=0.9552704, theta=-44.706242 -> V=1.0, theta=0.0
% INFO    : Bus 25922	: V=0.9555265, theta=-44.766522 -> V=1.0, theta=0.0
% INFO    : Bus 25923	: V=0.9559872, theta=-44.43915 -> V=1.0, theta=0.0
% INFO    : Bus 25924	: V=0.9563532, theta=-44.380889 -> V=1.0, theta=0.0
% INFO    : Bus 25925	: V=0.9551769, theta=-44.710898 -> V=1.0, theta=0.0
% INFO    : Bus 25926	: V=0.9563338, theta=-44.57427 -> V=1.0, theta=0.0
% INFO    : Bus 25927	: V=0.9567009, theta=-44.896946 -> V=1.0, theta=0.0
% INFO    : Bus 25928	: V=0.9560251, theta=-44.67123 -> V=1.0, theta=0.0
% INFO    : Bus 25929	: V=0.9578934, theta=-43.960463 -> V=1.0, theta=0.0
% INFO    : Bus 25930	: V=0.9568826, theta=-44.889453 -> V=1.0, theta=0.0
% INFO    : Bus 25931	: V=0.9555609, theta=-44.923932 -> V=1.0, theta=0.0
% INFO    : Bus 25932	: V=0.9540922, theta=-44.861444 -> V=1.0, theta=0.0
% INFO    : Bus 25933	: V=0.9586482, theta=-43.784662 -> V=1.0, theta=0.0
% INFO    : Bus 25934	: V=0.9576961, theta=-44.665968 -> V=1.0, theta=0.0
% INFO    : Bus 25935	: V=0.9600302, theta=-43.477988 -> V=1.0, theta=0.0
% INFO    : Bus 25936	: V=0.9613733, theta=-42.935554 -> V=1.0, theta=0.0
% INFO    : Bus 25937	: V=0.9610642, theta=-43.263172 -> V=1.0, theta=0.0
% INFO    : Bus 25938	: V=0.958546, theta=-43.576335 -> V=1.0, theta=0.0
% INFO    : Bus 25939	: V=0.9578351, theta=-44.378605 -> V=1.0, theta=0.0
% INFO    : Bus 25940	: V=0.9578496, theta=-44.442059 -> V=1.0, theta=0.0
% INFO    : Bus 25941	: V=0.9583863, theta=-44.664645 -> V=1.0, theta=0.0
% INFO    : Bus 25942	: V=0.9543711, theta=-44.480264 -> V=1.0, theta=0.0
% INFO    : Bus 25943	: V=0.9533771, theta=-44.519143 -> V=1.0, theta=0.0
% INFO    : Bus 25944	: V=0.9605651, theta=-42.72985 -> V=1.0, theta=0.0
% INFO    : Bus 25945	: V=0.9596456, theta=-43.509995 -> V=1.0, theta=0.0
% INFO    : Bus 25946	: V=0.9591007, theta=-43.608594 -> V=1.0, theta=0.0
% INFO    : Bus 25947	: V=0.9579658, theta=-43.80994 -> V=1.0, theta=0.0
% INFO    : Bus 25948	: V=0.9576893, theta=-43.861532 -> V=1.0, theta=0.0
% INFO    : Bus 25949	: V=0.9582582, theta=-43.758199 -> V=1.0, theta=0.0
% INFO    : Bus 25950	: V=0.9586586, theta=-43.688121 -> V=1.0, theta=0.0
% INFO    : Bus 25951	: V=0.9579789, theta=-43.943052 -> V=1.0, theta=0.0
% INFO    : Bus 25952	: V=0.9586313, theta=-43.480893 -> V=1.0, theta=0.0
% INFO    : Bus 25953	: V=0.9614483, theta=-42.652756 -> V=1.0, theta=0.0
% INFO    : Bus 25954	: V=0.9666796, theta=-41.267344 -> V=1.0, theta=0.0
% INFO    : Bus 25955	: V=0.9668007, theta=-41.240284 -> V=1.0, theta=0.0
% INFO    : Bus 25956	: V=0.9576399, theta=-43.297329 -> V=1.0, theta=0.0
% INFO    : Bus 25957	: V=0.9578427, theta=-43.241659 -> V=1.0, theta=0.0
% INFO    : Bus 25958	: V=0.9575945, theta=-43.957726 -> V=1.0, theta=0.0
% INFO    : Bus 25959	: V=0.9595172, theta=-42.910313 -> V=1.0, theta=0.0
% INFO    : Bus 25960	: V=0.9557909, theta=-43.8821 -> V=1.0, theta=0.0
% INFO    : Bus 25961	: V=0.9557698, theta=-43.664127 -> V=1.0, theta=0.0
% INFO    : Bus 25962	: V=0.9574628, theta=-43.327552 -> V=1.0, theta=0.0
% INFO    : Bus 25963	: V=0.962932, theta=-42.093934 -> V=1.0, theta=0.0
% INFO    : Bus 25964	: V=0.9596385, theta=-43.039962 -> V=1.0, theta=0.0
% INFO    : Bus 25965	: V=0.9646922, theta=-41.742864 -> V=1.0, theta=0.0
% INFO    : Bus 25966	: V=0.963424, theta=-42.093107 -> V=1.0, theta=0.0
% INFO    : Bus 25967	: V=0.959428, theta=-43.154639 -> V=1.0, theta=0.0
% INFO    : Bus 25968	: V=0.9622461, theta=-42.385982 -> V=1.0, theta=0.0
% INFO    : Bus 25969	: V=0.9616074, theta=-42.354128 -> V=1.0, theta=0.0
% INFO    : Bus 25970	: V=0.9708747, theta=-40.243946 -> V=1.0, theta=0.0
% INFO    : Bus 25971	: V=0.9572755, theta=-42.47878 -> V=1.0, theta=0.0
% INFO    : Bus 25972	: V=0.9588334, theta=-42.403351 -> V=1.0, theta=0.0
% INFO    : Bus 25973	: V=0.9597512, theta=-42.377585 -> V=1.0, theta=0.0
% INFO    : Bus 25974	: V=0.9556556, theta=-42.534276 -> V=1.0, theta=0.0
% INFO    : Bus 25975	: V=0.954479, theta=-42.586094 -> V=1.0, theta=0.0
% INFO    : Bus 25976	: V=0.9650123, theta=-41.593463 -> V=1.0, theta=0.0
% INFO    : Bus 25977	: V=0.9733286, theta=-39.368815 -> V=1.0, theta=0.0
% INFO    : Bus 25978	: V=0.9567492, theta=-41.931154 -> V=1.0, theta=0.0
% INFO    : Bus 25979	: V=0.9581119, theta=-42.452297 -> V=1.0, theta=0.0
% INFO    : Bus 25980	: V=0.9587411, theta=-42.399749 -> V=1.0, theta=0.0
% INFO    : Bus 25981	: V=0.9706141, theta=-40.289122 -> V=1.0, theta=0.0
% INFO    : Bus 25982	: V=0.9604384, theta=-42.33911 -> V=1.0, theta=0.0
% INFO    : Bus 25983	: V=0.9615861, theta=-42.313126 -> V=1.0, theta=0.0
% INFO    : Bus 25984	: V=0.9621957, theta=-42.058708 -> V=1.0, theta=0.0
% INFO    : Bus 25985	: V=0.9614095, theta=-42.265488 -> V=1.0, theta=0.0
% INFO    : Bus 25986	: V=0.9606707, theta=-42.2889 -> V=1.0, theta=0.0
% INFO    : Bus 25987	: V=0.9608343, theta=-42.28694 -> V=1.0, theta=0.0
% INFO    : Bus 25988	: V=0.9630404, theta=-41.906716 -> V=1.0, theta=0.0
% INFO    : Bus 25989	: V=0.9584133, theta=-42.665327 -> V=1.0, theta=0.0
% INFO    : Bus 25990	: V=0.9623608, theta=-42.025766 -> V=1.0, theta=0.0
% INFO    : Bus 25991	: V=0.9628203, theta=-41.999626 -> V=1.0, theta=0.0
% INFO    : Bus 25992	: V=0.9632749, theta=-41.891214 -> V=1.0, theta=0.0
% INFO    : Bus 25993	: V=0.9636112, theta=-41.859709 -> V=1.0, theta=0.0
% INFO    : Bus 25994	: V=0.9625846, theta=-42.032775 -> V=1.0, theta=0.0
% INFO    : Bus 25995	: V=0.9624345, theta=-42.445592 -> V=1.0, theta=0.0
% INFO    : Bus 25996	: V=0.962238, theta=-42.467564 -> V=1.0, theta=0.0
% INFO    : Bus 25997	: V=0.9625589, theta=-42.431937 -> V=1.0, theta=0.0
% INFO    : Bus 25998	: V=0.963556, theta=-42.136966 -> V=1.0, theta=0.0
% INFO    : Bus 25999	: V=0.9700393, theta=-40.638131 -> V=1.0, theta=0.0
% INFO    : Bus 26000	: V=0.9649407, theta=-41.899356 -> V=1.0, theta=0.0
% INFO    : Bus 26001	: V=0.9705456, theta=-40.421505 -> V=1.0, theta=0.0
% INFO    : Bus 26002	: V=0.9637715, theta=-42.290307 -> V=1.0, theta=0.0
% INFO    : Bus 26003	: V=0.9623979, theta=-42.075649 -> V=1.0, theta=0.0
% INFO    : Bus 26004	: V=0.9703882, theta=-40.442522 -> V=1.0, theta=0.0
% INFO    : Bus 26005	: V=0.9704248, theta=-40.44089 -> V=1.0, theta=0.0
% INFO    : Bus 26006	: V=0.9622718, theta=-42.581979 -> V=1.0, theta=0.0
% INFO    : Bus 26007	: V=0.9582065, theta=-43.41123 -> V=1.0, theta=0.0
% INFO    : Bus 26008	: V=0.9696051, theta=-40.726729 -> V=1.0, theta=0.0
% INFO    : Bus 26009	: V=0.9597411, theta=-43.221136 -> V=1.0, theta=0.0
% INFO    : Bus 26010	: V=0.9571558, theta=-43.514868 -> V=1.0, theta=0.0
% INFO    : Bus 26011	: V=0.9602736, theta=-43.026069 -> V=1.0, theta=0.0
% INFO    : Bus 26012	: V=0.9600409, theta=-43.113657 -> V=1.0, theta=0.0
% INFO    : Bus 26013	: V=0.9567359, theta=-43.560002 -> V=1.0, theta=0.0
% INFO    : Bus 26014	: V=0.9559607, theta=-43.738544 -> V=1.0, theta=0.0
% INFO    : Bus 26015	: V=0.9565724, theta=-43.779331 -> V=1.0, theta=0.0
% INFO    : Bus 26016	: V=0.9570229, theta=-43.457419 -> V=1.0, theta=0.0
% INFO    : Bus 26017	: V=0.956205, theta=-43.502018 -> V=1.0, theta=0.0
% INFO    : Bus 26018	: V=0.9567332, theta=-43.486897 -> V=1.0, theta=0.0
% INFO    : Bus 26019	: V=0.9617892, theta=-42.399072 -> V=1.0, theta=0.0
% INFO    : Bus 26020	: V=0.9570647, theta=-43.480402 -> V=1.0, theta=0.0
% INFO    : Bus 26021	: V=0.9574195, theta=-43.422404 -> V=1.0, theta=0.0
% INFO    : Bus 26022	: V=0.959371, theta=-43.056781 -> V=1.0, theta=0.0
% INFO    : Bus 26023	: V=0.9578212, theta=-43.352559 -> V=1.0, theta=0.0
% INFO    : Bus 26024	: V=0.958204, theta=-43.258634 -> V=1.0, theta=0.0
% INFO    : Bus 26025	: V=0.9599001, theta=-42.877028 -> V=1.0, theta=0.0
% INFO    : Bus 26026	: V=0.958827, theta=-42.915943 -> V=1.0, theta=0.0
% INFO    : Bus 26027	: V=0.9560051, theta=-43.685979 -> V=1.0, theta=0.0
% INFO    : Bus 26028	: V=0.9555794, theta=-43.697687 -> V=1.0, theta=0.0
% INFO    : Bus 26029	: V=0.9541919, theta=-44.076681 -> V=1.0, theta=0.0
% INFO    : Bus 26030	: V=0.9564835, theta=-44.484662 -> V=1.0, theta=0.0
% INFO    : Bus 26031	: V=0.9561738, theta=-43.999075 -> V=1.0, theta=0.0
% INFO    : Bus 26032	: V=0.9560714, theta=-43.79735 -> V=1.0, theta=0.0
% INFO    : Bus 26033	: V=0.957064, theta=-43.769142 -> V=1.0, theta=0.0
% INFO    : Bus 26034	: V=0.9557406, theta=-43.526059 -> V=1.0, theta=0.0
% INFO    : Bus 26035	: V=0.956997, theta=-44.331975 -> V=1.0, theta=0.0
% INFO    : Bus 26036	: V=0.9618154, theta=-42.74698 -> V=1.0, theta=0.0
% INFO    : Bus 26037	: V=0.956273, theta=-44.15421 -> V=1.0, theta=0.0
% INFO    : Bus 26038	: V=0.9565153, theta=-44.231306 -> V=1.0, theta=0.0
% INFO    : Bus 26039	: V=0.9625336, theta=-42.56313 -> V=1.0, theta=0.0
% INFO    : Bus 26040	: V=0.9557377, theta=-44.179729 -> V=1.0, theta=0.0
% INFO    : Bus 26041	: V=0.9615748, theta=-42.818311 -> V=1.0, theta=0.0
% INFO    : Bus 26042	: V=0.9572189, theta=-43.578685 -> V=1.0, theta=0.0
% INFO    : Bus 26043	: V=0.9616617, theta=-42.348401 -> V=1.0, theta=0.0
% INFO    : Bus 26044	: V=0.9627701, theta=-42.217587 -> V=1.0, theta=0.0
% INFO    : Bus 26045	: V=0.9587622, theta=-42.710975 -> V=1.0, theta=0.0
% INFO    : Bus 26046	: V=0.9660136, theta=-41.348724 -> V=1.0, theta=0.0
% INFO    : Bus 26047	: V=0.9623515, theta=-42.101366 -> V=1.0, theta=0.0
% INFO    : Bus 26048	: V=0.9640475, theta=-41.712776 -> V=1.0, theta=0.0
% INFO    : Bus 26049	: V=0.962069, theta=-42.354415 -> V=1.0, theta=0.0
% INFO    : Bus 26050	: V=0.9724383, theta=-40.120441 -> V=1.0, theta=0.0
% INFO    : Bus 26051	: V=0.9615039, theta=-42.380738 -> V=1.0, theta=0.0
% INFO    : Bus 26052	: V=0.9700847, theta=-40.441981 -> V=1.0, theta=0.0
% INFO    : Bus 26053	: V=0.970173, theta=-40.433138 -> V=1.0, theta=0.0
% INFO    : Bus 26054	: V=0.9639058, theta=-41.857142 -> V=1.0, theta=0.0
% INFO    : Bus 26055	: V=0.9705457, theta=-40.393435 -> V=1.0, theta=0.0
% INFO    : Bus 26056	: V=0.9738815, theta=-39.333642 -> V=1.0, theta=0.0
% INFO    : Bus 26057	: V=0.9601521, theta=-42.421008 -> V=1.0, theta=0.0
% INFO    : Bus 26058	: V=0.9734667, theta=-39.282635 -> V=1.0, theta=0.0
% INFO    : Bus 26059	: V=0.9552176, theta=-44.54317 -> V=1.0, theta=0.0
% INFO    : Bus 26060	: V=0.9552506, theta=-44.913666 -> V=1.0, theta=0.0
% INFO    : Bus 26061	: V=0.9579187, theta=-43.763622 -> V=1.0, theta=0.0
% INFO    : Bus 26062	: V=0.9555901, theta=-43.348082 -> V=1.0, theta=0.0
% INFO    : Bus 26063	: V=0.9621175, theta=-42.151475 -> V=1.0, theta=0.0
% INFO    : Bus 26064	: V=0.9557767, theta=-43.349725 -> V=1.0, theta=0.0
% INFO    : Bus 26065	: V=0.9611007, theta=-42.552583 -> V=1.0, theta=0.0
% INFO    : Bus 26066	: V=0.9575083, theta=-43.21944 -> V=1.0, theta=0.0
% INFO    : Bus 26067	: V=0.9583791, theta=-43.2004 -> V=1.0, theta=0.0
% INFO    : Bus 26068	: V=0.9563933, theta=-44.333875 -> V=1.0, theta=0.0
% INFO    : Bus 26069	: V=0.9595026, theta=-43.347914 -> V=1.0, theta=0.0
% INFO    : Bus 26070	: V=0.9638776, theta=-31.548473 -> V=1.0, theta=0.0
% INFO    : Bus 26071	: V=0.9648289, theta=-31.762007 -> V=1.0, theta=0.0
% INFO    : Bus 26072	: V=0.9692712, theta=-31.363306 -> V=1.0, theta=0.0
% INFO    : Bus 26073	: V=0.9650518, theta=-31.33693 -> V=1.0, theta=0.0
% INFO    : Bus 26074	: V=0.9714472, theta=-29.877098 -> V=1.0, theta=0.0
% INFO    : Bus 26075	: V=0.965552, theta=-30.973677 -> V=1.0, theta=0.0
% INFO    : Bus 26076	: V=0.9773364, theta=-29.268341 -> V=1.0, theta=0.0
% INFO    : Bus 26077	: V=0.9602921, theta=-28.861126 -> V=1.0, theta=0.0
% INFO    : Bus 26078	: V=0.9956738, theta=-27.359028 -> V=1.0, theta=0.0
% INFO    : Bus 26079	: V=1.0115509, theta=-31.376704 -> V=1.0, theta=0.0
% INFO    : Bus 26080	: V=0.9911239, theta=-32.868858 -> V=1.0, theta=0.0
% INFO    : Bus 26081	: V=1.0006478, theta=-31.553125 -> V=1.0, theta=0.0
% INFO    : Bus 26082	: V=1.0071906, theta=-34.073282 -> V=1.0, theta=0.0
% INFO    : Bus 26083	: V=1.0034039, theta=-32.95523 -> V=1.0, theta=0.0
% INFO    : Bus 26084	: V=1.0097075, theta=-32.967375 -> V=1.0, theta=0.0
% INFO    : Bus 26085	: V=1.0120076, theta=-31.466091 -> V=1.0, theta=0.0
% INFO    : Bus 26086	: V=0.9901057, theta=-53.819297 -> V=1.0, theta=0.0
% INFO    : Bus 26087	: V=0.9841989, theta=-54.676901 -> V=1.0, theta=0.0
% INFO    : Bus 26088	: V=0.9750272, theta=-53.383702 -> V=1.0, theta=0.0
% INFO    : Bus 26089	: V=0.9696729, theta=-54.524378 -> V=1.0, theta=0.0
% INFO    : Bus 26090	: V=0.9739583, theta=-54.641949 -> V=1.0, theta=0.0
% INFO    : Bus 26091	: V=0.9765075, theta=-55.026117 -> V=1.0, theta=0.0
% INFO    : Bus 26092	: V=0.9789549, theta=-55.48697 -> V=1.0, theta=0.0
% INFO    : Bus 26093	: V=0.9630344, theta=-57.841047 -> V=1.0, theta=0.0
% INFO    : Bus 26094	: V=0.9773007, theta=-54.250382 -> V=1.0, theta=0.0
% INFO    : Bus 26095	: V=0.9680748, theta=-53.998662 -> V=1.0, theta=0.0
% INFO    : Bus 26096	: V=0.9654042, theta=-54.1539 -> V=1.0, theta=0.0
% INFO    : Bus 26097	: V=0.9635984, theta=-54.277149 -> V=1.0, theta=0.0
% INFO    : Bus 26098	: V=0.9541875, theta=-55.939258 -> V=1.0, theta=0.0
% INFO    : Bus 26099	: V=0.9538175, theta=-57.002391 -> V=1.0, theta=0.0
% INFO    : Bus 26100	: V=0.9566389, theta=-58.7354 -> V=1.0, theta=0.0
% INFO    : Bus 26101	: V=0.9593944, theta=-58.229678 -> V=1.0, theta=0.0
% INFO    : Bus 26102	: V=1.0074687, theta=-50.818554 -> V=1.0, theta=0.0
% INFO    : Bus 26103	: V=0.9918487, theta=-52.92553 -> V=1.0, theta=0.0
% INFO    : Bus 26104	: V=0.9774988, theta=-54.324079 -> V=1.0, theta=0.0
% INFO    : Bus 26105	: V=0.9736681, theta=-56.443304 -> V=1.0, theta=0.0
% INFO    : Bus 26106	: V=0.9627669, theta=-58.138712 -> V=1.0, theta=0.0
% INFO    : Bus 26107	: V=0.9611716, theta=-34.136176 -> V=1.0, theta=0.0
% INFO    : Bus 26108	: V=0.9603213, theta=-34.146066 -> V=1.0, theta=0.0
% INFO    : Bus 26109	: V=0.9658838, theta=-33.185817 -> V=1.0, theta=0.0
% INFO    : Bus 26110	: V=0.9627956, theta=-34.155968 -> V=1.0, theta=0.0
% INFO    : Bus 26111	: V=0.9567864, theta=-35.015985 -> V=1.0, theta=0.0
% INFO    : Bus 26112	: V=0.9642396, theta=-33.713542 -> V=1.0, theta=0.0
% INFO    : Bus 26113	: V=0.959042, theta=-34.544449 -> V=1.0, theta=0.0
% INFO    : Bus 26114	: V=0.9602219, theta=-34.292293 -> V=1.0, theta=0.0
% INFO    : Bus 26115	: V=0.9632735, theta=-34.010151 -> V=1.0, theta=0.0
% INFO    : Bus 26116	: V=0.9663396, theta=-33.010395 -> V=1.0, theta=0.0
% INFO    : Bus 26117	: V=0.9673551, theta=-32.899065 -> V=1.0, theta=0.0
% INFO    : Bus 26118	: V=0.9681595, theta=-32.724134 -> V=1.0, theta=0.0
% INFO    : Bus 26119	: V=0.9703491, theta=-32.309246 -> V=1.0, theta=0.0
% INFO    : Bus 26120	: V=0.9692742, theta=-32.487644 -> V=1.0, theta=0.0
% INFO    : Bus 26121	: V=0.968192, theta=-32.71412 -> V=1.0, theta=0.0
% INFO    : Bus 26122	: V=0.9663957, theta=-33.113806 -> V=1.0, theta=0.0
% INFO    : Bus 26123	: V=0.9670076, theta=-32.917552 -> V=1.0, theta=0.0
% INFO    : Bus 26124	: V=0.9665442, theta=-33.012611 -> V=1.0, theta=0.0
% INFO    : Bus 26125	: V=0.9785797, theta=-30.845924 -> V=1.0, theta=0.0
% INFO    : Bus 26126	: V=0.9800501, theta=-30.657325 -> V=1.0, theta=0.0
% INFO    : Bus 26127	: V=0.9848766, theta=-29.605232 -> V=1.0, theta=0.0
% INFO    : Bus 26128	: V=0.9671654, theta=-33.022108 -> V=1.0, theta=0.0
% INFO    : Bus 26129	: V=0.9678837, theta=-32.836702 -> V=1.0, theta=0.0
% INFO    : Bus 26130	: V=0.9692096, theta=-32.557407 -> V=1.0, theta=0.0
% INFO    : Bus 26131	: V=0.9710292, theta=-32.196507 -> V=1.0, theta=0.0
% INFO    : Bus 26132	: V=0.9630236, theta=-33.982922 -> V=1.0, theta=0.0
% INFO    : Bus 26133	: V=0.9667197, theta=-33.316886 -> V=1.0, theta=0.0
% INFO    : Bus 26134	: V=0.9709851, theta=-32.240267 -> V=1.0, theta=0.0
% INFO    : Bus 26135	: V=0.9621039, theta=-34.447315 -> V=1.0, theta=0.0
% INFO    : Bus 26136	: V=0.956985, theta=-35.52406 -> V=1.0, theta=0.0
% INFO    : Bus 26137	: V=0.9669047, theta=-34.080384 -> V=1.0, theta=0.0
% INFO    : Bus 26138	: V=0.9736869, theta=-31.890563 -> V=1.0, theta=0.0
% INFO    : Bus 26139	: V=0.9774335, theta=-31.416859 -> V=1.0, theta=0.0
% INFO    : Bus 26140	: V=0.9584496, theta=-34.798547 -> V=1.0, theta=0.0
% INFO    : Bus 26141	: V=0.9753375, theta=-31.812232 -> V=1.0, theta=0.0
% INFO    : Bus 26142	: V=0.9963554, theta=-41.175541 -> V=1.0, theta=0.0
% INFO    : Bus 26143	: V=1.0106271, theta=-37.636415 -> V=1.0, theta=0.0
% INFO    : Bus 26144	: V=1.0010789, theta=-39.595134 -> V=1.0, theta=0.0
% INFO    : Bus 26145	: V=1.0103781, theta=-37.718858 -> V=1.0, theta=0.0
% INFO    : Bus 26146	: V=1.0033678, theta=-39.272917 -> V=1.0, theta=0.0
% INFO    : Bus 26147	: V=1.012316, theta=-37.135413 -> V=1.0, theta=0.0
% INFO    : Bus 26148	: V=1.0040312, theta=-39.290659 -> V=1.0, theta=0.0
% INFO    : Bus 26149	: V=1.0060233, theta=-38.767456 -> V=1.0, theta=0.0
% INFO    : Bus 26150	: V=1.0136395, theta=-36.598575 -> V=1.0, theta=0.0
% INFO    : Bus 26151	: V=1.016558, theta=-34.959576 -> V=1.0, theta=0.0
% INFO    : Bus 26152	: V=0.9776085, theta=-26.809395 -> V=1.0, theta=0.0
% INFO    : Bus 26153	: V=0.9751409, theta=-27.028 -> V=1.0, theta=0.0
% INFO    : Bus 26154	: V=0.9768141, theta=-26.948259 -> V=1.0, theta=0.0
% INFO    : Bus 26155	: V=0.9765601, theta=-26.983502 -> V=1.0, theta=0.0
% INFO    : Bus 26156	: V=0.9764255, theta=-27.001942 -> V=1.0, theta=0.0
% INFO    : Bus 26157	: V=0.9766611, theta=-26.971866 -> V=1.0, theta=0.0
% INFO    : Bus 26158	: V=0.9763739, theta=-27.008476 -> V=1.0, theta=0.0
% INFO    : Bus 26159	: V=0.9763403, theta=-27.017074 -> V=1.0, theta=0.0
% INFO    : Bus 26160	: V=0.9747642, theta=-27.263541 -> V=1.0, theta=0.0
% INFO    : Bus 26161	: V=0.9750345, theta=-27.259549 -> V=1.0, theta=0.0
% INFO    : Bus 26162	: V=0.9758513, theta=-27.097501 -> V=1.0, theta=0.0
% INFO    : Bus 26163	: V=0.9762749, theta=-27.031215 -> V=1.0, theta=0.0
% INFO    : Bus 26164	: V=0.9760105, theta=-27.034949 -> V=1.0, theta=0.0
% INFO    : Bus 26165	: V=0.9753932, theta=-27.041331 -> V=1.0, theta=0.0
% INFO    : Bus 26166	: V=0.9752115, theta=-27.04414 -> V=1.0, theta=0.0
% INFO    : Bus 26167	: V=0.9841778, theta=-26.091413 -> V=1.0, theta=0.0
% INFO    : Bus 26168	: V=0.9793666, theta=-26.775109 -> V=1.0, theta=0.0
% INFO    : Bus 26169	: V=0.9777695, theta=-27.001557 -> V=1.0, theta=0.0
% INFO    : Bus 26170	: V=0.9775598, theta=-27.055791 -> V=1.0, theta=0.0
% INFO    : Bus 26171	: V=0.9780892, theta=-26.968742 -> V=1.0, theta=0.0
% INFO    : Bus 26172	: V=0.9755768, theta=-27.257751 -> V=1.0, theta=0.0
% INFO    : Bus 26173	: V=0.9751166, theta=-27.261299 -> V=1.0, theta=0.0
% INFO    : Bus 26174	: V=0.9736906, theta=-27.362402 -> V=1.0, theta=0.0
% INFO    : Bus 26175	: V=0.9748728, theta=-27.323443 -> V=1.0, theta=0.0
% INFO    : Bus 26176	: V=0.9749011, theta=-27.415823 -> V=1.0, theta=0.0
% INFO    : Bus 26177	: V=0.9746453, theta=-27.348422 -> V=1.0, theta=0.0
% INFO    : Bus 26178	: V=0.9744057, theta=-27.350833 -> V=1.0, theta=0.0
% INFO    : Bus 26179	: V=0.9866776, theta=-27.370568 -> V=1.0, theta=0.0
% INFO    : Bus 26180	: V=0.9905617, theta=-26.679358 -> V=1.0, theta=0.0
% INFO    : Bus 26181	: V=0.9914231, theta=-26.632829 -> V=1.0, theta=0.0
% INFO    : Bus 26182	: V=0.984403, theta=-27.554466 -> V=1.0, theta=0.0
% INFO    : Bus 26183	: V=0.9885554, theta=-26.777449 -> V=1.0, theta=0.0
% INFO    : Bus 26184	: V=0.9744428, theta=-27.730297 -> V=1.0, theta=0.0
% INFO    : Bus 26185	: V=0.9860942, theta=-26.891634 -> V=1.0, theta=0.0
% INFO    : Bus 26186	: V=0.9741505, theta=-27.770267 -> V=1.0, theta=0.0
% INFO    : Bus 26187	: V=0.9818894, theta=-27.033519 -> V=1.0, theta=0.0
% INFO    : Bus 26188	: V=0.9809975, theta=-27.056683 -> V=1.0, theta=0.0
% INFO    : Bus 26189	: V=0.9747039, theta=-27.78767 -> V=1.0, theta=0.0
% INFO    : Bus 26190	: V=0.9746313, theta=-27.725267 -> V=1.0, theta=0.0
% INFO    : Bus 26191	: V=0.9811413, theta=-27.193023 -> V=1.0, theta=0.0
% INFO    : Bus 26192	: V=0.9822306, theta=-27.162077 -> V=1.0, theta=0.0
% INFO    : Bus 26193	: V=0.9802964, theta=-27.212479 -> V=1.0, theta=0.0
% INFO    : Bus 26194	: V=0.9814778, theta=-27.21367 -> V=1.0, theta=0.0
% INFO    : Bus 26195	: V=0.9758096, theta=-27.945721 -> V=1.0, theta=0.0
% INFO    : Bus 26196	: V=0.9727403, theta=-27.930386 -> V=1.0, theta=0.0
% INFO    : Bus 26197	: V=0.9795146, theta=-27.239821 -> V=1.0, theta=0.0
% INFO    : Bus 26198	: V=0.978696, theta=-27.319731 -> V=1.0, theta=0.0
% INFO    : Bus 26199	: V=0.97893, theta=-27.191446 -> V=1.0, theta=0.0
% INFO    : Bus 26200	: V=0.9794898, theta=-27.074568 -> V=1.0, theta=0.0
% INFO    : Bus 26201	: V=0.9801528, theta=-27.022709 -> V=1.0, theta=0.0
% INFO    : Bus 26202	: V=0.9800078, theta=-27.101672 -> V=1.0, theta=0.0
% INFO    : Bus 26203	: V=0.9803663, theta=-27.056804 -> V=1.0, theta=0.0
% INFO    : Bus 26204	: V=0.9811255, theta=-26.839297 -> V=1.0, theta=0.0
% INFO    : Bus 26205	: V=0.9757969, theta=-27.281599 -> V=1.0, theta=0.0
% INFO    : Bus 26206	: V=0.9762593, theta=-27.189473 -> V=1.0, theta=0.0
% INFO    : Bus 26207	: V=0.9770811, theta=-27.066418 -> V=1.0, theta=0.0
% INFO    : Bus 26208	: V=0.9777706, theta=-26.956975 -> V=1.0, theta=0.0
% INFO    : Bus 26209	: V=0.9789213, theta=-26.81274 -> V=1.0, theta=0.0
% INFO    : Bus 26210	: V=0.9797908, theta=-26.67276 -> V=1.0, theta=0.0
% INFO    : Bus 26211	: V=0.9953189, theta=-24.770629 -> V=1.0, theta=0.0
% INFO    : Bus 26212	: V=0.9838683, theta=-26.115139 -> V=1.0, theta=0.0
% INFO    : Bus 26213	: V=0.9826276, theta=-26.298625 -> V=1.0, theta=0.0
% INFO    : Bus 26214	: V=0.9833561, theta=-26.046782 -> V=1.0, theta=0.0
% INFO    : Bus 26215	: V=0.9844996, theta=-25.953349 -> V=1.0, theta=0.0
% INFO    : Bus 26216	: V=0.9829138, theta=-26.201478 -> V=1.0, theta=0.0
% INFO    : Bus 26217	: V=0.9805927, theta=-26.846089 -> V=1.0, theta=0.0
% INFO    : Bus 26218	: V=0.9833661, theta=-26.307708 -> V=1.0, theta=0.0
% INFO    : Bus 26219	: V=0.9833861, theta=-26.277399 -> V=1.0, theta=0.0
% INFO    : Bus 26220	: V=0.9796394, theta=-26.633943 -> V=1.0, theta=0.0
% INFO    : Bus 26221	: V=0.9889295, theta=-25.30616 -> V=1.0, theta=0.0
% INFO    : Bus 26222	: V=0.9855395, theta=-25.784366 -> V=1.0, theta=0.0
% INFO    : Bus 26223	: V=0.9841009, theta=-25.971933 -> V=1.0, theta=0.0
% INFO    : Bus 26224	: V=0.9854166, theta=-25.719789 -> V=1.0, theta=0.0
% INFO    : Bus 26225	: V=0.9825649, theta=-25.928022 -> V=1.0, theta=0.0
% INFO    : Bus 26226	: V=0.9831369, theta=-25.92261 -> V=1.0, theta=0.0
% INFO    : Bus 26227	: V=0.9810797, theta=-26.203498 -> V=1.0, theta=0.0
% INFO    : Bus 26228	: V=0.9843208, theta=-25.364805 -> V=1.0, theta=0.0
% INFO    : Bus 26229	: V=0.9848746, theta=-25.302958 -> V=1.0, theta=0.0
% INFO    : Bus 26230	: V=0.9852392, theta=-25.256507 -> V=1.0, theta=0.0
% INFO    : Bus 26231	: V=0.9854637, theta=-25.240425 -> V=1.0, theta=0.0
% INFO    : Bus 26232	: V=0.982197, theta=-25.511352 -> V=1.0, theta=0.0
% INFO    : Bus 26233	: V=0.9829072, theta=-25.793962 -> V=1.0, theta=0.0
% INFO    : Bus 26234	: V=0.9842851, theta=-25.4131 -> V=1.0, theta=0.0
% INFO    : Bus 26235	: V=0.9878281, theta=-25.009659 -> V=1.0, theta=0.0
% INFO    : Bus 26236	: V=0.9868916, theta=-25.361956 -> V=1.0, theta=0.0
% INFO    : Bus 26237	: V=0.9877778, theta=-25.153992 -> V=1.0, theta=0.0
% INFO    : Bus 26238	: V=0.9883258, theta=-25.031758 -> V=1.0, theta=0.0
% INFO    : Bus 26239	: V=0.9838618, theta=-25.572736 -> V=1.0, theta=0.0
% INFO    : Bus 26240	: V=1.0000286, theta=-23.164841 -> V=1.0, theta=0.0
% INFO    : Bus 26241	: V=0.9912253, theta=-24.672765 -> V=1.0, theta=0.0
% INFO    : Bus 26242	: V=0.9861018, theta=-25.283864 -> V=1.0, theta=0.0
% INFO    : Bus 26243	: V=0.9862231, theta=-25.133873 -> V=1.0, theta=0.0
% INFO    : Bus 26244	: V=1.0044161, theta=-22.206035 -> V=1.0, theta=0.0
% INFO    : Bus 26245	: V=0.9916821, theta=-24.554317 -> V=1.0, theta=0.0
% INFO    : Bus 26246	: V=0.9933796, theta=-24.367644 -> V=1.0, theta=0.0
% INFO    : Bus 26247	: V=0.9847529, theta=-25.399311 -> V=1.0, theta=0.0
% INFO    : Bus 26248	: V=0.9805156, theta=-27.223221 -> V=1.0, theta=0.0
% INFO    : Bus 26249	: V=0.9871874, theta=-25.179536 -> V=1.0, theta=0.0
% INFO    : Bus 26250	: V=0.97881, theta=-27.25433 -> V=1.0, theta=0.0
% INFO    : Bus 26251	: V=0.9770885, theta=-26.88176 -> V=1.0, theta=0.0
% INFO    : Bus 26252	: V=1.0070866, theta=-21.709357 -> V=1.0, theta=0.0
% INFO    : Bus 26253	: V=1.0104913, theta=-21.049725 -> V=1.0, theta=0.0
% INFO    : Bus 26254	: V=1.0050808, theta=-22.11264 -> V=1.0, theta=0.0
% INFO    : Bus 26255	: V=0.9908248, theta=-24.901208 -> V=1.0, theta=0.0
% INFO    : Bus 26256	: V=0.9885271, theta=-25.638129 -> V=1.0, theta=0.0
% INFO    : Bus 26257	: V=0.9852647, theta=-26.068903 -> V=1.0, theta=0.0
% INFO    : Bus 26258	: V=0.9871721, theta=-25.710607 -> V=1.0, theta=0.0
% INFO    : Bus 26259	: V=0.9928878, theta=-24.526421 -> V=1.0, theta=0.0
% INFO    : Bus 26260	: V=0.9944701, theta=-24.229556 -> V=1.0, theta=0.0
% INFO    : Bus 26261	: V=0.989485, theta=-25.193742 -> V=1.0, theta=0.0
% INFO    : Bus 26262	: V=0.9839532, theta=-26.251495 -> V=1.0, theta=0.0
% INFO    : Bus 26263	: V=0.9910287, theta=-24.895724 -> V=1.0, theta=0.0
% INFO    : Bus 26264	: V=0.9845753, theta=-26.200571 -> V=1.0, theta=0.0
% INFO    : Bus 26265	: V=0.9882369, theta=-25.493033 -> V=1.0, theta=0.0
% INFO    : Bus 26266	: V=0.9877615, theta=-25.149889 -> V=1.0, theta=0.0
% INFO    : Bus 26267	: V=0.9891404, theta=-25.329333 -> V=1.0, theta=0.0
% INFO    : Bus 26268	: V=0.9983757, theta=-23.710814 -> V=1.0, theta=0.0
% INFO    : Bus 26269	: V=0.9971554, theta=-23.984396 -> V=1.0, theta=0.0
% INFO    : Bus 26270	: V=0.991527, theta=-24.582464 -> V=1.0, theta=0.0
% INFO    : Bus 26271	: V=1.000593, theta=-23.090411 -> V=1.0, theta=0.0
% INFO    : Bus 26272	: V=1.000331, theta=-23.125947 -> V=1.0, theta=0.0
% INFO    : Bus 26273	: V=1.0002606, theta=-23.185047 -> V=1.0, theta=0.0
% INFO    : Bus 26274	: V=1.0011891, theta=-22.965274 -> V=1.0, theta=0.0
% INFO    : Bus 26275	: V=1.0010469, theta=-22.984764 -> V=1.0, theta=0.0
% INFO    : Bus 26276	: V=0.9962394, theta=-23.922787 -> V=1.0, theta=0.0
% INFO    : Bus 26277	: V=0.9952737, theta=-24.016844 -> V=1.0, theta=0.0
% INFO    : Bus 26278	: V=0.9891276, theta=-24.923989 -> V=1.0, theta=0.0
% INFO    : Bus 26279	: V=0.9872582, theta=-25.175631 -> V=1.0, theta=0.0
% INFO    : Bus 26280	: V=0.9886961, theta=-24.811589 -> V=1.0, theta=0.0
% INFO    : Bus 26281	: V=0.9829346, theta=-25.121522 -> V=1.0, theta=0.0
% INFO    : Bus 26282	: V=0.9849645, theta=-25.088371 -> V=1.0, theta=0.0
% INFO    : Bus 26283	: V=0.987794, theta=-24.983851 -> V=1.0, theta=0.0
% INFO    : Bus 26284	: V=0.9854577, theta=-25.231148 -> V=1.0, theta=0.0
% INFO    : Bus 26285	: V=0.9869007, theta=-25.043536 -> V=1.0, theta=0.0
% INFO    : Bus 26286	: V=0.9752849, theta=-27.469175 -> V=1.0, theta=0.0
% INFO    : Bus 26287	: V=0.9755541, theta=-27.527851 -> V=1.0, theta=0.0
% INFO    : Bus 26288	: V=0.9761718, theta=-27.339187 -> V=1.0, theta=0.0
% INFO    : Bus 26289	: V=0.9755234, theta=-27.415837 -> V=1.0, theta=0.0
% INFO    : Bus 26290	: V=0.9832335, theta=-26.352927 -> V=1.0, theta=0.0
% INFO    : Bus 26291	: V=0.9856059, theta=-26.041725 -> V=1.0, theta=0.0
% INFO    : Bus 26292	: V=0.9833546, theta=-26.362402 -> V=1.0, theta=0.0
% INFO    : Bus 26293	: V=0.983835, theta=-26.358302 -> V=1.0, theta=0.0
% INFO    : Bus 26294	: V=0.9814201, theta=-26.660591 -> V=1.0, theta=0.0
% INFO    : Bus 26295	: V=0.9945655, theta=-24.730791 -> V=1.0, theta=0.0
% INFO    : Bus 26296	: V=0.9887769, theta=-25.434634 -> V=1.0, theta=0.0
% INFO    : Bus 26297	: V=0.9951115, theta=-24.571837 -> V=1.0, theta=0.0
% INFO    : Bus 26298	: V=0.9849032, theta=-26.131572 -> V=1.0, theta=0.0
% INFO    : Bus 26299	: V=0.9840014, theta=-26.214148 -> V=1.0, theta=0.0
% INFO    : Bus 26300	: V=0.9880296, theta=-25.38985 -> V=1.0, theta=0.0
% INFO    : Bus 26301	: V=0.9883749, theta=-25.357238 -> V=1.0, theta=0.0
% INFO    : Bus 26302	: V=0.9774211, theta=-27.205945 -> V=1.0, theta=0.0
% INFO    : Bus 26303	: V=0.9778021, theta=-27.044612 -> V=1.0, theta=0.0
% INFO    : Bus 26304	: V=0.9803483, theta=-26.842617 -> V=1.0, theta=0.0
% INFO    : Bus 26305	: V=0.9715686, theta=-27.475857 -> V=1.0, theta=0.0
% INFO    : Bus 26306	: V=0.9811686, theta=-27.413914 -> V=1.0, theta=0.0
% INFO    : Bus 26307	: V=0.9686945, theta=-28.784418 -> V=1.0, theta=0.0
% INFO    : Bus 26308	: V=0.981544, theta=-27.343083 -> V=1.0, theta=0.0
% INFO    : Bus 26309	: V=0.9937089, theta=-25.221227 -> V=1.0, theta=0.0
% INFO    : Bus 26310	: V=0.9717105, theta=-28.068848 -> V=1.0, theta=0.0
% INFO    : Bus 26311	: V=0.9702838, theta=-28.113528 -> V=1.0, theta=0.0
% INFO    : Bus 26312	: V=0.9759452, theta=-27.988958 -> V=1.0, theta=0.0
% INFO    : Bus 26313	: V=0.977858, theta=-27.786991 -> V=1.0, theta=0.0
% INFO    : Bus 26314	: V=0.9783407, theta=-27.691164 -> V=1.0, theta=0.0
% INFO    : Bus 26315	: V=0.990407, theta=-26.053647 -> V=1.0, theta=0.0
% INFO    : Bus 26316	: V=0.978488, theta=-27.339384 -> V=1.0, theta=0.0
% INFO    : Bus 26317	: V=0.9785486, theta=-27.451647 -> V=1.0, theta=0.0
% INFO    : Bus 26318	: V=0.97367, theta=-27.930854 -> V=1.0, theta=0.0
% INFO    : Bus 26319	: V=0.9682809, theta=-28.059231 -> V=1.0, theta=0.0
% INFO    : Bus 26320	: V=0.970453, theta=-27.987798 -> V=1.0, theta=0.0
% INFO    : Bus 26321	: V=0.9789972, theta=-27.595088 -> V=1.0, theta=0.0
% INFO    : Bus 26322	: V=0.9766418, theta=-27.896299 -> V=1.0, theta=0.0
% INFO    : Bus 26323	: V=0.9754932, theta=-27.605464 -> V=1.0, theta=0.0
% INFO    : Bus 26324	: V=0.9765332, theta=-27.515163 -> V=1.0, theta=0.0
% INFO    : Bus 26325	: V=0.9770897, theta=-27.471543 -> V=1.0, theta=0.0
% INFO    : Bus 26326	: V=0.9774686, theta=-27.438433 -> V=1.0, theta=0.0
% INFO    : Bus 26327	: V=0.9780605, theta=-27.380705 -> V=1.0, theta=0.0
% INFO    : Bus 26328	: V=0.9672819, theta=-28.87386 -> V=1.0, theta=0.0
% INFO    : Bus 26329	: V=0.9685298, theta=-28.795382 -> V=1.0, theta=0.0
% INFO    : Bus 26330	: V=0.9780651, theta=-27.407143 -> V=1.0, theta=0.0
% INFO    : Bus 26331	: V=0.9708277, theta=-28.305899 -> V=1.0, theta=0.0
% INFO    : Bus 26332	: V=0.9720543, theta=-28.281299 -> V=1.0, theta=0.0
% INFO    : Bus 26333	: V=0.9740001, theta=-28.133993 -> V=1.0, theta=0.0
% INFO    : Bus 26334	: V=0.9682945, theta=-28.809256 -> V=1.0, theta=0.0
% INFO    : Bus 26335	: V=0.9794843, theta=-27.96622 -> V=1.0, theta=0.0
% INFO    : Bus 26336	: V=0.97854, theta=-28.042017 -> V=1.0, theta=0.0
% INFO    : Bus 26337	: V=0.980382, theta=-27.869224 -> V=1.0, theta=0.0
% INFO    : Bus 26338	: V=0.9855049, theta=-27.326758 -> V=1.0, theta=0.0
% INFO    : Bus 26339	: V=0.9837718, theta=-27.11234 -> V=1.0, theta=0.0
% INFO    : Bus 26340	: V=0.9862224, theta=-27.015431 -> V=1.0, theta=0.0
% INFO    : Bus 26341	: V=1.003327, theta=-25.686305 -> V=1.0, theta=0.0
% INFO    : Bus 26342	: V=0.9905219, theta=-27.002484 -> V=1.0, theta=0.0
% INFO    : Bus 26343	: V=1.0048935, theta=-25.460386 -> V=1.0, theta=0.0
% INFO    : Bus 26344	: V=0.9931042, theta=-26.541519 -> V=1.0, theta=0.0
% INFO    : Bus 26345	: V=0.993412, theta=-26.746058 -> V=1.0, theta=0.0
% INFO    : Bus 26346	: V=1.0051747, theta=-25.438474 -> V=1.0, theta=0.0
% INFO    : Bus 26347	: V=0.9977294, theta=-26.348194 -> V=1.0, theta=0.0
% INFO    : Bus 26348	: V=0.9998193, theta=-26.118538 -> V=1.0, theta=0.0
% INFO    : Bus 26349	: V=0.9797681, theta=-27.132494 -> V=1.0, theta=0.0
% INFO    : Bus 26350	: V=0.9796884, theta=-27.154059 -> V=1.0, theta=0.0
% INFO    : Bus 26351	: V=0.9799873, theta=-27.070626 -> V=1.0, theta=0.0
% INFO    : Bus 26352	: V=0.9748566, theta=-27.663626 -> V=1.0, theta=0.0
% INFO    : Bus 26353	: V=0.9748715, theta=-27.536181 -> V=1.0, theta=0.0
% INFO    : Bus 26354	: V=0.980531, theta=-26.898521 -> V=1.0, theta=0.0
% INFO    : Bus 26355	: V=0.9809153, theta=-26.924597 -> V=1.0, theta=0.0
% INFO    : Bus 26356	: V=0.994803, theta=-25.07679 -> V=1.0, theta=0.0
% INFO    : Bus 26357	: V=0.9995149, theta=-22.943624 -> V=1.0, theta=0.0
% INFO    : Bus 26358	: V=1.003918, theta=-22.538005 -> V=1.0, theta=0.0
% INFO    : Bus 26359	: V=1.0001762, theta=-22.648008 -> V=1.0, theta=0.0
% INFO    : Bus 26360	: V=1.0016426, theta=-22.496 -> V=1.0, theta=0.0
% INFO    : Bus 26361	: V=1.0031635, theta=-22.408618 -> V=1.0, theta=0.0
% INFO    : Bus 26362	: V=0.9785868, theta=-26.576048 -> V=1.0, theta=0.0
% INFO    : Bus 26363	: V=0.9772005, theta=-26.895516 -> V=1.0, theta=0.0
% INFO    : Bus 26364	: V=0.9746402, theta=-27.042303 -> V=1.0, theta=0.0
% INFO    : Bus 26365	: V=0.9835791, theta=-26.978006 -> V=1.0, theta=0.0
% INFO    : Bus 26366	: V=0.9754217, theta=-27.173381 -> V=1.0, theta=0.0
% INFO    : Bus 26367	: V=0.9762029, theta=-26.987716 -> V=1.0, theta=0.0
% INFO    : Bus 26368	: V=0.9831079, theta=-25.511179 -> V=1.0, theta=0.0
% INFO    : Bus 26369	: V=0.9764284, theta=-27.19187 -> V=1.0, theta=0.0
% INFO    : Bus 26370	: V=0.979405, theta=-27.177725 -> V=1.0, theta=0.0
% INFO    : Bus 26371	: V=0.9802813, theta=-26.212818 -> V=1.0, theta=0.0
% INFO    : Bus 26372	: V=0.9866083, theta=-27.547299 -> V=1.0, theta=0.0
% INFO    : Bus 26373	: V=0.9787369, theta=-27.286844 -> V=1.0, theta=0.0
% INFO    : Bus 26374	: V=0.9845162, theta=-31.418313 -> V=1.0, theta=0.0
% INFO    : Bus 26375	: V=0.9500296, theta=-37.143523 -> V=1.0, theta=0.0
% INFO    : Bus 26376	: V=0.9650507, theta=-32.813672 -> V=1.0, theta=0.0
% INFO    : Bus 26377	: V=0.9532889, theta=-36.938465 -> V=1.0, theta=0.0
% INFO    : Bus 26378	: V=0.9552818, theta=-36.794859 -> V=1.0, theta=0.0
% INFO    : Bus 26379	: V=0.986664, theta=-31.041137 -> V=1.0, theta=0.0
% INFO    : Bus 26380	: V=0.956911, theta=-36.38548 -> V=1.0, theta=0.0
% INFO    : Bus 26381	: V=0.9501761, theta=-37.302985 -> V=1.0, theta=0.0
% INFO    : Bus 26382	: V=0.952212, theta=-37.179232 -> V=1.0, theta=0.0
% INFO    : Bus 26383	: V=0.9618473, theta=-33.40381 -> V=1.0, theta=0.0
% INFO    : Bus 26384	: V=0.9589349, theta=-34.878687 -> V=1.0, theta=0.0
% INFO    : Bus 26385	: V=0.9609486, theta=-34.562661 -> V=1.0, theta=0.0
% INFO    : Bus 26386	: V=0.9648403, theta=-33.297981 -> V=1.0, theta=0.0
% INFO    : Bus 26387	: V=0.9541283, theta=-37.617729 -> V=1.0, theta=0.0
% INFO    : Bus 26388	: V=0.9568488, theta=-36.853119 -> V=1.0, theta=0.0
% INFO    : Bus 26389	: V=0.9489715, theta=-32.747008 -> V=1.0, theta=0.0
% INFO    : Bus 26390	: V=0.9593432, theta=-32.302331 -> V=1.0, theta=0.0
% INFO    : Bus 26391	: V=0.9664982, theta=-33.763664 -> V=1.0, theta=0.0
% INFO    : Bus 26392	: V=0.9578819, theta=-36.497902 -> V=1.0, theta=0.0
% INFO    : Bus 26393	: V=0.9497858, theta=-39.644983 -> V=1.0, theta=0.0
% INFO    : Bus 26394	: V=0.9952709, theta=-50.44275 -> V=1.0, theta=0.0
% INFO    : Bus 26395	: V=0.9742837, theta=-50.471658 -> V=1.0, theta=0.0
% INFO    : Bus 26396	: V=0.9863297, theta=-45.855023 -> V=1.0, theta=0.0
% INFO    : Bus 26397	: V=0.9900621, theta=-46.074712 -> V=1.0, theta=0.0
% INFO    : Bus 26398	: V=0.9930541, theta=-48.834782 -> V=1.0, theta=0.0
% INFO    : Bus 26399	: V=0.9876008, theta=-29.216712 -> V=1.0, theta=0.0
% INFO    : Bus 26400	: V=0.9880555, theta=-28.392964 -> V=1.0, theta=0.0
% INFO    : Bus 26401	: V=0.9866039, theta=-28.90421 -> V=1.0, theta=0.0
% INFO    : Bus 26402	: V=0.9865119, theta=-29.629894 -> V=1.0, theta=0.0
% INFO    : Bus 26403	: V=0.9745992, theta=-30.246198 -> V=1.0, theta=0.0
% INFO    : Bus 26404	: V=0.9743446, theta=-30.968513 -> V=1.0, theta=0.0
% INFO    : Bus 26405	: V=0.9865363, theta=-29.257554 -> V=1.0, theta=0.0
% INFO    : Bus 26406	: V=0.9917141, theta=-31.998764 -> V=1.0, theta=0.0
% INFO    : Bus 26407	: V=0.9898737, theta=-31.762646 -> V=1.0, theta=0.0
% INFO    : Bus 26408	: V=0.9870486, theta=-30.957698 -> V=1.0, theta=0.0
% INFO    : Bus 26409	: V=0.990041, theta=-29.003922 -> V=1.0, theta=0.0
% INFO    : Bus 26410	: V=0.9880373, theta=-29.861814 -> V=1.0, theta=0.0
% INFO    : Bus 26411	: V=0.9832954, theta=-30.714653 -> V=1.0, theta=0.0
% INFO    : Bus 26412	: V=0.9952362, theta=-30.864493 -> V=1.0, theta=0.0
% INFO    : Bus 26413	: V=0.9999728, theta=-29.681264 -> V=1.0, theta=0.0
% INFO    : Bus 26414	: V=0.9938691, theta=-27.729675 -> V=1.0, theta=0.0
% INFO    : Bus 26415	: V=0.9908709, theta=-37.021318 -> V=1.0, theta=0.0
% INFO    : Bus 26416	: V=0.9922335, theta=-35.071649 -> V=1.0, theta=0.0
% INFO    : Bus 26417	: V=0.9975122, theta=-35.62569 -> V=1.0, theta=0.0
% INFO    : Bus 26418	: V=0.9955079, theta=-36.265342 -> V=1.0, theta=0.0
% INFO    : Bus 26419	: V=0.997127, theta=-35.827881 -> V=1.0, theta=0.0
% INFO    : Bus 26420	: V=1.0009248, theta=-35.110902 -> V=1.0, theta=0.0
% INFO    : Bus 26421	: V=1.000069, theta=-35.002914 -> V=1.0, theta=0.0
% INFO    : Bus 26422	: V=0.9760706, theta=-49.812439 -> V=1.0, theta=0.0
% INFO    : Bus 26423	: V=0.9648145, theta=-51.189138 -> V=1.0, theta=0.0
% INFO    : Bus 26424	: V=0.9783253, theta=-49.25887 -> V=1.0, theta=0.0
% INFO    : Bus 26425	: V=0.9801336, theta=-48.032847 -> V=1.0, theta=0.0
% INFO    : Bus 26426	: V=0.9853474, theta=-46.875903 -> V=1.0, theta=0.0
% INFO    : Bus 26427	: V=0.9808365, theta=-48.248712 -> V=1.0, theta=0.0
% INFO    : Bus 26428	: V=0.9802391, theta=-48.245708 -> V=1.0, theta=0.0
% INFO    : Bus 26429	: V=0.9774048, theta=-48.667571 -> V=1.0, theta=0.0
% INFO    : Bus 26430	: V=0.9691257, theta=-44.515418 -> V=1.0, theta=0.0
% INFO    : Bus 26431	: V=0.9724072, theta=-43.545231 -> V=1.0, theta=0.0
% INFO    : Bus 26432	: V=0.9655219, theta=-44.937656 -> V=1.0, theta=0.0
% INFO    : Bus 26433	: V=0.9698218, theta=-43.553425 -> V=1.0, theta=0.0
% INFO    : Bus 26434	: V=0.9690756, theta=-43.649596 -> V=1.0, theta=0.0
% INFO    : Bus 26435	: V=0.9588176, theta=-45.417255 -> V=1.0, theta=0.0
% INFO    : Bus 26436	: V=0.9691907, theta=-42.486865 -> V=1.0, theta=0.0
% INFO    : Bus 26437	: V=0.9564686, theta=-47.831834 -> V=1.0, theta=0.0
% INFO    : Bus 26438	: V=0.9506705, theta=-47.868946 -> V=1.0, theta=0.0
% INFO    : Bus 26439	: V=0.9541412, theta=-48.545279 -> V=1.0, theta=0.0
% INFO    : Bus 26440	: V=0.9571571, theta=-49.419726 -> V=1.0, theta=0.0
% INFO    : Bus 26441	: V=0.958446, theta=-46.927932 -> V=1.0, theta=0.0
% INFO    : Bus 26442	: V=0.9674441, theta=-49.57635 -> V=1.0, theta=0.0
% INFO    : Bus 26443	: V=0.9959153, theta=-31.918199 -> V=1.0, theta=0.0
% INFO    : Bus 26444	: V=0.963349, theta=-34.731379 -> V=1.0, theta=0.0
% INFO    : Bus 26445	: V=0.9573321, theta=-34.448338 -> V=1.0, theta=0.0
% INFO    : Bus 26446	: V=0.961909, theta=-34.22516 -> V=1.0, theta=0.0
% INFO    : Bus 26447	: V=0.9563956, theta=-34.680896 -> V=1.0, theta=0.0
% INFO    : Bus 26448	: V=0.9820395, theta=-32.417402 -> V=1.0, theta=0.0
% INFO    : Bus 26449	: V=0.9786046, theta=-31.476209 -> V=1.0, theta=0.0
% INFO    : Bus 26450	: V=1.0182372, theta=-51.288565 -> V=1.0, theta=0.0
% INFO    : Bus 26451	: V=1.0102631, theta=-52.436779 -> V=1.0, theta=0.0
% INFO    : Bus 26452	: V=1.0085942, theta=-52.499527 -> V=1.0, theta=0.0
% INFO    : Bus 26453	: V=1.0105294, theta=-52.379658 -> V=1.0, theta=0.0
% INFO    : Bus 26454	: V=1.0088086, theta=-52.29751 -> V=1.0, theta=0.0
% INFO    : Bus 26455	: V=1.0173871, theta=-50.959993 -> V=1.0, theta=0.0
% INFO    : Bus 26456	: V=1.00994, theta=-52.382767 -> V=1.0, theta=0.0
% INFO    : Bus 26457	: V=1.0084298, theta=-52.513501 -> V=1.0, theta=0.0
% INFO    : Bus 26458	: V=1.0100172, theta=-52.420983 -> V=1.0, theta=0.0
% INFO    : Bus 26459	: V=1.0005291, theta=-54.35228 -> V=1.0, theta=0.0
% INFO    : Bus 26460	: V=0.9965354, theta=-53.953582 -> V=1.0, theta=0.0
% INFO    : Bus 26461	: V=1.0191752, theta=-52.66764 -> V=1.0, theta=0.0
% INFO    : Bus 26462	: V=1.0189792, theta=-52.445278 -> V=1.0, theta=0.0
% INFO    : Bus 26463	: V=1.0067359, theta=-53.658408 -> V=1.0, theta=0.0
% INFO    : Bus 26464	: V=1.0091782, theta=-52.705103 -> V=1.0, theta=0.0
% INFO    : Bus 26465	: V=0.999804, theta=-52.336129 -> V=1.0, theta=0.0
% INFO    : Bus 26466	: V=1.0171872, theta=-50.990189 -> V=1.0, theta=0.0
% INFO    : Bus 26467	: V=1.018576, theta=-50.787853 -> V=1.0, theta=0.0
% INFO    : Bus 26468	: V=1.0197185, theta=-49.781145 -> V=1.0, theta=0.0
% INFO    : Bus 26469	: V=1.0072504, theta=-50.700049 -> V=1.0, theta=0.0
% INFO    : Bus 26470	: V=1.0051985, theta=-50.1828 -> V=1.0, theta=0.0
% INFO    : Bus 26471	: V=0.9903197, theta=-51.506482 -> V=1.0, theta=0.0
% INFO    : Bus 26472	: V=1.0047136, theta=-49.886771 -> V=1.0, theta=0.0
% INFO    : Bus 26473	: V=0.9937362, theta=-43.038383 -> V=1.0, theta=0.0
% INFO    : Bus 26474	: V=0.9818645, theta=-45.70885 -> V=1.0, theta=0.0
% INFO    : Bus 26475	: V=0.9787005, theta=-46.289563 -> V=1.0, theta=0.0
% INFO    : Bus 26476	: V=0.9696191, theta=-47.150993 -> V=1.0, theta=0.0
% INFO    : Bus 26477	: V=0.9643061, theta=-47.05531 -> V=1.0, theta=0.0
% INFO    : Bus 26478	: V=0.9765845, theta=-45.807143 -> V=1.0, theta=0.0
% INFO    : Bus 26479	: V=0.9684785, theta=-46.640487 -> V=1.0, theta=0.0
% INFO    : Bus 26480	: V=0.9738779, theta=-46.056404 -> V=1.0, theta=0.0
% INFO    : Bus 26481	: V=0.9704892, theta=-44.803447 -> V=1.0, theta=0.0
% INFO    : Bus 26482	: V=0.9753094, theta=-45.232172 -> V=1.0, theta=0.0
% INFO    : Bus 26483	: V=0.9891044, theta=-42.882759 -> V=1.0, theta=0.0
% INFO    : Bus 26484	: V=0.9602859, theta=-46.774787 -> V=1.0, theta=0.0
% INFO    : Bus 26485	: V=0.9896552, theta=-51.860192 -> V=1.0, theta=0.0
% INFO    : Bus 26486	: V=0.99143, theta=-51.860721 -> V=1.0, theta=0.0
% INFO    : Bus 26487	: V=1.0011421, theta=-50.64552 -> V=1.0, theta=0.0
% INFO    : Bus 26488	: V=0.989205, theta=-51.97256 -> V=1.0, theta=0.0
% INFO    : Bus 26489	: V=0.9996403, theta=-50.724844 -> V=1.0, theta=0.0
% INFO    : Bus 26490	: V=1.0040126, theta=-49.953387 -> V=1.0, theta=0.0
% INFO    : Bus 26491	: V=0.9858135, theta=-52.359205 -> V=1.0, theta=0.0
% INFO    : Bus 26492	: V=0.9858556, theta=-52.297197 -> V=1.0, theta=0.0
% INFO    : Bus 26493	: V=1.0023693, theta=-50.025119 -> V=1.0, theta=0.0
% INFO    : Bus 26494	: V=0.9814884, theta=-52.374057 -> V=1.0, theta=0.0
% INFO    : Bus 26495	: V=0.9847277, theta=-52.208751 -> V=1.0, theta=0.0
% INFO    : Bus 26496	: V=1.0061094, theta=-49.854488 -> V=1.0, theta=0.0
% INFO    : Bus 26497	: V=0.9862117, theta=-52.374736 -> V=1.0, theta=0.0
% INFO    : Bus 26498	: V=0.9897611, theta=-51.931929 -> V=1.0, theta=0.0
% INFO    : Bus 26499	: V=0.9913746, theta=-51.837082 -> V=1.0, theta=0.0
% INFO    : Bus 26500	: V=0.9945987, theta=-51.78538 -> V=1.0, theta=0.0
% INFO    : Bus 26501	: V=1.0030237, theta=-50.787008 -> V=1.0, theta=0.0
% INFO    : Bus 26502	: V=1.0037931, theta=-50.66587 -> V=1.0, theta=0.0
% INFO    : Bus 26503	: V=1.0046808, theta=-50.524039 -> V=1.0, theta=0.0
% INFO    : Bus 26504	: V=1.011726, theta=-49.494758 -> V=1.0, theta=0.0
% INFO    : Bus 26505	: V=1.0082887, theta=-49.714139 -> V=1.0, theta=0.0
% INFO    : Bus 26506	: V=0.9946524, theta=-51.80441 -> V=1.0, theta=0.0
% INFO    : Bus 26507	: V=0.9939675, theta=-51.858393 -> V=1.0, theta=0.0
% INFO    : Bus 26508	: V=0.9983237, theta=-51.546474 -> V=1.0, theta=0.0
% INFO    : Bus 26509	: V=1.0025106, theta=-51.10637 -> V=1.0, theta=0.0
% INFO    : Bus 26510	: V=1.0012195, theta=-51.134425 -> V=1.0, theta=0.0
% INFO    : Bus 26511	: V=1.0019406, theta=-50.974456 -> V=1.0, theta=0.0
% INFO    : Bus 26512	: V=0.9949757, theta=-51.759506 -> V=1.0, theta=0.0
% INFO    : Bus 26513	: V=0.989516, theta=-52.158211 -> V=1.0, theta=0.0
% INFO    : Bus 26514	: V=0.998154, theta=-51.563736 -> V=1.0, theta=0.0
% INFO    : Bus 26515	: V=0.9938755, theta=-51.902804 -> V=1.0, theta=0.0
% INFO    : Bus 26516	: V=0.9954756, theta=-52.113912 -> V=1.0, theta=0.0
% INFO    : Bus 26517	: V=1.005473, theta=-50.943705 -> V=1.0, theta=0.0
% INFO    : Bus 26518	: V=1.0074256, theta=-50.817264 -> V=1.0, theta=0.0
% INFO    : Bus 26519	: V=1.0003785, theta=-51.54847 -> V=1.0, theta=0.0
% INFO    : Bus 26520	: V=0.9980686, theta=-51.657662 -> V=1.0, theta=0.0
% INFO    : Bus 26521	: V=1.0146046, theta=-49.914017 -> V=1.0, theta=0.0
% INFO    : Bus 26522	: V=1.007744, theta=-50.787168 -> V=1.0, theta=0.0
% INFO    : Bus 26523	: V=1.002762, theta=-51.12829 -> V=1.0, theta=0.0
% INFO    : Bus 26524	: V=1.0152606, theta=-49.939323 -> V=1.0, theta=0.0
% INFO    : Bus 26525	: V=1.0152382, theta=-49.899889 -> V=1.0, theta=0.0
% INFO    : Bus 26526	: V=0.9931576, theta=-51.958187 -> V=1.0, theta=0.0
% INFO    : Bus 26527	: V=0.9952068, theta=-51.723683 -> V=1.0, theta=0.0
% INFO    : Bus 26528	: V=0.9872053, theta=-52.537763 -> V=1.0, theta=0.0
% INFO    : Bus 26529	: V=0.9959194, theta=-53.093761 -> V=1.0, theta=0.0
% INFO    : Bus 26530	: V=1.0172732, theta=-49.789296 -> V=1.0, theta=0.0
% INFO    : Bus 26531	: V=1.0039951, theta=-51.712516 -> V=1.0, theta=0.0
% INFO    : Bus 26532	: V=1.018665, theta=-50.126348 -> V=1.0, theta=0.0
% INFO    : Bus 26533	: V=1.0107075, theta=-50.895978 -> V=1.0, theta=0.0
% INFO    : Bus 26534	: V=1.0080366, theta=-51.159702 -> V=1.0, theta=0.0
% INFO    : Bus 26535	: V=1.0065727, theta=-51.190655 -> V=1.0, theta=0.0
% INFO    : Bus 26536	: V=1.0100412, theta=-51.25431 -> V=1.0, theta=0.0
% INFO    : Bus 26537	: V=1.0089516, theta=-51.147185 -> V=1.0, theta=0.0
% INFO    : Bus 26538	: V=1.004152, theta=-51.031244 -> V=1.0, theta=0.0
% INFO    : Bus 26539	: V=1.0189392, theta=-49.691557 -> V=1.0, theta=0.0
% INFO    : Bus 26540	: V=0.9848789, theta=-52.339022 -> V=1.0, theta=0.0
% INFO    : Bus 26541	: V=1.0119469, theta=-49.880795 -> V=1.0, theta=0.0
% INFO    : Bus 26542	: V=1.0038586, theta=-50.505516 -> V=1.0, theta=0.0
% INFO    : Bus 26543	: V=1.0089756, theta=-30.315815 -> V=1.0, theta=0.0
% INFO    : Bus 26544	: V=1.0066941, theta=-30.280303 -> V=1.0, theta=0.0
% INFO    : Bus 26545	: V=1.0066249, theta=-30.184348 -> V=1.0, theta=0.0
% INFO    : Bus 26546	: V=1.0078801, theta=-29.736343 -> V=1.0, theta=0.0
% INFO    : Bus 26547	: V=0.9982855, theta=-31.978499 -> V=1.0, theta=0.0
% INFO    : Bus 26548	: V=1.0030705, theta=-29.861136 -> V=1.0, theta=0.0
% INFO    : Bus 26549	: V=1.0102893, theta=-27.723755 -> V=1.0, theta=0.0
% INFO    : Bus 26550	: V=1.0070489, theta=-29.829662 -> V=1.0, theta=0.0
% INFO    : Bus 26551	: V=1.0062188, theta=-30.674617 -> V=1.0, theta=0.0
% INFO    : Bus 26552	: V=0.9967355, theta=-33.244396 -> V=1.0, theta=0.0
% INFO    : Bus 26553	: V=1.0064793, theta=-31.208123 -> V=1.0, theta=0.0
% INFO    : Bus 26554	: V=1.0086974, theta=-31.703435 -> V=1.0, theta=0.0
% INFO    : Bus 26555	: V=0.9973135, theta=-33.811893 -> V=1.0, theta=0.0
% INFO    : Bus 26556	: V=0.9959741, theta=-33.796002 -> V=1.0, theta=0.0
% INFO    : Bus 26557	: V=0.993798, theta=-34.165389 -> V=1.0, theta=0.0
% INFO    : Bus 26558	: V=0.9953854, theta=-33.543619 -> V=1.0, theta=0.0
% INFO    : Bus 26559	: V=0.9554586, theta=-44.7715 -> V=1.0, theta=0.0
% INFO    : Bus 26560	: V=0.9556044, theta=-44.745129 -> V=1.0, theta=0.0
% INFO    : Bus 26561	: V=0.9555101, theta=-44.806746 -> V=1.0, theta=0.0
% INFO    : Bus 26562	: V=0.9563004, theta=-44.808979 -> V=1.0, theta=0.0
% INFO    : Bus 26563	: V=0.9675265, theta=-43.60683 -> V=1.0, theta=0.0
% INFO    : Bus 26564	: V=0.9700951, theta=-43.343131 -> V=1.0, theta=0.0
% INFO    : Bus 26565	: V=0.9722649, theta=-43.139175 -> V=1.0, theta=0.0
% INFO    : Bus 26566	: V=0.9674667, theta=-43.115827 -> V=1.0, theta=0.0
% INFO    : Bus 26567	: V=0.9663577, theta=-43.376447 -> V=1.0, theta=0.0
% INFO    : Bus 26568	: V=0.9659926, theta=-43.634841 -> V=1.0, theta=0.0
% INFO    : Bus 26569	: V=0.9568615, theta=-44.689538 -> V=1.0, theta=0.0
% INFO    : Bus 26570	: V=0.9594427, theta=-44.681739 -> V=1.0, theta=0.0
% INFO    : Bus 26571	: V=0.9655752, theta=-43.834202 -> V=1.0, theta=0.0
% INFO    : Bus 26572	: V=0.9657815, theta=-43.919712 -> V=1.0, theta=0.0
% INFO    : Bus 26573	: V=0.9627256, theta=-43.941569 -> V=1.0, theta=0.0
% INFO    : Bus 26574	: V=0.9662765, theta=-44.065913 -> V=1.0, theta=0.0
% INFO    : Bus 26575	: V=0.9599316, theta=-46.726692 -> V=1.0, theta=0.0
% INFO    : Bus 26576	: V=0.9604632, theta=-46.464904 -> V=1.0, theta=0.0
% INFO    : Bus 26577	: V=0.9545299, theta=-44.224561 -> V=1.0, theta=0.0
% INFO    : Bus 26578	: V=0.9612093, theta=-43.359537 -> V=1.0, theta=0.0
% INFO    : Bus 26579	: V=0.9598658, theta=-43.335737 -> V=1.0, theta=0.0
% INFO    : Bus 26580	: V=0.9639867, theta=-42.594977 -> V=1.0, theta=0.0
% INFO    : Bus 26581	: V=0.961818, theta=-43.390205 -> V=1.0, theta=0.0
% INFO    : Bus 26582	: V=0.9631119, theta=-43.375598 -> V=1.0, theta=0.0
% INFO    : Bus 26583	: V=0.963511, theta=-43.616852 -> V=1.0, theta=0.0
% INFO    : Bus 26584	: V=0.9703155, theta=-41.768689 -> V=1.0, theta=0.0
% INFO    : Bus 26585	: V=0.9582172, theta=-44.717713 -> V=1.0, theta=0.0
% INFO    : Bus 26586	: V=0.982788, theta=-40.258788 -> V=1.0, theta=0.0
% INFO    : Bus 26587	: V=0.9715297, theta=-42.448675 -> V=1.0, theta=0.0
% INFO    : Bus 26588	: V=0.9797033, theta=-42.454663 -> V=1.0, theta=0.0
% INFO    : Bus 26589	: V=0.9550432, theta=-44.750674 -> V=1.0, theta=0.0
% INFO    : Bus 26590	: V=0.9665351, theta=-43.275105 -> V=1.0, theta=0.0
% INFO    : Bus 26591	: V=0.9285666, theta=-41.072015 -> V=1.0, theta=0.0
% INFO    : Bus 26592	: V=0.9489808, theta=-36.463427 -> V=1.0, theta=0.0
% INFO    : Bus 26593	: V=0.9521913, theta=-34.889301 -> V=1.0, theta=0.0
% INFO    : Bus 26594	: V=0.9565747, theta=-34.17941 -> V=1.0, theta=0.0
% INFO    : Bus 26595	: V=0.9536283, theta=-34.972045 -> V=1.0, theta=0.0
% INFO    : Bus 26596	: V=0.9404584, theta=-36.472182 -> V=1.0, theta=0.0
% INFO    : Bus 26597	: V=0.9447637, theta=-37.809409 -> V=1.0, theta=0.0
% INFO    : Bus 26598	: V=0.9451136, theta=-37.79927 -> V=1.0, theta=0.0
% INFO    : Bus 26599	: V=0.9446925, theta=-38.091617 -> V=1.0, theta=0.0
% INFO    : Bus 26600	: V=0.9438581, theta=-39.140659 -> V=1.0, theta=0.0
% INFO    : Bus 26601	: V=0.9442271, theta=-37.963079 -> V=1.0, theta=0.0
% INFO    : Bus 26602	: V=0.9809973, theta=-48.306193 -> V=1.0, theta=0.0
% INFO    : Bus 26603	: V=0.982909, theta=-47.922073 -> V=1.0, theta=0.0
% INFO    : Bus 26604	: V=0.9934193, theta=-46.028184 -> V=1.0, theta=0.0
% INFO    : Bus 26605	: V=0.9756324, theta=-49.391774 -> V=1.0, theta=0.0
% INFO    : Bus 26606	: V=0.9930946, theta=-45.821593 -> V=1.0, theta=0.0
% INFO    : Bus 26607	: V=0.9819105, theta=-47.948198 -> V=1.0, theta=0.0
% INFO    : Bus 26608	: V=0.9819052, theta=-47.177815 -> V=1.0, theta=0.0
% INFO    : Bus 26609	: V=0.9822611, theta=-47.110104 -> V=1.0, theta=0.0
% INFO    : Bus 26610	: V=0.9837928, theta=-46.813792 -> V=1.0, theta=0.0
% INFO    : Bus 26611	: V=0.9890017, theta=-46.397061 -> V=1.0, theta=0.0
% INFO    : Bus 26612	: V=0.9883816, theta=-46.291493 -> V=1.0, theta=0.0
% INFO    : Bus 26613	: V=0.986579, theta=-46.068946 -> V=1.0, theta=0.0
% INFO    : Bus 26614	: V=0.985164, theta=-46.438077 -> V=1.0, theta=0.0
% INFO    : Bus 26615	: V=0.9825882, theta=-47.054965 -> V=1.0, theta=0.0
% INFO    : Bus 26616	: V=0.9815714, theta=-47.293292 -> V=1.0, theta=0.0
% INFO    : Bus 26617	: V=0.9822481, theta=-47.069526 -> V=1.0, theta=0.0
% INFO    : Bus 26618	: V=0.9833913, theta=-46.648076 -> V=1.0, theta=0.0
% INFO    : Bus 26619	: V=0.983481, theta=-46.746677 -> V=1.0, theta=0.0
% INFO    : Bus 26620	: V=0.9828105, theta=-46.908761 -> V=1.0, theta=0.0
% INFO    : Bus 26621	: V=0.9810455, theta=-47.363857 -> V=1.0, theta=0.0
% INFO    : Bus 26622	: V=0.9752507, theta=-47.811975 -> V=1.0, theta=0.0
% INFO    : Bus 26623	: V=0.9800535, theta=-47.468819 -> V=1.0, theta=0.0
% INFO    : Bus 26624	: V=0.9771544, theta=-47.696984 -> V=1.0, theta=0.0
% INFO    : Bus 26625	: V=0.9779241, theta=-47.527324 -> V=1.0, theta=0.0
% INFO    : Bus 26626	: V=0.9792082, theta=-47.23003 -> V=1.0, theta=0.0
% INFO    : Bus 26627	: V=0.9842549, theta=-46.587757 -> V=1.0, theta=0.0
% INFO    : Bus 26628	: V=0.9811672, theta=-47.607719 -> V=1.0, theta=0.0
% INFO    : Bus 26629	: V=0.9772295, theta=-45.956586 -> V=1.0, theta=0.0
% INFO    : Bus 26630	: V=0.9767849, theta=-47.548042 -> V=1.0, theta=0.0
% INFO    : Bus 26631	: V=0.9947853, theta=-44.659525 -> V=1.0, theta=0.0
% INFO    : Bus 26632	: V=0.9800637, theta=-46.729557 -> V=1.0, theta=0.0
% INFO    : Bus 26633	: V=0.9783597, theta=-47.207701 -> V=1.0, theta=0.0
% INFO    : Bus 26634	: V=0.9925006, theta=-45.216032 -> V=1.0, theta=0.0
% INFO    : Bus 26635	: V=0.9772337, theta=-48.302757 -> V=1.0, theta=0.0
% INFO    : Bus 26636	: V=0.9674976, theta=-48.211863 -> V=1.0, theta=0.0
% INFO    : Bus 26637	: V=0.9720311, theta=-49.335579 -> V=1.0, theta=0.0
% INFO    : Bus 26638	: V=0.9717338, theta=-49.585748 -> V=1.0, theta=0.0
% INFO    : Bus 26639	: V=0.979402, theta=-47.539518 -> V=1.0, theta=0.0
% INFO    : Bus 26640	: V=0.9788126, theta=-47.604762 -> V=1.0, theta=0.0
% INFO    : Bus 26641	: V=0.977424, theta=-47.942335 -> V=1.0, theta=0.0
% INFO    : Bus 26642	: V=0.9758455, theta=-48.33163 -> V=1.0, theta=0.0
% INFO    : Bus 26643	: V=0.9696063, theta=-49.653287 -> V=1.0, theta=0.0
% INFO    : Bus 26644	: V=0.9687632, theta=-49.877796 -> V=1.0, theta=0.0
% INFO    : Bus 26645	: V=0.9748812, theta=-48.562954 -> V=1.0, theta=0.0
% INFO    : Bus 26646	: V=0.9916592, theta=-45.654758 -> V=1.0, theta=0.0
% INFO    : Bus 26647	: V=0.977602, theta=-47.939983 -> V=1.0, theta=0.0
% INFO    : Bus 26648	: V=0.9782348, theta=-47.981138 -> V=1.0, theta=0.0
% INFO    : Bus 26649	: V=0.9740683, theta=-48.713133 -> V=1.0, theta=0.0
% INFO    : Bus 26650	: V=0.9735895, theta=-48.815738 -> V=1.0, theta=0.0
% INFO    : Bus 26651	: V=0.9686042, theta=-50.067857 -> V=1.0, theta=0.0
% INFO    : Bus 26652	: V=0.9755011, theta=-48.095601 -> V=1.0, theta=0.0
% INFO    : Bus 26653	: V=0.9775681, theta=-47.99737 -> V=1.0, theta=0.0
% INFO    : Bus 26654	: V=0.9766582, theta=-48.065191 -> V=1.0, theta=0.0
% INFO    : Bus 26655	: V=0.9711766, theta=-48.153315 -> V=1.0, theta=0.0
% INFO    : Bus 26656	: V=0.9719222, theta=-50.268971 -> V=1.0, theta=0.0
% INFO    : Bus 26657	: V=0.9741541, theta=-49.811259 -> V=1.0, theta=0.0
% INFO    : Bus 26658	: V=0.9730975, theta=-50.02154 -> V=1.0, theta=0.0
% INFO    : Bus 26659	: V=0.9768915, theta=-49.305951 -> V=1.0, theta=0.0
% INFO    : Bus 26660	: V=0.9712441, theta=-50.435687 -> V=1.0, theta=0.0
% INFO    : Bus 26661	: V=0.9699773, theta=-50.533587 -> V=1.0, theta=0.0
% INFO    : Bus 26662	: V=0.961499, theta=-52.821749 -> V=1.0, theta=0.0
% INFO    : Bus 26663	: V=0.9625716, theta=-52.317212 -> V=1.0, theta=0.0
% INFO    : Bus 26664	: V=0.9695013, theta=-50.575407 -> V=1.0, theta=0.0
% INFO    : Bus 26665	: V=0.9689492, theta=-50.357803 -> V=1.0, theta=0.0
% INFO    : Bus 26666	: V=0.9697027, theta=-46.942035 -> V=1.0, theta=0.0
% INFO    : Bus 26667	: V=0.9632998, theta=-48.256194 -> V=1.0, theta=0.0
% INFO    : Bus 26668	: V=0.9644902, theta=-49.985083 -> V=1.0, theta=0.0
% INFO    : Bus 26669	: V=0.9709302, theta=-50.151445 -> V=1.0, theta=0.0
% INFO    : Bus 26670	: V=0.9675202, theta=-49.332466 -> V=1.0, theta=0.0
% INFO    : Bus 26671	: V=0.9668897, theta=-49.545555 -> V=1.0, theta=0.0
% INFO    : Bus 26672	: V=0.9960117, theta=-44.290712 -> V=1.0, theta=0.0
% INFO    : Bus 26673	: V=0.9862834, theta=-46.526225 -> V=1.0, theta=0.0
% INFO    : Bus 26674	: V=0.9791997, theta=-48.68419 -> V=1.0, theta=0.0
% INFO    : Bus 26675	: V=0.9599085, theta=-33.23328 -> V=1.0, theta=0.0
% INFO    : Bus 26676	: V=0.971772, theta=-31.752529 -> V=1.0, theta=0.0
% INFO    : Bus 26677	: V=0.9728322, theta=-31.65776 -> V=1.0, theta=0.0
% INFO    : Bus 26678	: V=0.9649658, theta=-32.758125 -> V=1.0, theta=0.0
% INFO    : Bus 26679	: V=0.9578191, theta=-33.20655 -> V=1.0, theta=0.0
% INFO    : Bus 26680	: V=0.9661306, theta=-32.740968 -> V=1.0, theta=0.0
% INFO    : Bus 26681	: V=0.9763845, theta=-32.103713 -> V=1.0, theta=0.0
% INFO    : Bus 26682	: V=0.9806901, theta=-31.359561 -> V=1.0, theta=0.0
% INFO    : Bus 26683	: V=0.9828877, theta=-31.157581 -> V=1.0, theta=0.0
% INFO    : Bus 26684	: V=0.9852819, theta=-31.043511 -> V=1.0, theta=0.0
% INFO    : Bus 26685	: V=0.9820624, theta=-31.332525 -> V=1.0, theta=0.0
% INFO    : Bus 26686	: V=0.9578718, theta=-33.246937 -> V=1.0, theta=0.0
% INFO    : Bus 26687	: V=0.9583251, theta=-33.238936 -> V=1.0, theta=0.0
% INFO    : Bus 26688	: V=0.9595134, theta=-33.174378 -> V=1.0, theta=0.0
% INFO    : Bus 26689	: V=0.9599801, theta=-33.126307 -> V=1.0, theta=0.0
% INFO    : Bus 26690	: V=0.9622407, theta=-32.95355 -> V=1.0, theta=0.0
% INFO    : Bus 26691	: V=0.9697572, theta=-32.603221 -> V=1.0, theta=0.0
% INFO    : Bus 26692	: V=0.9769124, theta=-31.566027 -> V=1.0, theta=0.0
% INFO    : Bus 26693	: V=0.9777452, theta=-31.509999 -> V=1.0, theta=0.0
% INFO    : Bus 26694	: V=0.9708599, theta=-32.52942 -> V=1.0, theta=0.0
% INFO    : Bus 26695	: V=0.9738081, theta=-32.438452 -> V=1.0, theta=0.0
% INFO    : Bus 26696	: V=0.9690277, theta=-32.669976 -> V=1.0, theta=0.0
% INFO    : Bus 26697	: V=0.9757001, theta=-31.646702 -> V=1.0, theta=0.0
% INFO    : Bus 26698	: V=0.9691447, theta=-32.645664 -> V=1.0, theta=0.0
% INFO    : Bus 26699	: V=0.9604337, theta=-33.144894 -> V=1.0, theta=0.0
% INFO    : Bus 26700	: V=0.9615613, theta=-33.099588 -> V=1.0, theta=0.0
% INFO    : Bus 26701	: V=0.9731186, theta=-31.79964 -> V=1.0, theta=0.0
% INFO    : Bus 26702	: V=0.9739395, theta=-31.753488 -> V=1.0, theta=0.0
% INFO    : Bus 26703	: V=0.9681548, theta=-32.685992 -> V=1.0, theta=0.0
% INFO    : Bus 26704	: V=0.9672141, theta=-32.762013 -> V=1.0, theta=0.0
% INFO    : Bus 26705	: V=0.9693408, theta=-32.673087 -> V=1.0, theta=0.0
% INFO    : Bus 26706	: V=0.9796726, theta=-31.569503 -> V=1.0, theta=0.0
% INFO    : Bus 26707	: V=0.9720063, theta=-31.935426 -> V=1.0, theta=0.0
% INFO    : Bus 26708	: V=0.962395, theta=-33.068142 -> V=1.0, theta=0.0
% INFO    : Bus 26709	: V=0.966699, theta=-32.810975 -> V=1.0, theta=0.0
% INFO    : Bus 26710	: V=0.9661374, theta=-32.84932 -> V=1.0, theta=0.0
% INFO    : Bus 26711	: V=0.9612742, theta=-33.123508 -> V=1.0, theta=0.0
% INFO    : Bus 26712	: V=0.9651042, theta=-32.909018 -> V=1.0, theta=0.0
% INFO    : Bus 26713	: V=0.9657647, theta=-32.896674 -> V=1.0, theta=0.0
% INFO    : Bus 26714	: V=0.96032, theta=-33.210493 -> V=1.0, theta=0.0
% INFO    : Bus 26715	: V=0.9621338, theta=-33.118277 -> V=1.0, theta=0.0
% INFO    : Bus 26716	: V=0.9655754, theta=-32.913069 -> V=1.0, theta=0.0
% INFO    : Bus 26717	: V=0.9606953, theta=-33.18222 -> V=1.0, theta=0.0
% INFO    : Bus 26718	: V=0.95994, theta=-33.267381 -> V=1.0, theta=0.0
% INFO    : Bus 26719	: V=0.9658376, theta=-32.936774 -> V=1.0, theta=0.0
% INFO    : Bus 26720	: V=0.9732662, theta=-32.164376 -> V=1.0, theta=0.0
% INFO    : Bus 26721	: V=0.97616, theta=-32.272409 -> V=1.0, theta=0.0
% INFO    : Bus 26722	: V=0.9790732, theta=-31.696078 -> V=1.0, theta=0.0
% INFO    : Bus 26723	: V=0.9732799, theta=-32.495962 -> V=1.0, theta=0.0
% INFO    : Bus 26724	: V=0.9668799, theta=-32.844343 -> V=1.0, theta=0.0
% INFO    : Bus 26725	: V=0.9693179, theta=-32.732924 -> V=1.0, theta=0.0
% INFO    : Bus 26726	: V=0.97105, theta=-32.6386 -> V=1.0, theta=0.0
% INFO    : Bus 26727	: V=0.9775754, theta=-31.937409 -> V=1.0, theta=0.0
% INFO    : Bus 26728	: V=0.9659689, theta=-32.920278 -> V=1.0, theta=0.0
% INFO    : Bus 26729	: V=0.9665554, theta=-32.851424 -> V=1.0, theta=0.0
% INFO    : Bus 26730	: V=0.9631997, theta=-33.102975 -> V=1.0, theta=0.0
% INFO    : Bus 26731	: V=0.994022, theta=-29.427469 -> V=1.0, theta=0.0
% INFO    : Bus 26732	: V=0.0, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 26733	: V=0.9972888, theta=-29.17984 -> V=1.0, theta=0.0
% INFO    : Bus 26734	: V=0.9858319, theta=-31.042505 -> V=1.0, theta=0.0
% INFO    : Bus 26735	: V=0.9758328, theta=-31.268519 -> V=1.0, theta=0.0
% INFO    : Bus 26736	: V=0.9757484, theta=-31.384743 -> V=1.0, theta=0.0
% INFO    : Bus 26737	: V=0.9740337, theta=-31.548612 -> V=1.0, theta=0.0
% INFO    : Bus 26738	: V=0.9662097, theta=-32.22565 -> V=1.0, theta=0.0
% INFO    : Bus 26739	: V=0.9722942, theta=-31.586121 -> V=1.0, theta=0.0
% INFO    : Bus 26740	: V=0.9590663, theta=-33.384619 -> V=1.0, theta=0.0
% INFO    : Bus 26741	: V=0.9711495, theta=-31.71071 -> V=1.0, theta=0.0
% INFO    : Bus 26742	: V=0.9594898, theta=-33.061728 -> V=1.0, theta=0.0
% INFO    : Bus 26743	: V=0.9595361, theta=-33.009684 -> V=1.0, theta=0.0
% INFO    : Bus 26744	: V=0.9631539, theta=-32.76462 -> V=1.0, theta=0.0
% INFO    : Bus 26745	: V=0.9579431, theta=-33.206062 -> V=1.0, theta=0.0
% INFO    : Bus 26746	: V=0.9576926, theta=-33.18294 -> V=1.0, theta=0.0
% INFO    : Bus 26747	: V=0.9573345, theta=-33.222459 -> V=1.0, theta=0.0
% INFO    : Bus 26748	: V=0.959534, theta=-33.325208 -> V=1.0, theta=0.0
% INFO    : Bus 26749	: V=0.9604343, theta=-33.217643 -> V=1.0, theta=0.0
% INFO    : Bus 26750	: V=0.9616477, theta=-33.240438 -> V=1.0, theta=0.0
% INFO    : Bus 26751	: V=0.9644242, theta=-33.038404 -> V=1.0, theta=0.0
% INFO    : Bus 26752	: V=0.9667588, theta=-32.908503 -> V=1.0, theta=0.0
% INFO    : Bus 26753	: V=0.9663325, theta=-32.913939 -> V=1.0, theta=0.0
% INFO    : Bus 26754	: V=0.9835325, theta=-30.634642 -> V=1.0, theta=0.0
% INFO    : Bus 26755	: V=0.96595, theta=-33.02458 -> V=1.0, theta=0.0
% INFO    : Bus 26756	: V=0.9683685, theta=-32.665722 -> V=1.0, theta=0.0
% INFO    : Bus 26757	: V=0.9632052, theta=-33.130899 -> V=1.0, theta=0.0
% INFO    : Bus 26758	: V=0.9684887, theta=-32.610136 -> V=1.0, theta=0.0
% INFO    : Bus 26759	: V=0.9844763, theta=-30.643366 -> V=1.0, theta=0.0
% INFO    : Bus 26760	: V=0.9712536, theta=-32.011705 -> V=1.0, theta=0.0
% INFO    : Bus 26761	: V=0.9703678, theta=-32.101898 -> V=1.0, theta=0.0
% INFO    : Bus 26762	: V=0.9712291, theta=-32.047875 -> V=1.0, theta=0.0
% INFO    : Bus 26763	: V=0.9696906, theta=-32.127212 -> V=1.0, theta=0.0
% INFO    : Bus 26764	: V=0.9691109, theta=-32.141287 -> V=1.0, theta=0.0
% INFO    : Bus 26765	: V=0.9689079, theta=-32.12802 -> V=1.0, theta=0.0
% INFO    : Bus 26766	: V=0.9687187, theta=-32.095286 -> V=1.0, theta=0.0
% INFO    : Bus 26767	: V=0.9589453, theta=-33.320736 -> V=1.0, theta=0.0
% INFO    : Bus 26768	: V=0.9581081, theta=-33.429766 -> V=1.0, theta=0.0
% INFO    : Bus 26769	: V=0.9578715, theta=-33.450302 -> V=1.0, theta=0.0
% INFO    : Bus 26770	: V=0.9546167, theta=-33.674646 -> V=1.0, theta=0.0
% INFO    : Bus 26771	: V=0.9533307, theta=-33.826972 -> V=1.0, theta=0.0
% INFO    : Bus 26772	: V=0.9518366, theta=-34.140588 -> V=1.0, theta=0.0
% INFO    : Bus 26773	: V=0.9513026, theta=-34.243557 -> V=1.0, theta=0.0
% INFO    : Bus 26774	: V=0.9529256, theta=-34.159163 -> V=1.0, theta=0.0
% INFO    : Bus 26775	: V=0.9551987, theta=-33.676834 -> V=1.0, theta=0.0
% INFO    : Bus 26776	: V=0.9569883, theta=-33.551963 -> V=1.0, theta=0.0
% INFO    : Bus 26777	: V=0.9573845, theta=-33.579166 -> V=1.0, theta=0.0
% INFO    : Bus 26778	: V=0.9694238, theta=-32.062679 -> V=1.0, theta=0.0
% INFO    : Bus 26779	: V=0.9701083, theta=-32.059528 -> V=1.0, theta=0.0
% INFO    : Bus 26780	: V=0.9656465, theta=-32.74488 -> V=1.0, theta=0.0
% INFO    : Bus 26781	: V=0.982741, theta=-30.716944 -> V=1.0, theta=0.0
% INFO    : Bus 26782	: V=0.9729811, theta=-31.654744 -> V=1.0, theta=0.0
% INFO    : Bus 26783	: V=0.9716463, theta=-31.903219 -> V=1.0, theta=0.0
% INFO    : Bus 26784	: V=0.9572631, theta=-33.418117 -> V=1.0, theta=0.0
% INFO    : Bus 26785	: V=0.9631891, theta=-32.778049 -> V=1.0, theta=0.0
% INFO    : Bus 26786	: V=0.9634938, theta=-32.773834 -> V=1.0, theta=0.0
% INFO    : Bus 26787	: V=0.9550712, theta=-34.100518 -> V=1.0, theta=0.0
% INFO    : Bus 26788	: V=0.9561582, theta=-33.889912 -> V=1.0, theta=0.0
% INFO    : Bus 26789	: V=0.9523076, theta=-34.183008 -> V=1.0, theta=0.0
% INFO    : Bus 26790	: V=0.9623063, theta=-32.491968 -> V=1.0, theta=0.0
% INFO    : Bus 26791	: V=0.9601016, theta=-31.85773 -> V=1.0, theta=0.0
% INFO    : Bus 26792	: V=0.9757131, theta=-31.149039 -> V=1.0, theta=0.0
% INFO    : Bus 26793	: V=0.9835638, theta=-31.723953 -> V=1.0, theta=0.0
% INFO    : Bus 26794	: V=0.9918587, theta=-30.469714 -> V=1.0, theta=0.0
% INFO    : Bus 26795	: V=0.9922133, theta=-30.215353 -> V=1.0, theta=0.0
% INFO    : Bus 26796	: V=0.9789164, theta=-32.155146 -> V=1.0, theta=0.0
% INFO    : Bus 26797	: V=0.9789817, theta=-31.869346 -> V=1.0, theta=0.0
% INFO    : Bus 26798	: V=0.9970628, theta=-29.870501 -> V=1.0, theta=0.0
% INFO    : Bus 26799	: V=0.9606182, theta=-33.257698 -> V=1.0, theta=0.0
% INFO    : Bus 26800	: V=0.9751696, theta=-32.086458 -> V=1.0, theta=0.0
% INFO    : Bus 26801	: V=0.9588364, theta=-33.261461 -> V=1.0, theta=0.0
% INFO    : Bus 26802	: V=0.9691557, theta=-38.351107 -> V=1.0, theta=0.0
% INFO    : Bus 26803	: V=0.9517878, theta=-43.648974 -> V=1.0, theta=0.0
% INFO    : Bus 26804	: V=0.9536527, theta=-38.118116 -> V=1.0, theta=0.0
% INFO    : Bus 26805	: V=0.9700401, theta=-37.448309 -> V=1.0, theta=0.0
% INFO    : Bus 26806	: V=0.9490358, theta=-42.404621 -> V=1.0, theta=0.0
% INFO    : Bus 26807	: V=0.9544527, theta=-41.677705 -> V=1.0, theta=0.0
% INFO    : Bus 26808	: V=0.9684348, theta=-36.988498 -> V=1.0, theta=0.0
% INFO    : Bus 26809	: V=0.9687595, theta=-36.748766 -> V=1.0, theta=0.0
% INFO    : Bus 26810	: V=0.9576146, theta=-38.126355 -> V=1.0, theta=0.0
% INFO    : Bus 26811	: V=0.9563378, theta=-40.812061 -> V=1.0, theta=0.0
% INFO    : Bus 26812	: V=0.9750727, theta=-37.259803 -> V=1.0, theta=0.0
% INFO    : Bus 26813	: V=0.9696048, theta=-35.457824 -> V=1.0, theta=0.0
% INFO    : Bus 26814	: V=0.9658659, theta=-62.001113 -> V=1.0, theta=0.0
% INFO    : Bus 26815	: V=0.9653164, theta=-62.102518 -> V=1.0, theta=0.0
% INFO    : Bus 26816	: V=0.9595517, theta=-62.764008 -> V=1.0, theta=0.0
% INFO    : Bus 26817	: V=0.9618238, theta=-62.567321 -> V=1.0, theta=0.0
% INFO    : Bus 26818	: V=0.9661611, theta=-61.777575 -> V=1.0, theta=0.0
% INFO    : Bus 26819	: V=0.9628158, theta=-61.962991 -> V=1.0, theta=0.0
% INFO    : Bus 26820	: V=0.9630595, theta=-61.964405 -> V=1.0, theta=0.0
% INFO    : Bus 26821	: V=0.9637308, theta=-61.959127 -> V=1.0, theta=0.0
% INFO    : Bus 26822	: V=0.9633903, theta=-61.956911 -> V=1.0, theta=0.0
% INFO    : Bus 26823	: V=0.9622156, theta=-61.973715 -> V=1.0, theta=0.0
% INFO    : Bus 26824	: V=0.9653868, theta=-61.819857 -> V=1.0, theta=0.0
% INFO    : Bus 26825	: V=0.9624775, theta=-62.258688 -> V=1.0, theta=0.0
% INFO    : Bus 26826	: V=0.9655874, theta=-61.814782 -> V=1.0, theta=0.0
% INFO    : Bus 26827	: V=0.9624382, theta=-62.137541 -> V=1.0, theta=0.0
% INFO    : Bus 26828	: V=0.96291, theta=-62.128054 -> V=1.0, theta=0.0
% INFO    : Bus 26829	: V=0.9624318, theta=-62.135032 -> V=1.0, theta=0.0
% INFO    : Bus 26830	: V=0.964965, theta=-61.873877 -> V=1.0, theta=0.0
% INFO    : Bus 26831	: V=0.9620047, theta=-61.929319 -> V=1.0, theta=0.0
% INFO    : Bus 26832	: V=0.9624565, theta=-62.12758 -> V=1.0, theta=0.0
% INFO    : Bus 26833	: V=0.9629864, theta=-62.080439 -> V=1.0, theta=0.0
% INFO    : Bus 26834	: V=0.9646317, theta=-61.903467 -> V=1.0, theta=0.0
% INFO    : Bus 26835	: V=0.9627188, theta=-62.27363 -> V=1.0, theta=0.0
% INFO    : Bus 26836	: V=0.9652712, theta=-62.007491 -> V=1.0, theta=0.0
% INFO    : Bus 26837	: V=0.9601228, theta=-62.809413 -> V=1.0, theta=0.0
% INFO    : Bus 26838	: V=0.9589464, theta=-62.831845 -> V=1.0, theta=0.0
% INFO    : Bus 26839	: V=0.9597534, theta=-62.808846 -> V=1.0, theta=0.0
% INFO    : Bus 26840	: V=0.9637689, theta=-62.234903 -> V=1.0, theta=0.0
% INFO    : Bus 26841	: V=0.9680447, theta=-61.614455 -> V=1.0, theta=0.0
% INFO    : Bus 26842	: V=0.9645282, theta=-62.188272 -> V=1.0, theta=0.0
% INFO    : Bus 26843	: V=0.9693941, theta=-61.393578 -> V=1.0, theta=0.0
% INFO    : Bus 26844	: V=0.9651008, theta=-61.934405 -> V=1.0, theta=0.0
% INFO    : Bus 26845	: V=0.965159, theta=-62.026857 -> V=1.0, theta=0.0
% INFO    : Bus 26846	: V=0.9614385, theta=-62.301426 -> V=1.0, theta=0.0
% INFO    : Bus 26847	: V=0.9738918, theta=-60.694314 -> V=1.0, theta=0.0
% INFO    : Bus 26848	: V=0.9848588, theta=-58.363893 -> V=1.0, theta=0.0
% INFO    : Bus 26849	: V=0.9655734, theta=-61.859415 -> V=1.0, theta=0.0
% INFO    : Bus 26850	: V=0.9641127, theta=-61.78725 -> V=1.0, theta=0.0
% INFO    : Bus 26851	: V=0.9631398, theta=-61.873348 -> V=1.0, theta=0.0
% INFO    : Bus 26852	: V=0.9630588, theta=-62.003911 -> V=1.0, theta=0.0
% INFO    : Bus 26853	: V=0.9612615, theta=-61.978778 -> V=1.0, theta=0.0
% INFO    : Bus 26854	: V=0.9616702, theta=-61.866368 -> V=1.0, theta=0.0
% INFO    : Bus 26855	: V=0.9633351, theta=-61.833457 -> V=1.0, theta=0.0
% INFO    : Bus 26856	: V=0.9697747, theta=-60.743074 -> V=1.0, theta=0.0
% INFO    : Bus 26857	: V=0.9705654, theta=-60.625523 -> V=1.0, theta=0.0
% INFO    : Bus 26858	: V=0.9717953, theta=-60.510718 -> V=1.0, theta=0.0
% INFO    : Bus 26859	: V=0.9724717, theta=-60.200282 -> V=1.0, theta=0.0
% INFO    : Bus 26860	: V=0.9656506, theta=-60.625045 -> V=1.0, theta=0.0
% INFO    : Bus 26861	: V=0.9648035, theta=-60.83663 -> V=1.0, theta=0.0
% INFO    : Bus 26862	: V=0.9844194, theta=-58.041748 -> V=1.0, theta=0.0
% INFO    : Bus 26863	: V=0.9681704, theta=-61.225341 -> V=1.0, theta=0.0
% INFO    : Bus 26864	: V=0.9607695, theta=-62.037646 -> V=1.0, theta=0.0
% INFO    : Bus 26865	: V=0.9678573, theta=-61.419464 -> V=1.0, theta=0.0
% INFO    : Bus 26866	: V=0.9684257, theta=-61.828956 -> V=1.0, theta=0.0
% INFO    : Bus 26867	: V=0.9688327, theta=-61.045276 -> V=1.0, theta=0.0
% INFO    : Bus 26868	: V=0.9592715, theta=-62.093921 -> V=1.0, theta=0.0
% INFO    : Bus 26869	: V=0.9700875, theta=-60.672383 -> V=1.0, theta=0.0
% INFO    : Bus 26870	: V=0.9571805, theta=-60.94662 -> V=1.0, theta=0.0
% INFO    : Bus 26871	: V=0.965694, theta=-59.783532 -> V=1.0, theta=0.0
% INFO    : Bus 26872	: V=0.9697181, theta=-59.390274 -> V=1.0, theta=0.0
% INFO    : Bus 26873	: V=0.9734396, theta=-57.339901 -> V=1.0, theta=0.0
% INFO    : Bus 26874	: V=0.9738064, theta=-57.488971 -> V=1.0, theta=0.0
% INFO    : Bus 26875	: V=0.9709401, theta=-58.783145 -> V=1.0, theta=0.0
% INFO    : Bus 26876	: V=0.9678855, theta=-59.577918 -> V=1.0, theta=0.0
% INFO    : Bus 26877	: V=0.9755799, theta=-59.456093 -> V=1.0, theta=0.0
% INFO    : Bus 26878	: V=0.9766549, theta=-60.285234 -> V=1.0, theta=0.0
% INFO    : Bus 26879	: V=0.9658074, theta=-61.861674 -> V=1.0, theta=0.0
% INFO    : Bus 26880	: V=0.9665913, theta=-61.872847 -> V=1.0, theta=0.0
% INFO    : Bus 26881	: V=0.9653253, theta=-61.844201 -> V=1.0, theta=0.0
% INFO    : Bus 26882	: V=0.9599015, theta=-62.839982 -> V=1.0, theta=0.0
% INFO    : Bus 26883	: V=0.9620402, theta=-62.607169 -> V=1.0, theta=0.0
% INFO    : Bus 26884	: V=0.9532684, theta=-45.764432 -> V=1.0, theta=0.0
% INFO    : Bus 26885	: V=0.9561946, theta=-43.853042 -> V=1.0, theta=0.0
% INFO    : Bus 26886	: V=0.9536055, theta=-45.446425 -> V=1.0, theta=0.0
% INFO    : Bus 26887	: V=0.9783107, theta=-40.288322 -> V=1.0, theta=0.0
% INFO    : Bus 26888	: V=0.9534727, theta=-45.754598 -> V=1.0, theta=0.0
% INFO    : Bus 26889	: V=0.9531497, theta=-45.769501 -> V=1.0, theta=0.0
% INFO    : Bus 26890	: V=0.9525451, theta=-45.948527 -> V=1.0, theta=0.0
% INFO    : Bus 26891	: V=0.9531513, theta=-45.757821 -> V=1.0, theta=0.0
% INFO    : Bus 26892	: V=0.9533795, theta=-45.735644 -> V=1.0, theta=0.0
% INFO    : Bus 26893	: V=0.9546338, theta=-43.948011 -> V=1.0, theta=0.0
% INFO    : Bus 26894	: V=0.9513444, theta=-46.333973 -> V=1.0, theta=0.0
% INFO    : Bus 26895	: V=0.9535116, theta=-43.974882 -> V=1.0, theta=0.0
% INFO    : Bus 26896	: V=0.9462548, theta=-47.313904 -> V=1.0, theta=0.0
% INFO    : Bus 26897	: V=0.9478249, theta=-43.92435 -> V=1.0, theta=0.0
% INFO    : Bus 26898	: V=0.9521936, theta=-43.991079 -> V=1.0, theta=0.0
% INFO    : Bus 26899	: V=0.9471684, theta=-42.883717 -> V=1.0, theta=0.0
% INFO    : Bus 26900	: V=0.95254, theta=-45.564458 -> V=1.0, theta=0.0
% INFO    : Bus 26901	: V=0.9515592, theta=-44.906791 -> V=1.0, theta=0.0
% INFO    : Bus 26902	: V=0.961255, theta=-53.158897 -> V=1.0, theta=0.0
% INFO    : Bus 26903	: V=0.955881, theta=-54.505845 -> V=1.0, theta=0.0
% INFO    : Bus 26904	: V=0.9683713, theta=-50.839589 -> V=1.0, theta=0.0
% INFO    : Bus 26905	: V=0.9542706, theta=-54.547164 -> V=1.0, theta=0.0
% INFO    : Bus 26906	: V=0.9599068, theta=-53.091686 -> V=1.0, theta=0.0
% INFO    : Bus 26907	: V=0.9615343, theta=-53.715876 -> V=1.0, theta=0.0
% INFO    : Bus 26908	: V=0.9618494, theta=-54.214206 -> V=1.0, theta=0.0
% INFO    : Bus 26909	: V=0.9602391, theta=-53.545519 -> V=1.0, theta=0.0
% INFO    : Bus 26910	: V=0.9596593, theta=-53.334155 -> V=1.0, theta=0.0
% INFO    : Bus 26911	: V=0.9571828, theta=-54.227845 -> V=1.0, theta=0.0
% INFO    : Bus 26912	: V=0.9597194, theta=-53.243481 -> V=1.0, theta=0.0
% INFO    : Bus 26913	: V=0.9596221, theta=-53.230703 -> V=1.0, theta=0.0
% INFO    : Bus 26914	: V=0.9601949, theta=-53.143435 -> V=1.0, theta=0.0
% INFO    : Bus 26915	: V=0.9586663, theta=-53.855226 -> V=1.0, theta=0.0
% INFO    : Bus 26916	: V=0.9581174, theta=-54.183265 -> V=1.0, theta=0.0
% INFO    : Bus 26917	: V=0.9596771, theta=-53.464849 -> V=1.0, theta=0.0
% INFO    : Bus 26918	: V=0.9663843, theta=-51.405169 -> V=1.0, theta=0.0
% INFO    : Bus 26919	: V=0.9620987, theta=-53.000005 -> V=1.0, theta=0.0
% INFO    : Bus 26920	: V=0.9631717, theta=-52.189238 -> V=1.0, theta=0.0
% INFO    : Bus 26921	: V=0.9661046, theta=-51.80416 -> V=1.0, theta=0.0
% INFO    : Bus 26922	: V=0.9647875, theta=-51.949552 -> V=1.0, theta=0.0
% INFO    : Bus 26923	: V=0.9657686, theta=-52.642756 -> V=1.0, theta=0.0
% INFO    : Bus 26924	: V=0.9619354, theta=-53.606572 -> V=1.0, theta=0.0
% INFO    : Bus 26925	: V=0.9610926, theta=-52.700496 -> V=1.0, theta=0.0
% INFO    : Bus 26926	: V=0.9584044, theta=-54.227635 -> V=1.0, theta=0.0
% INFO    : Bus 26927	: V=0.9582044, theta=-54.168022 -> V=1.0, theta=0.0
% INFO    : Bus 26928	: V=0.957592, theta=-54.20019 -> V=1.0, theta=0.0
% INFO    : Bus 26929	: V=0.9617724, theta=-52.385595 -> V=1.0, theta=0.0
% INFO    : Bus 26930	: V=0.9572326, theta=-54.738518 -> V=1.0, theta=0.0
% INFO    : Bus 26931	: V=0.955861, theta=-54.821794 -> V=1.0, theta=0.0
% INFO    : Bus 26932	: V=0.9606694, theta=-52.74721 -> V=1.0, theta=0.0
% INFO    : Bus 26933	: V=0.9584972, theta=-53.878222 -> V=1.0, theta=0.0
% INFO    : Bus 26934	: V=0.9583353, theta=-54.019839 -> V=1.0, theta=0.0
% INFO    : Bus 26935	: V=0.9612384, theta=-55.868087 -> V=1.0, theta=0.0
% INFO    : Bus 26936	: V=0.9624813, theta=-54.514769 -> V=1.0, theta=0.0
% INFO    : Bus 26937	: V=0.964455, theta=-54.445181 -> V=1.0, theta=0.0
% INFO    : Bus 26938	: V=0.9641087, theta=-53.703247 -> V=1.0, theta=0.0
% INFO    : Bus 26939	: V=1.0138979, theta=-35.437698 -> V=1.0, theta=0.0
% INFO    : Bus 26940	: V=1.0192417, theta=-30.18684 -> V=1.0, theta=0.0
% INFO    : Bus 26941	: V=1.0100288, theta=-31.445597 -> V=1.0, theta=0.0
% INFO    : Bus 26942	: V=1.0193434, theta=-29.205258 -> V=1.0, theta=0.0
% INFO    : Bus 26943	: V=1.0162917, theta=-32.316588 -> V=1.0, theta=0.0
% INFO    : Bus 26944	: V=1.0154287, theta=-34.978356 -> V=1.0, theta=0.0
% INFO    : Bus 26945	: V=0.949725, theta=-30.820209 -> V=1.0, theta=0.0
% INFO    : Bus 26946	: V=0.9464078, theta=-31.519861 -> V=1.0, theta=0.0
% INFO    : Bus 26947	: V=0.9523917, theta=-30.725171 -> V=1.0, theta=0.0
% INFO    : Bus 26948	: V=0.9534182, theta=-31.023963 -> V=1.0, theta=0.0
% INFO    : Bus 26949	: V=0.953047, theta=-31.07828 -> V=1.0, theta=0.0
% INFO    : Bus 26950	: V=0.9525527, theta=-30.245116 -> V=1.0, theta=0.0
% INFO    : Bus 26951	: V=0.9528207, theta=-31.135866 -> V=1.0, theta=0.0
% INFO    : Bus 26952	: V=0.9618918, theta=-31.247394 -> V=1.0, theta=0.0
% INFO    : Bus 26953	: V=0.9524905, theta=-29.192448 -> V=1.0, theta=0.0
% INFO    : Bus 26954	: V=0.9477867, theta=-35.101212 -> V=1.0, theta=0.0
% INFO    : Bus 26955	: V=0.9469675, theta=-35.563355 -> V=1.0, theta=0.0
% INFO    : Bus 26956	: V=0.9576087, theta=-33.930986 -> V=1.0, theta=0.0
% INFO    : Bus 26957	: V=0.9454201, theta=-35.628013 -> V=1.0, theta=0.0
% INFO    : Bus 26958	: V=0.9516848, theta=-34.778034 -> V=1.0, theta=0.0
% INFO    : Bus 26959	: V=0.9624382, theta=-32.923369 -> V=1.0, theta=0.0
% INFO    : Bus 26960	: V=0.9599308, theta=-33.466408 -> V=1.0, theta=0.0
% INFO    : Bus 26961	: V=0.9572865, theta=-34.004368 -> V=1.0, theta=0.0
% INFO    : Bus 26962	: V=0.9556634, theta=-33.466465 -> V=1.0, theta=0.0
% INFO    : Bus 26963	: V=0.9546148, theta=-33.702665 -> V=1.0, theta=0.0
% INFO    : Bus 26964	: V=0.9482788, theta=-35.086972 -> V=1.0, theta=0.0
% INFO    : Bus 26965	: V=0.9533405, theta=-34.40806 -> V=1.0, theta=0.0
% INFO    : Bus 26966	: V=0.9532854, theta=-34.432723 -> V=1.0, theta=0.0
% INFO    : Bus 26967	: V=0.9684129, theta=-32.621699 -> V=1.0, theta=0.0
% INFO    : Bus 26968	: V=0.9475116, theta=-35.55078 -> V=1.0, theta=0.0
% INFO    : Bus 26969	: V=0.9383697, theta=-36.216085 -> V=1.0, theta=0.0
% INFO    : Bus 26970	: V=0.9402935, theta=-36.081227 -> V=1.0, theta=0.0
% INFO    : Bus 26971	: V=0.9514555, theta=-34.597326 -> V=1.0, theta=0.0
% INFO    : Bus 26972	: V=0.9520606, theta=-34.539812 -> V=1.0, theta=0.0
% INFO    : Bus 26973	: V=0.9547121, theta=-34.348992 -> V=1.0, theta=0.0
% INFO    : Bus 26974	: V=0.9300218, theta=-36.741178 -> V=1.0, theta=0.0
% INFO    : Bus 26975	: V=1.0043468, theta=-45.899684 -> V=1.0, theta=0.0
% INFO    : Bus 26976	: V=0.9925451, theta=-45.726155 -> V=1.0, theta=0.0
% INFO    : Bus 26977	: V=0.9918768, theta=-45.240291 -> V=1.0, theta=0.0
% INFO    : Bus 26978	: V=0.9941873, theta=-44.218468 -> V=1.0, theta=0.0
% INFO    : Bus 26979	: V=0.9809189, theta=-30.771043 -> V=1.0, theta=0.0
% INFO    : Bus 26980	: V=0.9696283, theta=-32.266934 -> V=1.0, theta=0.0
% INFO    : Bus 26981	: V=0.969718, theta=-32.251832 -> V=1.0, theta=0.0
% INFO    : Bus 26982	: V=0.972446, theta=-31.969831 -> V=1.0, theta=0.0
% INFO    : Bus 26983	: V=0.9716079, theta=-32.079704 -> V=1.0, theta=0.0
% INFO    : Bus 26984	: V=0.9707557, theta=-32.398118 -> V=1.0, theta=0.0
% INFO    : Bus 26985	: V=0.9710754, theta=-32.394214 -> V=1.0, theta=0.0
% INFO    : Bus 26986	: V=0.9680503, theta=-32.325239 -> V=1.0, theta=0.0
% INFO    : Bus 26987	: V=0.9677259, theta=-32.796744 -> V=1.0, theta=0.0
% INFO    : Bus 26988	: V=0.9824076, theta=-30.602206 -> V=1.0, theta=0.0
% INFO    : Bus 26989	: V=0.9829365, theta=-30.541614 -> V=1.0, theta=0.0
% INFO    : Bus 26990	: V=0.9650354, theta=-33.199686 -> V=1.0, theta=0.0
% INFO    : Bus 26991	: V=0.9714904, theta=-32.184396 -> V=1.0, theta=0.0
% INFO    : Bus 26992	: V=0.9724216, theta=-32.037638 -> V=1.0, theta=0.0
% INFO    : Bus 26993	: V=0.9629423, theta=-33.45194 -> V=1.0, theta=0.0
% INFO    : Bus 26994	: V=0.9698957, theta=-32.421026 -> V=1.0, theta=0.0
% INFO    : Bus 26995	: V=0.9669681, theta=-32.881395 -> V=1.0, theta=0.0
% INFO    : Bus 26996	: V=0.9815184, theta=-30.806201 -> V=1.0, theta=0.0
% INFO    : Bus 26997	: V=0.9701505, theta=-32.451002 -> V=1.0, theta=0.0
% INFO    : Bus 26998	: V=0.9674501, theta=-32.662295 -> V=1.0, theta=0.0
% INFO    : Bus 26999	: V=0.965869, theta=-32.857196 -> V=1.0, theta=0.0
% INFO    : Bus 27000	: V=0.9653172, theta=-32.897542 -> V=1.0, theta=0.0
% INFO    : Bus 27001	: V=0.9648486, theta=-32.929152 -> V=1.0, theta=0.0
% INFO    : Bus 27002	: V=0.9651549, theta=-32.836107 -> V=1.0, theta=0.0
% INFO    : Bus 27003	: V=0.9645581, theta=-32.828299 -> V=1.0, theta=0.0
% INFO    : Bus 27004	: V=0.9663062, theta=-32.628773 -> V=1.0, theta=0.0
% INFO    : Bus 27005	: V=0.9690749, theta=-32.319424 -> V=1.0, theta=0.0
% INFO    : Bus 27006	: V=0.9684628, theta=-32.462482 -> V=1.0, theta=0.0
% INFO    : Bus 27007	: V=0.9726771, theta=-31.705386 -> V=1.0, theta=0.0
% INFO    : Bus 27008	: V=0.9725766, theta=-31.714804 -> V=1.0, theta=0.0
% INFO    : Bus 27009	: V=0.9675491, theta=-32.597004 -> V=1.0, theta=0.0
% INFO    : Bus 27010	: V=0.9666579, theta=-32.670288 -> V=1.0, theta=0.0
% INFO    : Bus 27011	: V=0.9737069, theta=-31.809232 -> V=1.0, theta=0.0
% INFO    : Bus 27012	: V=0.9747122, theta=-31.689832 -> V=1.0, theta=0.0
% INFO    : Bus 27013	: V=0.9848071, theta=-30.325157 -> V=1.0, theta=0.0
% INFO    : Bus 27014	: V=0.9735259, theta=-31.838967 -> V=1.0, theta=0.0
% INFO    : Bus 27015	: V=0.97436, theta=-31.72776 -> V=1.0, theta=0.0
% INFO    : Bus 27016	: V=0.9742192, theta=-31.787959 -> V=1.0, theta=0.0
% INFO    : Bus 27017	: V=0.9754293, theta=-31.523201 -> V=1.0, theta=0.0
% INFO    : Bus 27018	: V=0.9771903, theta=-31.253895 -> V=1.0, theta=0.0
% INFO    : Bus 27019	: V=0.9709085, theta=-32.052432 -> V=1.0, theta=0.0
% INFO    : Bus 27020	: V=0.9709498, theta=-32.021124 -> V=1.0, theta=0.0
% INFO    : Bus 27021	: V=0.974879, theta=-31.630356 -> V=1.0, theta=0.0
% INFO    : Bus 27022	: V=0.9744346, theta=-31.692333 -> V=1.0, theta=0.0
% INFO    : Bus 27023	: V=0.9754552, theta=-31.55329 -> V=1.0, theta=0.0
% INFO    : Bus 27024	: V=0.9762704, theta=-31.251288 -> V=1.0, theta=0.0
% INFO    : Bus 27025	: V=0.9761041, theta=-31.231061 -> V=1.0, theta=0.0
% INFO    : Bus 27026	: V=0.9778277, theta=-30.931341 -> V=1.0, theta=0.0
% INFO    : Bus 27027	: V=0.976395, theta=-31.154641 -> V=1.0, theta=0.0
% INFO    : Bus 27028	: V=0.9755705, theta=-31.28863 -> V=1.0, theta=0.0
% INFO    : Bus 27029	: V=0.977425, theta=-30.991744 -> V=1.0, theta=0.0
% INFO    : Bus 27030	: V=0.9684815, theta=-32.279332 -> V=1.0, theta=0.0
% INFO    : Bus 27031	: V=0.9688504, theta=-32.27433 -> V=1.0, theta=0.0
% INFO    : Bus 27032	: V=0.9740083, theta=-31.543903 -> V=1.0, theta=0.0
% INFO    : Bus 27033	: V=0.9733812, theta=-31.636193 -> V=1.0, theta=0.0
% INFO    : Bus 27034	: V=0.9715894, theta=-31.9174 -> V=1.0, theta=0.0
% INFO    : Bus 27035	: V=0.9726601, theta=-31.72306 -> V=1.0, theta=0.0
% INFO    : Bus 27036	: V=0.9705449, theta=-32.123027 -> V=1.0, theta=0.0
% INFO    : Bus 27037	: V=0.9698912, theta=-32.207306 -> V=1.0, theta=0.0
% INFO    : Bus 27038	: V=0.9704399, theta=-32.136529 -> V=1.0, theta=0.0
% INFO    : Bus 27039	: V=0.9737041, theta=-31.591586 -> V=1.0, theta=0.0
% INFO    : Bus 27040	: V=0.9743113, theta=-31.493411 -> V=1.0, theta=0.0
% INFO    : Bus 27041	: V=0.9718172, theta=-31.92575 -> V=1.0, theta=0.0
% INFO    : Bus 27042	: V=0.9724504, theta=-31.948099 -> V=1.0, theta=0.0
% INFO    : Bus 27043	: V=0.9739055, theta=-31.707561 -> V=1.0, theta=0.0
% INFO    : Bus 27044	: V=0.9751691, theta=-31.502426 -> V=1.0, theta=0.0
% INFO    : Bus 27045	: V=0.971609, theta=-31.745029 -> V=1.0, theta=0.0
% INFO    : Bus 27046	: V=0.9767837, theta=-31.246333 -> V=1.0, theta=0.0
% INFO    : Bus 27047	: V=0.9801079, theta=-30.729335 -> V=1.0, theta=0.0
% INFO    : Bus 27048	: V=0.9743567, theta=-31.442554 -> V=1.0, theta=0.0
% INFO    : Bus 27049	: V=0.9760216, theta=-31.20628 -> V=1.0, theta=0.0
% INFO    : Bus 27050	: V=0.980646, theta=-30.55813 -> V=1.0, theta=0.0
% INFO    : Bus 27051	: V=0.9785775, theta=-30.811306 -> V=1.0, theta=0.0
% INFO    : Bus 27052	: V=0.9706377, theta=-31.802842 -> V=1.0, theta=0.0
% INFO    : Bus 27053	: V=0.9853799, theta=-29.867206 -> V=1.0, theta=0.0
% INFO    : Bus 27054	: V=0.9853205, theta=-29.881287 -> V=1.0, theta=0.0
% INFO    : Bus 27055	: V=0.9857211, theta=-29.687165 -> V=1.0, theta=0.0
% INFO    : Bus 27056	: V=0.9848358, theta=-29.791002 -> V=1.0, theta=0.0
% INFO    : Bus 27057	: V=0.9862945, theta=-29.537571 -> V=1.0, theta=0.0
% INFO    : Bus 27058	: V=0.982487, theta=-30.303008 -> V=1.0, theta=0.0
% INFO    : Bus 27059	: V=0.9850841, theta=-30.084439 -> V=1.0, theta=0.0
% INFO    : Bus 27060	: V=0.9868631, theta=-29.846572 -> V=1.0, theta=0.0
% INFO    : Bus 27061	: V=0.9888208, theta=-29.756372 -> V=1.0, theta=0.0
% INFO    : Bus 27062	: V=0.9821127, theta=-30.301174 -> V=1.0, theta=0.0
% INFO    : Bus 27063	: V=0.9852979, theta=-29.910286 -> V=1.0, theta=0.0
% INFO    : Bus 27064	: V=0.979365, theta=-30.732293 -> V=1.0, theta=0.0
% INFO    : Bus 27065	: V=0.9804645, theta=-30.555791 -> V=1.0, theta=0.0
% INFO    : Bus 27066	: V=0.9810302, theta=-30.55628 -> V=1.0, theta=0.0
% INFO    : Bus 27067	: V=0.9884508, theta=-29.428594 -> V=1.0, theta=0.0
% INFO    : Bus 27068	: V=0.9887555, theta=-29.358609 -> V=1.0, theta=0.0
% INFO    : Bus 27069	: V=0.9884949, theta=-29.407341 -> V=1.0, theta=0.0
% INFO    : Bus 27070	: V=0.9857611, theta=-29.747215 -> V=1.0, theta=0.0
% INFO    : Bus 27071	: V=0.9923247, theta=-28.741858 -> V=1.0, theta=0.0
% INFO    : Bus 27072	: V=0.989831, theta=-29.149298 -> V=1.0, theta=0.0
% INFO    : Bus 27073	: V=0.9861747, theta=-29.694657 -> V=1.0, theta=0.0
% INFO    : Bus 27074	: V=0.9863686, theta=-29.605946 -> V=1.0, theta=0.0
% INFO    : Bus 27075	: V=0.979543, theta=-30.186563 -> V=1.0, theta=0.0
% INFO    : Bus 27076	: V=0.9766776, theta=-31.160415 -> V=1.0, theta=0.0
% INFO    : Bus 27077	: V=0.9698697, theta=-32.146973 -> V=1.0, theta=0.0
% INFO    : Bus 27078	: V=0.959809, theta=-32.769592 -> V=1.0, theta=0.0
% INFO    : Bus 27079	: V=0.9614992, theta=-33.712043 -> V=1.0, theta=0.0
% INFO    : Bus 27080	: V=0.9756035, theta=-31.351125 -> V=1.0, theta=0.0
% INFO    : Bus 27081	: V=0.9747366, theta=-31.519141 -> V=1.0, theta=0.0
% INFO    : Bus 27082	: V=0.9739117, theta=-31.69662 -> V=1.0, theta=0.0
% INFO    : Bus 27083	: V=0.9668245, theta=-32.378594 -> V=1.0, theta=0.0
% INFO    : Bus 27084	: V=0.9627005, theta=-32.727809 -> V=1.0, theta=0.0
% INFO    : Bus 27085	: V=0.9705618, theta=-32.19456 -> V=1.0, theta=0.0
% INFO    : Bus 27086	: V=0.9806925, theta=-30.7962 -> V=1.0, theta=0.0
% INFO    : Bus 27087	: V=0.9697202, theta=-32.326146 -> V=1.0, theta=0.0
% INFO    : Bus 27088	: V=0.9621534, theta=-33.583799 -> V=1.0, theta=0.0
% INFO    : Bus 27089	: V=0.970016, theta=-32.293554 -> V=1.0, theta=0.0
% INFO    : Bus 27090	: V=0.9703436, theta=-32.259447 -> V=1.0, theta=0.0
% INFO    : Bus 27091	: V=0.9660618, theta=-32.863032 -> V=1.0, theta=0.0
% INFO    : Bus 27092	: V=0.9618623, theta=-33.549832 -> V=1.0, theta=0.0
% INFO    : Bus 27093	: V=0.9630523, theta=-33.192057 -> V=1.0, theta=0.0
% INFO    : Bus 27094	: V=0.9652698, theta=-33.129328 -> V=1.0, theta=0.0
% INFO    : Bus 27095	: V=0.9602563, theta=-33.867794 -> V=1.0, theta=0.0
% INFO    : Bus 27096	: V=0.9646818, theta=-33.229127 -> V=1.0, theta=0.0
% INFO    : Bus 27097	: V=0.9684364, theta=-32.748519 -> V=1.0, theta=0.0
% INFO    : Bus 27098	: V=0.9675943, theta=-32.778159 -> V=1.0, theta=0.0
% INFO    : Bus 27099	: V=0.9649307, theta=-32.998667 -> V=1.0, theta=0.0
% INFO    : Bus 27100	: V=0.9683195, theta=-32.590011 -> V=1.0, theta=0.0
% INFO    : Bus 27101	: V=0.9652387, theta=-32.754284 -> V=1.0, theta=0.0
% INFO    : Bus 27102	: V=0.9672506, theta=-32.871821 -> V=1.0, theta=0.0
% INFO    : Bus 27103	: V=0.9565032, theta=-34.148327 -> V=1.0, theta=0.0
% INFO    : Bus 27104	: V=0.9579238, theta=-34.039966 -> V=1.0, theta=0.0
% INFO    : Bus 27105	: V=0.9556518, theta=-34.29442 -> V=1.0, theta=0.0
% INFO    : Bus 27106	: V=0.957172, theta=-34.117119 -> V=1.0, theta=0.0
% INFO    : Bus 27107	: V=0.9622606, theta=-33.420973 -> V=1.0, theta=0.0
% INFO    : Bus 27108	: V=0.9628187, theta=-33.374641 -> V=1.0, theta=0.0
% INFO    : Bus 27109	: V=0.9635171, theta=-33.320668 -> V=1.0, theta=0.0
% INFO    : Bus 27110	: V=0.9606967, theta=-33.822379 -> V=1.0, theta=0.0
% INFO    : Bus 27111	: V=0.9573473, theta=-33.711007 -> V=1.0, theta=0.0
% INFO    : Bus 27112	: V=0.952871, theta=-34.509736 -> V=1.0, theta=0.0
% INFO    : Bus 27113	: V=0.9596894, theta=-33.537155 -> V=1.0, theta=0.0
% INFO    : Bus 27114	: V=0.9565613, theta=-33.924011 -> V=1.0, theta=0.0
% INFO    : Bus 27115	: V=0.9572266, theta=-33.785992 -> V=1.0, theta=0.0
% INFO    : Bus 27116	: V=0.9504296, theta=-34.623544 -> V=1.0, theta=0.0
% INFO    : Bus 27117	: V=0.9605856, theta=-33.127548 -> V=1.0, theta=0.0
% INFO    : Bus 27118	: V=0.9594015, theta=-33.934516 -> V=1.0, theta=0.0
% INFO    : Bus 27119	: V=0.9599009, theta=-33.647971 -> V=1.0, theta=0.0
% INFO    : Bus 27120	: V=0.954578, theta=-33.524591 -> V=1.0, theta=0.0
% INFO    : Bus 27121	: V=0.9596021, theta=-33.336619 -> V=1.0, theta=0.0
% INFO    : Bus 27122	: V=0.9588935, theta=-33.488219 -> V=1.0, theta=0.0
% INFO    : Bus 27123	: V=0.9590104, theta=-33.010253 -> V=1.0, theta=0.0
% INFO    : Bus 27124	: V=0.9614003, theta=-32.710274 -> V=1.0, theta=0.0
% INFO    : Bus 27125	: V=0.9683799, theta=-31.864367 -> V=1.0, theta=0.0
% INFO    : Bus 27126	: V=0.9742214, theta=-30.141075 -> V=1.0, theta=0.0
% INFO    : Bus 27127	: V=0.986905, theta=-29.183486 -> V=1.0, theta=0.0
% INFO    : Bus 27128	: V=0.9935725, theta=-28.003275 -> V=1.0, theta=0.0
% INFO    : Bus 27129	: V=0.9836272, theta=-30.460856 -> V=1.0, theta=0.0
% INFO    : Bus 27130	: V=0.9688351, theta=-32.651712 -> V=1.0, theta=0.0
% INFO    : Bus 27131	: V=0.9648698, theta=-33.012735 -> V=1.0, theta=0.0
% INFO    : Bus 27132	: V=1.0156711, theta=-34.226926 -> V=1.0, theta=0.0
% INFO    : Bus 27133	: V=0.9999764, theta=-37.250264 -> V=1.0, theta=0.0
% INFO    : Bus 27134	: V=0.9982291, theta=-37.221672 -> V=1.0, theta=0.0
% INFO    : Bus 27135	: V=1.0081179, theta=-35.319383 -> V=1.0, theta=0.0
% INFO    : Bus 27136	: V=0.9609361, theta=-48.033761 -> V=1.0, theta=0.0
% INFO    : Bus 27137	: V=0.9629994, theta=-47.992977 -> V=1.0, theta=0.0
% INFO    : Bus 27138	: V=0.948958, theta=-47.53228 -> V=1.0, theta=0.0
% INFO    : Bus 27139	: V=0.9506229, theta=-47.05578 -> V=1.0, theta=0.0
% INFO    : Bus 27140	: V=0.9616762, theta=-47.76935 -> V=1.0, theta=0.0
% INFO    : Bus 27141	: V=0.9605049, theta=-47.453014 -> V=1.0, theta=0.0
% INFO    : Bus 27142	: V=1.0098033, theta=-39.811047 -> V=1.0, theta=0.0
% INFO    : Bus 27143	: V=0.9906581, theta=-42.175377 -> V=1.0, theta=0.0
% INFO    : Bus 27144	: V=0.9664826, theta=-43.712967 -> V=1.0, theta=0.0
% INFO    : Bus 27145	: V=0.9859458, theta=-41.286639 -> V=1.0, theta=0.0
% INFO    : Bus 27146	: V=0.9947516, theta=-40.499235 -> V=1.0, theta=0.0
% INFO    : Bus 27147	: V=0.9899039, theta=-41.168623 -> V=1.0, theta=0.0
% INFO    : Bus 27148	: V=1.0024539, theta=-39.972426 -> V=1.0, theta=0.0
% INFO    : Bus 27149	: V=0.9928671, theta=-40.946085 -> V=1.0, theta=0.0
% INFO    : Bus 27150	: V=1.0004729, theta=-39.965387 -> V=1.0, theta=0.0
% INFO    : Bus 27151	: V=0.995621, theta=-39.962988 -> V=1.0, theta=0.0
% INFO    : Bus 27152	: V=0.9951178, theta=-39.910529 -> V=1.0, theta=0.0
% INFO    : Bus 27153	: V=0.9951608, theta=-39.997894 -> V=1.0, theta=0.0
% INFO    : Bus 27154	: V=0.9927919, theta=-40.398327 -> V=1.0, theta=0.0
% INFO    : Bus 27155	: V=0.9928563, theta=-40.386134 -> V=1.0, theta=0.0
% INFO    : Bus 27156	: V=0.992003, theta=-40.261383 -> V=1.0, theta=0.0
% INFO    : Bus 27157	: V=0.992815, theta=-39.901606 -> V=1.0, theta=0.0
% INFO    : Bus 27158	: V=1.0008036, theta=-38.314041 -> V=1.0, theta=0.0
% INFO    : Bus 27159	: V=0.9968589, theta=-39.680852 -> V=1.0, theta=0.0
% INFO    : Bus 27160	: V=1.0112983, theta=-38.966743 -> V=1.0, theta=0.0
% INFO    : Bus 27161	: V=1.0094017, theta=-38.009145 -> V=1.0, theta=0.0
% INFO    : Bus 27162	: V=1.0176891, theta=-34.43534 -> V=1.0, theta=0.0
% INFO    : Bus 27163	: V=0.9979515, theta=-38.26674 -> V=1.0, theta=0.0
% INFO    : Bus 27164	: V=0.9898402, theta=-35.776663 -> V=1.0, theta=0.0
% INFO    : Bus 27165	: V=0.9852887, theta=-37.094321 -> V=1.0, theta=0.0
% INFO    : Bus 27166	: V=0.9865143, theta=-36.788382 -> V=1.0, theta=0.0
% INFO    : Bus 27167	: V=0.9908529, theta=-36.841858 -> V=1.0, theta=0.0
% INFO    : Bus 27168	: V=0.9815929, theta=-37.385358 -> V=1.0, theta=0.0
% INFO    : Bus 27169	: V=0.9867751, theta=-36.831041 -> V=1.0, theta=0.0
% INFO    : Bus 27170	: V=0.9873991, theta=-36.658257 -> V=1.0, theta=0.0
% INFO    : Bus 27171	: V=0.9951903, theta=-33.129819 -> V=1.0, theta=0.0
% INFO    : Bus 27172	: V=0.9972103, theta=-33.102532 -> V=1.0, theta=0.0
% INFO    : Bus 27173	: V=1.0045038, theta=-31.114432 -> V=1.0, theta=0.0
% INFO    : Bus 27174	: V=1.0036372, theta=-30.618901 -> V=1.0, theta=0.0
% INFO    : Bus 27175	: V=0.9932528, theta=-30.848743 -> V=1.0, theta=0.0
% INFO    : Bus 27176	: V=0.9976729, theta=-34.310982 -> V=1.0, theta=0.0
% INFO    : Bus 27177	: V=0.9808106, theta=-27.567941 -> V=1.0, theta=0.0
% INFO    : Bus 27178	: V=0.9604729, theta=-27.856857 -> V=1.0, theta=0.0
% INFO    : Bus 27179	: V=0.9858093, theta=-24.31877 -> V=1.0, theta=0.0
% INFO    : Bus 27180	: V=0.9783442, theta=-26.739727 -> V=1.0, theta=0.0
% INFO    : Bus 27181	: V=0.9614427, theta=-27.740955 -> V=1.0, theta=0.0
% INFO    : Bus 27182	: V=0.9771549, theta=-41.553453 -> V=1.0, theta=0.0
% INFO    : Bus 27183	: V=0.9904967, theta=-39.874727 -> V=1.0, theta=0.0
% INFO    : Bus 27184	: V=0.9923333, theta=-39.309787 -> V=1.0, theta=0.0
% INFO    : Bus 27185	: V=0.9973581, theta=-37.127618 -> V=1.0, theta=0.0
% INFO    : Bus 27186	: V=0.9912419, theta=-39.617293 -> V=1.0, theta=0.0
% INFO    : Bus 27187	: V=0.9940905, theta=-37.560531 -> V=1.0, theta=0.0
% INFO    : Bus 27188	: V=0.9856247, theta=-36.291791 -> V=1.0, theta=0.0
% INFO    : Bus 27189	: V=0.9773457, theta=-37.853497 -> V=1.0, theta=0.0
% INFO    : Bus 27190	: V=0.976292, theta=-37.884681 -> V=1.0, theta=0.0
% INFO    : Bus 27191	: V=0.9857628, theta=-36.256671 -> V=1.0, theta=0.0
% INFO    : Bus 27192	: V=0.9863069, theta=-36.148943 -> V=1.0, theta=0.0
% INFO    : Bus 27193	: V=0.9769006, theta=-38.774938 -> V=1.0, theta=0.0
% INFO    : Bus 27194	: V=0.9781731, theta=-38.573902 -> V=1.0, theta=0.0
% INFO    : Bus 27195	: V=0.97841, theta=-37.974027 -> V=1.0, theta=0.0
% INFO    : Bus 27196	: V=0.9813012, theta=-37.283966 -> V=1.0, theta=0.0
% INFO    : Bus 27197	: V=0.9784418, theta=-38.405884 -> V=1.0, theta=0.0
% INFO    : Bus 27198	: V=0.9864953, theta=-35.974855 -> V=1.0, theta=0.0
% INFO    : Bus 27199	: V=0.9883215, theta=-34.611227 -> V=1.0, theta=0.0
% INFO    : Bus 27200	: V=0.9881094, theta=-35.754197 -> V=1.0, theta=0.0
% INFO    : Bus 27201	: V=0.9985009, theta=-30.201207 -> V=1.0, theta=0.0
% INFO    : Bus 27202	: V=0.9877256, theta=-32.215566 -> V=1.0, theta=0.0
% INFO    : Bus 27203	: V=0.9822015, theta=-32.014918 -> V=1.0, theta=0.0
% INFO    : Bus 27204	: V=0.986293, theta=-32.521173 -> V=1.0, theta=0.0
% INFO    : Bus 27205	: V=0.9952887, theta=-30.540816 -> V=1.0, theta=0.0
% INFO    : Bus 27206	: V=0.9969043, theta=-29.608444 -> V=1.0, theta=0.0
% INFO    : Bus 27207	: V=0.9546352, theta=-59.457926 -> V=1.0, theta=0.0
% INFO    : Bus 27208	: V=0.955835, theta=-60.07402 -> V=1.0, theta=0.0
% INFO    : Bus 27209	: V=0.9541349, theta=-58.813051 -> V=1.0, theta=0.0
% INFO    : Bus 27210	: V=0.9586907, theta=-54.694856 -> V=1.0, theta=0.0
% INFO    : Bus 27211	: V=0.9582792, theta=-55.114586 -> V=1.0, theta=0.0
% INFO    : Bus 27212	: V=0.9592191, theta=-55.421173 -> V=1.0, theta=0.0
% INFO    : Bus 27213	: V=0.9603053, theta=-56.003156 -> V=1.0, theta=0.0
% INFO    : Bus 27214	: V=0.9589733, theta=-55.549806 -> V=1.0, theta=0.0
% INFO    : Bus 27215	: V=0.9578806, theta=-58.953207 -> V=1.0, theta=0.0
% INFO    : Bus 27216	: V=0.9578284, theta=-59.483637 -> V=1.0, theta=0.0
% INFO    : Bus 27217	: V=0.9597635, theta=-60.15394 -> V=1.0, theta=0.0
% INFO    : Bus 27218	: V=0.9614457, theta=-58.440978 -> V=1.0, theta=0.0
% INFO    : Bus 27219	: V=0.9604827, theta=-60.151865 -> V=1.0, theta=0.0
% INFO    : Bus 27220	: V=0.9627775, theta=-58.817594 -> V=1.0, theta=0.0
% INFO    : Bus 27221	: V=0.9643642, theta=-59.13866 -> V=1.0, theta=0.0
% INFO    : Bus 27222	: V=0.960849, theta=-57.901986 -> V=1.0, theta=0.0
% INFO    : Bus 27223	: V=0.9609382, theta=-57.683022 -> V=1.0, theta=0.0
% INFO    : Bus 27224	: V=0.9609329, theta=-57.722442 -> V=1.0, theta=0.0
% INFO    : Bus 27225	: V=0.9591388, theta=-58.810535 -> V=1.0, theta=0.0
% INFO    : Bus 27226	: V=0.9611706, theta=-57.30685 -> V=1.0, theta=0.0
% INFO    : Bus 27227	: V=0.9619543, theta=-56.503229 -> V=1.0, theta=0.0
% INFO    : Bus 27228	: V=0.962611, theta=-55.684377 -> V=1.0, theta=0.0
% INFO    : Bus 27229	: V=0.9679076, theta=-53.626376 -> V=1.0, theta=0.0
% INFO    : Bus 27230	: V=0.9635481, theta=-56.921356 -> V=1.0, theta=0.0
% INFO    : Bus 27231	: V=0.9629657, theta=-57.040238 -> V=1.0, theta=0.0
% INFO    : Bus 27232	: V=0.9621422, theta=-57.089497 -> V=1.0, theta=0.0
% INFO    : Bus 27233	: V=0.9615431, theta=-56.853563 -> V=1.0, theta=0.0
% INFO    : Bus 27234	: V=0.9683517, theta=-53.782797 -> V=1.0, theta=0.0
% INFO    : Bus 27235	: V=0.9685554, theta=-53.925795 -> V=1.0, theta=0.0
% INFO    : Bus 27236	: V=0.9593827, theta=-58.706716 -> V=1.0, theta=0.0
% INFO    : Bus 27237	: V=0.9614631, theta=-57.691815 -> V=1.0, theta=0.0
% INFO    : Bus 27238	: V=0.9664588, theta=-57.276826 -> V=1.0, theta=0.0
% INFO    : Bus 27239	: V=0.9660654, theta=-59.27806 -> V=1.0, theta=0.0
% INFO    : Bus 27240	: V=0.9630785, theta=-57.558942 -> V=1.0, theta=0.0
% INFO    : Bus 27241	: V=0.970935, theta=-53.907191 -> V=1.0, theta=0.0
% INFO    : Bus 27242	: V=0.9674161, theta=-28.859516 -> V=1.0, theta=0.0
% INFO    : Bus 27243	: V=0.9659599, theta=-29.060473 -> V=1.0, theta=0.0
% INFO    : Bus 27244	: V=0.9791288, theta=-28.668027 -> V=1.0, theta=0.0
% INFO    : Bus 27245	: V=0.9934197, theta=-27.050743 -> V=1.0, theta=0.0
% INFO    : Bus 27246	: V=0.9932816, theta=-27.415239 -> V=1.0, theta=0.0
% INFO    : Bus 27247	: V=0.9774575, theta=-28.592957 -> V=1.0, theta=0.0
% INFO    : Bus 27248	: V=0.9810944, theta=-28.413002 -> V=1.0, theta=0.0
% INFO    : Bus 27249	: V=0.9869726, theta=-27.701826 -> V=1.0, theta=0.0
% INFO    : Bus 27250	: V=0.9787574, theta=-28.111876 -> V=1.0, theta=0.0
% INFO    : Bus 27251	: V=0.9835149, theta=-28.036664 -> V=1.0, theta=0.0
% INFO    : Bus 27252	: V=0.9953194, theta=-26.089269 -> V=1.0, theta=0.0
% INFO    : Bus 27253	: V=0.9922788, theta=-27.792661 -> V=1.0, theta=0.0
% INFO    : Bus 27254	: V=0.9697417, theta=-31.260128 -> V=1.0, theta=0.0
% INFO    : Bus 27255	: V=0.9519803, theta=-32.337194 -> V=1.0, theta=0.0
% INFO    : Bus 27256	: V=0.9697757, theta=-31.181229 -> V=1.0, theta=0.0
% INFO    : Bus 27257	: V=0.966289, theta=-32.611708 -> V=1.0, theta=0.0
% INFO    : Bus 27258	: V=0.9585691, theta=-32.253513 -> V=1.0, theta=0.0
% INFO    : Bus 27259	: V=0.9607832, theta=-31.719575 -> V=1.0, theta=0.0
% INFO    : Bus 27260	: V=0.9614654, theta=-31.332886 -> V=1.0, theta=0.0
% INFO    : Bus 27261	: V=0.9673503, theta=-49.617922 -> V=1.0, theta=0.0
% INFO    : Bus 27262	: V=0.9668641, theta=-49.709858 -> V=1.0, theta=0.0
% INFO    : Bus 27263	: V=0.9647019, theta=-50.591166 -> V=1.0, theta=0.0
% INFO    : Bus 27264	: V=0.9644225, theta=-50.686238 -> V=1.0, theta=0.0
% INFO    : Bus 27265	: V=0.967006, theta=-49.178277 -> V=1.0, theta=0.0
% INFO    : Bus 27266	: V=0.9646699, theta=-50.650546 -> V=1.0, theta=0.0
% INFO    : Bus 27267	: V=0.9684507, theta=-49.414353 -> V=1.0, theta=0.0
% INFO    : Bus 27268	: V=0.9665123, theta=-50.0975 -> V=1.0, theta=0.0
% INFO    : Bus 27269	: V=0.9660988, theta=-50.309053 -> V=1.0, theta=0.0
% INFO    : Bus 27270	: V=0.9665193, theta=-49.791805 -> V=1.0, theta=0.0
% INFO    : Bus 27271	: V=0.9662537, theta=-49.862065 -> V=1.0, theta=0.0
% INFO    : Bus 27272	: V=0.9633936, theta=-50.967523 -> V=1.0, theta=0.0
% INFO    : Bus 27273	: V=0.9643201, theta=-50.886734 -> V=1.0, theta=0.0
% INFO    : Bus 27274	: V=0.9677493, theta=-50.538144 -> V=1.0, theta=0.0
% INFO    : Bus 27275	: V=0.9680304, theta=-49.105745 -> V=1.0, theta=0.0
% INFO    : Bus 27276	: V=0.9686404, theta=-49.288524 -> V=1.0, theta=0.0
% INFO    : Bus 27277	: V=0.9774649, theta=-48.850664 -> V=1.0, theta=0.0
% INFO    : Bus 27278	: V=0.9663931, theta=-50.103431 -> V=1.0, theta=0.0
% INFO    : Bus 27279	: V=0.9677479, theta=-49.792695 -> V=1.0, theta=0.0
% INFO    : Bus 27280	: V=0.9646527, theta=-49.780037 -> V=1.0, theta=0.0
% INFO    : Bus 27281	: V=0.9664079, theta=-49.992416 -> V=1.0, theta=0.0
% INFO    : Bus 27282	: V=0.9660206, theta=-49.977401 -> V=1.0, theta=0.0
% INFO    : Bus 27283	: V=0.9709946, theta=-49.132981 -> V=1.0, theta=0.0
% INFO    : Bus 27284	: V=0.9746159, theta=-49.374924 -> V=1.0, theta=0.0
% INFO    : Bus 27285	: V=0.968806, theta=-50.466313 -> V=1.0, theta=0.0
% INFO    : Bus 27286	: V=0.9642904, theta=-49.257981 -> V=1.0, theta=0.0
% INFO    : Bus 27287	: V=0.9677277, theta=-50.269701 -> V=1.0, theta=0.0
% INFO    : Bus 27288	: V=0.9672629, theta=-48.023367 -> V=1.0, theta=0.0
% INFO    : Bus 27289	: V=0.9775907, theta=-48.727747 -> V=1.0, theta=0.0
% INFO    : Bus 27290	: V=0.9665092, theta=-49.2053 -> V=1.0, theta=0.0
% INFO    : Bus 27291	: V=0.9891666, theta=-34.964191 -> V=1.0, theta=0.0
% INFO    : Bus 27292	: V=0.9910791, theta=-33.419599 -> V=1.0, theta=0.0
% INFO    : Bus 27293	: V=0.9896065, theta=-33.295842 -> V=1.0, theta=0.0
% INFO    : Bus 27294	: V=0.9894512, theta=-33.454946 -> V=1.0, theta=0.0
% INFO    : Bus 27295	: V=0.9898379, theta=-31.766173 -> V=1.0, theta=0.0
% INFO    : Bus 27296	: V=0.9930989, theta=-32.537198 -> V=1.0, theta=0.0
% INFO    : Bus 27297	: V=0.9884753, theta=-33.12107 -> V=1.0, theta=0.0
% INFO    : Bus 27298	: V=0.9891916, theta=-33.181537 -> V=1.0, theta=0.0
% INFO    : Bus 27299	: V=0.9875877, theta=-33.684116 -> V=1.0, theta=0.0
% INFO    : Bus 27300	: V=0.987482, theta=-33.635392 -> V=1.0, theta=0.0
% INFO    : Bus 27301	: V=0.9914617, theta=-33.326989 -> V=1.0, theta=0.0
% INFO    : Bus 27302	: V=0.9882489, theta=-33.75942 -> V=1.0, theta=0.0
% INFO    : Bus 27303	: V=0.9918418, theta=-33.245367 -> V=1.0, theta=0.0
% INFO    : Bus 27304	: V=0.9905251, theta=-34.06198 -> V=1.0, theta=0.0
% INFO    : Bus 27305	: V=0.965647, theta=-33.242617 -> V=1.0, theta=0.0
% INFO    : Bus 27306	: V=0.9871402, theta=-32.886385 -> V=1.0, theta=0.0
% INFO    : Bus 27307	: V=0.9929847, theta=-31.382296 -> V=1.0, theta=0.0
% INFO    : Bus 27308	: V=0.9920307, theta=-34.825124 -> V=1.0, theta=0.0
% INFO    : Bus 27309	: V=0.9744788, theta=-34.659031 -> V=1.0, theta=0.0
% INFO    : Bus 27310	: V=0.9837799, theta=-33.128504 -> V=1.0, theta=0.0
% INFO    : Bus 27311	: V=0.9633201, theta=-36.353298 -> V=1.0, theta=0.0
% INFO    : Bus 27312	: V=0.958627, theta=-37.961683 -> V=1.0, theta=0.0
% INFO    : Bus 27313	: V=0.9593811, theta=-38.301667 -> V=1.0, theta=0.0
% INFO    : Bus 27314	: V=0.961476, theta=-38.233901 -> V=1.0, theta=0.0
% INFO    : Bus 27315	: V=0.9623382, theta=-38.217372 -> V=1.0, theta=0.0
% INFO    : Bus 27316	: V=0.9707141, theta=-35.259755 -> V=1.0, theta=0.0
% INFO    : Bus 27317	: V=0.9698616, theta=-38.025683 -> V=1.0, theta=0.0
% INFO    : Bus 27318	: V=0.962566, theta=-39.121186 -> V=1.0, theta=0.0
% INFO    : Bus 27319	: V=0.9568037, theta=-40.660899 -> V=1.0, theta=0.0
% INFO    : Bus 27320	: V=0.9738681, theta=-38.62303 -> V=1.0, theta=0.0
% INFO    : Bus 27321	: V=0.9614289, theta=-42.509651 -> V=1.0, theta=0.0
% INFO    : Bus 27322	: V=0.9601554, theta=-43.632925 -> V=1.0, theta=0.0
% INFO    : Bus 27323	: V=1.0010262, theta=-28.260991 -> V=1.0, theta=0.0
% INFO    : Bus 27324	: V=1.0034967, theta=-28.505736 -> V=1.0, theta=0.0
% INFO    : Bus 27325	: V=0.9996519, theta=-28.549759 -> V=1.0, theta=0.0
% INFO    : Bus 27326	: V=1.0030144, theta=-27.910005 -> V=1.0, theta=0.0
% INFO    : Bus 27327	: V=1.0047722, theta=-27.465851 -> V=1.0, theta=0.0
% INFO    : Bus 27328	: V=0.9932367, theta=-29.229177 -> V=1.0, theta=0.0
% INFO    : Bus 27329	: V=1.0076891, theta=-27.695555 -> V=1.0, theta=0.0
% INFO    : Bus 27330	: V=1.0145903, theta=-25.51843 -> V=1.0, theta=0.0
% INFO    : Bus 27331	: V=1.0208207, theta=-23.250715 -> V=1.0, theta=0.0
% INFO    : Bus 27332	: V=1.0106939, theta=-26.514489 -> V=1.0, theta=0.0
% INFO    : Bus 27333	: V=1.0104534, theta=-26.447923 -> V=1.0, theta=0.0
% INFO    : Bus 27334	: V=1.0061127, theta=-27.136185 -> V=1.0, theta=0.0
% INFO    : Bus 27335	: V=1.0047126, theta=-27.184396 -> V=1.0, theta=0.0
% INFO    : Bus 27336	: V=1.0048072, theta=-27.173304 -> V=1.0, theta=0.0
% INFO    : Bus 27337	: V=1.0118994, theta=-26.04795 -> V=1.0, theta=0.0
% INFO    : Bus 27338	: V=1.0043297, theta=-27.174562 -> V=1.0, theta=0.0
% INFO    : Bus 27339	: V=1.0070678, theta=-26.912529 -> V=1.0, theta=0.0
% INFO    : Bus 27340	: V=1.0005118, theta=-27.259738 -> V=1.0, theta=0.0
% INFO    : Bus 27341	: V=1.0058533, theta=-27.216031 -> V=1.0, theta=0.0
% INFO    : Bus 27342	: V=1.0037946, theta=-27.076308 -> V=1.0, theta=0.0
% INFO    : Bus 27343	: V=0.9490141, theta=-45.118107 -> V=1.0, theta=0.0
% INFO    : Bus 27344	: V=0.948883, theta=-42.483114 -> V=1.0, theta=0.0
% INFO    : Bus 27345	: V=0.9601672, theta=-37.7948 -> V=1.0, theta=0.0
% INFO    : Bus 27346	: V=0.9611616, theta=-37.270931 -> V=1.0, theta=0.0
% INFO    : Bus 27347	: V=0.9481321, theta=-39.149805 -> V=1.0, theta=0.0
% INFO    : Bus 27348	: V=0.9466794, theta=-39.38207 -> V=1.0, theta=0.0
% INFO    : Bus 27349	: V=0.9535787, theta=-39.268492 -> V=1.0, theta=0.0
% INFO    : Bus 27350	: V=0.9423405, theta=-41.46221 -> V=1.0, theta=0.0
% INFO    : Bus 27351	: V=0.9383419, theta=-41.44075 -> V=1.0, theta=0.0
% INFO    : Bus 27352	: V=0.9387292, theta=-42.168786 -> V=1.0, theta=0.0
% INFO    : Bus 27353	: V=0.9345283, theta=-41.718978 -> V=1.0, theta=0.0
% INFO    : Bus 27354	: V=0.9349562, theta=-41.877464 -> V=1.0, theta=0.0
% INFO    : Bus 27355	: V=0.9384072, theta=-41.921905 -> V=1.0, theta=0.0
% INFO    : Bus 27356	: V=0.9471809, theta=-45.085813 -> V=1.0, theta=0.0
% INFO    : Bus 27357	: V=0.9473296, theta=-34.346416 -> V=1.0, theta=0.0
% INFO    : Bus 27358	: V=0.9501257, theta=-33.570361 -> V=1.0, theta=0.0
% INFO    : Bus 27359	: V=0.9564535, theta=-32.17927 -> V=1.0, theta=0.0
% INFO    : Bus 27360	: V=0.942615, theta=-34.645812 -> V=1.0, theta=0.0
% INFO    : Bus 27361	: V=0.9429259, theta=-34.860147 -> V=1.0, theta=0.0
% INFO    : Bus 27362	: V=0.9409419, theta=-35.037428 -> V=1.0, theta=0.0
% INFO    : Bus 27363	: V=0.9369512, theta=-35.85151 -> V=1.0, theta=0.0
% INFO    : Bus 27364	: V=0.9356611, theta=-35.84198 -> V=1.0, theta=0.0
% INFO    : Bus 27365	: V=0.9336177, theta=-36.156307 -> V=1.0, theta=0.0
% INFO    : Bus 27366	: V=0.9442048, theta=-35.272898 -> V=1.0, theta=0.0
% INFO    : Bus 27367	: V=0.9624687, theta=-55.269391 -> V=1.0, theta=0.0
% INFO    : Bus 27368	: V=0.9611453, theta=-55.80832 -> V=1.0, theta=0.0
% INFO    : Bus 27369	: V=0.9607083, theta=-55.534124 -> V=1.0, theta=0.0
% INFO    : Bus 27370	: V=0.96082, theta=-55.503729 -> V=1.0, theta=0.0
% INFO    : Bus 27371	: V=0.9610247, theta=-55.499814 -> V=1.0, theta=0.0
% INFO    : Bus 27372	: V=0.9612525, theta=-55.441484 -> V=1.0, theta=0.0
% INFO    : Bus 27373	: V=0.9662667, theta=-54.791691 -> V=1.0, theta=0.0
% INFO    : Bus 27374	: V=0.9620476, theta=-55.334868 -> V=1.0, theta=0.0
% INFO    : Bus 27375	: V=0.9636952, theta=-55.151919 -> V=1.0, theta=0.0
% INFO    : Bus 27376	: V=0.9679583, theta=-53.994911 -> V=1.0, theta=0.0
% INFO    : Bus 27377	: V=0.964892, theta=-54.870094 -> V=1.0, theta=0.0
% INFO    : Bus 27378	: V=0.9733394, theta=-52.496681 -> V=1.0, theta=0.0
% INFO    : Bus 27379	: V=0.9669973, theta=-54.3837 -> V=1.0, theta=0.0
% INFO    : Bus 27380	: V=0.9631477, theta=-55.196412 -> V=1.0, theta=0.0
% INFO    : Bus 27381	: V=0.9667074, theta=-54.626643 -> V=1.0, theta=0.0
% INFO    : Bus 27382	: V=0.9672534, theta=-54.368621 -> V=1.0, theta=0.0
% INFO    : Bus 27383	: V=0.966853, theta=-54.381092 -> V=1.0, theta=0.0
% INFO    : Bus 27384	: V=0.9738796, theta=-52.351812 -> V=1.0, theta=0.0
% INFO    : Bus 27385	: V=0.9887165, theta=-56.450046 -> V=1.0, theta=0.0
% INFO    : Bus 27386	: V=0.9701849, theta=-57.102705 -> V=1.0, theta=0.0
% INFO    : Bus 27387	: V=0.9708394, theta=-57.052087 -> V=1.0, theta=0.0
% INFO    : Bus 27388	: V=0.9723283, theta=-56.663883 -> V=1.0, theta=0.0
% INFO    : Bus 27389	: V=0.9712061, theta=-56.519734 -> V=1.0, theta=0.0
% INFO    : Bus 27390	: V=0.9692875, theta=-57.118037 -> V=1.0, theta=0.0
% INFO    : Bus 27391	: V=0.9712481, theta=-56.886395 -> V=1.0, theta=0.0
% INFO    : Bus 27392	: V=0.9682319, theta=-56.562684 -> V=1.0, theta=0.0
% INFO    : Bus 27393	: V=0.9666434, theta=-56.127725 -> V=1.0, theta=0.0
% INFO    : Bus 27394	: V=0.9658637, theta=-56.089405 -> V=1.0, theta=0.0
% INFO    : Bus 27395	: V=0.9658703, theta=-56.069799 -> V=1.0, theta=0.0
% INFO    : Bus 27396	: V=0.966024, theta=-56.017488 -> V=1.0, theta=0.0
% INFO    : Bus 27397	: V=0.9659481, theta=-55.844458 -> V=1.0, theta=0.0
% INFO    : Bus 27398	: V=0.967678, theta=-54.265482 -> V=1.0, theta=0.0
% INFO    : Bus 27399	: V=0.9638952, theta=-55.458734 -> V=1.0, theta=0.0
% INFO    : Bus 27400	: V=0.9653704, theta=-54.917113 -> V=1.0, theta=0.0
% INFO    : Bus 27401	: V=0.9617462, theta=-56.181092 -> V=1.0, theta=0.0
% INFO    : Bus 27402	: V=0.9617394, theta=-55.044974 -> V=1.0, theta=0.0
% INFO    : Bus 27403	: V=0.962891, theta=-55.55266 -> V=1.0, theta=0.0
% INFO    : Bus 27404	: V=0.9628887, theta=-55.422507 -> V=1.0, theta=0.0
% INFO    : Bus 27405	: V=0.96365, theta=-54.871684 -> V=1.0, theta=0.0
% INFO    : Bus 27406	: V=0.9672973, theta=-54.298165 -> V=1.0, theta=0.0
% INFO    : Bus 27407	: V=0.9717622, theta=-53.096975 -> V=1.0, theta=0.0
% INFO    : Bus 27408	: V=0.9634536, theta=-55.235462 -> V=1.0, theta=0.0
% INFO    : Bus 27409	: V=0.9638503, theta=-55.347155 -> V=1.0, theta=0.0
% INFO    : Bus 27410	: V=0.9676678, theta=-54.052352 -> V=1.0, theta=0.0
% INFO    : Bus 27411	: V=0.9655563, theta=-54.873168 -> V=1.0, theta=0.0
% INFO    : Bus 27412	: V=0.965009, theta=-54.93871 -> V=1.0, theta=0.0
% INFO    : Bus 27413	: V=0.9633949, theta=-55.773671 -> V=1.0, theta=0.0
% INFO    : Bus 27414	: V=0.96587, theta=-55.446439 -> V=1.0, theta=0.0
% INFO    : Bus 27415	: V=0.9576457, theta=-56.47651 -> V=1.0, theta=0.0
% INFO    : Bus 27416	: V=0.9658886, theta=-55.679254 -> V=1.0, theta=0.0
% INFO    : Bus 27417	: V=0.9625993, theta=-55.862573 -> V=1.0, theta=0.0
% INFO    : Bus 27418	: V=0.9626908, theta=-55.763001 -> V=1.0, theta=0.0
% INFO    : Bus 27419	: V=0.9610755, theta=-55.911513 -> V=1.0, theta=0.0
% INFO    : Bus 27420	: V=0.9595735, theta=-55.952349 -> V=1.0, theta=0.0
% INFO    : Bus 27421	: V=0.9665359, theta=-55.054055 -> V=1.0, theta=0.0
% INFO    : Bus 27422	: V=0.9609843, theta=-55.893702 -> V=1.0, theta=0.0
% INFO    : Bus 27423	: V=0.9670889, theta=-55.184868 -> V=1.0, theta=0.0
% INFO    : Bus 27424	: V=0.9675813, theta=-55.243425 -> V=1.0, theta=0.0
% INFO    : Bus 27425	: V=0.9675743, theta=-55.534631 -> V=1.0, theta=0.0
% INFO    : Bus 27426	: V=0.9695047, theta=-56.153923 -> V=1.0, theta=0.0
% INFO    : Bus 27427	: V=0.9745778, theta=-52.685644 -> V=1.0, theta=0.0
% INFO    : Bus 27428	: V=0.9690456, theta=-54.912426 -> V=1.0, theta=0.0
% INFO    : Bus 27429	: V=0.9587984, theta=-56.131871 -> V=1.0, theta=0.0
% INFO    : Bus 27430	: V=0.9745855, theta=-51.915734 -> V=1.0, theta=0.0
% INFO    : Bus 27431	: V=0.9629597, theta=-54.935957 -> V=1.0, theta=0.0
% INFO    : Bus 27432	: V=0.9675656, theta=-53.90384 -> V=1.0, theta=0.0
% INFO    : Bus 27433	: V=0.9727908, theta=-52.673786 -> V=1.0, theta=0.0
% INFO    : Bus 27434	: V=0.9679322, theta=-53.830019 -> V=1.0, theta=0.0
% INFO    : Bus 27435	: V=0.9643118, theta=-54.683128 -> V=1.0, theta=0.0
% INFO    : Bus 27436	: V=0.9639213, theta=-55.089794 -> V=1.0, theta=0.0
% INFO    : Bus 27437	: V=0.965154, theta=-54.173756 -> V=1.0, theta=0.0
% INFO    : Bus 27438	: V=0.9653115, theta=-54.123303 -> V=1.0, theta=0.0
% INFO    : Bus 27439	: V=0.9716227, theta=-53.116304 -> V=1.0, theta=0.0
% INFO    : Bus 27440	: V=0.9678093, theta=-53.876012 -> V=1.0, theta=0.0
% INFO    : Bus 27441	: V=0.9649073, theta=-54.016786 -> V=1.0, theta=0.0
% INFO    : Bus 27442	: V=0.964304, theta=-54.085752 -> V=1.0, theta=0.0
% INFO    : Bus 27443	: V=0.964825, theta=-54.422995 -> V=1.0, theta=0.0
% INFO    : Bus 27444	: V=0.9682463, theta=-53.338469 -> V=1.0, theta=0.0
% INFO    : Bus 27445	: V=0.9692559, theta=-52.751182 -> V=1.0, theta=0.0
% INFO    : Bus 27446	: V=0.9692889, theta=-53.260162 -> V=1.0, theta=0.0
% INFO    : Bus 27447	: V=0.9695431, theta=-52.793117 -> V=1.0, theta=0.0
% INFO    : Bus 27448	: V=0.9700273, theta=-51.66482 -> V=1.0, theta=0.0
% INFO    : Bus 27449	: V=0.9721042, theta=-51.579022 -> V=1.0, theta=0.0
% INFO    : Bus 27450	: V=0.9762647, theta=-50.896912 -> V=1.0, theta=0.0
% INFO    : Bus 27451	: V=0.9725472, theta=-53.941198 -> V=1.0, theta=0.0
% INFO    : Bus 27452	: V=0.9684355, theta=-53.57125 -> V=1.0, theta=0.0
% INFO    : Bus 27453	: V=0.9594473, theta=-57.25343 -> V=1.0, theta=0.0
% INFO    : Bus 27454	: V=0.9606241, theta=-57.019534 -> V=1.0, theta=0.0
% INFO    : Bus 27455	: V=0.9608129, theta=-56.280575 -> V=1.0, theta=0.0
% INFO    : Bus 27456	: V=0.9604094, theta=-57.058341 -> V=1.0, theta=0.0
% INFO    : Bus 27457	: V=0.95876, theta=-57.474371 -> V=1.0, theta=0.0
% INFO    : Bus 27458	: V=0.9624617, theta=-56.045682 -> V=1.0, theta=0.0
% INFO    : Bus 27459	: V=0.9630575, theta=-55.979262 -> V=1.0, theta=0.0
% INFO    : Bus 27460	: V=0.9640052, theta=-55.813322 -> V=1.0, theta=0.0
% INFO    : Bus 27461	: V=0.9662207, theta=-54.175142 -> V=1.0, theta=0.0
% INFO    : Bus 27462	: V=0.9664075, theta=-54.189384 -> V=1.0, theta=0.0
% INFO    : Bus 27463	: V=0.9643974, theta=-56.344199 -> V=1.0, theta=0.0
% INFO    : Bus 27464	: V=0.9666875, theta=-54.210994 -> V=1.0, theta=0.0
% INFO    : Bus 27465	: V=0.9603692, theta=-57.034215 -> V=1.0, theta=0.0
% INFO    : Bus 27466	: V=0.9619235, theta=-56.874922 -> V=1.0, theta=0.0
% INFO    : Bus 27467	: V=0.9625388, theta=-56.840119 -> V=1.0, theta=0.0
% INFO    : Bus 27468	: V=0.9628668, theta=-56.78035 -> V=1.0, theta=0.0
% INFO    : Bus 27469	: V=0.9616775, theta=-56.929877 -> V=1.0, theta=0.0
% INFO    : Bus 27470	: V=0.9638693, theta=-56.042023 -> V=1.0, theta=0.0
% INFO    : Bus 27471	: V=0.9645388, theta=-55.886631 -> V=1.0, theta=0.0
% INFO    : Bus 27472	: V=0.9665335, theta=-54.320982 -> V=1.0, theta=0.0
% INFO    : Bus 27473	: V=0.9629045, theta=-56.246593 -> V=1.0, theta=0.0
% INFO    : Bus 27474	: V=0.9606038, theta=-57.024233 -> V=1.0, theta=0.0
% INFO    : Bus 27475	: V=0.9603969, theta=-57.026921 -> V=1.0, theta=0.0
% INFO    : Bus 27476	: V=0.9596177, theta=-57.051544 -> V=1.0, theta=0.0
% INFO    : Bus 27477	: V=0.9602325, theta=-57.022464 -> V=1.0, theta=0.0
% INFO    : Bus 27478	: V=0.9609406, theta=-56.986255 -> V=1.0, theta=0.0
% INFO    : Bus 27479	: V=0.9606969, theta=-56.988302 -> V=1.0, theta=0.0
% INFO    : Bus 27480	: V=0.9617605, theta=-56.91068 -> V=1.0, theta=0.0
% INFO    : Bus 27481	: V=0.9611184, theta=-56.254255 -> V=1.0, theta=0.0
% INFO    : Bus 27482	: V=0.9600236, theta=-57.098196 -> V=1.0, theta=0.0
% INFO    : Bus 27483	: V=0.9606914, theta=-56.278504 -> V=1.0, theta=0.0
% INFO    : Bus 27484	: V=0.9592836, theta=-57.131871 -> V=1.0, theta=0.0
% INFO    : Bus 27485	: V=0.96153, theta=-56.218108 -> V=1.0, theta=0.0
% INFO    : Bus 27486	: V=0.9558486, theta=-57.310811 -> V=1.0, theta=0.0
% INFO    : Bus 27487	: V=0.9612963, theta=-56.219422 -> V=1.0, theta=0.0
% INFO    : Bus 27488	: V=0.9664225, theta=-54.009344 -> V=1.0, theta=0.0
% INFO    : Bus 27489	: V=0.9599106, theta=-56.292241 -> V=1.0, theta=0.0
% INFO    : Bus 27490	: V=0.9589204, theta=-57.110453 -> V=1.0, theta=0.0
% INFO    : Bus 27491	: V=0.9600479, theta=-56.321975 -> V=1.0, theta=0.0
% INFO    : Bus 27492	: V=0.960167, theta=-56.323994 -> V=1.0, theta=0.0
% INFO    : Bus 27493	: V=0.9612069, theta=-56.984008 -> V=1.0, theta=0.0
% INFO    : Bus 27494	: V=0.9605959, theta=-56.29841 -> V=1.0, theta=0.0
% INFO    : Bus 27495	: V=0.9658352, theta=-54.058814 -> V=1.0, theta=0.0
% INFO    : Bus 27496	: V=0.9598418, theta=-56.208556 -> V=1.0, theta=0.0
% INFO    : Bus 27497	: V=0.9600168, theta=-56.228284 -> V=1.0, theta=0.0
% INFO    : Bus 27498	: V=0.9593091, theta=-57.070054 -> V=1.0, theta=0.0
% INFO    : Bus 27499	: V=0.9598613, theta=-56.290433 -> V=1.0, theta=0.0
% INFO    : Bus 27500	: V=0.9595568, theta=-57.05287 -> V=1.0, theta=0.0
% INFO    : Bus 27501	: V=0.960452, theta=-57.014876 -> V=1.0, theta=0.0
% INFO    : Bus 27502	: V=0.9607826, theta=-57.009519 -> V=1.0, theta=0.0
% INFO    : Bus 27503	: V=0.9605368, theta=-56.044475 -> V=1.0, theta=0.0
% INFO    : Bus 27504	: V=0.9583295, theta=-57.501485 -> V=1.0, theta=0.0
% INFO    : Bus 27505	: V=0.9601156, theta=-56.065625 -> V=1.0, theta=0.0
% INFO    : Bus 27506	: V=0.9658939, theta=-54.03821 -> V=1.0, theta=0.0
% INFO    : Bus 27507	: V=0.9604125, theta=-56.300471 -> V=1.0, theta=0.0
% INFO    : Bus 27508	: V=0.9603444, theta=-56.317922 -> V=1.0, theta=0.0
% INFO    : Bus 27509	: V=0.9600888, theta=-56.316957 -> V=1.0, theta=0.0
% INFO    : Bus 27510	: V=0.9603986, theta=-57.20832 -> V=1.0, theta=0.0
% INFO    : Bus 27511	: V=0.9594675, theta=-57.252375 -> V=1.0, theta=0.0
% INFO    : Bus 27512	: V=0.9579688, theta=-57.095645 -> V=1.0, theta=0.0
% INFO    : Bus 27513	: V=0.9575494, theta=-57.184941 -> V=1.0, theta=0.0
% INFO    : Bus 27514	: V=0.9610823, theta=-56.250389 -> V=1.0, theta=0.0
% INFO    : Bus 27515	: V=0.9554619, theta=-57.282332 -> V=1.0, theta=0.0
% INFO    : Bus 27516	: V=0.9592088, theta=-56.694355 -> V=1.0, theta=0.0
% INFO    : Bus 27517	: V=0.9586525, theta=-56.875132 -> V=1.0, theta=0.0
% INFO    : Bus 27518	: V=0.9575732, theta=-57.767791 -> V=1.0, theta=0.0
% INFO    : Bus 27519	: V=0.9580115, theta=-56.880355 -> V=1.0, theta=0.0
% INFO    : Bus 27520	: V=0.9559701, theta=-57.851902 -> V=1.0, theta=0.0
% INFO    : Bus 27521	: V=0.9569522, theta=-57.797451 -> V=1.0, theta=0.0
% INFO    : Bus 27522	: V=0.9598465, theta=-56.078525 -> V=1.0, theta=0.0
% INFO    : Bus 27523	: V=0.9585511, theta=-57.48644 -> V=1.0, theta=0.0
% INFO    : Bus 27524	: V=0.959633, theta=-56.030734 -> V=1.0, theta=0.0
% INFO    : Bus 27525	: V=0.9592747, theta=-57.314767 -> V=1.0, theta=0.0
% INFO    : Bus 27526	: V=0.9579091, theta=-56.917872 -> V=1.0, theta=0.0
% INFO    : Bus 27527	: V=0.9583885, theta=-57.308421 -> V=1.0, theta=0.0
% INFO    : Bus 27528	: V=0.9593664, theta=-57.169617 -> V=1.0, theta=0.0
% INFO    : Bus 27529	: V=0.9568036, theta=-55.891332 -> V=1.0, theta=0.0
% INFO    : Bus 27530	: V=0.9577728, theta=-54.83708 -> V=1.0, theta=0.0
% INFO    : Bus 27531	: V=0.9567395, theta=-54.915589 -> V=1.0, theta=0.0
% INFO    : Bus 27532	: V=0.9603626, theta=-55.045295 -> V=1.0, theta=0.0
% INFO    : Bus 27533	: V=0.9576711, theta=-55.524023 -> V=1.0, theta=0.0
% INFO    : Bus 27534	: V=0.9608276, theta=-56.724261 -> V=1.0, theta=0.0
% INFO    : Bus 27535	: V=0.9613465, theta=-55.84652 -> V=1.0, theta=0.0
% INFO    : Bus 27536	: V=0.9614293, theta=-55.823704 -> V=1.0, theta=0.0
% INFO    : Bus 27537	: V=0.9611711, theta=-56.977649 -> V=1.0, theta=0.0
% INFO    : Bus 27538	: V=0.9603716, theta=-55.732532 -> V=1.0, theta=0.0
% INFO    : Bus 27539	: V=0.9605313, theta=-55.803965 -> V=1.0, theta=0.0
% INFO    : Bus 27540	: V=0.9614638, theta=-55.684578 -> V=1.0, theta=0.0
% INFO    : Bus 27541	: V=0.9617832, theta=-55.711203 -> V=1.0, theta=0.0
% INFO    : Bus 27542	: V=0.9597229, theta=-57.052991 -> V=1.0, theta=0.0
% INFO    : Bus 27543	: V=0.9607681, theta=-57.252532 -> V=1.0, theta=0.0
% INFO    : Bus 27544	: V=0.9587029, theta=-56.762597 -> V=1.0, theta=0.0
% INFO    : Bus 27545	: V=0.9588456, theta=-57.712654 -> V=1.0, theta=0.0
% INFO    : Bus 27546	: V=0.9618544, theta=-57.531124 -> V=1.0, theta=0.0
% INFO    : Bus 27547	: V=0.9665819, theta=-54.298568 -> V=1.0, theta=0.0
% INFO    : Bus 27548	: V=0.9651667, theta=-56.023646 -> V=1.0, theta=0.0
% INFO    : Bus 27549	: V=0.9641752, theta=-56.122562 -> V=1.0, theta=0.0
% INFO    : Bus 27550	: V=0.9654345, theta=-56.06786 -> V=1.0, theta=0.0
% INFO    : Bus 27551	: V=0.9616386, theta=-57.057452 -> V=1.0, theta=0.0
% INFO    : Bus 27552	: V=0.9612556, theta=-56.600776 -> V=1.0, theta=0.0
% INFO    : Bus 27553	: V=0.9600421, theta=-57.157182 -> V=1.0, theta=0.0
% INFO    : Bus 27554	: V=0.9606778, theta=-56.61168 -> V=1.0, theta=0.0
% INFO    : Bus 27555	: V=0.9620787, theta=-55.998272 -> V=1.0, theta=0.0
% INFO    : Bus 27556	: V=0.9630754, theta=-55.772097 -> V=1.0, theta=0.0
% INFO    : Bus 27557	: V=0.9618306, theta=-56.06137 -> V=1.0, theta=0.0
% INFO    : Bus 27558	: V=0.9624536, theta=-55.853313 -> V=1.0, theta=0.0
% INFO    : Bus 27559	: V=0.9613862, theta=-56.172494 -> V=1.0, theta=0.0
% INFO    : Bus 27560	: V=0.9603615, theta=-57.008253 -> V=1.0, theta=0.0
% INFO    : Bus 27561	: V=0.9599018, theta=-56.462798 -> V=1.0, theta=0.0
% INFO    : Bus 27562	: V=0.9595632, theta=-56.746569 -> V=1.0, theta=0.0
% INFO    : Bus 27563	: V=0.9602471, theta=-56.307756 -> V=1.0, theta=0.0
% INFO    : Bus 27564	: V=0.9601771, theta=-56.165254 -> V=1.0, theta=0.0
% INFO    : Bus 27565	: V=0.9604619, theta=-56.931732 -> V=1.0, theta=0.0
% INFO    : Bus 27566	: V=0.96093, theta=-55.714564 -> V=1.0, theta=0.0
% INFO    : Bus 27567	: V=0.9604331, theta=-53.873203 -> V=1.0, theta=0.0
% INFO    : Bus 27568	: V=0.9605684, theta=-54.687267 -> V=1.0, theta=0.0
% INFO    : Bus 27569	: V=0.958298, theta=-55.429433 -> V=1.0, theta=0.0
% INFO    : Bus 27570	: V=0.9660876, theta=-50.994344 -> V=1.0, theta=0.0
% INFO    : Bus 27571	: V=0.9583187, theta=-54.4815 -> V=1.0, theta=0.0
% INFO    : Bus 27572	: V=0.958299, theta=-54.423477 -> V=1.0, theta=0.0
% INFO    : Bus 27573	: V=0.9564695, theta=-54.268424 -> V=1.0, theta=0.0
% INFO    : Bus 27574	: V=0.9583125, theta=-54.176669 -> V=1.0, theta=0.0
% INFO    : Bus 27575	: V=0.9601829, theta=-54.466115 -> V=1.0, theta=0.0
% INFO    : Bus 27576	: V=0.9611413, theta=-57.093717 -> V=1.0, theta=0.0
% INFO    : Bus 27577	: V=0.9598669, theta=-55.803388 -> V=1.0, theta=0.0
% INFO    : Bus 27578	: V=0.9651295, theta=-56.092844 -> V=1.0, theta=0.0
% INFO    : Bus 27579	: V=0.9555043, theta=-57.311506 -> V=1.0, theta=0.0
% INFO    : Bus 27580	: V=0.9607013, theta=-55.293178 -> V=1.0, theta=0.0
% INFO    : Bus 27581	: V=0.9608954, theta=-55.425995 -> V=1.0, theta=0.0
% INFO    : Bus 27582	: V=0.9611304, theta=-55.59892 -> V=1.0, theta=0.0
% INFO    : Bus 27583	: V=0.9598556, theta=-56.277684 -> V=1.0, theta=0.0
% INFO    : Bus 27584	: V=0.956845, theta=-57.499461 -> V=1.0, theta=0.0
% INFO    : Bus 27585	: V=0.9579094, theta=-57.126345 -> V=1.0, theta=0.0
% INFO    : Bus 27586	: V=0.960185, theta=-55.334392 -> V=1.0, theta=0.0
% INFO    : Bus 27587	: V=0.9602914, theta=-54.920364 -> V=1.0, theta=0.0
% INFO    : Bus 27588	: V=0.9712307, theta=-61.588575 -> V=1.0, theta=0.0
% INFO    : Bus 27589	: V=0.9722045, theta=-61.60537 -> V=1.0, theta=0.0
% INFO    : Bus 27590	: V=0.96862, theta=-62.024158 -> V=1.0, theta=0.0
% INFO    : Bus 27591	: V=0.9689993, theta=-61.065519 -> V=1.0, theta=0.0
% INFO    : Bus 27592	: V=0.9644614, theta=-61.761233 -> V=1.0, theta=0.0
% INFO    : Bus 27593	: V=0.9689972, theta=-61.240734 -> V=1.0, theta=0.0
% INFO    : Bus 27594	: V=0.9646509, theta=-61.545772 -> V=1.0, theta=0.0
% INFO    : Bus 27595	: V=0.968291, theta=-61.061435 -> V=1.0, theta=0.0
% INFO    : Bus 27596	: V=0.9700352, theta=-61.475215 -> V=1.0, theta=0.0
% INFO    : Bus 27597	: V=0.9681164, theta=-60.932245 -> V=1.0, theta=0.0
% INFO    : Bus 27598	: V=0.970628, theta=-61.533044 -> V=1.0, theta=0.0
% INFO    : Bus 27599	: V=0.9684018, theta=-62.216206 -> V=1.0, theta=0.0
% INFO    : Bus 27600	: V=0.9749205, theta=-61.602612 -> V=1.0, theta=0.0
% INFO    : Bus 27601	: V=0.9770219, theta=-61.579947 -> V=1.0, theta=0.0
% INFO    : Bus 27602	: V=0.9548257, theta=-62.716732 -> V=1.0, theta=0.0
% INFO    : Bus 27603	: V=0.9510124, theta=-63.49351 -> V=1.0, theta=0.0
% INFO    : Bus 27604	: V=0.959955, theta=-62.037723 -> V=1.0, theta=0.0
% INFO    : Bus 27605	: V=0.9538353, theta=-60.719273 -> V=1.0, theta=0.0
% INFO    : Bus 27606	: V=0.9592347, theta=-60.560508 -> V=1.0, theta=0.0
% INFO    : Bus 27607	: V=0.9605903, theta=-59.595462 -> V=1.0, theta=0.0
% INFO    : Bus 27608	: V=0.9601864, theta=-60.734012 -> V=1.0, theta=0.0
% INFO    : Bus 27609	: V=0.9677183, theta=-60.429104 -> V=1.0, theta=0.0
% INFO    : Bus 27610	: V=0.9616151, theta=-61.317779 -> V=1.0, theta=0.0
% INFO    : Bus 27611	: V=0.9676532, theta=-61.761681 -> V=1.0, theta=0.0
% INFO    : Bus 27612	: V=0.9578661, theta=-62.568671 -> V=1.0, theta=0.0
% INFO    : Bus 27613	: V=0.9592883, theta=-62.470008 -> V=1.0, theta=0.0
% INFO    : Bus 27614	: V=0.9652158, theta=-64.144615 -> V=1.0, theta=0.0
% INFO    : Bus 27615	: V=0.952224, theta=-63.714709 -> V=1.0, theta=0.0
% INFO    : Bus 27616	: V=0.9536139, theta=-63.762123 -> V=1.0, theta=0.0
% INFO    : Bus 27617	: V=0.9633319, theta=-62.976609 -> V=1.0, theta=0.0
% INFO    : Bus 27618	: V=0.9637068, theta=-62.803191 -> V=1.0, theta=0.0
% INFO    : Bus 27619	: V=0.9641551, theta=-62.620249 -> V=1.0, theta=0.0
% INFO    : Bus 27620	: V=0.958765, theta=-62.977867 -> V=1.0, theta=0.0
% INFO    : Bus 27621	: V=0.9667086, theta=-61.821849 -> V=1.0, theta=0.0
% INFO    : Bus 27622	: V=0.961434, theta=-62.775655 -> V=1.0, theta=0.0
% INFO    : Bus 27623	: V=0.9661451, theta=-61.91866 -> V=1.0, theta=0.0
% INFO    : Bus 27624	: V=0.9652856, theta=-62.569719 -> V=1.0, theta=0.0
% INFO    : Bus 27625	: V=0.9719941, theta=-62.151657 -> V=1.0, theta=0.0
% INFO    : Bus 27626	: V=0.9823924, theta=-61.522344 -> V=1.0, theta=0.0
% INFO    : Bus 27627	: V=0.973008, theta=-62.308056 -> V=1.0, theta=0.0
% INFO    : Bus 27628	: V=0.9738669, theta=-62.152469 -> V=1.0, theta=0.0
% INFO    : Bus 27629	: V=0.9802722, theta=-61.525674 -> V=1.0, theta=0.0
% INFO    : Bus 27630	: V=0.9825986, theta=-61.398289 -> V=1.0, theta=0.0
% INFO    : Bus 27631	: V=0.9776983, theta=-62.241254 -> V=1.0, theta=0.0
% INFO    : Bus 27632	: V=0.9664142, theta=-62.470057 -> V=1.0, theta=0.0
% INFO    : Bus 27633	: V=0.9722056, theta=-62.982573 -> V=1.0, theta=0.0
% INFO    : Bus 27634	: V=0.9638005, theta=-61.576246 -> V=1.0, theta=0.0
% INFO    : Bus 27635	: V=0.970494, theta=-62.315753 -> V=1.0, theta=0.0
% INFO    : Bus 27636	: V=0.9709609, theta=-62.039811 -> V=1.0, theta=0.0
% INFO    : Bus 27637	: V=0.9604882, theta=-61.878578 -> V=1.0, theta=0.0
% INFO    : Bus 27638	: V=0.9626526, theta=-60.102503 -> V=1.0, theta=0.0
% INFO    : Bus 27639	: V=0.9616955, theta=-60.154255 -> V=1.0, theta=0.0
% INFO    : Bus 27640	: V=0.9592498, theta=-61.014741 -> V=1.0, theta=0.0
% INFO    : Bus 27641	: V=0.9703896, theta=-61.543245 -> V=1.0, theta=0.0
% INFO    : Bus 27642	: V=0.9659669, theta=-61.957929 -> V=1.0, theta=0.0
% INFO    : Bus 27643	: V=0.9721233, theta=-50.376744 -> V=1.0, theta=0.0
% INFO    : Bus 27644	: V=0.9809976, theta=-48.755137 -> V=1.0, theta=0.0
% INFO    : Bus 27645	: V=0.9787749, theta=-49.676235 -> V=1.0, theta=0.0
% INFO    : Bus 27646	: V=0.9746537, theta=-51.669483 -> V=1.0, theta=0.0
% INFO    : Bus 27647	: V=0.9757069, theta=-49.306391 -> V=1.0, theta=0.0
% INFO    : Bus 27648	: V=0.9845007, theta=-47.52712 -> V=1.0, theta=0.0
% INFO    : Bus 27649	: V=0.9769101, theta=-49.249826 -> V=1.0, theta=0.0
% INFO    : Bus 27650	: V=0.9759962, theta=-48.785303 -> V=1.0, theta=0.0
% INFO    : Bus 27651	: V=0.9765824, theta=-48.696633 -> V=1.0, theta=0.0
% INFO    : Bus 27652	: V=0.9775827, theta=-48.397922 -> V=1.0, theta=0.0
% INFO    : Bus 27653	: V=0.9761103, theta=-48.863127 -> V=1.0, theta=0.0
% INFO    : Bus 27654	: V=0.9784779, theta=-47.721389 -> V=1.0, theta=0.0
% INFO    : Bus 27655	: V=0.9806289, theta=-48.092697 -> V=1.0, theta=0.0
% INFO    : Bus 27656	: V=0.9827644, theta=-47.780395 -> V=1.0, theta=0.0
% INFO    : Bus 27657	: V=0.9760752, theta=-47.647998 -> V=1.0, theta=0.0
% INFO    : Bus 27658	: V=0.9777568, theta=-47.239635 -> V=1.0, theta=0.0
% INFO    : Bus 27659	: V=0.9817534, theta=-45.436113 -> V=1.0, theta=0.0
% INFO    : Bus 27660	: V=0.9783078, theta=-45.589957 -> V=1.0, theta=0.0
% INFO    : Bus 27661	: V=0.9857888, theta=-44.546772 -> V=1.0, theta=0.0
% INFO    : Bus 27662	: V=0.9802121, theta=-46.795135 -> V=1.0, theta=0.0
% INFO    : Bus 27663	: V=0.9832283, theta=-45.603442 -> V=1.0, theta=0.0
% INFO    : Bus 27664	: V=0.9401794, theta=-42.08019 -> V=1.0, theta=0.0
% INFO    : Bus 27665	: V=0.9392067, theta=-42.250435 -> V=1.0, theta=0.0
% INFO    : Bus 27666	: V=0.9440679, theta=-40.590374 -> V=1.0, theta=0.0
% INFO    : Bus 27667	: V=0.9509847, theta=-41.966287 -> V=1.0, theta=0.0
% INFO    : Bus 27668	: V=0.9453885, theta=-42.095533 -> V=1.0, theta=0.0
% INFO    : Bus 27669	: V=0.9483101, theta=-40.941169 -> V=1.0, theta=0.0
% INFO    : Bus 27670	: V=0.9500448, theta=-40.926899 -> V=1.0, theta=0.0
% INFO    : Bus 27671	: V=0.9570642, theta=-42.751932 -> V=1.0, theta=0.0
% INFO    : Bus 27672	: V=0.9696962, theta=-40.360408 -> V=1.0, theta=0.0
% INFO    : Bus 27673	: V=0.9683142, theta=-39.316879 -> V=1.0, theta=0.0
% INFO    : Bus 27674	: V=0.9731423, theta=-28.326679 -> V=1.0, theta=0.0
% INFO    : Bus 27675	: V=0.9768242, theta=-26.146269 -> V=1.0, theta=0.0
% INFO    : Bus 27676	: V=0.974287, theta=-26.019768 -> V=1.0, theta=0.0
% INFO    : Bus 27677	: V=0.9584975, theta=-30.326262 -> V=1.0, theta=0.0
% INFO    : Bus 27678	: V=0.9730938, theta=-28.968196 -> V=1.0, theta=0.0
% INFO    : Bus 27679	: V=0.9627623, theta=-29.641193 -> V=1.0, theta=0.0
% INFO    : Bus 27680	: V=0.9743366, theta=-27.657705 -> V=1.0, theta=0.0
% INFO    : Bus 27681	: V=0.972269, theta=-27.852874 -> V=1.0, theta=0.0
% INFO    : Bus 27682	: V=0.9621812, theta=-29.787586 -> V=1.0, theta=0.0
% INFO    : Bus 27683	: V=0.9995874, theta=-34.219409 -> V=1.0, theta=0.0
% INFO    : Bus 27684	: V=1.0046086, theta=-33.70332 -> V=1.0, theta=0.0
% INFO    : Bus 27685	: V=1.0151497, theta=-30.912673 -> V=1.0, theta=0.0
% INFO    : Bus 27686	: V=0.9924528, theta=-28.475739 -> V=1.0, theta=0.0
% INFO    : Bus 27687	: V=0.9924951, theta=-28.471856 -> V=1.0, theta=0.0
% INFO    : Bus 27688	: V=0.9891167, theta=-28.903099 -> V=1.0, theta=0.0
% INFO    : Bus 27689	: V=0.9919224, theta=-28.759448 -> V=1.0, theta=0.0
% INFO    : Bus 27690	: V=0.9759233, theta=-30.214131 -> V=1.0, theta=0.0
% INFO    : Bus 27691	: V=0.9751728, theta=-30.132211 -> V=1.0, theta=0.0
% INFO    : Bus 27692	: V=0.9917091, theta=-28.756351 -> V=1.0, theta=0.0
% INFO    : Bus 27693	: V=0.9860201, theta=-28.761116 -> V=1.0, theta=0.0
% INFO    : Bus 27694	: V=0.9887735, theta=-28.781729 -> V=1.0, theta=0.0
% INFO    : Bus 27695	: V=0.9845067, theta=-29.594579 -> V=1.0, theta=0.0
% INFO    : Bus 27696	: V=0.9686703, theta=-30.017388 -> V=1.0, theta=0.0
% INFO    : Bus 27697	: V=0.9852078, theta=-28.895511 -> V=1.0, theta=0.0
% INFO    : Bus 27698	: V=0.9853689, theta=-28.907254 -> V=1.0, theta=0.0
% INFO    : Bus 27699	: V=0.9871572, theta=-28.563598 -> V=1.0, theta=0.0
% INFO    : Bus 27700	: V=0.9908947, theta=-28.291629 -> V=1.0, theta=0.0
% INFO    : Bus 27701	: V=0.986672, theta=-28.749266 -> V=1.0, theta=0.0
% INFO    : Bus 27702	: V=0.9814797, theta=-28.685607 -> V=1.0, theta=0.0
% INFO    : Bus 27703	: V=0.9804554, theta=-28.636583 -> V=1.0, theta=0.0
% INFO    : Bus 27704	: V=0.9751209, theta=-28.507666 -> V=1.0, theta=0.0
% INFO    : Bus 27705	: V=0.9770768, theta=-28.405846 -> V=1.0, theta=0.0
% INFO    : Bus 27706	: V=0.9761256, theta=-28.403633 -> V=1.0, theta=0.0
% INFO    : Bus 27707	: V=0.9749868, theta=-28.48234 -> V=1.0, theta=0.0
% INFO    : Bus 27708	: V=0.9657625, theta=-28.927852 -> V=1.0, theta=0.0
% INFO    : Bus 27709	: V=0.9759413, theta=-28.374271 -> V=1.0, theta=0.0
% INFO    : Bus 27710	: V=0.9768446, theta=-28.238435 -> V=1.0, theta=0.0
% INFO    : Bus 27711	: V=0.9651415, theta=-29.061727 -> V=1.0, theta=0.0
% INFO    : Bus 27712	: V=0.99365, theta=-27.739841 -> V=1.0, theta=0.0
% INFO    : Bus 27713	: V=0.9850073, theta=-28.387768 -> V=1.0, theta=0.0
% INFO    : Bus 27714	: V=0.9866748, theta=-28.036093 -> V=1.0, theta=0.0
% INFO    : Bus 27715	: V=0.9728303, theta=-29.221785 -> V=1.0, theta=0.0
% INFO    : Bus 27716	: V=0.9797523, theta=-29.17304 -> V=1.0, theta=0.0
% INFO    : Bus 27717	: V=0.988342, theta=-29.013405 -> V=1.0, theta=0.0
% INFO    : Bus 27718	: V=0.9891483, theta=-28.856522 -> V=1.0, theta=0.0
% INFO    : Bus 27719	: V=0.9978614, theta=-40.981163 -> V=1.0, theta=0.0
% INFO    : Bus 27720	: V=0.9974608, theta=-41.279589 -> V=1.0, theta=0.0
% INFO    : Bus 27721	: V=1.017496, theta=-34.640813 -> V=1.0, theta=0.0
% INFO    : Bus 27722	: V=1.0069244, theta=-39.270952 -> V=1.0, theta=0.0
% INFO    : Bus 27723	: V=1.0022315, theta=-41.145049 -> V=1.0, theta=0.0
% INFO    : Bus 27724	: V=1.0054652, theta=-41.069361 -> V=1.0, theta=0.0
% INFO    : Bus 27725	: V=1.0054599, theta=-41.155166 -> V=1.0, theta=0.0
% INFO    : Bus 27726	: V=1.0059542, theta=-41.206144 -> V=1.0, theta=0.0
% INFO    : Bus 27727	: V=1.0103058, theta=-40.339252 -> V=1.0, theta=0.0
% INFO    : Bus 27728	: V=1.0080264, theta=-41.489721 -> V=1.0, theta=0.0
% INFO    : Bus 27729	: V=1.0053835, theta=-40.961401 -> V=1.0, theta=0.0
% INFO    : Bus 27730	: V=1.0124144, theta=-37.85835 -> V=1.0, theta=0.0
% INFO    : Bus 27731	: V=1.0104453, theta=-39.485124 -> V=1.0, theta=0.0
% INFO    : Bus 27732	: V=1.0058556, theta=-39.339798 -> V=1.0, theta=0.0
% INFO    : Bus 27733	: V=1.012564, theta=-35.205895 -> V=1.0, theta=0.0
% INFO    : Bus 27734	: V=1.0110823, theta=-34.497214 -> V=1.0, theta=0.0
% INFO    : Bus 27735	: V=0.9786223, theta=-49.524334 -> V=1.0, theta=0.0
% INFO    : Bus 27736	: V=0.9727395, theta=-51.762901 -> V=1.0, theta=0.0
% INFO    : Bus 27737	: V=0.9726761, theta=-51.810781 -> V=1.0, theta=0.0
% INFO    : Bus 27738	: V=0.9744901, theta=-51.085061 -> V=1.0, theta=0.0
% INFO    : Bus 27739	: V=0.9799351, theta=-49.033446 -> V=1.0, theta=0.0
% INFO    : Bus 27740	: V=0.9790678, theta=-49.247556 -> V=1.0, theta=0.0
% INFO    : Bus 27741	: V=0.97231, theta=-52.092786 -> V=1.0, theta=0.0
% INFO    : Bus 27742	: V=0.9703975, theta=-52.596092 -> V=1.0, theta=0.0
% INFO    : Bus 27743	: V=0.9735283, theta=-53.025662 -> V=1.0, theta=0.0
% INFO    : Bus 27744	: V=0.9740031, theta=-52.748183 -> V=1.0, theta=0.0
% INFO    : Bus 27745	: V=0.9748289, theta=-52.712283 -> V=1.0, theta=0.0
% INFO    : Bus 27746	: V=0.974538, theta=-52.503716 -> V=1.0, theta=0.0
% INFO    : Bus 27747	: V=0.9741992, theta=-51.968202 -> V=1.0, theta=0.0
% INFO    : Bus 27748	: V=0.9746542, theta=-51.178472 -> V=1.0, theta=0.0
% INFO    : Bus 27749	: V=0.9762789, theta=-50.381355 -> V=1.0, theta=0.0
% INFO    : Bus 27750	: V=0.9760329, theta=-49.369321 -> V=1.0, theta=0.0
% INFO    : Bus 27751	: V=0.9735615, theta=-49.991544 -> V=1.0, theta=0.0
% INFO    : Bus 27752	: V=0.9715169, theta=-50.667248 -> V=1.0, theta=0.0
% INFO    : Bus 27753	: V=0.9694755, theta=-51.280121 -> V=1.0, theta=0.0
% INFO    : Bus 27754	: V=0.9704986, theta=-51.916711 -> V=1.0, theta=0.0
% INFO    : Bus 27755	: V=0.9683861, theta=-52.8346 -> V=1.0, theta=0.0
% INFO    : Bus 27756	: V=0.9668494, theta=-53.192323 -> V=1.0, theta=0.0
% INFO    : Bus 27757	: V=0.9655631, theta=-55.181805 -> V=1.0, theta=0.0
% INFO    : Bus 27758	: V=0.9674268, theta=-54.084424 -> V=1.0, theta=0.0
% INFO    : Bus 27759	: V=0.9693809, theta=-53.780286 -> V=1.0, theta=0.0
% INFO    : Bus 27760	: V=0.9688065, theta=-54.295716 -> V=1.0, theta=0.0
% INFO    : Bus 27761	: V=0.9742242, theta=-52.333792 -> V=1.0, theta=0.0
% INFO    : Bus 27762	: V=0.9742972, theta=-51.938907 -> V=1.0, theta=0.0
% INFO    : Bus 27763	: V=0.9649021, theta=-53.484827 -> V=1.0, theta=0.0
% INFO    : Bus 27764	: V=0.9652726, theta=-53.462266 -> V=1.0, theta=0.0
% INFO    : Bus 27765	: V=0.9710343, theta=-52.622763 -> V=1.0, theta=0.0
% INFO    : Bus 27766	: V=0.9732688, theta=-51.698418 -> V=1.0, theta=0.0
% INFO    : Bus 27767	: V=0.9580801, theta=-28.653478 -> V=1.0, theta=0.0
% INFO    : Bus 27768	: V=0.9505671, theta=-28.629492 -> V=1.0, theta=0.0
% INFO    : Bus 27769	: V=0.9599275, theta=-28.527252 -> V=1.0, theta=0.0
% INFO    : Bus 27770	: V=0.9522317, theta=-29.814675 -> V=1.0, theta=0.0
% INFO    : Bus 27771	: V=0.9804671, theta=-28.368393 -> V=1.0, theta=0.0
% INFO    : Bus 27772	: V=1.0033654, theta=-25.904684 -> V=1.0, theta=0.0
% INFO    : Bus 27773	: V=0.977538, theta=-28.21891 -> V=1.0, theta=0.0
% INFO    : Bus 27774	: V=0.9731153, theta=-28.373368 -> V=1.0, theta=0.0
% INFO    : Bus 27775	: V=0.960248, theta=-28.800151 -> V=1.0, theta=0.0
% INFO    : Bus 27776	: V=0.9787338, theta=-31.894019 -> V=1.0, theta=0.0
% INFO    : Bus 27777	: V=0.9661083, theta=-33.076134 -> V=1.0, theta=0.0
% INFO    : Bus 27778	: V=0.9747278, theta=-32.132664 -> V=1.0, theta=0.0
% INFO    : Bus 27779	: V=0.9648536, theta=-33.074542 -> V=1.0, theta=0.0
% INFO    : Bus 27780	: V=0.976269, theta=-32.174507 -> V=1.0, theta=0.0
% INFO    : Bus 27781	: V=0.9647431, theta=-33.10226 -> V=1.0, theta=0.0
% INFO    : Bus 27782	: V=0.962572, theta=-33.17352 -> V=1.0, theta=0.0
% INFO    : Bus 27783	: V=0.9620046, theta=-33.169647 -> V=1.0, theta=0.0
% INFO    : Bus 27784	: V=0.9781271, theta=-32.149092 -> V=1.0, theta=0.0
% INFO    : Bus 27785	: V=0.99321, theta=-30.343585 -> V=1.0, theta=0.0
% INFO    : Bus 27786	: V=0.9967621, theta=-30.165212 -> V=1.0, theta=0.0
% INFO    : Bus 27787	: V=0.9920495, theta=-31.574163 -> V=1.0, theta=0.0
% INFO    : Bus 27788	: V=0.9776481, theta=-32.657621 -> V=1.0, theta=0.0
% INFO    : Bus 27789	: V=0.9630446, theta=-33.127517 -> V=1.0, theta=0.0
% INFO    : Bus 27790	: V=0.9696436, theta=-32.300162 -> V=1.0, theta=0.0
% INFO    : Bus 27791	: V=0.9728295, theta=-31.995828 -> V=1.0, theta=0.0
% INFO    : Bus 27792	: V=0.9734881, theta=-32.330604 -> V=1.0, theta=0.0
% INFO    : Bus 27793	: V=0.9750297, theta=-32.489528 -> V=1.0, theta=0.0
% INFO    : Bus 27794	: V=0.9807735, theta=-32.384121 -> V=1.0, theta=0.0
% INFO    : Bus 27795	: V=0.9746256, theta=-32.517676 -> V=1.0, theta=0.0
% INFO    : Bus 27796	: V=0.9818071, theta=-32.34268 -> V=1.0, theta=0.0
% INFO    : Bus 27797	: V=0.9742963, theta=-32.487896 -> V=1.0, theta=0.0
% INFO    : Bus 27798	: V=0.9740833, theta=-32.567182 -> V=1.0, theta=0.0
% INFO    : Bus 27799	: V=0.9699726, theta=-33.488955 -> V=1.0, theta=0.0
% INFO    : Bus 27800	: V=0.9523003, theta=-38.443522 -> V=1.0, theta=0.0
% INFO    : Bus 27801	: V=0.9486312, theta=-35.222693 -> V=1.0, theta=0.0
% INFO    : Bus 27802	: V=0.9477606, theta=-35.712627 -> V=1.0, theta=0.0
% INFO    : Bus 27803	: V=0.9583811, theta=-34.142953 -> V=1.0, theta=0.0
% INFO    : Bus 27804	: V=0.9470813, theta=-40.619331 -> V=1.0, theta=0.0
% INFO    : Bus 27805	: V=0.957735, theta=-37.993656 -> V=1.0, theta=0.0
% INFO    : Bus 27806	: V=0.951217, theta=-38.868561 -> V=1.0, theta=0.0
% INFO    : Bus 27807	: V=0.948249, theta=-40.786143 -> V=1.0, theta=0.0
% INFO    : Bus 27808	: V=0.9471677, theta=-41.394843 -> V=1.0, theta=0.0
% INFO    : Bus 27809	: V=0.9466404, theta=-42.517442 -> V=1.0, theta=0.0
% INFO    : Bus 27810	: V=1.02, theta=-30.372237 -> V=1.0, theta=0.0
% INFO    : Bus 27811	: V=1.02, theta=-42.428822 -> V=1.0, theta=0.0
% INFO    : Bus 27812	: V=1.02, theta=-39.44351 -> V=1.0, theta=0.0
% INFO    : Bus 27813	: V=1.02, theta=-50.266262 -> V=1.0, theta=0.0
% INFO    : Bus 27814	: V=1.0189685, theta=-41.851118 -> V=1.0, theta=0.0
% INFO    : Bus 27815	: V=1.02, theta=-45.234186 -> V=1.0, theta=0.0
% INFO    : Bus 27816	: V=1.02, theta=-42.287661 -> V=1.0, theta=0.0
% INFO    : Bus 27817	: V=1.02, theta=-40.199086 -> V=1.0, theta=0.0
% INFO    : Bus 27818	: V=1.0110233, theta=-27.464409 -> V=1.0, theta=0.0
% INFO    : Bus 27819	: V=1.02, theta=-45.976331 -> V=1.0, theta=0.0
% INFO    : Bus 27820	: V=1.0068321, theta=-36.399099 -> V=1.0, theta=0.0
% INFO    : Bus 27821	: V=1.02, theta=-30.969202 -> V=1.0, theta=0.0
% INFO    : Bus 27822	: V=1.02, theta=-39.502624 -> V=1.0, theta=0.0
% INFO    : Bus 27823	: V=1.0004185, theta=-42.566312 -> V=1.0, theta=0.0
% INFO    : Bus 27824	: V=1.02, theta=-49.027501 -> V=1.0, theta=0.0
% INFO    : Bus 27825	: V=1.02, theta=-32.215918 -> V=1.0, theta=0.0
% INFO    : Bus 27826	: V=1.02, theta=-49.626484 -> V=1.0, theta=0.0
% INFO    : Bus 27827	: V=1.02, theta=-42.261375 -> V=1.0, theta=0.0
% INFO    : Bus 27828	: V=1.02, theta=-53.646849 -> V=1.0, theta=0.0
% INFO    : Bus 27829	: V=1.02, theta=-43.889614 -> V=1.0, theta=0.0
% INFO    : Bus 27830	: V=1.02, theta=-43.205084 -> V=1.0, theta=0.0
% INFO    : Bus 27831	: V=1.02, theta=-46.423456 -> V=1.0, theta=0.0
% INFO    : Bus 27832	: V=1.02, theta=-39.892932 -> V=1.0, theta=0.0
% INFO    : Bus 27833	: V=1.02, theta=-43.444968 -> V=1.0, theta=0.0
% INFO    : Bus 27834	: V=1.02, theta=-42.951482 -> V=1.0, theta=0.0
% INFO    : Bus 27835	: V=1.02, theta=-45.203737 -> V=1.0, theta=0.0
% INFO    : Bus 27836	: V=1.02, theta=-45.827848 -> V=1.0, theta=0.0
% INFO    : Bus 27837	: V=1.02, theta=-46.979455 -> V=1.0, theta=0.0
% INFO    : Bus 27838	: V=1.02, theta=-41.781853 -> V=1.0, theta=0.0
% INFO    : Bus 27839	: V=1.02, theta=-44.501043 -> V=1.0, theta=0.0
% INFO    : Bus 27840	: V=1.01, theta=-27.135812 -> V=1.0, theta=0.0
% INFO    : Bus 27841	: V=1.02, theta=-36.970528 -> V=1.0, theta=0.0
% INFO    : Bus 27842	: V=1.02, theta=-38.861217 -> V=1.0, theta=0.0
% INFO    : Bus 27843	: V=1.0058126, theta=-41.773161 -> V=1.0, theta=0.0
% INFO    : Bus 27844	: V=1.02, theta=-41.707926 -> V=1.0, theta=0.0
% INFO    : Bus 27845	: V=1.02, theta=-43.043173 -> V=1.0, theta=0.0
% INFO    : Bus 27846	: V=0.9960988, theta=-44.996143 -> V=1.0, theta=0.0
% INFO    : Bus 27847	: V=1.0135096, theta=-50.056059 -> V=1.0, theta=0.0
% INFO    : Bus 27848	: V=1.02, theta=-42.726217 -> V=1.0, theta=0.0
% INFO    : Bus 27849	: V=1.02, theta=-46.134097 -> V=1.0, theta=0.0
% INFO    : Bus 27850	: V=1.0198794, theta=-45.217665 -> V=1.0, theta=0.0
% INFO    : Bus 27851	: V=1.0007797, theta=-50.236308 -> V=1.0, theta=0.0
% INFO    : Bus 27852	: V=1.02, theta=-47.719329 -> V=1.0, theta=0.0
% INFO    : Bus 27853	: V=0.9727607, theta=-47.448285 -> V=1.0, theta=0.0
% INFO    : Bus 27854	: V=1.0198547, theta=-45.22447 -> V=1.0, theta=0.0
% INFO    : Bus 27855	: V=1.02, theta=-41.787965 -> V=1.0, theta=0.0
% INFO    : Bus 27856	: V=1.02, theta=-43.211042 -> V=1.0, theta=0.0
% INFO    : Bus 27857	: V=1.02, theta=-52.860727 -> V=1.0, theta=0.0
% INFO    : Bus 27858	: V=1.0016444, theta=-54.204799 -> V=1.0, theta=0.0
% INFO    : Bus 27859	: V=1.0199587, theta=-43.220705 -> V=1.0, theta=0.0
% INFO    : Bus 27860	: V=1.0167787, theta=-43.822325 -> V=1.0, theta=0.0
% INFO    : Bus 27861	: V=1.0096232, theta=-45.554137 -> V=1.0, theta=0.0
% INFO    : Bus 27862	: V=1.0191378, theta=-43.272452 -> V=1.0, theta=0.0
% INFO    : Bus 27863	: V=1.02, theta=-39.873604 -> V=1.0, theta=0.0
% INFO    : Bus 27864	: V=1.0050977, theta=-43.676633 -> V=1.0, theta=0.0
% INFO    : Bus 27865	: V=1.0033115, theta=-34.899524 -> V=1.0, theta=0.0
% INFO    : Bus 27866	: V=0.9885584, theta=-47.18679 -> V=1.0, theta=0.0
% INFO    : Bus 27867	: V=0.9892987, theta=-40.179034 -> V=1.0, theta=0.0
% INFO    : Bus 27868	: V=0.9919098, theta=-42.318724 -> V=1.0, theta=0.0
% INFO    : Bus 27869	: V=0.988673, theta=-37.141914 -> V=1.0, theta=0.0
% INFO    : Bus 27870	: V=1.02, theta=-51.472108 -> V=1.0, theta=0.0
% INFO    : Bus 27871	: V=0.9888481, theta=-42.861045 -> V=1.0, theta=0.0
% INFO    : Bus 27872	: V=1.0043389, theta=-33.473996 -> V=1.0, theta=0.0
% INFO    : Bus 27873	: V=0.9869156, theta=-50.647284 -> V=1.0, theta=0.0
% INFO    : Bus 27874	: V=1.000155, theta=-52.386399 -> V=1.0, theta=0.0
% INFO    : Bus 27875	: V=0.9891771, theta=-46.085552 -> V=1.0, theta=0.0
% INFO    : Bus 27876	: V=1.007227, theta=-46.057496 -> V=1.0, theta=0.0
% INFO    : Bus 27877	: V=1.02, theta=-37.316989 -> V=1.0, theta=0.0
% INFO    : Bus 27878	: V=0.9826624, theta=-48.567496 -> V=1.0, theta=0.0
% INFO    : Bus 27879	: V=1.0026874, theta=-50.568119 -> V=1.0, theta=0.0
% INFO    : Bus 27880	: V=1.0045097, theta=-48.19676 -> V=1.0, theta=0.0
% INFO    : Bus 27881	: V=0.9753695, theta=-49.337711 -> V=1.0, theta=0.0
% INFO    : Bus 27882	: V=0.9711844, theta=-51.112345 -> V=1.0, theta=0.0
% INFO    : Bus 27883	: V=1.0037568, theta=-47.021157 -> V=1.0, theta=0.0
% INFO    : Bus 27884	: V=1.010436, theta=-49.727299 -> V=1.0, theta=0.0
% INFO    : Bus 27885	: V=1.002456, theta=-42.881906 -> V=1.0, theta=0.0
% INFO    : Bus 27886	: V=0.999217, theta=-50.511222 -> V=1.0, theta=0.0
% INFO    : Bus 27887	: V=0.9936882, theta=-50.004067 -> V=1.0, theta=0.0
% INFO    : Bus 27888	: V=1.02, theta=-40.779647 -> V=1.0, theta=0.0
% INFO    : Bus 27889	: V=0.9782259, theta=-50.009563 -> V=1.0, theta=0.0
% INFO    : Bus 27890	: V=1.0027754, theta=-55.013122 -> V=1.0, theta=0.0
% INFO    : Bus 27891	: V=0.9844382, theta=-43.960785 -> V=1.0, theta=0.0
% INFO    : Bus 27892	: V=0.9706546, theta=-49.17745 -> V=1.0, theta=0.0
% INFO    : Bus 27893	: V=1.0197908, theta=-46.568636 -> V=1.0, theta=0.0
% INFO    : Bus 27894	: V=1.0191794, theta=-45.459549 -> V=1.0, theta=0.0
% INFO    : Bus 27895	: V=1.02, theta=-38.882862 -> V=1.0, theta=0.0
% INFO    : Bus 27896	: V=0.9840609, theta=-46.60577 -> V=1.0, theta=0.0
% INFO    : Bus 27897	: V=0.9968144, theta=-53.118305 -> V=1.0, theta=0.0
% INFO    : Bus 27898	: V=1.0030807, theta=-46.687306 -> V=1.0, theta=0.0
% INFO    : Bus 27899	: V=1.0180337, theta=-43.542533 -> V=1.0, theta=0.0
% INFO    : Bus 27900	: V=0.9948689, theta=-37.694194 -> V=1.0, theta=0.0
% INFO    : Bus 27901	: V=0.9984009, theta=-50.932019 -> V=1.0, theta=0.0
% INFO    : Bus 27902	: V=1.02, theta=-47.846142 -> V=1.0, theta=0.0
% INFO    : Bus 27903	: V=0.999121, theta=-42.604552 -> V=1.0, theta=0.0
% INFO    : Bus 27904	: V=0.98507, theta=-49.350261 -> V=1.0, theta=0.0
% INFO    : Bus 27905	: V=1.0134015, theta=-52.26023 -> V=1.0, theta=0.0
% INFO    : Bus 27906	: V=0.9924919, theta=-52.378479 -> V=1.0, theta=0.0
% INFO    : Bus 27907	: V=1.0172736, theta=-44.333364 -> V=1.0, theta=0.0
% INFO    : Bus 27908	: V=0.9875167, theta=-45.920784 -> V=1.0, theta=0.0
% INFO    : Bus 27909	: V=1.0025221, theta=-47.26812 -> V=1.0, theta=0.0
% INFO    : Bus 27910	: V=0.98329, theta=-50.196845 -> V=1.0, theta=0.0
% INFO    : Bus 27911	: V=0.9986309, theta=-44.738367 -> V=1.0, theta=0.0
% INFO    : Bus 27912	: V=1.0010632, theta=-52.695733 -> V=1.0, theta=0.0
% INFO    : Bus 27913	: V=0.9838915, theta=-50.176994 -> V=1.0, theta=0.0
% INFO    : Bus 27914	: V=0.9850086, theta=-50.437246 -> V=1.0, theta=0.0
% INFO    : Bus 27915	: V=1.02, theta=-21.120479 -> V=1.0, theta=0.0
% INFO    : Bus 27916	: V=1.02, theta=-24.296782 -> V=1.0, theta=0.0
% INFO    : Bus 27917	: V=1.02, theta=-25.834377 -> V=1.0, theta=0.0
% INFO    : Bus 27918	: V=1.02, theta=-22.790031 -> V=1.0, theta=0.0
% INFO    : Bus 27919	: V=1.0140722, theta=-26.601456 -> V=1.0, theta=0.0
% INFO    : Bus 27920	: V=1.02, theta=-38.955808 -> V=1.0, theta=0.0
% INFO    : Bus 27921	: V=1.02, theta=-22.715732 -> V=1.0, theta=0.0
% INFO    : Bus 27922	: V=1.02, theta=-23.845052 -> V=1.0, theta=0.0
% INFO    : Bus 27923	: V=0.9796297, theta=-36.209958 -> V=1.0, theta=0.0
% INFO    : Bus 27924	: V=1.02, theta=-21.987514 -> V=1.0, theta=0.0
% INFO    : Bus 27925	: V=1.02, theta=-22.873823 -> V=1.0, theta=0.0
% INFO    : Bus 27926	: V=1.0203141, theta=-24.234577 -> V=1.0, theta=0.0
% INFO    : Bus 27927	: V=1.02, theta=-24.996342 -> V=1.0, theta=0.0
% INFO    : Bus 27928	: V=1.02, theta=-21.876775 -> V=1.0, theta=0.0
% INFO    : Bus 27929	: V=1.02, theta=-34.004677 -> V=1.0, theta=0.0
% INFO    : Bus 27930	: V=1.02, theta=-24.173999 -> V=1.0, theta=0.0
% INFO    : Bus 27931	: V=1.02, theta=-32.569659 -> V=1.0, theta=0.0
% INFO    : Bus 27932	: V=1.02, theta=-22.952063 -> V=1.0, theta=0.0
% INFO    : Bus 27933	: V=1.0203471, theta=-24.233007 -> V=1.0, theta=0.0
% INFO    : Bus 27934	: V=1.02, theta=-33.570099 -> V=1.0, theta=0.0
% INFO    : Bus 27935	: V=1.02, theta=-25.549934 -> V=1.0, theta=0.0
% INFO    : Bus 27936	: V=1.02, theta=-26.104607 -> V=1.0, theta=0.0
% INFO    : Bus 27937	: V=1.02, theta=-34.019223 -> V=1.0, theta=0.0
% INFO    : Bus 27938	: V=1.02, theta=-47.61056 -> V=1.0, theta=0.0
% INFO    : Bus 27939	: V=1.02, theta=-23.596889 -> V=1.0, theta=0.0
% INFO    : Bus 27940	: V=1.02, theta=-23.270942 -> V=1.0, theta=0.0
% INFO    : Bus 27941	: V=1.0149072, theta=-26.081987 -> V=1.0, theta=0.0
% INFO    : Bus 27942	: V=1.02, theta=-28.744634 -> V=1.0, theta=0.0
% INFO    : Bus 27943	: V=1.02, theta=-23.644017 -> V=1.0, theta=0.0
% INFO    : Bus 27944	: V=1.02, theta=-27.285382 -> V=1.0, theta=0.0
% INFO    : Bus 27945	: V=1.02, theta=-27.537062 -> V=1.0, theta=0.0
% INFO    : Bus 27946	: V=1.02, theta=-33.704492 -> V=1.0, theta=0.0
% INFO    : Bus 27947	: V=1.0160357, theta=-33.182983 -> V=1.0, theta=0.0
% INFO    : Bus 27948	: V=1.02, theta=-31.508132 -> V=1.0, theta=0.0
% INFO    : Bus 27949	: V=1.02, theta=-22.025117 -> V=1.0, theta=0.0
% INFO    : Bus 27950	: V=1.02, theta=-32.542764 -> V=1.0, theta=0.0
% INFO    : Bus 27951	: V=1.02, theta=-34.883081 -> V=1.0, theta=0.0
% INFO    : Bus 27952	: V=1.02, theta=-26.179927 -> V=1.0, theta=0.0
% INFO    : Bus 27953	: V=1.0151868, theta=-38.993148 -> V=1.0, theta=0.0
% INFO    : Bus 27954	: V=0.9797443, theta=-38.372537 -> V=1.0, theta=0.0
% INFO    : Bus 27955	: V=1.017182, theta=-29.565912 -> V=1.0, theta=0.0
% INFO    : Bus 27956	: V=1.02, theta=-37.025957 -> V=1.0, theta=0.0
% INFO    : Bus 27957	: V=0.9741322, theta=-38.473515 -> V=1.0, theta=0.0
% INFO    : Bus 27958	: V=1.00826, theta=-36.241378 -> V=1.0, theta=0.0
% INFO    : Bus 27959	: V=1.02, theta=-24.789506 -> V=1.0, theta=0.0
% INFO    : Bus 27960	: V=1.02, theta=-28.854288 -> V=1.0, theta=0.0
% INFO    : Bus 27961	: V=1.0059189, theta=-48.473862 -> V=1.0, theta=0.0
% INFO    : Bus 27962	: V=1.02, theta=-48.51467 -> V=1.0, theta=0.0
% INFO    : Bus 27963	: V=0.9942871, theta=-30.64442 -> V=1.0, theta=0.0
% INFO    : Bus 27964	: V=0.9996476, theta=-41.478253 -> V=1.0, theta=0.0
% INFO    : Bus 27965	: V=0.9836385, theta=-38.815472 -> V=1.0, theta=0.0
% INFO    : Bus 27966	: V=0.9626279, theta=-35.120315 -> V=1.0, theta=0.0
% INFO    : Bus 27967	: V=1.008267, theta=-27.783808 -> V=1.0, theta=0.0
% INFO    : Bus 27968	: V=0.9923444, theta=-31.194768 -> V=1.0, theta=0.0
% INFO    : Bus 27969	: V=0.9989995, theta=-31.237817 -> V=1.0, theta=0.0
% INFO    : Bus 27970	: V=0.9874406, theta=-32.324158 -> V=1.0, theta=0.0
% INFO    : Bus 27971	: V=0.9869312, theta=-43.553985 -> V=1.0, theta=0.0
% INFO    : Bus 27972	: V=0.9884961, theta=-37.210671 -> V=1.0, theta=0.0
% INFO    : Bus 27973	: V=0.991243, theta=-27.314793 -> V=1.0, theta=0.0
% INFO    : Bus 27974	: V=1.02, theta=-25.695792 -> V=1.0, theta=0.0
% INFO    : Bus 27975	: V=0.9771043, theta=-38.843809 -> V=1.0, theta=0.0
% INFO    : Bus 27976	: V=1.02, theta=-25.607806 -> V=1.0, theta=0.0
% INFO    : Bus 27977	: V=0.9925943, theta=-37.676468 -> V=1.0, theta=0.0
% INFO    : Bus 27978	: V=1.0187747, theta=-23.654731 -> V=1.0, theta=0.0
% INFO    : Bus 27979	: V=1.0063272, theta=-39.680808 -> V=1.0, theta=0.0
% INFO    : Bus 27980	: V=1.02, theta=-33.492013 -> V=1.0, theta=0.0
% INFO    : Bus 27981	: V=1.02, theta=-26.735191 -> V=1.0, theta=0.0
% INFO    : Bus 27982	: V=1.02, theta=-32.718401 -> V=1.0, theta=0.0
% INFO    : Bus 27983	: V=1.0084103, theta=-25.867307 -> V=1.0, theta=0.0
% INFO    : Bus 27984	: V=1.02, theta=-22.006836 -> V=1.0, theta=0.0
% INFO    : Bus 27985	: V=1.02, theta=-24.0374 -> V=1.0, theta=0.0
% INFO    : Bus 27986	: V=1.02, theta=-26.842035 -> V=1.0, theta=0.0
% INFO    : Bus 27987	: V=1.02, theta=-23.284133 -> V=1.0, theta=0.0
% INFO    : Bus 27988	: V=1.02, theta=-24.670472 -> V=1.0, theta=0.0
% INFO    : Bus 27989	: V=1.02, theta=-23.003768 -> V=1.0, theta=0.0
% INFO    : Bus 27990	: V=1.02, theta=-38.261864 -> V=1.0, theta=0.0
% INFO    : Bus 27991	: V=1.02, theta=-36.70766 -> V=1.0, theta=0.0
% INFO    : Bus 27992	: V=1.0153838, theta=-29.312248 -> V=1.0, theta=0.0
% INFO    : Bus 27993	: V=1.02, theta=-35.759316 -> V=1.0, theta=0.0
% INFO    : Bus 27994	: V=1.02, theta=-33.014309 -> V=1.0, theta=0.0
% INFO    : Bus 27995	: V=1.0070047, theta=-31.760542 -> V=1.0, theta=0.0
% INFO    : Bus 27996	: V=1.02, theta=-25.947617 -> V=1.0, theta=0.0
% INFO    : Bus 27997	: V=0.9940195, theta=-32.751085 -> V=1.0, theta=0.0
% INFO    : Bus 27998	: V=1.02, theta=-26.982802 -> V=1.0, theta=0.0
% INFO    : Bus 27999	: V=1.0034701, theta=-30.211875 -> V=1.0, theta=0.0
% INFO    : Bus 28000	: V=1.02, theta=-35.455557 -> V=1.0, theta=0.0
% INFO    : Bus 28001	: V=0.9725372, theta=-29.407162 -> V=1.0, theta=0.0
% INFO    : Bus 28002	: V=0.9916448, theta=-38.426411 -> V=1.0, theta=0.0
% INFO    : Bus 28003	: V=1.0157593, theta=-32.313858 -> V=1.0, theta=0.0
% INFO    : Bus 28004	: V=1.0098262, theta=-35.011393 -> V=1.0, theta=0.0
% INFO    : Bus 28005	: V=1.0130762, theta=-28.661882 -> V=1.0, theta=0.0
% INFO    : Bus 28006	: V=1.02, theta=-24.824128 -> V=1.0, theta=0.0
% INFO    : Bus 28007	: V=1.02, theta=-26.689612 -> V=1.0, theta=0.0
% INFO    : Bus 28008	: V=0.994945, theta=-36.282898 -> V=1.0, theta=0.0
% INFO    : Bus 28009	: V=0.9989418, theta=-39.772915 -> V=1.0, theta=0.0
% INFO    : Bus 28010	: V=0.9966058, theta=-31.480561 -> V=1.0, theta=0.0
% INFO    : Bus 28011	: V=1.011332, theta=-27.668097 -> V=1.0, theta=0.0
% INFO    : Bus 28012	: V=0.9918846, theta=-32.431181 -> V=1.0, theta=0.0
% INFO    : Bus 28013	: V=1.009983, theta=-31.169611 -> V=1.0, theta=0.0
% INFO    : Bus 28014	: V=1.0140431, theta=-31.643489 -> V=1.0, theta=0.0
% INFO    : Bus 28015	: V=1.0096903, theta=-32.620705 -> V=1.0, theta=0.0
% INFO    : Bus 28016	: V=1.0092367, theta=-32.317595 -> V=1.0, theta=0.0
% INFO    : Bus 28017	: V=0.9712482, theta=-33.616553 -> V=1.0, theta=0.0
% INFO    : Bus 28018	: V=0.9729949, theta=-30.859068 -> V=1.0, theta=0.0
% INFO    : Bus 28019	: V=1.02, theta=-25.58718 -> V=1.0, theta=0.0
% INFO    : Bus 28020	: V=0.9780346, theta=-33.527982 -> V=1.0, theta=0.0
% INFO    : Bus 28021	: V=1.0146757, theta=-32.334164 -> V=1.0, theta=0.0
% INFO    : Bus 28022	: V=1.012545, theta=-24.530728 -> V=1.0, theta=0.0
% INFO    : Bus 28023	: V=1.0055161, theta=-27.249347 -> V=1.0, theta=0.0
% INFO    : Bus 28024	: V=0.9986889, theta=-28.27555 -> V=1.0, theta=0.0
% INFO    : Bus 28025	: V=1.0133911, theta=-32.447051 -> V=1.0, theta=0.0
% INFO    : Bus 28026	: V=0.9940283, theta=-49.999423 -> V=1.0, theta=0.0
% INFO    : Bus 28027	: V=1.0135279, theta=-45.887526 -> V=1.0, theta=0.0
% INFO    : Bus 28028	: V=1.0057742, theta=-48.948942 -> V=1.0, theta=0.0
% INFO    : Bus 28029	: V=1.0045742, theta=-48.965692 -> V=1.0, theta=0.0
% INFO    : Bus 28030	: V=0.990857, theta=-50.246713 -> V=1.0, theta=0.0
% INFO    : Bus 28031	: V=0.9873004, theta=-50.423028 -> V=1.0, theta=0.0
% INFO    : Bus 28032	: V=1.0029421, theta=-48.772472 -> V=1.0, theta=0.0
% INFO    : Bus 28033	: V=0.99367, theta=-49.992101 -> V=1.0, theta=0.0
% INFO    : Bus 28034	: V=0.9925863, theta=-50.021832 -> V=1.0, theta=0.0
% INFO    : Bus 28035	: V=0.990445, theta=-50.233705 -> V=1.0, theta=0.0
% INFO    : Bus 28036	: V=0.9926712, theta=-50.012321 -> V=1.0, theta=0.0
% INFO    : Bus 28037	: V=0.9936467, theta=-50.00584 -> V=1.0, theta=0.0
% INFO    : Bus 28038	: V=1.0030029, theta=-49.031564 -> V=1.0, theta=0.0
% INFO    : Bus 28039	: V=0.9934476, theta=-50.266259 -> V=1.0, theta=0.0
% INFO    : Bus 28040	: V=0.9980941, theta=-50.002301 -> V=1.0, theta=0.0
% INFO    : Bus 28041	: V=1.0082915, theta=-49.023979 -> V=1.0, theta=0.0
% INFO    : Bus 28042	: V=1.0075102, theta=-48.915246 -> V=1.0, theta=0.0
% INFO    : Bus 28043	: V=0.9851492, theta=-50.49754 -> V=1.0, theta=0.0
% INFO    : Bus 28044	: V=0.9853245, theta=-50.510764 -> V=1.0, theta=0.0
% INFO    : Bus 28045	: V=0.9860362, theta=-50.499918 -> V=1.0, theta=0.0
% INFO    : Bus 28046	: V=0.9847607, theta=-50.58783 -> V=1.0, theta=0.0
% INFO    : Bus 28047	: V=0.9838222, theta=-50.654236 -> V=1.0, theta=0.0
% INFO    : Bus 28048	: V=0.9836827, theta=-50.678382 -> V=1.0, theta=0.0
% INFO    : Bus 28049	: V=0.9855839, theta=-50.636906 -> V=1.0, theta=0.0
% INFO    : Bus 28050	: V=0.9846409, theta=-50.668438 -> V=1.0, theta=0.0
% INFO    : Bus 28051	: V=0.9900909, theta=-50.438696 -> V=1.0, theta=0.0
% INFO    : Bus 28052	: V=0.9874731, theta=-50.558031 -> V=1.0, theta=0.0
% INFO    : Bus 28053	: V=0.9907462, theta=-50.474076 -> V=1.0, theta=0.0
% INFO    : Bus 28054	: V=0.988228, theta=-50.579809 -> V=1.0, theta=0.0
% INFO    : Bus 28055	: V=1.0008685, theta=-50.253893 -> V=1.0, theta=0.0
% INFO    : Bus 28056	: V=1.0082389, theta=-49.87741 -> V=1.0, theta=0.0
% INFO    : Bus 28057	: V=1.0116256, theta=-49.125415 -> V=1.0, theta=0.0
% INFO    : Bus 28058	: V=1.0119528, theta=-49.570304 -> V=1.0, theta=0.0
% INFO    : Bus 28059	: V=1.003319, theta=-49.994653 -> V=1.0, theta=0.0
% INFO    : Bus 28060	: V=0.993292, theta=-50.416388 -> V=1.0, theta=0.0
% INFO    : Bus 28061	: V=0.9979018, theta=-50.183445 -> V=1.0, theta=0.0
% INFO    : Bus 28062	: V=1.0146908, theta=-49.240042 -> V=1.0, theta=0.0
% INFO    : Bus 28063	: V=0.9830589, theta=-50.741486 -> V=1.0, theta=0.0
% INFO    : Bus 28064	: V=0.9889219, theta=-49.058188 -> V=1.0, theta=0.0
% INFO    : Bus 28065	: V=1.0136758, theta=-45.454207 -> V=1.0, theta=0.0
% INFO    : Bus 28066	: V=0.9956666, theta=-48.532917 -> V=1.0, theta=0.0
% INFO    : Bus 28067	: V=0.9889733, theta=-49.69854 -> V=1.0, theta=0.0
% INFO    : Bus 28068	: V=0.9866684, theta=-49.731117 -> V=1.0, theta=0.0
% INFO    : Bus 28069	: V=0.9870275, theta=-50.854867 -> V=1.0, theta=0.0
% INFO    : Bus 28070	: V=0.9967, theta=-49.836716 -> V=1.0, theta=0.0
% INFO    : Bus 28071	: V=1.0072396, theta=-49.534935 -> V=1.0, theta=0.0
% INFO    : Bus 28072	: V=0.9983764, theta=-49.773647 -> V=1.0, theta=0.0
% INFO    : Bus 28073	: V=0.9825284, theta=-50.86956 -> V=1.0, theta=0.0
% INFO    : Bus 28074	: V=0.9810227, theta=-50.889387 -> V=1.0, theta=0.0
% INFO    : Bus 28075	: V=0.9943389, theta=-49.864358 -> V=1.0, theta=0.0
% INFO    : Bus 28076	: V=0.9974166, theta=-49.795843 -> V=1.0, theta=0.0
% INFO    : Bus 28077	: V=0.9838735, theta=-50.810027 -> V=1.0, theta=0.0
% INFO    : Bus 28078	: V=0.983135, theta=-50.81989 -> V=1.0, theta=0.0
% INFO    : Bus 28079	: V=0.9849459, theta=-50.727051 -> V=1.0, theta=0.0
% INFO    : Bus 28080	: V=0.9808632, theta=-50.869266 -> V=1.0, theta=0.0
% INFO    : Bus 28081	: V=0.9828719, theta=-50.66084 -> V=1.0, theta=0.0
% INFO    : Bus 28082	: V=0.9969797, theta=-43.712122 -> V=1.0, theta=0.0
% INFO    : Bus 28083	: V=0.9557871, theta=-49.076214 -> V=1.0, theta=0.0
% INFO    : Bus 28084	: V=0.9592765, theta=-47.538084 -> V=1.0, theta=0.0
% INFO    : Bus 28085	: V=0.9680999, theta=-46.546816 -> V=1.0, theta=0.0
% INFO    : Bus 28086	: V=0.9735584, theta=-51.026106 -> V=1.0, theta=0.0
% INFO    : Bus 28087	: V=1.0050032, theta=-47.904033 -> V=1.0, theta=0.0
% INFO    : Bus 28088	: V=1.00551, theta=-46.821656 -> V=1.0, theta=0.0
% INFO    : Bus 28089	: V=0.9956994, theta=-48.581512 -> V=1.0, theta=0.0
% INFO    : Bus 28090	: V=0.9618419, theta=-51.376734 -> V=1.0, theta=0.0
% INFO    : Bus 28091	: V=0.9633418, theta=-51.239108 -> V=1.0, theta=0.0
% INFO    : Bus 28092	: V=0.9820562, theta=-49.57539 -> V=1.0, theta=0.0
% INFO    : Bus 28093	: V=0.9832573, theta=-49.538925 -> V=1.0, theta=0.0
% INFO    : Bus 28094	: V=0.9692737, theta=-50.881138 -> V=1.0, theta=0.0
% INFO    : Bus 28095	: V=0.97006, theta=-50.835657 -> V=1.0, theta=0.0
% INFO    : Bus 28096	: V=0.9689654, theta=-50.91358 -> V=1.0, theta=0.0
% INFO    : Bus 28097	: V=0.9789986, theta=-50.279306 -> V=1.0, theta=0.0
% INFO    : Bus 28098	: V=0.9809348, theta=-50.207582 -> V=1.0, theta=0.0
% INFO    : Bus 28099	: V=0.9848337, theta=-49.435483 -> V=1.0, theta=0.0
% INFO    : Bus 28100	: V=0.9866885, theta=-49.316031 -> V=1.0, theta=0.0
% INFO    : Bus 28101	: V=0.9921275, theta=-48.937114 -> V=1.0, theta=0.0
% INFO    : Bus 28102	: V=0.9840488, theta=-49.72364 -> V=1.0, theta=0.0
% INFO    : Bus 28103	: V=0.9953968, theta=-48.689736 -> V=1.0, theta=0.0
% INFO    : Bus 28104	: V=0.9990779, theta=-48.427029 -> V=1.0, theta=0.0
% INFO    : Bus 28105	: V=1.0007911, theta=-48.300001 -> V=1.0, theta=0.0
% INFO    : Bus 28106	: V=0.9871036, theta=-49.676393 -> V=1.0, theta=0.0
% INFO    : Bus 28107	: V=0.9862269, theta=-49.709039 -> V=1.0, theta=0.0
% INFO    : Bus 28108	: V=0.9972678, theta=-48.55194 -> V=1.0, theta=0.0
% INFO    : Bus 28109	: V=0.9820645, theta=-50.11905 -> V=1.0, theta=0.0
% INFO    : Bus 28110	: V=0.9816866, theta=-50.196447 -> V=1.0, theta=0.0
% INFO    : Bus 28111	: V=0.9822152, theta=-50.091564 -> V=1.0, theta=0.0
% INFO    : Bus 28112	: V=1.0116925, theta=-46.903175 -> V=1.0, theta=0.0
% INFO    : Bus 28113	: V=0.9867332, theta=-49.720397 -> V=1.0, theta=0.0
% INFO    : Bus 28114	: V=0.9840956, theta=-49.772404 -> V=1.0, theta=0.0
% INFO    : Bus 28115	: V=0.9832521, theta=-49.793644 -> V=1.0, theta=0.0
% INFO    : Bus 28116	: V=0.9842893, theta=-49.758304 -> V=1.0, theta=0.0
% INFO    : Bus 28117	: V=0.982286, theta=-49.837693 -> V=1.0, theta=0.0
% INFO    : Bus 28118	: V=0.9847828, theta=-49.761716 -> V=1.0, theta=0.0
% INFO    : Bus 28119	: V=0.9827302, theta=-49.857403 -> V=1.0, theta=0.0
% INFO    : Bus 28120	: V=0.9824162, theta=-49.859633 -> V=1.0, theta=0.0
% INFO    : Bus 28121	: V=0.9817375, theta=-49.85855 -> V=1.0, theta=0.0
% INFO    : Bus 28122	: V=0.9807156, theta=-49.812996 -> V=1.0, theta=0.0
% INFO    : Bus 28123	: V=0.9813801, theta=-49.845099 -> V=1.0, theta=0.0
% INFO    : Bus 28124	: V=0.9918503, theta=-49.508376 -> V=1.0, theta=0.0
% INFO    : Bus 28125	: V=0.9935816, theta=-49.253344 -> V=1.0, theta=0.0
% INFO    : Bus 28126	: V=0.9857998, theta=-49.639945 -> V=1.0, theta=0.0
% INFO    : Bus 28127	: V=1.0104509, theta=-47.234869 -> V=1.0, theta=0.0
% INFO    : Bus 28128	: V=0.9870589, theta=-49.638579 -> V=1.0, theta=0.0
% INFO    : Bus 28129	: V=0.9662935, theta=-49.437195 -> V=1.0, theta=0.0
% INFO    : Bus 28130	: V=0.9649028, theta=-49.677799 -> V=1.0, theta=0.0
% INFO    : Bus 28131	: V=1.0142806, theta=-45.026728 -> V=1.0, theta=0.0
% INFO    : Bus 28132	: V=0.9452585, theta=-49.505561 -> V=1.0, theta=0.0
% INFO    : Bus 28133	: V=1.0173257, theta=-41.010506 -> V=1.0, theta=0.0
% INFO    : Bus 28134	: V=1.004836, theta=-42.004372 -> V=1.0, theta=0.0
% INFO    : Bus 28135	: V=1.0087171, theta=-41.772827 -> V=1.0, theta=0.0
% INFO    : Bus 28136	: V=1.0061156, theta=-41.891778 -> V=1.0, theta=0.0
% INFO    : Bus 28137	: V=1.0118653, theta=-41.272899 -> V=1.0, theta=0.0
% INFO    : Bus 28138	: V=1.0098506, theta=-41.637464 -> V=1.0, theta=0.0
% INFO    : Bus 28139	: V=1.0115736, theta=-41.389568 -> V=1.0, theta=0.0
% INFO    : Bus 28140	: V=1.0125639, theta=-41.216164 -> V=1.0, theta=0.0
% INFO    : Bus 28141	: V=1.0082201, theta=-41.597918 -> V=1.0, theta=0.0
% INFO    : Bus 28142	: V=1.00743, theta=-41.631615 -> V=1.0, theta=0.0
% INFO    : Bus 28143	: V=1.0129891, theta=-41.185647 -> V=1.0, theta=0.0
% INFO    : Bus 28144	: V=1.0071169, theta=-41.618159 -> V=1.0, theta=0.0
% INFO    : Bus 28145	: V=1.0167524, theta=-40.675239 -> V=1.0, theta=0.0
% INFO    : Bus 28146	: V=1.0193484, theta=-40.100534 -> V=1.0, theta=0.0
% INFO    : Bus 28147	: V=1.0139829, theta=-40.83336 -> V=1.0, theta=0.0
% INFO    : Bus 28148	: V=1.0197563, theta=-40.239872 -> V=1.0, theta=0.0
% INFO    : Bus 28149	: V=1.0189568, theta=-40.178007 -> V=1.0, theta=0.0
% INFO    : Bus 28150	: V=1.0162439, theta=-40.848353 -> V=1.0, theta=0.0
% INFO    : Bus 28151	: V=1.0194192, theta=-40.184386 -> V=1.0, theta=0.0
% INFO    : Bus 28152	: V=0.9990649, theta=-41.570466 -> V=1.0, theta=0.0
% INFO    : Bus 28153	: V=1.006446, theta=-41.115245 -> V=1.0, theta=0.0
% INFO    : Bus 28154	: V=1.018209, theta=-40.020275 -> V=1.0, theta=0.0
% INFO    : Bus 28155	: V=1.0088926, theta=-41.134716 -> V=1.0, theta=0.0
% INFO    : Bus 28156	: V=1.0001911, theta=-41.539256 -> V=1.0, theta=0.0
% INFO    : Bus 28157	: V=0.9954022, theta=-41.332271 -> V=1.0, theta=0.0
% INFO    : Bus 28158	: V=1.0010144, theta=-41.490605 -> V=1.0, theta=0.0
% INFO    : Bus 28159	: V=0.9987558, theta=-41.484699 -> V=1.0, theta=0.0
% INFO    : Bus 28160	: V=0.9931692, theta=-41.360385 -> V=1.0, theta=0.0
% INFO    : Bus 28161	: V=0.9994029, theta=-41.201805 -> V=1.0, theta=0.0
% INFO    : Bus 28162	: V=1.0140893, theta=-40.245352 -> V=1.0, theta=0.0
% INFO    : Bus 28163	: V=0.9708186, theta=-42.488663 -> V=1.0, theta=0.0
% INFO    : Bus 28164	: V=0.9726142, theta=-42.456992 -> V=1.0, theta=0.0
% INFO    : Bus 28165	: V=0.9657296, theta=-42.267726 -> V=1.0, theta=0.0
% INFO    : Bus 28166	: V=0.9648463, theta=-42.101123 -> V=1.0, theta=0.0
% INFO    : Bus 28167	: V=0.9637525, theta=-42.228849 -> V=1.0, theta=0.0
% INFO    : Bus 28168	: V=0.9669501, theta=-41.985589 -> V=1.0, theta=0.0
% INFO    : Bus 28169	: V=0.965767, theta=-42.156332 -> V=1.0, theta=0.0
% INFO    : Bus 28170	: V=0.9826541, theta=-41.139988 -> V=1.0, theta=0.0
% INFO    : Bus 28171	: V=0.9840351, theta=-41.276217 -> V=1.0, theta=0.0
% INFO    : Bus 28172	: V=0.963659, theta=-42.022786 -> V=1.0, theta=0.0
% INFO    : Bus 28173	: V=0.9646206, theta=-42.057485 -> V=1.0, theta=0.0
% INFO    : Bus 28174	: V=0.966081, theta=-41.964225 -> V=1.0, theta=0.0
% INFO    : Bus 28175	: V=0.9627996, theta=-42.118742 -> V=1.0, theta=0.0
% INFO    : Bus 28176	: V=0.9710341, theta=-41.535127 -> V=1.0, theta=0.0
% INFO    : Bus 28177	: V=0.9681547, theta=-41.787108 -> V=1.0, theta=0.0
% INFO    : Bus 28178	: V=1.0071123, theta=-38.56602 -> V=1.0, theta=0.0
% INFO    : Bus 28179	: V=0.9848379, theta=-40.266862 -> V=1.0, theta=0.0
% INFO    : Bus 28180	: V=0.9830015, theta=-39.941696 -> V=1.0, theta=0.0
% INFO    : Bus 28181	: V=0.9819857, theta=-39.987802 -> V=1.0, theta=0.0
% INFO    : Bus 28182	: V=0.9859628, theta=-39.404601 -> V=1.0, theta=0.0
% INFO    : Bus 28183	: V=0.9765212, theta=-40.304547 -> V=1.0, theta=0.0
% INFO    : Bus 28184	: V=0.9822713, theta=-40.351249 -> V=1.0, theta=0.0
% INFO    : Bus 28185	: V=0.9877494, theta=-39.462639 -> V=1.0, theta=0.0
% INFO    : Bus 28186	: V=0.9707393, theta=-41.465769 -> V=1.0, theta=0.0
% INFO    : Bus 28187	: V=0.9807575, theta=-40.075984 -> V=1.0, theta=0.0
% INFO    : Bus 28188	: V=0.9846932, theta=-39.465254 -> V=1.0, theta=0.0
% INFO    : Bus 28189	: V=0.9781467, theta=-40.073494 -> V=1.0, theta=0.0
% INFO    : Bus 28190	: V=0.9779546, theta=-40.1826 -> V=1.0, theta=0.0
% INFO    : Bus 28191	: V=0.9850957, theta=-39.449393 -> V=1.0, theta=0.0
% INFO    : Bus 28192	: V=0.9846509, theta=-38.763355 -> V=1.0, theta=0.0
% INFO    : Bus 28193	: V=0.9799253, theta=-40.081269 -> V=1.0, theta=0.0
% INFO    : Bus 28194	: V=0.9883253, theta=-38.454264 -> V=1.0, theta=0.0
% INFO    : Bus 28195	: V=0.9833427, theta=-37.752194 -> V=1.0, theta=0.0
% INFO    : Bus 28196	: V=0.9786388, theta=-38.31609 -> V=1.0, theta=0.0
% INFO    : Bus 28197	: V=0.9861979, theta=-37.881421 -> V=1.0, theta=0.0
% INFO    : Bus 28198	: V=0.9696992, theta=-40.810724 -> V=1.0, theta=0.0
% INFO    : Bus 28199	: V=0.9733477, theta=-40.51933 -> V=1.0, theta=0.0
% INFO    : Bus 28200	: V=0.9769548, theta=-38.827247 -> V=1.0, theta=0.0
% INFO    : Bus 28201	: V=0.9677998, theta=-41.065219 -> V=1.0, theta=0.0
% INFO    : Bus 28202	: V=0.9612744, theta=-41.905538 -> V=1.0, theta=0.0
% INFO    : Bus 28203	: V=0.9644732, theta=-41.472038 -> V=1.0, theta=0.0
% INFO    : Bus 28204	: V=0.959843, theta=-42.123141 -> V=1.0, theta=0.0
% INFO    : Bus 28205	: V=0.9579695, theta=-42.320728 -> V=1.0, theta=0.0
% INFO    : Bus 28206	: V=0.9575108, theta=-42.398267 -> V=1.0, theta=0.0
% INFO    : Bus 28207	: V=0.9579054, theta=-42.484991 -> V=1.0, theta=0.0
% INFO    : Bus 28208	: V=0.9605015, theta=-42.475584 -> V=1.0, theta=0.0
% INFO    : Bus 28209	: V=0.9609712, theta=-42.474217 -> V=1.0, theta=0.0
% INFO    : Bus 28210	: V=0.9627793, theta=-42.58177 -> V=1.0, theta=0.0
% INFO    : Bus 28211	: V=0.97733, theta=-43.035209 -> V=1.0, theta=0.0
% INFO    : Bus 28212	: V=0.9778606, theta=-42.993622 -> V=1.0, theta=0.0
% INFO    : Bus 28213	: V=0.9745407, theta=-43.273144 -> V=1.0, theta=0.0
% INFO    : Bus 28214	: V=0.9721734, theta=-43.495978 -> V=1.0, theta=0.0
% INFO    : Bus 28215	: V=0.968887, theta=-43.828562 -> V=1.0, theta=0.0
% INFO    : Bus 28216	: V=0.9665794, theta=-43.948789 -> V=1.0, theta=0.0
% INFO    : Bus 28217	: V=0.9655125, theta=-44.004247 -> V=1.0, theta=0.0
% INFO    : Bus 28218	: V=0.9649157, theta=-44.076637 -> V=1.0, theta=0.0
% INFO    : Bus 28219	: V=0.9873666, theta=-42.985725 -> V=1.0, theta=0.0
% INFO    : Bus 28220	: V=0.994528, theta=-42.210598 -> V=1.0, theta=0.0
% INFO    : Bus 28221	: V=0.9885509, theta=-42.288262 -> V=1.0, theta=0.0
% INFO    : Bus 28222	: V=0.9817501, theta=-42.830033 -> V=1.0, theta=0.0
% INFO    : Bus 28223	: V=0.9667454, theta=-42.619272 -> V=1.0, theta=0.0
% INFO    : Bus 28224	: V=0.992175, theta=-42.144619 -> V=1.0, theta=0.0
% INFO    : Bus 28225	: V=0.9976581, theta=-41.912956 -> V=1.0, theta=0.0
% INFO    : Bus 28226	: V=0.9900943, theta=-42.275483 -> V=1.0, theta=0.0
% INFO    : Bus 28227	: V=1.0041367, theta=-41.585098 -> V=1.0, theta=0.0
% INFO    : Bus 28228	: V=0.9992897, theta=-41.757673 -> V=1.0, theta=0.0
% INFO    : Bus 28229	: V=1.0046551, theta=-42.31635 -> V=1.0, theta=0.0
% INFO    : Bus 28230	: V=1.0000814, theta=-41.301139 -> V=1.0, theta=0.0
% INFO    : Bus 28231	: V=0.9940854, theta=-41.561426 -> V=1.0, theta=0.0
% INFO    : Bus 28232	: V=1.0047938, theta=-37.843265 -> V=1.0, theta=0.0
% INFO    : Bus 28233	: V=0.9889984, theta=-38.789612 -> V=1.0, theta=0.0
% INFO    : Bus 28234	: V=0.9814031, theta=-40.200561 -> V=1.0, theta=0.0
% INFO    : Bus 28235	: V=1.0051939, theta=-37.849448 -> V=1.0, theta=0.0
% INFO    : Bus 28236	: V=0.9918393, theta=-38.774913 -> V=1.0, theta=0.0
% INFO    : Bus 28237	: V=0.9811504, theta=-40.234258 -> V=1.0, theta=0.0
% INFO    : Bus 28238	: V=0.981606, theta=-40.208538 -> V=1.0, theta=0.0
% INFO    : Bus 28239	: V=0.9914869, theta=-37.947662 -> V=1.0, theta=0.0
% INFO    : Bus 28240	: V=1.0051133, theta=-36.900286 -> V=1.0, theta=0.0
% INFO    : Bus 28241	: V=1.0187586, theta=-40.341182 -> V=1.0, theta=0.0
% INFO    : Bus 28242	: V=1.0042137, theta=-41.281122 -> V=1.0, theta=0.0
% INFO    : Bus 28243	: V=0.9881973, theta=-42.426088 -> V=1.0, theta=0.0
% INFO    : Bus 28244	: V=0.9810683, theta=-43.93802 -> V=1.0, theta=0.0
% INFO    : Bus 28245	: V=0.9619616, theta=-44.536985 -> V=1.0, theta=0.0
% INFO    : Bus 28246	: V=0.959485, theta=-44.656078 -> V=1.0, theta=0.0
% INFO    : Bus 28247	: V=0.9585721, theta=-44.703718 -> V=1.0, theta=0.0
% INFO    : Bus 28248	: V=0.9594201, theta=-44.649218 -> V=1.0, theta=0.0
% INFO    : Bus 28249	: V=0.9600888, theta=-44.529491 -> V=1.0, theta=0.0
% INFO    : Bus 28250	: V=0.9756333, theta=-42.642266 -> V=1.0, theta=0.0
% INFO    : Bus 28251	: V=0.9598052, theta=-44.612791 -> V=1.0, theta=0.0
% INFO    : Bus 28252	: V=0.9591585, theta=-44.52615 -> V=1.0, theta=0.0
% INFO    : Bus 28253	: V=0.961795, theta=-44.260844 -> V=1.0, theta=0.0
% INFO    : Bus 28254	: V=0.9775803, theta=-42.289161 -> V=1.0, theta=0.0
% INFO    : Bus 28255	: V=0.9780638, theta=-42.300341 -> V=1.0, theta=0.0
% INFO    : Bus 28256	: V=0.962878, theta=-44.36303 -> V=1.0, theta=0.0
% INFO    : Bus 28257	: V=0.9794757, theta=-42.34684 -> V=1.0, theta=0.0
% INFO    : Bus 28258	: V=0.9794212, theta=-42.221371 -> V=1.0, theta=0.0
% INFO    : Bus 28259	: V=0.9665368, theta=-44.174293 -> V=1.0, theta=0.0
% INFO    : Bus 28260	: V=0.9616156, theta=-44.072404 -> V=1.0, theta=0.0
% INFO    : Bus 28261	: V=0.9623794, theta=-42.495881 -> V=1.0, theta=0.0
% INFO    : Bus 28262	: V=0.9563143, theta=-44.400212 -> V=1.0, theta=0.0
% INFO    : Bus 28263	: V=0.9633762, theta=-44.285534 -> V=1.0, theta=0.0
% INFO    : Bus 28264	: V=0.9622995, theta=-44.394445 -> V=1.0, theta=0.0
% INFO    : Bus 28265	: V=0.9653082, theta=-44.263266 -> V=1.0, theta=0.0
% INFO    : Bus 28266	: V=0.966894, theta=-44.119751 -> V=1.0, theta=0.0
% INFO    : Bus 28267	: V=0.9773026, theta=-42.722812 -> V=1.0, theta=0.0
% INFO    : Bus 28268	: V=0.9776325, theta=-42.629375 -> V=1.0, theta=0.0
% INFO    : Bus 28269	: V=0.9631222, theta=-44.053603 -> V=1.0, theta=0.0
% INFO    : Bus 28270	: V=0.9640781, theta=-43.998932 -> V=1.0, theta=0.0
% INFO    : Bus 28271	: V=0.9617257, theta=-44.500047 -> V=1.0, theta=0.0
% INFO    : Bus 28272	: V=0.9608469, theta=-44.588298 -> V=1.0, theta=0.0
% INFO    : Bus 28273	: V=0.9649833, theta=-44.345831 -> V=1.0, theta=0.0
% INFO    : Bus 28274	: V=0.9644951, theta=-44.411331 -> V=1.0, theta=0.0
% INFO    : Bus 28275	: V=0.965114, theta=-44.410461 -> V=1.0, theta=0.0
% INFO    : Bus 28276	: V=0.9634696, theta=-44.437333 -> V=1.0, theta=0.0
% INFO    : Bus 28277	: V=0.9627902, theta=-44.483943 -> V=1.0, theta=0.0
% INFO    : Bus 28278	: V=0.9623507, theta=-44.495866 -> V=1.0, theta=0.0
% INFO    : Bus 28279	: V=0.9788041, theta=-42.756849 -> V=1.0, theta=0.0
% INFO    : Bus 28280	: V=0.9811861, theta=-42.664192 -> V=1.0, theta=0.0
% INFO    : Bus 28281	: V=0.975786, theta=-43.544706 -> V=1.0, theta=0.0
% INFO    : Bus 28282	: V=0.969536, theta=-44.062931 -> V=1.0, theta=0.0
% INFO    : Bus 28283	: V=0.9726699, theta=-43.804158 -> V=1.0, theta=0.0
% INFO    : Bus 28284	: V=0.9736449, theta=-43.703296 -> V=1.0, theta=0.0
% INFO    : Bus 28285	: V=0.9722922, theta=-43.947839 -> V=1.0, theta=0.0
% INFO    : Bus 28286	: V=0.979682, theta=-42.825313 -> V=1.0, theta=0.0
% INFO    : Bus 28287	: V=0.978844, theta=-42.908731 -> V=1.0, theta=0.0
% INFO    : Bus 28288	: V=0.9769826, theta=-43.09573 -> V=1.0, theta=0.0
% INFO    : Bus 28289	: V=0.9774163, theta=-43.049429 -> V=1.0, theta=0.0
% INFO    : Bus 28290	: V=0.9673859, theta=-44.145221 -> V=1.0, theta=0.0
% INFO    : Bus 28291	: V=0.968021, theta=-44.104678 -> V=1.0, theta=0.0
% INFO    : Bus 28292	: V=0.9770728, theta=-42.811803 -> V=1.0, theta=0.0
% INFO    : Bus 28293	: V=0.9635774, theta=-44.426802 -> V=1.0, theta=0.0
% INFO    : Bus 28294	: V=0.9600379, theta=-44.690135 -> V=1.0, theta=0.0
% INFO    : Bus 28295	: V=0.9616369, theta=-44.672056 -> V=1.0, theta=0.0
% INFO    : Bus 28296	: V=0.9756985, theta=-43.093491 -> V=1.0, theta=0.0
% INFO    : Bus 28297	: V=0.9671251, theta=-44.316943 -> V=1.0, theta=0.0
% INFO    : Bus 28298	: V=0.9659971, theta=-44.417951 -> V=1.0, theta=0.0
% INFO    : Bus 28299	: V=0.9653696, theta=-44.435535 -> V=1.0, theta=0.0
% INFO    : Bus 28300	: V=0.9624517, theta=-44.693048 -> V=1.0, theta=0.0
% INFO    : Bus 28301	: V=0.9637911, theta=-44.607172 -> V=1.0, theta=0.0
% INFO    : Bus 28302	: V=0.9650284, theta=-44.462455 -> V=1.0, theta=0.0
% INFO    : Bus 28303	: V=0.9664025, theta=-44.423764 -> V=1.0, theta=0.0
% INFO    : Bus 28304	: V=0.966894, theta=-44.409949 -> V=1.0, theta=0.0
% INFO    : Bus 28305	: V=0.9672897, theta=-44.184669 -> V=1.0, theta=0.0
% INFO    : Bus 28306	: V=0.9682855, theta=-44.155065 -> V=1.0, theta=0.0
% INFO    : Bus 28307	: V=0.9594464, theta=-44.670378 -> V=1.0, theta=0.0
% INFO    : Bus 28308	: V=0.9603598, theta=-44.637427 -> V=1.0, theta=0.0
% INFO    : Bus 28309	: V=0.9841097, theta=-42.471869 -> V=1.0, theta=0.0
% INFO    : Bus 28310	: V=0.9769918, theta=-43.58871 -> V=1.0, theta=0.0
% INFO    : Bus 28311	: V=0.9758511, theta=-43.216417 -> V=1.0, theta=0.0
% INFO    : Bus 28312	: V=0.9763944, theta=-43.157817 -> V=1.0, theta=0.0
% INFO    : Bus 28313	: V=0.9625109, theta=-44.750483 -> V=1.0, theta=0.0
% INFO    : Bus 28314	: V=0.9692066, theta=-44.265691 -> V=1.0, theta=0.0
% INFO    : Bus 28315	: V=0.9739825, theta=-43.838244 -> V=1.0, theta=0.0
% INFO    : Bus 28316	: V=0.9736462, theta=-43.873449 -> V=1.0, theta=0.0
% INFO    : Bus 28317	: V=0.9645658, theta=-44.647986 -> V=1.0, theta=0.0
% INFO    : Bus 28318	: V=0.9660281, theta=-44.65417 -> V=1.0, theta=0.0
% INFO    : Bus 28319	: V=0.9757182, theta=-43.625322 -> V=1.0, theta=0.0
% INFO    : Bus 28320	: V=0.975617, theta=-43.632798 -> V=1.0, theta=0.0
% INFO    : Bus 28321	: V=0.9647043, theta=-44.348238 -> V=1.0, theta=0.0
% INFO    : Bus 28322	: V=0.9670513, theta=-44.177984 -> V=1.0, theta=0.0
% INFO    : Bus 28323	: V=0.9727919, theta=-43.720862 -> V=1.0, theta=0.0
% INFO    : Bus 28324	: V=0.9662659, theta=-44.23251 -> V=1.0, theta=0.0
% INFO    : Bus 28325	: V=0.968146, theta=-44.088044 -> V=1.0, theta=0.0
% INFO    : Bus 28326	: V=0.9790674, theta=-42.425418 -> V=1.0, theta=0.0
% INFO    : Bus 28327	: V=0.9754473, theta=-43.404368 -> V=1.0, theta=0.0
% INFO    : Bus 28328	: V=0.9800902, theta=-42.350057 -> V=1.0, theta=0.0
% INFO    : Bus 28329	: V=1.0122597, theta=-37.471486 -> V=1.0, theta=0.0
% INFO    : Bus 28330	: V=0.9912562, theta=-40.5313 -> V=1.0, theta=0.0
% INFO    : Bus 28331	: V=0.9802789, theta=-42.960812 -> V=1.0, theta=0.0
% INFO    : Bus 28332	: V=0.9795893, theta=-42.988835 -> V=1.0, theta=0.0
% INFO    : Bus 28333	: V=0.978591, theta=-43.060329 -> V=1.0, theta=0.0
% INFO    : Bus 28334	: V=0.9790391, theta=-43.030322 -> V=1.0, theta=0.0
% INFO    : Bus 28335	: V=0.980391, theta=-42.550143 -> V=1.0, theta=0.0
% INFO    : Bus 28336	: V=0.970523, theta=-44.316854 -> V=1.0, theta=0.0
% INFO    : Bus 28337	: V=0.9707952, theta=-44.21335 -> V=1.0, theta=0.0
% INFO    : Bus 28338	: V=0.9709735, theta=-44.295716 -> V=1.0, theta=0.0
% INFO    : Bus 28339	: V=0.9707425, theta=-44.266798 -> V=1.0, theta=0.0
% INFO    : Bus 28340	: V=0.973106, theta=-43.759613 -> V=1.0, theta=0.0
% INFO    : Bus 28341	: V=0.9720511, theta=-43.990998 -> V=1.0, theta=0.0
% INFO    : Bus 28342	: V=0.965264, theta=-44.314199 -> V=1.0, theta=0.0
% INFO    : Bus 28343	: V=0.9706227, theta=-43.924737 -> V=1.0, theta=0.0
% INFO    : Bus 28344	: V=0.9700378, theta=-44.266695 -> V=1.0, theta=0.0
% INFO    : Bus 28345	: V=0.9698103, theta=-43.99912 -> V=1.0, theta=0.0
% INFO    : Bus 28346	: V=0.9699223, theta=-43.996738 -> V=1.0, theta=0.0
% INFO    : Bus 28347	: V=0.9648011, theta=-44.327044 -> V=1.0, theta=0.0
% INFO    : Bus 28348	: V=0.969749, theta=-44.41512 -> V=1.0, theta=0.0
% INFO    : Bus 28349	: V=0.9696695, theta=-44.392953 -> V=1.0, theta=0.0
% INFO    : Bus 28350	: V=0.9691771, theta=-44.397549 -> V=1.0, theta=0.0
% INFO    : Bus 28351	: V=0.9698026, theta=-44.36626 -> V=1.0, theta=0.0
% INFO    : Bus 28352	: V=0.9693216, theta=-44.408577 -> V=1.0, theta=0.0
% INFO    : Bus 28353	: V=0.9697292, theta=-44.38227 -> V=1.0, theta=0.0
% INFO    : Bus 28354	: V=0.9694996, theta=-44.40154 -> V=1.0, theta=0.0
% INFO    : Bus 28355	: V=0.9698834, theta=-44.438061 -> V=1.0, theta=0.0
% INFO    : Bus 28356	: V=0.9701882, theta=-44.444191 -> V=1.0, theta=0.0
% INFO    : Bus 28357	: V=0.9732415, theta=-44.288219 -> V=1.0, theta=0.0
% INFO    : Bus 28358	: V=0.9699222, theta=-44.427902 -> V=1.0, theta=0.0
% INFO    : Bus 28359	: V=0.9696281, theta=-44.439812 -> V=1.0, theta=0.0
% INFO    : Bus 28360	: V=0.9745358, theta=-44.217035 -> V=1.0, theta=0.0
% INFO    : Bus 28361	: V=0.9739957, theta=-44.221482 -> V=1.0, theta=0.0
% INFO    : Bus 28362	: V=0.9750597, theta=-44.160229 -> V=1.0, theta=0.0
% INFO    : Bus 28363	: V=0.9755099, theta=-44.147975 -> V=1.0, theta=0.0
% INFO    : Bus 28364	: V=0.9781238, theta=-43.646779 -> V=1.0, theta=0.0
% INFO    : Bus 28365	: V=0.9785467, theta=-43.601229 -> V=1.0, theta=0.0
% INFO    : Bus 28366	: V=0.9821353, theta=-42.850635 -> V=1.0, theta=0.0
% INFO    : Bus 28367	: V=0.9814949, theta=-42.867923 -> V=1.0, theta=0.0
% INFO    : Bus 28368	: V=0.9878135, theta=-42.261712 -> V=1.0, theta=0.0
% INFO    : Bus 28369	: V=0.9877919, theta=-42.275354 -> V=1.0, theta=0.0
% INFO    : Bus 28370	: V=0.9875893, theta=-42.293735 -> V=1.0, theta=0.0
% INFO    : Bus 28371	: V=0.9882814, theta=-42.257383 -> V=1.0, theta=0.0
% INFO    : Bus 28372	: V=0.9823834, theta=-43.155108 -> V=1.0, theta=0.0
% INFO    : Bus 28373	: V=0.9810134, theta=-43.338283 -> V=1.0, theta=0.0
% INFO    : Bus 28374	: V=0.9814175, theta=-43.346751 -> V=1.0, theta=0.0
% INFO    : Bus 28375	: V=0.9794295, theta=-43.512513 -> V=1.0, theta=0.0
% INFO    : Bus 28376	: V=0.9800333, theta=-43.618262 -> V=1.0, theta=0.0
% INFO    : Bus 28377	: V=0.9784889, theta=-43.785326 -> V=1.0, theta=0.0
% INFO    : Bus 28378	: V=0.9816903, theta=-43.423689 -> V=1.0, theta=0.0
% INFO    : Bus 28379	: V=0.9805919, theta=-43.626542 -> V=1.0, theta=0.0
% INFO    : Bus 28380	: V=0.9798497, theta=-43.646017 -> V=1.0, theta=0.0
% INFO    : Bus 28381	: V=0.9825329, theta=-43.329854 -> V=1.0, theta=0.0
% INFO    : Bus 28382	: V=0.9837294, theta=-43.299199 -> V=1.0, theta=0.0
% INFO    : Bus 28383	: V=1.0017234, theta=-40.886217 -> V=1.0, theta=0.0
% INFO    : Bus 28384	: V=0.9827452, theta=-43.362444 -> V=1.0, theta=0.0
% INFO    : Bus 28385	: V=0.9824372, theta=-43.297105 -> V=1.0, theta=0.0
% INFO    : Bus 28386	: V=0.9841935, theta=-43.109464 -> V=1.0, theta=0.0
% INFO    : Bus 28387	: V=0.9831256, theta=-43.151149 -> V=1.0, theta=0.0
% INFO    : Bus 28388	: V=0.9831418, theta=-43.116258 -> V=1.0, theta=0.0
% INFO    : Bus 28389	: V=0.9828367, theta=-43.079805 -> V=1.0, theta=0.0
% INFO    : Bus 28390	: V=0.9893161, theta=-42.663642 -> V=1.0, theta=0.0
% INFO    : Bus 28391	: V=0.9866493, theta=-42.952763 -> V=1.0, theta=0.0
% INFO    : Bus 28392	: V=0.9846725, theta=-43.050761 -> V=1.0, theta=0.0
% INFO    : Bus 28393	: V=0.9999041, theta=-41.007225 -> V=1.0, theta=0.0
% INFO    : Bus 28394	: V=1.0028737, theta=-40.796953 -> V=1.0, theta=0.0
% INFO    : Bus 28395	: V=0.9713312, theta=-44.296683 -> V=1.0, theta=0.0
% INFO    : Bus 28396	: V=0.9857148, theta=-42.328064 -> V=1.0, theta=0.0
% INFO    : Bus 28397	: V=0.9809564, theta=-42.936955 -> V=1.0, theta=0.0
% INFO    : Bus 28398	: V=0.9816781, theta=-42.899797 -> V=1.0, theta=0.0
% INFO    : Bus 28399	: V=0.9880456, theta=-42.165893 -> V=1.0, theta=0.0
% INFO    : Bus 28400	: V=1.0138327, theta=-38.408593 -> V=1.0, theta=0.0
% INFO    : Bus 28401	: V=0.9951682, theta=-41.094763 -> V=1.0, theta=0.0
% INFO    : Bus 28402	: V=0.9866351, theta=-42.370713 -> V=1.0, theta=0.0
% INFO    : Bus 28403	: V=0.9871066, theta=-42.316268 -> V=1.0, theta=0.0
% INFO    : Bus 28404	: V=0.9839435, theta=-42.930765 -> V=1.0, theta=0.0
% INFO    : Bus 28405	: V=0.9801919, theta=-43.310279 -> V=1.0, theta=0.0
% INFO    : Bus 28406	: V=0.9807804, theta=-43.363756 -> V=1.0, theta=0.0
% INFO    : Bus 28407	: V=0.9858952, theta=-42.474542 -> V=1.0, theta=0.0
% INFO    : Bus 28408	: V=0.9854925, theta=-42.512063 -> V=1.0, theta=0.0
% INFO    : Bus 28409	: V=0.9878086, theta=-42.217817 -> V=1.0, theta=0.0
% INFO    : Bus 28410	: V=0.9875336, theta=-42.22555 -> V=1.0, theta=0.0
% INFO    : Bus 28411	: V=0.9719338, theta=-44.310757 -> V=1.0, theta=0.0
% INFO    : Bus 28412	: V=0.9714055, theta=-44.315186 -> V=1.0, theta=0.0
% INFO    : Bus 28413	: V=0.970034, theta=-44.382932 -> V=1.0, theta=0.0
% INFO    : Bus 28414	: V=0.9725089, theta=-44.319089 -> V=1.0, theta=0.0
% INFO    : Bus 28415	: V=0.9796564, theta=-43.502783 -> V=1.0, theta=0.0
% INFO    : Bus 28416	: V=0.9854554, theta=-42.378519 -> V=1.0, theta=0.0
% INFO    : Bus 28417	: V=0.9877118, theta=-42.237959 -> V=1.0, theta=0.0
% INFO    : Bus 28418	: V=0.9785712, theta=-43.641306 -> V=1.0, theta=0.0
% INFO    : Bus 28419	: V=0.9777463, theta=-43.662948 -> V=1.0, theta=0.0
% INFO    : Bus 28420	: V=0.972699, theta=-44.289111 -> V=1.0, theta=0.0
% INFO    : Bus 28421	: V=0.9706015, theta=-44.264539 -> V=1.0, theta=0.0
% INFO    : Bus 28422	: V=0.978409, theta=-43.497688 -> V=1.0, theta=0.0
% INFO    : Bus 28423	: V=0.9770153, theta=-43.679731 -> V=1.0, theta=0.0
% INFO    : Bus 28424	: V=0.9652754, theta=-44.728728 -> V=1.0, theta=0.0
% INFO    : Bus 28425	: V=0.9691576, theta=-44.433442 -> V=1.0, theta=0.0
% INFO    : Bus 28426	: V=0.9641426, theta=-44.821465 -> V=1.0, theta=0.0
% INFO    : Bus 28427	: V=0.97014, theta=-44.428703 -> V=1.0, theta=0.0
% INFO    : Bus 28428	: V=0.9686243, theta=-44.785326 -> V=1.0, theta=0.0
% INFO    : Bus 28429	: V=0.9697876, theta=-44.543057 -> V=1.0, theta=0.0
% INFO    : Bus 28430	: V=0.9728919, theta=-44.389915 -> V=1.0, theta=0.0
% INFO    : Bus 28431	: V=0.9675818, theta=-44.875669 -> V=1.0, theta=0.0
% INFO    : Bus 28432	: V=0.96679, theta=-44.911114 -> V=1.0, theta=0.0
% INFO    : Bus 28433	: V=0.967994, theta=-44.982073 -> V=1.0, theta=0.0
% INFO    : Bus 28434	: V=0.9695941, theta=-44.909156 -> V=1.0, theta=0.0
% INFO    : Bus 28435	: V=0.9681839, theta=-45.047377 -> V=1.0, theta=0.0
% INFO    : Bus 28436	: V=0.975406, theta=-44.053718 -> V=1.0, theta=0.0
% INFO    : Bus 28437	: V=0.9777713, theta=-43.672119 -> V=1.0, theta=0.0
% INFO    : Bus 28438	: V=0.9740056, theta=-44.254231 -> V=1.0, theta=0.0
% INFO    : Bus 28439	: V=0.9729903, theta=-44.139003 -> V=1.0, theta=0.0
% INFO    : Bus 28440	: V=0.9730048, theta=-43.89811 -> V=1.0, theta=0.0
% INFO    : Bus 28441	: V=0.9755242, theta=-43.786277 -> V=1.0, theta=0.0
% INFO    : Bus 28442	: V=0.9849525, theta=-42.582841 -> V=1.0, theta=0.0
% INFO    : Bus 28443	: V=0.972087, theta=-44.445837 -> V=1.0, theta=0.0
% INFO    : Bus 28444	: V=0.9801455, theta=-43.440926 -> V=1.0, theta=0.0
% INFO    : Bus 28445	: V=0.9846345, theta=-42.627841 -> V=1.0, theta=0.0
% INFO    : Bus 28446	: V=0.9844917, theta=-42.654036 -> V=1.0, theta=0.0
% INFO    : Bus 28447	: V=0.9691967, theta=-44.649751 -> V=1.0, theta=0.0
% INFO    : Bus 28448	: V=0.9696145, theta=-44.63815 -> V=1.0, theta=0.0
% INFO    : Bus 28449	: V=0.9706802, theta=-44.595845 -> V=1.0, theta=0.0
% INFO    : Bus 28450	: V=0.9705178, theta=-44.574475 -> V=1.0, theta=0.0
% INFO    : Bus 28451	: V=0.9850535, theta=-42.563571 -> V=1.0, theta=0.0
% INFO    : Bus 28452	: V=0.9852067, theta=-42.540925 -> V=1.0, theta=0.0
% INFO    : Bus 28453	: V=0.985381, theta=-42.531024 -> V=1.0, theta=0.0
% INFO    : Bus 28454	: V=0.9848591, theta=-42.591699 -> V=1.0, theta=0.0
% INFO    : Bus 28455	: V=0.9851127, theta=-42.556771 -> V=1.0, theta=0.0
% INFO    : Bus 28456	: V=0.9857468, theta=-42.487246 -> V=1.0, theta=0.0
% INFO    : Bus 28457	: V=0.986547, theta=-42.390362 -> V=1.0, theta=0.0
% INFO    : Bus 28458	: V=0.9873411, theta=-42.332877 -> V=1.0, theta=0.0
% INFO    : Bus 28459	: V=0.9844776, theta=-42.667212 -> V=1.0, theta=0.0
% INFO    : Bus 28460	: V=0.9705575, theta=-44.759379 -> V=1.0, theta=0.0
% INFO    : Bus 28461	: V=0.9715471, theta=-44.602006 -> V=1.0, theta=0.0
% INFO    : Bus 28462	: V=0.9831657, theta=-42.800383 -> V=1.0, theta=0.0
% INFO    : Bus 28463	: V=0.9708002, theta=-44.840787 -> V=1.0, theta=0.0
% INFO    : Bus 28464	: V=0.9736486, theta=-44.589607 -> V=1.0, theta=0.0
% INFO    : Bus 28465	: V=0.9780859, theta=-44.023908 -> V=1.0, theta=0.0
% INFO    : Bus 28466	: V=0.9749284, theta=-44.33371 -> V=1.0, theta=0.0
% INFO    : Bus 28467	: V=0.9722926, theta=-44.735977 -> V=1.0, theta=0.0
% INFO    : Bus 28468	: V=0.9716952, theta=-44.752319 -> V=1.0, theta=0.0
% INFO    : Bus 28469	: V=0.9810377, theta=-43.570206 -> V=1.0, theta=0.0
% INFO    : Bus 28470	: V=0.9903582, theta=-42.182844 -> V=1.0, theta=0.0
% INFO    : Bus 28471	: V=0.9883884, theta=-42.269343 -> V=1.0, theta=0.0
% INFO    : Bus 28472	: V=0.9800609, theta=-43.834167 -> V=1.0, theta=0.0
% INFO    : Bus 28473	: V=0.9793264, theta=-43.881013 -> V=1.0, theta=0.0
% INFO    : Bus 28474	: V=0.9735835, theta=-44.65941 -> V=1.0, theta=0.0
% INFO    : Bus 28475	: V=0.9924579, theta=-42.087602 -> V=1.0, theta=0.0
% INFO    : Bus 28476	: V=1.0172468, theta=-38.937946 -> V=1.0, theta=0.0
% INFO    : Bus 28477	: V=0.9864674, theta=-42.704071 -> V=1.0, theta=0.0
% INFO    : Bus 28478	: V=0.9929677, theta=-42.114547 -> V=1.0, theta=0.0
% INFO    : Bus 28479	: V=0.9719998, theta=-44.895955 -> V=1.0, theta=0.0
% INFO    : Bus 28480	: V=0.9754399, theta=-44.553446 -> V=1.0, theta=0.0
% INFO    : Bus 28481	: V=0.972904, theta=-44.841048 -> V=1.0, theta=0.0
% INFO    : Bus 28482	: V=0.975978, theta=-44.492727 -> V=1.0, theta=0.0
% INFO    : Bus 28483	: V=0.976445, theta=-44.490017 -> V=1.0, theta=0.0
% INFO    : Bus 28484	: V=0.9768454, theta=-44.447611 -> V=1.0, theta=0.0
% INFO    : Bus 28485	: V=0.9658464, theta=-45.144566 -> V=1.0, theta=0.0
% INFO    : Bus 28486	: V=0.968187, theta=-45.148617 -> V=1.0, theta=0.0
% INFO    : Bus 28487	: V=0.9644685, theta=-45.28553 -> V=1.0, theta=0.0
% INFO    : Bus 28488	: V=0.9661037, theta=-45.122009 -> V=1.0, theta=0.0
% INFO    : Bus 28489	: V=0.9707389, theta=-44.774974 -> V=1.0, theta=0.0
% INFO    : Bus 28490	: V=0.9817439, theta=-43.010683 -> V=1.0, theta=0.0
% INFO    : Bus 28491	: V=0.9836168, theta=-42.889459 -> V=1.0, theta=0.0
% INFO    : Bus 28492	: V=0.9737975, theta=-44.551228 -> V=1.0, theta=0.0
% INFO    : Bus 28493	: V=0.9807761, theta=-44.051578 -> V=1.0, theta=0.0
% INFO    : Bus 28494	: V=0.9772523, theta=-44.466927 -> V=1.0, theta=0.0
% INFO    : Bus 28495	: V=0.9612773, theta=-45.386145 -> V=1.0, theta=0.0
% INFO    : Bus 28496	: V=0.9715292, theta=-44.648323 -> V=1.0, theta=0.0
% INFO    : Bus 28497	: V=0.9662602, theta=-45.026366 -> V=1.0, theta=0.0
% INFO    : Bus 28498	: V=0.9657718, theta=-45.030958 -> V=1.0, theta=0.0
% INFO    : Bus 28499	: V=0.9671072, theta=-45.075875 -> V=1.0, theta=0.0
% INFO    : Bus 28500	: V=0.9682119, theta=-44.985716 -> V=1.0, theta=0.0
% INFO    : Bus 28501	: V=0.974864, theta=-44.644083 -> V=1.0, theta=0.0
% INFO    : Bus 28502	: V=0.976453, theta=-44.537869 -> V=1.0, theta=0.0
% INFO    : Bus 28503	: V=0.9781805, theta=-44.38442 -> V=1.0, theta=0.0
% INFO    : Bus 28504	: V=0.9775138, theta=-44.40873 -> V=1.0, theta=0.0
% INFO    : Bus 28505	: V=0.9746424, theta=-44.667749 -> V=1.0, theta=0.0
% INFO    : Bus 28506	: V=0.9764513, theta=-44.656308 -> V=1.0, theta=0.0
% INFO    : Bus 28507	: V=0.9796988, theta=-44.333179 -> V=1.0, theta=0.0
% INFO    : Bus 28508	: V=0.992565, theta=-42.226998 -> V=1.0, theta=0.0
% INFO    : Bus 28509	: V=0.9907506, theta=-42.453076 -> V=1.0, theta=0.0
% INFO    : Bus 28510	: V=0.9912997, theta=-42.390432 -> V=1.0, theta=0.0
% INFO    : Bus 28511	: V=0.9937324, theta=-42.098214 -> V=1.0, theta=0.0
% INFO    : Bus 28512	: V=0.9848735, theta=-43.012666 -> V=1.0, theta=0.0
% INFO    : Bus 28513	: V=0.9947649, theta=-41.959517 -> V=1.0, theta=0.0
% INFO    : Bus 28514	: V=0.9906015, theta=-42.384055 -> V=1.0, theta=0.0
% INFO    : Bus 28515	: V=0.9908061, theta=-42.450546 -> V=1.0, theta=0.0
% INFO    : Bus 28516	: V=0.9824505, theta=-43.056735 -> V=1.0, theta=0.0
% INFO    : Bus 28517	: V=0.9910067, theta=-42.339665 -> V=1.0, theta=0.0
% INFO    : Bus 28518	: V=0.9911753, theta=-42.333599 -> V=1.0, theta=0.0
% INFO    : Bus 28519	: V=0.9864398, theta=-43.003151 -> V=1.0, theta=0.0
% INFO    : Bus 28520	: V=1.0186943, theta=-38.977414 -> V=1.0, theta=0.0
% INFO    : Bus 28521	: V=0.9887934, theta=-42.718727 -> V=1.0, theta=0.0
% INFO    : Bus 28522	: V=0.9881563, theta=-42.771273 -> V=1.0, theta=0.0
% INFO    : Bus 28523	: V=0.989723, theta=-42.59119 -> V=1.0, theta=0.0
% INFO    : Bus 28524	: V=0.9785955, theta=-43.550766 -> V=1.0, theta=0.0
% INFO    : Bus 28525	: V=0.9794382, theta=-43.540724 -> V=1.0, theta=0.0
% INFO    : Bus 28526	: V=0.9794276, theta=-43.530962 -> V=1.0, theta=0.0
% INFO    : Bus 28527	: V=0.9901057, theta=-42.440687 -> V=1.0, theta=0.0
% INFO    : Bus 28528	: V=0.9808216, theta=-43.614558 -> V=1.0, theta=0.0
% INFO    : Bus 28529	: V=0.98808, theta=-42.746972 -> V=1.0, theta=0.0
% INFO    : Bus 28530	: V=0.9782455, theta=-44.474996 -> V=1.0, theta=0.0
% INFO    : Bus 28531	: V=0.9783908, theta=-44.470117 -> V=1.0, theta=0.0
% INFO    : Bus 28532	: V=0.9773447, theta=-44.552433 -> V=1.0, theta=0.0
% INFO    : Bus 28533	: V=0.9871188, theta=-42.865412 -> V=1.0, theta=0.0
% INFO    : Bus 28534	: V=0.988954, theta=-42.597355 -> V=1.0, theta=0.0
% INFO    : Bus 28535	: V=0.9880552, theta=-42.720965 -> V=1.0, theta=0.0
% INFO    : Bus 28536	: V=0.9875111, theta=-42.808175 -> V=1.0, theta=0.0
% INFO    : Bus 28537	: V=0.9861322, theta=-43.009857 -> V=1.0, theta=0.0
% INFO    : Bus 28538	: V=0.9762904, theta=-44.664165 -> V=1.0, theta=0.0
% INFO    : Bus 28539	: V=0.9756886, theta=-44.712742 -> V=1.0, theta=0.0
% INFO    : Bus 28540	: V=0.9763537, theta=-44.629401 -> V=1.0, theta=0.0
% INFO    : Bus 28541	: V=0.9843509, theta=-43.26516 -> V=1.0, theta=0.0
% INFO    : Bus 28542	: V=0.9829186, theta=-43.466603 -> V=1.0, theta=0.0
% INFO    : Bus 28543	: V=0.9843614, theta=-43.196661 -> V=1.0, theta=0.0
% INFO    : Bus 28544	: V=0.9845899, theta=-43.197786 -> V=1.0, theta=0.0
% INFO    : Bus 28545	: V=0.983004, theta=-43.29373 -> V=1.0, theta=0.0
% INFO    : Bus 28546	: V=0.9859829, theta=-43.02584 -> V=1.0, theta=0.0
% INFO    : Bus 28547	: V=0.982003, theta=-43.332148 -> V=1.0, theta=0.0
% INFO    : Bus 28548	: V=0.9796774, theta=-43.527483 -> V=1.0, theta=0.0
% INFO    : Bus 28549	: V=0.9864697, theta=-42.980824 -> V=1.0, theta=0.0
% INFO    : Bus 28550	: V=0.9869778, theta=-42.960196 -> V=1.0, theta=0.0
% INFO    : Bus 28551	: V=0.9860753, theta=-43.035065 -> V=1.0, theta=0.0
% INFO    : Bus 28552	: V=0.9791202, theta=-44.111697 -> V=1.0, theta=0.0
% INFO    : Bus 28553	: V=0.9804494, theta=-43.935753 -> V=1.0, theta=0.0
% INFO    : Bus 28554	: V=0.9802981, theta=-43.939845 -> V=1.0, theta=0.0
% INFO    : Bus 28555	: V=0.9853026, theta=-43.116971 -> V=1.0, theta=0.0
% INFO    : Bus 28556	: V=0.9815164, theta=-43.751072 -> V=1.0, theta=0.0
% INFO    : Bus 28557	: V=0.9911706, theta=-42.211376 -> V=1.0, theta=0.0
% INFO    : Bus 28558	: V=0.9848237, theta=-43.176553 -> V=1.0, theta=0.0
% INFO    : Bus 28559	: V=0.9839011, theta=-43.262531 -> V=1.0, theta=0.0
% INFO    : Bus 28560	: V=0.983336, theta=-43.293156 -> V=1.0, theta=0.0
% INFO    : Bus 28561	: V=0.9827885, theta=-43.414372 -> V=1.0, theta=0.0
% INFO    : Bus 28562	: V=0.9829015, theta=-43.416792 -> V=1.0, theta=0.0
% INFO    : Bus 28563	: V=0.977738, theta=-44.414204 -> V=1.0, theta=0.0
% INFO    : Bus 28564	: V=0.9818855, theta=-43.554162 -> V=1.0, theta=0.0
% INFO    : Bus 28565	: V=0.9750665, theta=-44.76809 -> V=1.0, theta=0.0
% INFO    : Bus 28566	: V=0.9762921, theta=-44.376858 -> V=1.0, theta=0.0
% INFO    : Bus 28567	: V=0.9793163, theta=-44.215992 -> V=1.0, theta=0.0
% INFO    : Bus 28568	: V=0.9804151, theta=-44.131524 -> V=1.0, theta=0.0
% INFO    : Bus 28569	: V=0.9758685, theta=-44.644073 -> V=1.0, theta=0.0
% INFO    : Bus 28570	: V=0.9778451, theta=-44.565607 -> V=1.0, theta=0.0
% INFO    : Bus 28571	: V=0.9772176, theta=-44.502964 -> V=1.0, theta=0.0
% INFO    : Bus 28572	: V=0.9755009, theta=-44.705317 -> V=1.0, theta=0.0
% INFO    : Bus 28573	: V=0.9839707, theta=-43.454473 -> V=1.0, theta=0.0
% INFO    : Bus 28574	: V=0.9761376, theta=-44.643882 -> V=1.0, theta=0.0
% INFO    : Bus 28575	: V=0.9745044, theta=-44.814941 -> V=1.0, theta=0.0
% INFO    : Bus 28576	: V=0.9747311, theta=-44.807131 -> V=1.0, theta=0.0
% INFO    : Bus 28577	: V=0.9832979, theta=-43.874491 -> V=1.0, theta=0.0
% INFO    : Bus 28578	: V=0.9823824, theta=-43.991403 -> V=1.0, theta=0.0
% INFO    : Bus 28579	: V=0.975335, theta=-44.779532 -> V=1.0, theta=0.0
% INFO    : Bus 28580	: V=0.9825385, theta=-43.853862 -> V=1.0, theta=0.0
% INFO    : Bus 28581	: V=1.0069535, theta=-39.307043 -> V=1.0, theta=0.0
% INFO    : Bus 28582	: V=0.9859786, theta=-43.120726 -> V=1.0, theta=0.0
% INFO    : Bus 28583	: V=0.9793772, theta=-44.227116 -> V=1.0, theta=0.0
% INFO    : Bus 28584	: V=0.9795024, theta=-44.240058 -> V=1.0, theta=0.0
% INFO    : Bus 28585	: V=0.9846247, theta=-43.13832 -> V=1.0, theta=0.0
% INFO    : Bus 28586	: V=0.9825082, theta=-43.955523 -> V=1.0, theta=0.0
% INFO    : Bus 28587	: V=0.9844875, theta=-43.769478 -> V=1.0, theta=0.0
% INFO    : Bus 28588	: V=0.9819218, theta=-44.025223 -> V=1.0, theta=0.0
% INFO    : Bus 28589	: V=0.9819748, theta=-43.986943 -> V=1.0, theta=0.0
% INFO    : Bus 28590	: V=0.989855, theta=-42.415819 -> V=1.0, theta=0.0
% INFO    : Bus 28591	: V=0.9791805, theta=-44.364922 -> V=1.0, theta=0.0
% INFO    : Bus 28592	: V=0.9758943, theta=-44.689412 -> V=1.0, theta=0.0
% INFO    : Bus 28593	: V=0.9750717, theta=-44.701757 -> V=1.0, theta=0.0
% INFO    : Bus 28594	: V=0.9752335, theta=-44.690543 -> V=1.0, theta=0.0
% INFO    : Bus 28595	: V=0.9752339, theta=-44.769219 -> V=1.0, theta=0.0
% INFO    : Bus 28596	: V=0.9755529, theta=-44.741477 -> V=1.0, theta=0.0
% INFO    : Bus 28597	: V=0.9852225, theta=-43.159966 -> V=1.0, theta=0.0
% INFO    : Bus 28598	: V=0.9816431, theta=-43.98334 -> V=1.0, theta=0.0
% INFO    : Bus 28599	: V=0.9739714, theta=-44.920773 -> V=1.0, theta=0.0
% INFO    : Bus 28600	: V=0.974279, theta=-44.815156 -> V=1.0, theta=0.0
% INFO    : Bus 28601	: V=0.9748016, theta=-44.793319 -> V=1.0, theta=0.0
% INFO    : Bus 28602	: V=0.9760706, theta=-44.645803 -> V=1.0, theta=0.0
% INFO    : Bus 28603	: V=0.9813787, theta=-43.683773 -> V=1.0, theta=0.0
% INFO    : Bus 28604	: V=0.9986612, theta=-41.196642 -> V=1.0, theta=0.0
% INFO    : Bus 28605	: V=0.9668735, theta=-45.0082 -> V=1.0, theta=0.0
% INFO    : Bus 28606	: V=0.9739172, theta=-51.266138 -> V=1.0, theta=0.0
% INFO    : Bus 28607	: V=0.9873395, theta=-48.507674 -> V=1.0, theta=0.0
% INFO    : Bus 28608	: V=0.9837048, theta=-49.785364 -> V=1.0, theta=0.0
% INFO    : Bus 28609	: V=1.001106, theta=-47.807637 -> V=1.0, theta=0.0
% INFO    : Bus 28610	: V=0.9809951, theta=-49.810321 -> V=1.0, theta=0.0
% INFO    : Bus 28611	: V=0.971625, theta=-51.182131 -> V=1.0, theta=0.0
% INFO    : Bus 28612	: V=0.9737051, theta=-50.927195 -> V=1.0, theta=0.0
% INFO    : Bus 28613	: V=0.9715831, theta=-51.16894 -> V=1.0, theta=0.0
% INFO    : Bus 28614	: V=0.9718661, theta=-51.141443 -> V=1.0, theta=0.0
% INFO    : Bus 28615	: V=0.9716982, theta=-51.225795 -> V=1.0, theta=0.0
% INFO    : Bus 28616	: V=0.9626401, theta=-52.187154 -> V=1.0, theta=0.0
% INFO    : Bus 28617	: V=0.9701789, theta=-51.393621 -> V=1.0, theta=0.0
% INFO    : Bus 28618	: V=0.9731494, theta=-51.279696 -> V=1.0, theta=0.0
% INFO    : Bus 28619	: V=0.9639862, theta=-51.562495 -> V=1.0, theta=0.0
% INFO    : Bus 28620	: V=0.9653731, theta=-51.274911 -> V=1.0, theta=0.0
% INFO    : Bus 28621	: V=0.9625215, theta=-51.840039 -> V=1.0, theta=0.0
% INFO    : Bus 28622	: V=0.9640658, theta=-51.817309 -> V=1.0, theta=0.0
% INFO    : Bus 28623	: V=0.9656625, theta=-51.891294 -> V=1.0, theta=0.0
% INFO    : Bus 28624	: V=0.9847362, theta=-49.777137 -> V=1.0, theta=0.0
% INFO    : Bus 28625	: V=0.9627964, theta=-52.382713 -> V=1.0, theta=0.0
% INFO    : Bus 28626	: V=0.9614019, theta=-52.332268 -> V=1.0, theta=0.0
% INFO    : Bus 28627	: V=0.9691666, theta=-51.525377 -> V=1.0, theta=0.0
% INFO    : Bus 28628	: V=0.9600645, theta=-52.517833 -> V=1.0, theta=0.0
% INFO    : Bus 28629	: V=0.9712557, theta=-51.216601 -> V=1.0, theta=0.0
% INFO    : Bus 28630	: V=0.9614873, theta=-52.224033 -> V=1.0, theta=0.0
% INFO    : Bus 28631	: V=0.9712347, theta=-51.224324 -> V=1.0, theta=0.0
% INFO    : Bus 28632	: V=0.9621086, theta=-52.096955 -> V=1.0, theta=0.0
% INFO    : Bus 28633	: V=0.9609648, theta=-52.123684 -> V=1.0, theta=0.0
% INFO    : Bus 28634	: V=0.9608766, theta=-51.902328 -> V=1.0, theta=0.0
% INFO    : Bus 28635	: V=0.964305, theta=-51.528935 -> V=1.0, theta=0.0
% INFO    : Bus 28636	: V=0.961998, theta=-51.735421 -> V=1.0, theta=0.0
% INFO    : Bus 28637	: V=0.9711497, theta=-51.235046 -> V=1.0, theta=0.0
% INFO    : Bus 28638	: V=0.9514911, theta=-54.821413 -> V=1.0, theta=0.0
% INFO    : Bus 28639	: V=0.9464502, theta=-55.433492 -> V=1.0, theta=0.0
% INFO    : Bus 28640	: V=0.9444204, theta=-55.901236 -> V=1.0, theta=0.0
% INFO    : Bus 28641	: V=0.9455079, theta=-55.790632 -> V=1.0, theta=0.0
% INFO    : Bus 28642	: V=0.9443875, theta=-55.854153 -> V=1.0, theta=0.0
% INFO    : Bus 28643	: V=0.9430124, theta=-55.551625 -> V=1.0, theta=0.0
% INFO    : Bus 28644	: V=0.9425084, theta=-55.746058 -> V=1.0, theta=0.0
% INFO    : Bus 28645	: V=0.9451606, theta=-55.427138 -> V=1.0, theta=0.0
% INFO    : Bus 28646	: V=0.9450408, theta=-55.504815 -> V=1.0, theta=0.0
% INFO    : Bus 28647	: V=0.9723053, theta=-50.207017 -> V=1.0, theta=0.0
% INFO    : Bus 28648	: V=0.9730383, theta=-50.33986 -> V=1.0, theta=0.0
% INFO    : Bus 28649	: V=0.9736046, theta=-50.106358 -> V=1.0, theta=0.0
% INFO    : Bus 28650	: V=0.9725948, theta=-50.173645 -> V=1.0, theta=0.0
% INFO    : Bus 28651	: V=0.9879279, theta=-49.022383 -> V=1.0, theta=0.0
% INFO    : Bus 28652	: V=0.9983751, theta=-47.018321 -> V=1.0, theta=0.0
% INFO    : Bus 28653	: V=0.9891555, theta=-48.673065 -> V=1.0, theta=0.0
% INFO    : Bus 28654	: V=0.9973709, theta=-46.912618 -> V=1.0, theta=0.0
% INFO    : Bus 28655	: V=1.0011261, theta=-46.407743 -> V=1.0, theta=0.0
% INFO    : Bus 28656	: V=0.9919225, theta=-49.722457 -> V=1.0, theta=0.0
% INFO    : Bus 28657	: V=0.9881534, theta=-48.107564 -> V=1.0, theta=0.0
% INFO    : Bus 28658	: V=0.9816609, theta=-49.370967 -> V=1.0, theta=0.0
% INFO    : Bus 28659	: V=0.9776475, theta=-49.870599 -> V=1.0, theta=0.0
% INFO    : Bus 28660	: V=0.9679112, theta=-51.084758 -> V=1.0, theta=0.0
% INFO    : Bus 28661	: V=0.9695267, theta=-50.919269 -> V=1.0, theta=0.0
% INFO    : Bus 28662	: V=0.9709243, theta=-50.779749 -> V=1.0, theta=0.0
% INFO    : Bus 28663	: V=0.9727522, theta=-50.618326 -> V=1.0, theta=0.0
% INFO    : Bus 28664	: V=0.9742076, theta=-50.736567 -> V=1.0, theta=0.0
% INFO    : Bus 28665	: V=0.9730502, theta=-50.705884 -> V=1.0, theta=0.0
% INFO    : Bus 28666	: V=0.9669479, theta=-51.42882 -> V=1.0, theta=0.0
% INFO    : Bus 28667	: V=0.9761718, theta=-50.747148 -> V=1.0, theta=0.0
% INFO    : Bus 28668	: V=0.9799726, theta=-50.046253 -> V=1.0, theta=0.0
% INFO    : Bus 28669	: V=0.9852329, theta=-50.362363 -> V=1.0, theta=0.0
% INFO    : Bus 28670	: V=0.9923981, theta=-49.807617 -> V=1.0, theta=0.0
% INFO    : Bus 28671	: V=0.9771325, theta=-51.192719 -> V=1.0, theta=0.0
% INFO    : Bus 28672	: V=0.9924532, theta=-49.911776 -> V=1.0, theta=0.0
% INFO    : Bus 28673	: V=0.9922868, theta=-49.207812 -> V=1.0, theta=0.0
% INFO    : Bus 28674	: V=0.9536075, theta=-48.806225 -> V=1.0, theta=0.0
% INFO    : Bus 28675	: V=0.9512689, theta=-49.192486 -> V=1.0, theta=0.0
% INFO    : Bus 28676	: V=0.9612198, theta=-48.105993 -> V=1.0, theta=0.0
% INFO    : Bus 28677	: V=0.9474469, theta=-49.248574 -> V=1.0, theta=0.0
% INFO    : Bus 28678	: V=0.9505429, theta=-47.54907 -> V=1.0, theta=0.0
% INFO    : Bus 28679	: V=0.9495894, theta=-48.791608 -> V=1.0, theta=0.0
% INFO    : Bus 28680	: V=0.9664916, theta=-45.769488 -> V=1.0, theta=0.0
% INFO    : Bus 28681	: V=1.0087371, theta=-40.785259 -> V=1.0, theta=0.0
% INFO    : Bus 28682	: V=0.9570919, theta=-47.228616 -> V=1.0, theta=0.0
% INFO    : Bus 28683	: V=0.9530803, theta=-47.660635 -> V=1.0, theta=0.0
% INFO    : Bus 28684	: V=0.9569239, theta=-47.189965 -> V=1.0, theta=0.0
% INFO    : Bus 28685	: V=0.955331, theta=-47.302621 -> V=1.0, theta=0.0
% INFO    : Bus 28686	: V=0.9559713, theta=-47.166551 -> V=1.0, theta=0.0
% INFO    : Bus 28687	: V=0.9671821, theta=-46.320345 -> V=1.0, theta=0.0
% INFO    : Bus 28688	: V=0.9664708, theta=-46.23269 -> V=1.0, theta=0.0
% INFO    : Bus 28689	: V=0.9503369, theta=-47.876376 -> V=1.0, theta=0.0
% INFO    : Bus 28690	: V=0.9469833, theta=-48.155628 -> V=1.0, theta=0.0
% INFO    : Bus 28691	: V=0.9645389, theta=-46.414259 -> V=1.0, theta=0.0
% INFO    : Bus 28692	: V=0.9552815, theta=-47.264494 -> V=1.0, theta=0.0
% INFO    : Bus 28693	: V=0.9561596, theta=-47.148407 -> V=1.0, theta=0.0
% INFO    : Bus 28694	: V=0.9556235, theta=-49.213427 -> V=1.0, theta=0.0
% INFO    : Bus 28695	: V=0.9821943, theta=-48.997872 -> V=1.0, theta=0.0
% INFO    : Bus 28696	: V=0.9493069, theta=-49.411164 -> V=1.0, theta=0.0
% INFO    : Bus 28697	: V=0.9932902, theta=-47.460464 -> V=1.0, theta=0.0
% INFO    : Bus 28698	: V=0.9640476, theta=-49.175755 -> V=1.0, theta=0.0
% INFO    : Bus 28699	: V=0.9948619, theta=-47.344533 -> V=1.0, theta=0.0
% INFO    : Bus 28700	: V=0.9524386, theta=-48.972539 -> V=1.0, theta=0.0
% INFO    : Bus 28701	: V=0.9710524, theta=-46.216453 -> V=1.0, theta=0.0
% INFO    : Bus 28702	: V=0.9760175, theta=-45.914636 -> V=1.0, theta=0.0
% INFO    : Bus 28703	: V=0.9958645, theta=-44.222738 -> V=1.0, theta=0.0
% INFO    : Bus 28704	: V=0.9569889, theta=-55.905322 -> V=1.0, theta=0.0
% INFO    : Bus 28705	: V=0.9575518, theta=-55.920794 -> V=1.0, theta=0.0
% INFO    : Bus 28706	: V=0.9603133, theta=-55.649552 -> V=1.0, theta=0.0
% INFO    : Bus 28707	: V=0.9558816, theta=-56.023833 -> V=1.0, theta=0.0
% INFO    : Bus 28708	: V=0.9597683, theta=-55.685923 -> V=1.0, theta=0.0
% INFO    : Bus 28709	: V=0.9554264, theta=-56.036894 -> V=1.0, theta=0.0
% INFO    : Bus 28710	: V=0.9594832, theta=-55.692194 -> V=1.0, theta=0.0
% INFO    : Bus 28711	: V=0.9561964, theta=-55.925869 -> V=1.0, theta=0.0
% INFO    : Bus 28712	: V=0.9565073, theta=-56.090872 -> V=1.0, theta=0.0
% INFO    : Bus 28713	: V=0.9584011, theta=-55.898744 -> V=1.0, theta=0.0
% INFO    : Bus 28714	: V=0.9473776, theta=-56.693636 -> V=1.0, theta=0.0
% INFO    : Bus 28715	: V=0.9463401, theta=-56.780366 -> V=1.0, theta=0.0
% INFO    : Bus 28716	: V=0.9460666, theta=-56.755421 -> V=1.0, theta=0.0
% INFO    : Bus 28717	: V=0.9474578, theta=-56.710578 -> V=1.0, theta=0.0
% INFO    : Bus 28718	: V=0.9474046, theta=-56.729407 -> V=1.0, theta=0.0
% INFO    : Bus 28719	: V=0.9466801, theta=-56.797093 -> V=1.0, theta=0.0
% INFO    : Bus 28720	: V=0.94735, theta=-56.777425 -> V=1.0, theta=0.0
% INFO    : Bus 28721	: V=0.9507153, theta=-56.53101 -> V=1.0, theta=0.0
% INFO    : Bus 28722	: V=0.9513773, theta=-56.521081 -> V=1.0, theta=0.0
% INFO    : Bus 28723	: V=0.9464158, theta=-56.804929 -> V=1.0, theta=0.0
% INFO    : Bus 28724	: V=0.9555308, theta=-56.00403 -> V=1.0, theta=0.0
% INFO    : Bus 28725	: V=0.9570957, theta=-55.971249 -> V=1.0, theta=0.0
% INFO    : Bus 28726	: V=0.9620024, theta=-54.736892 -> V=1.0, theta=0.0
% INFO    : Bus 28727	: V=0.948673, theta=-56.659902 -> V=1.0, theta=0.0
% INFO    : Bus 28728	: V=0.9525007, theta=-56.436072 -> V=1.0, theta=0.0
% INFO    : Bus 28729	: V=0.9629347, theta=-54.661621 -> V=1.0, theta=0.0
% INFO    : Bus 28730	: V=1.0007574, theta=-49.330519 -> V=1.0, theta=0.0
% INFO    : Bus 28731	: V=0.9503042, theta=-56.57447 -> V=1.0, theta=0.0
% INFO    : Bus 28732	: V=0.9541683, theta=-56.576042 -> V=1.0, theta=0.0
% INFO    : Bus 28733	: V=0.9509674, theta=-56.987575 -> V=1.0, theta=0.0
% INFO    : Bus 28734	: V=0.9495269, theta=-56.738077 -> V=1.0, theta=0.0
% INFO    : Bus 28735	: V=0.9432591, theta=-58.252204 -> V=1.0, theta=0.0
% INFO    : Bus 28736	: V=0.9380145, theta=-56.625058 -> V=1.0, theta=0.0
% INFO    : Bus 28737	: V=0.9449776, theta=-58.004988 -> V=1.0, theta=0.0
% INFO    : Bus 28738	: V=0.9487984, theta=-56.754152 -> V=1.0, theta=0.0
% INFO    : Bus 28739	: V=0.9478888, theta=-56.741339 -> V=1.0, theta=0.0
% INFO    : Bus 28740	: V=0.9541408, theta=-56.172439 -> V=1.0, theta=0.0
% INFO    : Bus 28741	: V=0.9569267, theta=-56.150195 -> V=1.0, theta=0.0
% INFO    : Bus 28742	: V=0.9483864, theta=-56.764906 -> V=1.0, theta=0.0
% INFO    : Bus 28743	: V=0.9521656, theta=-56.835605 -> V=1.0, theta=0.0
% INFO    : Bus 28744	: V=0.9483902, theta=-56.81637 -> V=1.0, theta=0.0
% INFO    : Bus 28745	: V=0.9631783, theta=-54.741485 -> V=1.0, theta=0.0
% INFO    : Bus 28746	: V=0.952993, theta=-56.444052 -> V=1.0, theta=0.0
% INFO    : Bus 28747	: V=0.9541799, theta=-56.407933 -> V=1.0, theta=0.0
% INFO    : Bus 28748	: V=0.9501391, theta=-57.036384 -> V=1.0, theta=0.0
% INFO    : Bus 28749	: V=0.9494204, theta=-57.135326 -> V=1.0, theta=0.0
% INFO    : Bus 28750	: V=0.9638115, theta=-54.637317 -> V=1.0, theta=0.0
% INFO    : Bus 28751	: V=0.9531828, theta=-56.674351 -> V=1.0, theta=0.0
% INFO    : Bus 28752	: V=0.9532741, theta=-56.479055 -> V=1.0, theta=0.0
% INFO    : Bus 28753	: V=0.952803, theta=-56.502101 -> V=1.0, theta=0.0
% INFO    : Bus 28754	: V=0.9526051, theta=-56.496302 -> V=1.0, theta=0.0
% INFO    : Bus 28755	: V=0.954137, theta=-56.404783 -> V=1.0, theta=0.0
% INFO    : Bus 28756	: V=0.9528083, theta=-56.455902 -> V=1.0, theta=0.0
% INFO    : Bus 28757	: V=0.9485908, theta=-57.184704 -> V=1.0, theta=0.0
% INFO    : Bus 28758	: V=0.9485411, theta=-57.025567 -> V=1.0, theta=0.0
% INFO    : Bus 28759	: V=0.9476156, theta=-57.16941 -> V=1.0, theta=0.0
% INFO    : Bus 28760	: V=0.9478502, theta=-56.724273 -> V=1.0, theta=0.0
% INFO    : Bus 28761	: V=0.9372441, theta=-55.064602 -> V=1.0, theta=0.0
% INFO    : Bus 28762	: V=0.9425304, theta=-53.907768 -> V=1.0, theta=0.0
% INFO    : Bus 28763	: V=0.9466666, theta=-51.870968 -> V=1.0, theta=0.0
% INFO    : Bus 28764	: V=0.944573, theta=-53.468275 -> V=1.0, theta=0.0
% INFO    : Bus 28765	: V=0.9483528, theta=-53.392182 -> V=1.0, theta=0.0
% INFO    : Bus 28766	: V=0.9468544, theta=-47.780633 -> V=1.0, theta=0.0
% INFO    : Bus 28767	: V=0.9854749, theta=-51.342958 -> V=1.0, theta=0.0
% INFO    : Bus 28768	: V=0.9816216, theta=-52.209564 -> V=1.0, theta=0.0
% INFO    : Bus 28769	: V=0.9911144, theta=-49.79655 -> V=1.0, theta=0.0
% INFO    : Bus 28770	: V=0.9634208, theta=-52.847658 -> V=1.0, theta=0.0
% INFO    : Bus 28771	: V=0.9667782, theta=-52.695921 -> V=1.0, theta=0.0
% INFO    : Bus 28772	: V=0.9825225, theta=-51.596408 -> V=1.0, theta=0.0
% INFO    : Bus 28773	: V=0.9827242, theta=-51.598599 -> V=1.0, theta=0.0
% INFO    : Bus 28774	: V=0.9618304, theta=-52.962831 -> V=1.0, theta=0.0
% INFO    : Bus 28775	: V=0.963469, theta=-52.876506 -> V=1.0, theta=0.0
% INFO    : Bus 28776	: V=0.9843335, theta=-51.406793 -> V=1.0, theta=0.0
% INFO    : Bus 28777	: V=0.9923055, theta=-50.72425 -> V=1.0, theta=0.0
% INFO    : Bus 28778	: V=0.9899805, theta=-50.919723 -> V=1.0, theta=0.0
% INFO    : Bus 28779	: V=1.0088326, theta=-44.646005 -> V=1.0, theta=0.0
% INFO    : Bus 28780	: V=1.0041191, theta=-44.637234 -> V=1.0, theta=0.0
% INFO    : Bus 28781	: V=1.014775, theta=-44.361729 -> V=1.0, theta=0.0
% INFO    : Bus 28782	: V=0.9932209, theta=-46.915803 -> V=1.0, theta=0.0
% INFO    : Bus 28783	: V=1.0096186, theta=-44.711101 -> V=1.0, theta=0.0
% INFO    : Bus 28784	: V=0.9789046, theta=-48.881311 -> V=1.0, theta=0.0
% INFO    : Bus 28785	: V=1.0123129, theta=-44.43081 -> V=1.0, theta=0.0
% INFO    : Bus 28786	: V=0.9702995, theta=-50.381116 -> V=1.0, theta=0.0
% INFO    : Bus 28787	: V=1.0027415, theta=-46.963887 -> V=1.0, theta=0.0
% INFO    : Bus 28788	: V=1.0204829, theta=-45.374729 -> V=1.0, theta=0.0
% INFO    : Bus 28789	: V=1.0120178, theta=-47.169021 -> V=1.0, theta=0.0
% INFO    : Bus 28790	: V=1.0030845, theta=-47.540164 -> V=1.0, theta=0.0
% INFO    : Bus 28791	: V=1.002188, theta=-42.098088 -> V=1.0, theta=0.0
% INFO    : Bus 28792	: V=0.9943803, theta=-42.670967 -> V=1.0, theta=0.0
% INFO    : Bus 28793	: V=0.9934409, theta=-42.718884 -> V=1.0, theta=0.0
% INFO    : Bus 28794	: V=0.9776994, theta=-44.331868 -> V=1.0, theta=0.0
% INFO    : Bus 28795	: V=0.9767888, theta=-44.436465 -> V=1.0, theta=0.0
% INFO    : Bus 28796	: V=0.9712611, theta=-44.845798 -> V=1.0, theta=0.0
% INFO    : Bus 28797	: V=0.9737824, theta=-44.702276 -> V=1.0, theta=0.0
% INFO    : Bus 28798	: V=0.973308, theta=-44.70641 -> V=1.0, theta=0.0
% INFO    : Bus 28799	: V=0.9733104, theta=-44.744209 -> V=1.0, theta=0.0
% INFO    : Bus 28800	: V=0.9811302, theta=-44.165897 -> V=1.0, theta=0.0
% INFO    : Bus 28801	: V=0.98909, theta=-43.51828 -> V=1.0, theta=0.0
% INFO    : Bus 28802	: V=0.9778002, theta=-44.364316 -> V=1.0, theta=0.0
% INFO    : Bus 28803	: V=0.9717147, theta=-44.725246 -> V=1.0, theta=0.0
% INFO    : Bus 28804	: V=0.9702141, theta=-44.973771 -> V=1.0, theta=0.0
% INFO    : Bus 28805	: V=0.9696528, theta=-44.978698 -> V=1.0, theta=0.0
% INFO    : Bus 28806	: V=0.9696326, theta=-45.01832 -> V=1.0, theta=0.0
% INFO    : Bus 28807	: V=0.9773428, theta=-44.552368 -> V=1.0, theta=0.0
% INFO    : Bus 28808	: V=0.9906134, theta=-43.162607 -> V=1.0, theta=0.0
% INFO    : Bus 28809	: V=0.9781105, theta=-44.275639 -> V=1.0, theta=0.0
% INFO    : Bus 28810	: V=0.9701325, theta=-44.989931 -> V=1.0, theta=0.0
% INFO    : Bus 28811	: V=0.978125, theta=-44.24425 -> V=1.0, theta=0.0
% INFO    : Bus 28812	: V=0.9780349, theta=-44.262009 -> V=1.0, theta=0.0
% INFO    : Bus 28813	: V=0.9738474, theta=-44.760695 -> V=1.0, theta=0.0
% INFO    : Bus 28814	: V=0.979372, theta=-44.170002 -> V=1.0, theta=0.0
% INFO    : Bus 28815	: V=0.9741739, theta=-44.577131 -> V=1.0, theta=0.0
% INFO    : Bus 28816	: V=0.9776455, theta=-44.386549 -> V=1.0, theta=0.0
% INFO    : Bus 28817	: V=0.975403, theta=-44.509899 -> V=1.0, theta=0.0
% INFO    : Bus 28818	: V=0.9917889, theta=-43.089731 -> V=1.0, theta=0.0
% INFO    : Bus 28819	: V=0.9905869, theta=-43.139382 -> V=1.0, theta=0.0
% INFO    : Bus 28820	: V=1.0198912, theta=-39.472787 -> V=1.0, theta=0.0
% INFO    : Bus 28821	: V=1.0011005, theta=-42.040237 -> V=1.0, theta=0.0
% INFO    : Bus 28822	: V=0.9972619, theta=-42.805435 -> V=1.0, theta=0.0
% INFO    : Bus 28823	: V=0.9943339, theta=-42.656046 -> V=1.0, theta=0.0
% INFO    : Bus 28824	: V=0.9791404, theta=-44.24476 -> V=1.0, theta=0.0
% INFO    : Bus 28825	: V=0.9891505, theta=-43.415626 -> V=1.0, theta=0.0
% INFO    : Bus 28826	: V=0.9794993, theta=-44.204189 -> V=1.0, theta=0.0
% INFO    : Bus 28827	: V=0.9867532, theta=-43.608092 -> V=1.0, theta=0.0
% INFO    : Bus 28828	: V=0.9830495, theta=-43.959965 -> V=1.0, theta=0.0
% INFO    : Bus 28829	: V=0.989745, theta=-43.929991 -> V=1.0, theta=0.0
% INFO    : Bus 28830	: V=0.9820934, theta=-44.016599 -> V=1.0, theta=0.0
% INFO    : Bus 28831	: V=0.9769523, theta=-44.350817 -> V=1.0, theta=0.0
% INFO    : Bus 28832	: V=0.9777313, theta=-44.308543 -> V=1.0, theta=0.0
% INFO    : Bus 28833	: V=0.9853279, theta=-43.734148 -> V=1.0, theta=0.0
% INFO    : Bus 28834	: V=0.9843859, theta=-44.089797 -> V=1.0, theta=0.0
% INFO    : Bus 28835	: V=0.984761, theta=-43.787236 -> V=1.0, theta=0.0
% INFO    : Bus 28836	: V=0.9767386, theta=-44.35189 -> V=1.0, theta=0.0
% INFO    : Bus 28837	: V=0.9820433, theta=-44.000819 -> V=1.0, theta=0.0
% INFO    : Bus 28838	: V=0.9862416, theta=-43.697963 -> V=1.0, theta=0.0
% INFO    : Bus 28839	: V=0.9809809, theta=-44.063871 -> V=1.0, theta=0.0
% INFO    : Bus 28840	: V=0.9831024, theta=-44.050281 -> V=1.0, theta=0.0
% INFO    : Bus 28841	: V=0.9945093, theta=-42.881906 -> V=1.0, theta=0.0
% INFO    : Bus 28842	: V=0.9988106, theta=-42.838488 -> V=1.0, theta=0.0
% INFO    : Bus 28843	: V=0.9679984, theta=-45.693611 -> V=1.0, theta=0.0
% INFO    : Bus 28844	: V=0.9755901, theta=-45.11858 -> V=1.0, theta=0.0
% INFO    : Bus 28845	: V=0.9659248, theta=-45.721232 -> V=1.0, theta=0.0
% INFO    : Bus 28846	: V=0.9778993, theta=-44.532469 -> V=1.0, theta=0.0
% INFO    : Bus 28847	: V=0.9763546, theta=-44.63399 -> V=1.0, theta=0.0
% INFO    : Bus 28848	: V=0.9765716, theta=-44.605176 -> V=1.0, theta=0.0
% INFO    : Bus 28849	: V=0.9667331, theta=-45.709185 -> V=1.0, theta=0.0
% INFO    : Bus 28850	: V=0.9646081, theta=-45.827489 -> V=1.0, theta=0.0
% INFO    : Bus 28851	: V=0.9629415, theta=-45.909153 -> V=1.0, theta=0.0
% INFO    : Bus 28852	: V=0.9615512, theta=-45.958337 -> V=1.0, theta=0.0
% INFO    : Bus 28853	: V=0.9759211, theta=-44.770562 -> V=1.0, theta=0.0
% INFO    : Bus 28854	: V=0.9610083, theta=-45.985322 -> V=1.0, theta=0.0
% INFO    : Bus 28855	: V=0.9622771, theta=-46.08359 -> V=1.0, theta=0.0
% INFO    : Bus 28856	: V=0.9626682, theta=-46.004286 -> V=1.0, theta=0.0
% INFO    : Bus 28857	: V=0.9637008, theta=-45.963191 -> V=1.0, theta=0.0
% INFO    : Bus 28858	: V=0.9904873, theta=-43.17296 -> V=1.0, theta=0.0
% INFO    : Bus 28859	: V=0.9907045, theta=-43.145015 -> V=1.0, theta=0.0
% INFO    : Bus 28860	: V=1.0080753, theta=-40.527851 -> V=1.0, theta=0.0
% INFO    : Bus 28861	: V=0.9614686, theta=-46.162898 -> V=1.0, theta=0.0
% INFO    : Bus 28862	: V=0.9633583, theta=-46.016505 -> V=1.0, theta=0.0
% INFO    : Bus 28863	: V=0.9654379, theta=-45.889145 -> V=1.0, theta=0.0
% INFO    : Bus 28864	: V=0.967672, theta=-45.760821 -> V=1.0, theta=0.0
% INFO    : Bus 28865	: V=0.961022, theta=-46.391372 -> V=1.0, theta=0.0
% INFO    : Bus 28866	: V=0.9679809, theta=-45.623199 -> V=1.0, theta=0.0
% INFO    : Bus 28867	: V=0.9613178, theta=-46.290483 -> V=1.0, theta=0.0
% INFO    : Bus 28868	: V=0.9616623, theta=-46.303097 -> V=1.0, theta=0.0
% INFO    : Bus 28869	: V=0.9633523, theta=-46.069609 -> V=1.0, theta=0.0
% INFO    : Bus 28870	: V=0.9963833, theta=-43.716817 -> V=1.0, theta=0.0
% INFO    : Bus 28871	: V=0.9579341, theta=-46.681932 -> V=1.0, theta=0.0
% INFO    : Bus 28872	: V=0.9610467, theta=-46.513272 -> V=1.0, theta=0.0
% INFO    : Bus 28873	: V=0.9599851, theta=-46.610243 -> V=1.0, theta=0.0
% INFO    : Bus 28874	: V=0.9667657, theta=-45.466471 -> V=1.0, theta=0.0
% INFO    : Bus 28875	: V=0.9582974, theta=-46.467328 -> V=1.0, theta=0.0
% INFO    : Bus 28876	: V=0.9666896, theta=-45.502524 -> V=1.0, theta=0.0
% INFO    : Bus 28877	: V=0.9662261, theta=-45.523987 -> V=1.0, theta=0.0
% INFO    : Bus 28878	: V=0.9590336, theta=-46.395987 -> V=1.0, theta=0.0
% INFO    : Bus 28879	: V=0.9659798, theta=-45.542892 -> V=1.0, theta=0.0
% INFO    : Bus 28880	: V=0.9548598, theta=-47.001974 -> V=1.0, theta=0.0
% INFO    : Bus 28881	: V=0.9549471, theta=-46.822187 -> V=1.0, theta=0.0
% INFO    : Bus 28882	: V=0.9537603, theta=-47.16815 -> V=1.0, theta=0.0
% INFO    : Bus 28883	: V=0.9533497, theta=-47.224323 -> V=1.0, theta=0.0
% INFO    : Bus 28884	: V=0.9528097, theta=-47.382876 -> V=1.0, theta=0.0
% INFO    : Bus 28885	: V=0.9531158, theta=-47.488383 -> V=1.0, theta=0.0
% INFO    : Bus 28886	: V=0.9630394, theta=-46.009786 -> V=1.0, theta=0.0
% INFO    : Bus 28887	: V=0.9723822, theta=-44.951106 -> V=1.0, theta=0.0
% INFO    : Bus 28888	: V=0.9648836, theta=-45.467672 -> V=1.0, theta=0.0
% INFO    : Bus 28889	: V=0.9694896, theta=-45.230086 -> V=1.0, theta=0.0
% INFO    : Bus 28890	: V=0.9910051, theta=-42.794274 -> V=1.0, theta=0.0
% INFO    : Bus 28891	: V=0.9645951, theta=-45.71894 -> V=1.0, theta=0.0
% INFO    : Bus 28892	: V=0.9602925, theta=-46.227001 -> V=1.0, theta=0.0
% INFO    : Bus 28893	: V=0.9526903, theta=-46.990994 -> V=1.0, theta=0.0
% INFO    : Bus 28894	: V=0.9523408, theta=-46.980628 -> V=1.0, theta=0.0
% INFO    : Bus 28895	: V=0.9683863, theta=-45.175577 -> V=1.0, theta=0.0
% INFO    : Bus 28896	: V=0.969761, theta=-45.160156 -> V=1.0, theta=0.0
% INFO    : Bus 28897	: V=0.9621668, theta=-46.043173 -> V=1.0, theta=0.0
% INFO    : Bus 28898	: V=0.9660821, theta=-45.67967 -> V=1.0, theta=0.0
% INFO    : Bus 28899	: V=0.9732108, theta=-44.855419 -> V=1.0, theta=0.0
% INFO    : Bus 28900	: V=0.9679004, theta=-45.314212 -> V=1.0, theta=0.0
% INFO    : Bus 28901	: V=0.9688471, theta=-45.367385 -> V=1.0, theta=0.0
% INFO    : Bus 28902	: V=0.9602522, theta=-45.749417 -> V=1.0, theta=0.0
% INFO    : Bus 28903	: V=0.9667152, theta=-45.663555 -> V=1.0, theta=0.0
% INFO    : Bus 28904	: V=0.9533078, theta=-47.498962 -> V=1.0, theta=0.0
% INFO    : Bus 28905	: V=0.9660782, theta=-45.593728 -> V=1.0, theta=0.0
% INFO    : Bus 28906	: V=0.9642886, theta=-45.7983 -> V=1.0, theta=0.0
% INFO    : Bus 28907	: V=0.9657387, theta=-45.84414 -> V=1.0, theta=0.0
% INFO    : Bus 28908	: V=0.9655044, theta=-46.156313 -> V=1.0, theta=0.0
% INFO    : Bus 28909	: V=0.9568531, theta=-46.779323 -> V=1.0, theta=0.0
% INFO    : Bus 28910	: V=0.9684399, theta=-45.264671 -> V=1.0, theta=0.0
% INFO    : Bus 28911	: V=0.9955663, theta=-42.446835 -> V=1.0, theta=0.0
% INFO    : Bus 28912	: V=0.968365, theta=-45.244225 -> V=1.0, theta=0.0
% INFO    : Bus 28913	: V=0.9699628, theta=-45.179296 -> V=1.0, theta=0.0
% INFO    : Bus 28914	: V=0.9904045, theta=-43.303364 -> V=1.0, theta=0.0
% INFO    : Bus 28915	: V=0.9850956, theta=-43.629348 -> V=1.0, theta=0.0
% INFO    : Bus 28916	: V=0.9868719, theta=-43.588119 -> V=1.0, theta=0.0
% INFO    : Bus 28917	: V=0.9802348, theta=-43.948348 -> V=1.0, theta=0.0
% INFO    : Bus 28918	: V=0.9930495, theta=-42.652139 -> V=1.0, theta=0.0
% INFO    : Bus 28919	: V=0.9893379, theta=-43.05175 -> V=1.0, theta=0.0
% INFO    : Bus 28920	: V=0.9864178, theta=-43.369119 -> V=1.0, theta=0.0
% INFO    : Bus 28921	: V=0.9811868, theta=-44.059808 -> V=1.0, theta=0.0
% INFO    : Bus 28922	: V=0.9835115, theta=-43.856935 -> V=1.0, theta=0.0
% INFO    : Bus 28923	: V=0.9767162, theta=-44.214545 -> V=1.0, theta=0.0
% INFO    : Bus 28924	: V=0.9794259, theta=-44.213338 -> V=1.0, theta=0.0
% INFO    : Bus 28925	: V=0.977131, theta=-44.423672 -> V=1.0, theta=0.0
% INFO    : Bus 28926	: V=0.9841087, theta=-43.620232 -> V=1.0, theta=0.0
% INFO    : Bus 28927	: V=0.9781082, theta=-44.265339 -> V=1.0, theta=0.0
% INFO    : Bus 28928	: V=0.9768911, theta=-44.373359 -> V=1.0, theta=0.0
% INFO    : Bus 28929	: V=0.974629, theta=-44.656758 -> V=1.0, theta=0.0
% INFO    : Bus 28930	: V=0.9808922, theta=-43.93581 -> V=1.0, theta=0.0
% INFO    : Bus 28931	: V=0.9512021, theta=-47.463699 -> V=1.0, theta=0.0
% INFO    : Bus 28932	: V=0.9582487, theta=-46.309261 -> V=1.0, theta=0.0
% INFO    : Bus 28933	: V=0.9722634, theta=-44.881023 -> V=1.0, theta=0.0
% INFO    : Bus 28934	: V=0.9581374, theta=-46.460695 -> V=1.0, theta=0.0
% INFO    : Bus 28935	: V=0.959866, theta=-46.368028 -> V=1.0, theta=0.0
% INFO    : Bus 28936	: V=0.97198, theta=-44.931199 -> V=1.0, theta=0.0
% INFO    : Bus 28937	: V=0.9744718, theta=-44.645649 -> V=1.0, theta=0.0
% INFO    : Bus 28938	: V=0.9603289, theta=-46.358891 -> V=1.0, theta=0.0
% INFO    : Bus 28939	: V=0.9742082, theta=-44.733052 -> V=1.0, theta=0.0
% INFO    : Bus 28940	: V=0.9754558, theta=-44.598101 -> V=1.0, theta=0.0
% INFO    : Bus 28941	: V=0.9721951, theta=-45.086642 -> V=1.0, theta=0.0
% INFO    : Bus 28942	: V=0.9695742, theta=-45.381384 -> V=1.0, theta=0.0
% INFO    : Bus 28943	: V=0.9688468, theta=-45.47145 -> V=1.0, theta=0.0
% INFO    : Bus 28944	: V=0.9701757, theta=-45.327027 -> V=1.0, theta=0.0
% INFO    : Bus 28945	: V=0.9682464, theta=-45.542895 -> V=1.0, theta=0.0
% INFO    : Bus 28946	: V=0.9668981, theta=-45.693323 -> V=1.0, theta=0.0
% INFO    : Bus 28947	: V=0.9680185, theta=-45.558823 -> V=1.0, theta=0.0
% INFO    : Bus 28948	: V=0.9663155, theta=-45.721816 -> V=1.0, theta=0.0
% INFO    : Bus 28949	: V=0.9673322, theta=-45.61556 -> V=1.0, theta=0.0
% INFO    : Bus 28950	: V=0.9560177, theta=-46.799919 -> V=1.0, theta=0.0
% INFO    : Bus 28951	: V=0.9659025, theta=-45.884967 -> V=1.0, theta=0.0
% INFO    : Bus 28952	: V=0.9553041, theta=-46.890266 -> V=1.0, theta=0.0
% INFO    : Bus 28953	: V=0.9565373, theta=-46.773005 -> V=1.0, theta=0.0
% INFO    : Bus 28954	: V=0.9567631, theta=-46.79022 -> V=1.0, theta=0.0
% INFO    : Bus 28955	: V=0.9527087, theta=-46.984447 -> V=1.0, theta=0.0
% INFO    : Bus 28956	: V=0.9654399, theta=-46.040916 -> V=1.0, theta=0.0
% INFO    : Bus 28957	: V=0.9652823, theta=-46.184594 -> V=1.0, theta=0.0
% INFO    : Bus 28958	: V=0.9567744, theta=-46.789591 -> V=1.0, theta=0.0
% INFO    : Bus 28959	: V=0.9659962, theta=-45.705467 -> V=1.0, theta=0.0
% INFO    : Bus 28960	: V=0.9630663, theta=-45.140461 -> V=1.0, theta=0.0
% INFO    : Bus 28961	: V=0.9727156, theta=-44.692892 -> V=1.0, theta=0.0
% INFO    : Bus 28962	: V=1.0147663, theta=-42.169491 -> V=1.0, theta=0.0
% INFO    : Bus 28963	: V=1.0119387, theta=-40.230883 -> V=1.0, theta=0.0
% INFO    : Bus 28964	: V=0.966435, theta=-57.878824 -> V=1.0, theta=0.0
% INFO    : Bus 28965	: V=0.9798809, theta=-56.191578 -> V=1.0, theta=0.0
% INFO    : Bus 28966	: V=0.9695052, theta=-57.464275 -> V=1.0, theta=0.0
% INFO    : Bus 28967	: V=0.9688194, theta=-57.468691 -> V=1.0, theta=0.0
% INFO    : Bus 28968	: V=0.9708028, theta=-56.972358 -> V=1.0, theta=0.0
% INFO    : Bus 28969	: V=0.9716278, theta=-56.958817 -> V=1.0, theta=0.0
% INFO    : Bus 28970	: V=0.9706646, theta=-56.962593 -> V=1.0, theta=0.0
% INFO    : Bus 28971	: V=0.9780483, theta=-56.564149 -> V=1.0, theta=0.0
% INFO    : Bus 28972	: V=0.9759744, theta=-56.587366 -> V=1.0, theta=0.0
% INFO    : Bus 28973	: V=0.9798407, theta=-56.435627 -> V=1.0, theta=0.0
% INFO    : Bus 28974	: V=0.9828573, theta=-55.87625 -> V=1.0, theta=0.0
% INFO    : Bus 28975	: V=0.9826964, theta=-56.046661 -> V=1.0, theta=0.0
% INFO    : Bus 28976	: V=0.9916179, theta=-55.300499 -> V=1.0, theta=0.0
% INFO    : Bus 28977	: V=0.9946708, theta=-55.043735 -> V=1.0, theta=0.0
% INFO    : Bus 28978	: V=0.9789616, theta=-56.587147 -> V=1.0, theta=0.0
% INFO    : Bus 28979	: V=1.0037505, theta=-54.154825 -> V=1.0, theta=0.0
% INFO    : Bus 28980	: V=0.9765158, theta=-56.814558 -> V=1.0, theta=0.0
% INFO    : Bus 28981	: V=0.9765595, theta=-56.729836 -> V=1.0, theta=0.0
% INFO    : Bus 28982	: V=0.9856754, theta=-55.775767 -> V=1.0, theta=0.0
% INFO    : Bus 28983	: V=0.9852526, theta=-55.82479 -> V=1.0, theta=0.0
% INFO    : Bus 28984	: V=0.9729341, theta=-56.932608 -> V=1.0, theta=0.0
% INFO    : Bus 28985	: V=0.971775, theta=-56.976879 -> V=1.0, theta=0.0
% INFO    : Bus 28986	: V=0.9823297, theta=-56.047815 -> V=1.0, theta=0.0
% INFO    : Bus 28987	: V=0.9617457, theta=-58.345449 -> V=1.0, theta=0.0
% INFO    : Bus 28988	: V=0.9607068, theta=-58.613947 -> V=1.0, theta=0.0
% INFO    : Bus 28989	: V=0.9595849, theta=-58.68699 -> V=1.0, theta=0.0
% INFO    : Bus 28990	: V=0.9756844, theta=-56.506346 -> V=1.0, theta=0.0
% INFO    : Bus 28991	: V=0.9529421, theta=-57.869344 -> V=1.0, theta=0.0
% INFO    : Bus 28992	: V=0.9448324, theta=-59.962819 -> V=1.0, theta=0.0
% INFO    : Bus 28993	: V=0.9553827, theta=-59.080432 -> V=1.0, theta=0.0
% INFO    : Bus 28994	: V=0.9586432, theta=-58.893312 -> V=1.0, theta=0.0
% INFO    : Bus 28995	: V=0.9564186, theta=-59.05243 -> V=1.0, theta=0.0
% INFO    : Bus 28996	: V=0.9473256, theta=-59.906019 -> V=1.0, theta=0.0
% INFO    : Bus 28997	: V=0.9506795, theta=-59.612445 -> V=1.0, theta=0.0
% INFO    : Bus 28998	: V=0.9580519, theta=-58.80801 -> V=1.0, theta=0.0
% INFO    : Bus 28999	: V=0.9486896, theta=-59.75847 -> V=1.0, theta=0.0
% INFO    : Bus 29000	: V=0.958908, theta=-58.706564 -> V=1.0, theta=0.0
% INFO    : Bus 29001	: V=0.9582597, theta=-58.780841 -> V=1.0, theta=0.0
% INFO    : Bus 29002	: V=0.9604032, theta=-58.365025 -> V=1.0, theta=0.0
% INFO    : Bus 29003	: V=0.9572556, theta=-58.840856 -> V=1.0, theta=0.0
% INFO    : Bus 29004	: V=0.9601191, theta=-58.553341 -> V=1.0, theta=0.0
% INFO    : Bus 29005	: V=0.961526, theta=-58.367873 -> V=1.0, theta=0.0
% INFO    : Bus 29006	: V=0.9600903, theta=-58.331928 -> V=1.0, theta=0.0
% INFO    : Bus 29007	: V=0.9694742, theta=-57.278925 -> V=1.0, theta=0.0
% INFO    : Bus 29008	: V=0.9786268, theta=-56.341874 -> V=1.0, theta=0.0
% INFO    : Bus 29009	: V=0.9665, theta=-57.524635 -> V=1.0, theta=0.0
% INFO    : Bus 29010	: V=0.976329, theta=-56.449586 -> V=1.0, theta=0.0
% INFO    : Bus 29011	: V=0.9602425, theta=-58.093909 -> V=1.0, theta=0.0
% INFO    : Bus 29012	: V=0.9604884, theta=-58.132095 -> V=1.0, theta=0.0
% INFO    : Bus 29013	: V=0.9597849, theta=-58.139475 -> V=1.0, theta=0.0
% INFO    : Bus 29014	: V=0.9625945, theta=-57.914769 -> V=1.0, theta=0.0
% INFO    : Bus 29015	: V=0.9800101, theta=-56.106086 -> V=1.0, theta=0.0
% INFO    : Bus 29016	: V=0.998528, theta=-54.596078 -> V=1.0, theta=0.0
% INFO    : Bus 29017	: V=1.0014508, theta=-54.522909 -> V=1.0, theta=0.0
% INFO    : Bus 29018	: V=0.9976975, theta=-54.790376 -> V=1.0, theta=0.0
% INFO    : Bus 29019	: V=0.9844053, theta=-55.86065 -> V=1.0, theta=0.0
% INFO    : Bus 29020	: V=0.9887075, theta=-55.607425 -> V=1.0, theta=0.0
% INFO    : Bus 29021	: V=0.9854658, theta=-55.8868 -> V=1.0, theta=0.0
% INFO    : Bus 29022	: V=0.9722025, theta=-56.657222 -> V=1.0, theta=0.0
% INFO    : Bus 29023	: V=0.9963968, theta=-54.994403 -> V=1.0, theta=0.0
% INFO    : Bus 29024	: V=1.003109, theta=-54.388218 -> V=1.0, theta=0.0
% INFO    : Bus 29025	: V=1.0001263, theta=-54.483583 -> V=1.0, theta=0.0
% INFO    : Bus 29026	: V=0.9967181, theta=-54.993278 -> V=1.0, theta=0.0
% INFO    : Bus 29027	: V=0.995455, theta=-55.152761 -> V=1.0, theta=0.0
% INFO    : Bus 29028	: V=0.9974162, theta=-55.19965 -> V=1.0, theta=0.0
% INFO    : Bus 29029	: V=0.9848865, theta=-55.983021 -> V=1.0, theta=0.0
% INFO    : Bus 29030	: V=0.999367, theta=-54.467027 -> V=1.0, theta=0.0
% INFO    : Bus 29031	: V=1.0018669, theta=-55.069902 -> V=1.0, theta=0.0
% INFO    : Bus 29032	: V=0.9546201, theta=-55.056514 -> V=1.0, theta=0.0
% INFO    : Bus 29033	: V=0.9577042, theta=-55.391089 -> V=1.0, theta=0.0
% INFO    : Bus 29034	: V=0.9600373, theta=-57.44014 -> V=1.0, theta=0.0
% INFO    : Bus 29035	: V=0.9619179, theta=-49.14888 -> V=1.0, theta=0.0
% INFO    : Bus 29036	: V=0.9618593, theta=-49.024345 -> V=1.0, theta=0.0
% INFO    : Bus 29037	: V=0.9616543, theta=-49.137539 -> V=1.0, theta=0.0
% INFO    : Bus 29038	: V=0.9616832, theta=-49.099618 -> V=1.0, theta=0.0
% INFO    : Bus 29039	: V=0.9617389, theta=-49.153964 -> V=1.0, theta=0.0
% INFO    : Bus 29040	: V=0.9622873, theta=-48.981748 -> V=1.0, theta=0.0
% INFO    : Bus 29041	: V=0.9611105, theta=-49.211098 -> V=1.0, theta=0.0
% INFO    : Bus 29042	: V=0.9854239, theta=-46.299319 -> V=1.0, theta=0.0
% INFO    : Bus 29043	: V=0.9501046, theta=-50.811035 -> V=1.0, theta=0.0
% INFO    : Bus 29044	: V=0.9532149, theta=-50.460025 -> V=1.0, theta=0.0
% INFO    : Bus 29045	: V=0.9567225, theta=-49.971206 -> V=1.0, theta=0.0
% INFO    : Bus 29046	: V=0.9580196, theta=-49.765536 -> V=1.0, theta=0.0
% INFO    : Bus 29047	: V=0.9606793, theta=-49.288945 -> V=1.0, theta=0.0
% INFO    : Bus 29048	: V=0.9567473, theta=-49.875591 -> V=1.0, theta=0.0
% INFO    : Bus 29049	: V=0.9600239, theta=-49.365926 -> V=1.0, theta=0.0
% INFO    : Bus 29050	: V=0.9607439, theta=-49.304844 -> V=1.0, theta=0.0
% INFO    : Bus 29051	: V=0.9628703, theta=-49.084443 -> V=1.0, theta=0.0
% INFO    : Bus 29052	: V=0.9617408, theta=-49.150935 -> V=1.0, theta=0.0
% INFO    : Bus 29053	: V=0.9623846, theta=-49.122039 -> V=1.0, theta=0.0
% INFO    : Bus 29054	: V=0.9588294, theta=-49.816272 -> V=1.0, theta=0.0
% INFO    : Bus 29055	: V=0.9661044, theta=-53.617989 -> V=1.0, theta=0.0
% INFO    : Bus 29056	: V=0.9514014, theta=-55.406498 -> V=1.0, theta=0.0
% INFO    : Bus 29057	: V=0.9327981, theta=-57.312081 -> V=1.0, theta=0.0
% INFO    : Bus 29058	: V=0.9292072, theta=-57.570821 -> V=1.0, theta=0.0
% INFO    : Bus 29059	: V=0.9786387, theta=-50.296473 -> V=1.0, theta=0.0
% INFO    : Bus 29060	: V=0.9784149, theta=-50.385954 -> V=1.0, theta=0.0
% INFO    : Bus 29061	: V=0.9739607, theta=-51.083186 -> V=1.0, theta=0.0
% INFO    : Bus 29062	: V=0.9972795, theta=-50.582299 -> V=1.0, theta=0.0
% INFO    : Bus 29063	: V=0.9715891, theta=-51.446723 -> V=1.0, theta=0.0
% INFO    : Bus 29064	: V=0.9786558, theta=-50.492934 -> V=1.0, theta=0.0
% INFO    : Bus 29065	: V=0.9744677, theta=-51.424378 -> V=1.0, theta=0.0
% INFO    : Bus 29066	: V=0.9759629, theta=-50.751116 -> V=1.0, theta=0.0
% INFO    : Bus 29067	: V=0.9906085, theta=-50.292874 -> V=1.0, theta=0.0
% INFO    : Bus 29068	: V=0.9916772, theta=-49.87957 -> V=1.0, theta=0.0
% INFO    : Bus 29069	: V=0.9965221, theta=-50.376521 -> V=1.0, theta=0.0
% INFO    : Bus 29070	: V=0.9959231, theta=-48.246448 -> V=1.0, theta=0.0
% INFO    : Bus 29071	: V=0.9992374, theta=-49.649715 -> V=1.0, theta=0.0
% INFO    : Bus 29072	: V=1.0014597, theta=-49.454521 -> V=1.0, theta=0.0
% INFO    : Bus 29073	: V=0.9702357, theta=-36.258856 -> V=1.0, theta=0.0
% INFO    : Bus 29074	: V=0.9719373, theta=-45.337783 -> V=1.0, theta=0.0
% INFO    : Bus 29075	: V=0.9455135, theta=-44.683398 -> V=1.0, theta=0.0
% INFO    : Bus 29076	: V=0.9421447, theta=-53.141095 -> V=1.0, theta=0.0
% INFO    : Bus 29077	: V=0.9461691, theta=-55.604008 -> V=1.0, theta=0.0
% INFO    : Bus 29078	: V=0.9406853, theta=-56.831954 -> V=1.0, theta=0.0
% INFO    : Bus 29079	: V=0.9964957, theta=-53.048442 -> V=1.0, theta=0.0
% INFO    : Bus 29080	: V=1.0062196, theta=-52.608557 -> V=1.0, theta=0.0
% INFO    : Bus 29081	: V=1.0007145, theta=-52.468121 -> V=1.0, theta=0.0
% INFO    : Bus 29082	: V=1.0014058, theta=-45.064407 -> V=1.0, theta=0.0
% INFO    : Bus 29083	: V=0.9990629, theta=-45.274705 -> V=1.0, theta=0.0
% INFO    : Bus 29084	: V=1.0105893, theta=-44.305045 -> V=1.0, theta=0.0
% INFO    : Bus 29085	: V=1.0193365, theta=-43.778527 -> V=1.0, theta=0.0
% INFO    : Bus 29086	: V=1.0183497, theta=-42.923096 -> V=1.0, theta=0.0
% INFO    : Bus 29087	: V=1.0098289, theta=-44.407035 -> V=1.0, theta=0.0
% INFO    : Bus 29088	: V=1.0066584, theta=-36.377914 -> V=1.0, theta=0.0
% INFO    : Bus 29089	: V=0.9958701, theta=-36.420704 -> V=1.0, theta=0.0
% INFO    : Bus 29090	: V=0.9595684, theta=-44.502181 -> V=1.0, theta=0.0
% INFO    : Bus 29091	: V=0.9714482, theta=-46.249758 -> V=1.0, theta=0.0
% INFO    : Bus 29092	: V=0.9665169, theta=-45.882895 -> V=1.0, theta=0.0
% INFO    : Bus 29093	: V=0.9893804, theta=-37.974446 -> V=1.0, theta=0.0
% INFO    : Bus 29094	: V=0.9759374, theta=-51.108979 -> V=1.0, theta=0.0
% INFO    : Bus 29095	: V=0.9790126, theta=-51.087955 -> V=1.0, theta=0.0
% INFO    : Bus 29096	: V=0.9811954, theta=-50.756904 -> V=1.0, theta=0.0
% INFO    : Bus 29097	: V=0.979911, theta=-50.952473 -> V=1.0, theta=0.0
% INFO    : Bus 29098	: V=0.9800255, theta=-51.068498 -> V=1.0, theta=0.0
% INFO    : Bus 29099	: V=0.9688635, theta=-52.059056 -> V=1.0, theta=0.0
% INFO    : Bus 29100	: V=0.9840004, theta=-50.926113 -> V=1.0, theta=0.0
% INFO    : Bus 29101	: V=0.9750955, theta=-51.989763 -> V=1.0, theta=0.0
% INFO    : Bus 29102	: V=0.9863272, theta=-50.829729 -> V=1.0, theta=0.0
% INFO    : Bus 29103	: V=0.9987423, theta=-50.327393 -> V=1.0, theta=0.0
% INFO    : Bus 29104	: V=0.9907617, theta=-50.138765 -> V=1.0, theta=0.0
% INFO    : Bus 29105	: V=0.9958275, theta=-49.887388 -> V=1.0, theta=0.0
% INFO    : Bus 29106	: V=0.9938829, theta=-50.282262 -> V=1.0, theta=0.0
% INFO    : Bus 29107	: V=0.9972284, theta=-50.180856 -> V=1.0, theta=0.0
% INFO    : Bus 29108	: V=0.9977675, theta=-50.213116 -> V=1.0, theta=0.0
% INFO    : Bus 29109	: V=0.9942794, theta=-50.563435 -> V=1.0, theta=0.0
% INFO    : Bus 29110	: V=0.9944134, theta=-50.942453 -> V=1.0, theta=0.0
% INFO    : Bus 29111	: V=0.9842719, theta=-51.876696 -> V=1.0, theta=0.0
% INFO    : Bus 29112	: V=0.9844269, theta=-51.887785 -> V=1.0, theta=0.0
% INFO    : Bus 29113	: V=0.9932153, theta=-50.908805 -> V=1.0, theta=0.0
% INFO    : Bus 29114	: V=0.9933431, theta=-50.84335 -> V=1.0, theta=0.0
% INFO    : Bus 29115	: V=0.9938857, theta=-50.717083 -> V=1.0, theta=0.0
% INFO    : Bus 29116	: V=0.9807116, theta=-51.784826 -> V=1.0, theta=0.0
% INFO    : Bus 29117	: V=0.9893146, theta=-51.055573 -> V=1.0, theta=0.0
% INFO    : Bus 29118	: V=0.9941289, theta=-50.697307 -> V=1.0, theta=0.0
% INFO    : Bus 29119	: V=0.9937125, theta=-50.79381 -> V=1.0, theta=0.0
% INFO    : Bus 29120	: V=0.9941636, theta=-50.669097 -> V=1.0, theta=0.0
% INFO    : Bus 29121	: V=0.9935453, theta=-50.874706 -> V=1.0, theta=0.0
% INFO    : Bus 29122	: V=0.9936031, theta=-50.960446 -> V=1.0, theta=0.0
% INFO    : Bus 29123	: V=0.9942824, theta=-50.941698 -> V=1.0, theta=0.0
% INFO    : Bus 29124	: V=0.9935023, theta=-50.935085 -> V=1.0, theta=0.0
% INFO    : Bus 29125	: V=0.9936132, theta=-50.91586 -> V=1.0, theta=0.0
% INFO    : Bus 29126	: V=0.9933513, theta=-50.897644 -> V=1.0, theta=0.0
% INFO    : Bus 29127	: V=0.9929129, theta=-50.975348 -> V=1.0, theta=0.0
% INFO    : Bus 29128	: V=0.9929995, theta=-51.001244 -> V=1.0, theta=0.0
% INFO    : Bus 29129	: V=0.9928174, theta=-51.114742 -> V=1.0, theta=0.0
% INFO    : Bus 29130	: V=0.9928743, theta=-51.083385 -> V=1.0, theta=0.0
% INFO    : Bus 29131	: V=0.9912459, theta=-51.206186 -> V=1.0, theta=0.0
% INFO    : Bus 29132	: V=0.9911086, theta=-51.206745 -> V=1.0, theta=0.0
% INFO    : Bus 29133	: V=0.9928587, theta=-51.13317 -> V=1.0, theta=0.0
% INFO    : Bus 29134	: V=0.9953591, theta=-50.906475 -> V=1.0, theta=0.0
% INFO    : Bus 29135	: V=0.9807212, theta=-51.772286 -> V=1.0, theta=0.0
% INFO    : Bus 29136	: V=0.9916877, theta=-51.050512 -> V=1.0, theta=0.0
% INFO    : Bus 29137	: V=0.9932034, theta=-50.031429 -> V=1.0, theta=0.0
% INFO    : Bus 29138	: V=0.9600539, theta=-48.101885 -> V=1.0, theta=0.0
% INFO    : Bus 29139	: V=1.0079957, theta=-45.606263 -> V=1.0, theta=0.0
% INFO    : Bus 29140	: V=0.9658318, theta=-48.339728 -> V=1.0, theta=0.0
% INFO    : Bus 29141	: V=0.9650471, theta=-48.429944 -> V=1.0, theta=0.0
% INFO    : Bus 29142	: V=0.9829711, theta=-46.666939 -> V=1.0, theta=0.0
% INFO    : Bus 29143	: V=0.9841961, theta=-46.5908 -> V=1.0, theta=0.0
% INFO    : Bus 29144	: V=0.9691595, theta=-48.164026 -> V=1.0, theta=0.0
% INFO    : Bus 29145	: V=0.9622427, theta=-48.754078 -> V=1.0, theta=0.0
% INFO    : Bus 29146	: V=0.9638311, theta=-48.649716 -> V=1.0, theta=0.0
% INFO    : Bus 29147	: V=0.9834081, theta=-46.561351 -> V=1.0, theta=0.0
% INFO    : Bus 29148	: V=0.9620941, theta=-48.736989 -> V=1.0, theta=0.0
% INFO    : Bus 29149	: V=0.9576526, theta=-49.049797 -> V=1.0, theta=0.0
% INFO    : Bus 29150	: V=0.9567539, theta=-48.84356 -> V=1.0, theta=0.0
% INFO    : Bus 29151	: V=0.9611509, theta=-49.880195 -> V=1.0, theta=0.0
% INFO    : Bus 29152	: V=0.9567074, theta=-49.084792 -> V=1.0, theta=0.0
% INFO    : Bus 29153	: V=0.9718213, theta=-46.552193 -> V=1.0, theta=0.0
% INFO    : Bus 29154	: V=0.9617875, theta=-48.956901 -> V=1.0, theta=0.0
% INFO    : Bus 29155	: V=0.9583436, theta=-49.139307 -> V=1.0, theta=0.0
% INFO    : Bus 29156	: V=0.9527316, theta=-49.160312 -> V=1.0, theta=0.0
% INFO    : Bus 29157	: V=0.9714563, theta=-42.744722 -> V=1.0, theta=0.0
% INFO    : Bus 29158	: V=0.9612379, theta=-46.031965 -> V=1.0, theta=0.0
% INFO    : Bus 29159	: V=0.9568371, theta=-48.219282 -> V=1.0, theta=0.0
% INFO    : Bus 29160	: V=0.9682264, theta=-45.544071 -> V=1.0, theta=0.0
% INFO    : Bus 29161	: V=0.9696925, theta=-44.404611 -> V=1.0, theta=0.0
% INFO    : Bus 29162	: V=0.9624283, theta=-48.551927 -> V=1.0, theta=0.0
% INFO    : Bus 29163	: V=0.9676872, theta=-49.397581 -> V=1.0, theta=0.0
% INFO    : Bus 29164	: V=0.9717775, theta=-50.872209 -> V=1.0, theta=0.0
% INFO    : Bus 29165	: V=0.9846815, theta=-49.33555 -> V=1.0, theta=0.0
% INFO    : Bus 29166	: V=0.9678254, theta=-51.330001 -> V=1.0, theta=0.0
% INFO    : Bus 29167	: V=0.9662447, theta=-51.349244 -> V=1.0, theta=0.0
% INFO    : Bus 29168	: V=0.9676796, theta=-51.27425 -> V=1.0, theta=0.0
% INFO    : Bus 29169	: V=0.96836, theta=-51.357189 -> V=1.0, theta=0.0
% INFO    : Bus 29170	: V=0.9693687, theta=-51.34523 -> V=1.0, theta=0.0
% INFO    : Bus 29171	: V=0.9667682, theta=-51.704184 -> V=1.0, theta=0.0
% INFO    : Bus 29172	: V=0.9818184, theta=-50.363878 -> V=1.0, theta=0.0
% INFO    : Bus 29173	: V=0.9695984, theta=-51.371245 -> V=1.0, theta=0.0
% INFO    : Bus 29174	: V=0.9699752, theta=-51.334228 -> V=1.0, theta=0.0
% INFO    : Bus 29175	: V=0.986005, theta=-49.219552 -> V=1.0, theta=0.0
% INFO    : Bus 29176	: V=0.972204, theta=-50.85468 -> V=1.0, theta=0.0
% INFO    : Bus 29177	: V=0.9724946, theta=-50.834783 -> V=1.0, theta=0.0
% INFO    : Bus 29178	: V=0.9836401, theta=-50.076448 -> V=1.0, theta=0.0
% INFO    : Bus 29179	: V=0.9766635, theta=-50.564212 -> V=1.0, theta=0.0
% INFO    : Bus 29180	: V=0.9735756, theta=-51.085814 -> V=1.0, theta=0.0
% INFO    : Bus 29181	: V=0.9742048, theta=-51.080716 -> V=1.0, theta=0.0
% INFO    : Bus 29182	: V=0.9724197, theta=-51.204862 -> V=1.0, theta=0.0
% INFO    : Bus 29183	: V=0.9846612, theta=-50.111456 -> V=1.0, theta=0.0
% INFO    : Bus 29184	: V=0.9749064, theta=-51.139022 -> V=1.0, theta=0.0
% INFO    : Bus 29185	: V=0.9839875, theta=-50.100348 -> V=1.0, theta=0.0
% INFO    : Bus 29186	: V=0.9840613, theta=-50.057203 -> V=1.0, theta=0.0
% INFO    : Bus 29187	: V=0.9773947, theta=-50.531528 -> V=1.0, theta=0.0
% INFO    : Bus 29188	: V=0.9855177, theta=-49.780833 -> V=1.0, theta=0.0
% INFO    : Bus 29189	: V=0.9852651, theta=-49.840651 -> V=1.0, theta=0.0
% INFO    : Bus 29190	: V=0.9851132, theta=-49.890839 -> V=1.0, theta=0.0
% INFO    : Bus 29191	: V=0.9850202, theta=-49.937909 -> V=1.0, theta=0.0
% INFO    : Bus 29192	: V=0.985385, theta=-49.93069 -> V=1.0, theta=0.0
% INFO    : Bus 29193	: V=0.9859631, theta=-49.914765 -> V=1.0, theta=0.0
% INFO    : Bus 29194	: V=0.9887011, theta=-49.784018 -> V=1.0, theta=0.0
% INFO    : Bus 29195	: V=0.989067, theta=-49.791426 -> V=1.0, theta=0.0
% INFO    : Bus 29196	: V=0.988481, theta=-49.790342 -> V=1.0, theta=0.0
% INFO    : Bus 29197	: V=0.9890252, theta=-49.633478 -> V=1.0, theta=0.0
% INFO    : Bus 29198	: V=0.9908034, theta=-49.473402 -> V=1.0, theta=0.0
% INFO    : Bus 29199	: V=0.9913158, theta=-49.416475 -> V=1.0, theta=0.0
% INFO    : Bus 29200	: V=0.9837311, theta=-50.059462 -> V=1.0, theta=0.0
% INFO    : Bus 29201	: V=0.9920463, theta=-49.338887 -> V=1.0, theta=0.0
% INFO    : Bus 29202	: V=0.984087, theta=-50.062292 -> V=1.0, theta=0.0
% INFO    : Bus 29203	: V=0.9862127, theta=-49.662828 -> V=1.0, theta=0.0
% INFO    : Bus 29204	: V=0.9867968, theta=-49.572623 -> V=1.0, theta=0.0
% INFO    : Bus 29205	: V=0.9851088, theta=-49.574734 -> V=1.0, theta=0.0
% INFO    : Bus 29206	: V=0.9967681, theta=-48.403848 -> V=1.0, theta=0.0
% INFO    : Bus 29207	: V=0.9875351, theta=-49.465097 -> V=1.0, theta=0.0
% INFO    : Bus 29208	: V=0.9931099, theta=-49.239519 -> V=1.0, theta=0.0
% INFO    : Bus 29209	: V=0.9980266, theta=-48.566585 -> V=1.0, theta=0.0
% INFO    : Bus 29210	: V=0.9978307, theta=-48.657587 -> V=1.0, theta=0.0
% INFO    : Bus 29211	: V=0.9979257, theta=-48.647981 -> V=1.0, theta=0.0
% INFO    : Bus 29212	: V=0.9919532, theta=-49.371545 -> V=1.0, theta=0.0
% INFO    : Bus 29213	: V=0.9917783, theta=-49.380248 -> V=1.0, theta=0.0
% INFO    : Bus 29214	: V=0.98545, theta=-49.957929 -> V=1.0, theta=0.0
% INFO    : Bus 29215	: V=0.9980658, theta=-48.983606 -> V=1.0, theta=0.0
% INFO    : Bus 29216	: V=0.9926538, theta=-49.525433 -> V=1.0, theta=0.0
% INFO    : Bus 29217	: V=0.9845776, theta=-49.963152 -> V=1.0, theta=0.0
% INFO    : Bus 29218	: V=0.9930478, theta=-49.261372 -> V=1.0, theta=0.0
% INFO    : Bus 29219	: V=0.9931923, theta=-49.234981 -> V=1.0, theta=0.0
% INFO    : Bus 29220	: V=0.9937747, theta=-49.177817 -> V=1.0, theta=0.0
% INFO    : Bus 29221	: V=0.987036, theta=-49.760694 -> V=1.0, theta=0.0
% INFO    : Bus 29222	: V=0.9982109, theta=-48.481142 -> V=1.0, theta=0.0
% INFO    : Bus 29223	: V=1.0161951, theta=-46.232089 -> V=1.0, theta=0.0
% INFO    : Bus 29224	: V=0.9977875, theta=-48.734173 -> V=1.0, theta=0.0
% INFO    : Bus 29225	: V=0.9803586, theta=-50.594127 -> V=1.0, theta=0.0
% INFO    : Bus 29226	: V=0.985021, theta=-49.965648 -> V=1.0, theta=0.0
% INFO    : Bus 29227	: V=0.9983664, theta=-48.959439 -> V=1.0, theta=0.0
% INFO    : Bus 29228	: V=0.9920219, theta=-49.618019 -> V=1.0, theta=0.0
% INFO    : Bus 29229	: V=0.9963405, theta=-49.093259 -> V=1.0, theta=0.0
% INFO    : Bus 29230	: V=0.9795631, theta=-50.601445 -> V=1.0, theta=0.0
% INFO    : Bus 29231	: V=0.9961275, theta=-49.047863 -> V=1.0, theta=0.0
% INFO    : Bus 29232	: V=0.9959134, theta=-49.062178 -> V=1.0, theta=0.0
% INFO    : Bus 29233	: V=0.9957673, theta=-49.074572 -> V=1.0, theta=0.0
% INFO    : Bus 29234	: V=0.9934235, theta=-49.676809 -> V=1.0, theta=0.0
% INFO    : Bus 29235	: V=0.991488, theta=-49.883213 -> V=1.0, theta=0.0
% INFO    : Bus 29236	: V=1.0002985, theta=-49.5476 -> V=1.0, theta=0.0
% INFO    : Bus 29237	: V=0.9902901, theta=-49.899008 -> V=1.0, theta=0.0
% INFO    : Bus 29238	: V=0.998461, theta=-49.126909 -> V=1.0, theta=0.0
% INFO    : Bus 29239	: V=0.9927877, theta=-49.815468 -> V=1.0, theta=0.0
% INFO    : Bus 29240	: V=0.9982791, theta=-48.899878 -> V=1.0, theta=0.0
% INFO    : Bus 29241	: V=0.99332, theta=-49.773427 -> V=1.0, theta=0.0
% INFO    : Bus 29242	: V=0.9921669, theta=-49.897934 -> V=1.0, theta=0.0
% INFO    : Bus 29243	: V=0.993302, theta=-49.828545 -> V=1.0, theta=0.0
% INFO    : Bus 29244	: V=0.992776, theta=-49.969667 -> V=1.0, theta=0.0
% INFO    : Bus 29245	: V=0.9926826, theta=-49.95258 -> V=1.0, theta=0.0
% INFO    : Bus 29246	: V=1.0172803, theta=-49.605591 -> V=1.0, theta=0.0
% INFO    : Bus 29247	: V=1.0033173, theta=-47.787247 -> V=1.0, theta=0.0
% INFO    : Bus 29248	: V=0.9802556, theta=-49.83296 -> V=1.0, theta=0.0
% INFO    : Bus 29249	: V=0.9747289, theta=-49.575838 -> V=1.0, theta=0.0
% INFO    : Bus 29250	: V=0.9637179, theta=-49.975151 -> V=1.0, theta=0.0
% INFO    : Bus 29251	: V=0.9766311, theta=-49.331949 -> V=1.0, theta=0.0
% INFO    : Bus 29252	: V=0.9768794, theta=-49.695202 -> V=1.0, theta=0.0
% INFO    : Bus 29253	: V=0.9723321, theta=-50.598872 -> V=1.0, theta=0.0
% INFO    : Bus 29254	: V=0.97089, theta=-50.753077 -> V=1.0, theta=0.0
% INFO    : Bus 29255	: V=0.9614485, theta=-52.702014 -> V=1.0, theta=0.0
% INFO    : Bus 29256	: V=0.9594198, theta=-52.522971 -> V=1.0, theta=0.0
% INFO    : Bus 29257	: V=0.953433, theta=-53.18268 -> V=1.0, theta=0.0
% INFO    : Bus 29258	: V=0.9540589, theta=-52.972721 -> V=1.0, theta=0.0
% INFO    : Bus 29259	: V=0.9531519, theta=-53.146455 -> V=1.0, theta=0.0
% INFO    : Bus 29260	: V=0.9686932, theta=-50.564695 -> V=1.0, theta=0.0
% INFO    : Bus 29261	: V=0.952709, theta=-53.205725 -> V=1.0, theta=0.0
% INFO    : Bus 29262	: V=0.9699006, theta=-50.325474 -> V=1.0, theta=0.0
% INFO    : Bus 29263	: V=0.9715312, theta=-50.044852 -> V=1.0, theta=0.0
% INFO    : Bus 29264	: V=0.9743912, theta=-50.378872 -> V=1.0, theta=0.0
% INFO    : Bus 29265	: V=0.9769647, theta=-50.252247 -> V=1.0, theta=0.0
% INFO    : Bus 29266	: V=0.9785302, theta=-50.069123 -> V=1.0, theta=0.0
% INFO    : Bus 29267	: V=0.9871898, theta=-49.108655 -> V=1.0, theta=0.0
% INFO    : Bus 29268	: V=0.9869686, theta=-49.129603 -> V=1.0, theta=0.0
% INFO    : Bus 29269	: V=0.9757825, theta=-50.414753 -> V=1.0, theta=0.0
% INFO    : Bus 29270	: V=0.9698243, theta=-50.881359 -> V=1.0, theta=0.0
% INFO    : Bus 29271	: V=0.9604607, theta=-52.185913 -> V=1.0, theta=0.0
% INFO    : Bus 29272	: V=0.9684773, theta=-51.281699 -> V=1.0, theta=0.0
% INFO    : Bus 29273	: V=0.9597224, theta=-52.085229 -> V=1.0, theta=0.0
% INFO    : Bus 29274	: V=0.9591029, theta=-52.567081 -> V=1.0, theta=0.0
% INFO    : Bus 29275	: V=0.9587031, theta=-52.344278 -> V=1.0, theta=0.0
% INFO    : Bus 29276	: V=0.9601442, theta=-52.305304 -> V=1.0, theta=0.0
% INFO    : Bus 29277	: V=0.9590974, theta=-52.591593 -> V=1.0, theta=0.0
% INFO    : Bus 29278	: V=0.9574667, theta=-52.833172 -> V=1.0, theta=0.0
% INFO    : Bus 29279	: V=0.9694511, theta=-51.132459 -> V=1.0, theta=0.0
% INFO    : Bus 29280	: V=0.9605204, theta=-52.036615 -> V=1.0, theta=0.0
% INFO    : Bus 29281	: V=0.9690503, theta=-51.189858 -> V=1.0, theta=0.0
% INFO    : Bus 29282	: V=0.9536166, theta=-52.572871 -> V=1.0, theta=0.0
% INFO    : Bus 29283	: V=0.9541857, theta=-52.560697 -> V=1.0, theta=0.0
% INFO    : Bus 29284	: V=0.9710998, theta=-50.968658 -> V=1.0, theta=0.0
% INFO    : Bus 29285	: V=0.9559482, theta=-52.877547 -> V=1.0, theta=0.0
% INFO    : Bus 29286	: V=0.9501182, theta=-53.652092 -> V=1.0, theta=0.0
% INFO    : Bus 29287	: V=0.9515486, theta=-53.573825 -> V=1.0, theta=0.0
% INFO    : Bus 29288	: V=0.9539806, theta=-52.891848 -> V=1.0, theta=0.0
% INFO    : Bus 29289	: V=0.9517986, theta=-53.622798 -> V=1.0, theta=0.0
% INFO    : Bus 29290	: V=0.9558309, theta=-52.89506 -> V=1.0, theta=0.0
% INFO    : Bus 29291	: V=0.9539388, theta=-53.49551 -> V=1.0, theta=0.0
% INFO    : Bus 29292	: V=0.9526427, theta=-53.010173 -> V=1.0, theta=0.0
% INFO    : Bus 29293	: V=0.9551144, theta=-53.392715 -> V=1.0, theta=0.0
% INFO    : Bus 29294	: V=0.967263, theta=-50.933958 -> V=1.0, theta=0.0
% INFO    : Bus 29295	: V=0.9584575, theta=-52.434304 -> V=1.0, theta=0.0
% INFO    : Bus 29296	: V=0.9538025, theta=-53.417616 -> V=1.0, theta=0.0
% INFO    : Bus 29297	: V=0.956879, theta=-53.090725 -> V=1.0, theta=0.0
% INFO    : Bus 29298	: V=0.9663327, theta=-51.593045 -> V=1.0, theta=0.0
% INFO    : Bus 29299	: V=0.9574705, theta=-52.757551 -> V=1.0, theta=0.0
% INFO    : Bus 29300	: V=0.9552591, theta=-53.231568 -> V=1.0, theta=0.0
% INFO    : Bus 29301	: V=0.9588018, theta=-52.776182 -> V=1.0, theta=0.0
% INFO    : Bus 29302	: V=0.9681029, theta=-51.429703 -> V=1.0, theta=0.0
% INFO    : Bus 29303	: V=0.9593875, theta=-52.289385 -> V=1.0, theta=0.0
% INFO    : Bus 29304	: V=0.9575065, theta=-52.41185 -> V=1.0, theta=0.0
% INFO    : Bus 29305	: V=0.9593028, theta=-52.78246 -> V=1.0, theta=0.0
% INFO    : Bus 29306	: V=0.9610857, theta=-52.161082 -> V=1.0, theta=0.0
% INFO    : Bus 29307	: V=0.9629891, theta=-52.027401 -> V=1.0, theta=0.0
% INFO    : Bus 29308	: V=0.9609728, theta=-52.739314 -> V=1.0, theta=0.0
% INFO    : Bus 29309	: V=0.9622224, theta=-52.116847 -> V=1.0, theta=0.0
% INFO    : Bus 29310	: V=0.9622676, theta=-52.157568 -> V=1.0, theta=0.0
% INFO    : Bus 29311	: V=0.9589042, theta=-52.859699 -> V=1.0, theta=0.0
% INFO    : Bus 29312	: V=0.9632659, theta=-52.143506 -> V=1.0, theta=0.0
% INFO    : Bus 29313	: V=0.9652945, theta=-52.331278 -> V=1.0, theta=0.0
% INFO    : Bus 29314	: V=0.9640217, theta=-52.136258 -> V=1.0, theta=0.0
% INFO    : Bus 29315	: V=0.9666585, theta=-52.293953 -> V=1.0, theta=0.0
% INFO    : Bus 29316	: V=0.9667576, theta=-52.028137 -> V=1.0, theta=0.0
% INFO    : Bus 29317	: V=0.9750871, theta=-51.131715 -> V=1.0, theta=0.0
% INFO    : Bus 29318	: V=0.9778466, theta=-51.028098 -> V=1.0, theta=0.0
% INFO    : Bus 29319	: V=0.9791853, theta=-50.972123 -> V=1.0, theta=0.0
% INFO    : Bus 29320	: V=0.9597344, theta=-52.983998 -> V=1.0, theta=0.0
% INFO    : Bus 29321	: V=0.965168, theta=-52.459151 -> V=1.0, theta=0.0
% INFO    : Bus 29322	: V=0.9653957, theta=-52.390322 -> V=1.0, theta=0.0
% INFO    : Bus 29323	: V=0.9609901, theta=-53.203436 -> V=1.0, theta=0.0
% INFO    : Bus 29324	: V=0.9536627, theta=-53.517024 -> V=1.0, theta=0.0
% INFO    : Bus 29325	: V=0.9565407, theta=-52.886743 -> V=1.0, theta=0.0
% INFO    : Bus 29326	: V=0.9575983, theta=-53.048817 -> V=1.0, theta=0.0
% INFO    : Bus 29327	: V=0.9590159, theta=-52.94801 -> V=1.0, theta=0.0
% INFO    : Bus 29328	: V=0.9578383, theta=-52.984791 -> V=1.0, theta=0.0
% INFO    : Bus 29329	: V=0.9643017, theta=-53.211351 -> V=1.0, theta=0.0
% INFO    : Bus 29330	: V=0.9630005, theta=-52.960405 -> V=1.0, theta=0.0
% INFO    : Bus 29331	: V=0.9674636, theta=-52.072947 -> V=1.0, theta=0.0
% INFO    : Bus 29332	: V=0.9666011, theta=-52.309069 -> V=1.0, theta=0.0
% INFO    : Bus 29333	: V=0.9581664, theta=-53.228626 -> V=1.0, theta=0.0
% INFO    : Bus 29334	: V=0.9564132, theta=-53.263302 -> V=1.0, theta=0.0
% INFO    : Bus 29335	: V=0.9567662, theta=-53.05725 -> V=1.0, theta=0.0
% INFO    : Bus 29336	: V=0.9566301, theta=-53.104506 -> V=1.0, theta=0.0
% INFO    : Bus 29337	: V=0.9860081, theta=-50.238368 -> V=1.0, theta=0.0
% INFO    : Bus 29338	: V=1.0105793, theta=-46.796395 -> V=1.0, theta=0.0
% INFO    : Bus 29339	: V=0.9765567, theta=-51.371793 -> V=1.0, theta=0.0
% INFO    : Bus 29340	: V=0.9687107, theta=-52.167275 -> V=1.0, theta=0.0
% INFO    : Bus 29341	: V=0.9776684, theta=-51.240458 -> V=1.0, theta=0.0
% INFO    : Bus 29342	: V=0.9707107, theta=-51.892305 -> V=1.0, theta=0.0
% INFO    : Bus 29343	: V=0.9964318, theta=-48.931539 -> V=1.0, theta=0.0
% INFO    : Bus 29344	: V=0.9819486, theta=-50.776721 -> V=1.0, theta=0.0
% INFO    : Bus 29345	: V=0.9707272, theta=-51.914142 -> V=1.0, theta=0.0
% INFO    : Bus 29346	: V=0.9794599, theta=-51.052417 -> V=1.0, theta=0.0
% INFO    : Bus 29347	: V=0.9694904, theta=-52.05028 -> V=1.0, theta=0.0
% INFO    : Bus 29348	: V=0.9855912, theta=-50.59011 -> V=1.0, theta=0.0
% INFO    : Bus 29349	: V=0.9694628, theta=-52.033672 -> V=1.0, theta=0.0
% INFO    : Bus 29350	: V=0.9754819, theta=-51.532377 -> V=1.0, theta=0.0
% INFO    : Bus 29351	: V=0.9701678, theta=-52.18368 -> V=1.0, theta=0.0
% INFO    : Bus 29352	: V=0.9849149, theta=-50.787563 -> V=1.0, theta=0.0
% INFO    : Bus 29353	: V=0.9852864, theta=-50.234027 -> V=1.0, theta=0.0
% INFO    : Bus 29354	: V=0.9628172, theta=-52.120811 -> V=1.0, theta=0.0
% INFO    : Bus 29355	: V=0.9854483, theta=-50.229689 -> V=1.0, theta=0.0
% INFO    : Bus 29356	: V=0.9829662, theta=-50.308097 -> V=1.0, theta=0.0
% INFO    : Bus 29357	: V=0.9841362, theta=-50.240022 -> V=1.0, theta=0.0
% INFO    : Bus 29358	: V=0.9848957, theta=-50.209358 -> V=1.0, theta=0.0
% INFO    : Bus 29359	: V=0.9846898, theta=-50.153816 -> V=1.0, theta=0.0
% INFO    : Bus 29360	: V=0.9847568, theta=-50.184122 -> V=1.0, theta=0.0
% INFO    : Bus 29361	: V=0.991061, theta=-48.760821 -> V=1.0, theta=0.0
% INFO    : Bus 29362	: V=0.9898573, theta=-48.970777 -> V=1.0, theta=0.0
% INFO    : Bus 29363	: V=0.9792298, theta=-49.978287 -> V=1.0, theta=0.0
% INFO    : Bus 29364	: V=0.9679645, theta=-50.343626 -> V=1.0, theta=0.0
% INFO    : Bus 29365	: V=0.9623306, theta=-50.531587 -> V=1.0, theta=0.0
% INFO    : Bus 29366	: V=0.9632107, theta=-50.49056 -> V=1.0, theta=0.0
% INFO    : Bus 29367	: V=0.9645229, theta=-50.43465 -> V=1.0, theta=0.0
% INFO    : Bus 29368	: V=0.9707406, theta=-50.067666 -> V=1.0, theta=0.0
% INFO    : Bus 29369	: V=0.967337, theta=-50.160318 -> V=1.0, theta=0.0
% INFO    : Bus 29370	: V=0.9684889, theta=-50.056478 -> V=1.0, theta=0.0
% INFO    : Bus 29371	: V=0.970834, theta=-49.849002 -> V=1.0, theta=0.0
% INFO    : Bus 29372	: V=0.981879, theta=-48.565929 -> V=1.0, theta=0.0
% INFO    : Bus 29373	: V=0.9905849, theta=-48.515616 -> V=1.0, theta=0.0
% INFO    : Bus 29374	: V=0.9724603, theta=-49.844455 -> V=1.0, theta=0.0
% INFO    : Bus 29375	: V=0.98302, theta=-49.389628 -> V=1.0, theta=0.0
% INFO    : Bus 29376	: V=0.992245, theta=-48.057984 -> V=1.0, theta=0.0
% INFO    : Bus 29377	: V=0.9750141, theta=-49.641598 -> V=1.0, theta=0.0
% INFO    : Bus 29378	: V=0.9771845, theta=-49.470154 -> V=1.0, theta=0.0
% INFO    : Bus 29379	: V=0.9775495, theta=-49.097508 -> V=1.0, theta=0.0
% INFO    : Bus 29380	: V=0.9679241, theta=-49.874903 -> V=1.0, theta=0.0
% INFO    : Bus 29381	: V=0.9682061, theta=-49.665884 -> V=1.0, theta=0.0
% INFO    : Bus 29382	: V=0.9788555, theta=-48.883356 -> V=1.0, theta=0.0
% INFO    : Bus 29383	: V=0.9803463, theta=-48.764396 -> V=1.0, theta=0.0
% INFO    : Bus 29384	: V=0.9701136, theta=-49.660335 -> V=1.0, theta=0.0
% INFO    : Bus 29385	: V=0.9665057, theta=-49.78973 -> V=1.0, theta=0.0
% INFO    : Bus 29386	: V=0.9666761, theta=-49.86299 -> V=1.0, theta=0.0
% INFO    : Bus 29387	: V=0.9667962, theta=-49.873333 -> V=1.0, theta=0.0
% INFO    : Bus 29388	: V=0.9772978, theta=-49.071009 -> V=1.0, theta=0.0
% INFO    : Bus 29389	: V=0.9682124, theta=-49.67218 -> V=1.0, theta=0.0
% INFO    : Bus 29390	: V=0.9782273, theta=-48.910518 -> V=1.0, theta=0.0
% INFO    : Bus 29391	: V=0.972534, theta=-49.226236 -> V=1.0, theta=0.0
% INFO    : Bus 29392	: V=0.9840594, theta=-48.392682 -> V=1.0, theta=0.0
% INFO    : Bus 29393	: V=0.9889716, theta=-47.84249 -> V=1.0, theta=0.0
% INFO    : Bus 29394	: V=0.9912861, theta=-47.741611 -> V=1.0, theta=0.0
% INFO    : Bus 29395	: V=0.9768868, theta=-49.346718 -> V=1.0, theta=0.0
% INFO    : Bus 29396	: V=0.9748774, theta=-49.500445 -> V=1.0, theta=0.0
% INFO    : Bus 29397	: V=0.9851572, theta=-48.224567 -> V=1.0, theta=0.0
% INFO    : Bus 29398	: V=0.987226, theta=-48.008549 -> V=1.0, theta=0.0
% INFO    : Bus 29399	: V=0.9735426, theta=-49.394889 -> V=1.0, theta=0.0
% INFO    : Bus 29400	: V=0.9900943, theta=-47.690677 -> V=1.0, theta=0.0
% INFO    : Bus 29401	: V=0.9974342, theta=-47.239021 -> V=1.0, theta=0.0
% INFO    : Bus 29402	: V=0.9739054, theta=-49.72365 -> V=1.0, theta=0.0
% INFO    : Bus 29403	: V=0.9783736, theta=-49.354488 -> V=1.0, theta=0.0
% INFO    : Bus 29404	: V=0.9940586, theta=-47.741209 -> V=1.0, theta=0.0
% INFO    : Bus 29405	: V=0.9781843, theta=-49.315096 -> V=1.0, theta=0.0
% INFO    : Bus 29406	: V=0.9805973, theta=-49.168033 -> V=1.0, theta=0.0
% INFO    : Bus 29407	: V=0.9816857, theta=-49.10724 -> V=1.0, theta=0.0
% INFO    : Bus 29408	: V=0.9736066, theta=-50.013532 -> V=1.0, theta=0.0
% INFO    : Bus 29409	: V=0.9731408, theta=-49.852927 -> V=1.0, theta=0.0
% INFO    : Bus 29410	: V=0.9774908, theta=-49.524289 -> V=1.0, theta=0.0
% INFO    : Bus 29411	: V=0.9758711, theta=-49.536626 -> V=1.0, theta=0.0
% INFO    : Bus 29412	: V=0.9782687, theta=-49.446586 -> V=1.0, theta=0.0
% INFO    : Bus 29413	: V=0.9776701, theta=-49.416071 -> V=1.0, theta=0.0
% INFO    : Bus 29414	: V=0.9858374, theta=-48.157178 -> V=1.0, theta=0.0
% INFO    : Bus 29415	: V=0.9866068, theta=-48.108808 -> V=1.0, theta=0.0
% INFO    : Bus 29416	: V=0.9839862, theta=-48.584918 -> V=1.0, theta=0.0
% INFO    : Bus 29417	: V=0.9887656, theta=-47.938975 -> V=1.0, theta=0.0
% INFO    : Bus 29418	: V=0.9878381, theta=-47.889934 -> V=1.0, theta=0.0
% INFO    : Bus 29419	: V=0.9840001, theta=-48.630851 -> V=1.0, theta=0.0
% INFO    : Bus 29420	: V=0.9836988, theta=-48.613374 -> V=1.0, theta=0.0
% INFO    : Bus 29421	: V=0.9824834, theta=-48.612903 -> V=1.0, theta=0.0
% INFO    : Bus 29422	: V=0.983406, theta=-48.570695 -> V=1.0, theta=0.0
% INFO    : Bus 29423	: V=0.9986219, theta=-46.922283 -> V=1.0, theta=0.0
% INFO    : Bus 29424	: V=0.9880933, theta=-47.847354 -> V=1.0, theta=0.0
% INFO    : Bus 29425	: V=0.9952364, theta=-48.440167 -> V=1.0, theta=0.0
% INFO    : Bus 29426	: V=0.9770221, theta=-50.038065 -> V=1.0, theta=0.0
% INFO    : Bus 29427	: V=0.9757774, theta=-50.082045 -> V=1.0, theta=0.0
% INFO    : Bus 29428	: V=0.9756778, theta=-49.978511 -> V=1.0, theta=0.0
% INFO    : Bus 29429	: V=0.995709, theta=-48.254432 -> V=1.0, theta=0.0
% INFO    : Bus 29430	: V=1.0189026, theta=-45.582269 -> V=1.0, theta=0.0
% INFO    : Bus 29431	: V=0.9955077, theta=-47.912858 -> V=1.0, theta=0.0
% INFO    : Bus 29432	: V=0.9783496, theta=-49.561114 -> V=1.0, theta=0.0
% INFO    : Bus 29433	: V=0.9942904, theta=-47.904995 -> V=1.0, theta=0.0
% INFO    : Bus 29434	: V=1.0195849, theta=-45.279633 -> V=1.0, theta=0.0
% INFO    : Bus 29435	: V=0.9841299, theta=-48.829067 -> V=1.0, theta=0.0
% INFO    : Bus 29436	: V=1.0186242, theta=-44.308724 -> V=1.0, theta=0.0
% INFO    : Bus 29437	: V=1.0003437, theta=-47.257894 -> V=1.0, theta=0.0
% INFO    : Bus 29438	: V=0.9860126, theta=-48.670009 -> V=1.0, theta=0.0
% INFO    : Bus 29439	: V=0.9983277, theta=-47.395021 -> V=1.0, theta=0.0
% INFO    : Bus 29440	: V=1.0182518, theta=-43.795446 -> V=1.0, theta=0.0
% INFO    : Bus 29441	: V=0.9902365, theta=-47.154182 -> V=1.0, theta=0.0
% INFO    : Bus 29442	: V=0.993326, theta=-47.768182 -> V=1.0, theta=0.0
% INFO    : Bus 29443	: V=0.9872612, theta=-48.109358 -> V=1.0, theta=0.0
% INFO    : Bus 29444	: V=0.9974241, theta=-47.394731 -> V=1.0, theta=0.0
% INFO    : Bus 29445	: V=1.0012637, theta=-47.150801 -> V=1.0, theta=0.0
% INFO    : Bus 29446	: V=0.9963666, theta=-47.521725 -> V=1.0, theta=0.0
% INFO    : Bus 29447	: V=0.9961582, theta=-47.522271 -> V=1.0, theta=0.0
% INFO    : Bus 29448	: V=0.9954848, theta=-47.573485 -> V=1.0, theta=0.0
% INFO    : Bus 29449	: V=0.9925532, theta=-47.606071 -> V=1.0, theta=0.0
% INFO    : Bus 29450	: V=0.9916274, theta=-47.749161 -> V=1.0, theta=0.0
% INFO    : Bus 29451	: V=1.0175558, theta=-44.431734 -> V=1.0, theta=0.0
% INFO    : Bus 29452	: V=0.9931589, theta=-47.372461 -> V=1.0, theta=0.0
% INFO    : Bus 29453	: V=1.0033594, theta=-46.073754 -> V=1.0, theta=0.0
% INFO    : Bus 29454	: V=0.994404, theta=-47.291751 -> V=1.0, theta=0.0
% INFO    : Bus 29455	: V=0.9897621, theta=-48.603161 -> V=1.0, theta=0.0
% INFO    : Bus 29456	: V=1.0073455, theta=-46.60791 -> V=1.0, theta=0.0
% INFO    : Bus 29457	: V=1.0035643, theta=-47.111282 -> V=1.0, theta=0.0
% INFO    : Bus 29458	: V=1.0019946, theta=-47.171964 -> V=1.0, theta=0.0
% INFO    : Bus 29459	: V=0.988626, theta=-48.231618 -> V=1.0, theta=0.0
% INFO    : Bus 29460	: V=1.0015886, theta=-47.186151 -> V=1.0, theta=0.0
% INFO    : Bus 29461	: V=0.9897883, theta=-48.166075 -> V=1.0, theta=0.0
% INFO    : Bus 29462	: V=0.9922113, theta=-48.096088 -> V=1.0, theta=0.0
% INFO    : Bus 29463	: V=1.0001713, theta=-47.389102 -> V=1.0, theta=0.0
% INFO    : Bus 29464	: V=1.0011667, theta=-47.19696 -> V=1.0, theta=0.0
% INFO    : Bus 29465	: V=0.997052, theta=-47.536254 -> V=1.0, theta=0.0
% INFO    : Bus 29466	: V=1.0009397, theta=-47.196324 -> V=1.0, theta=0.0
% INFO    : Bus 29467	: V=0.9850254, theta=-48.988571 -> V=1.0, theta=0.0
% INFO    : Bus 29468	: V=1.0064564, theta=-46.991422 -> V=1.0, theta=0.0
% INFO    : Bus 29469	: V=1.0066905, theta=-46.793234 -> V=1.0, theta=0.0
% INFO    : Bus 29470	: V=1.0063637, theta=-46.782334 -> V=1.0, theta=0.0
% INFO    : Bus 29471	: V=1.006841, theta=-46.977208 -> V=1.0, theta=0.0
% INFO    : Bus 29472	: V=1.0059857, theta=-47.032534 -> V=1.0, theta=0.0
% INFO    : Bus 29473	: V=1.0051298, theta=-47.049915 -> V=1.0, theta=0.0
% INFO    : Bus 29474	: V=1.0049007, theta=-47.101224 -> V=1.0, theta=0.0
% INFO    : Bus 29475	: V=1.0025955, theta=-47.294573 -> V=1.0, theta=0.0
% INFO    : Bus 29476	: V=0.9540605, theta=-52.973352 -> V=1.0, theta=0.0
% INFO    : Bus 29477	: V=0.9533576, theta=-53.186042 -> V=1.0, theta=0.0
% INFO    : Bus 29478	: V=0.9845438, theta=-51.006381 -> V=1.0, theta=0.0
% INFO    : Bus 29479	: V=0.9994763, theta=-48.855308 -> V=1.0, theta=0.0
% INFO    : Bus 29480	: V=0.9567658, theta=-53.057496 -> V=1.0, theta=0.0
% INFO    : Bus 29481	: V=0.9575297, theta=-53.54443 -> V=1.0, theta=0.0
% INFO    : Bus 29482	: V=0.9601513, theta=-52.913615 -> V=1.0, theta=0.0
% INFO    : Bus 29483	: V=0.9575335, theta=-53.500245 -> V=1.0, theta=0.0
% INFO    : Bus 29484	: V=0.965387, theta=-52.370547 -> V=1.0, theta=0.0
% INFO    : Bus 29485	: V=0.9901532, theta=-34.95974 -> V=1.0, theta=0.0
% INFO    : Bus 29486	: V=1.0035688, theta=-33.559341 -> V=1.0, theta=0.0
% INFO    : Bus 29487	: V=0.9923398, theta=-35.066521 -> V=1.0, theta=0.0
% INFO    : Bus 29488	: V=1.0092001, theta=-32.800274 -> V=1.0, theta=0.0
% INFO    : Bus 29489	: V=0.9982495, theta=-34.316947 -> V=1.0, theta=0.0
% INFO    : Bus 29490	: V=1.0046537, theta=-33.471933 -> V=1.0, theta=0.0
% INFO    : Bus 29491	: V=0.9742105, theta=-37.926297 -> V=1.0, theta=0.0
% INFO    : Bus 29492	: V=0.9934415, theta=-34.695533 -> V=1.0, theta=0.0
% INFO    : Bus 29493	: V=0.9939259, theta=-34.836727 -> V=1.0, theta=0.0
% INFO    : Bus 29494	: V=0.9925433, theta=-34.987652 -> V=1.0, theta=0.0
% INFO    : Bus 29495	: V=1.003697, theta=-33.499049 -> V=1.0, theta=0.0
% INFO    : Bus 29496	: V=0.9979477, theta=-34.236827 -> V=1.0, theta=0.0
% INFO    : Bus 29497	: V=0.9980766, theta=-34.143548 -> V=1.0, theta=0.0
% INFO    : Bus 29498	: V=1.0029935, theta=-33.525864 -> V=1.0, theta=0.0
% INFO    : Bus 29499	: V=0.9973245, theta=-34.145698 -> V=1.0, theta=0.0
% INFO    : Bus 29500	: V=1.0023282, theta=-33.521792 -> V=1.0, theta=0.0
% INFO    : Bus 29501	: V=0.9884283, theta=-35.015959 -> V=1.0, theta=0.0
% INFO    : Bus 29502	: V=0.9909634, theta=-34.524784 -> V=1.0, theta=0.0
% INFO    : Bus 29503	: V=1.0056501, theta=-33.639409 -> V=1.0, theta=0.0
% INFO    : Bus 29504	: V=1.005002, theta=-33.837408 -> V=1.0, theta=0.0
% INFO    : Bus 29505	: V=0.9814799, theta=-37.47335 -> V=1.0, theta=0.0
% INFO    : Bus 29506	: V=0.9946661, theta=-35.481081 -> V=1.0, theta=0.0
% INFO    : Bus 29507	: V=0.9907041, theta=-36.316019 -> V=1.0, theta=0.0
% INFO    : Bus 29508	: V=0.9890192, theta=-36.688875 -> V=1.0, theta=0.0
% INFO    : Bus 29509	: V=0.9816373, theta=-37.542461 -> V=1.0, theta=0.0
% INFO    : Bus 29510	: V=0.9881558, theta=-37.002631 -> V=1.0, theta=0.0
% INFO    : Bus 29511	: V=1.006968, theta=-33.500598 -> V=1.0, theta=0.0
% INFO    : Bus 29512	: V=0.9836093, theta=-37.390726 -> V=1.0, theta=0.0
% INFO    : Bus 29513	: V=0.9852937, theta=-37.694424 -> V=1.0, theta=0.0
% INFO    : Bus 29514	: V=1.0097867, theta=-32.4675 -> V=1.0, theta=0.0
% INFO    : Bus 29515	: V=0.9891616, theta=-50.111318 -> V=1.0, theta=0.0
% INFO    : Bus 29516	: V=0.9809655, theta=-50.960634 -> V=1.0, theta=0.0
% INFO    : Bus 29517	: V=0.9797279, theta=-51.336559 -> V=1.0, theta=0.0
% INFO    : Bus 29518	: V=0.9571265, theta=-53.929439 -> V=1.0, theta=0.0
% INFO    : Bus 29519	: V=0.9578567, theta=-53.704693 -> V=1.0, theta=0.0
% INFO    : Bus 29520	: V=0.9746765, theta=-51.942947 -> V=1.0, theta=0.0
% INFO    : Bus 29521	: V=0.9642138, theta=-52.921097 -> V=1.0, theta=0.0
% INFO    : Bus 29522	: V=0.9703272, theta=-51.898358 -> V=1.0, theta=0.0
% INFO    : Bus 29523	: V=0.9942576, theta=-50.873521 -> V=1.0, theta=0.0
% INFO    : Bus 29524	: V=0.9834082, theta=-51.374848 -> V=1.0, theta=0.0
% INFO    : Bus 29525	: V=0.9576408, theta=-53.717923 -> V=1.0, theta=0.0
% INFO    : Bus 29526	: V=0.9718724, theta=-52.809777 -> V=1.0, theta=0.0
% INFO    : Bus 29527	: V=0.9816293, theta=-52.168874 -> V=1.0, theta=0.0
% INFO    : Bus 29528	: V=0.9939543, theta=-49.20909 -> V=1.0, theta=0.0
% INFO    : Bus 29529	: V=0.9996863, theta=-51.698068 -> V=1.0, theta=0.0
% INFO    : Bus 29530	: V=1.0034564, theta=-50.518598 -> V=1.0, theta=0.0
% INFO    : Bus 29531	: V=0.9888731, theta=-47.050501 -> V=1.0, theta=0.0
% INFO    : Bus 29532	: V=0.9882931, theta=-48.306754 -> V=1.0, theta=0.0
% INFO    : Bus 29533	: V=0.9871118, theta=-49.158596 -> V=1.0, theta=0.0
% INFO    : Bus 29534	: V=0.9952096, theta=-45.245967 -> V=1.0, theta=0.0
% INFO    : Bus 29535	: V=0.9888872, theta=-46.234077 -> V=1.0, theta=0.0
% INFO    : Bus 29536	: V=0.9626082, theta=-47.739509 -> V=1.0, theta=0.0
% INFO    : Bus 29537	: V=0.9718731, theta=-49.953843 -> V=1.0, theta=0.0
% INFO    : Bus 29538	: V=0.9686785, theta=-49.373108 -> V=1.0, theta=0.0
% INFO    : Bus 29539	: V=0.9655931, theta=-50.141873 -> V=1.0, theta=0.0
% INFO    : Bus 29540	: V=0.9859758, theta=-49.248729 -> V=1.0, theta=0.0
% INFO    : Bus 29541	: V=0.9680805, theta=-49.272073 -> V=1.0, theta=0.0
% INFO    : Bus 29542	: V=0.9613778, theta=-50.280265 -> V=1.0, theta=0.0
% INFO    : Bus 29543	: V=0.9585153, theta=-51.083008 -> V=1.0, theta=0.0
% INFO    : Bus 29544	: V=0.9665851, theta=-49.881587 -> V=1.0, theta=0.0
% INFO    : Bus 29545	: V=0.9662665, theta=-49.742902 -> V=1.0, theta=0.0
% INFO    : Bus 29546	: V=0.9650046, theta=-49.799469 -> V=1.0, theta=0.0
% INFO    : Bus 29547	: V=0.9640724, theta=-49.82789 -> V=1.0, theta=0.0
% INFO    : Bus 29548	: V=0.9584678, theta=-51.492564 -> V=1.0, theta=0.0
% INFO    : Bus 29549	: V=0.9584213, theta=-51.419165 -> V=1.0, theta=0.0
% INFO    : Bus 29550	: V=0.960114, theta=-51.326325 -> V=1.0, theta=0.0
% INFO    : Bus 29551	: V=0.9592554, theta=-51.419362 -> V=1.0, theta=0.0
% INFO    : Bus 29552	: V=0.9580733, theta=-51.441557 -> V=1.0, theta=0.0
% INFO    : Bus 29553	: V=0.9650605, theta=-50.431289 -> V=1.0, theta=0.0
% INFO    : Bus 29554	: V=0.9596566, theta=-51.310831 -> V=1.0, theta=0.0
% INFO    : Bus 29555	: V=0.9552098, theta=-51.905503 -> V=1.0, theta=0.0
% INFO    : Bus 29556	: V=0.9567301, theta=-51.751804 -> V=1.0, theta=0.0
% INFO    : Bus 29557	: V=0.9642435, theta=-51.039209 -> V=1.0, theta=0.0
% INFO    : Bus 29558	: V=0.9564784, theta=-51.706333 -> V=1.0, theta=0.0
% INFO    : Bus 29559	: V=0.9566889, theta=-51.550961 -> V=1.0, theta=0.0
% INFO    : Bus 29560	: V=0.9568272, theta=-51.528255 -> V=1.0, theta=0.0
% INFO    : Bus 29561	: V=0.95339, theta=-51.829192 -> V=1.0, theta=0.0
% INFO    : Bus 29562	: V=0.9552393, theta=-51.323832 -> V=1.0, theta=0.0
% INFO    : Bus 29563	: V=0.9563979, theta=-51.239935 -> V=1.0, theta=0.0
% INFO    : Bus 29564	: V=0.9564138, theta=-51.327621 -> V=1.0, theta=0.0
% INFO    : Bus 29565	: V=0.9633476, theta=-49.723244 -> V=1.0, theta=0.0
% INFO    : Bus 29566	: V=0.9556739, theta=-51.171186 -> V=1.0, theta=0.0
% INFO    : Bus 29567	: V=0.971607, theta=-47.719224 -> V=1.0, theta=0.0
% INFO    : Bus 29568	: V=0.9573846, theta=-50.892685 -> V=1.0, theta=0.0
% INFO    : Bus 29569	: V=0.9673705, theta=-49.095098 -> V=1.0, theta=0.0
% INFO    : Bus 29570	: V=0.9673797, theta=-48.852557 -> V=1.0, theta=0.0
% INFO    : Bus 29571	: V=0.9652512, theta=-49.107948 -> V=1.0, theta=0.0
% INFO    : Bus 29572	: V=0.9641625, theta=-51.039498 -> V=1.0, theta=0.0
% INFO    : Bus 29573	: V=0.9576553, theta=-51.384671 -> V=1.0, theta=0.0
% INFO    : Bus 29574	: V=0.9588934, theta=-51.16907 -> V=1.0, theta=0.0
% INFO    : Bus 29575	: V=0.9777074, theta=-49.836091 -> V=1.0, theta=0.0
% INFO    : Bus 29576	: V=0.96584, theta=-50.893354 -> V=1.0, theta=0.0
% INFO    : Bus 29577	: V=0.9655123, theta=-50.571248 -> V=1.0, theta=0.0
% INFO    : Bus 29578	: V=0.9539157, theta=-52.08555 -> V=1.0, theta=0.0
% INFO    : Bus 29579	: V=0.9616284, theta=-50.708054 -> V=1.0, theta=0.0
% INFO    : Bus 29580	: V=0.9754878, theta=-49.232705 -> V=1.0, theta=0.0
% INFO    : Bus 29581	: V=0.9565334, theta=-50.702282 -> V=1.0, theta=0.0
% INFO    : Bus 29582	: V=0.9647355, theta=-50.029296 -> V=1.0, theta=0.0
% INFO    : Bus 29583	: V=0.9573922, theta=-50.272648 -> V=1.0, theta=0.0
% INFO    : Bus 29584	: V=0.963595, theta=-50.45144 -> V=1.0, theta=0.0
% INFO    : Bus 29585	: V=0.9772163, theta=-49.059701 -> V=1.0, theta=0.0
% INFO    : Bus 29586	: V=0.9838744, theta=-48.466074 -> V=1.0, theta=0.0
% INFO    : Bus 29587	: V=0.9866226, theta=-50.254519 -> V=1.0, theta=0.0
% INFO    : Bus 29588	: V=0.9890427, theta=-50.054431 -> V=1.0, theta=0.0
% INFO    : Bus 29589	: V=1.018285, theta=-47.032641 -> V=1.0, theta=0.0
% INFO    : Bus 29590	: V=1.0042661, theta=-48.248073 -> V=1.0, theta=0.0
% INFO    : Bus 29591	: V=0.9813338, theta=-50.68022 -> V=1.0, theta=0.0
% INFO    : Bus 29592	: V=0.9883609, theta=-50.064377 -> V=1.0, theta=0.0
% INFO    : Bus 29593	: V=0.9809694, theta=-50.436121 -> V=1.0, theta=0.0
% INFO    : Bus 29594	: V=1.0166529, theta=-46.941638 -> V=1.0, theta=0.0
% INFO    : Bus 29595	: V=0.9811994, theta=-50.784193 -> V=1.0, theta=0.0
% INFO    : Bus 29596	: V=0.9665984, theta=-53.602488 -> V=1.0, theta=0.0
% INFO    : Bus 29597	: V=0.9737497, theta=-51.687833 -> V=1.0, theta=0.0
% INFO    : Bus 29598	: V=0.9750861, theta=-51.531296 -> V=1.0, theta=0.0
% INFO    : Bus 29599	: V=0.9791137, theta=-51.062615 -> V=1.0, theta=0.0
% INFO    : Bus 29600	: V=0.9774994, theta=-51.28476 -> V=1.0, theta=0.0
% INFO    : Bus 29601	: V=1.0178301, theta=-47.109628 -> V=1.0, theta=0.0
% INFO    : Bus 29602	: V=0.9904878, theta=-49.684426 -> V=1.0, theta=0.0
% INFO    : Bus 29603	: V=0.9757324, theta=-51.681906 -> V=1.0, theta=0.0
% INFO    : Bus 29604	: V=0.9694213, theta=-52.451861 -> V=1.0, theta=0.0
% INFO    : Bus 29605	: V=0.9685194, theta=-52.480957 -> V=1.0, theta=0.0
% INFO    : Bus 29606	: V=0.9653023, theta=-53.064955 -> V=1.0, theta=0.0
% INFO    : Bus 29607	: V=0.9746424, theta=-51.771542 -> V=1.0, theta=0.0
% INFO    : Bus 29608	: V=0.9754164, theta=-51.38435 -> V=1.0, theta=0.0
% INFO    : Bus 29609	: V=0.9724219, theta=-52.285429 -> V=1.0, theta=0.0
% INFO    : Bus 29610	: V=0.9635701, theta=-53.388746 -> V=1.0, theta=0.0
% INFO    : Bus 29611	: V=0.9712515, theta=-52.435712 -> V=1.0, theta=0.0
% INFO    : Bus 29612	: V=0.9628932, theta=-53.474789 -> V=1.0, theta=0.0
% INFO    : Bus 29613	: V=0.9605392, theta=-53.630034 -> V=1.0, theta=0.0
% INFO    : Bus 29614	: V=0.9613232, theta=-53.585023 -> V=1.0, theta=0.0
% INFO    : Bus 29615	: V=0.9638706, theta=-53.179168 -> V=1.0, theta=0.0
% INFO    : Bus 29616	: V=0.9622311, theta=-53.240591 -> V=1.0, theta=0.0
% INFO    : Bus 29617	: V=0.9524617, theta=-55.236182 -> V=1.0, theta=0.0
% INFO    : Bus 29618	: V=0.9666379, theta=-52.919186 -> V=1.0, theta=0.0
% INFO    : Bus 29619	: V=0.9467826, theta=-55.995477 -> V=1.0, theta=0.0
% INFO    : Bus 29620	: V=0.9486957, theta=-55.864778 -> V=1.0, theta=0.0
% INFO    : Bus 29621	: V=0.9505871, theta=-55.517136 -> V=1.0, theta=0.0
% INFO    : Bus 29622	: V=0.9496431, theta=-55.55678 -> V=1.0, theta=0.0
% INFO    : Bus 29623	: V=0.9501387, theta=-55.54204 -> V=1.0, theta=0.0
% INFO    : Bus 29624	: V=0.9514295, theta=-55.449737 -> V=1.0, theta=0.0
% INFO    : Bus 29625	: V=0.9503576, theta=-55.515031 -> V=1.0, theta=0.0
% INFO    : Bus 29626	: V=0.9486486, theta=-55.348174 -> V=1.0, theta=0.0
% INFO    : Bus 29627	: V=0.9750554, theta=-51.383905 -> V=1.0, theta=0.0
% INFO    : Bus 29628	: V=0.9572184, theta=-54.0877 -> V=1.0, theta=0.0
% INFO    : Bus 29629	: V=0.9631948, theta=-52.884134 -> V=1.0, theta=0.0
% INFO    : Bus 29630	: V=0.9601205, theta=-53.381004 -> V=1.0, theta=0.0
% INFO    : Bus 29631	: V=0.9657775, theta=-53.02616 -> V=1.0, theta=0.0
% INFO    : Bus 29632	: V=0.9717977, theta=-51.857244 -> V=1.0, theta=0.0
% INFO    : Bus 29633	: V=0.989152, theta=-49.815873 -> V=1.0, theta=0.0
% INFO    : Bus 29634	: V=0.9680421, theta=-52.267862 -> V=1.0, theta=0.0
% INFO    : Bus 29635	: V=0.9697944, theta=-52.137342 -> V=1.0, theta=0.0
% INFO    : Bus 29636	: V=0.9621303, theta=-53.369392 -> V=1.0, theta=0.0
% INFO    : Bus 29637	: V=0.9645869, theta=-52.929808 -> V=1.0, theta=0.0
% INFO    : Bus 29638	: V=0.9620649, theta=-53.43204 -> V=1.0, theta=0.0
% INFO    : Bus 29639	: V=0.972309, theta=-51.838438 -> V=1.0, theta=0.0
% INFO    : Bus 29640	: V=0.9566926, theta=-54.51336 -> V=1.0, theta=0.0
% INFO    : Bus 29641	: V=0.9578181, theta=-54.414048 -> V=1.0, theta=0.0
% INFO    : Bus 29642	: V=0.950127, theta=-55.072783 -> V=1.0, theta=0.0
% INFO    : Bus 29643	: V=0.952123, theta=-54.940309 -> V=1.0, theta=0.0
% INFO    : Bus 29644	: V=0.9537231, theta=-54.802096 -> V=1.0, theta=0.0
% INFO    : Bus 29645	: V=0.9511372, theta=-55.251649 -> V=1.0, theta=0.0
% INFO    : Bus 29646	: V=0.9544678, theta=-54.673755 -> V=1.0, theta=0.0
% INFO    : Bus 29647	: V=0.9554068, theta=-54.648252 -> V=1.0, theta=0.0
% INFO    : Bus 29648	: V=0.9662909, theta=-52.609769 -> V=1.0, theta=0.0
% INFO    : Bus 29649	: V=0.9649764, theta=-52.761115 -> V=1.0, theta=0.0
% INFO    : Bus 29650	: V=0.9672575, theta=-52.48549 -> V=1.0, theta=0.0
% INFO    : Bus 29651	: V=0.95472, theta=-54.848909 -> V=1.0, theta=0.0
% INFO    : Bus 29652	: V=0.9692475, theta=-52.217943 -> V=1.0, theta=0.0
% INFO    : Bus 29653	: V=0.9577991, theta=-54.393014 -> V=1.0, theta=0.0
% INFO    : Bus 29654	: V=0.9521514, theta=-55.116391 -> V=1.0, theta=0.0
% INFO    : Bus 29655	: V=0.9537388, theta=-55.002466 -> V=1.0, theta=0.0
% INFO    : Bus 29656	: V=0.9531253, theta=-55.088307 -> V=1.0, theta=0.0
% INFO    : Bus 29657	: V=0.9775547, theta=-51.113828 -> V=1.0, theta=0.0
% INFO    : Bus 29658	: V=0.9840685, theta=-50.680176 -> V=1.0, theta=0.0
% INFO    : Bus 29659	: V=0.9836051, theta=-50.747561 -> V=1.0, theta=0.0
% INFO    : Bus 29660	: V=0.9811019, theta=-50.770605 -> V=1.0, theta=0.0
% INFO    : Bus 29661	: V=0.9968479, theta=-49.141387 -> V=1.0, theta=0.0
% INFO    : Bus 29662	: V=1.0023675, theta=-48.628161 -> V=1.0, theta=0.0
% INFO    : Bus 29663	: V=0.9736851, theta=-51.507194 -> V=1.0, theta=0.0
% INFO    : Bus 29664	: V=0.9731467, theta=-51.503474 -> V=1.0, theta=0.0
% INFO    : Bus 29665	: V=0.9721159, theta=-51.69691 -> V=1.0, theta=0.0
% INFO    : Bus 29666	: V=0.9699967, theta=-51.979962 -> V=1.0, theta=0.0
% INFO    : Bus 29667	: V=0.9936621, theta=-49.412524 -> V=1.0, theta=0.0
% INFO    : Bus 29668	: V=1.0013237, theta=-48.271884 -> V=1.0, theta=0.0
% INFO    : Bus 29669	: V=0.989516, theta=-49.730859 -> V=1.0, theta=0.0
% INFO    : Bus 29670	: V=1.0057082, theta=-48.227039 -> V=1.0, theta=0.0
% INFO    : Bus 29671	: V=0.985262, theta=-49.778173 -> V=1.0, theta=0.0
% INFO    : Bus 29672	: V=0.9847061, theta=-49.785518 -> V=1.0, theta=0.0
% INFO    : Bus 29673	: V=0.9824691, theta=-47.387474 -> V=1.0, theta=0.0
% INFO    : Bus 29674	: V=0.9729171, theta=-52.280782 -> V=1.0, theta=0.0
% INFO    : Bus 29675	: V=0.972596, theta=-51.425878 -> V=1.0, theta=0.0
% INFO    : Bus 29676	: V=0.9773266, theta=-51.048078 -> V=1.0, theta=0.0
% INFO    : Bus 29677	: V=0.9747159, theta=-51.289529 -> V=1.0, theta=0.0
% INFO    : Bus 29678	: V=0.976577, theta=-51.429951 -> V=1.0, theta=0.0
% INFO    : Bus 29679	: V=0.9701408, theta=-52.715672 -> V=1.0, theta=0.0
% INFO    : Bus 29680	: V=0.9783051, theta=-51.138307 -> V=1.0, theta=0.0
% INFO    : Bus 29681	: V=0.9570105, theta=-53.735125 -> V=1.0, theta=0.0
% INFO    : Bus 29682	: V=0.9732976, theta=-51.44737 -> V=1.0, theta=0.0
% INFO    : Bus 29683	: V=0.977387, theta=-51.263306 -> V=1.0, theta=0.0
% INFO    : Bus 29684	: V=0.9560444, theta=-55.112474 -> V=1.0, theta=0.0
% INFO    : Bus 29685	: V=0.9793504, theta=-51.21796 -> V=1.0, theta=0.0
% INFO    : Bus 29686	: V=0.9573887, theta=-52.154375 -> V=1.0, theta=0.0
% INFO    : Bus 29687	: V=0.9812399, theta=-50.651856 -> V=1.0, theta=0.0
% INFO    : Bus 29688	: V=0.9737691, theta=-51.399305 -> V=1.0, theta=0.0
% INFO    : Bus 29689	: V=1.0048471, theta=-48.35588 -> V=1.0, theta=0.0
% INFO    : Bus 29690	: V=0.9763187, theta=-51.21323 -> V=1.0, theta=0.0
% INFO    : Bus 29691	: V=0.9695632, theta=-51.10245 -> V=1.0, theta=0.0
% INFO    : Bus 29692	: V=0.9721606, theta=-51.317045 -> V=1.0, theta=0.0
% INFO    : Bus 29693	: V=0.9737917, theta=-51.307215 -> V=1.0, theta=0.0
% INFO    : Bus 29694	: V=0.9624518, theta=-51.563146 -> V=1.0, theta=0.0
% INFO    : Bus 29695	: V=0.9739286, theta=-50.430072 -> V=1.0, theta=0.0
% INFO    : Bus 29696	: V=0.98814, theta=-49.74092 -> V=1.0, theta=0.0
% INFO    : Bus 29697	: V=0.959886, theta=-51.749118 -> V=1.0, theta=0.0
% INFO    : Bus 29698	: V=0.9654247, theta=-50.733324 -> V=1.0, theta=0.0
% INFO    : Bus 29699	: V=0.957704, theta=-51.812767 -> V=1.0, theta=0.0
% INFO    : Bus 29700	: V=0.9636357, theta=-51.162938 -> V=1.0, theta=0.0
% INFO    : Bus 29701	: V=0.9782712, theta=-50.420584 -> V=1.0, theta=0.0
% INFO    : Bus 29702	: V=0.9700657, theta=-51.049599 -> V=1.0, theta=0.0
% INFO    : Bus 29703	: V=0.9644673, theta=-51.526517 -> V=1.0, theta=0.0
% INFO    : Bus 29704	: V=0.9773425, theta=-50.115579 -> V=1.0, theta=0.0
% INFO    : Bus 29705	: V=0.9611908, theta=-51.628223 -> V=1.0, theta=0.0
% INFO    : Bus 29706	: V=0.9555912, theta=-52.553903 -> V=1.0, theta=0.0
% INFO    : Bus 29707	: V=0.9600076, theta=-52.029882 -> V=1.0, theta=0.0
% INFO    : Bus 29708	: V=0.9583535, theta=-52.127502 -> V=1.0, theta=0.0
% INFO    : Bus 29709	: V=0.9620777, theta=-51.876719 -> V=1.0, theta=0.0
% INFO    : Bus 29710	: V=0.95782, theta=-52.141592 -> V=1.0, theta=0.0
% INFO    : Bus 29711	: V=0.9595203, theta=-52.04387 -> V=1.0, theta=0.0
% INFO    : Bus 29712	: V=0.9584864, theta=-52.073993 -> V=1.0, theta=0.0
% INFO    : Bus 29713	: V=0.9587384, theta=-54.816758 -> V=1.0, theta=0.0
% INFO    : Bus 29714	: V=0.9586979, theta=-54.817629 -> V=1.0, theta=0.0
% INFO    : Bus 29715	: V=0.9692602, theta=-52.812197 -> V=1.0, theta=0.0
% INFO    : Bus 29716	: V=0.9619354, theta=-54.406983 -> V=1.0, theta=0.0
% INFO    : Bus 29717	: V=0.9566794, theta=-55.097711 -> V=1.0, theta=0.0
% INFO    : Bus 29718	: V=0.9638232, theta=-53.748875 -> V=1.0, theta=0.0
% INFO    : Bus 29719	: V=0.959419, theta=-54.799756 -> V=1.0, theta=0.0
% INFO    : Bus 29720	: V=0.9669402, theta=-53.223542 -> V=1.0, theta=0.0
% INFO    : Bus 29721	: V=0.9580993, theta=-54.969862 -> V=1.0, theta=0.0
% INFO    : Bus 29722	: V=0.9677626, theta=-53.091677 -> V=1.0, theta=0.0
% INFO    : Bus 29723	: V=0.9658751, theta=-53.406578 -> V=1.0, theta=0.0
% INFO    : Bus 29724	: V=0.9465234, theta=-56.509428 -> V=1.0, theta=0.0
% INFO    : Bus 29725	: V=0.95581, theta=-55.122804 -> V=1.0, theta=0.0
% INFO    : Bus 29726	: V=0.9542688, theta=-55.237303 -> V=1.0, theta=0.0
% INFO    : Bus 29727	: V=0.9644499, theta=-53.742172 -> V=1.0, theta=0.0
% INFO    : Bus 29728	: V=0.9495967, theta=-56.508301 -> V=1.0, theta=0.0
% INFO    : Bus 29729	: V=0.9539064, theta=-55.243636 -> V=1.0, theta=0.0
% INFO    : Bus 29730	: V=0.9515386, theta=-55.515365 -> V=1.0, theta=0.0
% INFO    : Bus 29731	: V=0.9526605, theta=-55.78171 -> V=1.0, theta=0.0
% INFO    : Bus 29732	: V=0.9491934, theta=-56.227373 -> V=1.0, theta=0.0
% INFO    : Bus 29733	: V=0.9500734, theta=-56.426904 -> V=1.0, theta=0.0
% INFO    : Bus 29734	: V=0.9492119, theta=-56.514313 -> V=1.0, theta=0.0
% INFO    : Bus 29735	: V=0.9463841, theta=-56.664923 -> V=1.0, theta=0.0
% INFO    : Bus 29736	: V=0.9474026, theta=-56.628981 -> V=1.0, theta=0.0
% INFO    : Bus 29737	: V=0.9472896, theta=-55.964725 -> V=1.0, theta=0.0
% INFO    : Bus 29738	: V=0.9467061, theta=-56.054978 -> V=1.0, theta=0.0
% INFO    : Bus 29739	: V=0.9451916, theta=-56.318862 -> V=1.0, theta=0.0
% INFO    : Bus 29740	: V=0.9451453, theta=-56.382396 -> V=1.0, theta=0.0
% INFO    : Bus 29741	: V=0.9453549, theta=-56.315069 -> V=1.0, theta=0.0
% INFO    : Bus 29742	: V=0.9457328, theta=-56.47516 -> V=1.0, theta=0.0
% INFO    : Bus 29743	: V=0.9458192, theta=-55.154451 -> V=1.0, theta=0.0
% INFO    : Bus 29744	: V=0.9479628, theta=-55.072165 -> V=1.0, theta=0.0
% INFO    : Bus 29745	: V=0.9452133, theta=-56.183827 -> V=1.0, theta=0.0
% INFO    : Bus 29747	: V=0.9342369, theta=-57.491587 -> V=1.0, theta=0.0
% INFO    : Bus 29748	: V=0.937716, theta=-57.155765 -> V=1.0, theta=0.0
% INFO    : Bus 29749	: V=0.9391441, theta=-57.090025 -> V=1.0, theta=0.0
% INFO    : Bus 29750	: V=0.9824707, theta=-50.649276 -> V=1.0, theta=0.0
% INFO    : Bus 29751	: V=0.9423503, theta=-55.537881 -> V=1.0, theta=0.0
% INFO    : Bus 29752	: V=0.9755247, theta=-51.319916 -> V=1.0, theta=0.0
% INFO    : Bus 29753	: V=0.9482298, theta=-55.834918 -> V=1.0, theta=0.0
% INFO    : Bus 29754	: V=0.9795621, theta=-50.438229 -> V=1.0, theta=0.0
% INFO    : Bus 29755	: V=0.9788151, theta=-50.487576 -> V=1.0, theta=0.0
% INFO    : Bus 29756	: V=0.9787989, theta=-50.497476 -> V=1.0, theta=0.0
% INFO    : Bus 29757	: V=0.9789189, theta=-50.498836 -> V=1.0, theta=0.0
% INFO    : Bus 29758	: V=0.9790291, theta=-50.462126 -> V=1.0, theta=0.0
% INFO    : Bus 29759	: V=0.9657878, theta=-51.635748 -> V=1.0, theta=0.0
% INFO    : Bus 29760	: V=0.9703337, theta=-51.377271 -> V=1.0, theta=0.0
% INFO    : Bus 29761	: V=0.9803318, theta=-50.37378 -> V=1.0, theta=0.0
% INFO    : Bus 29762	: V=0.9694135, theta=-51.378444 -> V=1.0, theta=0.0
% INFO    : Bus 29763	: V=0.9642498, theta=-51.79653 -> V=1.0, theta=0.0
% INFO    : Bus 29764	: V=0.9793187, theta=-50.470378 -> V=1.0, theta=0.0
% INFO    : Bus 29765	: V=0.9793185, theta=-50.480779 -> V=1.0, theta=0.0
% INFO    : Bus 29766	: V=0.9791327, theta=-50.492401 -> V=1.0, theta=0.0
% INFO    : Bus 29767	: V=0.9648302, theta=-51.794492 -> V=1.0, theta=0.0
% INFO    : Bus 29768	: V=0.9643161, theta=-51.800075 -> V=1.0, theta=0.0
% INFO    : Bus 29769	: V=0.9654608, theta=-51.744566 -> V=1.0, theta=0.0
% INFO    : Bus 29770	: V=0.964303, theta=-51.811742 -> V=1.0, theta=0.0
% INFO    : Bus 29771	: V=0.965648, theta=-51.736545 -> V=1.0, theta=0.0
% INFO    : Bus 29772	: V=0.9666084, theta=-51.60901 -> V=1.0, theta=0.0
% INFO    : Bus 29773	: V=0.9702566, theta=-51.397416 -> V=1.0, theta=0.0
% INFO    : Bus 29774	: V=0.9829795, theta=-50.148033 -> V=1.0, theta=0.0
% INFO    : Bus 29775	: V=0.968683, theta=-51.378197 -> V=1.0, theta=0.0
% INFO    : Bus 29776	: V=0.9675719, theta=-51.433515 -> V=1.0, theta=0.0
% INFO    : Bus 29777	: V=0.9672519, theta=-51.470135 -> V=1.0, theta=0.0
% INFO    : Bus 29778	: V=0.9691631, theta=-51.448359 -> V=1.0, theta=0.0
% INFO    : Bus 29779	: V=0.96366, theta=-51.913833 -> V=1.0, theta=0.0
% INFO    : Bus 29780	: V=0.9616457, theta=-51.989925 -> V=1.0, theta=0.0
% INFO    : Bus 29781	: V=0.9646222, theta=-51.788327 -> V=1.0, theta=0.0
% INFO    : Bus 29782	: V=0.9646201, theta=-51.806411 -> V=1.0, theta=0.0
% INFO    : Bus 29783	: V=0.9850574, theta=-49.984631 -> V=1.0, theta=0.0
% INFO    : Bus 29784	: V=0.9676641, theta=-51.578387 -> V=1.0, theta=0.0
% INFO    : Bus 29785	: V=0.9681362, theta=-51.53706 -> V=1.0, theta=0.0
% INFO    : Bus 29786	: V=0.9658967, theta=-51.711923 -> V=1.0, theta=0.0
% INFO    : Bus 29787	: V=0.9747401, theta=-51.045821 -> V=1.0, theta=0.0
% INFO    : Bus 29788	: V=0.9699289, theta=-51.404323 -> V=1.0, theta=0.0
% INFO    : Bus 29789	: V=0.9858394, theta=-49.893894 -> V=1.0, theta=0.0
% INFO    : Bus 29790	: V=1.0181226, theta=-46.584267 -> V=1.0, theta=0.0
% INFO    : Bus 29791	: V=0.9872433, theta=-49.792612 -> V=1.0, theta=0.0
% INFO    : Bus 29792	: V=0.9845366, theta=-50.010019 -> V=1.0, theta=0.0
% INFO    : Bus 29793	: V=0.9770287, theta=-50.860735 -> V=1.0, theta=0.0
% INFO    : Bus 29794	: V=0.9777872, theta=-50.800979 -> V=1.0, theta=0.0
% INFO    : Bus 29795	: V=0.980156, theta=-50.55394 -> V=1.0, theta=0.0
% INFO    : Bus 29796	: V=0.9828209, theta=-50.148516 -> V=1.0, theta=0.0
% INFO    : Bus 29797	: V=0.9919513, theta=-49.353965 -> V=1.0, theta=0.0
% INFO    : Bus 29798	: V=0.9750183, theta=-50.810394 -> V=1.0, theta=0.0
% INFO    : Bus 29799	: V=0.9635621, theta=-51.890131 -> V=1.0, theta=0.0
% INFO    : Bus 29800	: V=0.9755051, theta=-50.840932 -> V=1.0, theta=0.0
% INFO    : Bus 29801	: V=0.9735925, theta=-51.357439 -> V=1.0, theta=0.0
% INFO    : Bus 29802	: V=0.9772323, theta=-50.774232 -> V=1.0, theta=0.0
% INFO    : Bus 29803	: V=0.9688464, theta=-52.210172 -> V=1.0, theta=0.0
% INFO    : Bus 29804	: V=0.9651727, theta=-51.59827 -> V=1.0, theta=0.0
% INFO    : Bus 29805	: V=0.9667365, theta=-51.58042 -> V=1.0, theta=0.0
% INFO    : Bus 29806	: V=0.9757306, theta=-50.835419 -> V=1.0, theta=0.0
% INFO    : Bus 29807	: V=0.9768664, theta=-50.775546 -> V=1.0, theta=0.0
% INFO    : Bus 29808	: V=0.9764472, theta=-50.735097 -> V=1.0, theta=0.0
% INFO    : Bus 29809	: V=0.9714021, theta=-50.904191 -> V=1.0, theta=0.0
% INFO    : Bus 29810	: V=0.9599366, theta=-52.64253 -> V=1.0, theta=0.0
% INFO    : Bus 29811	: V=0.9796978, theta=-50.46769 -> V=1.0, theta=0.0
% INFO    : Bus 29812	: V=0.9863794, theta=-49.582461 -> V=1.0, theta=0.0
% INFO    : Bus 29813	: V=0.975817, theta=-50.801839 -> V=1.0, theta=0.0
% INFO    : Bus 29814	: V=0.9741749, theta=-50.981498 -> V=1.0, theta=0.0
% INFO    : Bus 29815	: V=0.9753831, theta=-50.858096 -> V=1.0, theta=0.0
% INFO    : Bus 29816	: V=0.9655461, theta=-51.877379 -> V=1.0, theta=0.0
% INFO    : Bus 29817	: V=0.9661932, theta=-51.140295 -> V=1.0, theta=0.0
% INFO    : Bus 29818	: V=0.9725132, theta=-50.899078 -> V=1.0, theta=0.0
% INFO    : Bus 29819	: V=0.9885516, theta=-49.480991 -> V=1.0, theta=0.0
% INFO    : Bus 29820	: V=0.9801406, theta=-50.029929 -> V=1.0, theta=0.0
% INFO    : Bus 29821	: V=0.975957, theta=-51.040218 -> V=1.0, theta=0.0
% INFO    : Bus 29822	: V=0.991, theta=-49.946152 -> V=1.0, theta=0.0
% INFO    : Bus 29823	: V=0.9840232, theta=-50.025778 -> V=1.0, theta=0.0
% INFO    : Bus 29824	: V=0.9895652, theta=-48.785917 -> V=1.0, theta=0.0
% INFO    : Bus 29825	: V=1.0052536, theta=-47.111187 -> V=1.0, theta=0.0
% INFO    : Bus 29826	: V=1.0020095, theta=-47.688226 -> V=1.0, theta=0.0
% INFO    : Bus 29827	: V=0.9834063, theta=-48.766857 -> V=1.0, theta=0.0
% INFO    : Bus 29828	: V=0.9881027, theta=-49.772705 -> V=1.0, theta=0.0
% INFO    : Bus 29829	: V=0.9882859, theta=-49.976927 -> V=1.0, theta=0.0
% INFO    : Bus 29830	: V=0.9915352, theta=-47.42079 -> V=1.0, theta=0.0
% INFO    : Bus 29831	: V=0.989103, theta=-49.82369 -> V=1.0, theta=0.0
% INFO    : Bus 29832	: V=0.9831682, theta=-50.020753 -> V=1.0, theta=0.0
% INFO    : Bus 29833	: V=0.9880934, theta=-55.064064 -> V=1.0, theta=0.0
% INFO    : Bus 29834	: V=0.9874978, theta=-52.259135 -> V=1.0, theta=0.0
% INFO    : Bus 29835	: V=0.9871553, theta=-53.058963 -> V=1.0, theta=0.0
% INFO    : Bus 29836	: V=0.9942901, theta=-52.151984 -> V=1.0, theta=0.0
% INFO    : Bus 29837	: V=0.9977801, theta=-52.615208 -> V=1.0, theta=0.0
% INFO    : Bus 29838	: V=0.9594984, theta=-51.662999 -> V=1.0, theta=0.0
% INFO    : Bus 29839	: V=0.9756092, theta=-49.878743 -> V=1.0, theta=0.0
% INFO    : Bus 29840	: V=0.9771282, theta=-49.779696 -> V=1.0, theta=0.0
% INFO    : Bus 29841	: V=0.9688372, theta=-51.200062 -> V=1.0, theta=0.0
% INFO    : Bus 29842	: V=0.9620725, theta=-51.582951 -> V=1.0, theta=0.0
% INFO    : Bus 29843	: V=0.9670202, theta=-51.239303 -> V=1.0, theta=0.0
% INFO    : Bus 29844	: V=0.9640942, theta=-51.484078 -> V=1.0, theta=0.0
% INFO    : Bus 29845	: V=0.9792231, theta=-49.597829 -> V=1.0, theta=0.0
% INFO    : Bus 29846	: V=0.9659554, theta=-51.359588 -> V=1.0, theta=0.0
% INFO    : Bus 29847	: V=0.9608077, theta=-51.635068 -> V=1.0, theta=0.0
% INFO    : Bus 29848	: V=0.9615943, theta=-51.62889 -> V=1.0, theta=0.0
% INFO    : Bus 29849	: V=0.9593045, theta=-51.74982 -> V=1.0, theta=0.0
% INFO    : Bus 29850	: V=0.960346, theta=-51.686325 -> V=1.0, theta=0.0
% INFO    : Bus 29851	: V=0.9548471, theta=-52.204528 -> V=1.0, theta=0.0
% INFO    : Bus 29852	: V=0.9563977, theta=-52.084477 -> V=1.0, theta=0.0
% INFO    : Bus 29853	: V=0.9570699, theta=-51.966402 -> V=1.0, theta=0.0
% INFO    : Bus 29854	: V=0.9552495, theta=-52.195601 -> V=1.0, theta=0.0
% INFO    : Bus 29855	: V=0.953677, theta=-52.350234 -> V=1.0, theta=0.0
% INFO    : Bus 29856	: V=0.9577864, theta=-51.945641 -> V=1.0, theta=0.0
% INFO    : Bus 29857	: V=0.9578005, theta=-51.943828 -> V=1.0, theta=0.0
% INFO    : Bus 29858	: V=0.9582015, theta=-51.913748 -> V=1.0, theta=0.0
% INFO    : Bus 29859	: V=0.9605154, theta=-51.610914 -> V=1.0, theta=0.0
% INFO    : Bus 29860	: V=0.9604363, theta=-51.688411 -> V=1.0, theta=0.0
% INFO    : Bus 29861	: V=0.9599448, theta=-51.748845 -> V=1.0, theta=0.0
% INFO    : Bus 29862	: V=0.9683356, theta=-51.200208 -> V=1.0, theta=0.0
% INFO    : Bus 29863	: V=0.9696431, theta=-51.091474 -> V=1.0, theta=0.0
% INFO    : Bus 29864	: V=0.9722129, theta=-50.830819 -> V=1.0, theta=0.0
% INFO    : Bus 29865	: V=0.9825055, theta=-49.291484 -> V=1.0, theta=0.0
% INFO    : Bus 29866	: V=0.9871536, theta=-48.764256 -> V=1.0, theta=0.0
% INFO    : Bus 29867	: V=1.0092828, theta=-46.006866 -> V=1.0, theta=0.0
% INFO    : Bus 29868	: V=1.0100523, theta=-45.887725 -> V=1.0, theta=0.0
% INFO    : Bus 29869	: V=0.9976496, theta=-46.918713 -> V=1.0, theta=0.0
% INFO    : Bus 29870	: V=0.9794694, theta=-49.648274 -> V=1.0, theta=0.0
% INFO    : Bus 29871	: V=0.9682552, theta=-51.256426 -> V=1.0, theta=0.0
% INFO    : Bus 29872	: V=0.9671444, theta=-51.330969 -> V=1.0, theta=0.0
% INFO    : Bus 29873	: V=0.9701583, theta=-51.241561 -> V=1.0, theta=0.0
% INFO    : Bus 29874	: V=0.960311, theta=-51.680211 -> V=1.0, theta=0.0
% INFO    : Bus 29875	: V=0.956753, theta=-51.868627 -> V=1.0, theta=0.0
% INFO    : Bus 29876	: V=0.9582916, theta=-51.809029 -> V=1.0, theta=0.0
% INFO    : Bus 29877	: V=0.9525409, theta=-52.401444 -> V=1.0, theta=0.0
% INFO    : Bus 29878	: V=0.9511004, theta=-52.54157 -> V=1.0, theta=0.0
% INFO    : Bus 29879	: V=0.9502874, theta=-52.576755 -> V=1.0, theta=0.0
% INFO    : Bus 29880	: V=0.9557851, theta=-51.780798 -> V=1.0, theta=0.0
% INFO    : Bus 29881	: V=0.9546431, theta=-52.258336 -> V=1.0, theta=0.0
% INFO    : Bus 29882	: V=0.951077, theta=-52.581463 -> V=1.0, theta=0.0
% INFO    : Bus 29883	: V=0.9583199, theta=-51.664912 -> V=1.0, theta=0.0
% INFO    : Bus 29884	: V=0.9530848, theta=-52.303904 -> V=1.0, theta=0.0
% INFO    : Bus 29885	: V=0.9600276, theta=-51.543165 -> V=1.0, theta=0.0
% INFO    : Bus 29886	: V=0.9639431, theta=-51.324124 -> V=1.0, theta=0.0
% INFO    : Bus 29887	: V=0.9678493, theta=-51.074514 -> V=1.0, theta=0.0
% INFO    : Bus 29888	: V=0.9756208, theta=-49.94162 -> V=1.0, theta=0.0
% INFO    : Bus 29889	: V=0.9679059, theta=-51.153664 -> V=1.0, theta=0.0
% INFO    : Bus 29890	: V=0.9800659, theta=-49.715006 -> V=1.0, theta=0.0
% INFO    : Bus 29891	: V=0.9482118, theta=-52.659619 -> V=1.0, theta=0.0
% INFO    : Bus 29892	: V=0.9490314, theta=-52.609695 -> V=1.0, theta=0.0
% INFO    : Bus 29893	: V=0.9591608, theta=-52.528736 -> V=1.0, theta=0.0
% INFO    : Bus 29894	: V=0.9475484, theta=-52.790747 -> V=1.0, theta=0.0
% INFO    : Bus 29895	: V=0.9710378, theta=-50.779175 -> V=1.0, theta=0.0
% INFO    : Bus 29896	: V=0.9756618, theta=-50.292815 -> V=1.0, theta=0.0
% INFO    : Bus 29897	: V=0.9765958, theta=-50.253557 -> V=1.0, theta=0.0
% INFO    : Bus 29898	: V=0.9902375, theta=-48.124727 -> V=1.0, theta=0.0
% INFO    : Bus 29899	: V=0.9980254, theta=-47.513692 -> V=1.0, theta=0.0
% INFO    : Bus 29900	: V=0.9976262, theta=-47.552509 -> V=1.0, theta=0.0
% INFO    : Bus 29901	: V=0.9871774, theta=-48.816132 -> V=1.0, theta=0.0
% INFO    : Bus 29902	: V=0.9952893, theta=-47.010529 -> V=1.0, theta=0.0
% INFO    : Bus 29903	: V=0.9970214, theta=-46.335706 -> V=1.0, theta=0.0
% INFO    : Bus 29904	: V=0.9775801, theta=-50.053868 -> V=1.0, theta=0.0
% INFO    : Bus 29905	: V=0.9968551, theta=-46.93465 -> V=1.0, theta=0.0
% INFO    : Bus 29906	: V=0.9618836, theta=-49.732538 -> V=1.0, theta=0.0
% INFO    : Bus 29907	: V=0.9635172, theta=-51.487117 -> V=1.0, theta=0.0
% INFO    : Bus 29908	: V=0.974724, theta=-48.906904 -> V=1.0, theta=0.0
% INFO    : Bus 29909	: V=0.9915726, theta=-48.23232 -> V=1.0, theta=0.0
% INFO    : Bus 29910	: V=1.0112891, theta=-45.70028 -> V=1.0, theta=0.0
% INFO    : Bus 29911	: V=1.0130183, theta=-45.462827 -> V=1.0, theta=0.0
% INFO    : Bus 29912	: V=0.9575427, theta=-49.834282 -> V=1.0, theta=0.0
% INFO    : Bus 29913	: V=0.9582921, theta=-49.869559 -> V=1.0, theta=0.0
% INFO    : Bus 29914	: V=0.9608067, theta=-51.586353 -> V=1.0, theta=0.0
% INFO    : Bus 29915	: V=0.9660821, theta=-51.307928 -> V=1.0, theta=0.0
% INFO    : Bus 29916	: V=0.9660782, theta=-51.842467 -> V=1.0, theta=0.0
% INFO    : Bus 29917	: V=0.9804704, theta=-50.552783 -> V=1.0, theta=0.0
% INFO    : Bus 29918	: V=0.9726819, theta=-51.077093 -> V=1.0, theta=0.0
% INFO    : Bus 29919	: V=0.9706499, theta=-51.186986 -> V=1.0, theta=0.0
% INFO    : Bus 29920	: V=0.9754114, theta=-50.331926 -> V=1.0, theta=0.0
% INFO    : Bus 29921	: V=0.981655, theta=-49.659407 -> V=1.0, theta=0.0
% INFO    : Bus 29922	: V=0.9768186, theta=-48.723221 -> V=1.0, theta=0.0
% INFO    : Bus 29923	: V=0.9744008, theta=-48.997741 -> V=1.0, theta=0.0
% INFO    : Bus 29924	: V=0.9728889, theta=-49.170251 -> V=1.0, theta=0.0
% INFO    : Bus 29925	: V=0.9583597, theta=-51.472132 -> V=1.0, theta=0.0
% INFO    : Bus 29926	: V=0.9735411, theta=-48.934426 -> V=1.0, theta=0.0
% INFO    : Bus 29927	: V=0.9573657, theta=-51.365604 -> V=1.0, theta=0.0
% INFO    : Bus 29928	: V=0.9583807, theta=-51.185854 -> V=1.0, theta=0.0
% INFO    : Bus 29929	: V=0.9647527, theta=-50.933809 -> V=1.0, theta=0.0
% INFO    : Bus 29930	: V=0.966021, theta=-51.121888 -> V=1.0, theta=0.0
% INFO    : Bus 29931	: V=0.9655498, theta=-51.208078 -> V=1.0, theta=0.0
% INFO    : Bus 29932	: V=0.9542885, theta=-53.224181 -> V=1.0, theta=0.0
% INFO    : Bus 29933	: V=0.9639182, theta=-51.403586 -> V=1.0, theta=0.0
% INFO    : Bus 29934	: V=0.9660322, theta=-51.322453 -> V=1.0, theta=0.0
% INFO    : Bus 29935	: V=0.9526086, theta=-53.126412 -> V=1.0, theta=0.0
% INFO    : Bus 29936	: V=0.9645539, theta=-51.524653 -> V=1.0, theta=0.0
% INFO    : Bus 29937	: V=0.964629, theta=-51.561866 -> V=1.0, theta=0.0
% INFO    : Bus 29938	: V=0.9644013, theta=-51.559807 -> V=1.0, theta=0.0
% INFO    : Bus 29939	: V=0.9590563, theta=-52.51475 -> V=1.0, theta=0.0
% INFO    : Bus 29940	: V=0.9564931, theta=-52.964705 -> V=1.0, theta=0.0
% INFO    : Bus 29941	: V=0.9744314, theta=-50.543093 -> V=1.0, theta=0.0
% INFO    : Bus 29942	: V=0.9656615, theta=-51.346986 -> V=1.0, theta=0.0
% INFO    : Bus 29943	: V=0.9665021, theta=-51.370873 -> V=1.0, theta=0.0
% INFO    : Bus 29944	: V=0.9543927, theta=-52.411952 -> V=1.0, theta=0.0
% INFO    : Bus 29945	: V=0.9523384, theta=-52.472601 -> V=1.0, theta=0.0
% INFO    : Bus 29946	: V=0.9669304, theta=-51.257065 -> V=1.0, theta=0.0
% INFO    : Bus 29947	: V=0.9665977, theta=-51.306053 -> V=1.0, theta=0.0
% INFO    : Bus 29948	: V=0.9700654, theta=-51.209991 -> V=1.0, theta=0.0
% INFO    : Bus 29949	: V=0.9702869, theta=-50.905018 -> V=1.0, theta=0.0
% INFO    : Bus 29950	: V=0.9686398, theta=-51.27695 -> V=1.0, theta=0.0
% INFO    : Bus 29951	: V=0.956058, theta=-52.480963 -> V=1.0, theta=0.0
% INFO    : Bus 29952	: V=0.9791594, theta=-50.382743 -> V=1.0, theta=0.0
% INFO    : Bus 29953	: V=0.9679711, theta=-51.316915 -> V=1.0, theta=0.0
% INFO    : Bus 29954	: V=0.9571096, theta=-52.358171 -> V=1.0, theta=0.0
% INFO    : Bus 29955	: V=0.9593172, theta=-52.243286 -> V=1.0, theta=0.0
% INFO    : Bus 29956	: V=0.9678614, theta=-51.312461 -> V=1.0, theta=0.0
% INFO    : Bus 29957	: V=0.9672527, theta=-51.339828 -> V=1.0, theta=0.0
% INFO    : Bus 29958	: V=0.967493, theta=-51.322987 -> V=1.0, theta=0.0
% INFO    : Bus 29959	: V=0.9670048, theta=-51.335774 -> V=1.0, theta=0.0
% INFO    : Bus 29960	: V=0.9673382, theta=-51.246605 -> V=1.0, theta=0.0
% INFO    : Bus 29961	: V=0.9669909, theta=-51.298008 -> V=1.0, theta=0.0
% INFO    : Bus 29962	: V=0.9665855, theta=-51.318413 -> V=1.0, theta=0.0
% INFO    : Bus 29963	: V=0.9665176, theta=-51.360535 -> V=1.0, theta=0.0
% INFO    : Bus 29964	: V=0.9662866, theta=-51.347854 -> V=1.0, theta=0.0
% INFO    : Bus 29965	: V=0.9662955, theta=-51.435215 -> V=1.0, theta=0.0
% INFO    : Bus 29966	: V=0.9559125, theta=-52.24353 -> V=1.0, theta=0.0
% INFO    : Bus 29967	: V=0.9683064, theta=-51.266092 -> V=1.0, theta=0.0
% INFO    : Bus 29968	: V=0.9650654, theta=-51.461552 -> V=1.0, theta=0.0
% INFO    : Bus 29969	: V=0.9684557, theta=-51.293764 -> V=1.0, theta=0.0
% INFO    : Bus 29970	: V=0.9720811, theta=-51.055288 -> V=1.0, theta=0.0
% INFO    : Bus 29971	: V=0.9660726, theta=-51.515837 -> V=1.0, theta=0.0
% INFO    : Bus 29972	: V=0.9711991, theta=-50.834846 -> V=1.0, theta=0.0
% INFO    : Bus 29973	: V=0.9698915, theta=-51.017744 -> V=1.0, theta=0.0
% INFO    : Bus 29974	: V=0.9605238, theta=-52.367496 -> V=1.0, theta=0.0
% INFO    : Bus 29975	: V=0.9910677, theta=-49.296846 -> V=1.0, theta=0.0
% INFO    : Bus 29976	: V=0.9755195, theta=-50.219633 -> V=1.0, theta=0.0
% INFO    : Bus 29977	: V=0.973352, theta=-49.022337 -> V=1.0, theta=0.0
% INFO    : Bus 29978	: V=0.9840275, theta=-34.038317 -> V=1.0, theta=0.0
% INFO    : Bus 29979	: V=0.9820753, theta=-34.52016 -> V=1.0, theta=0.0
% INFO    : Bus 29980	: V=0.9768097, theta=-35.097431 -> V=1.0, theta=0.0
% INFO    : Bus 29981	: V=0.9845712, theta=-34.292396 -> V=1.0, theta=0.0
% INFO    : Bus 29982	: V=1.0024643, theta=-32.019812 -> V=1.0, theta=0.0
% INFO    : Bus 29983	: V=0.9753999, theta=-34.976836 -> V=1.0, theta=0.0
% INFO    : Bus 29984	: V=0.9803932, theta=-34.163679 -> V=1.0, theta=0.0
% INFO    : Bus 29985	: V=0.981094, theta=-34.122026 -> V=1.0, theta=0.0
% INFO    : Bus 29986	: V=0.9735683, theta=-35.181201 -> V=1.0, theta=0.0
% INFO    : Bus 29987	: V=0.9728134, theta=-35.287672 -> V=1.0, theta=0.0
% INFO    : Bus 29988	: V=0.9742266, theta=-35.317839 -> V=1.0, theta=0.0
% INFO    : Bus 29989	: V=0.9672656, theta=-35.509698 -> V=1.0, theta=0.0
% INFO    : Bus 29990	: V=0.97553, theta=-34.976457 -> V=1.0, theta=0.0
% INFO    : Bus 29991	: V=0.9819841, theta=-34.322856 -> V=1.0, theta=0.0
% INFO    : Bus 29992	: V=0.9853176, theta=-34.066676 -> V=1.0, theta=0.0
% INFO    : Bus 29993	: V=0.9802694, theta=-34.354735 -> V=1.0, theta=0.0
% INFO    : Bus 29994	: V=0.9657154, theta=-36.795568 -> V=1.0, theta=0.0
% INFO    : Bus 29995	: V=0.9822419, theta=-34.052693 -> V=1.0, theta=0.0
% INFO    : Bus 29996	: V=0.9804667, theta=-34.264188 -> V=1.0, theta=0.0
% INFO    : Bus 29997	: V=0.9692992, theta=-35.489088 -> V=1.0, theta=0.0
% INFO    : Bus 29998	: V=0.9790087, theta=-34.60095 -> V=1.0, theta=0.0
% INFO    : Bus 29999	: V=0.9771951, theta=-34.787761 -> V=1.0, theta=0.0
% INFO    : Bus 30000	: V=0.9740863, theta=-35.281986 -> V=1.0, theta=0.0
% INFO    : Bus 30001	: V=0.9684923, theta=-36.303044 -> V=1.0, theta=0.0
% INFO    : Bus 30002	: V=0.9747397, theta=-35.118442 -> V=1.0, theta=0.0
% INFO    : Bus 30003	: V=0.9740147, theta=-35.258541 -> V=1.0, theta=0.0
% INFO    : Bus 30004	: V=0.9673312, theta=-35.691246 -> V=1.0, theta=0.0
% INFO    : Bus 30005	: V=0.9757265, theta=-34.967042 -> V=1.0, theta=0.0
% INFO    : Bus 30006	: V=0.9665172, theta=-36.498662 -> V=1.0, theta=0.0
% INFO    : Bus 30007	: V=0.9576074, theta=-38.622471 -> V=1.0, theta=0.0
% INFO    : Bus 30008	: V=0.9605188, theta=-37.713885 -> V=1.0, theta=0.0
% INFO    : Bus 30009	: V=1.0046166, theta=-30.749243 -> V=1.0, theta=0.0
% INFO    : Bus 30010	: V=1.0095907, theta=-29.74394 -> V=1.0, theta=0.0
% INFO    : Bus 30011	: V=1.0082476, theta=-30.023156 -> V=1.0, theta=0.0
% INFO    : Bus 30012	: V=0.9779713, theta=-44.066565 -> V=1.0, theta=0.0
% INFO    : Bus 30013	: V=0.9712781, theta=-45.241947 -> V=1.0, theta=0.0
% INFO    : Bus 30014	: V=0.9803102, theta=-43.811722 -> V=1.0, theta=0.0
% INFO    : Bus 30015	: V=0.9773286, theta=-44.294762 -> V=1.0, theta=0.0
% INFO    : Bus 30016	: V=0.9756339, theta=-44.631282 -> V=1.0, theta=0.0
% INFO    : Bus 30017	: V=0.9778808, theta=-44.380403 -> V=1.0, theta=0.0
% INFO    : Bus 30018	: V=0.9687093, theta=-45.553573 -> V=1.0, theta=0.0
% INFO    : Bus 30019	: V=0.9776407, theta=-44.386081 -> V=1.0, theta=0.0
% INFO    : Bus 30020	: V=0.9777157, theta=-44.286717 -> V=1.0, theta=0.0
% INFO    : Bus 30021	: V=0.9762982, theta=-44.583854 -> V=1.0, theta=0.0
% INFO    : Bus 30022	: V=0.9684576, theta=-45.559057 -> V=1.0, theta=0.0
% INFO    : Bus 30023	: V=0.9756266, theta=-44.633268 -> V=1.0, theta=0.0
% INFO    : Bus 30024	: V=0.9757659, theta=-44.624776 -> V=1.0, theta=0.0
% INFO    : Bus 30025	: V=0.9727654, theta=-45.09471 -> V=1.0, theta=0.0
% INFO    : Bus 30026	: V=0.9727143, theta=-45.11256 -> V=1.0, theta=0.0
% INFO    : Bus 30027	: V=0.9769179, theta=-44.500513 -> V=1.0, theta=0.0
% INFO    : Bus 30028	: V=0.9769845, theta=-44.166537 -> V=1.0, theta=0.0
% INFO    : Bus 30029	: V=0.9772883, theta=-44.490388 -> V=1.0, theta=0.0
% INFO    : Bus 30030	: V=0.9796294, theta=-43.878023 -> V=1.0, theta=0.0
% INFO    : Bus 30031	: V=0.9836979, theta=-43.307316 -> V=1.0, theta=0.0
% INFO    : Bus 30032	: V=0.9774789, theta=-44.302526 -> V=1.0, theta=0.0
% INFO    : Bus 30033	: V=0.9784639, theta=-44.014789 -> V=1.0, theta=0.0
% INFO    : Bus 30034	: V=0.9803971, theta=-43.744243 -> V=1.0, theta=0.0
% INFO    : Bus 30035	: V=0.9785021, theta=-43.994639 -> V=1.0, theta=0.0
% INFO    : Bus 30036	: V=0.9768239, theta=-44.235007 -> V=1.0, theta=0.0
% INFO    : Bus 30037	: V=0.9755978, theta=-44.386843 -> V=1.0, theta=0.0
% INFO    : Bus 30038	: V=0.9794476, theta=-43.892159 -> V=1.0, theta=0.0
% INFO    : Bus 30039	: V=0.9783678, theta=-44.032892 -> V=1.0, theta=0.0
% INFO    : Bus 30040	: V=0.9729933, theta=-44.920992 -> V=1.0, theta=0.0
% INFO    : Bus 30041	: V=0.974782, theta=-44.799191 -> V=1.0, theta=0.0
% INFO    : Bus 30042	: V=0.9726888, theta=-45.095289 -> V=1.0, theta=0.0
% INFO    : Bus 30043	: V=0.9734034, theta=-44.997735 -> V=1.0, theta=0.0
% INFO    : Bus 30044	: V=0.9716564, theta=-45.255181 -> V=1.0, theta=0.0
% INFO    : Bus 30045	: V=0.9697031, theta=-45.472961 -> V=1.0, theta=0.0
% INFO    : Bus 30046	: V=0.974258, theta=-44.528795 -> V=1.0, theta=0.0
% INFO    : Bus 30047	: V=0.9747085, theta=-44.48357 -> V=1.0, theta=0.0
% INFO    : Bus 30048	: V=0.9770488, theta=-44.211457 -> V=1.0, theta=0.0
% INFO    : Bus 30049	: V=0.965611, theta=-46.377048 -> V=1.0, theta=0.0
% INFO    : Bus 30050	: V=0.9756401, theta=-44.378801 -> V=1.0, theta=0.0
% INFO    : Bus 30051	: V=0.9741386, theta=-44.541949 -> V=1.0, theta=0.0
% INFO    : Bus 30052	: V=0.9667057, theta=-45.926878 -> V=1.0, theta=0.0
% INFO    : Bus 30053	: V=0.9671195, theta=-45.915539 -> V=1.0, theta=0.0
% INFO    : Bus 30054	: V=0.9771388, theta=-44.222351 -> V=1.0, theta=0.0
% INFO    : Bus 30055	: V=0.9765602, theta=-44.27446 -> V=1.0, theta=0.0
% INFO    : Bus 30056	: V=0.9681059, theta=-45.822558 -> V=1.0, theta=0.0
% INFO    : Bus 30057	: V=0.9673641, theta=-45.909581 -> V=1.0, theta=0.0
% INFO    : Bus 30058	: V=0.9640715, theta=-46.284578 -> V=1.0, theta=0.0
% INFO    : Bus 30059	: V=0.9659494, theta=-46.101764 -> V=1.0, theta=0.0
% INFO    : Bus 30060	: V=0.9665033, theta=-46.023103 -> V=1.0, theta=0.0
% INFO    : Bus 30061	: V=0.965278, theta=-46.199714 -> V=1.0, theta=0.0
% INFO    : Bus 30062	: V=0.9671603, theta=-45.935752 -> V=1.0, theta=0.0
% INFO    : Bus 30063	: V=0.9686667, theta=-45.768547 -> V=1.0, theta=0.0
% INFO    : Bus 30064	: V=0.9768211, theta=-44.25472 -> V=1.0, theta=0.0
% INFO    : Bus 30065	: V=0.9742667, theta=-45.001265 -> V=1.0, theta=0.0
% INFO    : Bus 30066	: V=0.9761217, theta=-44.403806 -> V=1.0, theta=0.0
% INFO    : Bus 30067	: V=0.9684605, theta=-45.733181 -> V=1.0, theta=0.0
% INFO    : Bus 30068	: V=0.9797696, theta=-44.098168 -> V=1.0, theta=0.0
% INFO    : Bus 30069	: V=0.9728074, theta=-45.411994 -> V=1.0, theta=0.0
% INFO    : Bus 30070	: V=0.9755559, theta=-45.195751 -> V=1.0, theta=0.0
% INFO    : Bus 30071	: V=0.9742797, theta=-45.382733 -> V=1.0, theta=0.0
% INFO    : Bus 30072	: V=0.9782395, theta=-44.263383 -> V=1.0, theta=0.0
% INFO    : Bus 30073	: V=0.9690045, theta=-45.841595 -> V=1.0, theta=0.0
% INFO    : Bus 30074	: V=0.9730109, theta=-45.49242 -> V=1.0, theta=0.0
% INFO    : Bus 30075	: V=0.9721421, theta=-45.548933 -> V=1.0, theta=0.0
% INFO    : Bus 30076	: V=0.9746302, theta=-45.161029 -> V=1.0, theta=0.0
% INFO    : Bus 30077	: V=0.9734251, theta=-45.297971 -> V=1.0, theta=0.0
% INFO    : Bus 30078	: V=0.9738065, theta=-45.28372 -> V=1.0, theta=0.0
% INFO    : Bus 30079	: V=0.9799445, theta=-44.116531 -> V=1.0, theta=0.0
% INFO    : Bus 30080	: V=0.9726246, theta=-45.401903 -> V=1.0, theta=0.0
% INFO    : Bus 30081	: V=0.9719556, theta=-45.448776 -> V=1.0, theta=0.0
% INFO    : Bus 30082	: V=0.9796852, theta=-44.127865 -> V=1.0, theta=0.0
% INFO    : Bus 30083	: V=0.9721469, theta=-45.575217 -> V=1.0, theta=0.0
% INFO    : Bus 30084	: V=0.9706372, theta=-45.683903 -> V=1.0, theta=0.0
% INFO    : Bus 30085	: V=0.9697597, theta=-45.745466 -> V=1.0, theta=0.0
% INFO    : Bus 30086	: V=0.9710788, theta=-45.623671 -> V=1.0, theta=0.0
% INFO    : Bus 30087	: V=0.9710654, theta=-45.65001 -> V=1.0, theta=0.0
% INFO    : Bus 30088	: V=0.9714212, theta=-45.631957 -> V=1.0, theta=0.0
% INFO    : Bus 30089	: V=0.9697885, theta=-45.743466 -> V=1.0, theta=0.0
% INFO    : Bus 30090	: V=0.9672289, theta=-46.012811 -> V=1.0, theta=0.0
% INFO    : Bus 30091	: V=0.9669626, theta=-46.090584 -> V=1.0, theta=0.0
% INFO    : Bus 30092	: V=0.9632751, theta=-46.402917 -> V=1.0, theta=0.0
% INFO    : Bus 30093	: V=0.9663845, theta=-46.072702 -> V=1.0, theta=0.0
% INFO    : Bus 30094	: V=0.9622873, theta=-46.53391 -> V=1.0, theta=0.0
% INFO    : Bus 30095	: V=0.9629443, theta=-46.440221 -> V=1.0, theta=0.0
% INFO    : Bus 30096	: V=0.9613, theta=-46.599509 -> V=1.0, theta=0.0
% INFO    : Bus 30097	: V=0.973148, theta=-44.635705 -> V=1.0, theta=0.0
% INFO    : Bus 30098	: V=0.9724693, theta=-44.703735 -> V=1.0, theta=0.0
% INFO    : Bus 30099	: V=0.9624395, theta=-46.480683 -> V=1.0, theta=0.0
% INFO    : Bus 30100	: V=0.9639612, theta=-46.36566 -> V=1.0, theta=0.0
% INFO    : Bus 30101	: V=0.9661882, theta=-45.846256 -> V=1.0, theta=0.0
% INFO    : Bus 30102	: V=0.966976, theta=-45.720233 -> V=1.0, theta=0.0
% INFO    : Bus 30103	: V=0.9683095, theta=-45.528648 -> V=1.0, theta=0.0
% INFO    : Bus 30104	: V=0.9636915, theta=-46.234998 -> V=1.0, theta=0.0
% INFO    : Bus 30105	: V=0.9596274, theta=-46.699934 -> V=1.0, theta=0.0
% INFO    : Bus 30106	: V=0.960368, theta=-46.650066 -> V=1.0, theta=0.0
% INFO    : Bus 30107	: V=0.9596774, theta=-46.685483 -> V=1.0, theta=0.0
% INFO    : Bus 30108	: V=0.9595419, theta=-46.709419 -> V=1.0, theta=0.0
% INFO    : Bus 30109	: V=0.9626446, theta=-46.537312 -> V=1.0, theta=0.0
% INFO    : Bus 30110	: V=0.9638797, theta=-46.41411 -> V=1.0, theta=0.0
% INFO    : Bus 30111	: V=0.9778013, theta=-44.336749 -> V=1.0, theta=0.0
% INFO    : Bus 30112	: V=0.9694153, theta=-45.794147 -> V=1.0, theta=0.0
% INFO    : Bus 30113	: V=0.9707035, theta=-45.663292 -> V=1.0, theta=0.0
% INFO    : Bus 30114	: V=0.9708822, theta=-45.654357 -> V=1.0, theta=0.0
% INFO    : Bus 30115	: V=0.9631263, theta=-46.609844 -> V=1.0, theta=0.0
% INFO    : Bus 30116	: V=0.9624358, theta=-46.629083 -> V=1.0, theta=0.0
% INFO    : Bus 30117	: V=0.9749372, theta=-44.698567 -> V=1.0, theta=0.0
% INFO    : Bus 30118	: V=0.9632134, theta=-46.439443 -> V=1.0, theta=0.0
% INFO    : Bus 30119	: V=0.9622632, theta=-46.616692 -> V=1.0, theta=0.0
% INFO    : Bus 30120	: V=0.9628197, theta=-46.59608 -> V=1.0, theta=0.0
% INFO    : Bus 30121	: V=0.9605369, theta=-46.680001 -> V=1.0, theta=0.0
% INFO    : Bus 30122	: V=0.9618442, theta=-46.606625 -> V=1.0, theta=0.0
% INFO    : Bus 30123	: V=0.9612275, theta=-46.659867 -> V=1.0, theta=0.0
% INFO    : Bus 30124	: V=0.9591637, theta=-46.710709 -> V=1.0, theta=0.0
% INFO    : Bus 30125	: V=0.961068, theta=-46.693306 -> V=1.0, theta=0.0
% INFO    : Bus 30126	: V=0.9586472, theta=-46.73621 -> V=1.0, theta=0.0
% INFO    : Bus 30127	: V=0.9605084, theta=-46.736525 -> V=1.0, theta=0.0
% INFO    : Bus 30128	: V=0.9611904, theta=-46.717185 -> V=1.0, theta=0.0
% INFO    : Bus 30129	: V=0.9618472, theta=-46.670101 -> V=1.0, theta=0.0
% INFO    : Bus 30130	: V=0.9613504, theta=-46.672925 -> V=1.0, theta=0.0
% INFO    : Bus 30131	: V=0.9642651, theta=-46.572024 -> V=1.0, theta=0.0
% INFO    : Bus 30132	: V=0.9641083, theta=-46.52626 -> V=1.0, theta=0.0
% INFO    : Bus 30133	: V=0.9739949, theta=-44.766119 -> V=1.0, theta=0.0
% INFO    : Bus 30134	: V=0.9620922, theta=-46.62663 -> V=1.0, theta=0.0
% INFO    : Bus 30135	: V=0.9624779, theta=-46.607245 -> V=1.0, theta=0.0
% INFO    : Bus 30136	: V=0.972528, theta=-44.85066 -> V=1.0, theta=0.0
% INFO    : Bus 30137	: V=0.9622863, theta=-46.63143 -> V=1.0, theta=0.0
% INFO    : Bus 30138	: V=0.9618542, theta=-46.662315 -> V=1.0, theta=0.0
% INFO    : Bus 30139	: V=0.9731136, theta=-44.770167 -> V=1.0, theta=0.0
% INFO    : Bus 30140	: V=0.9618632, theta=-46.642708 -> V=1.0, theta=0.0
% INFO    : Bus 30141	: V=0.9626888, theta=-46.595176 -> V=1.0, theta=0.0
% INFO    : Bus 30142	: V=0.9625759, theta=-46.598055 -> V=1.0, theta=0.0
% INFO    : Bus 30143	: V=0.9630889, theta=-46.594208 -> V=1.0, theta=0.0
% INFO    : Bus 30144	: V=0.9647445, theta=-46.537892 -> V=1.0, theta=0.0
% INFO    : Bus 30145	: V=0.9632065, theta=-46.587882 -> V=1.0, theta=0.0
% INFO    : Bus 30146	: V=0.9624051, theta=-46.609109 -> V=1.0, theta=0.0
% INFO    : Bus 30147	: V=0.9641259, theta=-46.539171 -> V=1.0, theta=0.0
% INFO    : Bus 30148	: V=0.9649347, theta=-46.476478 -> V=1.0, theta=0.0
% INFO    : Bus 30149	: V=0.9654424, theta=-46.445214 -> V=1.0, theta=0.0
% INFO    : Bus 30150	: V=0.9638863, theta=-46.527929 -> V=1.0, theta=0.0
% INFO    : Bus 30151	: V=0.9656821, theta=-46.394492 -> V=1.0, theta=0.0
% INFO    : Bus 30152	: V=0.9657746, theta=-46.391889 -> V=1.0, theta=0.0
% INFO    : Bus 30153	: V=0.9660067, theta=-46.385615 -> V=1.0, theta=0.0
% INFO    : Bus 30154	: V=0.9654793, theta=-46.431431 -> V=1.0, theta=0.0
% INFO    : Bus 30155	: V=0.9653804, theta=-46.434187 -> V=1.0, theta=0.0
% INFO    : Bus 30156	: V=0.9667795, theta=-45.774137 -> V=1.0, theta=0.0
% INFO    : Bus 30157	: V=0.976172, theta=-44.229831 -> V=1.0, theta=0.0
% INFO    : Bus 30158	: V=0.9756268, theta=-44.27125 -> V=1.0, theta=0.0
% INFO    : Bus 30159	: V=0.964822, theta=-45.92519 -> V=1.0, theta=0.0
% INFO    : Bus 30160	: V=0.9658279, theta=-45.888538 -> V=1.0, theta=0.0
% INFO    : Bus 30161	: V=0.9659164, theta=-45.886154 -> V=1.0, theta=0.0
% INFO    : Bus 30162	: V=0.9646127, theta=-45.916575 -> V=1.0, theta=0.0
% INFO    : Bus 30163	: V=0.9647105, theta=-45.93009 -> V=1.0, theta=0.0
% INFO    : Bus 30164	: V=0.9644468, theta=-45.949662 -> V=1.0, theta=0.0
% INFO    : Bus 30165	: V=0.9636452, theta=-45.958894 -> V=1.0, theta=0.0
% INFO    : Bus 30166	: V=0.9639064, theta=-45.941346 -> V=1.0, theta=0.0
% INFO    : Bus 30167	: V=0.9623485, theta=-46.057718 -> V=1.0, theta=0.0
% INFO    : Bus 30168	: V=0.9621545, theta=-46.062914 -> V=1.0, theta=0.0
% INFO    : Bus 30169	: V=0.9651877, theta=-45.916306 -> V=1.0, theta=0.0
% INFO    : Bus 30170	: V=0.9647147, theta=-45.940476 -> V=1.0, theta=0.0
% INFO    : Bus 30171	: V=0.9650392, theta=-45.920475 -> V=1.0, theta=0.0
% INFO    : Bus 30172	: V=0.966537, theta=-45.774518 -> V=1.0, theta=0.0
% INFO    : Bus 30173	: V=0.9674767, theta=-45.696673 -> V=1.0, theta=0.0
% INFO    : Bus 30174	: V=0.9679134, theta=-45.659475 -> V=1.0, theta=0.0
% INFO    : Bus 30175	: V=0.9690766, theta=-45.55489 -> V=1.0, theta=0.0
% INFO    : Bus 30176	: V=0.9706212, theta=-45.409738 -> V=1.0, theta=0.0
% INFO    : Bus 30177	: V=0.9756816, theta=-44.425365 -> V=1.0, theta=0.0
% INFO    : Bus 30178	: V=0.970648, theta=-45.37857 -> V=1.0, theta=0.0
% INFO    : Bus 30179	: V=0.9702203, theta=-45.421001 -> V=1.0, theta=0.0
% INFO    : Bus 30180	: V=0.9733074, theta=-44.93174 -> V=1.0, theta=0.0
% INFO    : Bus 30181	: V=0.9712209, theta=-45.321731 -> V=1.0, theta=0.0
% INFO    : Bus 30182	: V=0.9761417, theta=-44.364223 -> V=1.0, theta=0.0
% INFO    : Bus 30183	: V=0.9725964, theta=-45.187631 -> V=1.0, theta=0.0
% INFO    : Bus 30184	: V=0.97222, theta=-45.226157 -> V=1.0, theta=0.0
% INFO    : Bus 30185	: V=0.9768271, theta=-44.27397 -> V=1.0, theta=0.0
% INFO    : Bus 30186	: V=0.972786, theta=-45.155584 -> V=1.0, theta=0.0
% INFO    : Bus 30187	: V=0.973319, theta=-45.122848 -> V=1.0, theta=0.0
% INFO    : Bus 30188	: V=0.9628006, theta=-46.017132 -> V=1.0, theta=0.0
% INFO    : Bus 30189	: V=0.9615328, theta=-46.077334 -> V=1.0, theta=0.0
% INFO    : Bus 30190	: V=0.9622368, theta=-46.057459 -> V=1.0, theta=0.0
% INFO    : Bus 30191	: V=0.9626683, theta=-46.020801 -> V=1.0, theta=0.0
% INFO    : Bus 30192	: V=0.9722429, theta=-45.54581 -> V=1.0, theta=0.0
% INFO    : Bus 30193	: V=0.9801752, theta=-44.129509 -> V=1.0, theta=0.0
% INFO    : Bus 30194	: V=0.9787125, theta=-44.264886 -> V=1.0, theta=0.0
% INFO    : Bus 30195	: V=0.971046, theta=-46.013746 -> V=1.0, theta=0.0
% INFO    : Bus 30196	: V=0.9779177, theta=-44.468215 -> V=1.0, theta=0.0
% INFO    : Bus 30197	: V=0.9661746, theta=-46.442625 -> V=1.0, theta=0.0
% INFO    : Bus 30198	: V=0.9675523, theta=-46.34467 -> V=1.0, theta=0.0
% INFO    : Bus 30199	: V=0.9641433, theta=-46.552379 -> V=1.0, theta=0.0
% INFO    : Bus 30200	: V=0.965582, theta=-46.47576 -> V=1.0, theta=0.0
% INFO    : Bus 30201	: V=0.9651714, theta=-46.510882 -> V=1.0, theta=0.0
% INFO    : Bus 30202	: V=0.9649751, theta=-46.490565 -> V=1.0, theta=0.0
% INFO    : Bus 30203	: V=0.9655956, theta=-46.44672 -> V=1.0, theta=0.0
% INFO    : Bus 30204	: V=0.9747444, theta=-44.824895 -> V=1.0, theta=0.0
% INFO    : Bus 30205	: V=0.9659392, theta=-46.426577 -> V=1.0, theta=0.0
% INFO    : Bus 30206	: V=0.9656549, theta=-46.437334 -> V=1.0, theta=0.0
% INFO    : Bus 30207	: V=0.9666801, theta=-46.406087 -> V=1.0, theta=0.0
% INFO    : Bus 30208	: V=0.9661649, theta=-46.424674 -> V=1.0, theta=0.0
% INFO    : Bus 30209	: V=0.9655865, theta=-46.458919 -> V=1.0, theta=0.0
% INFO    : Bus 30210	: V=0.9660906, theta=-46.422767 -> V=1.0, theta=0.0
% INFO    : Bus 30211	: V=0.9656705, theta=-46.446144 -> V=1.0, theta=0.0
% INFO    : Bus 30212	: V=0.9658158, theta=-46.437327 -> V=1.0, theta=0.0
% INFO    : Bus 30213	: V=0.9768984, theta=-44.590833 -> V=1.0, theta=0.0
% INFO    : Bus 30214	: V=0.9676183, theta=-46.279336 -> V=1.0, theta=0.0
% INFO    : Bus 30215	: V=0.9692398, theta=-46.195489 -> V=1.0, theta=0.0
% INFO    : Bus 30216	: V=0.9695489, theta=-45.809806 -> V=1.0, theta=0.0
% INFO    : Bus 30217	: V=0.9783937, theta=-44.428604 -> V=1.0, theta=0.0
% INFO    : Bus 30218	: V=0.9781692, theta=-44.451623 -> V=1.0, theta=0.0
% INFO    : Bus 30219	: V=0.9779089, theta=-44.482658 -> V=1.0, theta=0.0
% INFO    : Bus 30220	: V=0.9767722, theta=-44.584892 -> V=1.0, theta=0.0
% INFO    : Bus 30221	: V=0.972443, theta=-45.83232 -> V=1.0, theta=0.0
% INFO    : Bus 30222	: V=0.9732033, theta=-44.958902 -> V=1.0, theta=0.0
% INFO    : Bus 30223	: V=0.973332, theta=-44.946625 -> V=1.0, theta=0.0
% INFO    : Bus 30224	: V=0.9685871, theta=-45.886969 -> V=1.0, theta=0.0
% INFO    : Bus 30225	: V=0.9681039, theta=-45.910933 -> V=1.0, theta=0.0
% INFO    : Bus 30226	: V=0.9687987, theta=-45.873412 -> V=1.0, theta=0.0
% INFO    : Bus 30227	: V=0.9728638, theta=-45.872025 -> V=1.0, theta=0.0
% INFO    : Bus 30228	: V=0.972532, theta=-45.950279 -> V=1.0, theta=0.0
% INFO    : Bus 30229	: V=0.968886, theta=-46.231749 -> V=1.0, theta=0.0
% INFO    : Bus 30230	: V=0.9703991, theta=-46.187805 -> V=1.0, theta=0.0
% INFO    : Bus 30231	: V=0.9688259, theta=-46.239127 -> V=1.0, theta=0.0
% INFO    : Bus 30232	: V=0.9704129, theta=-46.162152 -> V=1.0, theta=0.0
% INFO    : Bus 30233	: V=0.9671275, theta=-46.31802 -> V=1.0, theta=0.0
% INFO    : Bus 30234	: V=0.9683643, theta=-46.326039 -> V=1.0, theta=0.0
% INFO    : Bus 30235	: V=0.9664508, theta=-46.408834 -> V=1.0, theta=0.0
% INFO    : Bus 30236	: V=0.9661899, theta=-46.427035 -> V=1.0, theta=0.0
% INFO    : Bus 30237	: V=0.966789, theta=-46.391258 -> V=1.0, theta=0.0
% INFO    : Bus 30238	: V=0.9666365, theta=-46.413218 -> V=1.0, theta=0.0
% INFO    : Bus 30239	: V=0.9662779, theta=-46.419613 -> V=1.0, theta=0.0
% INFO    : Bus 30240	: V=0.9664274, theta=-46.411745 -> V=1.0, theta=0.0
% INFO    : Bus 30241	: V=0.9752447, theta=-44.798531 -> V=1.0, theta=0.0
% INFO    : Bus 30242	: V=0.9747154, theta=-44.824742 -> V=1.0, theta=0.0
% INFO    : Bus 30243	: V=0.9751993, theta=-44.774284 -> V=1.0, theta=0.0
% INFO    : Bus 30244	: V=0.9686328, theta=-46.069934 -> V=1.0, theta=0.0
% INFO    : Bus 30245	: V=0.9692629, theta=-45.957519 -> V=1.0, theta=0.0
% INFO    : Bus 30246	: V=0.9675442, theta=-46.218945 -> V=1.0, theta=0.0
% INFO    : Bus 30247	: V=0.9675331, theta=-46.219251 -> V=1.0, theta=0.0
% INFO    : Bus 30248	: V=0.967826, theta=-46.178216 -> V=1.0, theta=0.0
% INFO    : Bus 30249	: V=0.9680764, theta=-46.142954 -> V=1.0, theta=0.0
% INFO    : Bus 30250	: V=0.9685188, theta=-46.072352 -> V=1.0, theta=0.0
% INFO    : Bus 30251	: V=0.9676104, theta=-46.378153 -> V=1.0, theta=0.0
% INFO    : Bus 30252	: V=0.9650903, theta=-46.4679 -> V=1.0, theta=0.0
% INFO    : Bus 30253	: V=0.9658984, theta=-46.437273 -> V=1.0, theta=0.0
% INFO    : Bus 30254	: V=0.9800356, theta=-44.600333 -> V=1.0, theta=0.0
% INFO    : Bus 30255	: V=0.9689763, theta=-46.283395 -> V=1.0, theta=0.0
% INFO    : Bus 30256	: V=0.9685562, theta=-46.294065 -> V=1.0, theta=0.0
% INFO    : Bus 30257	: V=0.9677504, theta=-46.367553 -> V=1.0, theta=0.0
% INFO    : Bus 30258	: V=0.9681229, theta=-46.357193 -> V=1.0, theta=0.0
% INFO    : Bus 30259	: V=0.9705803, theta=-46.183338 -> V=1.0, theta=0.0
% INFO    : Bus 30260	: V=0.9697795, theta=-46.268913 -> V=1.0, theta=0.0
% INFO    : Bus 30261	: V=0.9708972, theta=-46.205878 -> V=1.0, theta=0.0
% INFO    : Bus 30262	: V=0.9730275, theta=-45.984173 -> V=1.0, theta=0.0
% INFO    : Bus 30263	: V=0.9865322, theta=-44.482233 -> V=1.0, theta=0.0
% INFO    : Bus 30264	: V=0.9675907, theta=-46.001437 -> V=1.0, theta=0.0
% INFO    : Bus 30265	: V=0.9737241, theta=-45.963044 -> V=1.0, theta=0.0
% INFO    : Bus 30266	: V=0.9751009, theta=-45.824604 -> V=1.0, theta=0.0
% INFO    : Bus 30267	: V=0.9687661, theta=-45.95285 -> V=1.0, theta=0.0
% INFO    : Bus 30268	: V=0.9683707, theta=-45.981607 -> V=1.0, theta=0.0
% INFO    : Bus 30269	: V=0.96914, theta=-45.848316 -> V=1.0, theta=0.0
% INFO    : Bus 30270	: V=0.9745644, theta=-44.829009 -> V=1.0, theta=0.0
% INFO    : Bus 30271	: V=0.9719626, theta=-45.761025 -> V=1.0, theta=0.0
% INFO    : Bus 30272	: V=0.9724267, theta=-45.730023 -> V=1.0, theta=0.0
% INFO    : Bus 30273	: V=0.9893492, theta=-44.790419 -> V=1.0, theta=0.0
% INFO    : Bus 30274	: V=0.9735037, theta=-45.695369 -> V=1.0, theta=0.0
% INFO    : Bus 30275	: V=0.9733934, theta=-45.638513 -> V=1.0, theta=0.0
% INFO    : Bus 30276	: V=0.9995388, theta=-43.925626 -> V=1.0, theta=0.0
% INFO    : Bus 30277	: V=0.9753911, theta=-45.606537 -> V=1.0, theta=0.0
% INFO    : Bus 30278	: V=0.9875231, theta=-44.448565 -> V=1.0, theta=0.0
% INFO    : Bus 30279	: V=0.9830673, theta=-45.214142 -> V=1.0, theta=0.0
% INFO    : Bus 30280	: V=0.9921613, theta=-44.256534 -> V=1.0, theta=0.0
% INFO    : Bus 30281	: V=1.0020292, theta=-43.816505 -> V=1.0, theta=0.0
% INFO    : Bus 30282	: V=0.9987657, theta=-44.139439 -> V=1.0, theta=0.0
% INFO    : Bus 30283	: V=0.9786541, theta=-44.267022 -> V=1.0, theta=0.0
% INFO    : Bus 30284	: V=1.0041742, theta=-43.718756 -> V=1.0, theta=0.0
% INFO    : Bus 30285	: V=0.9740221, theta=-44.478607 -> V=1.0, theta=0.0
% INFO    : Bus 30286	: V=1.0041147, theta=-43.690086 -> V=1.0, theta=0.0
% INFO    : Bus 30287	: V=0.97811, theta=-44.187681 -> V=1.0, theta=0.0
% INFO    : Bus 30288	: V=0.9796546, theta=-44.230905 -> V=1.0, theta=0.0
% INFO    : Bus 30289	: V=0.9777732, theta=-44.213246 -> V=1.0, theta=0.0
% INFO    : Bus 30290	: V=0.9753851, theta=-44.402206 -> V=1.0, theta=0.0
% INFO    : Bus 30291	: V=0.9781985, theta=-44.10295 -> V=1.0, theta=0.0
% INFO    : Bus 30292	: V=0.9768525, theta=-44.277255 -> V=1.0, theta=0.0
% INFO    : Bus 30293	: V=0.976542, theta=-43.871856 -> V=1.0, theta=0.0
% INFO    : Bus 30294	: V=0.9778026, theta=-44.139571 -> V=1.0, theta=0.0
% INFO    : Bus 30295	: V=0.973861, theta=-45.462073 -> V=1.0, theta=0.0
% INFO    : Bus 30296	: V=0.9713432, theta=-45.506872 -> V=1.0, theta=0.0
% INFO    : Bus 30297	: V=0.9826275, theta=-43.167919 -> V=1.0, theta=0.0
% INFO    : Bus 30298	: V=0.9742334, theta=-44.939628 -> V=1.0, theta=0.0
% INFO    : Bus 30299	: V=0.9767728, theta=-44.179218 -> V=1.0, theta=0.0
% INFO    : Bus 30300	: V=0.9819612, theta=-43.360317 -> V=1.0, theta=0.0
% INFO    : Bus 30301	: V=0.9742286, theta=-44.472768 -> V=1.0, theta=0.0
% INFO    : Bus 30302	: V=0.9724477, theta=-45.24545 -> V=1.0, theta=0.0
% INFO    : Bus 30303	: V=0.973374, theta=-45.09377 -> V=1.0, theta=0.0
% INFO    : Bus 30304	: V=0.9742728, theta=-44.348945 -> V=1.0, theta=0.0
% INFO    : Bus 30305	: V=0.9715, theta=-45.395131 -> V=1.0, theta=0.0
% INFO    : Bus 30306	: V=0.9730931, theta=-44.738658 -> V=1.0, theta=0.0
% INFO    : Bus 30307	: V=0.9708628, theta=-45.653828 -> V=1.0, theta=0.0
% INFO    : Bus 30308	: V=0.973671, theta=-44.681647 -> V=1.0, theta=0.0
% INFO    : Bus 30309	: V=0.9742909, theta=-44.616757 -> V=1.0, theta=0.0
% INFO    : Bus 30310	: V=0.9731704, theta=-44.782207 -> V=1.0, theta=0.0
% INFO    : Bus 30311	: V=0.9693723, theta=-45.589811 -> V=1.0, theta=0.0
% INFO    : Bus 30312	: V=0.9724113, theta=-44.870255 -> V=1.0, theta=0.0
% INFO    : Bus 30313	: V=0.9676147, theta=-45.896783 -> V=1.0, theta=0.0
% INFO    : Bus 30314	: V=0.9727219, theta=-44.777866 -> V=1.0, theta=0.0
% INFO    : Bus 30315	: V=0.9687738, theta=-45.854093 -> V=1.0, theta=0.0
% INFO    : Bus 30316	: V=0.9744152, theta=-44.771947 -> V=1.0, theta=0.0
% INFO    : Bus 30317	: V=0.9732597, theta=-44.858833 -> V=1.0, theta=0.0
% INFO    : Bus 30318	: V=0.9721818, theta=-44.895339 -> V=1.0, theta=0.0
% INFO    : Bus 30319	: V=0.9661903, theta=-46.052532 -> V=1.0, theta=0.0
% INFO    : Bus 30320	: V=0.9654442, theta=-46.135613 -> V=1.0, theta=0.0
% INFO    : Bus 30321	: V=0.9661342, theta=-46.063044 -> V=1.0, theta=0.0
% INFO    : Bus 30322	: V=0.9727971, theta=-45.117099 -> V=1.0, theta=0.0
% INFO    : Bus 30323	: V=0.9656915, theta=-46.069251 -> V=1.0, theta=0.0
% INFO    : Bus 30324	: V=0.9654405, theta=-46.108619 -> V=1.0, theta=0.0
% INFO    : Bus 30325	: V=0.9631003, theta=-46.367623 -> V=1.0, theta=0.0
% INFO    : Bus 30326	: V=0.9649415, theta=-46.190817 -> V=1.0, theta=0.0
% INFO    : Bus 30327	: V=0.9643233, theta=-46.23779 -> V=1.0, theta=0.0
% INFO    : Bus 30328	: V=0.9714121, theta=-44.958467 -> V=1.0, theta=0.0
% INFO    : Bus 30329	: V=0.9636268, theta=-46.277908 -> V=1.0, theta=0.0
% INFO    : Bus 30330	: V=0.9618356, theta=-46.487057 -> V=1.0, theta=0.0
% INFO    : Bus 30331	: V=0.9637134, theta=-46.321746 -> V=1.0, theta=0.0
% INFO    : Bus 30332	: V=0.9630863, theta=-46.353639 -> V=1.0, theta=0.0
% INFO    : Bus 30333	: V=0.9633804, theta=-46.345332 -> V=1.0, theta=0.0
% INFO    : Bus 30334	: V=0.9639505, theta=-46.291192 -> V=1.0, theta=0.0
% INFO    : Bus 30335	: V=0.9643052, theta=-46.254566 -> V=1.0, theta=0.0
% INFO    : Bus 30336	: V=0.966131, theta=-46.034366 -> V=1.0, theta=0.0
% INFO    : Bus 30337	: V=0.9661913, theta=-46.028141 -> V=1.0, theta=0.0
% INFO    : Bus 30338	: V=0.9835992, theta=-44.022101 -> V=1.0, theta=0.0
% INFO    : Bus 30339	: V=0.9706044, theta=-45.700084 -> V=1.0, theta=0.0
% INFO    : Bus 30340	: V=0.9753906, theta=-45.253651 -> V=1.0, theta=0.0
% INFO    : Bus 30341	: V=0.9742952, theta=-45.373834 -> V=1.0, theta=0.0
% INFO    : Bus 30342	: V=0.973787, theta=-45.396651 -> V=1.0, theta=0.0
% INFO    : Bus 30343	: V=0.9823454, theta=-43.984286 -> V=1.0, theta=0.0
% INFO    : Bus 30344	: V=0.9769943, theta=-45.078412 -> V=1.0, theta=0.0
% INFO    : Bus 30345	: V=0.9767592, theta=-45.084818 -> V=1.0, theta=0.0
% INFO    : Bus 30346	: V=0.9775163, theta=-45.031155 -> V=1.0, theta=0.0
% INFO    : Bus 30347	: V=0.977562, theta=-45.030022 -> V=1.0, theta=0.0
% INFO    : Bus 30348	: V=0.9766554, theta=-44.689225 -> V=1.0, theta=0.0
% INFO    : Bus 30349	: V=0.9780579, theta=-44.748199 -> V=1.0, theta=0.0
% INFO    : Bus 30350	: V=0.9923265, theta=-42.149044 -> V=1.0, theta=0.0
% INFO    : Bus 30351	: V=0.9841483, theta=-43.553281 -> V=1.0, theta=0.0
% INFO    : Bus 30352	: V=0.9916761, theta=-42.206546 -> V=1.0, theta=0.0
% INFO    : Bus 30353	: V=0.9912948, theta=-42.239432 -> V=1.0, theta=0.0
% INFO    : Bus 30354	: V=0.977392, theta=-44.824321 -> V=1.0, theta=0.0
% INFO    : Bus 30355	: V=0.9806798, theta=-44.026734 -> V=1.0, theta=0.0
% INFO    : Bus 30356	: V=0.9830982, theta=-43.909419 -> V=1.0, theta=0.0
% INFO    : Bus 30357	: V=0.9852867, theta=-43.445529 -> V=1.0, theta=0.0
% INFO    : Bus 30358	: V=0.9764967, theta=-44.914189 -> V=1.0, theta=0.0
% INFO    : Bus 30359	: V=0.9762242, theta=-44.949226 -> V=1.0, theta=0.0
% INFO    : Bus 30360	: V=0.9737719, theta=-45.028081 -> V=1.0, theta=0.0
% INFO    : Bus 30361	: V=0.9733213, theta=-44.9099 -> V=1.0, theta=0.0
% INFO    : Bus 30362	: V=0.9777825, theta=-44.157935 -> V=1.0, theta=0.0
% INFO    : Bus 30363	: V=0.9776594, theta=-44.164171 -> V=1.0, theta=0.0
% INFO    : Bus 30364	: V=0.9794705, theta=-43.871887 -> V=1.0, theta=0.0
% INFO    : Bus 30365	: V=0.9832427, theta=-43.267224 -> V=1.0, theta=0.0
% INFO    : Bus 30366	: V=0.9810675, theta=-43.679835 -> V=1.0, theta=0.0
% INFO    : Bus 30367	: V=0.9807909, theta=-43.701974 -> V=1.0, theta=0.0
% INFO    : Bus 30368	: V=0.978576, theta=-44.3767 -> V=1.0, theta=0.0
% INFO    : Bus 30369	: V=0.9821488, theta=-43.497101 -> V=1.0, theta=0.0
% INFO    : Bus 30370	: V=0.9817047, theta=-43.557267 -> V=1.0, theta=0.0
% INFO    : Bus 30371	: V=0.9791101, theta=-44.271083 -> V=1.0, theta=0.0
% INFO    : Bus 30372	: V=0.9808605, theta=-43.69207 -> V=1.0, theta=0.0
% INFO    : Bus 30373	: V=0.9801189, theta=-43.780655 -> V=1.0, theta=0.0
% INFO    : Bus 30374	: V=0.9802643, theta=-43.832252 -> V=1.0, theta=0.0
% INFO    : Bus 30375	: V=0.9728368, theta=-45.031463 -> V=1.0, theta=0.0
% INFO    : Bus 30376	: V=0.9734464, theta=-44.971611 -> V=1.0, theta=0.0
% INFO    : Bus 30377	: V=0.978768, theta=-44.040941 -> V=1.0, theta=0.0
% INFO    : Bus 30378	: V=0.9792394, theta=-43.974461 -> V=1.0, theta=0.0
% INFO    : Bus 30379	: V=0.9804611, theta=-43.862217 -> V=1.0, theta=0.0
% INFO    : Bus 30380	: V=0.9792145, theta=-44.452467 -> V=1.0, theta=0.0
% INFO    : Bus 30381	: V=0.9765569, theta=-44.753895 -> V=1.0, theta=0.0
% INFO    : Bus 30382	: V=0.9809435, theta=-43.819078 -> V=1.0, theta=0.0
% INFO    : Bus 30383	: V=0.9772085, theta=-44.661928 -> V=1.0, theta=0.0
% INFO    : Bus 30384	: V=0.9751736, theta=-44.856959 -> V=1.0, theta=0.0
% INFO    : Bus 30385	: V=0.9764193, theta=-44.71855 -> V=1.0, theta=0.0
% INFO    : Bus 30386	: V=0.9792395, theta=-44.364603 -> V=1.0, theta=0.0
% INFO    : Bus 30387	: V=0.9789114, theta=-44.355532 -> V=1.0, theta=0.0
% INFO    : Bus 30388	: V=0.9796972, theta=-44.33533 -> V=1.0, theta=0.0
% INFO    : Bus 30389	: V=0.9754793, theta=-44.664319 -> V=1.0, theta=0.0
% INFO    : Bus 30390	: V=0.9760413, theta=-44.097231 -> V=1.0, theta=0.0
% INFO    : Bus 30391	: V=0.9777841, theta=-43.658357 -> V=1.0, theta=0.0
% INFO    : Bus 30392	: V=0.9781911, theta=-43.735108 -> V=1.0, theta=0.0
% INFO    : Bus 30393	: V=0.9765701, theta=-43.817719 -> V=1.0, theta=0.0
% INFO    : Bus 30394	: V=0.97863, theta=-43.936418 -> V=1.0, theta=0.0
% INFO    : Bus 30395	: V=0.9769767, theta=-43.796111 -> V=1.0, theta=0.0
% INFO    : Bus 30396	: V=0.9777648, theta=-43.673587 -> V=1.0, theta=0.0
% INFO    : Bus 30397	: V=0.9787278, theta=-43.637173 -> V=1.0, theta=0.0
% INFO    : Bus 30398	: V=0.9759713, theta=-43.661053 -> V=1.0, theta=0.0
% INFO    : Bus 30399	: V=0.9817853, theta=-43.196919 -> V=1.0, theta=0.0
% INFO    : Bus 30400	: V=0.9919838, theta=-41.709338 -> V=1.0, theta=0.0
% INFO    : Bus 30401	: V=0.9792901, theta=-43.861055 -> V=1.0, theta=0.0
% INFO    : Bus 30402	: V=0.9816542, theta=-43.493885 -> V=1.0, theta=0.0
% INFO    : Bus 30403	: V=0.9778536, theta=-43.822197 -> V=1.0, theta=0.0
% INFO    : Bus 30404	: V=0.9910765, theta=-41.82408 -> V=1.0, theta=0.0
% INFO    : Bus 30405	: V=0.9780951, theta=-43.890412 -> V=1.0, theta=0.0
% INFO    : Bus 30406	: V=0.9778406, theta=-43.757849 -> V=1.0, theta=0.0
% INFO    : Bus 30407	: V=0.9758331, theta=-43.84041 -> V=1.0, theta=0.0
% INFO    : Bus 30408	: V=0.9911778, theta=-41.784143 -> V=1.0, theta=0.0
% INFO    : Bus 30409	: V=0.978362, theta=-43.008285 -> V=1.0, theta=0.0
% INFO    : Bus 30410	: V=0.9972756, theta=-40.870317 -> V=1.0, theta=0.0
% INFO    : Bus 30411	: V=0.9930093, theta=-41.175689 -> V=1.0, theta=0.0
% INFO    : Bus 30412	: V=0.9986462, theta=-40.837731 -> V=1.0, theta=0.0
% INFO    : Bus 30413	: V=0.9866563, theta=-42.656078 -> V=1.0, theta=0.0
% INFO    : Bus 30414	: V=0.9858715, theta=-42.772929 -> V=1.0, theta=0.0
% INFO    : Bus 30415	: V=0.9870112, theta=-42.81354 -> V=1.0, theta=0.0
% INFO    : Bus 30416	: V=0.9858575, theta=-42.84587 -> V=1.0, theta=0.0
% INFO    : Bus 30417	: V=0.9866998, theta=-42.682076 -> V=1.0, theta=0.0
% INFO    : Bus 30418	: V=0.9937308, theta=-41.657093 -> V=1.0, theta=0.0
% INFO    : Bus 30419	: V=0.995253, theta=-41.320809 -> V=1.0, theta=0.0
% INFO    : Bus 30420	: V=0.9944194, theta=-41.46893 -> V=1.0, theta=0.0
% INFO    : Bus 30421	: V=0.9882429, theta=-42.876871 -> V=1.0, theta=0.0
% INFO    : Bus 30422	: V=0.984658, theta=-42.827387 -> V=1.0, theta=0.0
% INFO    : Bus 30423	: V=0.984251, theta=-43.058938 -> V=1.0, theta=0.0
% INFO    : Bus 30424	: V=0.985591, theta=-43.015794 -> V=1.0, theta=0.0
% INFO    : Bus 30425	: V=0.9863527, theta=-42.854719 -> V=1.0, theta=0.0
% INFO    : Bus 30426	: V=1.0059056, theta=-40.165726 -> V=1.0, theta=0.0
% INFO    : Bus 30427	: V=0.9845403, theta=-42.934464 -> V=1.0, theta=0.0
% INFO    : Bus 30428	: V=0.9759549, theta=-43.450406 -> V=1.0, theta=0.0
% INFO    : Bus 30429	: V=0.9693699, theta=-44.189143 -> V=1.0, theta=0.0
% INFO    : Bus 30430	: V=0.9837379, theta=-43.7782 -> V=1.0, theta=0.0
% INFO    : Bus 30431	: V=0.9816478, theta=-44.062974 -> V=1.0, theta=0.0
% INFO    : Bus 30432	: V=0.9819786, theta=-44.023507 -> V=1.0, theta=0.0
% INFO    : Bus 30433	: V=0.9827901, theta=-43.950714 -> V=1.0, theta=0.0
% INFO    : Bus 30434	: V=0.9858778, theta=-43.457517 -> V=1.0, theta=0.0
% INFO    : Bus 30435	: V=1.0057293, theta=-39.695598 -> V=1.0, theta=0.0
% INFO    : Bus 30436	: V=0.9868217, theta=-43.074527 -> V=1.0, theta=0.0
% INFO    : Bus 30437	: V=0.9882738, theta=-42.87567 -> V=1.0, theta=0.0
% INFO    : Bus 30438	: V=0.9894088, theta=-42.718781 -> V=1.0, theta=0.0
% INFO    : Bus 30439	: V=0.9863843, theta=-43.178585 -> V=1.0, theta=0.0
% INFO    : Bus 30440	: V=0.9814717, theta=-43.801763 -> V=1.0, theta=0.0
% INFO    : Bus 30441	: V=0.9827142, theta=-43.708451 -> V=1.0, theta=0.0
% INFO    : Bus 30442	: V=0.984849, theta=-43.377545 -> V=1.0, theta=0.0
% INFO    : Bus 30443	: V=0.9835123, theta=-43.649923 -> V=1.0, theta=0.0
% INFO    : Bus 30444	: V=0.9832769, theta=-43.6844 -> V=1.0, theta=0.0
% INFO    : Bus 30445	: V=0.9841326, theta=-43.505205 -> V=1.0, theta=0.0
% INFO    : Bus 30446	: V=0.9835875, theta=-43.632241 -> V=1.0, theta=0.0
% INFO    : Bus 30447	: V=0.9808648, theta=-44.19602 -> V=1.0, theta=0.0
% INFO    : Bus 30448	: V=0.9830441, theta=-43.731451 -> V=1.0, theta=0.0
% INFO    : Bus 30449	: V=0.9829872, theta=-43.728514 -> V=1.0, theta=0.0
% INFO    : Bus 30450	: V=0.982744, theta=-43.751993 -> V=1.0, theta=0.0
% INFO    : Bus 30451	: V=0.9772434, theta=-44.854391 -> V=1.0, theta=0.0
% INFO    : Bus 30452	: V=0.9790328, theta=-44.783415 -> V=1.0, theta=0.0
% INFO    : Bus 30453	: V=0.983002, theta=-43.760396 -> V=1.0, theta=0.0
% INFO    : Bus 30454	: V=0.9763979, theta=-45.013806 -> V=1.0, theta=0.0
% INFO    : Bus 30455	: V=0.9623686, theta=-46.443063 -> V=1.0, theta=0.0
% INFO    : Bus 30456	: V=0.960064, theta=-46.592493 -> V=1.0, theta=0.0
% INFO    : Bus 30457	: V=0.9608363, theta=-46.574826 -> V=1.0, theta=0.0
% INFO    : Bus 30458	: V=0.9600345, theta=-46.614733 -> V=1.0, theta=0.0
% INFO    : Bus 30459	: V=0.9625539, theta=-46.31525 -> V=1.0, theta=0.0
% INFO    : Bus 30460	: V=0.9629034, theta=-46.280721 -> V=1.0, theta=0.0
% INFO    : Bus 30461	: V=0.963492, theta=-46.204913 -> V=1.0, theta=0.0
% INFO    : Bus 30462	: V=0.9641531, theta=-46.094896 -> V=1.0, theta=0.0
% INFO    : Bus 30463	: V=0.9668027, theta=-45.855216 -> V=1.0, theta=0.0
% INFO    : Bus 30464	: V=0.9657583, theta=-45.958211 -> V=1.0, theta=0.0
% INFO    : Bus 30465	: V=0.9652415, theta=-45.951362 -> V=1.0, theta=0.0
% INFO    : Bus 30466	: V=0.968083, theta=-45.745441 -> V=1.0, theta=0.0
% INFO    : Bus 30467	: V=0.9739124, theta=-44.398806 -> V=1.0, theta=0.0
% INFO    : Bus 30468	: V=0.96889, theta=-45.601998 -> V=1.0, theta=0.0
% INFO    : Bus 30469	: V=0.9668732, theta=-45.804043 -> V=1.0, theta=0.0
% INFO    : Bus 30470	: V=0.9662485, theta=-45.819582 -> V=1.0, theta=0.0
% INFO    : Bus 30471	: V=0.9651458, theta=-45.994408 -> V=1.0, theta=0.0
% INFO    : Bus 30472	: V=0.9662275, theta=-45.884487 -> V=1.0, theta=0.0
% INFO    : Bus 30473	: V=0.967916, theta=-45.738383 -> V=1.0, theta=0.0
% INFO    : Bus 30474	: V=0.9776271, theta=-43.903284 -> V=1.0, theta=0.0
% INFO    : Bus 30475	: V=0.9685709, theta=-45.630738 -> V=1.0, theta=0.0
% INFO    : Bus 30476	: V=0.9686891, theta=-45.596729 -> V=1.0, theta=0.0
% INFO    : Bus 30477	: V=0.9785033, theta=-43.819605 -> V=1.0, theta=0.0
% INFO    : Bus 30478	: V=0.9679059, theta=-45.77743 -> V=1.0, theta=0.0
% INFO    : Bus 30479	: V=0.968372, theta=-45.74875 -> V=1.0, theta=0.0
% INFO    : Bus 30480	: V=0.967786, theta=-45.772647 -> V=1.0, theta=0.0
% INFO    : Bus 30481	: V=0.9683552, theta=-45.64126 -> V=1.0, theta=0.0
% INFO    : Bus 30482	: V=0.9688207, theta=-45.611148 -> V=1.0, theta=0.0
% INFO    : Bus 30483	: V=0.971359, theta=-45.362104 -> V=1.0, theta=0.0
% INFO    : Bus 30484	: V=0.9727625, theta=-45.206216 -> V=1.0, theta=0.0
% INFO    : Bus 30485	: V=0.9791514, theta=-43.758264 -> V=1.0, theta=0.0
% INFO    : Bus 30486	: V=0.9692783, theta=-45.521407 -> V=1.0, theta=0.0
% INFO    : Bus 30487	: V=0.9796521, theta=-43.700182 -> V=1.0, theta=0.0
% INFO    : Bus 30488	: V=0.9742273, theta=-44.762402 -> V=1.0, theta=0.0
% INFO    : Bus 30489	: V=0.9790442, theta=-43.763765 -> V=1.0, theta=0.0
% INFO    : Bus 30490	: V=0.9699259, theta=-45.468703 -> V=1.0, theta=0.0
% INFO    : Bus 30491	: V=0.9682281, theta=-45.615331 -> V=1.0, theta=0.0
% INFO    : Bus 30492	: V=0.9755905, theta=-44.567121 -> V=1.0, theta=0.0
% INFO    : Bus 30493	: V=0.9674766, theta=-45.634003 -> V=1.0, theta=0.0
% INFO    : Bus 30494	: V=0.9748889, theta=-44.619604 -> V=1.0, theta=0.0
% INFO    : Bus 30495	: V=0.975312, theta=-44.664673 -> V=1.0, theta=0.0
% INFO    : Bus 30496	: V=0.9759507, theta=-44.651338 -> V=1.0, theta=0.0
% INFO    : Bus 30497	: V=0.9805704, theta=-43.589502 -> V=1.0, theta=0.0
% INFO    : Bus 30498	: V=0.9770756, theta=-44.460777 -> V=1.0, theta=0.0
% INFO    : Bus 30499	: V=0.9904702, theta=-41.898905 -> V=1.0, theta=0.0
% INFO    : Bus 30500	: V=0.976469, theta=-44.610081 -> V=1.0, theta=0.0
% INFO    : Bus 30501	: V=0.9749805, theta=-44.912456 -> V=1.0, theta=0.0
% INFO    : Bus 30502	: V=0.9766574, theta=-44.167009 -> V=1.0, theta=0.0
% INFO    : Bus 30503	: V=0.9784029, theta=-43.950721 -> V=1.0, theta=0.0
% INFO    : Bus 30504	: V=1.0078639, theta=-39.209393 -> V=1.0, theta=0.0
% INFO    : Bus 30505	: V=0.9928645, theta=-41.575556 -> V=1.0, theta=0.0
% INFO    : Bus 30506	: V=0.9769241, theta=-44.138016 -> V=1.0, theta=0.0
% INFO    : Bus 30507	: V=0.9740873, theta=-44.321921 -> V=1.0, theta=0.0
% INFO    : Bus 30508	: V=0.9759787, theta=-44.012525 -> V=1.0, theta=0.0
% INFO    : Bus 30509	: V=0.9762281, theta=-43.920149 -> V=1.0, theta=0.0
% INFO    : Bus 30510	: V=0.9769401, theta=-43.925202 -> V=1.0, theta=0.0
% INFO    : Bus 30511	: V=0.9761529, theta=-44.054027 -> V=1.0, theta=0.0
% INFO    : Bus 30512	: V=0.9760502, theta=-44.099492 -> V=1.0, theta=0.0
% INFO    : Bus 30513	: V=0.9784812, theta=-43.77105 -> V=1.0, theta=0.0
% INFO    : Bus 30514	: V=0.9771263, theta=-43.836463 -> V=1.0, theta=0.0
% INFO    : Bus 30515	: V=0.9697208, theta=-46.134908 -> V=1.0, theta=0.0
% INFO    : Bus 30516	: V=1.0089147, theta=-39.541623 -> V=1.0, theta=0.0
% INFO    : Bus 30517	: V=0.9769468, theta=-44.298237 -> V=1.0, theta=0.0
% INFO    : Bus 30518	: V=0.9735897, theta=-45.986918 -> V=1.0, theta=0.0
% INFO    : Bus 30519	: V=0.9716409, theta=-45.499644 -> V=1.0, theta=0.0
% INFO    : Bus 30520	: V=1.0037783, theta=-40.313337 -> V=1.0, theta=0.0
% INFO    : Bus 30521	: V=0.9778763, theta=-43.013419 -> V=1.0, theta=0.0
% INFO    : Bus 30522	: V=1.0148118, theta=-37.943595 -> V=1.0, theta=0.0
% INFO    : Bus 30523	: V=0.9720889, theta=-45.384707 -> V=1.0, theta=0.0
% INFO    : Bus 30524	: V=1.0096746, theta=-39.307404 -> V=1.0, theta=0.0
% INFO    : Bus 30525	: V=1.0030242, theta=-40.123395 -> V=1.0, theta=0.0
% INFO    : Bus 30526	: V=0.9881963, theta=-42.960835 -> V=1.0, theta=0.0
% INFO    : Bus 30527	: V=0.9940865, theta=-42.193887 -> V=1.0, theta=0.0
% INFO    : Bus 30528	: V=0.9772346, theta=-44.325233 -> V=1.0, theta=0.0
% INFO    : Bus 30529	: V=0.9746013, theta=-44.389535 -> V=1.0, theta=0.0
% INFO    : Bus 30530	: V=0.9687571, theta=-44.944119 -> V=1.0, theta=0.0
% INFO    : Bus 30531	: V=0.9651325, theta=-45.181647 -> V=1.0, theta=0.0
% INFO    : Bus 30532	: V=0.9737188, theta=-45.404562 -> V=1.0, theta=0.0
% INFO    : Bus 30533	: V=0.9963065, theta=-44.968892 -> V=1.0, theta=0.0
% INFO    : Bus 30534	: V=0.9824804, theta=-45.569717 -> V=1.0, theta=0.0
% INFO    : Bus 30535	: V=1.0038135, theta=-43.890963 -> V=1.0, theta=0.0
% INFO    : Bus 30536	: V=0.998106, theta=-44.756783 -> V=1.0, theta=0.0
% INFO    : Bus 30537	: V=0.9985592, theta=-44.747864 -> V=1.0, theta=0.0
% INFO    : Bus 30538	: V=1.0053759, theta=-46.424622 -> V=1.0, theta=0.0
% INFO    : Bus 30539	: V=0.9928717, theta=-47.507094 -> V=1.0, theta=0.0
% INFO    : Bus 30540	: V=1.0105636, theta=-46.890585 -> V=1.0, theta=0.0
% INFO    : Bus 30541	: V=1.0086776, theta=-46.762351 -> V=1.0, theta=0.0
% INFO    : Bus 30542	: V=1.0135767, theta=-47.339178 -> V=1.0, theta=0.0
% INFO    : Bus 30543	: V=1.0170224, theta=-47.663594 -> V=1.0, theta=0.0
% INFO    : Bus 30544	: V=1.0190664, theta=-47.779447 -> V=1.0, theta=0.0
% INFO    : Bus 30545	: V=1.01577, theta=-48.088737 -> V=1.0, theta=0.0
% INFO    : Bus 30546	: V=1.0124539, theta=-48.470917 -> V=1.0, theta=0.0
% INFO    : Bus 30547	: V=1.0091766, theta=-48.855608 -> V=1.0, theta=0.0
% INFO    : Bus 30548	: V=1.0060486, theta=-49.139793 -> V=1.0, theta=0.0
% INFO    : Bus 30549	: V=1.0061719, theta=-49.144735 -> V=1.0, theta=0.0
% INFO    : Bus 30550	: V=1.0059006, theta=-49.214533 -> V=1.0, theta=0.0
% INFO    : Bus 30551	: V=1.007634, theta=-49.000012 -> V=1.0, theta=0.0
% INFO    : Bus 30552	: V=1.0056518, theta=-49.219337 -> V=1.0, theta=0.0
% INFO    : Bus 30553	: V=0.9840942, theta=-43.398686 -> V=1.0, theta=0.0
% INFO    : Bus 30555	: V=0.9927542, theta=-43.461169 -> V=1.0, theta=0.0
% INFO    : Bus 30556	: V=1.0000777, theta=-43.043616 -> V=1.0, theta=0.0
% INFO    : Bus 30557	: V=0.9802461, theta=-44.377811 -> V=1.0, theta=0.0
% INFO    : Bus 30558	: V=0.9876721, theta=-43.72179 -> V=1.0, theta=0.0
% INFO    : Bus 30559	: V=0.984603, theta=-43.99785 -> V=1.0, theta=0.0
% INFO    : Bus 30560	: V=0.9784485, theta=-44.010836 -> V=1.0, theta=0.0
% INFO    : Bus 30561	: V=0.9879403, theta=-43.132835 -> V=1.0, theta=0.0
% INFO    : Bus 30562	: V=0.9732362, theta=-44.583516 -> V=1.0, theta=0.0
% INFO    : Bus 30563	: V=0.9733094, theta=-43.967895 -> V=1.0, theta=0.0
% INFO    : Bus 30564	: V=0.9796309, theta=-44.033406 -> V=1.0, theta=0.0
% INFO    : Bus 30565	: V=0.9748877, theta=-44.140493 -> V=1.0, theta=0.0
% INFO    : Bus 30566	: V=1.0011843, theta=-42.743695 -> V=1.0, theta=0.0
% INFO    : Bus 30567	: V=0.9673465, theta=-52.331738 -> V=1.0, theta=0.0
% INFO    : Bus 30568	: V=0.9866528, theta=-49.149331 -> V=1.0, theta=0.0
% INFO    : Bus 30569	: V=0.9765823, theta=-49.890465 -> V=1.0, theta=0.0
% INFO    : Bus 30570	: V=1.0143083, theta=-45.214779 -> V=1.0, theta=0.0
% INFO    : Bus 30571	: V=0.9818025, theta=-49.711531 -> V=1.0, theta=0.0
% INFO    : Bus 30572	: V=0.9908833, theta=-49.29243 -> V=1.0, theta=0.0
% INFO    : Bus 30573	: V=1.0020948, theta=-49.027479 -> V=1.0, theta=0.0
% INFO    : Bus 30574	: V=1.0021047, theta=-48.453963 -> V=1.0, theta=0.0
% INFO    : Bus 30575	: V=0.9659821, theta=-53.493914 -> V=1.0, theta=0.0
% INFO    : Bus 30576	: V=0.9637603, theta=-53.960202 -> V=1.0, theta=0.0
% INFO    : Bus 30577	: V=0.9607601, theta=-53.895187 -> V=1.0, theta=0.0
% INFO    : Bus 30578	: V=0.9595573, theta=-53.975335 -> V=1.0, theta=0.0
% INFO    : Bus 30579	: V=0.9636354, theta=-53.940284 -> V=1.0, theta=0.0
% INFO    : Bus 30580	: V=0.9758874, theta=-52.041744 -> V=1.0, theta=0.0
% INFO    : Bus 30581	: V=0.984588, theta=-50.425891 -> V=1.0, theta=0.0
% INFO    : Bus 30582	: V=0.9596436, theta=-54.506782 -> V=1.0, theta=0.0
% INFO    : Bus 30583	: V=0.9712234, theta=-52.58608 -> V=1.0, theta=0.0
% INFO    : Bus 30584	: V=0.9603228, theta=-54.488852 -> V=1.0, theta=0.0
% INFO    : Bus 30585	: V=0.9591606, theta=-54.518796 -> V=1.0, theta=0.0
% INFO    : Bus 30586	: V=0.9618732, theta=-53.978378 -> V=1.0, theta=0.0
% INFO    : Bus 30587	: V=0.9550799, theta=-55.734941 -> V=1.0, theta=0.0
% INFO    : Bus 30588	: V=0.9623603, theta=-53.926576 -> V=1.0, theta=0.0
% INFO    : Bus 30589	: V=0.9594344, theta=-54.266221 -> V=1.0, theta=0.0
% INFO    : Bus 30590	: V=0.9585546, theta=-54.476521 -> V=1.0, theta=0.0
% INFO    : Bus 30591	: V=0.9603322, theta=-54.158097 -> V=1.0, theta=0.0
% INFO    : Bus 30592	: V=0.9581592, theta=-54.565561 -> V=1.0, theta=0.0
% INFO    : Bus 30593	: V=0.9585237, theta=-54.574803 -> V=1.0, theta=0.0
% INFO    : Bus 30594	: V=0.9526812, theta=-55.985507 -> V=1.0, theta=0.0
% INFO    : Bus 30595	: V=0.9547085, theta=-55.703849 -> V=1.0, theta=0.0
% INFO    : Bus 30596	: V=0.95336, theta=-55.912011 -> V=1.0, theta=0.0
% INFO    : Bus 30597	: V=0.9538189, theta=-55.766665 -> V=1.0, theta=0.0
% INFO    : Bus 30598	: V=0.9563708, theta=-55.688399 -> V=1.0, theta=0.0
% INFO    : Bus 30599	: V=0.9648557, theta=-54.13089 -> V=1.0, theta=0.0
% INFO    : Bus 30600	: V=0.9498045, theta=-56.625186 -> V=1.0, theta=0.0
% INFO    : Bus 30601	: V=0.9581293, theta=-54.523242 -> V=1.0, theta=0.0
% INFO    : Bus 30602	: V=0.9671363, theta=-53.260491 -> V=1.0, theta=0.0
% INFO    : Bus 30603	: V=0.9736363, theta=-52.119724 -> V=1.0, theta=0.0
% INFO    : Bus 30604	: V=0.9736962, theta=-52.154071 -> V=1.0, theta=0.0
% INFO    : Bus 30605	: V=0.966684, theta=-53.273081 -> V=1.0, theta=0.0
% INFO    : Bus 30606	: V=0.9674266, theta=-53.252233 -> V=1.0, theta=0.0
% INFO    : Bus 30607	: V=0.9739774, theta=-52.069446 -> V=1.0, theta=0.0
% INFO    : Bus 30608	: V=0.9861025, theta=-36.068732 -> V=1.0, theta=0.0
% INFO    : Bus 30609	: V=0.9655522, theta=-41.414718 -> V=1.0, theta=0.0
% INFO    : Bus 30610	: V=0.9803815, theta=-37.50611 -> V=1.0, theta=0.0
% INFO    : Bus 30611	: V=0.9944085, theta=-35.385304 -> V=1.0, theta=0.0
% INFO    : Bus 30612	: V=0.978298, theta=-35.676841 -> V=1.0, theta=0.0
% INFO    : Bus 30613	: V=0.9713173, theta=-35.782814 -> V=1.0, theta=0.0
% INFO    : Bus 30614	: V=0.9754942, theta=-35.758989 -> V=1.0, theta=0.0
% INFO    : Bus 30615	: V=0.9773954, theta=-35.745285 -> V=1.0, theta=0.0
% INFO    : Bus 30616	: V=0.9959164, theta=-34.13961 -> V=1.0, theta=0.0
% INFO    : Bus 30617	: V=0.9954325, theta=-34.675659 -> V=1.0, theta=0.0
% INFO    : Bus 30618	: V=0.9780405, theta=-36.161273 -> V=1.0, theta=0.0
% INFO    : Bus 30619	: V=0.9552896, theta=-48.391823 -> V=1.0, theta=0.0
% INFO    : Bus 30620	: V=0.9542186, theta=-48.398258 -> V=1.0, theta=0.0
% INFO    : Bus 30621	: V=0.9679027, theta=-47.523192 -> V=1.0, theta=0.0
% INFO    : Bus 30622	: V=0.967809, theta=-47.498978 -> V=1.0, theta=0.0
% INFO    : Bus 30623	: V=0.9569416, theta=-48.331842 -> V=1.0, theta=0.0
% INFO    : Bus 30624	: V=0.9540955, theta=-48.420986 -> V=1.0, theta=0.0
% INFO    : Bus 30625	: V=0.9546701, theta=-48.363303 -> V=1.0, theta=0.0
% INFO    : Bus 30626	: V=0.9537542, theta=-48.406163 -> V=1.0, theta=0.0
% INFO    : Bus 30627	: V=0.9514816, theta=-48.527015 -> V=1.0, theta=0.0
% INFO    : Bus 30628	: V=0.9689863, theta=-47.586092 -> V=1.0, theta=0.0
% INFO    : Bus 30629	: V=0.9696707, theta=-47.539879 -> V=1.0, theta=0.0
% INFO    : Bus 30630	: V=0.9692126, theta=-47.571017 -> V=1.0, theta=0.0
% INFO    : Bus 30631	: V=0.9702396, theta=-47.548007 -> V=1.0, theta=0.0
% INFO    : Bus 30632	: V=0.9701147, theta=-47.577514 -> V=1.0, theta=0.0
% INFO    : Bus 30633	: V=0.9626541, theta=-48.397242 -> V=1.0, theta=0.0
% INFO    : Bus 30634	: V=0.9704789, theta=-47.551502 -> V=1.0, theta=0.0
% INFO    : Bus 30635	: V=0.9745434, theta=-47.210507 -> V=1.0, theta=0.0
% INFO    : Bus 30636	: V=0.9716147, theta=-47.484693 -> V=1.0, theta=0.0
% INFO    : Bus 30637	: V=0.9728384, theta=-47.374522 -> V=1.0, theta=0.0
% INFO    : Bus 30638	: V=0.9583212, theta=-48.98367 -> V=1.0, theta=0.0
% INFO    : Bus 30639	: V=0.9717514, theta=-47.454623 -> V=1.0, theta=0.0
% INFO    : Bus 30640	: V=0.9732867, theta=-47.285759 -> V=1.0, theta=0.0
% INFO    : Bus 30641	: V=0.9721427, theta=-47.377778 -> V=1.0, theta=0.0
% INFO    : Bus 30642	: V=0.9711819, theta=-47.462493 -> V=1.0, theta=0.0
% INFO    : Bus 30643	: V=0.954675, theta=-48.310418 -> V=1.0, theta=0.0
% INFO    : Bus 30644	: V=0.9652614, theta=-47.80697 -> V=1.0, theta=0.0
% INFO    : Bus 30645	: V=0.9672748, theta=-47.438407 -> V=1.0, theta=0.0
% INFO    : Bus 30646	: V=0.9632557, theta=-47.514102 -> V=1.0, theta=0.0
% INFO    : Bus 30647	: V=0.9632952, theta=-47.496295 -> V=1.0, theta=0.0
% INFO    : Bus 30648	: V=0.9659197, theta=-47.28282 -> V=1.0, theta=0.0
% INFO    : Bus 30649	: V=0.9688294, theta=-47.102997 -> V=1.0, theta=0.0
% INFO    : Bus 30650	: V=0.9645603, theta=-47.40476 -> V=1.0, theta=0.0
% INFO    : Bus 30651	: V=0.9683762, theta=-47.118035 -> V=1.0, theta=0.0
% INFO    : Bus 30652	: V=0.9660844, theta=-47.264276 -> V=1.0, theta=0.0
% INFO    : Bus 30653	: V=0.9670825, theta=-47.144486 -> V=1.0, theta=0.0
% INFO    : Bus 30654	: V=0.9662978, theta=-47.244269 -> V=1.0, theta=0.0
% INFO    : Bus 30655	: V=0.9659535, theta=-47.26564 -> V=1.0, theta=0.0
% INFO    : Bus 30656	: V=0.9675395, theta=-47.141054 -> V=1.0, theta=0.0
% INFO    : Bus 30657	: V=0.9623457, theta=-47.500729 -> V=1.0, theta=0.0
% INFO    : Bus 30658	: V=0.9628838, theta=-47.708954 -> V=1.0, theta=0.0
% INFO    : Bus 30659	: V=0.9636357, theta=-47.690329 -> V=1.0, theta=0.0
% INFO    : Bus 30660	: V=0.965798, theta=-47.27611 -> V=1.0, theta=0.0
% INFO    : Bus 30661	: V=0.9687817, theta=-47.000411 -> V=1.0, theta=0.0
% INFO    : Bus 30662	: V=0.9675022, theta=-47.111014 -> V=1.0, theta=0.0
% INFO    : Bus 30663	: V=0.9656348, theta=-47.318902 -> V=1.0, theta=0.0
% INFO    : Bus 30664	: V=0.9658451, theta=-47.271566 -> V=1.0, theta=0.0
% INFO    : Bus 30665	: V=0.9662257, theta=-47.211407 -> V=1.0, theta=0.0
% INFO    : Bus 30666	: V=0.9584068, theta=-47.698516 -> V=1.0, theta=0.0
% INFO    : Bus 30667	: V=0.9665271, theta=-47.17391 -> V=1.0, theta=0.0
% INFO    : Bus 30668	: V=0.9520979, theta=-48.303734 -> V=1.0, theta=0.0
% INFO    : Bus 30669	: V=0.9520409, theta=-48.308358 -> V=1.0, theta=0.0
% INFO    : Bus 30670	: V=0.9499414, theta=-48.44647 -> V=1.0, theta=0.0
% INFO    : Bus 30671	: V=0.9508218, theta=-48.380705 -> V=1.0, theta=0.0
% INFO    : Bus 30672	: V=0.9557883, theta=-48.147833 -> V=1.0, theta=0.0
% INFO    : Bus 30673	: V=0.9495971, theta=-48.540088 -> V=1.0, theta=0.0
% INFO    : Bus 30674	: V=0.9561559, theta=-48.12568 -> V=1.0, theta=0.0
% INFO    : Bus 30675	: V=0.9537677, theta=-48.382457 -> V=1.0, theta=0.0
% INFO    : Bus 30676	: V=0.970024, theta=-47.553457 -> V=1.0, theta=0.0
% INFO    : Bus 30677	: V=0.9683892, theta=-47.607238 -> V=1.0, theta=0.0
% INFO    : Bus 30678	: V=0.9690607, theta=-47.588856 -> V=1.0, theta=0.0
% INFO    : Bus 30679	: V=0.968116, theta=-47.595617 -> V=1.0, theta=0.0
% INFO    : Bus 30680	: V=0.9683336, theta=-47.628684 -> V=1.0, theta=0.0
% INFO    : Bus 30681	: V=0.9685403, theta=-47.62676 -> V=1.0, theta=0.0
% INFO    : Bus 30682	: V=0.9686887, theta=-47.650815 -> V=1.0, theta=0.0
% INFO    : Bus 30683	: V=0.9619616, theta=-48.240028 -> V=1.0, theta=0.0
% INFO    : Bus 30684	: V=0.969323, theta=-47.59749 -> V=1.0, theta=0.0
% INFO    : Bus 30685	: V=0.969193, theta=-47.640569 -> V=1.0, theta=0.0
% INFO    : Bus 30686	: V=0.9626956, theta=-48.314156 -> V=1.0, theta=0.0
% INFO    : Bus 30687	: V=0.9605661, theta=-48.2628 -> V=1.0, theta=0.0
% INFO    : Bus 30688	: V=0.9690206, theta=-47.668985 -> V=1.0, theta=0.0
% INFO    : Bus 30689	: V=0.969571, theta=-47.669768 -> V=1.0, theta=0.0
% INFO    : Bus 30690	: V=0.9692777, theta=-47.689651 -> V=1.0, theta=0.0
% INFO    : Bus 30691	: V=0.9692326, theta=-47.69033 -> V=1.0, theta=0.0
% INFO    : Bus 30692	: V=0.9696942, theta=-47.703364 -> V=1.0, theta=0.0
% INFO    : Bus 30693	: V=0.9589572, theta=-48.458625 -> V=1.0, theta=0.0
% INFO    : Bus 30694	: V=0.9697744, theta=-47.750701 -> V=1.0, theta=0.0
% INFO    : Bus 30695	: V=0.9697008, theta=-47.802249 -> V=1.0, theta=0.0
% INFO    : Bus 30696	: V=0.9694739, theta=-47.753498 -> V=1.0, theta=0.0
% INFO    : Bus 30697	: V=0.9700125, theta=-47.944105 -> V=1.0, theta=0.0
% INFO    : Bus 30698	: V=0.9716113, theta=-48.072229 -> V=1.0, theta=0.0
% INFO    : Bus 30699	: V=0.9742062, theta=-47.895308 -> V=1.0, theta=0.0
% INFO    : Bus 30700	: V=0.9688923, theta=-48.166776 -> V=1.0, theta=0.0
% INFO    : Bus 30701	: V=0.9853337, theta=-46.203939 -> V=1.0, theta=0.0
% INFO    : Bus 30702	: V=0.9716991, theta=-48.623529 -> V=1.0, theta=0.0
% INFO    : Bus 30703	: V=0.9699497, theta=-47.710213 -> V=1.0, theta=0.0
% INFO    : Bus 30704	: V=0.9601855, theta=-48.529469 -> V=1.0, theta=0.0
% INFO    : Bus 30705	: V=0.9703997, theta=-47.6348 -> V=1.0, theta=0.0
% INFO    : Bus 30706	: V=0.9623482, theta=-48.383915 -> V=1.0, theta=0.0
% INFO    : Bus 30707	: V=0.960354, theta=-48.560264 -> V=1.0, theta=0.0
% INFO    : Bus 30708	: V=0.9631242, theta=-48.347721 -> V=1.0, theta=0.0
% INFO    : Bus 30709	: V=0.9623546, theta=-48.405402 -> V=1.0, theta=0.0
% INFO    : Bus 30710	: V=0.9726735, theta=-47.380797 -> V=1.0, theta=0.0
% INFO    : Bus 30711	: V=0.9678316, theta=-47.762749 -> V=1.0, theta=0.0
% INFO    : Bus 30712	: V=0.9659759, theta=-47.842864 -> V=1.0, theta=0.0
% INFO    : Bus 30713	: V=1.0121292, theta=-43.068387 -> V=1.0, theta=0.0
% INFO    : Bus 30714	: V=0.9753296, theta=-47.117989 -> V=1.0, theta=0.0
% INFO    : Bus 30715	: V=0.9696391, theta=-47.172982 -> V=1.0, theta=0.0
% INFO    : Bus 30716	: V=0.968938, theta=-47.230361 -> V=1.0, theta=0.0
% INFO    : Bus 30717	: V=0.9678029, theta=-47.349883 -> V=1.0, theta=0.0
% INFO    : Bus 30718	: V=0.9556173, theta=-48.256972 -> V=1.0, theta=0.0
% INFO    : Bus 30719	: V=0.9536705, theta=-48.911482 -> V=1.0, theta=0.0
% INFO    : Bus 30720	: V=0.9675317, theta=-47.251022 -> V=1.0, theta=0.0
% INFO    : Bus 30721	: V=0.9670961, theta=-47.265124 -> V=1.0, theta=0.0
% INFO    : Bus 30722	: V=0.9666027, theta=-47.318367 -> V=1.0, theta=0.0
% INFO    : Bus 30723	: V=0.9665818, theta=-47.291347 -> V=1.0, theta=0.0
% INFO    : Bus 30724	: V=0.9657124, theta=-47.378836 -> V=1.0, theta=0.0
% INFO    : Bus 30725	: V=0.9662118, theta=-47.307591 -> V=1.0, theta=0.0
% INFO    : Bus 30726	: V=0.9646283, theta=-47.455485 -> V=1.0, theta=0.0
% INFO    : Bus 30727	: V=0.9576252, theta=-48.206292 -> V=1.0, theta=0.0
% INFO    : Bus 30728	: V=0.9641618, theta=-47.477513 -> V=1.0, theta=0.0
% INFO    : Bus 30729	: V=0.9658086, theta=-47.322561 -> V=1.0, theta=0.0
% INFO    : Bus 30730	: V=0.9636176, theta=-47.502559 -> V=1.0, theta=0.0
% INFO    : Bus 30731	: V=0.9655784, theta=-47.315003 -> V=1.0, theta=0.0
% INFO    : Bus 30732	: V=0.9655189, theta=-47.329648 -> V=1.0, theta=0.0
% INFO    : Bus 30733	: V=0.967268, theta=-47.212342 -> V=1.0, theta=0.0
% INFO    : Bus 30734	: V=0.9661173, theta=-47.27612 -> V=1.0, theta=0.0
% INFO    : Bus 30735	: V=0.9671448, theta=-47.211133 -> V=1.0, theta=0.0
% INFO    : Bus 30736	: V=0.966856, theta=-47.226345 -> V=1.0, theta=0.0
% INFO    : Bus 30737	: V=0.9577185, theta=-47.915771 -> V=1.0, theta=0.0
% INFO    : Bus 30738	: V=0.9671056, theta=-46.858847 -> V=1.0, theta=0.0
% INFO    : Bus 30739	: V=0.951169, theta=-48.416796 -> V=1.0, theta=0.0
% INFO    : Bus 30740	: V=0.953636, theta=-48.299194 -> V=1.0, theta=0.0
% INFO    : Bus 30741	: V=0.9677433, theta=-46.789199 -> V=1.0, theta=0.0
% INFO    : Bus 30742	: V=0.969179, theta=-46.680395 -> V=1.0, theta=0.0
% INFO    : Bus 30743	: V=0.9582102, theta=-48.01231 -> V=1.0, theta=0.0
% INFO    : Bus 30744	: V=0.9689795, theta=-46.679241 -> V=1.0, theta=0.0
% INFO    : Bus 30745	: V=0.9740803, theta=-46.265699 -> V=1.0, theta=0.0
% INFO    : Bus 30746	: V=0.9751321, theta=-46.160915 -> V=1.0, theta=0.0
% INFO    : Bus 30747	: V=0.9768603, theta=-46.013452 -> V=1.0, theta=0.0
% INFO    : Bus 30748	: V=0.9603351, theta=-47.795782 -> V=1.0, theta=0.0
% INFO    : Bus 30749	: V=0.9609415, theta=-47.745634 -> V=1.0, theta=0.0
% INFO    : Bus 30750	: V=0.9982552, theta=-43.155213 -> V=1.0, theta=0.0
% INFO    : Bus 30751	: V=0.9890531, theta=-44.690465 -> V=1.0, theta=0.0
% INFO    : Bus 30752	: V=0.9671579, theta=-46.128285 -> V=1.0, theta=0.0
% INFO    : Bus 30753	: V=0.968789, theta=-47.060683 -> V=1.0, theta=0.0
% INFO    : Bus 30754	: V=0.9547615, theta=-48.348848 -> V=1.0, theta=0.0
% INFO    : Bus 30755	: V=0.9847778, theta=-45.273804 -> V=1.0, theta=0.0
% INFO    : Bus 30756	: V=0.9689487, theta=-46.970159 -> V=1.0, theta=0.0
% INFO    : Bus 30757	: V=0.9857274, theta=-45.192791 -> V=1.0, theta=0.0
% INFO    : Bus 30758	: V=0.9700673, theta=-47.008716 -> V=1.0, theta=0.0
% INFO    : Bus 30759	: V=0.9871124, theta=-45.07299 -> V=1.0, theta=0.0
% INFO    : Bus 30760	: V=0.9885963, theta=-44.934457 -> V=1.0, theta=0.0
% INFO    : Bus 30761	: V=0.9703656, theta=-46.554844 -> V=1.0, theta=0.0
% INFO    : Bus 30762	: V=0.9715243, theta=-46.456493 -> V=1.0, theta=0.0
% INFO    : Bus 30763	: V=0.9731145, theta=-46.315272 -> V=1.0, theta=0.0
% INFO    : Bus 30764	: V=0.9552191, theta=-48.030368 -> V=1.0, theta=0.0
% INFO    : Bus 30765	: V=0.9791406, theta=-45.831553 -> V=1.0, theta=0.0
% INFO    : Bus 30766	: V=0.9863542, theta=-45.099127 -> V=1.0, theta=0.0
% INFO    : Bus 30767	: V=0.9960795, theta=-44.236346 -> V=1.0, theta=0.0
% INFO    : Bus 30768	: V=0.9931419, theta=-44.652443 -> V=1.0, theta=0.0
% INFO    : Bus 30769	: V=0.9709259, theta=-46.891098 -> V=1.0, theta=0.0
% INFO    : Bus 30770	: V=0.9886911, theta=-45.119116 -> V=1.0, theta=0.0
% INFO    : Bus 30771	: V=0.986338, theta=-45.522106 -> V=1.0, theta=0.0
% INFO    : Bus 30772	: V=0.958827, theta=-48.314363 -> V=1.0, theta=0.0
% INFO    : Bus 30773	: V=0.9700239, theta=-47.34209 -> V=1.0, theta=0.0
% INFO    : Bus 30774	: V=0.9869803, theta=-45.52322 -> V=1.0, theta=0.0
% INFO    : Bus 30775	: V=0.987704, theta=-45.50464 -> V=1.0, theta=0.0
% INFO    : Bus 30776	: V=0.970401, theta=-47.583302 -> V=1.0, theta=0.0
% INFO    : Bus 30777	: V=0.9690164, theta=-47.649872 -> V=1.0, theta=0.0
% INFO    : Bus 30778	: V=0.9583582, theta=-48.560601 -> V=1.0, theta=0.0
% INFO    : Bus 30779	: V=0.968421, theta=-47.643303 -> V=1.0, theta=0.0
% INFO    : Bus 30780	: V=0.9686104, theta=-47.648456 -> V=1.0, theta=0.0
% INFO    : Bus 30781	: V=0.9883176, theta=-45.974669 -> V=1.0, theta=0.0
% INFO    : Bus 30782	: V=0.97486, theta=-47.264905 -> V=1.0, theta=0.0
% INFO    : Bus 30783	: V=0.9771608, theta=-47.085838 -> V=1.0, theta=0.0
% INFO    : Bus 30784	: V=0.9714941, theta=-47.493578 -> V=1.0, theta=0.0
% INFO    : Bus 30785	: V=0.971461, theta=-47.466977 -> V=1.0, theta=0.0
% INFO    : Bus 30786	: V=0.9748126, theta=-47.203437 -> V=1.0, theta=0.0
% INFO    : Bus 30787	: V=0.973613, theta=-47.286256 -> V=1.0, theta=0.0
% INFO    : Bus 30788	: V=0.9765051, theta=-47.090553 -> V=1.0, theta=0.0
% INFO    : Bus 30789	: V=0.9842624, theta=-46.591647 -> V=1.0, theta=0.0
% INFO    : Bus 30790	: V=0.9803285, theta=-46.870449 -> V=1.0, theta=0.0
% INFO    : Bus 30791	: V=0.9882152, theta=-46.588812 -> V=1.0, theta=0.0
% INFO    : Bus 30792	: V=0.987127, theta=-47.185267 -> V=1.0, theta=0.0
% INFO    : Bus 30793	: V=0.9729675, theta=-47.874364 -> V=1.0, theta=0.0
% INFO    : Bus 30794	: V=0.9785302, theta=-47.66192 -> V=1.0, theta=0.0
% INFO    : Bus 30795	: V=0.9840925, theta=-47.029569 -> V=1.0, theta=0.0
% INFO    : Bus 30796	: V=0.9824414, theta=-47.35645 -> V=1.0, theta=0.0
% INFO    : Bus 30797	: V=0.9780061, theta=-47.665316 -> V=1.0, theta=0.0
% INFO    : Bus 30798	: V=0.9508526, theta=-49.652045 -> V=1.0, theta=0.0
% INFO    : Bus 30799	: V=0.9696981, theta=-48.028546 -> V=1.0, theta=0.0
% INFO    : Bus 30800	: V=0.9685101, theta=-48.068203 -> V=1.0, theta=0.0
% INFO    : Bus 30801	: V=0.9819282, theta=-46.581352 -> V=1.0, theta=0.0
% INFO    : Bus 30802	: V=0.9710687, theta=-47.500183 -> V=1.0, theta=0.0
% INFO    : Bus 30803	: V=1.0124053, theta=-43.029256 -> V=1.0, theta=0.0
% INFO    : Bus 30804	: V=0.9805934, theta=-46.869262 -> V=1.0, theta=0.0
% INFO    : Bus 30805	: V=0.9772475, theta=-47.308454 -> V=1.0, theta=0.0
% INFO    : Bus 30806	: V=0.9688583, theta=-47.988313 -> V=1.0, theta=0.0
% INFO    : Bus 30807	: V=0.9789986, theta=-47.064383 -> V=1.0, theta=0.0
% INFO    : Bus 30808	: V=0.9758913, theta=-47.521575 -> V=1.0, theta=0.0
% INFO    : Bus 30809	: V=0.9717009, theta=-48.055986 -> V=1.0, theta=0.0
% INFO    : Bus 30810	: V=0.9753378, theta=-46.975555 -> V=1.0, theta=0.0
% INFO    : Bus 30811	: V=0.9668253, theta=-47.693236 -> V=1.0, theta=0.0
% INFO    : Bus 30812	: V=0.968432, theta=-47.637012 -> V=1.0, theta=0.0
% INFO    : Bus 30813	: V=0.9662409, theta=-47.710378 -> V=1.0, theta=0.0
% INFO    : Bus 30814	: V=0.9585569, theta=-49.604772 -> V=1.0, theta=0.0
% INFO    : Bus 30815	: V=0.9693774, theta=-48.445964 -> V=1.0, theta=0.0
% INFO    : Bus 30816	: V=0.9525452, theta=-48.987233 -> V=1.0, theta=0.0
% INFO    : Bus 30817	: V=0.9611868, theta=-48.51989 -> V=1.0, theta=0.0
% INFO    : Bus 30818	: V=0.9548989, theta=-48.377075 -> V=1.0, theta=0.0
% INFO    : Bus 30819	: V=0.9826295, theta=-46.095876 -> V=1.0, theta=0.0
% INFO    : Bus 30820	: V=0.9636013, theta=-47.470697 -> V=1.0, theta=0.0
% INFO    : Bus 30821	: V=0.9680322, theta=-47.56272 -> V=1.0, theta=0.0
% INFO    : Bus 30822	: V=0.9832367, theta=-45.997037 -> V=1.0, theta=0.0
% INFO    : Bus 30823	: V=0.9671433, theta=-47.468624 -> V=1.0, theta=0.0
% INFO    : Bus 30824	: V=0.968059, theta=-47.449683 -> V=1.0, theta=0.0
% INFO    : Bus 30825	: V=0.9926526, theta=-46.269702 -> V=1.0, theta=0.0
% INFO    : Bus 30826	: V=0.9889278, theta=-46.746797 -> V=1.0, theta=0.0
% INFO    : Bus 30827	: V=0.9991798, theta=-45.59363 -> V=1.0, theta=0.0
% INFO    : Bus 30828	: V=0.9975157, theta=-45.60859 -> V=1.0, theta=0.0
% INFO    : Bus 30829	: V=0.9684636, theta=-48.04515 -> V=1.0, theta=0.0
% INFO    : Bus 30830	: V=0.9896247, theta=-46.218597 -> V=1.0, theta=0.0
% INFO    : Bus 30831	: V=0.9823421, theta=-46.741621 -> V=1.0, theta=0.0
% INFO    : Bus 30832	: V=0.9857277, theta=-46.588245 -> V=1.0, theta=0.0
% INFO    : Bus 30833	: V=0.9862728, theta=-46.676174 -> V=1.0, theta=0.0
% INFO    : Bus 30834	: V=0.9768657, theta=-46.832037 -> V=1.0, theta=0.0
% INFO    : Bus 30835	: V=0.9803293, theta=-46.793168 -> V=1.0, theta=0.0
% INFO    : Bus 30836	: V=0.9893479, theta=-46.080813 -> V=1.0, theta=0.0
% INFO    : Bus 30837	: V=0.991696, theta=-45.973304 -> V=1.0, theta=0.0
% INFO    : Bus 30838	: V=0.9900864, theta=-46.047971 -> V=1.0, theta=0.0
% INFO    : Bus 30839	: V=0.9830841, theta=-46.578971 -> V=1.0, theta=0.0
% INFO    : Bus 30840	: V=0.9904828, theta=-46.033044 -> V=1.0, theta=0.0
% INFO    : Bus 30841	: V=0.9889647, theta=-46.244936 -> V=1.0, theta=0.0
% INFO    : Bus 30842	: V=0.9829251, theta=-46.580968 -> V=1.0, theta=0.0
% INFO    : Bus 30843	: V=0.9830148, theta=-46.572396 -> V=1.0, theta=0.0
% INFO    : Bus 30844	: V=0.9833724, theta=-46.504969 -> V=1.0, theta=0.0
% INFO    : Bus 30845	: V=0.9889992, theta=-45.446531 -> V=1.0, theta=0.0
% INFO    : Bus 30846	: V=0.9857031, theta=-45.851817 -> V=1.0, theta=0.0
% INFO    : Bus 30847	: V=0.9787042, theta=-46.531902 -> V=1.0, theta=0.0
% INFO    : Bus 30848	: V=0.9909551, theta=-45.316989 -> V=1.0, theta=0.0
% INFO    : Bus 30849	: V=0.9841299, theta=-46.408498 -> V=1.0, theta=0.0
% INFO    : Bus 30850	: V=0.9719776, theta=-47.158662 -> V=1.0, theta=0.0
% INFO    : Bus 30851	: V=0.993603, theta=-45.103504 -> V=1.0, theta=0.0
% INFO    : Bus 30852	: V=0.9877751, theta=-46.093806 -> V=1.0, theta=0.0
% INFO    : Bus 30853	: V=0.9849743, theta=-46.664659 -> V=1.0, theta=0.0
% INFO    : Bus 30854	: V=0.987448, theta=-46.069764 -> V=1.0, theta=0.0
% INFO    : Bus 30855	: V=0.9828113, theta=-46.320965 -> V=1.0, theta=0.0
% INFO    : Bus 30856	: V=0.9989439, theta=-44.452687 -> V=1.0, theta=0.0
% INFO    : Bus 30857	: V=0.9744039, theta=-46.463798 -> V=1.0, theta=0.0
% INFO    : Bus 30858	: V=0.9737151, theta=-46.47018 -> V=1.0, theta=0.0
% INFO    : Bus 30859	: V=0.9762176, theta=-46.515296 -> V=1.0, theta=0.0
% INFO    : Bus 30860	: V=0.9792206, theta=-46.434433 -> V=1.0, theta=0.0
% INFO    : Bus 30861	: V=0.9651708, theta=-48.170357 -> V=1.0, theta=0.0
% INFO    : Bus 30862	: V=0.9639103, theta=-48.239532 -> V=1.0, theta=0.0
% INFO    : Bus 30863	: V=0.9780691, theta=-46.677718 -> V=1.0, theta=0.0
% INFO    : Bus 30864	: V=0.9755072, theta=-46.87482 -> V=1.0, theta=0.0
% INFO    : Bus 30865	: V=1.0025101, theta=-42.486219 -> V=1.0, theta=0.0
% INFO    : Bus 30866	: V=0.9508932, theta=-40.022595 -> V=1.0, theta=0.0
% INFO    : Bus 30867	: V=0.9500455, theta=-40.098539 -> V=1.0, theta=0.0
% INFO    : Bus 30868	: V=0.9546394, theta=-39.662811 -> V=1.0, theta=0.0
% INFO    : Bus 30869	: V=0.9628649, theta=-37.203544 -> V=1.0, theta=0.0
% INFO    : Bus 30870	: V=0.955449, theta=-39.773691 -> V=1.0, theta=0.0
% INFO    : Bus 30871	: V=0.9561876, theta=-39.491137 -> V=1.0, theta=0.0
% INFO    : Bus 30872	: V=0.9564887, theta=-39.709142 -> V=1.0, theta=0.0
% INFO    : Bus 30873	: V=0.9575615, theta=-39.657662 -> V=1.0, theta=0.0
% INFO    : Bus 30874	: V=0.9561334, theta=-39.241219 -> V=1.0, theta=0.0
% INFO    : Bus 30875	: V=0.9563873, theta=-39.054643 -> V=1.0, theta=0.0
% INFO    : Bus 30876	: V=0.9551928, theta=-39.512744 -> V=1.0, theta=0.0
% INFO    : Bus 30877	: V=0.9565894, theta=-39.540888 -> V=1.0, theta=0.0
% INFO    : Bus 30878	: V=0.957316, theta=-39.57858 -> V=1.0, theta=0.0
% INFO    : Bus 30879	: V=0.9555493, theta=-39.887334 -> V=1.0, theta=0.0
% INFO    : Bus 30880	: V=0.9655714, theta=-39.597609 -> V=1.0, theta=0.0
% INFO    : Bus 30881	: V=0.966984, theta=-39.545082 -> V=1.0, theta=0.0
% INFO    : Bus 30882	: V=0.9545376, theta=-39.909822 -> V=1.0, theta=0.0
% INFO    : Bus 30883	: V=0.9594931, theta=-39.845674 -> V=1.0, theta=0.0
% INFO    : Bus 30884	: V=0.9533109, theta=-40.007631 -> V=1.0, theta=0.0
% INFO    : Bus 30885	: V=0.9542783, theta=-39.979553 -> V=1.0, theta=0.0
% INFO    : Bus 30886	: V=0.9630435, theta=-39.774814 -> V=1.0, theta=0.0
% INFO    : Bus 30887	: V=0.9697816, theta=-39.462748 -> V=1.0, theta=0.0
% INFO    : Bus 30888	: V=0.9604313, theta=-39.849239 -> V=1.0, theta=0.0
% INFO    : Bus 30889	: V=0.9797921, theta=-38.561009 -> V=1.0, theta=0.0
% INFO    : Bus 30890	: V=0.9804982, theta=-38.558338 -> V=1.0, theta=0.0
% INFO    : Bus 30891	: V=0.9671635, theta=-39.589618 -> V=1.0, theta=0.0
% INFO    : Bus 30892	: V=0.9893145, theta=-37.612481 -> V=1.0, theta=0.0
% INFO    : Bus 30893	: V=0.9875006, theta=-37.710095 -> V=1.0, theta=0.0
% INFO    : Bus 30894	: V=0.9727505, theta=-39.198069 -> V=1.0, theta=0.0
% INFO    : Bus 30895	: V=0.9694264, theta=-39.426786 -> V=1.0, theta=0.0
% INFO    : Bus 30896	: V=0.9716164, theta=-39.300275 -> V=1.0, theta=0.0
% INFO    : Bus 30897	: V=0.9720852, theta=-39.147557 -> V=1.0, theta=0.0
% INFO    : Bus 30898	: V=0.9880356, theta=-37.601952 -> V=1.0, theta=0.0
% INFO    : Bus 30899	: V=0.9692446, theta=-39.269503 -> V=1.0, theta=0.0
% INFO    : Bus 30900	: V=0.9682087, theta=-39.311418 -> V=1.0, theta=0.0
% INFO    : Bus 30901	: V=0.9876168, theta=-37.465643 -> V=1.0, theta=0.0
% INFO    : Bus 30902	: V=0.9772528, theta=-38.807105 -> V=1.0, theta=0.0
% INFO    : Bus 30903	: V=0.9789795, theta=-38.730306 -> V=1.0, theta=0.0
% INFO    : Bus 30904	: V=0.9842466, theta=-38.192045 -> V=1.0, theta=0.0
% INFO    : Bus 30905	: V=0.9912064, theta=-37.509645 -> V=1.0, theta=0.0
% INFO    : Bus 30906	: V=0.9934219, theta=-37.391839 -> V=1.0, theta=0.0
% INFO    : Bus 30907	: V=0.9897302, theta=-37.487563 -> V=1.0, theta=0.0
% INFO    : Bus 30908	: V=0.9857906, theta=-38.097549 -> V=1.0, theta=0.0
% INFO    : Bus 30909	: V=1.0076841, theta=-35.343576 -> V=1.0, theta=0.0
% INFO    : Bus 30910	: V=0.9869042, theta=-38.035895 -> V=1.0, theta=0.0
% INFO    : Bus 30911	: V=1.0077284, theta=-35.233059 -> V=1.0, theta=0.0
% INFO    : Bus 30912	: V=0.9958908, theta=-37.290787 -> V=1.0, theta=0.0
% INFO    : Bus 30913	: V=1.0005097, theta=-36.930012 -> V=1.0, theta=0.0
% INFO    : Bus 30914	: V=1.0035817, theta=-36.5085 -> V=1.0, theta=0.0
% INFO    : Bus 30915	: V=0.9902767, theta=-37.69743 -> V=1.0, theta=0.0
% INFO    : Bus 30916	: V=0.9787434, theta=-38.658333 -> V=1.0, theta=0.0
% INFO    : Bus 30917	: V=0.9819063, theta=-38.41699 -> V=1.0, theta=0.0
% INFO    : Bus 30918	: V=0.9742708, theta=-38.69977 -> V=1.0, theta=0.0
% INFO    : Bus 30919	: V=0.9751923, theta=-38.692669 -> V=1.0, theta=0.0
% INFO    : Bus 30920	: V=0.9721885, theta=-38.750945 -> V=1.0, theta=0.0
% INFO    : Bus 30921	: V=0.9718054, theta=-38.756389 -> V=1.0, theta=0.0
% INFO    : Bus 30922	: V=0.9719876, theta=-38.754417 -> V=1.0, theta=0.0
% INFO    : Bus 30923	: V=0.9728932, theta=-38.717162 -> V=1.0, theta=0.0
% INFO    : Bus 30924	: V=0.9831775, theta=-37.503878 -> V=1.0, theta=0.0
% INFO    : Bus 30925	: V=0.9774917, theta=-38.672478 -> V=1.0, theta=0.0
% INFO    : Bus 30926	: V=0.9783775, theta=-38.64036 -> V=1.0, theta=0.0
% INFO    : Bus 30927	: V=0.9742368, theta=-38.731579 -> V=1.0, theta=0.0
% INFO    : Bus 30928	: V=0.9726616, theta=-38.743645 -> V=1.0, theta=0.0
% INFO    : Bus 30929	: V=0.9856236, theta=-37.957548 -> V=1.0, theta=0.0
% INFO    : Bus 30930	: V=0.9868371, theta=-37.89016 -> V=1.0, theta=0.0
% INFO    : Bus 30931	: V=0.9844156, theta=-38.314213 -> V=1.0, theta=0.0
% INFO    : Bus 30932	: V=0.9854384, theta=-38.270808 -> V=1.0, theta=0.0
% INFO    : Bus 30933	: V=0.9882443, theta=-37.923251 -> V=1.0, theta=0.0
% INFO    : Bus 30934	: V=0.9870591, theta=-38.020704 -> V=1.0, theta=0.0
% INFO    : Bus 30935	: V=0.9859497, theta=-38.108061 -> V=1.0, theta=0.0
% INFO    : Bus 30936	: V=0.9849123, theta=-38.192217 -> V=1.0, theta=0.0
% INFO    : Bus 30937	: V=0.9823387, theta=-38.504562 -> V=1.0, theta=0.0
% INFO    : Bus 30938	: V=0.984777, theta=-37.997504 -> V=1.0, theta=0.0
% INFO    : Bus 30939	: V=0.9836927, theta=-38.073961 -> V=1.0, theta=0.0
% INFO    : Bus 30940	: V=0.9726646, theta=-38.782613 -> V=1.0, theta=0.0
% INFO    : Bus 30941	: V=0.9721629, theta=-38.753692 -> V=1.0, theta=0.0
% INFO    : Bus 30942	: V=0.9788908, theta=-37.776819 -> V=1.0, theta=0.0
% INFO    : Bus 30943	: V=0.9780496, theta=-37.839242 -> V=1.0, theta=0.0
% INFO    : Bus 30944	: V=0.9746875, theta=-39.116033 -> V=1.0, theta=0.0
% INFO    : Bus 30945	: V=0.9825364, theta=-38.394687 -> V=1.0, theta=0.0
% INFO    : Bus 30946	: V=0.975304, theta=-39.083266 -> V=1.0, theta=0.0
% INFO    : Bus 30947	: V=0.9875525, theta=-38.102036 -> V=1.0, theta=0.0
% INFO    : Bus 30948	: V=0.9816991, theta=-38.490603 -> V=1.0, theta=0.0
% INFO    : Bus 30949	: V=0.9748052, theta=-39.20281 -> V=1.0, theta=0.0
% INFO    : Bus 30950	: V=0.973883, theta=-39.889246 -> V=1.0, theta=0.0
% INFO    : Bus 30951	: V=0.9812041, theta=-38.49272 -> V=1.0, theta=0.0
% INFO    : Bus 30952	: V=0.9907477, theta=-36.744204 -> V=1.0, theta=0.0
% INFO    : Bus 30953	: V=0.9781359, theta=-37.901037 -> V=1.0, theta=0.0
% INFO    : Bus 30954	: V=0.971168, theta=-38.841303 -> V=1.0, theta=0.0
% INFO    : Bus 30955	: V=0.977023, theta=-38.083707 -> V=1.0, theta=0.0
% INFO    : Bus 30956	: V=0.9766196, theta=-38.154837 -> V=1.0, theta=0.0
% INFO    : Bus 30957	: V=0.9716391, theta=-38.867994 -> V=1.0, theta=0.0
% INFO    : Bus 30958	: V=0.9712038, theta=-38.918166 -> V=1.0, theta=0.0
% INFO    : Bus 30959	: V=0.971513, theta=-38.881108 -> V=1.0, theta=0.0
% INFO    : Bus 30960	: V=0.976301, theta=-38.213804 -> V=1.0, theta=0.0
% INFO    : Bus 30961	: V=0.9757833, theta=-38.328313 -> V=1.0, theta=0.0
% INFO    : Bus 30962	: V=0.974736, theta=-38.569404 -> V=1.0, theta=0.0
% INFO    : Bus 30963	: V=0.9790292, theta=-38.430634 -> V=1.0, theta=0.0
% INFO    : Bus 30964	: V=0.9693575, theta=-39.083472 -> V=1.0, theta=0.0
% INFO    : Bus 30965	: V=0.9771417, theta=-38.607702 -> V=1.0, theta=0.0
% INFO    : Bus 30966	: V=0.9778592, theta=-38.545058 -> V=1.0, theta=0.0
% INFO    : Bus 30967	: V=0.9720826, theta=-39.261914 -> V=1.0, theta=0.0
% INFO    : Bus 30968	: V=0.9804212, theta=-38.530759 -> V=1.0, theta=0.0
% INFO    : Bus 30969	: V=0.9798879, theta=-38.561266 -> V=1.0, theta=0.0
% INFO    : Bus 30970	: V=0.9769967, theta=-39.132078 -> V=1.0, theta=0.0
% INFO    : Bus 30971	: V=0.9744382, theta=-39.239692 -> V=1.0, theta=0.0
% INFO    : Bus 30972	: V=0.9763017, theta=-38.688931 -> V=1.0, theta=0.0
% INFO    : Bus 30973	: V=0.9756703, theta=-38.745874 -> V=1.0, theta=0.0
% INFO    : Bus 30974	: V=0.9710084, theta=-39.393444 -> V=1.0, theta=0.0
% INFO    : Bus 30975	: V=0.9743756, theta=-38.715861 -> V=1.0, theta=0.0
% INFO    : Bus 30976	: V=0.9706665, theta=-39.247423 -> V=1.0, theta=0.0
% INFO    : Bus 30977	: V=0.9700487, theta=-39.260549 -> V=1.0, theta=0.0
% INFO    : Bus 30978	: V=0.9719875, theta=-39.031959 -> V=1.0, theta=0.0
% INFO    : Bus 30979	: V=0.9752251, theta=-38.303236 -> V=1.0, theta=0.0
% INFO    : Bus 30980	: V=0.9736557, theta=-38.623027 -> V=1.0, theta=0.0
% INFO    : Bus 30981	: V=0.9703678, theta=-39.254031 -> V=1.0, theta=0.0
% INFO    : Bus 30982	: V=0.9717076, theta=-39.151182 -> V=1.0, theta=0.0
% INFO    : Bus 30983	: V=0.9769331, theta=-38.105076 -> V=1.0, theta=0.0
% INFO    : Bus 30984	: V=0.9723475, theta=-38.879808 -> V=1.0, theta=0.0
% INFO    : Bus 30985	: V=0.9761627, theta=-38.182692 -> V=1.0, theta=0.0
% INFO    : Bus 30986	: V=0.9706341, theta=-39.219311 -> V=1.0, theta=0.0
% INFO    : Bus 30987	: V=0.9710049, theta=-39.184574 -> V=1.0, theta=0.0
% INFO    : Bus 30988	: V=0.9740192, theta=-38.884354 -> V=1.0, theta=0.0
% INFO    : Bus 30989	: V=0.9719225, theta=-39.365692 -> V=1.0, theta=0.0
% INFO    : Bus 30990	: V=0.9749829, theta=-38.807043 -> V=1.0, theta=0.0
% INFO    : Bus 30991	: V=0.9761705, theta=-39.064595 -> V=1.0, theta=0.0
% INFO    : Bus 30992	: V=0.9781269, theta=-39.107185 -> V=1.0, theta=0.0
% INFO    : Bus 30993	: V=0.9932925, theta=-37.794717 -> V=1.0, theta=0.0
% INFO    : Bus 30994	: V=0.9796118, theta=-39.08331 -> V=1.0, theta=0.0
% INFO    : Bus 30995	: V=0.9752408, theta=-39.206611 -> V=1.0, theta=0.0
% INFO    : Bus 30996	: V=0.9797395, theta=-38.571138 -> V=1.0, theta=0.0
% INFO    : Bus 30997	: V=0.9756538, theta=-39.198261 -> V=1.0, theta=0.0
% INFO    : Bus 30998	: V=0.9781777, theta=-39.093752 -> V=1.0, theta=0.0
% INFO    : Bus 30999	: V=0.9782405, theta=-39.093307 -> V=1.0, theta=0.0
% INFO    : Bus 31000	: V=0.9727232, theta=-39.727118 -> V=1.0, theta=0.0
% INFO    : Bus 31001	: V=0.965716, theta=-40.760693 -> V=1.0, theta=0.0
% INFO    : Bus 31002	: V=0.9919063, theta=-37.865955 -> V=1.0, theta=0.0
% INFO    : Bus 31003	: V=0.9751945, theta=-39.481067 -> V=1.0, theta=0.0
% INFO    : Bus 31004	: V=0.9737443, theta=-39.699711 -> V=1.0, theta=0.0
% INFO    : Bus 31005	: V=0.9730491, theta=-39.718073 -> V=1.0, theta=0.0
% INFO    : Bus 31006	: V=0.9725877, theta=-39.803747 -> V=1.0, theta=0.0
% INFO    : Bus 31007	: V=0.9723075, theta=-39.687352 -> V=1.0, theta=0.0
% INFO    : Bus 31008	: V=0.9743884, theta=-39.295695 -> V=1.0, theta=0.0
% INFO    : Bus 31009	: V=0.9884799, theta=-36.989192 -> V=1.0, theta=0.0
% INFO    : Bus 31010	: V=0.968912, theta=-40.046087 -> V=1.0, theta=0.0
% INFO    : Bus 31011	: V=0.9705609, theta=-39.891369 -> V=1.0, theta=0.0
% INFO    : Bus 31012	: V=0.9717306, theta=-39.770163 -> V=1.0, theta=0.0
% INFO    : Bus 31013	: V=0.9723624, theta=-39.653402 -> V=1.0, theta=0.0
% INFO    : Bus 31014	: V=0.9733136, theta=-38.946029 -> V=1.0, theta=0.0
% INFO    : Bus 31015	: V=0.9730183, theta=-38.971031 -> V=1.0, theta=0.0
% INFO    : Bus 31016	: V=0.9731628, theta=-39.50047 -> V=1.0, theta=0.0
% INFO    : Bus 31017	: V=0.9726852, theta=-39.005888 -> V=1.0, theta=0.0
% INFO    : Bus 31018	: V=0.9723154, theta=-38.900906 -> V=1.0, theta=0.0
% INFO    : Bus 31019	: V=0.9591509, theta=-42.355661 -> V=1.0, theta=0.0
% INFO    : Bus 31020	: V=0.9703883, theta=-39.40534 -> V=1.0, theta=0.0
% INFO    : Bus 31021	: V=0.9640506, theta=-40.612761 -> V=1.0, theta=0.0
% INFO    : Bus 31022	: V=0.9692826, theta=-39.637952 -> V=1.0, theta=0.0
% INFO    : Bus 31023	: V=0.9682911, theta=-39.814722 -> V=1.0, theta=0.0
% INFO    : Bus 31024	: V=0.9674234, theta=-39.991365 -> V=1.0, theta=0.0
% INFO    : Bus 31025	: V=0.9687017, theta=-39.701173 -> V=1.0, theta=0.0
% INFO    : Bus 31026	: V=0.9660946, theta=-40.280076 -> V=1.0, theta=0.0
% INFO    : Bus 31027	: V=0.9647502, theta=-40.530753 -> V=1.0, theta=0.0
% INFO    : Bus 31028	: V=0.9601043, theta=-42.195173 -> V=1.0, theta=0.0
% INFO    : Bus 31029	: V=0.9614268, theta=-41.997132 -> V=1.0, theta=0.0
% INFO    : Bus 31030	: V=0.9616997, theta=-41.998172 -> V=1.0, theta=0.0
% INFO    : Bus 31031	: V=0.9641902, theta=-40.613629 -> V=1.0, theta=0.0
% INFO    : Bus 31032	: V=0.9609542, theta=-42.037603 -> V=1.0, theta=0.0
% INFO    : Bus 31033	: V=0.9597681, theta=-42.293636 -> V=1.0, theta=0.0
% INFO    : Bus 31034	: V=0.9603992, theta=-42.275794 -> V=1.0, theta=0.0
% INFO    : Bus 31035	: V=0.9603533, theta=-42.183592 -> V=1.0, theta=0.0
% INFO    : Bus 31036	: V=0.96008, theta=-42.191401 -> V=1.0, theta=0.0
% INFO    : Bus 31037	: V=0.9585659, theta=-42.474485 -> V=1.0, theta=0.0
% INFO    : Bus 31038	: V=0.9587914, theta=-42.364826 -> V=1.0, theta=0.0
% INFO    : Bus 31039	: V=0.9594612, theta=-42.303041 -> V=1.0, theta=0.0
% INFO    : Bus 31040	: V=0.969705, theta=-39.487325 -> V=1.0, theta=0.0
% INFO    : Bus 31041	: V=0.9709758, theta=-39.196031 -> V=1.0, theta=0.0
% INFO    : Bus 31042	: V=0.967154, theta=-39.998871 -> V=1.0, theta=0.0
% INFO    : Bus 31043	: V=0.9657938, theta=-40.855428 -> V=1.0, theta=0.0
% INFO    : Bus 31044	: V=0.9679807, theta=-39.862762 -> V=1.0, theta=0.0
% INFO    : Bus 31045	: V=0.9669241, theta=-40.100425 -> V=1.0, theta=0.0
% INFO    : Bus 31046	: V=0.964272, theta=-40.636628 -> V=1.0, theta=0.0
% INFO    : Bus 31047	: V=0.9665256, theta=-40.107472 -> V=1.0, theta=0.0
% INFO    : Bus 31048	: V=0.9653232, theta=-40.416992 -> V=1.0, theta=0.0
% INFO    : Bus 31049	: V=0.9659102, theta=-40.210257 -> V=1.0, theta=0.0
% INFO    : Bus 31050	: V=0.9622483, theta=-41.60355 -> V=1.0, theta=0.0
% INFO    : Bus 31051	: V=0.9690613, theta=-40.293624 -> V=1.0, theta=0.0
% INFO    : Bus 31052	: V=0.9660867, theta=-40.55155 -> V=1.0, theta=0.0
% INFO    : Bus 31053	: V=0.9659467, theta=-40.822784 -> V=1.0, theta=0.0
% INFO    : Bus 31054	: V=0.9646689, theta=-40.938174 -> V=1.0, theta=0.0
% INFO    : Bus 31055	: V=0.9703493, theta=-40.030966 -> V=1.0, theta=0.0
% INFO    : Bus 31056	: V=0.9668165, theta=-40.72311 -> V=1.0, theta=0.0
% INFO    : Bus 31057	: V=0.9712345, theta=-39.797684 -> V=1.0, theta=0.0
% INFO    : Bus 31058	: V=0.9709823, theta=-39.895363 -> V=1.0, theta=0.0
% INFO    : Bus 31059	: V=0.9711808, theta=-39.848194 -> V=1.0, theta=0.0
% INFO    : Bus 31060	: V=0.9699653, theta=-40.011286 -> V=1.0, theta=0.0
% INFO    : Bus 31061	: V=0.966557, theta=-40.737056 -> V=1.0, theta=0.0
% INFO    : Bus 31062	: V=0.9690883, theta=-40.13807 -> V=1.0, theta=0.0
% INFO    : Bus 31063	: V=0.9682692, theta=-40.249947 -> V=1.0, theta=0.0
% INFO    : Bus 31064	: V=0.9666653, theta=-40.468128 -> V=1.0, theta=0.0
% INFO    : Bus 31065	: V=0.9572426, theta=-42.271656 -> V=1.0, theta=0.0
% INFO    : Bus 31066	: V=0.9669908, theta=-40.427507 -> V=1.0, theta=0.0
% INFO    : Bus 31067	: V=0.9653336, theta=-40.62266 -> V=1.0, theta=0.0
% INFO    : Bus 31068	: V=0.9625258, theta=-41.277285 -> V=1.0, theta=0.0
% INFO    : Bus 31069	: V=0.9679413, theta=-40.439354 -> V=1.0, theta=0.0
% INFO    : Bus 31070	: V=0.9612725, theta=-41.677505 -> V=1.0, theta=0.0
% INFO    : Bus 31071	: V=0.9611385, theta=-41.71063 -> V=1.0, theta=0.0
% INFO    : Bus 31072	: V=0.9599725, theta=-41.794937 -> V=1.0, theta=0.0
% INFO    : Bus 31073	: V=0.9587566, theta=-41.989757 -> V=1.0, theta=0.0
% INFO    : Bus 31074	: V=0.9591796, theta=-41.922875 -> V=1.0, theta=0.0
% INFO    : Bus 31075	: V=0.9559367, theta=-43.430877 -> V=1.0, theta=0.0
% INFO    : Bus 31076	: V=0.9582743, theta=-42.130326 -> V=1.0, theta=0.0
% INFO    : Bus 31077	: V=0.9579365, theta=-42.285497 -> V=1.0, theta=0.0
% INFO    : Bus 31078	: V=0.9589796, theta=-41.998957 -> V=1.0, theta=0.0
% INFO    : Bus 31079	: V=0.9597947, theta=-41.947804 -> V=1.0, theta=0.0
% INFO    : Bus 31080	: V=0.9573535, theta=-42.212506 -> V=1.0, theta=0.0
% INFO    : Bus 31081	: V=0.9578276, theta=-42.426943 -> V=1.0, theta=0.0
% INFO    : Bus 31082	: V=0.9613309, theta=-41.739364 -> V=1.0, theta=0.0
% INFO    : Bus 31083	: V=0.9583149, theta=-42.785811 -> V=1.0, theta=0.0
% INFO    : Bus 31084	: V=0.9564646, theta=-43.104166 -> V=1.0, theta=0.0
% INFO    : Bus 31085	: V=0.958192, theta=-43.01652 -> V=1.0, theta=0.0
% INFO    : Bus 31086	: V=0.9559733, theta=-43.520557 -> V=1.0, theta=0.0
% INFO    : Bus 31087	: V=0.9559106, theta=-43.876185 -> V=1.0, theta=0.0
% INFO    : Bus 31088	: V=0.9563511, theta=-43.359513 -> V=1.0, theta=0.0
% INFO    : Bus 31089	: V=0.954817, theta=-43.546345 -> V=1.0, theta=0.0
% INFO    : Bus 31090	: V=0.95981, theta=-42.056104 -> V=1.0, theta=0.0
% INFO    : Bus 31091	: V=0.9544189, theta=-44.720779 -> V=1.0, theta=0.0
% INFO    : Bus 31092	: V=0.9548796, theta=-44.705498 -> V=1.0, theta=0.0
% INFO    : Bus 31093	: V=0.9545926, theta=-44.792521 -> V=1.0, theta=0.0
% INFO    : Bus 31094	: V=0.9554701, theta=-43.557691 -> V=1.0, theta=0.0
% INFO    : Bus 31095	: V=0.9541866, theta=-44.775819 -> V=1.0, theta=0.0
% INFO    : Bus 31096	: V=0.954659, theta=-44.712461 -> V=1.0, theta=0.0
% INFO    : Bus 31097	: V=0.9659898, theta=-40.548932 -> V=1.0, theta=0.0
% INFO    : Bus 31098	: V=0.9579566, theta=-42.160452 -> V=1.0, theta=0.0
% INFO    : Bus 31099	: V=0.9545963, theta=-44.686311 -> V=1.0, theta=0.0
% INFO    : Bus 31100	: V=0.9539806, theta=-44.825801 -> V=1.0, theta=0.0
% INFO    : Bus 31101	: V=0.9548248, theta=-44.808715 -> V=1.0, theta=0.0
% INFO    : Bus 31102	: V=0.9567375, theta=-44.795915 -> V=1.0, theta=0.0
% INFO    : Bus 31103	: V=0.9539418, theta=-44.851337 -> V=1.0, theta=0.0
% INFO    : Bus 31104	: V=0.9561797, theta=-44.808205 -> V=1.0, theta=0.0
% INFO    : Bus 31105	: V=0.955028, theta=-44.802848 -> V=1.0, theta=0.0
% INFO    : Bus 31106	: V=0.9554205, theta=-44.516068 -> V=1.0, theta=0.0
% INFO    : Bus 31107	: V=0.9547885, theta=-44.542529 -> V=1.0, theta=0.0
% INFO    : Bus 31108	: V=0.9558209, theta=-44.637918 -> V=1.0, theta=0.0
% INFO    : Bus 31109	: V=0.9570982, theta=-44.614499 -> V=1.0, theta=0.0
% INFO    : Bus 31110	: V=0.9559719, theta=-44.176162 -> V=1.0, theta=0.0
% INFO    : Bus 31111	: V=0.958288, theta=-44.146678 -> V=1.0, theta=0.0
% INFO    : Bus 31112	: V=0.9566312, theta=-44.214428 -> V=1.0, theta=0.0
% INFO    : Bus 31113	: V=0.9567304, theta=-44.270106 -> V=1.0, theta=0.0
% INFO    : Bus 31114	: V=0.9595089, theta=-44.261353 -> V=1.0, theta=0.0
% INFO    : Bus 31115	: V=0.9577444, theta=-44.291159 -> V=1.0, theta=0.0
% INFO    : Bus 31116	: V=0.9607167, theta=-44.270933 -> V=1.0, theta=0.0
% INFO    : Bus 31117	: V=0.9631016, theta=-44.007007 -> V=1.0, theta=0.0
% INFO    : Bus 31118	: V=0.9606095, theta=-44.143534 -> V=1.0, theta=0.0
% INFO    : Bus 31119	: V=0.9732377, theta=-37.665388 -> V=1.0, theta=0.0
% INFO    : Bus 31120	: V=0.9721319, theta=-39.624424 -> V=1.0, theta=0.0
% INFO    : Bus 31121	: V=0.9685226, theta=-41.255023 -> V=1.0, theta=0.0
% INFO    : Bus 31122	: V=0.9644991, theta=-41.959421 -> V=1.0, theta=0.0
% INFO    : Bus 31123	: V=0.9993836, theta=-34.252037 -> V=1.0, theta=0.0
% INFO    : Bus 31124	: V=0.9945138, theta=-34.990136 -> V=1.0, theta=0.0
% INFO    : Bus 31125	: V=0.9935333, theta=-35.095819 -> V=1.0, theta=0.0
% INFO    : Bus 31126	: V=0.991505, theta=-35.413791 -> V=1.0, theta=0.0
% INFO    : Bus 31127	: V=0.9594633, theta=-44.022227 -> V=1.0, theta=0.0
% INFO    : Bus 31128	: V=0.9593461, theta=-44.114038 -> V=1.0, theta=0.0
% INFO    : Bus 31129	: V=0.9574167, theta=-44.320583 -> V=1.0, theta=0.0
% INFO    : Bus 31130	: V=0.9596317, theta=-44.186881 -> V=1.0, theta=0.0
% INFO    : Bus 31131	: V=0.9588153, theta=-44.086669 -> V=1.0, theta=0.0
% INFO    : Bus 31132	: V=0.9586963, theta=-44.184983 -> V=1.0, theta=0.0
% INFO    : Bus 31133	: V=0.9592382, theta=-44.122101 -> V=1.0, theta=0.0
% INFO    : Bus 31134	: V=0.9600277, theta=-44.124414 -> V=1.0, theta=0.0
% INFO    : Bus 31135	: V=0.9605326, theta=-44.119632 -> V=1.0, theta=0.0
% INFO    : Bus 31136	: V=0.9595068, theta=-43.956401 -> V=1.0, theta=0.0
% INFO    : Bus 31137	: V=0.9598162, theta=-43.867366 -> V=1.0, theta=0.0
% INFO    : Bus 31138	: V=0.9577006, theta=-43.294221 -> V=1.0, theta=0.0
% INFO    : Bus 31139	: V=0.95909, theta=-43.270581 -> V=1.0, theta=0.0
% INFO    : Bus 31140	: V=0.9587807, theta=-43.627781 -> V=1.0, theta=0.0
% INFO    : Bus 31141	: V=0.9568008, theta=-43.350274 -> V=1.0, theta=0.0
% INFO    : Bus 31142	: V=0.9569242, theta=-43.346729 -> V=1.0, theta=0.0
% INFO    : Bus 31143	: V=0.9585784, theta=-43.001118 -> V=1.0, theta=0.0
% INFO    : Bus 31144	: V=0.9596097, theta=-42.959469 -> V=1.0, theta=0.0
% INFO    : Bus 31145	: V=0.9878033, theta=-36.013344 -> V=1.0, theta=0.0
% INFO    : Bus 31146	: V=0.9863216, theta=-36.259703 -> V=1.0, theta=0.0
% INFO    : Bus 31147	: V=0.9834806, theta=-36.745927 -> V=1.0, theta=0.0
% INFO    : Bus 31148	: V=0.9647663, theta=-40.016819 -> V=1.0, theta=0.0
% INFO    : Bus 31149	: V=0.9699251, theta=-40.196057 -> V=1.0, theta=0.0
% INFO    : Bus 31150	: V=0.9683093, theta=-40.488552 -> V=1.0, theta=0.0
% INFO    : Bus 31151	: V=0.968877, theta=-40.3587 -> V=1.0, theta=0.0
% INFO    : Bus 31152	: V=0.9846455, theta=-35.834986 -> V=1.0, theta=0.0
% INFO    : Bus 31153	: V=0.9834568, theta=-35.843446 -> V=1.0, theta=0.0
% INFO    : Bus 31154	: V=0.9816794, theta=-37.301535 -> V=1.0, theta=0.0
% INFO    : Bus 31155	: V=0.9800981, theta=-37.572772 -> V=1.0, theta=0.0
% INFO    : Bus 31156	: V=0.9832588, theta=-37.005212 -> V=1.0, theta=0.0
% INFO    : Bus 31157	: V=0.9781616, theta=-37.753494 -> V=1.0, theta=0.0
% INFO    : Bus 31158	: V=0.9803397, theta=-37.358565 -> V=1.0, theta=0.0
% INFO    : Bus 31159	: V=0.9590485, theta=-44.1783 -> V=1.0, theta=0.0
% INFO    : Bus 31160	: V=0.9582778, theta=-44.226252 -> V=1.0, theta=0.0
% INFO    : Bus 31161	: V=0.9572561, theta=-39.177336 -> V=1.0, theta=0.0
% INFO    : Bus 31162	: V=0.9989243, theta=-34.501059 -> V=1.0, theta=0.0
% INFO    : Bus 31163	: V=0.9963859, theta=-34.775662 -> V=1.0, theta=0.0
% INFO    : Bus 31164	: V=0.9865417, theta=-36.485349 -> V=1.0, theta=0.0
% INFO    : Bus 31165	: V=0.9938896, theta=-35.236891 -> V=1.0, theta=0.0
% INFO    : Bus 31166	: V=0.969889, theta=-39.01639 -> V=1.0, theta=0.0
% INFO    : Bus 31167	: V=0.9832631, theta=-37.044468 -> V=1.0, theta=0.0
% INFO    : Bus 31168	: V=0.9588768, theta=-38.797201 -> V=1.0, theta=0.0
% INFO    : Bus 31169	: V=0.966112, theta=-39.246399 -> V=1.0, theta=0.0
% INFO    : Bus 31170	: V=0.9754018, theta=-38.675398 -> V=1.0, theta=0.0
% INFO    : Bus 31171	: V=0.9828045, theta=-37.376139 -> V=1.0, theta=0.0
% INFO    : Bus 31172	: V=0.9821698, theta=-37.318507 -> V=1.0, theta=0.0
% INFO    : Bus 31173	: V=0.9588888, theta=-39.454619 -> V=1.0, theta=0.0
% INFO    : Bus 31174	: V=0.9607743, theta=-39.489263 -> V=1.0, theta=0.0
% INFO    : Bus 31175	: V=0.9844132, theta=-37.416442 -> V=1.0, theta=0.0
% INFO    : Bus 31176	: V=0.9881288, theta=-36.200135 -> V=1.0, theta=0.0
% INFO    : Bus 31177	: V=0.9902604, theta=-35.837094 -> V=1.0, theta=0.0
% INFO    : Bus 31178	: V=1.013103, theta=-31.766162 -> V=1.0, theta=0.0
% INFO    : Bus 31179	: V=1.0130781, theta=-28.389798 -> V=1.0, theta=0.0
% INFO    : Bus 31180	: V=1.0037824, theta=-30.900458 -> V=1.0, theta=0.0
% INFO    : Bus 31181	: V=0.99741, theta=-34.12619 -> V=1.0, theta=0.0
% INFO    : Bus 31182	: V=1.0006267, theta=-31.677289 -> V=1.0, theta=0.0
% INFO    : Bus 31183	: V=0.9985782, theta=-34.223146 -> V=1.0, theta=0.0
% INFO    : Bus 31184	: V=0.9986893, theta=-34.266874 -> V=1.0, theta=0.0
% INFO    : Bus 31185	: V=0.9951044, theta=-34.903562 -> V=1.0, theta=0.0
% INFO    : Bus 31186	: V=0.9936624, theta=-34.645744 -> V=1.0, theta=0.0
% INFO    : Bus 31187	: V=0.9970055, theta=-34.613386 -> V=1.0, theta=0.0
% INFO    : Bus 31188	: V=0.9781532, theta=-37.891398 -> V=1.0, theta=0.0
% INFO    : Bus 31189	: V=0.9855052, theta=-37.346411 -> V=1.0, theta=0.0
% INFO    : Bus 31190	: V=0.958395, theta=-39.367449 -> V=1.0, theta=0.0
% INFO    : Bus 31191	: V=0.9590451, theta=-44.094003 -> V=1.0, theta=0.0
% INFO    : Bus 31192	: V=0.9823827, theta=-38.16036 -> V=1.0, theta=0.0
% INFO    : Bus 31193	: V=0.9891411, theta=-51.802498 -> V=1.0, theta=0.0
% INFO    : Bus 31194	: V=0.9874649, theta=-51.947076 -> V=1.0, theta=0.0
% INFO    : Bus 31195	: V=0.9774281, theta=-52.746665 -> V=1.0, theta=0.0
% INFO    : Bus 31196	: V=0.9753737, theta=-52.83544 -> V=1.0, theta=0.0
% INFO    : Bus 31197	: V=0.9832307, theta=-52.580608 -> V=1.0, theta=0.0
% INFO    : Bus 31198	: V=0.9767716, theta=-53.38095 -> V=1.0, theta=0.0
% INFO    : Bus 31199	: V=0.9957532, theta=-51.75465 -> V=1.0, theta=0.0
% INFO    : Bus 31200	: V=0.9968049, theta=-51.717131 -> V=1.0, theta=0.0
% INFO    : Bus 31201	: V=0.9985058, theta=-51.720605 -> V=1.0, theta=0.0
% INFO    : Bus 31202	: V=1.0120588, theta=-50.828254 -> V=1.0, theta=0.0
% INFO    : Bus 31203	: V=0.9917181, theta=-52.271289 -> V=1.0, theta=0.0
% INFO    : Bus 31204	: V=0.9995261, theta=-51.7096 -> V=1.0, theta=0.0
% INFO    : Bus 31205	: V=0.9921991, theta=-52.2662 -> V=1.0, theta=0.0
% INFO    : Bus 31206	: V=0.9928018, theta=-52.249442 -> V=1.0, theta=0.0
% INFO    : Bus 31207	: V=0.9932594, theta=-52.244616 -> V=1.0, theta=0.0
% INFO    : Bus 31208	: V=0.9987641, theta=-51.751291 -> V=1.0, theta=0.0
% INFO    : Bus 31209	: V=1.0025009, theta=-51.5302 -> V=1.0, theta=0.0
% INFO    : Bus 31210	: V=1.0000667, theta=-51.672491 -> V=1.0, theta=0.0
% INFO    : Bus 31211	: V=0.9942137, theta=-52.171933 -> V=1.0, theta=0.0
% INFO    : Bus 31212	: V=0.998226, theta=-51.763891 -> V=1.0, theta=0.0
% INFO    : Bus 31213	: V=0.9967642, theta=-51.85593 -> V=1.0, theta=0.0
% INFO    : Bus 31214	: V=0.9975942, theta=-51.815934 -> V=1.0, theta=0.0
% INFO    : Bus 31215	: V=1.0149681, theta=-50.505466 -> V=1.0, theta=0.0
% INFO    : Bus 31216	: V=0.9976626, theta=-51.68351 -> V=1.0, theta=0.0
% INFO    : Bus 31217	: V=0.9944966, theta=-51.792377 -> V=1.0, theta=0.0
% INFO    : Bus 31218	: V=0.9929539, theta=-51.859549 -> V=1.0, theta=0.0
% INFO    : Bus 31219	: V=0.9776609, theta=-53.306782 -> V=1.0, theta=0.0
% INFO    : Bus 31220	: V=0.9939382, theta=-51.824819 -> V=1.0, theta=0.0
% INFO    : Bus 31221	: V=0.9902007, theta=-51.922347 -> V=1.0, theta=0.0
% INFO    : Bus 31222	: V=0.9916933, theta=-51.91035 -> V=1.0, theta=0.0
% INFO    : Bus 31223	: V=0.9841404, theta=-52.5773 -> V=1.0, theta=0.0
% INFO    : Bus 31224	: V=0.9837647, theta=-52.606368 -> V=1.0, theta=0.0
% INFO    : Bus 31225	: V=0.9838872, theta=-52.433917 -> V=1.0, theta=0.0
% INFO    : Bus 31226	: V=0.9765099, theta=-52.82055 -> V=1.0, theta=0.0
% INFO    : Bus 31227	: V=0.9773248, theta=-52.78891 -> V=1.0, theta=0.0
% INFO    : Bus 31228	: V=0.9763777, theta=-52.801393 -> V=1.0, theta=0.0
% INFO    : Bus 31229	: V=0.9835972, theta=-52.450304 -> V=1.0, theta=0.0
% INFO    : Bus 31230	: V=0.9907976, theta=-51.932524 -> V=1.0, theta=0.0
% INFO    : Bus 31231	: V=0.9840645, theta=-52.587298 -> V=1.0, theta=0.0
% INFO    : Bus 31232	: V=0.9786732, theta=-52.693547 -> V=1.0, theta=0.0
% INFO    : Bus 31233	: V=0.9895103, theta=-51.873426 -> V=1.0, theta=0.0
% INFO    : Bus 31234	: V=0.9847463, theta=-52.188916 -> V=1.0, theta=0.0
% INFO    : Bus 31235	: V=0.9804169, theta=-52.562313 -> V=1.0, theta=0.0
% INFO    : Bus 31236	: V=0.9826665, theta=-52.380811 -> V=1.0, theta=0.0
% INFO    : Bus 31237	: V=0.9945498, theta=-51.524821 -> V=1.0, theta=0.0
% INFO    : Bus 31238	: V=0.9885024, theta=-51.744711 -> V=1.0, theta=0.0
% INFO    : Bus 31239	: V=0.9952323, theta=-51.233225 -> V=1.0, theta=0.0
% INFO    : Bus 31240	: V=0.9827484, theta=-52.336046 -> V=1.0, theta=0.0
% INFO    : Bus 31241	: V=0.991038, theta=-51.768191 -> V=1.0, theta=0.0
% INFO    : Bus 31242	: V=0.9954312, theta=-51.766107 -> V=1.0, theta=0.0
% INFO    : Bus 31243	: V=0.9992182, theta=-51.596823 -> V=1.0, theta=0.0
% INFO    : Bus 31244	: V=0.9967825, theta=-51.718975 -> V=1.0, theta=0.0
% INFO    : Bus 31245	: V=0.9872827, theta=-52.430721 -> V=1.0, theta=0.0
% INFO    : Bus 31246	: V=0.9956015, theta=-51.759311 -> V=1.0, theta=0.0
% INFO    : Bus 31247	: V=0.9979159, theta=-51.661338 -> V=1.0, theta=0.0
% INFO    : Bus 31248	: V=0.9912493, theta=-52.200551 -> V=1.0, theta=0.0
% INFO    : Bus 31249	: V=0.9954517, theta=-51.902684 -> V=1.0, theta=0.0
% INFO    : Bus 31250	: V=0.9969363, theta=-51.826973 -> V=1.0, theta=0.0
% INFO    : Bus 31251	: V=0.9940684, theta=-51.947977 -> V=1.0, theta=0.0
% INFO    : Bus 31252	: V=0.9808854, theta=-52.830524 -> V=1.0, theta=0.0
% INFO    : Bus 31253	: V=0.9950558, theta=-51.917562 -> V=1.0, theta=0.0
% INFO    : Bus 31254	: V=0.9771342, theta=-52.939322 -> V=1.0, theta=0.0
% INFO    : Bus 31255	: V=0.9700254, theta=-53.128695 -> V=1.0, theta=0.0
% INFO    : Bus 31256	: V=0.9802213, theta=-52.171041 -> V=1.0, theta=0.0
% INFO    : Bus 31257	: V=0.9573805, theta=-53.490297 -> V=1.0, theta=0.0
% INFO    : Bus 31258	: V=0.9546552, theta=-53.596953 -> V=1.0, theta=0.0
% INFO    : Bus 31259	: V=0.9544979, theta=-53.559007 -> V=1.0, theta=0.0
% INFO    : Bus 31260	: V=0.9852757, theta=-51.955581 -> V=1.0, theta=0.0
% INFO    : Bus 31261	: V=0.991022, theta=-51.652176 -> V=1.0, theta=0.0
% INFO    : Bus 31262	: V=0.9902278, theta=-51.91999 -> V=1.0, theta=0.0
% INFO    : Bus 31263	: V=0.9919816, theta=-52.000312 -> V=1.0, theta=0.0
% INFO    : Bus 31264	: V=0.9798264, theta=-52.850063 -> V=1.0, theta=0.0
% INFO    : Bus 31265	: V=0.9905423, theta=-51.974128 -> V=1.0, theta=0.0
% INFO    : Bus 31266	: V=0.9910564, theta=-52.016258 -> V=1.0, theta=0.0
% INFO    : Bus 31267	: V=0.9919805, theta=-51.356195 -> V=1.0, theta=0.0
% INFO    : Bus 31268	: V=1.008027, theta=-50.216262 -> V=1.0, theta=0.0
% INFO    : Bus 31269	: V=0.9792626, theta=-52.105914 -> V=1.0, theta=0.0
% INFO    : Bus 31270	: V=0.9911684, theta=-51.534917 -> V=1.0, theta=0.0
% INFO    : Bus 31271	: V=1.0113682, theta=-50.160888 -> V=1.0, theta=0.0
% INFO    : Bus 31272	: V=0.9760256, theta=-52.221816 -> V=1.0, theta=0.0
% INFO    : Bus 31273	: V=0.9812704, theta=-51.631095 -> V=1.0, theta=0.0
% INFO    : Bus 31274	: V=0.9840563, theta=-51.737291 -> V=1.0, theta=0.0
% INFO    : Bus 31275	: V=0.9741057, theta=-52.500419 -> V=1.0, theta=0.0
% INFO    : Bus 31276	: V=0.978262, theta=-52.011911 -> V=1.0, theta=0.0
% INFO    : Bus 31277	: V=0.9752242, theta=-52.062402 -> V=1.0, theta=0.0
% INFO    : Bus 31278	: V=0.9734697, theta=-52.223254 -> V=1.0, theta=0.0
% INFO    : Bus 31279	: V=0.9547945, theta=-53.585909 -> V=1.0, theta=0.0
% INFO    : Bus 31280	: V=0.9552445, theta=-53.558609 -> V=1.0, theta=0.0
% INFO    : Bus 31281	: V=0.967949, theta=-52.541854 -> V=1.0, theta=0.0
% INFO    : Bus 31282	: V=0.968891, theta=-52.495284 -> V=1.0, theta=0.0
% INFO    : Bus 31283	: V=0.9704813, theta=-52.404134 -> V=1.0, theta=0.0
% INFO    : Bus 31284	: V=0.969806, theta=-52.43177 -> V=1.0, theta=0.0
% INFO    : Bus 31285	: V=0.9540371, theta=-53.597601 -> V=1.0, theta=0.0
% INFO    : Bus 31286	: V=0.9511695, theta=-53.735356 -> V=1.0, theta=0.0
% INFO    : Bus 31287	: V=0.9687376, theta=-52.074932 -> V=1.0, theta=0.0
% INFO    : Bus 31288	: V=0.9659359, theta=-52.323403 -> V=1.0, theta=0.0
% INFO    : Bus 31289	: V=0.9666733, theta=-52.072135 -> V=1.0, theta=0.0
% INFO    : Bus 31290	: V=0.9628748, theta=-52.898209 -> V=1.0, theta=0.0
% INFO    : Bus 31291	: V=0.9638908, theta=-52.498918 -> V=1.0, theta=0.0
% INFO    : Bus 31292	: V=0.9608972, theta=-52.417819 -> V=1.0, theta=0.0
% INFO    : Bus 31293	: V=0.9512101, theta=-53.66249 -> V=1.0, theta=0.0
% INFO    : Bus 31294	: V=0.9537705, theta=-53.478451 -> V=1.0, theta=0.0
% INFO    : Bus 31295	: V=0.9520443, theta=-53.259493 -> V=1.0, theta=0.0
% INFO    : Bus 31296	: V=0.9545272, theta=-53.413426 -> V=1.0, theta=0.0
% INFO    : Bus 31297	: V=0.9529336, theta=-53.236566 -> V=1.0, theta=0.0
% INFO    : Bus 31298	: V=0.9720691, theta=-51.785292 -> V=1.0, theta=0.0
% INFO    : Bus 31299	: V=0.9754963, theta=-51.491183 -> V=1.0, theta=0.0
% INFO    : Bus 31300	: V=0.9803425, theta=-51.091435 -> V=1.0, theta=0.0
% INFO    : Bus 31301	: V=0.9762763, theta=-51.243584 -> V=1.0, theta=0.0
% INFO    : Bus 31302	: V=0.9766217, theta=-51.431474 -> V=1.0, theta=0.0
% INFO    : Bus 31303	: V=0.9858352, theta=-50.663439 -> V=1.0, theta=0.0
% INFO    : Bus 31304	: V=0.9834045, theta=-50.669318 -> V=1.0, theta=0.0
% INFO    : Bus 31305	: V=0.9863524, theta=-50.487401 -> V=1.0, theta=0.0
% INFO    : Bus 31306	: V=0.9809475, theta=-50.637552 -> V=1.0, theta=0.0
% INFO    : Bus 31307	: V=0.9863221, theta=-50.297644 -> V=1.0, theta=0.0
% INFO    : Bus 31308	: V=0.9796223, theta=-50.596895 -> V=1.0, theta=0.0
% INFO    : Bus 31309	: V=0.9790206, theta=-50.566522 -> V=1.0, theta=0.0
% INFO    : Bus 31310	: V=0.9686153, theta=-51.797103 -> V=1.0, theta=0.0
% INFO    : Bus 31311	: V=0.9616946, theta=-52.01615 -> V=1.0, theta=0.0
% INFO    : Bus 31312	: V=0.9625874, theta=-52.280946 -> V=1.0, theta=0.0
% INFO    : Bus 31313	: V=0.9605356, theta=-52.021758 -> V=1.0, theta=0.0
% INFO    : Bus 31314	: V=0.9803826, theta=-50.325405 -> V=1.0, theta=0.0
% INFO    : Bus 31315	: V=0.9709489, theta=-51.496352 -> V=1.0, theta=0.0
% INFO    : Bus 31316	: V=0.969618, theta=-51.532541 -> V=1.0, theta=0.0
% INFO    : Bus 31317	: V=0.9639327, theta=-52.186169 -> V=1.0, theta=0.0
% INFO    : Bus 31318	: V=0.9778312, theta=-50.586208 -> V=1.0, theta=0.0
% INFO    : Bus 31319	: V=0.9700517, theta=-51.523409 -> V=1.0, theta=0.0
% INFO    : Bus 31320	: V=0.9649722, theta=-51.855901 -> V=1.0, theta=0.0
% INFO    : Bus 31321	: V=0.9671028, theta=-51.712684 -> V=1.0, theta=0.0
% INFO    : Bus 31322	: V=0.9773342, theta=-50.539871 -> V=1.0, theta=0.0
% INFO    : Bus 31323	: V=0.977344, theta=-50.38873 -> V=1.0, theta=0.0
% INFO    : Bus 31324	: V=0.9866676, theta=-50.038733 -> V=1.0, theta=0.0
% INFO    : Bus 31325	: V=0.9777174, theta=-50.174626 -> V=1.0, theta=0.0
% INFO    : Bus 31326	: V=0.9673957, theta=-54.544353 -> V=1.0, theta=0.0
% INFO    : Bus 31327	: V=0.9610548, theta=-54.891348 -> V=1.0, theta=0.0
% INFO    : Bus 31328	: V=0.9516177, theta=-55.672147 -> V=1.0, theta=0.0
% INFO    : Bus 31329	: V=0.9601241, theta=-54.902801 -> V=1.0, theta=0.0
% INFO    : Bus 31330	: V=0.9712563, theta=-54.404707 -> V=1.0, theta=0.0
% INFO    : Bus 31331	: V=0.967846, theta=-54.508877 -> V=1.0, theta=0.0
% INFO    : Bus 31332	: V=0.9618637, theta=-54.846963 -> V=1.0, theta=0.0
% INFO    : Bus 31333	: V=0.9612018, theta=-54.852974 -> V=1.0, theta=0.0
% INFO    : Bus 31334	: V=0.9669824, theta=-54.624763 -> V=1.0, theta=0.0
% INFO    : Bus 31335	: V=0.965186, theta=-54.718773 -> V=1.0, theta=0.0
% INFO    : Bus 31336	: V=0.9693687, theta=-54.487973 -> V=1.0, theta=0.0
% INFO    : Bus 31337	: V=0.9791143, theta=-53.653996 -> V=1.0, theta=0.0
% INFO    : Bus 31338	: V=0.9811033, theta=-53.639863 -> V=1.0, theta=0.0
% INFO    : Bus 31339	: V=0.9809683, theta=-53.609688 -> V=1.0, theta=0.0
% INFO    : Bus 31340	: V=0.9973397, theta=-52.498409 -> V=1.0, theta=0.0
% INFO    : Bus 31341	: V=0.9714051, theta=-54.291282 -> V=1.0, theta=0.0
% INFO    : Bus 31342	: V=0.9796249, theta=-53.141537 -> V=1.0, theta=0.0
% INFO    : Bus 31343	: V=0.97434, theta=-54.004087 -> V=1.0, theta=0.0
% INFO    : Bus 31344	: V=0.9786655, theta=-53.559126 -> V=1.0, theta=0.0
% INFO    : Bus 31345	: V=0.9763385, theta=-53.731956 -> V=1.0, theta=0.0
% INFO    : Bus 31346	: V=0.9729238, theta=-53.998077 -> V=1.0, theta=0.0
% INFO    : Bus 31347	: V=0.9708249, theta=-54.12067 -> V=1.0, theta=0.0
% INFO    : Bus 31348	: V=0.968912, theta=-54.222817 -> V=1.0, theta=0.0
% INFO    : Bus 31349	: V=0.9686999, theta=-54.249913 -> V=1.0, theta=0.0
% INFO    : Bus 31350	: V=0.9664976, theta=-54.500586 -> V=1.0, theta=0.0
% INFO    : Bus 31351	: V=0.9557858, theta=-55.161789 -> V=1.0, theta=0.0
% INFO    : Bus 31352	: V=0.9544319, theta=-55.21193 -> V=1.0, theta=0.0
% INFO    : Bus 31353	: V=0.9530162, theta=-55.23679 -> V=1.0, theta=0.0
% INFO    : Bus 31354	: V=0.9562303, theta=-55.078065 -> V=1.0, theta=0.0
% INFO    : Bus 31355	: V=0.9544521, theta=-55.203216 -> V=1.0, theta=0.0
% INFO    : Bus 31356	: V=0.9580245, theta=-54.973294 -> V=1.0, theta=0.0
% INFO    : Bus 31357	: V=0.9614085, theta=-54.763481 -> V=1.0, theta=0.0
% INFO    : Bus 31358	: V=0.9693943, theta=-54.042463 -> V=1.0, theta=0.0
% INFO    : Bus 31359	: V=0.9705417, theta=-54.034153 -> V=1.0, theta=0.0
% INFO    : Bus 31360	: V=0.9692325, theta=-54.246288 -> V=1.0, theta=0.0
% INFO    : Bus 31361	: V=0.984489, theta=-52.799633 -> V=1.0, theta=0.0
% INFO    : Bus 31362	: V=0.9715623, theta=-53.967803 -> V=1.0, theta=0.0
% INFO    : Bus 31363	: V=0.9829725, theta=-52.932296 -> V=1.0, theta=0.0
% INFO    : Bus 31364	: V=0.9869665, theta=-52.534571 -> V=1.0, theta=0.0
% INFO    : Bus 31365	: V=0.9863124, theta=-52.548765 -> V=1.0, theta=0.0
% INFO    : Bus 31366	: V=0.9776734, theta=-53.549447 -> V=1.0, theta=0.0
% INFO    : Bus 31367	: V=0.978147, theta=-53.542836 -> V=1.0, theta=0.0
% INFO    : Bus 31368	: V=0.9772402, theta=-53.630215 -> V=1.0, theta=0.0
% INFO    : Bus 31369	: V=0.9768658, theta=-53.675262 -> V=1.0, theta=0.0
% INFO    : Bus 31370	: V=0.9783278, theta=-53.593924 -> V=1.0, theta=0.0
% INFO    : Bus 31371	: V=0.979304, theta=-53.555752 -> V=1.0, theta=0.0
% INFO    : Bus 31372	: V=0.9793245, theta=-53.524403 -> V=1.0, theta=0.0
% INFO    : Bus 31373	: V=0.9795433, theta=-53.473947 -> V=1.0, theta=0.0
% INFO    : Bus 31374	: V=0.9798837, theta=-53.420828 -> V=1.0, theta=0.0
% INFO    : Bus 31375	: V=0.9804333, theta=-53.447317 -> V=1.0, theta=0.0
% INFO    : Bus 31376	: V=0.9829112, theta=-53.1835 -> V=1.0, theta=0.0
% INFO    : Bus 31377	: V=1.002807, theta=-50.882685 -> V=1.0, theta=0.0
% INFO    : Bus 31378	: V=0.9862499, theta=-52.801467 -> V=1.0, theta=0.0
% INFO    : Bus 31379	: V=0.9800348, theta=-53.375091 -> V=1.0, theta=0.0
% INFO    : Bus 31380	: V=0.9885352, theta=-52.423357 -> V=1.0, theta=0.0
% INFO    : Bus 31381	: V=0.9805611, theta=-53.249836 -> V=1.0, theta=0.0
% INFO    : Bus 31382	: V=0.9797612, theta=-53.272412 -> V=1.0, theta=0.0
% INFO    : Bus 31383	: V=0.9812355, theta=-53.23836 -> V=1.0, theta=0.0
% INFO    : Bus 31384	: V=0.9902347, theta=-52.393832 -> V=1.0, theta=0.0
% INFO    : Bus 31385	: V=0.9816765, theta=-53.205295 -> V=1.0, theta=0.0
% INFO    : Bus 31386	: V=0.9810455, theta=-53.210605 -> V=1.0, theta=0.0
% INFO    : Bus 31387	: V=0.9956118, theta=-51.520663 -> V=1.0, theta=0.0
% INFO    : Bus 31388	: V=1.0024567, theta=-50.902319 -> V=1.0, theta=0.0
% INFO    : Bus 31389	: V=0.9903641, theta=-52.455063 -> V=1.0, theta=0.0
% INFO    : Bus 31390	: V=0.9927064, theta=-51.758002 -> V=1.0, theta=0.0
% INFO    : Bus 31391	: V=0.9792684, theta=-52.664989 -> V=1.0, theta=0.0
% INFO    : Bus 31392	: V=0.9606764, theta=-54.304053 -> V=1.0, theta=0.0
% INFO    : Bus 31393	: V=0.9641719, theta=-54.060282 -> V=1.0, theta=0.0
% INFO    : Bus 31394	: V=0.9822602, theta=-52.282549 -> V=1.0, theta=0.0
% INFO    : Bus 31395	: V=0.9784424, theta=-52.810204 -> V=1.0, theta=0.0
% INFO    : Bus 31396	: V=0.9908828, theta=-52.320138 -> V=1.0, theta=0.0
% INFO    : Bus 31397	: V=1.0113269, theta=-50.280944 -> V=1.0, theta=0.0
% INFO    : Bus 31398	: V=0.9853508, theta=-52.763016 -> V=1.0, theta=0.0
% INFO    : Bus 31399	: V=0.9769259, theta=-52.906175 -> V=1.0, theta=0.0
% INFO    : Bus 31400	: V=0.9875398, theta=-52.169903 -> V=1.0, theta=0.0
% INFO    : Bus 31401	: V=1.0111454, theta=-50.314918 -> V=1.0, theta=0.0
% INFO    : Bus 31402	: V=0.9846234, theta=-52.795691 -> V=1.0, theta=0.0
% INFO    : Bus 31403	: V=0.971223, theta=-54.113837 -> V=1.0, theta=0.0
% INFO    : Bus 31404	: V=0.9854599, theta=-52.745476 -> V=1.0, theta=0.0
% INFO    : Bus 31405	: V=0.9687734, theta=-54.235301 -> V=1.0, theta=0.0
% INFO    : Bus 31406	: V=0.9670051, theta=-54.322993 -> V=1.0, theta=0.0
% INFO    : Bus 31407	: V=0.9642483, theta=-54.543564 -> V=1.0, theta=0.0
% INFO    : Bus 31408	: V=0.9680025, theta=-54.242855 -> V=1.0, theta=0.0
% INFO    : Bus 31409	: V=0.9679027, theta=-54.311563 -> V=1.0, theta=0.0
% INFO    : Bus 31410	: V=0.9827886, theta=-52.529658 -> V=1.0, theta=0.0
% INFO    : Bus 31411	: V=0.9776556, theta=-52.836935 -> V=1.0, theta=0.0
% INFO    : Bus 31412	: V=0.9638151, theta=-54.264292 -> V=1.0, theta=0.0
% INFO    : Bus 31413	: V=0.980272, theta=-52.681757 -> V=1.0, theta=0.0
% INFO    : Bus 31414	: V=0.9756694, theta=-52.942287 -> V=1.0, theta=0.0
% INFO    : Bus 31415	: V=0.9548115, theta=-55.055909 -> V=1.0, theta=0.0
% INFO    : Bus 31416	: V=0.9773618, theta=-52.707199 -> V=1.0, theta=0.0
% INFO    : Bus 31417	: V=0.9661071, theta=-53.880885 -> V=1.0, theta=0.0
% INFO    : Bus 31418	: V=0.9730573, theta=-52.996157 -> V=1.0, theta=0.0
% INFO    : Bus 31419	: V=0.9734341, theta=-53.032932 -> V=1.0, theta=0.0
% INFO    : Bus 31420	: V=0.956372, theta=-54.97915 -> V=1.0, theta=0.0
% INFO    : Bus 31421	: V=0.9604537, theta=-54.805988 -> V=1.0, theta=0.0
% INFO    : Bus 31422	: V=0.9594278, theta=-54.870864 -> V=1.0, theta=0.0
% INFO    : Bus 31423	: V=0.9549593, theta=-55.065925 -> V=1.0, theta=0.0
% INFO    : Bus 31424	: V=0.9589994, theta=-54.903902 -> V=1.0, theta=0.0
% INFO    : Bus 31425	: V=0.9624818, theta=-54.6784 -> V=1.0, theta=0.0
% INFO    : Bus 31426	: V=0.9589129, theta=-54.915023 -> V=1.0, theta=0.0
% INFO    : Bus 31427	: V=0.9539735, theta=-55.120032 -> V=1.0, theta=0.0
% INFO    : Bus 31428	: V=0.9539057, theta=-55.125044 -> V=1.0, theta=0.0
% INFO    : Bus 31429	: V=0.950707, theta=-55.31981 -> V=1.0, theta=0.0
% INFO    : Bus 31430	: V=0.9517771, theta=-55.268948 -> V=1.0, theta=0.0
% INFO    : Bus 31431	: V=0.9481839, theta=-56.548927 -> V=1.0, theta=0.0
% INFO    : Bus 31432	: V=0.9527965, theta=-55.17786 -> V=1.0, theta=0.0
% INFO    : Bus 31433	: V=0.9543209, theta=-55.504224 -> V=1.0, theta=0.0
% INFO    : Bus 31434	: V=0.9537397, theta=-55.515307 -> V=1.0, theta=0.0
% INFO    : Bus 31435	: V=0.955219, theta=-55.478341 -> V=1.0, theta=0.0
% INFO    : Bus 31436	: V=0.9543983, theta=-55.499381 -> V=1.0, theta=0.0
% INFO    : Bus 31437	: V=0.9548088, theta=-55.489137 -> V=1.0, theta=0.0
% INFO    : Bus 31438	: V=0.9545913, theta=-55.601835 -> V=1.0, theta=0.0
% INFO    : Bus 31439	: V=0.9487486, theta=-56.437634 -> V=1.0, theta=0.0
% INFO    : Bus 31440	: V=0.9497282, theta=-56.409448 -> V=1.0, theta=0.0
% INFO    : Bus 31441	: V=0.9483658, theta=-56.523451 -> V=1.0, theta=0.0
% INFO    : Bus 31442	: V=0.9478454, theta=-56.538526 -> V=1.0, theta=0.0
% INFO    : Bus 31443	: V=0.9572853, theta=-55.34768 -> V=1.0, theta=0.0
% INFO    : Bus 31444	: V=0.9563963, theta=-55.425848 -> V=1.0, theta=0.0
% INFO    : Bus 31445	: V=0.9549103, theta=-55.556717 -> V=1.0, theta=0.0
% INFO    : Bus 31446	: V=0.9674359, theta=-53.4944 -> V=1.0, theta=0.0
% INFO    : Bus 31447	: V=0.9550986, theta=-55.561714 -> V=1.0, theta=0.0
% INFO    : Bus 31448	: V=0.955857, theta=-55.51001 -> V=1.0, theta=0.0
% INFO    : Bus 31449	: V=0.9716453, theta=-53.097434 -> V=1.0, theta=0.0
% INFO    : Bus 31450	: V=0.958804, theta=-54.941988 -> V=1.0, theta=0.0
% INFO    : Bus 31451	: V=0.9701728, theta=-53.258993 -> V=1.0, theta=0.0
% INFO    : Bus 31452	: V=0.9576268, theta=-55.014647 -> V=1.0, theta=0.0
% INFO    : Bus 31453	: V=0.9569833, theta=-55.362361 -> V=1.0, theta=0.0
% INFO    : Bus 31454	: V=0.9582777, theta=-55.005857 -> V=1.0, theta=0.0
% INFO    : Bus 31455	: V=0.9592485, theta=-54.577741 -> V=1.0, theta=0.0
% INFO    : Bus 31456	: V=0.9601947, theta=-54.47937 -> V=1.0, theta=0.0
% INFO    : Bus 31457	: V=0.961468, theta=-54.341361 -> V=1.0, theta=0.0
% INFO    : Bus 31458	: V=0.9760674, theta=-52.948491 -> V=1.0, theta=0.0
% INFO    : Bus 31459	: V=1.0036139, theta=-47.699828 -> V=1.0, theta=0.0
% INFO    : Bus 31460	: V=0.9585706, theta=-54.667078 -> V=1.0, theta=0.0
% INFO    : Bus 31461	: V=0.95683, theta=-54.811833 -> V=1.0, theta=0.0
% INFO    : Bus 31462	: V=0.962182, theta=-54.282277 -> V=1.0, theta=0.0
% INFO    : Bus 31463	: V=0.9672933, theta=-53.799091 -> V=1.0, theta=0.0
% INFO    : Bus 31464	: V=0.9738613, theta=-52.751296 -> V=1.0, theta=0.0
% INFO    : Bus 31465	: V=0.9744498, theta=-52.709015 -> V=1.0, theta=0.0
% INFO    : Bus 31466	: V=0.9554465, theta=-56.042436 -> V=1.0, theta=0.0
% INFO    : Bus 31467	: V=0.9616986, theta=-54.200598 -> V=1.0, theta=0.0
% INFO    : Bus 31468	: V=0.9544079, theta=-56.128879 -> V=1.0, theta=0.0
% INFO    : Bus 31469	: V=0.9566331, theta=-55.999264 -> V=1.0, theta=0.0
% INFO    : Bus 31470	: V=0.9551585, theta=-56.109617 -> V=1.0, theta=0.0
% INFO    : Bus 31471	: V=0.9587839, theta=-55.475862 -> V=1.0, theta=0.0
% INFO    : Bus 31472	: V=0.9596427, theta=-55.451308 -> V=1.0, theta=0.0
% INFO    : Bus 31473	: V=0.9538797, theta=-56.187456 -> V=1.0, theta=0.0
% INFO    : Bus 31474	: V=0.9556609, theta=-56.065293 -> V=1.0, theta=0.0
% INFO    : Bus 31475	: V=0.95277, theta=-54.943971 -> V=1.0, theta=0.0
% INFO    : Bus 31476	: V=0.9494338, theta=-55.300246 -> V=1.0, theta=0.0
% INFO    : Bus 31477	: V=0.9498347, theta=-55.276974 -> V=1.0, theta=0.0
% INFO    : Bus 31478	: V=0.9521565, theta=-55.038527 -> V=1.0, theta=0.0
% INFO    : Bus 31479	: V=0.9558259, theta=-54.844707 -> V=1.0, theta=0.0
% INFO    : Bus 31480	: V=0.9526871, theta=-55.021758 -> V=1.0, theta=0.0
% INFO    : Bus 31481	: V=0.954137, theta=-54.94968 -> V=1.0, theta=0.0
% INFO    : Bus 31482	: V=0.9518551, theta=-55.01851 -> V=1.0, theta=0.0
% INFO    : Bus 31483	: V=0.9558226, theta=-54.801184 -> V=1.0, theta=0.0
% INFO    : Bus 31484	: V=0.9544747, theta=-54.984782 -> V=1.0, theta=0.0
% INFO    : Bus 31485	: V=0.9569967, theta=-54.753263 -> V=1.0, theta=0.0
% INFO    : Bus 31486	: V=0.9556203, theta=-54.908764 -> V=1.0, theta=0.0
% INFO    : Bus 31487	: V=0.983654, theta=-53.594147 -> V=1.0, theta=0.0
% INFO    : Bus 31488	: V=0.956015, theta=-54.914089 -> V=1.0, theta=0.0
% INFO    : Bus 31489	: V=0.9628951, theta=-54.405151 -> V=1.0, theta=0.0
% INFO    : Bus 31490	: V=0.9599014, theta=-54.501143 -> V=1.0, theta=0.0
% INFO    : Bus 31491	: V=0.9617083, theta=-54.270446 -> V=1.0, theta=0.0
% INFO    : Bus 31492	: V=0.9587374, theta=-54.525874 -> V=1.0, theta=0.0
% INFO    : Bus 31493	: V=0.9572755, theta=-54.554744 -> V=1.0, theta=0.0
% INFO    : Bus 31494	: V=0.9639972, theta=-54.123479 -> V=1.0, theta=0.0
% INFO    : Bus 31495	: V=0.9661956, theta=-54.066342 -> V=1.0, theta=0.0
% INFO    : Bus 31496	: V=0.9931054, theta=-53.186662 -> V=1.0, theta=0.0
% INFO    : Bus 31497	: V=0.9671172, theta=-54.090165 -> V=1.0, theta=0.0
% INFO    : Bus 31498	: V=0.9611431, theta=-54.488033 -> V=1.0, theta=0.0
% INFO    : Bus 31499	: V=0.9604754, theta=-54.503229 -> V=1.0, theta=0.0
% INFO    : Bus 31500	: V=0.9595075, theta=-54.399876 -> V=1.0, theta=0.0
% INFO    : Bus 31501	: V=0.9639372, theta=-54.122629 -> V=1.0, theta=0.0
% INFO    : Bus 31502	: V=0.9602853, theta=-54.370736 -> V=1.0, theta=0.0
% INFO    : Bus 31503	: V=0.9529982, theta=-54.887341 -> V=1.0, theta=0.0
% INFO    : Bus 31504	: V=0.9624161, theta=-54.363511 -> V=1.0, theta=0.0
% INFO    : Bus 31505	: V=0.9578565, theta=-54.596263 -> V=1.0, theta=0.0
% INFO    : Bus 31506	: V=0.9550781, theta=-54.772679 -> V=1.0, theta=0.0
% INFO    : Bus 31507	: V=0.9559379, theta=-54.752786 -> V=1.0, theta=0.0
% INFO    : Bus 31508	: V=0.9578466, theta=-54.750761 -> V=1.0, theta=0.0
% INFO    : Bus 31509	: V=0.9572597, theta=-54.697982 -> V=1.0, theta=0.0
% INFO    : Bus 31510	: V=0.951738, theta=-54.941976 -> V=1.0, theta=0.0
% INFO    : Bus 31511	: V=0.9752659, theta=-53.201382 -> V=1.0, theta=0.0
% INFO    : Bus 31512	: V=0.9608404, theta=-54.515029 -> V=1.0, theta=0.0
% INFO    : Bus 31513	: V=0.9768176, theta=-53.123647 -> V=1.0, theta=0.0
% INFO    : Bus 31514	: V=0.9787691, theta=-53.15692 -> V=1.0, theta=0.0
% INFO    : Bus 31515	: V=0.9865972, theta=-52.423581 -> V=1.0, theta=0.0
% INFO    : Bus 31516	: V=0.9883192, theta=-52.336164 -> V=1.0, theta=0.0
% INFO    : Bus 31517	: V=0.9838358, theta=-52.653233 -> V=1.0, theta=0.0
% INFO    : Bus 31518	: V=0.9813448, theta=-52.828457 -> V=1.0, theta=0.0
% INFO    : Bus 31519	: V=0.9669126, theta=-54.12614 -> V=1.0, theta=0.0
% INFO    : Bus 31520	: V=0.9698347, theta=-53.97226 -> V=1.0, theta=0.0
% INFO    : Bus 31521	: V=0.9785866, theta=-53.023053 -> V=1.0, theta=0.0
% INFO    : Bus 31522	: V=1.0170295, theta=-50.413301 -> V=1.0, theta=0.0
% INFO    : Bus 31523	: V=0.9808792, theta=-52.83037 -> V=1.0, theta=0.0
% INFO    : Bus 31524	: V=0.979476, theta=-53.074922 -> V=1.0, theta=0.0
% INFO    : Bus 31525	: V=0.9661029, theta=-53.999403 -> V=1.0, theta=0.0
% INFO    : Bus 31526	: V=0.9681073, theta=-53.981732 -> V=1.0, theta=0.0
% INFO    : Bus 31527	: V=0.9708396, theta=-53.836587 -> V=1.0, theta=0.0
% INFO    : Bus 31528	: V=0.9658798, theta=-54.080165 -> V=1.0, theta=0.0
% INFO    : Bus 31529	: V=0.9647208, theta=-54.113118 -> V=1.0, theta=0.0
% INFO    : Bus 31530	: V=0.9766304, theta=-52.361113 -> V=1.0, theta=0.0
% INFO    : Bus 31531	: V=0.9746454, theta=-51.656385 -> V=1.0, theta=0.0
% INFO    : Bus 31532	: V=0.9763061, theta=-53.049312 -> V=1.0, theta=0.0
% INFO    : Bus 31533	: V=0.9715089, theta=-53.255689 -> V=1.0, theta=0.0
% INFO    : Bus 31534	: V=0.9648861, theta=-54.007424 -> V=1.0, theta=0.0
% INFO    : Bus 31535	: V=0.9691686, theta=-53.393255 -> V=1.0, theta=0.0
% INFO    : Bus 31536	: V=0.9634741, theta=-54.021381 -> V=1.0, theta=0.0
% INFO    : Bus 31537	: V=0.9647678, theta=-53.95347 -> V=1.0, theta=0.0
% INFO    : Bus 31538	: V=0.9783698, theta=-52.213109 -> V=1.0, theta=0.0
% INFO    : Bus 31539	: V=0.9958467, theta=-51.941419 -> V=1.0, theta=0.0
% INFO    : Bus 31540	: V=0.9820199, theta=-53.03936 -> V=1.0, theta=0.0
% INFO    : Bus 31541	: V=0.9946344, theta=-51.997087 -> V=1.0, theta=0.0
% INFO    : Bus 31542	: V=1.0021942, theta=-51.535949 -> V=1.0, theta=0.0
% INFO    : Bus 31543	: V=0.9956348, theta=-51.921335 -> V=1.0, theta=0.0
% INFO    : Bus 31544	: V=0.9563074, theta=-55.372052 -> V=1.0, theta=0.0
% INFO    : Bus 31545	: V=0.9519674, theta=-56.243097 -> V=1.0, theta=0.0
% INFO    : Bus 31546	: V=0.9563798, theta=-55.373821 -> V=1.0, theta=0.0
% INFO    : Bus 31547	: V=0.9547252, theta=-55.572494 -> V=1.0, theta=0.0
% INFO    : Bus 31548	: V=0.946543, theta=-56.612857 -> V=1.0, theta=0.0
% INFO    : Bus 31549	: V=0.948143, theta=-56.529396 -> V=1.0, theta=0.0
% INFO    : Bus 31550	: V=0.9471625, theta=-56.576254 -> V=1.0, theta=0.0
% INFO    : Bus 31551	: V=0.9499097, theta=-55.340657 -> V=1.0, theta=0.0
% INFO    : Bus 31552	: V=0.9517976, theta=-55.138582 -> V=1.0, theta=0.0
% INFO    : Bus 31553	: V=0.9527945, theta=-55.245033 -> V=1.0, theta=0.0
% INFO    : Bus 31554	: V=0.952458, theta=-55.249169 -> V=1.0, theta=0.0
% INFO    : Bus 31555	: V=0.9517991, theta=-55.255442 -> V=1.0, theta=0.0
% INFO    : Bus 31556	: V=0.9531121, theta=-55.628831 -> V=1.0, theta=0.0
% INFO    : Bus 31557	: V=0.9555793, theta=-55.448729 -> V=1.0, theta=0.0
% INFO    : Bus 31558	: V=0.9539588, theta=-55.557062 -> V=1.0, theta=0.0
% INFO    : Bus 31559	: V=0.9579733, theta=-55.054087 -> V=1.0, theta=0.0
% INFO    : Bus 31560	: V=0.9570659, theta=-55.058081 -> V=1.0, theta=0.0
% INFO    : Bus 31561	: V=0.9541697, theta=-55.551081 -> V=1.0, theta=0.0
% INFO    : Bus 31562	: V=0.9576623, theta=-55.078995 -> V=1.0, theta=0.0
% INFO    : Bus 31563	: V=0.9595534, theta=-54.98741 -> V=1.0, theta=0.0
% INFO    : Bus 31564	: V=0.9654271, theta=-54.585407 -> V=1.0, theta=0.0
% INFO    : Bus 31565	: V=0.9652982, theta=-54.586957 -> V=1.0, theta=0.0
% INFO    : Bus 31566	: V=0.9663385, theta=-54.575117 -> V=1.0, theta=0.0
% INFO    : Bus 31567	: V=0.999261, theta=-52.413276 -> V=1.0, theta=0.0
% INFO    : Bus 31568	: V=0.9741011, theta=-53.950415 -> V=1.0, theta=0.0
% INFO    : Bus 31569	: V=0.9964226, theta=-47.639586 -> V=1.0, theta=0.0
% INFO    : Bus 31570	: V=0.9834676, theta=-48.626491 -> V=1.0, theta=0.0
% INFO    : Bus 31571	: V=0.9948442, theta=-47.711447 -> V=1.0, theta=0.0
% INFO    : Bus 31572	: V=0.9885714, theta=-48.279327 -> V=1.0, theta=0.0
% INFO    : Bus 31573	: V=0.9936648, theta=-47.749329 -> V=1.0, theta=0.0
% INFO    : Bus 31574	: V=0.9858451, theta=-48.129926 -> V=1.0, theta=0.0
% INFO    : Bus 31575	: V=0.9920508, theta=-47.760792 -> V=1.0, theta=0.0
% INFO    : Bus 31576	: V=0.9926546, theta=-47.771812 -> V=1.0, theta=0.0
% INFO    : Bus 31577	: V=0.9822188, theta=-48.629374 -> V=1.0, theta=0.0
% INFO    : Bus 31578	: V=0.9817626, theta=-48.606043 -> V=1.0, theta=0.0
% INFO    : Bus 31579	: V=0.9827518, theta=-48.655559 -> V=1.0, theta=0.0
% INFO    : Bus 31580	: V=0.9814259, theta=-48.713174 -> V=1.0, theta=0.0
% INFO    : Bus 31581	: V=0.9902187, theta=-48.13602 -> V=1.0, theta=0.0
% INFO    : Bus 31582	: V=0.9813181, theta=-48.996544 -> V=1.0, theta=0.0
% INFO    : Bus 31583	: V=0.9844166, theta=-48.636124 -> V=1.0, theta=0.0
% INFO    : Bus 31584	: V=0.9827806, theta=-48.942396 -> V=1.0, theta=0.0
% INFO    : Bus 31585	: V=0.9968124, theta=-47.647563 -> V=1.0, theta=0.0
% INFO    : Bus 31586	: V=0.985062, theta=-48.628981 -> V=1.0, theta=0.0
% INFO    : Bus 31587	: V=0.9986686, theta=-47.542431 -> V=1.0, theta=0.0
% INFO    : Bus 31588	: V=1.0141906, theta=-45.113301 -> V=1.0, theta=0.0
% INFO    : Bus 31589	: V=1.0173984, theta=-46.119041 -> V=1.0, theta=0.0
% INFO    : Bus 31590	: V=1.0080129, theta=-45.746204 -> V=1.0, theta=0.0
% INFO    : Bus 31591	: V=1.0150996, theta=-45.882738 -> V=1.0, theta=0.0
% INFO    : Bus 31592	: V=1.0023111, theta=-46.777695 -> V=1.0, theta=0.0
% INFO    : Bus 31593	: V=1.0044783, theta=-47.108582 -> V=1.0, theta=0.0
% INFO    : Bus 31594	: V=0.9947073, theta=-47.829963 -> V=1.0, theta=0.0
% INFO    : Bus 31595	: V=1.0039668, theta=-46.958399 -> V=1.0, theta=0.0
% INFO    : Bus 31596	: V=1.0007681, theta=-47.289802 -> V=1.0, theta=0.0
% INFO    : Bus 31597	: V=0.9852792, theta=-48.63053 -> V=1.0, theta=0.0
% INFO    : Bus 31598	: V=0.9942452, theta=-47.850892 -> V=1.0, theta=0.0
% INFO    : Bus 31599	: V=0.9910694, theta=-47.717417 -> V=1.0, theta=0.0
% INFO    : Bus 31600	: V=0.9914487, theta=-47.735107 -> V=1.0, theta=0.0
% INFO    : Bus 31601	: V=0.9948486, theta=-47.494377 -> V=1.0, theta=0.0
% INFO    : Bus 31602	: V=1.0002205, theta=-46.602563 -> V=1.0, theta=0.0
% INFO    : Bus 31603	: V=0.9920077, theta=-47.707463 -> V=1.0, theta=0.0
% INFO    : Bus 31604	: V=0.989146, theta=-48.034702 -> V=1.0, theta=0.0
% INFO    : Bus 31605	: V=0.985449, theta=-48.348863 -> V=1.0, theta=0.0
% INFO    : Bus 31606	: V=0.9857457, theta=-48.116204 -> V=1.0, theta=0.0
% INFO    : Bus 31607	: V=0.9788412, theta=-48.726373 -> V=1.0, theta=0.0
% INFO    : Bus 31608	: V=0.9855233, theta=-48.171774 -> V=1.0, theta=0.0
% INFO    : Bus 31609	: V=0.9794655, theta=-48.689887 -> V=1.0, theta=0.0
% INFO    : Bus 31610	: V=0.9817073, theta=-48.412939 -> V=1.0, theta=0.0
% INFO    : Bus 31611	: V=0.9832732, theta=-48.387031 -> V=1.0, theta=0.0
% INFO    : Bus 31612	: V=0.9868062, theta=-48.020919 -> V=1.0, theta=0.0
% INFO    : Bus 31613	: V=0.9862393, theta=-48.071549 -> V=1.0, theta=0.0
% INFO    : Bus 31614	: V=0.9715161, theta=-49.79228 -> V=1.0, theta=0.0
% INFO    : Bus 31615	: V=0.985996, theta=-48.381968 -> V=1.0, theta=0.0
% INFO    : Bus 31616	: V=0.9807712, theta=-48.399595 -> V=1.0, theta=0.0
% INFO    : Bus 31617	: V=0.9796111, theta=-48.788624 -> V=1.0, theta=0.0
% INFO    : Bus 31618	: V=0.9880484, theta=-49.247201 -> V=1.0, theta=0.0
% INFO    : Bus 31619	: V=0.9797764, theta=-49.124384 -> V=1.0, theta=0.0
% INFO    : Bus 31620	: V=0.9769235, theta=-49.289211 -> V=1.0, theta=0.0
% INFO    : Bus 31621	: V=0.9740287, theta=-49.312972 -> V=1.0, theta=0.0
% INFO    : Bus 31622	: V=0.9821329, theta=-49.012379 -> V=1.0, theta=0.0
% INFO    : Bus 31623	: V=0.9952284, theta=-48.054942 -> V=1.0, theta=0.0
% INFO    : Bus 31624	: V=0.9948309, theta=-48.389524 -> V=1.0, theta=0.0
% INFO    : Bus 31625	: V=0.9934894, theta=-48.469367 -> V=1.0, theta=0.0
% INFO    : Bus 31626	: V=0.9977649, theta=-48.234942 -> V=1.0, theta=0.0
% INFO    : Bus 31627	: V=0.9984897, theta=-48.178988 -> V=1.0, theta=0.0
% INFO    : Bus 31628	: V=0.9859581, theta=-48.569879 -> V=1.0, theta=0.0
% INFO    : Bus 31629	: V=0.9858755, theta=-49.20009 -> V=1.0, theta=0.0
% INFO    : Bus 31630	: V=0.9972442, theta=-48.279925 -> V=1.0, theta=0.0
% INFO    : Bus 31631	: V=0.9989738, theta=-48.158082 -> V=1.0, theta=0.0
% INFO    : Bus 31632	: V=0.9908312, theta=-48.101055 -> V=1.0, theta=0.0
% INFO    : Bus 31633	: V=0.9879196, theta=-49.023499 -> V=1.0, theta=0.0
% INFO    : Bus 31634	: V=0.9932439, theta=-48.595496 -> V=1.0, theta=0.0
% INFO    : Bus 31635	: V=0.9888346, theta=-48.111065 -> V=1.0, theta=0.0
% INFO    : Bus 31636	: V=0.9930616, theta=-47.677704 -> V=1.0, theta=0.0
% INFO    : Bus 31637	: V=1.0004784, theta=-47.055813 -> V=1.0, theta=0.0
% INFO    : Bus 31638	: V=0.9827047, theta=-46.670252 -> V=1.0, theta=0.0
% INFO    : Bus 31639	: V=0.9779209, theta=-47.733807 -> V=1.0, theta=0.0
% INFO    : Bus 31640	: V=1.0064795, theta=-46.575287 -> V=1.0, theta=0.0
% INFO    : Bus 31641	: V=1.0119954, theta=-46.133188 -> V=1.0, theta=0.0
% INFO    : Bus 31642	: V=0.9768974, theta=-47.912371 -> V=1.0, theta=0.0
% INFO    : Bus 31643	: V=0.9792809, theta=-47.88889 -> V=1.0, theta=0.0
% INFO    : Bus 31644	: V=0.978367, theta=-47.740109 -> V=1.0, theta=0.0
% INFO    : Bus 31645	: V=1.0025496, theta=-45.131841 -> V=1.0, theta=0.0
% INFO    : Bus 31646	: V=0.9799274, theta=-47.070579 -> V=1.0, theta=0.0
% INFO    : Bus 31647	: V=0.978872, theta=-47.716615 -> V=1.0, theta=0.0
% INFO    : Bus 31648	: V=0.9883535, theta=-46.508162 -> V=1.0, theta=0.0
% INFO    : Bus 31649	: V=0.9892608, theta=-46.429739 -> V=1.0, theta=0.0
% INFO    : Bus 31650	: V=0.9777187, theta=-47.691695 -> V=1.0, theta=0.0
% INFO    : Bus 31651	: V=0.9801149, theta=-47.499166 -> V=1.0, theta=0.0
% INFO    : Bus 31652	: V=0.9864781, theta=-46.732589 -> V=1.0, theta=0.0
% INFO    : Bus 31653	: V=0.9882935, theta=-46.876578 -> V=1.0, theta=0.0
% INFO    : Bus 31654	: V=0.9758041, theta=-48.081864 -> V=1.0, theta=0.0
% INFO    : Bus 31655	: V=0.9744126, theta=-48.095777 -> V=1.0, theta=0.0
% INFO    : Bus 31656	: V=0.9830996, theta=-47.810953 -> V=1.0, theta=0.0
% INFO    : Bus 31657	: V=0.9889099, theta=-47.51535 -> V=1.0, theta=0.0
% INFO    : Bus 31658	: V=0.9903449, theta=-47.499617 -> V=1.0, theta=0.0
% INFO    : Bus 31659	: V=1.0054527, theta=-46.828771 -> V=1.0, theta=0.0
% INFO    : Bus 31660	: V=1.0041338, theta=-46.790472 -> V=1.0, theta=0.0
% INFO    : Bus 31661	: V=1.0025344, theta=-46.694805 -> V=1.0, theta=0.0
% INFO    : Bus 31662	: V=0.9963032, theta=-47.185961 -> V=1.0, theta=0.0
% INFO    : Bus 31663	: V=1.0025862, theta=-46.446318 -> V=1.0, theta=0.0
% INFO    : Bus 31664	: V=0.9945665, theta=-47.204992 -> V=1.0, theta=0.0
% INFO    : Bus 31665	: V=0.9846489, theta=-47.793673 -> V=1.0, theta=0.0
% INFO    : Bus 31666	: V=0.9797053, theta=-47.952675 -> V=1.0, theta=0.0
% INFO    : Bus 31667	: V=0.9810663, theta=-47.858697 -> V=1.0, theta=0.0
% INFO    : Bus 31668	: V=0.9795236, theta=-47.932918 -> V=1.0, theta=0.0
% INFO    : Bus 31669	: V=0.9879091, theta=-47.564233 -> V=1.0, theta=0.0
% INFO    : Bus 31670	: V=0.99807, theta=-46.637991 -> V=1.0, theta=0.0
% INFO    : Bus 31671	: V=0.9910571, theta=-46.90204 -> V=1.0, theta=0.0
% INFO    : Bus 31672	: V=0.9800327, theta=-47.898292 -> V=1.0, theta=0.0
% INFO    : Bus 31673	: V=0.9885398, theta=-46.92618 -> V=1.0, theta=0.0
% INFO    : Bus 31674	: V=0.9898507, theta=-46.872565 -> V=1.0, theta=0.0
% INFO    : Bus 31675	: V=0.9925464, theta=-46.816381 -> V=1.0, theta=0.0
% INFO    : Bus 31676	: V=0.9911809, theta=-46.811746 -> V=1.0, theta=0.0
% INFO    : Bus 31677	: V=0.9615846, theta=-48.643283 -> V=1.0, theta=0.0
% INFO    : Bus 31678	: V=0.9609775, theta=-48.653409 -> V=1.0, theta=0.0
% INFO    : Bus 31679	: V=0.9606903, theta=-48.679622 -> V=1.0, theta=0.0
% INFO    : Bus 31680	: V=0.9736009, theta=-48.068528 -> V=1.0, theta=0.0
% INFO    : Bus 31681	: V=0.9711345, theta=-48.314711 -> V=1.0, theta=0.0
% INFO    : Bus 31682	: V=0.9738063, theta=-48.081938 -> V=1.0, theta=0.0
% INFO    : Bus 31683	: V=0.9660099, theta=-48.497238 -> V=1.0, theta=0.0
% INFO    : Bus 31684	: V=0.9606294, theta=-48.697444 -> V=1.0, theta=0.0
% INFO    : Bus 31685	: V=0.9581277, theta=-48.268147 -> V=1.0, theta=0.0
% INFO    : Bus 31686	: V=0.9736731, theta=-46.330551 -> V=1.0, theta=0.0
% INFO    : Bus 31687	: V=0.959275, theta=-48.684682 -> V=1.0, theta=0.0
% INFO    : Bus 31688	: V=0.9584215, theta=-48.676895 -> V=1.0, theta=0.0
% INFO    : Bus 31689	: V=0.9854816, theta=-47.057987 -> V=1.0, theta=0.0
% INFO    : Bus 31690	: V=1.0116163, theta=-44.941829 -> V=1.0, theta=0.0
% INFO    : Bus 31691	: V=0.9956726, theta=-46.65016 -> V=1.0, theta=0.0
% INFO    : Bus 31692	: V=0.9962418, theta=-46.660628 -> V=1.0, theta=0.0
% INFO    : Bus 31693	: V=0.9870631, theta=-47.24502 -> V=1.0, theta=0.0
% INFO    : Bus 31694	: V=0.9952998, theta=-47.061287 -> V=1.0, theta=0.0
% INFO    : Bus 31695	: V=1.0063171, theta=-45.204407 -> V=1.0, theta=0.0
% INFO    : Bus 31696	: V=1.0022631, theta=-46.447846 -> V=1.0, theta=0.0
% INFO    : Bus 31697	: V=0.9910372, theta=-47.56627 -> V=1.0, theta=0.0
% INFO    : Bus 31698	: V=1.001564, theta=-45.834182 -> V=1.0, theta=0.0
% INFO    : Bus 31699	: V=0.9845155, theta=-48.217597 -> V=1.0, theta=0.0
% INFO    : Bus 31700	: V=1.0038519, theta=-46.33785 -> V=1.0, theta=0.0
% INFO    : Bus 31701	: V=1.009861, theta=-46.131192 -> V=1.0, theta=0.0
% INFO    : Bus 31702	: V=1.0076861, theta=-45.94916 -> V=1.0, theta=0.0
% INFO    : Bus 31703	: V=1.0061052, theta=-46.163855 -> V=1.0, theta=0.0
% INFO    : Bus 31704	: V=1.0048292, theta=-46.30394 -> V=1.0, theta=0.0
% INFO    : Bus 31705	: V=0.9849619, theta=-47.288381 -> V=1.0, theta=0.0
% INFO    : Bus 31706	: V=0.9552269, theta=-48.610982 -> V=1.0, theta=0.0
% INFO    : Bus 31707	: V=0.9587912, theta=-48.191805 -> V=1.0, theta=0.0
% INFO    : Bus 31708	: V=0.9689868, theta=-48.013763 -> V=1.0, theta=0.0
% INFO    : Bus 31709	: V=0.9682808, theta=-48.137029 -> V=1.0, theta=0.0
% INFO    : Bus 31710	: V=0.9562524, theta=-48.704339 -> V=1.0, theta=0.0
% INFO    : Bus 31711	: V=0.974298, theta=-45.999039 -> V=1.0, theta=0.0
% INFO    : Bus 31712	: V=0.9707067, theta=-47.801747 -> V=1.0, theta=0.0
% INFO    : Bus 31713	: V=0.97628, theta=-45.248433 -> V=1.0, theta=0.0
% INFO    : Bus 31714	: V=0.9694151, theta=-47.811421 -> V=1.0, theta=0.0
% INFO    : Bus 31715	: V=0.9777111, theta=-47.323239 -> V=1.0, theta=0.0
% INFO    : Bus 31716	: V=1.0081512, theta=-45.53197 -> V=1.0, theta=0.0
% INFO    : Bus 31717	: V=1.0084684, theta=-45.362393 -> V=1.0, theta=0.0
% INFO    : Bus 31718	: V=1.0102783, theta=-45.190339 -> V=1.0, theta=0.0
% INFO    : Bus 31719	: V=1.013955, theta=-44.075415 -> V=1.0, theta=0.0
% INFO    : Bus 31720	: V=1.0201396, theta=-43.087228 -> V=1.0, theta=0.0
% INFO    : Bus 31721	: V=0.9845618, theta=-48.624787 -> V=1.0, theta=0.0
% INFO    : Bus 31722	: V=0.9759956, theta=-46.686983 -> V=1.0, theta=0.0
% INFO    : Bus 31723	: V=1.0075124, theta=-43.698094 -> V=1.0, theta=0.0
% INFO    : Bus 31724	: V=0.9794845, theta=-48.47577 -> V=1.0, theta=0.0
% INFO    : Bus 31725	: V=0.9805014, theta=-48.232531 -> V=1.0, theta=0.0
% INFO    : Bus 31726	: V=0.98836, theta=-48.208625 -> V=1.0, theta=0.0
% INFO    : Bus 31727	: V=0.9847948, theta=-48.962814 -> V=1.0, theta=0.0
% INFO    : Bus 31728	: V=0.9795309, theta=-48.413953 -> V=1.0, theta=0.0
% INFO    : Bus 31729	: V=1.0066025, theta=-44.442027 -> V=1.0, theta=0.0
% INFO    : Bus 31730	: V=1.0122933, theta=-43.749195 -> V=1.0, theta=0.0
% INFO    : Bus 31731	: V=1.0122509, theta=-43.841984 -> V=1.0, theta=0.0
% INFO    : Bus 31732	: V=1.0123182, theta=-44.016103 -> V=1.0, theta=0.0
% INFO    : Bus 31733	: V=1.0125281, theta=-44.059832 -> V=1.0, theta=0.0
% INFO    : Bus 31734	: V=1.0061718, theta=-44.578036 -> V=1.0, theta=0.0
% INFO    : Bus 31735	: V=1.0079865, theta=-44.598349 -> V=1.0, theta=0.0
% INFO    : Bus 31736	: V=0.9988533, theta=-45.432461 -> V=1.0, theta=0.0
% INFO    : Bus 31737	: V=1.0039396, theta=-44.796137 -> V=1.0, theta=0.0
% INFO    : Bus 31738	: V=0.995425, theta=-45.675608 -> V=1.0, theta=0.0
% INFO    : Bus 31739	: V=0.9555278, theta=-49.130269 -> V=1.0, theta=0.0
% INFO    : Bus 31740	: V=0.9630445, theta=-48.075154 -> V=1.0, theta=0.0
% INFO    : Bus 31741	: V=0.9625746, theta=-48.178835 -> V=1.0, theta=0.0
% INFO    : Bus 31742	: V=0.9526671, theta=-50.113495 -> V=1.0, theta=0.0
% INFO    : Bus 31743	: V=0.9628988, theta=-47.027435 -> V=1.0, theta=0.0
% INFO    : Bus 31744	: V=0.9639296, theta=-47.111378 -> V=1.0, theta=0.0
% INFO    : Bus 31745	: V=0.9525727, theta=-47.638185 -> V=1.0, theta=0.0
% INFO    : Bus 31746	: V=0.9612687, theta=-46.575442 -> V=1.0, theta=0.0
% INFO    : Bus 31747	: V=0.9514965, theta=-47.669166 -> V=1.0, theta=0.0
% INFO    : Bus 31748	: V=0.9534699, theta=-47.529856 -> V=1.0, theta=0.0
% INFO    : Bus 31749	: V=0.9627916, theta=-46.363496 -> V=1.0, theta=0.0
% INFO    : Bus 31750	: V=0.9542123, theta=-47.485038 -> V=1.0, theta=0.0
% INFO    : Bus 31751	: V=0.9541641, theta=-47.521444 -> V=1.0, theta=0.0
% INFO    : Bus 31752	: V=0.9656043, theta=-46.253998 -> V=1.0, theta=0.0
% INFO    : Bus 31753	: V=0.9584214, theta=-46.749628 -> V=1.0, theta=0.0
% INFO    : Bus 31754	: V=0.9564543, theta=-47.106206 -> V=1.0, theta=0.0
% INFO    : Bus 31755	: V=0.9542868, theta=-47.1992 -> V=1.0, theta=0.0
% INFO    : Bus 31756	: V=0.9664332, theta=-46.277913 -> V=1.0, theta=0.0
% INFO    : Bus 31757	: V=0.9685643, theta=-46.249822 -> V=1.0, theta=0.0
% INFO    : Bus 31758	: V=0.9526674, theta=-47.21221 -> V=1.0, theta=0.0
% INFO    : Bus 31759	: V=0.9657644, theta=-47.084549 -> V=1.0, theta=0.0
% INFO    : Bus 31760	: V=0.9893119, theta=-45.049622 -> V=1.0, theta=0.0
% INFO    : Bus 31761	: V=0.9644981, theta=-47.947941 -> V=1.0, theta=0.0
% INFO    : Bus 31762	: V=0.9675128, theta=-47.701601 -> V=1.0, theta=0.0
% INFO    : Bus 31763	: V=0.9947852, theta=-44.887859 -> V=1.0, theta=0.0
% INFO    : Bus 31764	: V=0.9756727, theta=-47.490024 -> V=1.0, theta=0.0
% INFO    : Bus 31765	: V=1.0010991, theta=-44.679761 -> V=1.0, theta=0.0
% INFO    : Bus 31766	: V=0.9652421, theta=-47.979669 -> V=1.0, theta=0.0
% INFO    : Bus 31767	: V=0.9618149, theta=-48.932421 -> V=1.0, theta=0.0
% INFO    : Bus 31768	: V=0.9615287, theta=-48.889757 -> V=1.0, theta=0.0
% INFO    : Bus 31769	: V=0.9614087, theta=-48.827671 -> V=1.0, theta=0.0
% INFO    : Bus 31770	: V=0.959899, theta=-49.050515 -> V=1.0, theta=0.0
% INFO    : Bus 31771	: V=0.9636172, theta=-48.19256 -> V=1.0, theta=0.0
% INFO    : Bus 31772	: V=0.9629952, theta=-48.256954 -> V=1.0, theta=0.0
% INFO    : Bus 31773	: V=0.9597252, theta=-49.026958 -> V=1.0, theta=0.0
% INFO    : Bus 31774	: V=0.9612209, theta=-48.702797 -> V=1.0, theta=0.0
% INFO    : Bus 31775	: V=0.9616029, theta=-48.516303 -> V=1.0, theta=0.0
% INFO    : Bus 31776	: V=0.9590056, theta=-49.150159 -> V=1.0, theta=0.0
% INFO    : Bus 31777	: V=0.9522224, theta=-50.126321 -> V=1.0, theta=0.0
% INFO    : Bus 31778	: V=1.0026939, theta=-33.197478 -> V=1.0, theta=0.0
% INFO    : Bus 31779	: V=0.9912469, theta=-34.512069 -> V=1.0, theta=0.0
% INFO    : Bus 31780	: V=0.9904409, theta=-34.575168 -> V=1.0, theta=0.0
% INFO    : Bus 31781	: V=0.9924761, theta=-34.391719 -> V=1.0, theta=0.0
% INFO    : Bus 31782	: V=1.0034134, theta=-33.077466 -> V=1.0, theta=0.0
% INFO    : Bus 31783	: V=1.0019567, theta=-33.406515 -> V=1.0, theta=0.0
% INFO    : Bus 31784	: V=0.9905449, theta=-34.497784 -> V=1.0, theta=0.0
% INFO    : Bus 31785	: V=1.0007201, theta=-33.647605 -> V=1.0, theta=0.0
% INFO    : Bus 31786	: V=0.9958651, theta=-34.108062 -> V=1.0, theta=0.0
% INFO    : Bus 31787	: V=0.9893191, theta=-34.612991 -> V=1.0, theta=0.0
% INFO    : Bus 31788	: V=0.9988533, theta=-33.876461 -> V=1.0, theta=0.0
% INFO    : Bus 31789	: V=0.9982374, theta=-33.990662 -> V=1.0, theta=0.0
% INFO    : Bus 31790	: V=0.9961946, theta=-34.17027 -> V=1.0, theta=0.0
% INFO    : Bus 31791	: V=0.9837115, theta=-34.82244 -> V=1.0, theta=0.0
% INFO    : Bus 31792	: V=0.9913258, theta=-34.235413 -> V=1.0, theta=0.0
% INFO    : Bus 31793	: V=0.9911549, theta=-34.202933 -> V=1.0, theta=0.0
% INFO    : Bus 31794	: V=1.0037106, theta=-33.318112 -> V=1.0, theta=0.0
% INFO    : Bus 31795	: V=1.0026494, theta=-33.135646 -> V=1.0, theta=0.0
% INFO    : Bus 31796	: V=1.0013004, theta=-33.036534 -> V=1.0, theta=0.0
% INFO    : Bus 31797	: V=0.9940834, theta=-34.008632 -> V=1.0, theta=0.0
% INFO    : Bus 31798	: V=0.99124, theta=-34.220382 -> V=1.0, theta=0.0
% INFO    : Bus 31799	: V=1.0009496, theta=-33.289234 -> V=1.0, theta=0.0
% INFO    : Bus 31800	: V=1.0026996, theta=-33.120264 -> V=1.0, theta=0.0
% INFO    : Bus 31801	: V=1.0029517, theta=-33.124599 -> V=1.0, theta=0.0
% INFO    : Bus 31802	: V=0.9975689, theta=-33.476042 -> V=1.0, theta=0.0
% INFO    : Bus 31803	: V=0.9806427, theta=-34.753647 -> V=1.0, theta=0.0
% INFO    : Bus 31804	: V=0.9800399, theta=-34.756314 -> V=1.0, theta=0.0
% INFO    : Bus 31805	: V=0.9804092, theta=-34.759399 -> V=1.0, theta=0.0
% INFO    : Bus 31806	: V=0.9882491, theta=-34.418117 -> V=1.0, theta=0.0
% INFO    : Bus 31807	: V=0.9915281, theta=-33.53074 -> V=1.0, theta=0.0
% INFO    : Bus 31808	: V=0.9779903, theta=-34.901759 -> V=1.0, theta=0.0
% INFO    : Bus 31809	: V=0.9924983, theta=-33.447759 -> V=1.0, theta=0.0
% INFO    : Bus 31810	: V=1.001554, theta=-32.860332 -> V=1.0, theta=0.0
% INFO    : Bus 31811	: V=0.9813391, theta=-34.743207 -> V=1.0, theta=0.0
% INFO    : Bus 31812	: V=0.984553, theta=-34.533359 -> V=1.0, theta=0.0
% INFO    : Bus 31813	: V=1.0105964, theta=-31.676043 -> V=1.0, theta=0.0
% INFO    : Bus 31814	: V=1.0147622, theta=-32.131141 -> V=1.0, theta=0.0
% INFO    : Bus 31815	: V=1.0030615, theta=-32.117373 -> V=1.0, theta=0.0
% INFO    : Bus 31816	: V=1.0026085, theta=-32.435185 -> V=1.0, theta=0.0
% INFO    : Bus 31817	: V=1.0118763, theta=-31.931672 -> V=1.0, theta=0.0
% INFO    : Bus 31818	: V=0.9791828, theta=-34.75076 -> V=1.0, theta=0.0
% INFO    : Bus 31819	: V=0.9954029, theta=-33.23796 -> V=1.0, theta=0.0
% INFO    : Bus 31820	: V=0.9727372, theta=-35.435775 -> V=1.0, theta=0.0
% INFO    : Bus 31821	: V=0.995509, theta=-34.159365 -> V=1.0, theta=0.0
% INFO    : Bus 31822	: V=0.9522381, theta=-53.541476 -> V=1.0, theta=0.0
% INFO    : Bus 31823	: V=0.9687424, theta=-56.782222 -> V=1.0, theta=0.0
% INFO    : Bus 31824	: V=0.9830355, theta=-54.662639 -> V=1.0, theta=0.0
% INFO    : Bus 31825	: V=0.9929791, theta=-54.432464 -> V=1.0, theta=0.0
% INFO    : Bus 31826	: V=1.0115309, theta=-52.463821 -> V=1.0, theta=0.0
% INFO    : Bus 31827	: V=0.9987049, theta=-55.119144 -> V=1.0, theta=0.0
% INFO    : Bus 31828	: V=1.0104168, theta=-53.555791 -> V=1.0, theta=0.0
% INFO    : Bus 31829	: V=1.0128743, theta=-53.532406 -> V=1.0, theta=0.0
% INFO    : Bus 31830	: V=1.006861, theta=-54.330419 -> V=1.0, theta=0.0
% INFO    : Bus 31831	: V=0.9989434, theta=-55.320968 -> V=1.0, theta=0.0
% INFO    : Bus 31832	: V=1.0154061, theta=-53.721716 -> V=1.0, theta=0.0
% INFO    : Bus 31833	: V=1.0171045, theta=-53.724139 -> V=1.0, theta=0.0
% INFO    : Bus 31834	: V=1.0175987, theta=-52.817419 -> V=1.0, theta=0.0
% INFO    : Bus 31835	: V=1.013861, theta=-53.627534 -> V=1.0, theta=0.0
% INFO    : Bus 31836	: V=0.9430595, theta=-57.550936 -> V=1.0, theta=0.0
% INFO    : Bus 31837	: V=1.0073841, theta=-51.375694 -> V=1.0, theta=0.0
% INFO    : Bus 31838	: V=1.0112129, theta=-53.188909 -> V=1.0, theta=0.0
% INFO    : Bus 31839	: V=0.9494701, theta=-56.936852 -> V=1.0, theta=0.0
% INFO    : Bus 31840	: V=0.9497777, theta=-57.587561 -> V=1.0, theta=0.0
% INFO    : Bus 31841	: V=0.9493917, theta=-57.566679 -> V=1.0, theta=0.0
% INFO    : Bus 31842	: V=0.9491402, theta=-57.507803 -> V=1.0, theta=0.0
% INFO    : Bus 31843	: V=0.9486665, theta=-57.266559 -> V=1.0, theta=0.0
% INFO    : Bus 31844	: V=0.946378, theta=-57.295647 -> V=1.0, theta=0.0
% INFO    : Bus 31845	: V=0.9535288, theta=-56.102422 -> V=1.0, theta=0.0
% INFO    : Bus 31846	: V=0.9731936, theta=-56.542663 -> V=1.0, theta=0.0
% INFO    : Bus 31847	: V=0.9644604, theta=-52.611878 -> V=1.0, theta=0.0
% INFO    : Bus 31848	: V=0.9648282, theta=-52.693416 -> V=1.0, theta=0.0
% INFO    : Bus 31849	: V=0.9655148, theta=-52.412239 -> V=1.0, theta=0.0
% INFO    : Bus 31850	: V=0.9661545, theta=-52.282816 -> V=1.0, theta=0.0
% INFO    : Bus 31851	: V=0.9852594, theta=-49.37819 -> V=1.0, theta=0.0
% INFO    : Bus 31852	: V=0.9668701, theta=-52.414132 -> V=1.0, theta=0.0
% INFO    : Bus 31853	: V=0.9642909, theta=-52.867364 -> V=1.0, theta=0.0
% INFO    : Bus 31854	: V=0.969504, theta=-51.878185 -> V=1.0, theta=0.0
% INFO    : Bus 31855	: V=0.9706852, theta=-51.704113 -> V=1.0, theta=0.0
% INFO    : Bus 31856	: V=0.9631606, theta=-52.926183 -> V=1.0, theta=0.0
% INFO    : Bus 31857	: V=0.9644227, theta=-52.803899 -> V=1.0, theta=0.0
% INFO    : Bus 31858	: V=0.9680839, theta=-52.057945 -> V=1.0, theta=0.0
% INFO    : Bus 31859	: V=0.9617259, theta=-53.040087 -> V=1.0, theta=0.0
% INFO    : Bus 31860	: V=0.9628458, theta=-52.947746 -> V=1.0, theta=0.0
% INFO    : Bus 31861	: V=0.9611097, theta=-52.859193 -> V=1.0, theta=0.0
% INFO    : Bus 31862	: V=0.9593968, theta=-52.908802 -> V=1.0, theta=0.0
% INFO    : Bus 31863	: V=0.9597186, theta=-52.515298 -> V=1.0, theta=0.0
% INFO    : Bus 31864	: V=0.9648022, theta=-52.365779 -> V=1.0, theta=0.0
% INFO    : Bus 31865	: V=0.9655054, theta=-52.318244 -> V=1.0, theta=0.0
% INFO    : Bus 31866	: V=1.0081937, theta=-46.128661 -> V=1.0, theta=0.0
% INFO    : Bus 31867	: V=0.9725061, theta=-51.429249 -> V=1.0, theta=0.0
% INFO    : Bus 31868	: V=0.9770741, theta=-49.917063 -> V=1.0, theta=0.0
% INFO    : Bus 31869	: V=0.9659717, theta=-52.607712 -> V=1.0, theta=0.0
% INFO    : Bus 31870	: V=0.9756501, theta=-50.063369 -> V=1.0, theta=0.0
% INFO    : Bus 31871	: V=0.9656883, theta=-51.750488 -> V=1.0, theta=0.0
% INFO    : Bus 31872	: V=0.9655557, theta=-52.294533 -> V=1.0, theta=0.0
% INFO    : Bus 31873	: V=0.964065, theta=-52.638543 -> V=1.0, theta=0.0
% INFO    : Bus 31874	: V=0.9626662, theta=-52.875577 -> V=1.0, theta=0.0
% INFO    : Bus 31875	: V=0.963128, theta=-52.994277 -> V=1.0, theta=0.0
% INFO    : Bus 31876	: V=0.9618958, theta=-52.513287 -> V=1.0, theta=0.0
% INFO    : Bus 31877	: V=0.9637273, theta=-51.944204 -> V=1.0, theta=0.0
% INFO    : Bus 31878	: V=0.964364, theta=-51.869692 -> V=1.0, theta=0.0
% INFO    : Bus 31879	: V=0.9620966, theta=-53.115612 -> V=1.0, theta=0.0
% INFO    : Bus 31880	: V=0.9613683, theta=-53.189435 -> V=1.0, theta=0.0
% INFO    : Bus 31881	: V=0.9617233, theta=-52.995256 -> V=1.0, theta=0.0
% INFO    : Bus 31882	: V=0.9589765, theta=-53.476166 -> V=1.0, theta=0.0
% INFO    : Bus 31883	: V=0.9591799, theta=-53.375707 -> V=1.0, theta=0.0
% INFO    : Bus 31884	: V=0.9669518, theta=-52.200538 -> V=1.0, theta=0.0
% INFO    : Bus 31885	: V=0.9661259, theta=-52.311179 -> V=1.0, theta=0.0
% INFO    : Bus 31886	: V=0.9592794, theta=-53.4769 -> V=1.0, theta=0.0
% INFO    : Bus 31887	: V=0.9642293, theta=-52.510003 -> V=1.0, theta=0.0
% INFO    : Bus 31888	: V=0.9650881, theta=-52.421598 -> V=1.0, theta=0.0
% INFO    : Bus 31889	: V=0.9577302, theta=-53.494094 -> V=1.0, theta=0.0
% INFO    : Bus 31890	: V=0.9584204, theta=-53.381151 -> V=1.0, theta=0.0
% INFO    : Bus 31891	: V=0.9589929, theta=-53.33414 -> V=1.0, theta=0.0
% INFO    : Bus 31892	: V=0.9574732, theta=-53.408475 -> V=1.0, theta=0.0
% INFO    : Bus 31893	: V=0.955952, theta=-53.570589 -> V=1.0, theta=0.0
% INFO    : Bus 31894	: V=0.9566079, theta=-53.554113 -> V=1.0, theta=0.0
% INFO    : Bus 31895	: V=0.9564858, theta=-53.664029 -> V=1.0, theta=0.0
% INFO    : Bus 31896	: V=0.953959, theta=-53.993206 -> V=1.0, theta=0.0
% INFO    : Bus 31897	: V=0.9554541, theta=-53.815787 -> V=1.0, theta=0.0
% INFO    : Bus 31898	: V=0.963592, theta=-52.57367 -> V=1.0, theta=0.0
% INFO    : Bus 31899	: V=0.9555609, theta=-53.867187 -> V=1.0, theta=0.0
% INFO    : Bus 31900	: V=0.9531745, theta=-54.098021 -> V=1.0, theta=0.0
% INFO    : Bus 31901	: V=0.9580295, theta=-53.658272 -> V=1.0, theta=0.0
% INFO    : Bus 31902	: V=0.9519675, theta=-54.2885 -> V=1.0, theta=0.0
% INFO    : Bus 31903	: V=0.9497262, theta=-54.516491 -> V=1.0, theta=0.0
% INFO    : Bus 31904	: V=0.9612513, theta=-53.215933 -> V=1.0, theta=0.0
% INFO    : Bus 31905	: V=0.9560815, theta=-53.945134 -> V=1.0, theta=0.0
% INFO    : Bus 31906	: V=0.9538772, theta=-54.2401 -> V=1.0, theta=0.0
% INFO    : Bus 31907	: V=0.9531554, theta=-54.33069 -> V=1.0, theta=0.0
% INFO    : Bus 31908	: V=0.9518481, theta=-54.473906 -> V=1.0, theta=0.0
% INFO    : Bus 31909	: V=0.9483221, theta=-55.588334 -> V=1.0, theta=0.0
% INFO    : Bus 31910	: V=0.9487338, theta=-55.52206 -> V=1.0, theta=0.0
% INFO    : Bus 31911	: V=0.947872, theta=-55.686076 -> V=1.0, theta=0.0
% INFO    : Bus 31912	: V=0.9476945, theta=-55.64818 -> V=1.0, theta=0.0
% INFO    : Bus 31913	: V=0.9471163, theta=-55.83502 -> V=1.0, theta=0.0
% INFO    : Bus 31914	: V=0.9466253, theta=-55.916626 -> V=1.0, theta=0.0
% INFO    : Bus 31915	: V=0.9473099, theta=-55.834644 -> V=1.0, theta=0.0
% INFO    : Bus 31916	: V=0.9467522, theta=-55.905599 -> V=1.0, theta=0.0
% INFO    : Bus 31917	: V=0.9459879, theta=-56.005589 -> V=1.0, theta=0.0
% INFO    : Bus 31918	: V=0.9453579, theta=-56.063122 -> V=1.0, theta=0.0
% INFO    : Bus 31919	: V=0.9452247, theta=-56.058784 -> V=1.0, theta=0.0
% INFO    : Bus 31920	: V=0.9474082, theta=-55.791434 -> V=1.0, theta=0.0
% INFO    : Bus 31921	: V=0.9470322, theta=-55.834226 -> V=1.0, theta=0.0
% INFO    : Bus 31922	: V=0.9443249, theta=-56.145902 -> V=1.0, theta=0.0
% INFO    : Bus 31923	: V=0.9439226, theta=-56.15706 -> V=1.0, theta=0.0
% INFO    : Bus 31924	: V=0.9433389, theta=-56.182298 -> V=1.0, theta=0.0
% INFO    : Bus 31925	: V=0.9436464, theta=-56.119195 -> V=1.0, theta=0.0
% INFO    : Bus 31926	: V=0.9437203, theta=-56.047747 -> V=1.0, theta=0.0
% INFO    : Bus 31927	: V=0.9636177, theta=-53.329343 -> V=1.0, theta=0.0
% INFO    : Bus 31928	: V=0.97629, theta=-51.076223 -> V=1.0, theta=0.0
% INFO    : Bus 31929	: V=1.0110771, theta=-46.683496 -> V=1.0, theta=0.0
% INFO    : Bus 31930	: V=0.9696908, theta=-51.318131 -> V=1.0, theta=0.0
% INFO    : Bus 31931	: V=0.9502794, theta=-55.145696 -> V=1.0, theta=0.0
% INFO    : Bus 31932	: V=0.9547261, theta=-54.163886 -> V=1.0, theta=0.0
% INFO    : Bus 31933	: V=0.9484462, theta=-55.492498 -> V=1.0, theta=0.0
% INFO    : Bus 31934	: V=0.9514646, theta=-55.055473 -> V=1.0, theta=0.0
% INFO    : Bus 31935	: V=0.955649, theta=-54.493503 -> V=1.0, theta=0.0
% INFO    : Bus 31936	: V=0.9490727, theta=-55.585807 -> V=1.0, theta=0.0
% INFO    : Bus 31937	: V=0.9606368, theta=-53.801227 -> V=1.0, theta=0.0
% INFO    : Bus 31938	: V=0.9636797, theta=-53.277802 -> V=1.0, theta=0.0
% INFO    : Bus 31939	: V=0.9613614, theta=-53.625947 -> V=1.0, theta=0.0
% INFO    : Bus 31940	: V=0.9571916, theta=-54.360409 -> V=1.0, theta=0.0
% INFO    : Bus 31941	: V=0.9850483, theta=-45.751706 -> V=1.0, theta=0.0
% INFO    : Bus 31942	: V=0.976501, theta=-46.484977 -> V=1.0, theta=0.0
% INFO    : Bus 31943	: V=0.9759468, theta=-46.488767 -> V=1.0, theta=0.0
% INFO    : Bus 31944	: V=0.9739104, theta=-46.59759 -> V=1.0, theta=0.0
% INFO    : Bus 31945	: V=0.9825711, theta=-45.89156 -> V=1.0, theta=0.0
% INFO    : Bus 31946	: V=0.9735537, theta=-46.631955 -> V=1.0, theta=0.0
% INFO    : Bus 31947	: V=0.9736232, theta=-46.62501 -> V=1.0, theta=0.0
% INFO    : Bus 31948	: V=0.9804809, theta=-45.979402 -> V=1.0, theta=0.0
% INFO    : Bus 31949	: V=0.974781, theta=-46.585695 -> V=1.0, theta=0.0
% INFO    : Bus 31950	: V=1.0182068, theta=-42.036856 -> V=1.0, theta=0.0
% INFO    : Bus 31951	: V=0.9996185, theta=-44.135329 -> V=1.0, theta=0.0
% INFO    : Bus 31952	: V=0.984763, theta=-45.70879 -> V=1.0, theta=0.0
% INFO    : Bus 31953	: V=0.9898396, theta=-45.15689 -> V=1.0, theta=0.0
% INFO    : Bus 31954	: V=0.970137, theta=-46.844944 -> V=1.0, theta=0.0
% INFO    : Bus 31955	: V=0.9740366, theta=-46.444972 -> V=1.0, theta=0.0
% INFO    : Bus 31956	: V=0.9786489, theta=-46.177162 -> V=1.0, theta=0.0
% INFO    : Bus 31957	: V=0.9758367, theta=-46.38963 -> V=1.0, theta=0.0
% INFO    : Bus 31958	: V=0.9767946, theta=-46.244481 -> V=1.0, theta=0.0
% INFO    : Bus 31959	: V=0.9709345, theta=-46.835844 -> V=1.0, theta=0.0
% INFO    : Bus 31960	: V=0.9755135, theta=-46.533065 -> V=1.0, theta=0.0
% INFO    : Bus 31961	: V=0.9763782, theta=-46.430564 -> V=1.0, theta=0.0
% INFO    : Bus 31962	: V=0.9770555, theta=-46.353567 -> V=1.0, theta=0.0
% INFO    : Bus 31963	: V=0.9801037, theta=-46.020605 -> V=1.0, theta=0.0
% INFO    : Bus 31964	: V=0.9803912, theta=-46.01442 -> V=1.0, theta=0.0
% INFO    : Bus 31965	: V=0.9786363, theta=-46.066572 -> V=1.0, theta=0.0
% INFO    : Bus 31966	: V=0.97732, theta=-46.231472 -> V=1.0, theta=0.0
% INFO    : Bus 31967	: V=0.9711086, theta=-46.739734 -> V=1.0, theta=0.0
% INFO    : Bus 31968	: V=0.9887064, theta=-45.07629 -> V=1.0, theta=0.0
% INFO    : Bus 31969	: V=0.9892336, theta=-44.514046 -> V=1.0, theta=0.0
% INFO    : Bus 31970	: V=0.9932749, theta=-43.982728 -> V=1.0, theta=0.0
% INFO    : Bus 31971	: V=0.9725504, theta=-46.523391 -> V=1.0, theta=0.0
% INFO    : Bus 31972	: V=0.9714012, theta=-46.589448 -> V=1.0, theta=0.0
% INFO    : Bus 31973	: V=0.9742724, theta=-46.324938 -> V=1.0, theta=0.0
% INFO    : Bus 31974	: V=0.9739451, theta=-46.337718 -> V=1.0, theta=0.0
% INFO    : Bus 31975	: V=0.9749691, theta=-46.287602 -> V=1.0, theta=0.0
% INFO    : Bus 31976	: V=0.9719896, theta=-46.491504 -> V=1.0, theta=0.0
% INFO    : Bus 31977	: V=0.9736699, theta=-46.329289 -> V=1.0, theta=0.0
% INFO    : Bus 31978	: V=0.9747911, theta=-46.261576 -> V=1.0, theta=0.0
% INFO    : Bus 31979	: V=0.9705097, theta=-46.582629 -> V=1.0, theta=0.0
% INFO    : Bus 31980	: V=0.9705662, theta=-46.619546 -> V=1.0, theta=0.0
% INFO    : Bus 31981	: V=0.9746837, theta=-46.285055 -> V=1.0, theta=0.0
% INFO    : Bus 31982	: V=0.9731041, theta=-46.391861 -> V=1.0, theta=0.0
% INFO    : Bus 31983	: V=0.9735119, theta=-46.365979 -> V=1.0, theta=0.0
% INFO    : Bus 31984	: V=0.9706816, theta=-46.686737 -> V=1.0, theta=0.0
% INFO    : Bus 31985	: V=0.9685193, theta=-46.830584 -> V=1.0, theta=0.0
% INFO    : Bus 31986	: V=0.9516135, theta=-49.045059 -> V=1.0, theta=0.0
% INFO    : Bus 31987	: V=0.9716117, theta=-46.6219 -> V=1.0, theta=0.0
% INFO    : Bus 31988	: V=0.964874, theta=-47.520647 -> V=1.0, theta=0.0
% INFO    : Bus 31989	: V=0.9845883, theta=-45.690097 -> V=1.0, theta=0.0
% INFO    : Bus 31990	: V=0.9686279, theta=-46.914428 -> V=1.0, theta=0.0
% INFO    : Bus 31991	: V=0.9747558, theta=-46.645929 -> V=1.0, theta=0.0
% INFO    : Bus 31992	: V=0.9664682, theta=-47.695807 -> V=1.0, theta=0.0
% INFO    : Bus 31993	: V=0.9682006, theta=-47.638532 -> V=1.0, theta=0.0
% INFO    : Bus 31994	: V=0.9689196, theta=-47.29243 -> V=1.0, theta=0.0
% INFO    : Bus 31995	: V=0.9785025, theta=-46.418872 -> V=1.0, theta=0.0
% INFO    : Bus 31996	: V=0.9751357, theta=-46.669815 -> V=1.0, theta=0.0
% INFO    : Bus 31997	: V=0.975597, theta=-46.642345 -> V=1.0, theta=0.0
% INFO    : Bus 31998	: V=0.967835, theta=-47.338942 -> V=1.0, theta=0.0
% INFO    : Bus 31999	: V=0.9676129, theta=-47.4428 -> V=1.0, theta=0.0
% INFO    : Bus 32000	: V=0.9763406, theta=-46.591004 -> V=1.0, theta=0.0
% INFO    : Bus 32001	: V=0.975688, theta=-46.64086 -> V=1.0, theta=0.0
% INFO    : Bus 32002	: V=0.9686869, theta=-47.615033 -> V=1.0, theta=0.0
% INFO    : Bus 32003	: V=0.9711951, theta=-47.038324 -> V=1.0, theta=0.0
% INFO    : Bus 32004	: V=0.9705969, theta=-47.090831 -> V=1.0, theta=0.0
% INFO    : Bus 32005	: V=0.9670159, theta=-47.747698 -> V=1.0, theta=0.0
% INFO    : Bus 32006	: V=0.9674112, theta=-47.661636 -> V=1.0, theta=0.0
% INFO    : Bus 32007	: V=0.9692918, theta=-47.120011 -> V=1.0, theta=0.0
% INFO    : Bus 32008	: V=0.9580677, theta=-48.110851 -> V=1.0, theta=0.0
% INFO    : Bus 32009	: V=0.958754, theta=-48.098453 -> V=1.0, theta=0.0
% INFO    : Bus 32010	: V=0.9592525, theta=-48.094041 -> V=1.0, theta=0.0
% INFO    : Bus 32011	: V=0.9678304, theta=-47.336866 -> V=1.0, theta=0.0
% INFO    : Bus 32012	: V=0.9720837, theta=-46.912582 -> V=1.0, theta=0.0
% INFO    : Bus 32013	: V=0.9707492, theta=-46.985697 -> V=1.0, theta=0.0
% INFO    : Bus 32014	: V=0.9534141, theta=-48.402433 -> V=1.0, theta=0.0
% INFO    : Bus 32015	: V=0.9568064, theta=-48.610924 -> V=1.0, theta=0.0
% INFO    : Bus 32016	: V=0.9678203, theta=-47.226916 -> V=1.0, theta=0.0
% INFO    : Bus 32017	: V=0.9684441, theta=-46.865478 -> V=1.0, theta=0.0
% INFO    : Bus 32018	: V=0.9672071, theta=-46.93809 -> V=1.0, theta=0.0
% INFO    : Bus 32019	: V=0.96694, theta=-46.942173 -> V=1.0, theta=0.0
% INFO    : Bus 32020	: V=0.9668643, theta=-46.936811 -> V=1.0, theta=0.0
% INFO    : Bus 32021	: V=0.9590501, theta=-47.902385 -> V=1.0, theta=0.0
% INFO    : Bus 32022	: V=0.9666307, theta=-46.945139 -> V=1.0, theta=0.0
% INFO    : Bus 32023	: V=0.9586285, theta=-47.925421 -> V=1.0, theta=0.0
% INFO    : Bus 32024	: V=0.9665439, theta=-46.931457 -> V=1.0, theta=0.0
% INFO    : Bus 32025	: V=0.9678186, theta=-47.181311 -> V=1.0, theta=0.0
% INFO    : Bus 32026	: V=0.958906, theta=-47.902772 -> V=1.0, theta=0.0
% INFO    : Bus 32027	: V=0.9633714, theta=-51.488716 -> V=1.0, theta=0.0
% INFO    : Bus 32028	: V=0.9571864, theta=-51.968466 -> V=1.0, theta=0.0
% INFO    : Bus 32029	: V=0.965588, theta=-51.470669 -> V=1.0, theta=0.0
% INFO    : Bus 32030	: V=0.9674578, theta=-51.395687 -> V=1.0, theta=0.0
% INFO    : Bus 32031	: V=0.9644894, theta=-51.108108 -> V=1.0, theta=0.0
% INFO    : Bus 32032	: V=0.9733765, theta=-51.167146 -> V=1.0, theta=0.0
% INFO    : Bus 32033	: V=0.9709419, theta=-51.234387 -> V=1.0, theta=0.0
% INFO    : Bus 32034	: V=0.9667919, theta=-50.87655 -> V=1.0, theta=0.0
% INFO    : Bus 32035	: V=0.9663928, theta=-50.967587 -> V=1.0, theta=0.0
% INFO    : Bus 32036	: V=0.9556373, theta=-52.080655 -> V=1.0, theta=0.0
% INFO    : Bus 32037	: V=0.9725521, theta=-51.15456 -> V=1.0, theta=0.0
% INFO    : Bus 32038	: V=0.9753493, theta=-49.856565 -> V=1.0, theta=0.0
% INFO    : Bus 32039	: V=0.9653089, theta=-51.03219 -> V=1.0, theta=0.0
% INFO    : Bus 32040	: V=0.9637707, theta=-51.508439 -> V=1.0, theta=0.0
% INFO    : Bus 32041	: V=0.9663118, theta=-50.944361 -> V=1.0, theta=0.0
% INFO    : Bus 32042	: V=0.9527313, theta=-52.047731 -> V=1.0, theta=0.0
% INFO    : Bus 32043	: V=0.9665429, theta=-50.994622 -> V=1.0, theta=0.0
% INFO    : Bus 32044	: V=0.9661168, theta=-51.030271 -> V=1.0, theta=0.0
% INFO    : Bus 32045	: V=0.9735279, theta=-50.246551 -> V=1.0, theta=0.0
% INFO    : Bus 32046	: V=0.995793, theta=-51.670559 -> V=1.0, theta=0.0
% INFO    : Bus 32047	: V=1.0072272, theta=-51.70609 -> V=1.0, theta=0.0
% INFO    : Bus 32048	: V=1.0093562, theta=-51.101682 -> V=1.0, theta=0.0
% INFO    : Bus 32049	: V=1.013283, theta=-51.377689 -> V=1.0, theta=0.0
% INFO    : Bus 32050	: V=1.0076209, theta=-51.775931 -> V=1.0, theta=0.0
% INFO    : Bus 32051	: V=1.0013418, theta=-51.671878 -> V=1.0, theta=0.0
% INFO    : Bus 32052	: V=0.9997886, theta=-51.079443 -> V=1.0, theta=0.0
% INFO    : Bus 32053	: V=0.9986071, theta=-50.155913 -> V=1.0, theta=0.0
% INFO    : Bus 32054	: V=0.997316, theta=-48.962089 -> V=1.0, theta=0.0
% INFO    : Bus 32055	: V=1.0009206, theta=-48.61529 -> V=1.0, theta=0.0
% INFO    : Bus 32056	: V=1.0036117, theta=-48.207126 -> V=1.0, theta=0.0
% INFO    : Bus 32057	: V=0.9562364, theta=-49.818481 -> V=1.0, theta=0.0
% INFO    : Bus 32058	: V=0.963144, theta=-51.62614 -> V=1.0, theta=0.0
% INFO    : Bus 32059	: V=0.9614908, theta=-52.486033 -> V=1.0, theta=0.0
% INFO    : Bus 32060	: V=0.9606042, theta=-49.073881 -> V=1.0, theta=0.0
% INFO    : Bus 32061	: V=0.9614943, theta=-49.053832 -> V=1.0, theta=0.0
% INFO    : Bus 32062	: V=0.9613961, theta=-48.953838 -> V=1.0, theta=0.0
% INFO    : Bus 32063	: V=0.9614116, theta=-48.894914 -> V=1.0, theta=0.0
% INFO    : Bus 32064	: V=0.9617258, theta=-48.723689 -> V=1.0, theta=0.0
% INFO    : Bus 32065	: V=0.9621969, theta=-48.576774 -> V=1.0, theta=0.0
% INFO    : Bus 32066	: V=0.9620584, theta=-48.648746 -> V=1.0, theta=0.0
% INFO    : Bus 32067	: V=0.9610568, theta=-48.956171 -> V=1.0, theta=0.0
% INFO    : Bus 32068	: V=0.9624472, theta=-48.591447 -> V=1.0, theta=0.0
% INFO    : Bus 32069	: V=0.9642623, theta=-48.457991 -> V=1.0, theta=0.0
% INFO    : Bus 32070	: V=0.9631298, theta=-48.50053 -> V=1.0, theta=0.0
% INFO    : Bus 32071	: V=0.9629873, theta=-48.643842 -> V=1.0, theta=0.0
% INFO    : Bus 32072	: V=0.9593703, theta=-49.353181 -> V=1.0, theta=0.0
% INFO    : Bus 32073	: V=0.9563959, theta=-49.925611 -> V=1.0, theta=0.0
% INFO    : Bus 32074	: V=0.9637747, theta=-48.350412 -> V=1.0, theta=0.0
% INFO    : Bus 32075	: V=0.9630981, theta=-48.423646 -> V=1.0, theta=0.0
% INFO    : Bus 32076	: V=0.9625949, theta=-48.471407 -> V=1.0, theta=0.0
% INFO    : Bus 32077	: V=0.9628341, theta=-48.410944 -> V=1.0, theta=0.0
% INFO    : Bus 32078	: V=0.963284, theta=-48.317837 -> V=1.0, theta=0.0
% INFO    : Bus 32079	: V=0.9607043, theta=-48.334575 -> V=1.0, theta=0.0
% INFO    : Bus 32080	: V=0.963947, theta=-48.220227 -> V=1.0, theta=0.0
% INFO    : Bus 32081	: V=0.9646869, theta=-48.256289 -> V=1.0, theta=0.0
% INFO    : Bus 32082	: V=0.9647202, theta=-48.287878 -> V=1.0, theta=0.0
% INFO    : Bus 32083	: V=0.9659845, theta=-48.139352 -> V=1.0, theta=0.0
% INFO    : Bus 32084	: V=0.9624043, theta=-48.379 -> V=1.0, theta=0.0
% INFO    : Bus 32085	: V=0.9646332, theta=-48.131289 -> V=1.0, theta=0.0
% INFO    : Bus 32086	: V=0.9653808, theta=-48.041945 -> V=1.0, theta=0.0
% INFO    : Bus 32087	: V=0.9619521, theta=-48.32478 -> V=1.0, theta=0.0
% INFO    : Bus 32088	: V=0.9663716, theta=-47.924906 -> V=1.0, theta=0.0
% INFO    : Bus 32089	: V=0.9669455, theta=-48.094847 -> V=1.0, theta=0.0
% INFO    : Bus 32090	: V=0.9635225, theta=-48.104622 -> V=1.0, theta=0.0
% INFO    : Bus 32091	: V=0.9671011, theta=-47.844713 -> V=1.0, theta=0.0
% INFO    : Bus 32092	: V=0.9680263, theta=-47.744864 -> V=1.0, theta=0.0
% INFO    : Bus 32093	: V=0.968679, theta=-47.654288 -> V=1.0, theta=0.0
% INFO    : Bus 32094	: V=0.9602077, theta=-48.793087 -> V=1.0, theta=0.0
% INFO    : Bus 32095	: V=0.9660741, theta=-47.921688 -> V=1.0, theta=0.0
% INFO    : Bus 32096	: V=0.9617413, theta=-48.340043 -> V=1.0, theta=0.0
% INFO    : Bus 32097	: V=0.9652868, theta=-47.96593 -> V=1.0, theta=0.0
% INFO    : Bus 32098	: V=0.9685746, theta=-47.690361 -> V=1.0, theta=0.0
% INFO    : Bus 32099	: V=0.9686224, theta=-47.714853 -> V=1.0, theta=0.0
% INFO    : Bus 32100	: V=0.9697829, theta=-47.440508 -> V=1.0, theta=0.0
% INFO    : Bus 32101	: V=0.9700012, theta=-47.539399 -> V=1.0, theta=0.0
% INFO    : Bus 32102	: V=0.9629556, theta=-48.10971 -> V=1.0, theta=0.0
% INFO    : Bus 32103	: V=0.9639629, theta=-48.052461 -> V=1.0, theta=0.0
% INFO    : Bus 32104	: V=0.9719285, theta=-47.245108 -> V=1.0, theta=0.0
% INFO    : Bus 32105	: V=0.971159, theta=-47.329713 -> V=1.0, theta=0.0
% INFO    : Bus 32106	: V=0.970228, theta=-47.404061 -> V=1.0, theta=0.0
% INFO    : Bus 32107	: V=0.960542, theta=-48.335881 -> V=1.0, theta=0.0
% INFO    : Bus 32108	: V=0.9626608, theta=-48.120139 -> V=1.0, theta=0.0
% INFO    : Bus 32109	: V=0.9741056, theta=-46.790066 -> V=1.0, theta=0.0
% INFO    : Bus 32110	: V=0.963381, theta=-48.094659 -> V=1.0, theta=0.0
% INFO    : Bus 32111	: V=0.9747405, theta=-46.891868 -> V=1.0, theta=0.0
% INFO    : Bus 32112	: V=0.9807263, theta=-45.861138 -> V=1.0, theta=0.0
% INFO    : Bus 32113	: V=0.9917261, theta=-44.010321 -> V=1.0, theta=0.0
% INFO    : Bus 32114	: V=0.9823587, theta=-45.641215 -> V=1.0, theta=0.0
% INFO    : Bus 32115	: V=0.9738344, theta=-47.053224 -> V=1.0, theta=0.0
% INFO    : Bus 32116	: V=0.9764843, theta=-46.738351 -> V=1.0, theta=0.0
% INFO    : Bus 32117	: V=0.9898811, theta=-44.670595 -> V=1.0, theta=0.0
% INFO    : Bus 32118	: V=0.9880849, theta=-44.891111 -> V=1.0, theta=0.0
% INFO    : Bus 32119	: V=0.9761398, theta=-46.75112 -> V=1.0, theta=0.0
% INFO    : Bus 32120	: V=1.0145947, theta=-41.32131 -> V=1.0, theta=0.0
% INFO    : Bus 32121	: V=0.9876902, theta=-44.957022 -> V=1.0, theta=0.0
% INFO    : Bus 32122	: V=0.9882868, theta=-44.890158 -> V=1.0, theta=0.0
% INFO    : Bus 32123	: V=0.9898708, theta=-44.687696 -> V=1.0, theta=0.0
% INFO    : Bus 32124	: V=0.9848181, theta=-45.320776 -> V=1.0, theta=0.0
% INFO    : Bus 32125	: V=0.9914703, theta=-44.486549 -> V=1.0, theta=0.0
% INFO    : Bus 32126	: V=0.9617323, theta=-48.84371 -> V=1.0, theta=0.0
% INFO    : Bus 32127	: V=0.9575584, theta=-49.64686 -> V=1.0, theta=0.0
% INFO    : Bus 32128	: V=0.9476951, theta=-50.271395 -> V=1.0, theta=0.0
% INFO    : Bus 32129	: V=0.9600587, theta=-48.451844 -> V=1.0, theta=0.0
% INFO    : Bus 32130	: V=0.9606162, theta=-48.242702 -> V=1.0, theta=0.0
% INFO    : Bus 32131	: V=0.9710302, theta=-46.292327 -> V=1.0, theta=0.0
% INFO    : Bus 32132	: V=0.9983025, theta=-44.999826 -> V=1.0, theta=0.0
% INFO    : Bus 32133	: V=0.9924681, theta=-45.818748 -> V=1.0, theta=0.0
% INFO    : Bus 32134	: V=0.9966794, theta=-44.743524 -> V=1.0, theta=0.0
% INFO    : Bus 32135	: V=0.9954638, theta=-44.969232 -> V=1.0, theta=0.0
% INFO    : Bus 32136	: V=0.986752, theta=-45.713418 -> V=1.0, theta=0.0
% INFO    : Bus 32137	: V=0.9805117, theta=-46.199872 -> V=1.0, theta=0.0
% INFO    : Bus 32138	: V=0.9830907, theta=-45.966652 -> V=1.0, theta=0.0
% INFO    : Bus 32139	: V=0.9798847, theta=-46.040005 -> V=1.0, theta=0.0
% INFO    : Bus 32140	: V=0.9888781, theta=-45.339655 -> V=1.0, theta=0.0
% INFO    : Bus 32141	: V=0.9906262, theta=-45.21075 -> V=1.0, theta=0.0
% INFO    : Bus 32142	: V=0.9977561, theta=-44.566467 -> V=1.0, theta=0.0
% INFO    : Bus 32143	: V=0.9975551, theta=-44.581455 -> V=1.0, theta=0.0
% INFO    : Bus 32144	: V=0.9920852, theta=-45.105127 -> V=1.0, theta=0.0
% INFO    : Bus 32145	: V=0.9889538, theta=-45.503973 -> V=1.0, theta=0.0
% INFO    : Bus 32146	: V=0.9997886, theta=-44.313434 -> V=1.0, theta=0.0
% INFO    : Bus 32147	: V=0.9905069, theta=-45.551199 -> V=1.0, theta=0.0
% INFO    : Bus 32148	: V=0.9874815, theta=-45.69104 -> V=1.0, theta=0.0
% INFO    : Bus 32149	: V=0.9896753, theta=-45.321215 -> V=1.0, theta=0.0
% INFO    : Bus 32150	: V=0.9904234, theta=-45.288307 -> V=1.0, theta=0.0
% INFO    : Bus 32151	: V=0.996929, theta=-44.871589 -> V=1.0, theta=0.0
% INFO    : Bus 32152	: V=0.9957936, theta=-44.936883 -> V=1.0, theta=0.0
% INFO    : Bus 32153	: V=1.0067439, theta=-43.433989 -> V=1.0, theta=0.0
% INFO    : Bus 32154	: V=0.9857168, theta=-45.505241 -> V=1.0, theta=0.0
% INFO    : Bus 32155	: V=0.965476, theta=-46.917091 -> V=1.0, theta=0.0
% INFO    : Bus 32156	: V=0.9693305, theta=-46.859297 -> V=1.0, theta=0.0
% INFO    : Bus 32157	: V=0.9920059, theta=-45.210094 -> V=1.0, theta=0.0
% INFO    : Bus 32158	: V=0.9926409, theta=-45.177148 -> V=1.0, theta=0.0
% INFO    : Bus 32159	: V=0.9814128, theta=-46.15044 -> V=1.0, theta=0.0
% INFO    : Bus 32160	: V=0.9943954, theta=-45.08167 -> V=1.0, theta=0.0
% INFO    : Bus 32161	: V=0.9700058, theta=-46.787307 -> V=1.0, theta=0.0
% INFO    : Bus 32162	: V=0.982007, theta=-45.713126 -> V=1.0, theta=0.0
% INFO    : Bus 32163	: V=0.9835683, theta=-45.626684 -> V=1.0, theta=0.0
% INFO    : Bus 32164	: V=0.984753, theta=-45.627824 -> V=1.0, theta=0.0
% INFO    : Bus 32165	: V=0.991282, theta=-45.246842 -> V=1.0, theta=0.0
% INFO    : Bus 32166	: V=0.9698075, theta=-46.690467 -> V=1.0, theta=0.0
% INFO    : Bus 32167	: V=0.9679699, theta=-46.726039 -> V=1.0, theta=0.0
% INFO    : Bus 32168	: V=0.9674727, theta=-46.889166 -> V=1.0, theta=0.0
% INFO    : Bus 32169	: V=0.9685486, theta=-46.874191 -> V=1.0, theta=0.0
% INFO    : Bus 32170	: V=0.9810654, theta=-46.186582 -> V=1.0, theta=0.0
% INFO    : Bus 32171	: V=0.9682313, theta=-46.878043 -> V=1.0, theta=0.0
% INFO    : Bus 32172	: V=0.9814559, theta=-46.166915 -> V=1.0, theta=0.0
% INFO    : Bus 32173	: V=0.998477, theta=-49.4401 -> V=1.0, theta=0.0
% INFO    : Bus 32174	: V=1.0118963, theta=-48.529719 -> V=1.0, theta=0.0
% INFO    : Bus 32175	: V=1.0172401, theta=-48.049372 -> V=1.0, theta=0.0
% INFO    : Bus 32176	: V=0.9828335, theta=-50.473867 -> V=1.0, theta=0.0
% INFO    : Bus 32177	: V=0.9760708, theta=-49.959051 -> V=1.0, theta=0.0
% INFO    : Bus 32178	: V=0.9651036, theta=-50.216867 -> V=1.0, theta=0.0
% INFO    : Bus 32179	: V=0.9744815, theta=-50.502562 -> V=1.0, theta=0.0
% INFO    : Bus 32180	: V=0.9772402, theta=-50.280109 -> V=1.0, theta=0.0
% INFO    : Bus 32181	: V=0.9820591, theta=-50.278897 -> V=1.0, theta=0.0
% INFO    : Bus 32182	: V=0.9551898, theta=-53.311941 -> V=1.0, theta=0.0
% INFO    : Bus 32183	: V=0.9618168, theta=-52.811008 -> V=1.0, theta=0.0
% INFO    : Bus 32184	: V=0.9771142, theta=-50.909239 -> V=1.0, theta=0.0
% INFO    : Bus 32185	: V=0.9750705, theta=-51.384852 -> V=1.0, theta=0.0
% INFO    : Bus 32186	: V=0.982985, theta=-50.416815 -> V=1.0, theta=0.0
% INFO    : Bus 32187	: V=0.9732963, theta=-51.809496 -> V=1.0, theta=0.0
% INFO    : Bus 32188	: V=0.9493739, theta=-54.439096 -> V=1.0, theta=0.0
% INFO    : Bus 32189	: V=0.952946, theta=-54.281031 -> V=1.0, theta=0.0
% INFO    : Bus 32190	: V=0.95374, theta=-54.142102 -> V=1.0, theta=0.0
% INFO    : Bus 32191	: V=0.9517692, theta=-53.406284 -> V=1.0, theta=0.0
% INFO    : Bus 32192	: V=0.9911911, theta=-48.260493 -> V=1.0, theta=0.0
% INFO    : Bus 32193	: V=0.9604371, theta=-52.557702 -> V=1.0, theta=0.0
% INFO    : Bus 32194	: V=0.950482, theta=-54.3658 -> V=1.0, theta=0.0
% INFO    : Bus 32195	: V=1.004438, theta=-26.43978 -> V=1.0, theta=0.0
% INFO    : Bus 32196	: V=1.0077798, theta=-27.886409 -> V=1.0, theta=0.0
% INFO    : Bus 32197	: V=1.0034189, theta=-29.472374 -> V=1.0, theta=0.0
% INFO    : Bus 32198	: V=0.9999464, theta=-33.560526 -> V=1.0, theta=0.0
% INFO    : Bus 32199	: V=1.0014292, theta=-30.939434 -> V=1.0, theta=0.0
% INFO    : Bus 32200	: V=0.9771418, theta=-51.045774 -> V=1.0, theta=0.0
% INFO    : Bus 32201	: V=0.9861488, theta=-50.182753 -> V=1.0, theta=0.0
% INFO    : Bus 32202	: V=0.9905794, theta=-46.952228 -> V=1.0, theta=0.0
% INFO    : Bus 32203	: V=0.9987891, theta=-33.388562 -> V=1.0, theta=0.0
% INFO    : Bus 32204	: V=0.9814565, theta=-40.262191 -> V=1.0, theta=0.0
% INFO    : Bus 32205	: V=0.9858847, theta=-39.763015 -> V=1.0, theta=0.0
% INFO    : Bus 32206	: V=0.9809987, theta=-51.635743 -> V=1.0, theta=0.0
% INFO    : Bus 32207	: V=0.9607266, theta=-48.630983 -> V=1.0, theta=0.0
% INFO    : Bus 32208	: V=1.0053076, theta=-25.141649 -> V=1.0, theta=0.0
% INFO    : Bus 32209	: V=1.0164684, theta=-25.756424 -> V=1.0, theta=0.0
% INFO    : Bus 32210	: V=1.0095464, theta=-26.267152 -> V=1.0, theta=0.0
% INFO    : Bus 32211	: V=1.0102259, theta=-26.042337 -> V=1.0, theta=0.0
% INFO    : Bus 32212	: V=1.0053048, theta=-27.526345 -> V=1.0, theta=0.0
% INFO    : Bus 32213	: V=1.0027395, theta=-25.980702 -> V=1.0, theta=0.0
% INFO    : Bus 32214	: V=1.0071864, theta=-25.979182 -> V=1.0, theta=0.0
% INFO    : Bus 32215	: V=1.0065552, theta=-25.926564 -> V=1.0, theta=0.0
% INFO    : Bus 32216	: V=1.0066205, theta=-26.615498 -> V=1.0, theta=0.0
% INFO    : Bus 32217	: V=0.9488172, theta=-41.343987 -> V=1.0, theta=0.0
% INFO    : Bus 32218	: V=0.9605267, theta=-40.262594 -> V=1.0, theta=0.0
% INFO    : Bus 32219	: V=0.9611174, theta=-40.309546 -> V=1.0, theta=0.0
% INFO    : Bus 32220	: V=0.9944819, theta=-35.365004 -> V=1.0, theta=0.0
% INFO    : Bus 32221	: V=0.9703228, theta=-41.443075 -> V=1.0, theta=0.0
% INFO    : Bus 32222	: V=0.9738251, theta=-39.991319 -> V=1.0, theta=0.0
% INFO    : Bus 32223	: V=0.9731315, theta=-41.306612 -> V=1.0, theta=0.0
% INFO    : Bus 32224	: V=0.9670222, theta=-41.804366 -> V=1.0, theta=0.0
% INFO    : Bus 32225	: V=0.9912891, theta=-39.313164 -> V=1.0, theta=0.0
% INFO    : Bus 32226	: V=0.97782, theta=-39.539038 -> V=1.0, theta=0.0
% INFO    : Bus 32227	: V=0.9738627, theta=-40.1895 -> V=1.0, theta=0.0
% INFO    : Bus 32228	: V=0.97946, theta=-39.844879 -> V=1.0, theta=0.0
% INFO    : Bus 32229	: V=0.9813545, theta=-39.179424 -> V=1.0, theta=0.0
% INFO    : Bus 32230	: V=0.9723107, theta=-40.278245 -> V=1.0, theta=0.0
% INFO    : Bus 32231	: V=1.0015589, theta=-37.925087 -> V=1.0, theta=0.0
% INFO    : Bus 32232	: V=0.9805287, theta=-38.894472 -> V=1.0, theta=0.0
% INFO    : Bus 32233	: V=0.9711321, theta=-40.334795 -> V=1.0, theta=0.0
% INFO    : Bus 32234	: V=0.986674, theta=-38.198722 -> V=1.0, theta=0.0
% INFO    : Bus 32235	: V=0.9884359, theta=-37.508651 -> V=1.0, theta=0.0
% INFO    : Bus 32236	: V=0.9827462, theta=-38.976197 -> V=1.0, theta=0.0
% INFO    : Bus 32237	: V=1.0077177, theta=-37.656167 -> V=1.0, theta=0.0
% INFO    : Bus 32238	: V=0.9886491, theta=-38.134188 -> V=1.0, theta=0.0
% INFO    : Bus 32239	: V=0.9584063, theta=-34.228547 -> V=1.0, theta=0.0
% INFO    : Bus 32240	: V=0.951362, theta=-35.616058 -> V=1.0, theta=0.0
% INFO    : Bus 32241	: V=0.9517934, theta=-33.819604 -> V=1.0, theta=0.0
% INFO    : Bus 32242	: V=0.9613396, theta=-32.838636 -> V=1.0, theta=0.0
% INFO    : Bus 32243	: V=0.964043, theta=-34.187647 -> V=1.0, theta=0.0
% INFO    : Bus 32244	: V=0.9614078, theta=-34.46529 -> V=1.0, theta=0.0
% INFO    : Bus 32245	: V=0.967136, theta=-33.855097 -> V=1.0, theta=0.0
% INFO    : Bus 32246	: V=0.9656322, theta=-34.755553 -> V=1.0, theta=0.0
% INFO    : Bus 32247	: V=0.9589734, theta=-34.733014 -> V=1.0, theta=0.0
% INFO    : Bus 32248	: V=0.9554857, theta=-36.807875 -> V=1.0, theta=0.0
% INFO    : Bus 32249	: V=0.9562017, theta=-36.633319 -> V=1.0, theta=0.0
% INFO    : Bus 32250	: V=0.9613343, theta=-35.550188 -> V=1.0, theta=0.0
% INFO    : Bus 32251	: V=0.9744987, theta=-33.328004 -> V=1.0, theta=0.0
% INFO    : Bus 32252	: V=0.9725331, theta=-33.283122 -> V=1.0, theta=0.0
% INFO    : Bus 32253	: V=0.9748427, theta=-32.784408 -> V=1.0, theta=0.0
% INFO    : Bus 32254	: V=0.9826385, theta=-47.674962 -> V=1.0, theta=0.0
% INFO    : Bus 32255	: V=0.9895763, theta=-44.277666 -> V=1.0, theta=0.0
% INFO    : Bus 32256	: V=0.9905643, theta=-45.556205 -> V=1.0, theta=0.0
% INFO    : Bus 32257	: V=0.9913667, theta=-46.264171 -> V=1.0, theta=0.0
% INFO    : Bus 32258	: V=0.9985948, theta=-47.528325 -> V=1.0, theta=0.0
% INFO    : Bus 32259	: V=0.9827037, theta=-51.588017 -> V=1.0, theta=0.0
% INFO    : Bus 32260	: V=0.9693653, theta=-53.057961 -> V=1.0, theta=0.0
% INFO    : Bus 32261	: V=0.9731507, theta=-54.596346 -> V=1.0, theta=0.0
% INFO    : Bus 32262	: V=0.9796754, theta=-51.673099 -> V=1.0, theta=0.0
% INFO    : Bus 32263	: V=0.9751935, theta=-55.004311 -> V=1.0, theta=0.0
% INFO    : Bus 32264	: V=0.9800974, theta=-55.551651 -> V=1.0, theta=0.0
% INFO    : Bus 32265	: V=0.9820064, theta=-32.144939 -> V=1.0, theta=0.0
% INFO    : Bus 32266	: V=0.9823125, theta=-32.140046 -> V=1.0, theta=0.0
% INFO    : Bus 32267	: V=0.9829654, theta=-32.12893 -> V=1.0, theta=0.0
% INFO    : Bus 32268	: V=0.9822728, theta=-32.140859 -> V=1.0, theta=0.0
% INFO    : Bus 32269	: V=0.9843545, theta=-32.047596 -> V=1.0, theta=0.0
% INFO    : Bus 32270	: V=0.983418, theta=-32.003723 -> V=1.0, theta=0.0
% INFO    : Bus 32271	: V=0.9813242, theta=-32.107871 -> V=1.0, theta=0.0
% INFO    : Bus 32272	: V=0.9788423, theta=-32.158356 -> V=1.0, theta=0.0
% INFO    : Bus 32273	: V=0.9840803, theta=-32.051083 -> V=1.0, theta=0.0
% INFO    : Bus 32274	: V=0.977966, theta=-32.174348 -> V=1.0, theta=0.0
% INFO    : Bus 32275	: V=0.9789771, theta=-32.164097 -> V=1.0, theta=0.0
% INFO    : Bus 32276	: V=0.9850255, theta=-31.930081 -> V=1.0, theta=0.0
% INFO    : Bus 32277	: V=0.9831953, theta=-32.020783 -> V=1.0, theta=0.0
% INFO    : Bus 32278	: V=0.985011, theta=-31.120236 -> V=1.0, theta=0.0
% INFO    : Bus 32279	: V=0.9861193, theta=-31.118075 -> V=1.0, theta=0.0
% INFO    : Bus 32280	: V=0.9978895, theta=-29.867197 -> V=1.0, theta=0.0
% INFO    : Bus 32281	: V=0.9958569, theta=-30.068771 -> V=1.0, theta=0.0
% INFO    : Bus 32282	: V=0.9845436, theta=-32.045495 -> V=1.0, theta=0.0
% INFO    : Bus 32283	: V=0.9864241, theta=-31.853081 -> V=1.0, theta=0.0
% INFO    : Bus 32284	: V=0.9857328, theta=-32.004403 -> V=1.0, theta=0.0
% INFO    : Bus 32285	: V=0.9854564, theta=-32.079214 -> V=1.0, theta=0.0
% INFO    : Bus 32286	: V=0.9847108, theta=-32.087937 -> V=1.0, theta=0.0
% INFO    : Bus 32287	: V=0.9852776, theta=-32.115087 -> V=1.0, theta=0.0
% INFO    : Bus 32288	: V=0.9859451, theta=-32.141354 -> V=1.0, theta=0.0
% INFO    : Bus 32289	: V=1.0060171, theta=-29.549175 -> V=1.0, theta=0.0
% INFO    : Bus 32290	: V=0.9875131, theta=-31.993339 -> V=1.0, theta=0.0
% INFO    : Bus 32291	: V=0.9849613, theta=-32.098277 -> V=1.0, theta=0.0
% INFO    : Bus 32292	: V=0.9872464, theta=-31.955097 -> V=1.0, theta=0.0
% INFO    : Bus 32293	: V=0.9754671, theta=-32.813702 -> V=1.0, theta=0.0
% INFO    : Bus 32294	: V=0.9997795, theta=-29.680858 -> V=1.0, theta=0.0
% INFO    : Bus 32295	: V=0.9863459, theta=-31.602612 -> V=1.0, theta=0.0
% INFO    : Bus 32296	: V=0.9796065, theta=-32.322086 -> V=1.0, theta=0.0
% INFO    : Bus 32297	: V=0.9831632, theta=-32.134887 -> V=1.0, theta=0.0
% INFO    : Bus 32298	: V=1.0030004, theta=-29.376849 -> V=1.0, theta=0.0
% INFO    : Bus 32299	: V=1.0036052, theta=-31.790134 -> V=1.0, theta=0.0
% INFO    : Bus 32300	: V=0.9882854, theta=-31.825451 -> V=1.0, theta=0.0
% INFO    : Bus 32301	: V=1.0027796, theta=-30.881132 -> V=1.0, theta=0.0
% INFO    : Bus 32302	: V=1.022043, theta=-26.084333 -> V=1.0, theta=0.0
% INFO    : Bus 32303	: V=1.0047121, theta=-29.793984 -> V=1.0, theta=0.0
% INFO    : Bus 32304	: V=0.9774467, theta=-32.355204 -> V=1.0, theta=0.0
% INFO    : Bus 32305	: V=0.9705863, theta=-32.342871 -> V=1.0, theta=0.0
% INFO    : Bus 32306	: V=0.9946013, theta=-30.240349 -> V=1.0, theta=0.0
% INFO    : Bus 32307	: V=0.9807681, theta=-32.096804 -> V=1.0, theta=0.0
% INFO    : Bus 32308	: V=0.9780385, theta=-32.986127 -> V=1.0, theta=0.0
% INFO    : Bus 32309	: V=0.9990607, theta=-35.96704 -> V=1.0, theta=0.0
% INFO    : Bus 32310	: V=1.0089402, theta=-35.896122 -> V=1.0, theta=0.0
% INFO    : Bus 32311	: V=1.002648, theta=-37.115956 -> V=1.0, theta=0.0
% INFO    : Bus 32312	: V=0.9823981, theta=-41.603271 -> V=1.0, theta=0.0
% INFO    : Bus 32313	: V=0.9892834, theta=-41.867625 -> V=1.0, theta=0.0
% INFO    : Bus 32314	: V=0.9935469, theta=-41.784111 -> V=1.0, theta=0.0
% INFO    : Bus 32315	: V=0.9802892, theta=-55.065154 -> V=1.0, theta=0.0
% INFO    : Bus 32316	: V=0.9796586, theta=-55.204924 -> V=1.0, theta=0.0
% INFO    : Bus 32317	: V=0.9777977, theta=-55.648189 -> V=1.0, theta=0.0
% INFO    : Bus 32318	: V=0.978495, theta=-55.624185 -> V=1.0, theta=0.0
% INFO    : Bus 32319	: V=0.9783055, theta=-54.858889 -> V=1.0, theta=0.0
% INFO    : Bus 32320	: V=0.9928391, theta=-29.749113 -> V=1.0, theta=0.0
% INFO    : Bus 32321	: V=0.9729427, theta=-30.859472 -> V=1.0, theta=0.0
% INFO    : Bus 32322	: V=0.9836859, theta=-32.635709 -> V=1.0, theta=0.0
% INFO    : Bus 32323	: V=0.9857497, theta=-32.129894 -> V=1.0, theta=0.0
% INFO    : Bus 32324	: V=0.9870474, theta=-31.818397 -> V=1.0, theta=0.0
% INFO    : Bus 32325	: V=0.9941019, theta=-31.010432 -> V=1.0, theta=0.0
% INFO    : Bus 32326	: V=0.9819684, theta=-31.781351 -> V=1.0, theta=0.0
% INFO    : Bus 32327	: V=0.9807959, theta=-28.57847 -> V=1.0, theta=0.0
% INFO    : Bus 32328	: V=0.9752833, theta=-29.147981 -> V=1.0, theta=0.0
% INFO    : Bus 32329	: V=0.9561527, theta=-31.01581 -> V=1.0, theta=0.0
% INFO    : Bus 32330	: V=0.9629166, theta=-30.798026 -> V=1.0, theta=0.0
% INFO    : Bus 32331	: V=0.9612918, theta=-30.997185 -> V=1.0, theta=0.0
% INFO    : Bus 32332	: V=0.9594983, theta=-31.062048 -> V=1.0, theta=0.0
% INFO    : Bus 32333	: V=0.9736897, theta=-29.443273 -> V=1.0, theta=0.0
% INFO    : Bus 32334	: V=0.9583194, theta=-30.841998 -> V=1.0, theta=0.0
% INFO    : Bus 32335	: V=0.9612098, theta=-30.54594 -> V=1.0, theta=0.0
% INFO    : Bus 32336	: V=0.958725, theta=-31.006053 -> V=1.0, theta=0.0
% INFO    : Bus 32337	: V=0.9509005, theta=-31.320635 -> V=1.0, theta=0.0
% INFO    : Bus 32338	: V=0.9648872, theta=-30.588304 -> V=1.0, theta=0.0
% INFO    : Bus 32339	: V=1.0021494, theta=-25.611041 -> V=1.0, theta=0.0
% INFO    : Bus 32340	: V=0.9593841, theta=-30.027344 -> V=1.0, theta=0.0
% INFO    : Bus 32341	: V=0.9476985, theta=-30.372108 -> V=1.0, theta=0.0
% INFO    : Bus 32342	: V=0.9369453, theta=-31.172882 -> V=1.0, theta=0.0
% INFO    : Bus 32343	: V=1.0087797, theta=-24.371853 -> V=1.0, theta=0.0
% INFO    : Bus 32344	: V=0.9555546, theta=-29.813919 -> V=1.0, theta=0.0
% INFO    : Bus 32345	: V=0.9919032, theta=-30.907349 -> V=1.0, theta=0.0
% INFO    : Bus 32346	: V=0.9679238, theta=-35.791246 -> V=1.0, theta=0.0
% INFO    : Bus 32347	: V=0.9579367, theta=-36.433064 -> V=1.0, theta=0.0
% INFO    : Bus 32348	: V=0.9643114, theta=-48.260237 -> V=1.0, theta=0.0
% INFO    : Bus 32349	: V=0.9624803, theta=-47.244394 -> V=1.0, theta=0.0
% INFO    : Bus 32350	: V=0.9788427, theta=-42.64717 -> V=1.0, theta=0.0
% INFO    : Bus 32351	: V=0.9970905, theta=-42.032086 -> V=1.0, theta=0.0
% INFO    : Bus 32352	: V=0.9745716, theta=-43.947381 -> V=1.0, theta=0.0
% INFO    : Bus 32353	: V=0.9721932, theta=-43.953511 -> V=1.0, theta=0.0
% INFO    : Bus 32354	: V=0.9834316, theta=-43.692809 -> V=1.0, theta=0.0
% INFO    : Bus 32355	: V=0.9864578, theta=-43.502231 -> V=1.0, theta=0.0
% INFO    : Bus 32356	: V=0.9817508, theta=-43.803189 -> V=1.0, theta=0.0
% INFO    : Bus 32357	: V=0.9924564, theta=-42.651857 -> V=1.0, theta=0.0
% INFO    : Bus 32358	: V=0.9857096, theta=-43.560643 -> V=1.0, theta=0.0
% INFO    : Bus 32359	: V=0.9957242, theta=-43.000001 -> V=1.0, theta=0.0
% INFO    : Bus 32360	: V=0.9862241, theta=-28.097637 -> V=1.0, theta=0.0
% INFO    : Bus 32361	: V=0.9791082, theta=-29.236767 -> V=1.0, theta=0.0
% INFO    : Bus 32362	: V=0.9464154, theta=-31.451243 -> V=1.0, theta=0.0
% INFO    : Bus 32363	: V=0.9635354, theta=-32.253028 -> V=1.0, theta=0.0
% INFO    : Bus 32364	: V=0.966539, theta=-31.538527 -> V=1.0, theta=0.0
% INFO    : Bus 32365	: V=0.9705588, theta=-31.567989 -> V=1.0, theta=0.0
% INFO    : Bus 32366	: V=0.9756852, theta=-30.788317 -> V=1.0, theta=0.0
% INFO    : Bus 32367	: V=0.9904337, theta=-28.363029 -> V=1.0, theta=0.0
% INFO    : Bus 32368	: V=0.9745491, theta=-29.520193 -> V=1.0, theta=0.0
% INFO    : Bus 32369	: V=0.9893187, theta=-28.894502 -> V=1.0, theta=0.0
% INFO    : Bus 32370	: V=0.986409, theta=-29.284111 -> V=1.0, theta=0.0
% INFO    : Bus 32371	: V=0.9799347, theta=-30.287582 -> V=1.0, theta=0.0
% INFO    : Bus 32372	: V=0.9885792, theta=-29.270422 -> V=1.0, theta=0.0
% INFO    : Bus 32373	: V=0.9822486, theta=-29.945274 -> V=1.0, theta=0.0
% INFO    : Bus 32374	: V=0.9713665, theta=-31.075446 -> V=1.0, theta=0.0
% INFO    : Bus 32375	: V=1.0003857, theta=-30.186305 -> V=1.0, theta=0.0
% INFO    : Bus 32376	: V=1.0101471, theta=-26.638225 -> V=1.0, theta=0.0
% INFO    : Bus 32377	: V=0.9953667, theta=-28.524761 -> V=1.0, theta=0.0
% INFO    : Bus 32378	: V=0.9892766, theta=-29.205847 -> V=1.0, theta=0.0
% INFO    : Bus 32379	: V=0.9857951, theta=-28.243179 -> V=1.0, theta=0.0
% INFO    : Bus 32380	: V=0.9671996, theta=-29.796825 -> V=1.0, theta=0.0
% INFO    : Bus 32381	: V=0.9543485, theta=-31.219914 -> V=1.0, theta=0.0
% INFO    : Bus 32382	: V=0.9506322, theta=-31.33446 -> V=1.0, theta=0.0
% INFO    : Bus 32383	: V=0.9563279, theta=-31.019184 -> V=1.0, theta=0.0
% INFO    : Bus 32384	: V=0.9595384, theta=-30.770007 -> V=1.0, theta=0.0
% INFO    : Bus 32385	: V=0.9628018, theta=-30.449205 -> V=1.0, theta=0.0
% INFO    : Bus 32386	: V=0.954321, theta=-31.141823 -> V=1.0, theta=0.0
% INFO    : Bus 32387	: V=0.9338958, theta=-33.5185 -> V=1.0, theta=0.0
% INFO    : Bus 32388	: V=0.9629483, theta=-31.067395 -> V=1.0, theta=0.0
% INFO    : Bus 32389	: V=0.9585573, theta=-31.511868 -> V=1.0, theta=0.0
% INFO    : Bus 32390	: V=0.9405311, theta=-32.909552 -> V=1.0, theta=0.0
% INFO    : Bus 32391	: V=1.0010791, theta=-41.322617 -> V=1.0, theta=0.0
% INFO    : Bus 32392	: V=0.9380326, theta=-45.998005 -> V=1.0, theta=0.0
% INFO    : Bus 32393	: V=1.0091715, theta=-29.892789 -> V=1.0, theta=0.0
% INFO    : Bus 32394	: V=1.0079339, theta=-29.937133 -> V=1.0, theta=0.0
% INFO    : Bus 32395	: V=1.0106025, theta=-29.825059 -> V=1.0, theta=0.0
% INFO    : Bus 32396	: V=0.9863992, theta=-31.253345 -> V=1.0, theta=0.0
% INFO    : Bus 32397	: V=0.9841388, theta=-31.386443 -> V=1.0, theta=0.0
% INFO    : Bus 32398	: V=0.9892474, theta=-31.136741 -> V=1.0, theta=0.0
% INFO    : Bus 32399	: V=0.9861878, theta=-31.256632 -> V=1.0, theta=0.0
% INFO    : Bus 32400	: V=0.9854571, theta=-31.284223 -> V=1.0, theta=0.0
% INFO    : Bus 32401	: V=0.9844986, theta=-31.277157 -> V=1.0, theta=0.0
% INFO    : Bus 32402	: V=0.9769916, theta=-31.669623 -> V=1.0, theta=0.0
% INFO    : Bus 32403	: V=0.9896493, theta=-31.090459 -> V=1.0, theta=0.0
% INFO    : Bus 32404	: V=0.9857455, theta=-31.279057 -> V=1.0, theta=0.0
% INFO    : Bus 32405	: V=0.9848445, theta=-31.271734 -> V=1.0, theta=0.0
% INFO    : Bus 32406	: V=0.9874344, theta=-31.211951 -> V=1.0, theta=0.0
% INFO    : Bus 32407	: V=0.9863478, theta=-31.248769 -> V=1.0, theta=0.0
% INFO    : Bus 32408	: V=0.9837629, theta=-31.325586 -> V=1.0, theta=0.0
% INFO    : Bus 32409	: V=0.9909579, theta=-31.091559 -> V=1.0, theta=0.0
% INFO    : Bus 32410	: V=0.9904303, theta=-31.087246 -> V=1.0, theta=0.0
% INFO    : Bus 32411	: V=0.9888269, theta=-31.098073 -> V=1.0, theta=0.0
% INFO    : Bus 32412	: V=0.9819372, theta=-31.368299 -> V=1.0, theta=0.0
% INFO    : Bus 32413	: V=0.981178, theta=-31.356933 -> V=1.0, theta=0.0
% INFO    : Bus 32414	: V=0.9774737, theta=-31.717899 -> V=1.0, theta=0.0
% INFO    : Bus 32415	: V=0.9783127, theta=-31.641739 -> V=1.0, theta=0.0
% INFO    : Bus 32416	: V=0.9813742, theta=-31.528435 -> V=1.0, theta=0.0
% INFO    : Bus 32417	: V=0.9805573, theta=-31.367191 -> V=1.0, theta=0.0
% INFO    : Bus 32418	: V=0.9833388, theta=-30.912989 -> V=1.0, theta=0.0
% INFO    : Bus 32419	: V=0.9854863, theta=-30.85445 -> V=1.0, theta=0.0
% INFO    : Bus 32420	: V=0.9980642, theta=-29.049873 -> V=1.0, theta=0.0
% INFO    : Bus 32421	: V=0.990894, theta=-30.38165 -> V=1.0, theta=0.0
% INFO    : Bus 32422	: V=1.0149542, theta=-24.578001 -> V=1.0, theta=0.0
% INFO    : Bus 32423	: V=1.0003222, theta=-28.950639 -> V=1.0, theta=0.0
% INFO    : Bus 32424	: V=1.0066199, theta=-29.411709 -> V=1.0, theta=0.0
% INFO    : Bus 32425	: V=0.9914198, theta=-30.373429 -> V=1.0, theta=0.0
% INFO    : Bus 32426	: V=0.9929323, theta=-30.364914 -> V=1.0, theta=0.0
% INFO    : Bus 32427	: V=0.9913482, theta=-30.483252 -> V=1.0, theta=0.0
% INFO    : Bus 32428	: V=0.9940023, theta=-30.430826 -> V=1.0, theta=0.0
% INFO    : Bus 32429	: V=0.991039, theta=-30.964137 -> V=1.0, theta=0.0
% INFO    : Bus 32430	: V=0.9894577, theta=-31.066754 -> V=1.0, theta=0.0
% INFO    : Bus 32431	: V=0.9743742, theta=-31.925271 -> V=1.0, theta=0.0
% INFO    : Bus 32432	: V=0.9782648, theta=-31.541375 -> V=1.0, theta=0.0
% INFO    : Bus 32433	: V=0.98439, theta=-30.899029 -> V=1.0, theta=0.0
% INFO    : Bus 32434	: V=0.9898127, theta=-30.973857 -> V=1.0, theta=0.0
% INFO    : Bus 32435	: V=0.9938424, theta=-30.557939 -> V=1.0, theta=0.0
% INFO    : Bus 32436	: V=1.015492, theta=-29.445645 -> V=1.0, theta=0.0
% INFO    : Bus 32437	: V=0.9851792, theta=-33.070802 -> V=1.0, theta=0.0
% INFO    : Bus 32438	: V=0.9872961, theta=-31.162516 -> V=1.0, theta=0.0
% INFO    : Bus 32439	: V=1.010803, theta=-28.428474 -> V=1.0, theta=0.0
% INFO    : Bus 32440	: V=0.9928437, theta=-29.255251 -> V=1.0, theta=0.0
% INFO    : Bus 32441	: V=0.9923128, theta=-29.550935 -> V=1.0, theta=0.0
% INFO    : Bus 32442	: V=0.9990505, theta=-29.914922 -> V=1.0, theta=0.0
% INFO    : Bus 32443	: V=0.9865526, theta=-31.113902 -> V=1.0, theta=0.0
% INFO    : Bus 32444	: V=0.9844025, theta=-31.373804 -> V=1.0, theta=0.0
% INFO    : Bus 32445	: V=0.9909733, theta=-31.105057 -> V=1.0, theta=0.0
% INFO    : Bus 32446	: V=0.994377, theta=-30.594157 -> V=1.0, theta=0.0
% INFO    : Bus 32447	: V=0.9890119, theta=-30.795799 -> V=1.0, theta=0.0
% INFO    : Bus 32448	: V=0.9908707, theta=-30.304678 -> V=1.0, theta=0.0
% INFO    : Bus 32449	: V=0.9785284, theta=-31.477158 -> V=1.0, theta=0.0
% INFO    : Bus 32450	: V=0.9705195, theta=-31.697903 -> V=1.0, theta=0.0
% INFO    : Bus 32451	: V=0.9751435, theta=-31.643582 -> V=1.0, theta=0.0
% INFO    : Bus 32452	: V=0.9683031, theta=-31.91123 -> V=1.0, theta=0.0
% INFO    : Bus 32453	: V=0.9728043, theta=-31.787428 -> V=1.0, theta=0.0
% INFO    : Bus 32454	: V=0.9754519, theta=-31.667283 -> V=1.0, theta=0.0
% INFO    : Bus 32455	: V=0.9738864, theta=-31.676599 -> V=1.0, theta=0.0
% INFO    : Bus 32456	: V=0.9727756, theta=-31.824413 -> V=1.0, theta=0.0
% INFO    : Bus 32457	: V=0.9734239, theta=-31.811216 -> V=1.0, theta=0.0
% INFO    : Bus 32458	: V=0.9874332, theta=-31.220402 -> V=1.0, theta=0.0
% INFO    : Bus 32459	: V=0.9872557, theta=-31.229625 -> V=1.0, theta=0.0
% INFO    : Bus 32460	: V=0.9872606, theta=-31.222725 -> V=1.0, theta=0.0
% INFO    : Bus 32461	: V=0.9846907, theta=-30.410565 -> V=1.0, theta=0.0
% INFO    : Bus 32462	: V=1.0145727, theta=-29.631875 -> V=1.0, theta=0.0
% INFO    : Bus 32463	: V=1.0164252, theta=-29.587748 -> V=1.0, theta=0.0
% INFO    : Bus 32464	: V=0.9381389, theta=-39.336111 -> V=1.0, theta=0.0
% INFO    : Bus 32465	: V=0.966524, theta=-39.299239 -> V=1.0, theta=0.0
% INFO    : Bus 32466	: V=0.9451597, theta=-39.117101 -> V=1.0, theta=0.0
% INFO    : Bus 32467	: V=0.9618819, theta=-39.357436 -> V=1.0, theta=0.0
% INFO    : Bus 32468	: V=0.9682617, theta=-36.387939 -> V=1.0, theta=0.0
% INFO    : Bus 32469	: V=0.9767205, theta=-28.64601 -> V=1.0, theta=0.0
% INFO    : Bus 32470	: V=0.9920436, theta=-26.25336 -> V=1.0, theta=0.0
% INFO    : Bus 32471	: V=0.9767153, theta=-27.400738 -> V=1.0, theta=0.0
% INFO    : Bus 32472	: V=0.9826526, theta=-27.288969 -> V=1.0, theta=0.0
% INFO    : Bus 32473	: V=0.9876714, theta=-27.062879 -> V=1.0, theta=0.0
% INFO    : Bus 32474	: V=0.999757, theta=-24.119966 -> V=1.0, theta=0.0
% INFO    : Bus 32475	: V=0.9569864, theta=-40.047127 -> V=1.0, theta=0.0
% INFO    : Bus 32476	: V=0.9462584, theta=-38.04979 -> V=1.0, theta=0.0
% INFO    : Bus 32477	: V=0.9449599, theta=-39.439705 -> V=1.0, theta=0.0
% INFO    : Bus 32478	: V=0.9745981, theta=-33.794467 -> V=1.0, theta=0.0
% INFO    : Bus 32479	: V=0.9576995, theta=-39.666101 -> V=1.0, theta=0.0
% INFO    : Bus 32480	: V=0.9550464, theta=-40.552764 -> V=1.0, theta=0.0
% INFO    : Bus 32481	: V=0.9506688, theta=-40.702168 -> V=1.0, theta=0.0
% INFO    : Bus 32482	: V=0.9591765, theta=-38.48536 -> V=1.0, theta=0.0
% INFO    : Bus 32483	: V=0.9461028, theta=-40.093871 -> V=1.0, theta=0.0
% INFO    : Bus 32484	: V=0.9489309, theta=-41.489185 -> V=1.0, theta=0.0
% INFO    : Bus 32485	: V=0.9499152, theta=-40.845622 -> V=1.0, theta=0.0
% INFO    : Bus 32486	: V=0.9556057, theta=-39.079308 -> V=1.0, theta=0.0
% INFO    : Bus 32487	: V=0.9539061, theta=-39.332878 -> V=1.0, theta=0.0
% INFO    : Bus 32488	: V=0.9529779, theta=-39.489377 -> V=1.0, theta=0.0
% INFO    : Bus 32489	: V=0.9519851, theta=-39.651782 -> V=1.0, theta=0.0
% INFO    : Bus 32490	: V=0.9476643, theta=-39.503463 -> V=1.0, theta=0.0
% INFO    : Bus 32491	: V=0.9483041, theta=-39.449974 -> V=1.0, theta=0.0
% INFO    : Bus 32492	: V=0.9477029, theta=-39.437523 -> V=1.0, theta=0.0
% INFO    : Bus 32493	: V=0.950552, theta=-37.98605 -> V=1.0, theta=0.0
% INFO    : Bus 32494	: V=0.948284, theta=-39.306746 -> V=1.0, theta=0.0
% INFO    : Bus 32495	: V=0.9463124, theta=-39.384544 -> V=1.0, theta=0.0
% INFO    : Bus 32496	: V=0.9438063, theta=-39.184174 -> V=1.0, theta=0.0
% INFO    : Bus 32497	: V=0.9471373, theta=-39.722132 -> V=1.0, theta=0.0
% INFO    : Bus 32498	: V=0.9465227, theta=-39.054527 -> V=1.0, theta=0.0
% INFO    : Bus 32499	: V=0.9511867, theta=-37.858135 -> V=1.0, theta=0.0
% INFO    : Bus 32500	: V=0.9527137, theta=-37.499485 -> V=1.0, theta=0.0
% INFO    : Bus 32501	: V=0.9883174, theta=-35.345462 -> V=1.0, theta=0.0
% INFO    : Bus 32502	: V=0.9900577, theta=-34.975178 -> V=1.0, theta=0.0
% INFO    : Bus 32503	: V=0.9939931, theta=-34.533103 -> V=1.0, theta=0.0
% INFO    : Bus 32504	: V=0.9896968, theta=-35.275909 -> V=1.0, theta=0.0
% INFO    : Bus 32505	: V=0.9969047, theta=-34.377311 -> V=1.0, theta=0.0
% INFO    : Bus 32506	: V=0.9887983, theta=-35.275783 -> V=1.0, theta=0.0
% INFO    : Bus 32507	: V=0.989987, theta=-35.261529 -> V=1.0, theta=0.0
% INFO    : Bus 32508	: V=0.9903028, theta=-35.275783 -> V=1.0, theta=0.0
% INFO    : Bus 32509	: V=0.9915051, theta=-35.216858 -> V=1.0, theta=0.0
% INFO    : Bus 32510	: V=0.988525, theta=-35.27819 -> V=1.0, theta=0.0
% INFO    : Bus 32511	: V=0.994936, theta=-34.482936 -> V=1.0, theta=0.0
% INFO    : Bus 32512	: V=0.9902764, theta=-34.972132 -> V=1.0, theta=0.0
% INFO    : Bus 32513	: V=0.984772, theta=-35.449676 -> V=1.0, theta=0.0
% INFO    : Bus 32514	: V=0.9866374, theta=-35.422134 -> V=1.0, theta=0.0
% INFO    : Bus 32515	: V=1.0150695, theta=-32.381678 -> V=1.0, theta=0.0
% INFO    : Bus 32516	: V=1.0143321, theta=-32.702575 -> V=1.0, theta=0.0
% INFO    : Bus 32517	: V=1.0141861, theta=-33.067499 -> V=1.0, theta=0.0
% INFO    : Bus 32518	: V=0.9954717, theta=-35.5298 -> V=1.0, theta=0.0
% INFO    : Bus 32519	: V=0.9965124, theta=-35.670391 -> V=1.0, theta=0.0
% INFO    : Bus 32520	: V=0.9994275, theta=-34.461428 -> V=1.0, theta=0.0
% INFO    : Bus 32521	: V=0.9939336, theta=-34.85668 -> V=1.0, theta=0.0
% INFO    : Bus 32522	: V=1.0013669, theta=-33.937276 -> V=1.0, theta=0.0
% INFO    : Bus 32523	: V=0.9861317, theta=-35.200473 -> V=1.0, theta=0.0
% INFO    : Bus 32524	: V=0.9902329, theta=-35.477087 -> V=1.0, theta=0.0
% INFO    : Bus 32525	: V=0.9760909, theta=-36.041382 -> V=1.0, theta=0.0
% INFO    : Bus 32526	: V=0.9821209, theta=-35.679465 -> V=1.0, theta=0.0
% INFO    : Bus 32527	: V=0.9838553, theta=-35.58834 -> V=1.0, theta=0.0
% INFO    : Bus 32528	: V=0.9876226, theta=-34.868457 -> V=1.0, theta=0.0
% INFO    : Bus 32529	: V=0.9880868, theta=-34.667577 -> V=1.0, theta=0.0
% INFO    : Bus 32530	: V=0.9900705, theta=-34.394201 -> V=1.0, theta=0.0
% INFO    : Bus 32531	: V=0.9744234, theta=-45.227934 -> V=1.0, theta=0.0
% INFO    : Bus 32532	: V=0.9551327, theta=-38.7358 -> V=1.0, theta=0.0
% INFO    : Bus 32533	: V=0.9497301, theta=-38.683602 -> V=1.0, theta=0.0
% INFO    : Bus 32534	: V=0.9504243, theta=-38.671709 -> V=1.0, theta=0.0
% INFO    : Bus 32535	: V=0.9478232, theta=-40.736363 -> V=1.0, theta=0.0
% INFO    : Bus 32536	: V=0.9474616, theta=-40.876969 -> V=1.0, theta=0.0
% INFO    : Bus 32537	: V=0.953006, theta=-39.350603 -> V=1.0, theta=0.0
% INFO    : Bus 32538	: V=0.9510252, theta=-40.074666 -> V=1.0, theta=0.0
% INFO    : Bus 32539	: V=0.9519034, theta=-39.682406 -> V=1.0, theta=0.0
% INFO    : Bus 32540	: V=0.9508736, theta=-40.126805 -> V=1.0, theta=0.0
% INFO    : Bus 32541	: V=0.9523261, theta=-39.784256 -> V=1.0, theta=0.0
% INFO    : Bus 32542	: V=0.9462665, theta=-41.104561 -> V=1.0, theta=0.0
% INFO    : Bus 32543	: V=0.9499738, theta=-40.589643 -> V=1.0, theta=0.0
% INFO    : Bus 32544	: V=0.9454747, theta=-43.106282 -> V=1.0, theta=0.0
% INFO    : Bus 32545	: V=0.953601, theta=-39.708948 -> V=1.0, theta=0.0
% INFO    : Bus 32546	: V=0.9444084, theta=-40.998678 -> V=1.0, theta=0.0
% INFO    : Bus 32547	: V=0.9508469, theta=-39.602692 -> V=1.0, theta=0.0
% INFO    : Bus 32548	: V=0.952266, theta=-39.412699 -> V=1.0, theta=0.0
% INFO    : Bus 32549	: V=0.9544681, theta=-39.356624 -> V=1.0, theta=0.0
% INFO    : Bus 32550	: V=0.963828, theta=-36.844544 -> V=1.0, theta=0.0
% INFO    : Bus 32551	: V=0.9584694, theta=-38.112612 -> V=1.0, theta=0.0
% INFO    : Bus 32552	: V=0.9566865, theta=-38.475867 -> V=1.0, theta=0.0
% INFO    : Bus 32553	: V=0.9540091, theta=-38.957116 -> V=1.0, theta=0.0
% INFO    : Bus 32554	: V=0.9599158, theta=-37.708661 -> V=1.0, theta=0.0
% INFO    : Bus 32555	: V=0.9543688, theta=-38.791894 -> V=1.0, theta=0.0
% INFO    : Bus 32556	: V=0.9572357, theta=-38.247707 -> V=1.0, theta=0.0
% INFO    : Bus 32557	: V=0.9567473, theta=-38.480977 -> V=1.0, theta=0.0
% INFO    : Bus 32558	: V=0.9557925, theta=-37.974666 -> V=1.0, theta=0.0
% INFO    : Bus 32559	: V=0.9559527, theta=-38.65273 -> V=1.0, theta=0.0
% INFO    : Bus 32560	: V=0.9477277, theta=-40.454427 -> V=1.0, theta=0.0
% INFO    : Bus 32561	: V=0.9512835, theta=-39.429409 -> V=1.0, theta=0.0
% INFO    : Bus 32562	: V=0.9546347, theta=-38.943493 -> V=1.0, theta=0.0
% INFO    : Bus 32563	: V=0.9528839, theta=-39.050795 -> V=1.0, theta=0.0
% INFO    : Bus 32564	: V=0.9522715, theta=-39.214058 -> V=1.0, theta=0.0
% INFO    : Bus 32565	: V=0.9531948, theta=-38.899093 -> V=1.0, theta=0.0
% INFO    : Bus 32566	: V=0.9575384, theta=-37.776728 -> V=1.0, theta=0.0
% INFO    : Bus 32567	: V=0.9463881, theta=-40.391833 -> V=1.0, theta=0.0
% INFO    : Bus 32568	: V=0.9513605, theta=-39.090811 -> V=1.0, theta=0.0
% INFO    : Bus 32569	: V=0.9524687, theta=-40.031923 -> V=1.0, theta=0.0
% INFO    : Bus 32570	: V=0.9562476, theta=-38.802151 -> V=1.0, theta=0.0
% INFO    : Bus 32571	: V=0.9539755, theta=-38.176567 -> V=1.0, theta=0.0
% INFO    : Bus 32572	: V=0.945094, theta=-40.631736 -> V=1.0, theta=0.0
% INFO    : Bus 32573	: V=0.9450737, theta=-40.754928 -> V=1.0, theta=0.0
% INFO    : Bus 32574	: V=0.9454144, theta=-40.868532 -> V=1.0, theta=0.0
% INFO    : Bus 32575	: V=0.94583, theta=-40.930327 -> V=1.0, theta=0.0
% INFO    : Bus 32576	: V=0.9449986, theta=-40.970757 -> V=1.0, theta=0.0
% INFO    : Bus 32577	: V=0.9549055, theta=-38.079251 -> V=1.0, theta=0.0
% INFO    : Bus 32578	: V=0.9500391, theta=-39.330936 -> V=1.0, theta=0.0
% INFO    : Bus 32579	: V=0.946632, theta=-39.806367 -> V=1.0, theta=0.0
% INFO    : Bus 32580	: V=0.948721, theta=-39.541961 -> V=1.0, theta=0.0
% INFO    : Bus 32581	: V=0.9553586, theta=-38.455375 -> V=1.0, theta=0.0
% INFO    : Bus 32582	: V=0.992764, theta=-48.003174 -> V=1.0, theta=0.0
% INFO    : Bus 32583	: V=0.9929333, theta=-48.604254 -> V=1.0, theta=0.0
% INFO    : Bus 32584	: V=0.9598343, theta=-35.805904 -> V=1.0, theta=0.0
% INFO    : Bus 32585	: V=0.9504268, theta=-37.184096 -> V=1.0, theta=0.0
% INFO    : Bus 32586	: V=0.9513021, theta=-37.152343 -> V=1.0, theta=0.0
% INFO    : Bus 32587	: V=0.9476846, theta=-37.295456 -> V=1.0, theta=0.0
% INFO    : Bus 32588	: V=0.9483426, theta=-39.123347 -> V=1.0, theta=0.0
% INFO    : Bus 32589	: V=0.9532119, theta=-37.091203 -> V=1.0, theta=0.0
% INFO    : Bus 32590	: V=0.9499602, theta=-37.341129 -> V=1.0, theta=0.0
% INFO    : Bus 32591	: V=0.9529432, theta=-37.349462 -> V=1.0, theta=0.0
% INFO    : Bus 32592	: V=0.9538218, theta=-37.080722 -> V=1.0, theta=0.0
% INFO    : Bus 32593	: V=0.9567513, theta=-36.426483 -> V=1.0, theta=0.0
% INFO    : Bus 32594	: V=0.9464981, theta=-38.95623 -> V=1.0, theta=0.0
% INFO    : Bus 32595	: V=0.9469098, theta=-38.939758 -> V=1.0, theta=0.0
% INFO    : Bus 32596	: V=0.9480997, theta=-38.86551 -> V=1.0, theta=0.0
% INFO    : Bus 32597	: V=0.9479021, theta=-37.28832 -> V=1.0, theta=0.0
% INFO    : Bus 32598	: V=0.9477309, theta=-39.209608 -> V=1.0, theta=0.0
% INFO    : Bus 32599	: V=0.9523959, theta=-37.568929 -> V=1.0, theta=0.0
% INFO    : Bus 32600	: V=0.9525374, theta=-38.163735 -> V=1.0, theta=0.0
% INFO    : Bus 32601	: V=0.952004, theta=-37.906419 -> V=1.0, theta=0.0
% INFO    : Bus 32602	: V=0.9524703, theta=-37.349396 -> V=1.0, theta=0.0
% INFO    : Bus 32603	: V=0.9531781, theta=-37.176065 -> V=1.0, theta=0.0
% INFO    : Bus 32604	: V=0.9535255, theta=-36.981129 -> V=1.0, theta=0.0
% INFO    : Bus 32605	: V=0.951886, theta=-38.494672 -> V=1.0, theta=0.0
% INFO    : Bus 32606	: V=0.9521158, theta=-36.911183 -> V=1.0, theta=0.0
% INFO    : Bus 32607	: V=0.9542218, theta=-36.640103 -> V=1.0, theta=0.0
% INFO    : Bus 32608	: V=0.9547465, theta=-36.532303 -> V=1.0, theta=0.0
% INFO    : Bus 32609	: V=0.9569401, theta=-35.803212 -> V=1.0, theta=0.0
% INFO    : Bus 32610	: V=0.955547, theta=-36.189169 -> V=1.0, theta=0.0
% INFO    : Bus 32611	: V=0.9489747, theta=-39.251661 -> V=1.0, theta=0.0
% INFO    : Bus 32612	: V=0.9506445, theta=-39.338299 -> V=1.0, theta=0.0
% INFO    : Bus 32613	: V=0.9543603, theta=-38.523143 -> V=1.0, theta=0.0
% INFO    : Bus 32614	: V=0.9531132, theta=-38.354104 -> V=1.0, theta=0.0
% INFO    : Bus 32615	: V=0.9546679, theta=-39.162391 -> V=1.0, theta=0.0
% INFO    : Bus 32616	: V=0.9527676, theta=-40.938314 -> V=1.0, theta=0.0
% INFO    : Bus 32617	: V=0.9526754, theta=-40.015933 -> V=1.0, theta=0.0
% INFO    : Bus 32618	: V=0.9500073, theta=-40.668281 -> V=1.0, theta=0.0
% INFO    : Bus 32619	: V=0.9529853, theta=-39.497952 -> V=1.0, theta=0.0
% INFO    : Bus 32620	: V=0.9490592, theta=-39.416022 -> V=1.0, theta=0.0
% INFO    : Bus 32621	: V=0.9525202, theta=-39.579534 -> V=1.0, theta=0.0
% INFO    : Bus 32622	: V=0.9525022, theta=-40.186199 -> V=1.0, theta=0.0
% INFO    : Bus 32623	: V=0.9517618, theta=-40.165578 -> V=1.0, theta=0.0
% INFO    : Bus 32624	: V=0.9531347, theta=-40.256602 -> V=1.0, theta=0.0
% INFO    : Bus 32625	: V=0.9553534, theta=-39.180306 -> V=1.0, theta=0.0
% INFO    : Bus 32626	: V=0.9530223, theta=-39.788265 -> V=1.0, theta=0.0
% INFO    : Bus 32627	: V=0.9508493, theta=-40.970437 -> V=1.0, theta=0.0
% INFO    : Bus 32628	: V=0.9540676, theta=-39.539339 -> V=1.0, theta=0.0
% INFO    : Bus 32629	: V=0.9534805, theta=-39.780111 -> V=1.0, theta=0.0
% INFO    : Bus 32630	: V=0.9491427, theta=-41.813389 -> V=1.0, theta=0.0
% INFO    : Bus 32631	: V=0.9506845, theta=-41.673461 -> V=1.0, theta=0.0
% INFO    : Bus 32632	: V=0.9493886, theta=-41.735621 -> V=1.0, theta=0.0
% INFO    : Bus 32633	: V=0.9515033, theta=-41.045491 -> V=1.0, theta=0.0
% INFO    : Bus 32634	: V=0.9536452, theta=-39.374957 -> V=1.0, theta=0.0
% INFO    : Bus 32635	: V=0.9497673, theta=-39.345148 -> V=1.0, theta=0.0
% INFO    : Bus 32636	: V=0.9513567, theta=-41.543344 -> V=1.0, theta=0.0
% INFO    : Bus 32637	: V=0.9488501, theta=-41.820627 -> V=1.0, theta=0.0
% INFO    : Bus 32638	: V=0.9498424, theta=-40.695824 -> V=1.0, theta=0.0
% INFO    : Bus 32639	: V=0.9520662, theta=-40.789663 -> V=1.0, theta=0.0
% INFO    : Bus 32640	: V=0.9508813, theta=-40.535554 -> V=1.0, theta=0.0
% INFO    : Bus 32641	: V=0.9523937, theta=-40.431306 -> V=1.0, theta=0.0
% INFO    : Bus 32642	: V=0.9514209, theta=-40.595214 -> V=1.0, theta=0.0
% INFO    : Bus 32643	: V=0.9527038, theta=-40.246306 -> V=1.0, theta=0.0
% INFO    : Bus 32644	: V=0.9534804, theta=-40.211682 -> V=1.0, theta=0.0
% INFO    : Bus 32645	: V=0.9515913, theta=-40.492724 -> V=1.0, theta=0.0
% INFO    : Bus 32646	: V=0.9530933, theta=-39.306689 -> V=1.0, theta=0.0
% INFO    : Bus 32647	: V=0.9508492, theta=-40.652727 -> V=1.0, theta=0.0
% INFO    : Bus 32648	: V=0.9520462, theta=-40.499016 -> V=1.0, theta=0.0
% INFO    : Bus 32649	: V=0.9664059, theta=-36.213504 -> V=1.0, theta=0.0
% INFO    : Bus 32650	: V=0.9562179, theta=-39.198203 -> V=1.0, theta=0.0
% INFO    : Bus 32651	: V=0.9546878, theta=-39.602257 -> V=1.0, theta=0.0
% INFO    : Bus 32652	: V=0.9528373, theta=-39.160237 -> V=1.0, theta=0.0
% INFO    : Bus 32653	: V=0.9556736, theta=-38.624085 -> V=1.0, theta=0.0
% INFO    : Bus 32654	: V=0.9506613, theta=-39.287629 -> V=1.0, theta=0.0
% INFO    : Bus 32655	: V=0.9479771, theta=-39.404054 -> V=1.0, theta=0.0
% INFO    : Bus 32656	: V=0.954499, theta=-39.010482 -> V=1.0, theta=0.0
% INFO    : Bus 32657	: V=0.9537669, theta=-39.183789 -> V=1.0, theta=0.0
% INFO    : Bus 32658	: V=0.9503505, theta=-39.274326 -> V=1.0, theta=0.0
% INFO    : Bus 32659	: V=0.953573, theta=-39.169147 -> V=1.0, theta=0.0
% INFO    : Bus 32660	: V=0.9509005, theta=-40.653593 -> V=1.0, theta=0.0
% INFO    : Bus 32661	: V=0.9491631, theta=-40.271393 -> V=1.0, theta=0.0
% INFO    : Bus 32662	: V=0.9524005, theta=-39.014943 -> V=1.0, theta=0.0
% INFO    : Bus 32663	: V=0.9527999, theta=-39.258606 -> V=1.0, theta=0.0
% INFO    : Bus 32664	: V=0.9527257, theta=-40.077552 -> V=1.0, theta=0.0
% INFO    : Bus 32665	: V=0.9478055, theta=-40.357851 -> V=1.0, theta=0.0
% INFO    : Bus 32666	: V=0.9536495, theta=-40.354689 -> V=1.0, theta=0.0
% INFO    : Bus 32667	: V=0.9551628, theta=-37.88186 -> V=1.0, theta=0.0
% INFO    : Bus 32668	: V=0.9526507, theta=-40.537019 -> V=1.0, theta=0.0
% INFO    : Bus 32669	: V=0.9532554, theta=-40.601329 -> V=1.0, theta=0.0
% INFO    : Bus 32670	: V=0.9536672, theta=-40.602266 -> V=1.0, theta=0.0
% INFO    : Bus 32671	: V=0.9527087, theta=-40.689091 -> V=1.0, theta=0.0
% INFO    : Bus 32672	: V=0.9526294, theta=-40.534143 -> V=1.0, theta=0.0
% INFO    : Bus 32673	: V=0.9529482, theta=-40.568026 -> V=1.0, theta=0.0
% INFO    : Bus 32674	: V=0.9530361, theta=-40.162642 -> V=1.0, theta=0.0
% INFO    : Bus 32675	: V=0.956776, theta=-39.206457 -> V=1.0, theta=0.0
% INFO    : Bus 32676	: V=0.9575324, theta=-39.108844 -> V=1.0, theta=0.0
% INFO    : Bus 32677	: V=0.9536836, theta=-40.746663 -> V=1.0, theta=0.0
% INFO    : Bus 32678	: V=0.9632578, theta=-39.113999 -> V=1.0, theta=0.0
% INFO    : Bus 32679	: V=0.9524263, theta=-40.995399 -> V=1.0, theta=0.0
% INFO    : Bus 32680	: V=0.9530375, theta=-40.599381 -> V=1.0, theta=0.0
% INFO    : Bus 32681	: V=0.9606791, theta=-39.358375 -> V=1.0, theta=0.0
% INFO    : Bus 32682	: V=0.9566668, theta=-39.781215 -> V=1.0, theta=0.0
% INFO    : Bus 32683	: V=0.9614092, theta=-39.289366 -> V=1.0, theta=0.0
% INFO    : Bus 32684	: V=0.9574085, theta=-39.766994 -> V=1.0, theta=0.0
% INFO    : Bus 32685	: V=0.9573243, theta=-37.19272 -> V=1.0, theta=0.0
% INFO    : Bus 32686	: V=0.9585122, theta=-38.938518 -> V=1.0, theta=0.0
% INFO    : Bus 32687	: V=0.9603482, theta=-38.649824 -> V=1.0, theta=0.0
% INFO    : Bus 32688	: V=0.9596384, theta=-36.615985 -> V=1.0, theta=0.0
% INFO    : Bus 32689	: V=0.9544793, theta=-39.195981 -> V=1.0, theta=0.0
% INFO    : Bus 32690	: V=0.9620878, theta=-38.384068 -> V=1.0, theta=0.0
% INFO    : Bus 32691	: V=0.9584845, theta=-38.819289 -> V=1.0, theta=0.0
% INFO    : Bus 32692	: V=0.958019, theta=-38.931699 -> V=1.0, theta=0.0
% INFO    : Bus 32693	: V=0.9528465, theta=-37.755761 -> V=1.0, theta=0.0
% INFO    : Bus 32694	: V=0.9533861, theta=-36.984874 -> V=1.0, theta=0.0
% INFO    : Bus 32695	: V=0.9541513, theta=-36.847877 -> V=1.0, theta=0.0
% INFO    : Bus 32696	: V=0.9588905, theta=-36.149068 -> V=1.0, theta=0.0
% INFO    : Bus 32697	: V=0.956638, theta=-36.459177 -> V=1.0, theta=0.0
% INFO    : Bus 32698	: V=0.9533454, theta=-36.997888 -> V=1.0, theta=0.0
% INFO    : Bus 32699	: V=0.9564341, theta=-35.947282 -> V=1.0, theta=0.0
% INFO    : Bus 32700	: V=0.9547469, theta=-37.381868 -> V=1.0, theta=0.0
% INFO    : Bus 32701	: V=0.9554675, theta=-36.114926 -> V=1.0, theta=0.0
% INFO    : Bus 32702	: V=0.950053, theta=-37.354204 -> V=1.0, theta=0.0
% INFO    : Bus 32703	: V=0.9575165, theta=-35.764141 -> V=1.0, theta=0.0
% INFO    : Bus 32704	: V=0.9889192, theta=-43.342717 -> V=1.0, theta=0.0
% INFO    : Bus 32705	: V=0.9831538, theta=-41.707395 -> V=1.0, theta=0.0
% INFO    : Bus 32706	: V=0.9808053, theta=-47.259736 -> V=1.0, theta=0.0
% INFO    : Bus 32707	: V=0.9885622, theta=-45.738635 -> V=1.0, theta=0.0
% INFO    : Bus 32708	: V=0.9886145, theta=-45.071009 -> V=1.0, theta=0.0
% INFO    : Bus 32709	: V=0.980604, theta=-47.858649 -> V=1.0, theta=0.0
% INFO    : Bus 32710	: V=0.988568, theta=-45.88154 -> V=1.0, theta=0.0
% INFO    : Bus 32711	: V=0.9886328, theta=-46.221559 -> V=1.0, theta=0.0
% INFO    : Bus 32712	: V=0.9883568, theta=-46.116114 -> V=1.0, theta=0.0
% INFO    : Bus 32713	: V=0.9695119, theta=-54.44021 -> V=1.0, theta=0.0
% INFO    : Bus 32714	: V=0.9704923, theta=-54.316627 -> V=1.0, theta=0.0
% INFO    : Bus 32715	: V=0.9700847, theta=-54.823045 -> V=1.0, theta=0.0
% INFO    : Bus 32716	: V=0.9760206, theta=-54.659201 -> V=1.0, theta=0.0
% INFO    : Bus 32717	: V=0.9684366, theta=-54.996426 -> V=1.0, theta=0.0
% INFO    : Bus 32718	: V=0.9798837, theta=-54.901535 -> V=1.0, theta=0.0
% INFO    : Bus 32719	: V=0.9802569, theta=-54.839716 -> V=1.0, theta=0.0
% INFO    : Bus 32720	: V=0.9818137, theta=-54.447652 -> V=1.0, theta=0.0
% INFO    : Bus 32721	: V=0.9829223, theta=-54.318307 -> V=1.0, theta=0.0
% INFO    : Bus 32722	: V=0.9988372, theta=-51.436223 -> V=1.0, theta=0.0
% INFO    : Bus 32723	: V=0.9803974, theta=-30.537716 -> V=1.0, theta=0.0
% INFO    : Bus 32724	: V=0.9919056, theta=-29.339535 -> V=1.0, theta=0.0
% INFO    : Bus 32725	: V=0.9893242, theta=-29.540147 -> V=1.0, theta=0.0
% INFO    : Bus 32726	: V=0.9740885, theta=-31.088724 -> V=1.0, theta=0.0
% INFO    : Bus 32727	: V=0.9771603, theta=-30.820409 -> V=1.0, theta=0.0
% INFO    : Bus 32728	: V=0.9738892, theta=-31.03644 -> V=1.0, theta=0.0
% INFO    : Bus 32729	: V=0.9716263, theta=-31.214116 -> V=1.0, theta=0.0
% INFO    : Bus 32730	: V=0.9814074, theta=-29.388942 -> V=1.0, theta=0.0
% INFO    : Bus 32731	: V=0.9869354, theta=-29.753419 -> V=1.0, theta=0.0
% INFO    : Bus 32732	: V=0.9811104, theta=-29.432738 -> V=1.0, theta=0.0
% INFO    : Bus 32733	: V=0.9803527, theta=-30.449476 -> V=1.0, theta=0.0
% INFO    : Bus 32734	: V=1.000442, theta=-28.599234 -> V=1.0, theta=0.0
% INFO    : Bus 32735	: V=0.9957695, theta=-28.988158 -> V=1.0, theta=0.0
% INFO    : Bus 32736	: V=1.0086129, theta=-27.779919 -> V=1.0, theta=0.0
% INFO    : Bus 32737	: V=1.0067924, theta=-27.71434 -> V=1.0, theta=0.0
% INFO    : Bus 32738	: V=0.9881746, theta=-28.433823 -> V=1.0, theta=0.0
% INFO    : Bus 32739	: V=0.9950222, theta=-28.018106 -> V=1.0, theta=0.0
% INFO    : Bus 32740	: V=0.982366, theta=-29.254046 -> V=1.0, theta=0.0
% INFO    : Bus 32741	: V=0.9840533, theta=-28.999855 -> V=1.0, theta=0.0
% INFO    : Bus 32742	: V=0.9870398, theta=-29.717503 -> V=1.0, theta=0.0
% INFO    : Bus 32743	: V=0.965064, theta=-53.467152 -> V=1.0, theta=0.0
% INFO    : Bus 32744	: V=0.9699833, theta=-54.398841 -> V=1.0, theta=0.0
% INFO    : Bus 32745	: V=0.959904, theta=-55.805946 -> V=1.0, theta=0.0
% INFO    : Bus 32746	: V=0.9736479, theta=-54.884684 -> V=1.0, theta=0.0
% INFO    : Bus 32747	: V=1.0060437, theta=-29.149494 -> V=1.0, theta=0.0
% INFO    : Bus 32748	: V=1.001449, theta=-30.25851 -> V=1.0, theta=0.0
% INFO    : Bus 32749	: V=0.9845935, theta=-32.056502 -> V=1.0, theta=0.0
% INFO    : Bus 32750	: V=0.9947713, theta=-31.240012 -> V=1.0, theta=0.0
% INFO    : Bus 32751	: V=0.9958251, theta=-30.51408 -> V=1.0, theta=0.0
% INFO    : Bus 32752	: V=0.9810402, theta=-33.250958 -> V=1.0, theta=0.0
% INFO    : Bus 32753	: V=0.9568776, theta=-36.082021 -> V=1.0, theta=0.0
% INFO    : Bus 32754	: V=0.9611955, theta=-35.448258 -> V=1.0, theta=0.0
% INFO    : Bus 32755	: V=0.9667273, theta=-35.320908 -> V=1.0, theta=0.0
% INFO    : Bus 32756	: V=0.9717834, theta=-34.798881 -> V=1.0, theta=0.0
% INFO    : Bus 32757	: V=0.964958, theta=-35.530843 -> V=1.0, theta=0.0
% INFO    : Bus 32758	: V=0.9822098, theta=-33.047298 -> V=1.0, theta=0.0
% INFO    : Bus 32759	: V=0.9775913, theta=-34.065694 -> V=1.0, theta=0.0
% INFO    : Bus 32760	: V=0.9745733, theta=-34.781788 -> V=1.0, theta=0.0
% INFO    : Bus 32761	: V=0.9925809, theta=-31.463778 -> V=1.0, theta=0.0
% INFO    : Bus 32762	: V=0.9890806, theta=-31.969478 -> V=1.0, theta=0.0
% INFO    : Bus 32763	: V=0.976137, theta=-33.100455 -> V=1.0, theta=0.0
% INFO    : Bus 32764	: V=0.997384, theta=-30.612378 -> V=1.0, theta=0.0
% INFO    : Bus 32765	: V=0.97481, theta=-33.368037 -> V=1.0, theta=0.0
% INFO    : Bus 32766	: V=0.9899416, theta=-31.899668 -> V=1.0, theta=0.0
% INFO    : Bus 32767	: V=0.9954382, theta=-35.495576 -> V=1.0, theta=0.0
% INFO    : Bus 32768	: V=1.0004103, theta=-32.506439 -> V=1.0, theta=0.0
% INFO    : Bus 32769	: V=0.9898384, theta=-35.249899 -> V=1.0, theta=0.0
% INFO    : Bus 32770	: V=0.9794919, theta=-44.787155 -> V=1.0, theta=0.0
% INFO    : Bus 32771	: V=0.9743915, theta=-47.293325 -> V=1.0, theta=0.0
% INFO    : Bus 32772	: V=0.9759522, theta=-44.085976 -> V=1.0, theta=0.0
% INFO    : Bus 32773	: V=0.9799048, theta=-45.775604 -> V=1.0, theta=0.0
% INFO    : Bus 32774	: V=0.9732229, theta=-47.061413 -> V=1.0, theta=0.0
% INFO    : Bus 32775	: V=0.9776577, theta=-46.718634 -> V=1.0, theta=0.0
% INFO    : Bus 32776	: V=0.9703296, theta=-28.560547 -> V=1.0, theta=0.0
% INFO    : Bus 32777	: V=0.9599843, theta=-29.059333 -> V=1.0, theta=0.0
% INFO    : Bus 32778	: V=0.9800409, theta=-27.749723 -> V=1.0, theta=0.0
% INFO    : Bus 32779	: V=0.9646363, theta=-28.722953 -> V=1.0, theta=0.0
% INFO    : Bus 32780	: V=0.9510714, theta=-38.72834 -> V=1.0, theta=0.0
% INFO    : Bus 32781	: V=0.9506987, theta=-42.269036 -> V=1.0, theta=0.0
% INFO    : Bus 32782	: V=0.9592973, theta=-38.858686 -> V=1.0, theta=0.0
% INFO    : Bus 32783	: V=0.978712, theta=-48.986589 -> V=1.0, theta=0.0
% INFO    : Bus 32784	: V=0.9790505, theta=-48.620337 -> V=1.0, theta=0.0
% INFO    : Bus 32785	: V=0.9860149, theta=-46.727106 -> V=1.0, theta=0.0
% INFO    : Bus 32786	: V=0.9797124, theta=-48.864461 -> V=1.0, theta=0.0
% INFO    : Bus 32787	: V=0.9848394, theta=-47.449508 -> V=1.0, theta=0.0
% INFO    : Bus 32788	: V=0.9766122, theta=-50.014233 -> V=1.0, theta=0.0
% INFO    : Bus 32789	: V=0.9795858, theta=-49.728882 -> V=1.0, theta=0.0
% INFO    : Bus 32790	: V=0.9482516, theta=-42.321325 -> V=1.0, theta=0.0
% INFO    : Bus 32791	: V=0.9484408, theta=-42.276877 -> V=1.0, theta=0.0
% INFO    : Bus 32792	: V=0.9472165, theta=-42.362071 -> V=1.0, theta=0.0
% INFO    : Bus 32793	: V=0.948391, theta=-42.247153 -> V=1.0, theta=0.0
% INFO    : Bus 32794	: V=0.9480094, theta=-42.200441 -> V=1.0, theta=0.0
% INFO    : Bus 32795	: V=0.9478137, theta=-42.333391 -> V=1.0, theta=0.0
% INFO    : Bus 32796	: V=0.9468315, theta=-42.37211 -> V=1.0, theta=0.0
% INFO    : Bus 32797	: V=0.9465509, theta=-42.384209 -> V=1.0, theta=0.0
% INFO    : Bus 32798	: V=0.9454386, theta=-43.003703 -> V=1.0, theta=0.0
% INFO    : Bus 32799	: V=0.945843, theta=-42.142746 -> V=1.0, theta=0.0
% INFO    : Bus 32800	: V=0.9520879, theta=-42.261928 -> V=1.0, theta=0.0
% INFO    : Bus 32801	: V=0.9549713, theta=-40.647445 -> V=1.0, theta=0.0
% INFO    : Bus 32802	: V=0.9519803, theta=-42.249661 -> V=1.0, theta=0.0
% INFO    : Bus 32803	: V=0.9557873, theta=-40.611925 -> V=1.0, theta=0.0
% INFO    : Bus 32804	: V=0.9570334, theta=-40.449715 -> V=1.0, theta=0.0
% INFO    : Bus 32805	: V=0.9560594, theta=-40.575199 -> V=1.0, theta=0.0
% INFO    : Bus 32806	: V=0.9533193, theta=-42.066343 -> V=1.0, theta=0.0
% INFO    : Bus 32807	: V=0.9558081, theta=-41.361156 -> V=1.0, theta=0.0
% INFO    : Bus 32808	: V=0.9503974, theta=-42.268035 -> V=1.0, theta=0.0
% INFO    : Bus 32809	: V=0.950791, theta=-42.631696 -> V=1.0, theta=0.0
% INFO    : Bus 32810	: V=0.952749, theta=-42.166621 -> V=1.0, theta=0.0
% INFO    : Bus 32811	: V=0.9532913, theta=-42.165218 -> V=1.0, theta=0.0
% INFO    : Bus 32812	: V=0.9564339, theta=-41.331148 -> V=1.0, theta=0.0
% INFO    : Bus 32813	: V=0.9550757, theta=-41.991385 -> V=1.0, theta=0.0
% INFO    : Bus 32814	: V=0.9579454, theta=-40.279398 -> V=1.0, theta=0.0
% INFO    : Bus 32815	: V=0.9584145, theta=-40.176057 -> V=1.0, theta=0.0
% INFO    : Bus 32816	: V=0.9569494, theta=-41.306773 -> V=1.0, theta=0.0
% INFO    : Bus 32817	: V=0.9852659, theta=-32.381687 -> V=1.0, theta=0.0
% INFO    : Bus 32818	: V=0.9532999, theta=-42.350294 -> V=1.0, theta=0.0
% INFO    : Bus 32819	: V=0.9522203, theta=-42.471308 -> V=1.0, theta=0.0
% INFO    : Bus 32820	: V=0.9507045, theta=-42.527338 -> V=1.0, theta=0.0
% INFO    : Bus 32821	: V=0.9514513, theta=-42.519381 -> V=1.0, theta=0.0
% INFO    : Bus 32822	: V=0.9509706, theta=-42.530014 -> V=1.0, theta=0.0
% INFO    : Bus 32823	: V=0.9514406, theta=-42.421963 -> V=1.0, theta=0.0
% INFO    : Bus 32824	: V=0.9507518, theta=-42.616037 -> V=1.0, theta=0.0
% INFO    : Bus 32825	: V=0.9502825, theta=-42.590262 -> V=1.0, theta=0.0
% INFO    : Bus 32826	: V=0.9503537, theta=-42.584105 -> V=1.0, theta=0.0
% INFO    : Bus 32827	: V=0.9487281, theta=-42.646589 -> V=1.0, theta=0.0
% INFO    : Bus 32828	: V=0.9496055, theta=-42.637529 -> V=1.0, theta=0.0
% INFO    : Bus 32829	: V=0.9486772, theta=-42.649796 -> V=1.0, theta=0.0
% INFO    : Bus 32830	: V=0.9484809, theta=-42.623892 -> V=1.0, theta=0.0
% INFO    : Bus 32831	: V=0.9459226, theta=-42.965314 -> V=1.0, theta=0.0
% INFO    : Bus 32832	: V=0.9493658, theta=-41.671612 -> V=1.0, theta=0.0
% INFO    : Bus 32833	: V=0.9485556, theta=-41.85847 -> V=1.0, theta=0.0
% INFO    : Bus 32834	: V=0.9468538, theta=-42.908846 -> V=1.0, theta=0.0
% INFO    : Bus 32835	: V=0.9485014, theta=-41.905535 -> V=1.0, theta=0.0
% INFO    : Bus 32836	: V=0.9485222, theta=-41.950618 -> V=1.0, theta=0.0
% INFO    : Bus 32837	: V=0.9505901, theta=-42.633993 -> V=1.0, theta=0.0
% INFO    : Bus 32838	: V=0.9534777, theta=-41.048047 -> V=1.0, theta=0.0
% INFO    : Bus 32839	: V=0.953436, theta=-42.259977 -> V=1.0, theta=0.0
% INFO    : Bus 32840	: V=0.9520935, theta=-42.350214 -> V=1.0, theta=0.0
% INFO    : Bus 32841	: V=0.949358, theta=-42.950715 -> V=1.0, theta=0.0
% INFO    : Bus 32842	: V=0.968015, theta=-37.683386 -> V=1.0, theta=0.0
% INFO    : Bus 32843	: V=0.9533241, theta=-42.508077 -> V=1.0, theta=0.0
% INFO    : Bus 32844	: V=0.9514822, theta=-42.695472 -> V=1.0, theta=0.0
% INFO    : Bus 32845	: V=0.9505468, theta=-42.763452 -> V=1.0, theta=0.0
% INFO    : Bus 32846	: V=0.9548646, theta=-42.299626 -> V=1.0, theta=0.0
% INFO    : Bus 32847	: V=0.955803, theta=-42.077944 -> V=1.0, theta=0.0
% INFO    : Bus 32848	: V=0.9551855, theta=-42.284811 -> V=1.0, theta=0.0
% INFO    : Bus 32849	: V=0.9483174, theta=-43.069777 -> V=1.0, theta=0.0
% INFO    : Bus 32850	: V=0.9533276, theta=-41.365664 -> V=1.0, theta=0.0
% INFO    : Bus 32851	: V=0.9494322, theta=-43.018559 -> V=1.0, theta=0.0
% INFO    : Bus 32852	: V=0.9482037, theta=-43.128605 -> V=1.0, theta=0.0
% INFO    : Bus 32853	: V=0.9524974, theta=-42.586742 -> V=1.0, theta=0.0
% INFO    : Bus 32854	: V=0.9521287, theta=-42.651318 -> V=1.0, theta=0.0
% INFO    : Bus 32855	: V=0.955678, theta=-42.083652 -> V=1.0, theta=0.0
% INFO    : Bus 32856	: V=0.95475, theta=-41.079562 -> V=1.0, theta=0.0
% INFO    : Bus 32857	: V=0.9488062, theta=-42.890617 -> V=1.0, theta=0.0
% INFO    : Bus 32858	: V=0.9495837, theta=-42.909827 -> V=1.0, theta=0.0
% INFO    : Bus 32859	: V=0.9458938, theta=-42.762332 -> V=1.0, theta=0.0
% INFO    : Bus 32860	: V=0.9485934, theta=-42.919353 -> V=1.0, theta=0.0
% INFO    : Bus 32861	: V=0.9459887, theta=-42.773349 -> V=1.0, theta=0.0
% INFO    : Bus 32862	: V=0.9487086, theta=-42.983337 -> V=1.0, theta=0.0
% INFO    : Bus 32863	: V=0.9485498, theta=-42.968159 -> V=1.0, theta=0.0
% INFO    : Bus 32864	: V=0.945436, theta=-43.290026 -> V=1.0, theta=0.0
% INFO    : Bus 32865	: V=0.9446822, theta=-43.397792 -> V=1.0, theta=0.0
% INFO    : Bus 32866	: V=0.9463163, theta=-43.18494 -> V=1.0, theta=0.0
% INFO    : Bus 32867	: V=0.9442013, theta=-43.265034 -> V=1.0, theta=0.0
% INFO    : Bus 32868	: V=0.947067, theta=-43.07982 -> V=1.0, theta=0.0
% INFO    : Bus 32869	: V=0.9499432, theta=-41.409448 -> V=1.0, theta=0.0
% INFO    : Bus 32870	: V=0.949986, theta=-41.546259 -> V=1.0, theta=0.0
% INFO    : Bus 32871	: V=0.9467735, theta=-42.783769 -> V=1.0, theta=0.0
% INFO    : Bus 32872	: V=0.9458181, theta=-43.007619 -> V=1.0, theta=0.0
% INFO    : Bus 32873	: V=0.9452584, theta=-43.152998 -> V=1.0, theta=0.0
% INFO    : Bus 32874	: V=0.9454954, theta=-42.937043 -> V=1.0, theta=0.0
% INFO    : Bus 32875	: V=0.9458304, theta=-42.37661 -> V=1.0, theta=0.0
% INFO    : Bus 32876	: V=0.9457562, theta=-42.45403 -> V=1.0, theta=0.0
% INFO    : Bus 32877	: V=0.945715, theta=-42.542726 -> V=1.0, theta=0.0
% INFO    : Bus 32878	: V=0.9427473, theta=-43.520306 -> V=1.0, theta=0.0
% INFO    : Bus 32879	: V=0.9456674, theta=-42.616735 -> V=1.0, theta=0.0
% INFO    : Bus 32880	: V=0.9438304, theta=-43.461794 -> V=1.0, theta=0.0
% INFO    : Bus 32881	: V=0.9429106, theta=-43.530758 -> V=1.0, theta=0.0
% INFO    : Bus 32882	: V=0.94476, theta=-43.35629 -> V=1.0, theta=0.0
% INFO    : Bus 32883	: V=0.9456551, theta=-43.240241 -> V=1.0, theta=0.0
% INFO    : Bus 32884	: V=0.9452932, theta=-43.267932 -> V=1.0, theta=0.0
% INFO    : Bus 32885	: V=0.9471686, theta=-43.029496 -> V=1.0, theta=0.0
% INFO    : Bus 32886	: V=0.9456584, theta=-42.720167 -> V=1.0, theta=0.0
% INFO    : Bus 32887	: V=0.9462179, theta=-43.215721 -> V=1.0, theta=0.0
% INFO    : Bus 32888	: V=0.9435303, theta=-43.509457 -> V=1.0, theta=0.0
% INFO    : Bus 32889	: V=0.9457846, theta=-43.445789 -> V=1.0, theta=0.0
% INFO    : Bus 32890	: V=0.9447415, theta=-43.495497 -> V=1.0, theta=0.0
% INFO    : Bus 32891	: V=0.9444482, theta=-43.534385 -> V=1.0, theta=0.0
% INFO    : Bus 32892	: V=0.9437427, theta=-43.568214 -> V=1.0, theta=0.0
% INFO    : Bus 32893	: V=0.9441924, theta=-43.478274 -> V=1.0, theta=0.0
% INFO    : Bus 32894	: V=0.9426067, theta=-43.579962 -> V=1.0, theta=0.0
% INFO    : Bus 32895	: V=0.9468341, theta=-42.352702 -> V=1.0, theta=0.0
% INFO    : Bus 32896	: V=0.9506141, theta=-41.692451 -> V=1.0, theta=0.0
% INFO    : Bus 32897	: V=0.9504791, theta=-43.053307 -> V=1.0, theta=0.0
% INFO    : Bus 32898	: V=0.9384317, theta=-44.555185 -> V=1.0, theta=0.0
% INFO    : Bus 32899	: V=0.9395009, theta=-44.451006 -> V=1.0, theta=0.0
% INFO    : Bus 32900	: V=0.9479258, theta=-43.425493 -> V=1.0, theta=0.0
% INFO    : Bus 32901	: V=0.9506597, theta=-43.086677 -> V=1.0, theta=0.0
% INFO    : Bus 32902	: V=0.9499242, theta=-41.882506 -> V=1.0, theta=0.0
% INFO    : Bus 32903	: V=0.9455799, theta=-43.279608 -> V=1.0, theta=0.0
% INFO    : Bus 32904	: V=0.9489598, theta=-43.22822 -> V=1.0, theta=0.0
% INFO    : Bus 32905	: V=0.9491406, theta=-43.367008 -> V=1.0, theta=0.0
% INFO    : Bus 32906	: V=0.9439838, theta=-43.119019 -> V=1.0, theta=0.0
% INFO    : Bus 32907	: V=0.9432599, theta=-43.150989 -> V=1.0, theta=0.0
% INFO    : Bus 32908	: V=0.9423072, theta=-43.498392 -> V=1.0, theta=0.0
% INFO    : Bus 32909	: V=0.9427466, theta=-43.377975 -> V=1.0, theta=0.0
% INFO    : Bus 32910	: V=0.942923, theta=-43.410846 -> V=1.0, theta=0.0
% INFO    : Bus 32911	: V=0.9459008, theta=-42.477407 -> V=1.0, theta=0.0
% INFO    : Bus 32912	: V=0.9385701, theta=-43.260235 -> V=1.0, theta=0.0
% INFO    : Bus 32913	: V=0.9450872, theta=-42.463693 -> V=1.0, theta=0.0
% INFO    : Bus 32914	: V=0.9436623, theta=-43.182551 -> V=1.0, theta=0.0
% INFO    : Bus 32915	: V=0.9470109, theta=-41.286512 -> V=1.0, theta=0.0
% INFO    : Bus 32916	: V=0.9492642, theta=-40.970835 -> V=1.0, theta=0.0
% INFO    : Bus 32917	: V=0.9477727, theta=-42.106731 -> V=1.0, theta=0.0
% INFO    : Bus 32918	: V=0.9453045, theta=-42.490496 -> V=1.0, theta=0.0
% INFO    : Bus 32919	: V=0.9456015, theta=-42.490265 -> V=1.0, theta=0.0
% INFO    : Bus 32920	: V=0.9377853, theta=-44.647447 -> V=1.0, theta=0.0
% INFO    : Bus 32921	: V=0.9384611, theta=-44.614517 -> V=1.0, theta=0.0
% INFO    : Bus 32922	: V=0.9422686, theta=-43.543419 -> V=1.0, theta=0.0
% INFO    : Bus 32923	: V=0.9429862, theta=-43.420367 -> V=1.0, theta=0.0
% INFO    : Bus 32924	: V=0.9426626, theta=-43.486389 -> V=1.0, theta=0.0
% INFO    : Bus 32925	: V=0.9422368, theta=-43.556873 -> V=1.0, theta=0.0
% INFO    : Bus 32926	: V=0.9419945, theta=-43.609911 -> V=1.0, theta=0.0
% INFO    : Bus 32927	: V=0.9451854, theta=-43.027173 -> V=1.0, theta=0.0
% INFO    : Bus 32928	: V=0.9444725, theta=-43.135126 -> V=1.0, theta=0.0
% INFO    : Bus 32929	: V=0.9437379, theta=-43.250779 -> V=1.0, theta=0.0
% INFO    : Bus 32930	: V=0.9464141, theta=-41.996594 -> V=1.0, theta=0.0
% INFO    : Bus 32931	: V=0.947154, theta=-41.701835 -> V=1.0, theta=0.0
% INFO    : Bus 32932	: V=0.947449, theta=-42.220353 -> V=1.0, theta=0.0
% INFO    : Bus 32933	: V=0.945378, theta=-42.312964 -> V=1.0, theta=0.0
% INFO    : Bus 32934	: V=0.9915839, theta=-36.849375 -> V=1.0, theta=0.0
% INFO    : Bus 32935	: V=0.9887942, theta=-37.887003 -> V=1.0, theta=0.0
% INFO    : Bus 32936	: V=0.9868167, theta=-39.097674 -> V=1.0, theta=0.0
% INFO    : Bus 32937	: V=0.9737952, theta=-40.517956 -> V=1.0, theta=0.0
% INFO    : Bus 32938	: V=0.9692993, theta=-40.743366 -> V=1.0, theta=0.0
% INFO    : Bus 32939	: V=0.9879375, theta=-40.659989 -> V=1.0, theta=0.0
% INFO    : Bus 32940	: V=0.9789085, theta=-40.730552 -> V=1.0, theta=0.0
% INFO    : Bus 32941	: V=0.9882064, theta=-42.558453 -> V=1.0, theta=0.0
% INFO    : Bus 32942	: V=0.9795601, theta=-43.433358 -> V=1.0, theta=0.0
% INFO    : Bus 32943	: V=0.9788149, theta=-51.662406 -> V=1.0, theta=0.0
% INFO    : Bus 32944	: V=0.9788008, theta=-51.629503 -> V=1.0, theta=0.0
% INFO    : Bus 32945	: V=0.9751929, theta=-50.316188 -> V=1.0, theta=0.0
% INFO    : Bus 32946	: V=0.9774385, theta=-51.150237 -> V=1.0, theta=0.0
% INFO    : Bus 32947	: V=0.9756327, theta=-50.42272 -> V=1.0, theta=0.0
% INFO    : Bus 32948	: V=0.977959, theta=-51.268153 -> V=1.0, theta=0.0
% INFO    : Bus 32949	: V=0.9780116, theta=-51.274323 -> V=1.0, theta=0.0
% INFO    : Bus 32950	: V=0.9777036, theta=-51.397993 -> V=1.0, theta=0.0
% INFO    : Bus 32951	: V=0.9785596, theta=-51.311901 -> V=1.0, theta=0.0
% INFO    : Bus 32952	: V=0.9759594, theta=-50.486928 -> V=1.0, theta=0.0
% INFO    : Bus 32953	: V=0.9763108, theta=-50.541069 -> V=1.0, theta=0.0
% INFO    : Bus 32954	: V=0.9762884, theta=-51.551586 -> V=1.0, theta=0.0
% INFO    : Bus 32955	: V=0.9771303, theta=-51.509312 -> V=1.0, theta=0.0
% INFO    : Bus 32956	: V=0.9776797, theta=-51.728151 -> V=1.0, theta=0.0
% INFO    : Bus 32957	: V=0.9779642, theta=-51.002754 -> V=1.0, theta=0.0
% INFO    : Bus 32958	: V=0.98001, theta=-51.086624 -> V=1.0, theta=0.0
% INFO    : Bus 32959	: V=0.9687175, theta=-51.561183 -> V=1.0, theta=0.0
% INFO    : Bus 32960	: V=0.9851466, theta=-51.086 -> V=1.0, theta=0.0
% INFO    : Bus 32961	: V=0.9757821, theta=-51.573697 -> V=1.0, theta=0.0
% INFO    : Bus 32962	: V=0.991752, theta=-50.598929 -> V=1.0, theta=0.0
% INFO    : Bus 32963	: V=0.9773333, theta=-50.668187 -> V=1.0, theta=0.0
% INFO    : Bus 32964	: V=0.9778325, theta=-51.937647 -> V=1.0, theta=0.0
% INFO    : Bus 32965	: V=0.9940673, theta=-50.366863 -> V=1.0, theta=0.0
% INFO    : Bus 32966	: V=0.9697815, theta=-52.808644 -> V=1.0, theta=0.0
% INFO    : Bus 32967	: V=0.9769797, theta=-50.447617 -> V=1.0, theta=0.0
% INFO    : Bus 32968	: V=0.9776705, theta=-51.484118 -> V=1.0, theta=0.0
% INFO    : Bus 32969	: V=0.9725006, theta=-50.070462 -> V=1.0, theta=0.0
% INFO    : Bus 32970	: V=0.97658, theta=-33.962207 -> V=1.0, theta=0.0
% INFO    : Bus 32971	: V=0.9744824, theta=-33.933879 -> V=1.0, theta=0.0
% INFO    : Bus 32972	: V=0.9524819, theta=-36.154592 -> V=1.0, theta=0.0
% INFO    : Bus 32973	: V=0.9558759, theta=-36.148433 -> V=1.0, theta=0.0
% INFO    : Bus 32974	: V=0.9616985, theta=-33.814398 -> V=1.0, theta=0.0
% INFO    : Bus 32975	: V=0.9504913, theta=-36.040451 -> V=1.0, theta=0.0
% INFO    : Bus 32976	: V=0.9599833, theta=-33.967213 -> V=1.0, theta=0.0
% INFO    : Bus 32977	: V=0.9758869, theta=-30.591375 -> V=1.0, theta=0.0
% INFO    : Bus 32978	: V=0.9557179, theta=-34.059058 -> V=1.0, theta=0.0
% INFO    : Bus 32979	: V=0.9541518, theta=-34.240315 -> V=1.0, theta=0.0
% INFO    : Bus 32980	: V=0.957459, theta=-33.855317 -> V=1.0, theta=0.0
% INFO    : Bus 32981	: V=0.9688131, theta=-31.331438 -> V=1.0, theta=0.0
% INFO    : Bus 32982	: V=0.9716215, theta=-31.041897 -> V=1.0, theta=0.0
% INFO    : Bus 32983	: V=0.9594912, theta=-34.000425 -> V=1.0, theta=0.0
% INFO    : Bus 32984	: V=0.9534322, theta=-34.439524 -> V=1.0, theta=0.0
% INFO    : Bus 32985	: V=0.9527932, theta=-34.525569 -> V=1.0, theta=0.0
% INFO    : Bus 32986	: V=0.9561684, theta=-35.044456 -> V=1.0, theta=0.0
% INFO    : Bus 32987	: V=0.952027, theta=-37.376833 -> V=1.0, theta=0.0
% INFO    : Bus 32988	: V=0.9477438, theta=-36.170278 -> V=1.0, theta=0.0
% INFO    : Bus 32989	: V=0.9618192, theta=-36.645218 -> V=1.0, theta=0.0
% INFO    : Bus 32990	: V=0.9640885, theta=-48.517615 -> V=1.0, theta=0.0
% INFO    : Bus 32991	: V=0.9834354, theta=-46.715319 -> V=1.0, theta=0.0
% INFO    : Bus 32992	: V=0.993014, theta=-47.535473 -> V=1.0, theta=0.0
% INFO    : Bus 32993	: V=0.9786288, theta=-48.823484 -> V=1.0, theta=0.0
% INFO    : Bus 32994	: V=0.978171, theta=-49.958852 -> V=1.0, theta=0.0
% INFO    : Bus 32995	: V=0.9945611, theta=-53.375819 -> V=1.0, theta=0.0
% INFO    : Bus 32996	: V=0.9946474, theta=-53.985636 -> V=1.0, theta=0.0
% INFO    : Bus 32997	: V=0.9757497, theta=-29.939067 -> V=1.0, theta=0.0
% INFO    : Bus 32998	: V=1.005659, theta=-26.844201 -> V=1.0, theta=0.0
% INFO    : Bus 32999	: V=1.0055969, theta=-27.065458 -> V=1.0, theta=0.0
% INFO    : Bus 33000	: V=0.9854762, theta=-29.443729 -> V=1.0, theta=0.0
% INFO    : Bus 33001	: V=1.0123581, theta=-26.669191 -> V=1.0, theta=0.0
% INFO    : Bus 33002	: V=1.0195572, theta=-25.498384 -> V=1.0, theta=0.0
% INFO    : Bus 33003	: V=1.0199401, theta=-24.986556 -> V=1.0, theta=0.0
% INFO    : Bus 33004	: V=1.0169231, theta=-24.740484 -> V=1.0, theta=0.0
% INFO    : Bus 33005	: V=0.999509, theta=-28.657935 -> V=1.0, theta=0.0
% INFO    : Bus 33006	: V=1.0001057, theta=-29.099565 -> V=1.0, theta=0.0
% INFO    : Bus 33007	: V=1.0123051, theta=-32.556394 -> V=1.0, theta=0.0
% INFO    : Bus 33008	: V=1.0123502, theta=-31.606592 -> V=1.0, theta=0.0
% INFO    : Bus 33009	: V=1.00995, theta=-30.770419 -> V=1.0, theta=0.0
% INFO    : Bus 33010	: V=1.0100295, theta=-31.053902 -> V=1.0, theta=0.0
% INFO    : Bus 33011	: V=1.0094207, theta=-30.514696 -> V=1.0, theta=0.0
% INFO    : Bus 33012	: V=0.9946876, theta=-26.943247 -> V=1.0, theta=0.0
% INFO    : Bus 33013	: V=0.9881863, theta=-27.861113 -> V=1.0, theta=0.0
% INFO    : Bus 33014	: V=0.9888536, theta=-27.862019 -> V=1.0, theta=0.0
% INFO    : Bus 33015	: V=0.9944079, theta=-27.5927 -> V=1.0, theta=0.0
% INFO    : Bus 33016	: V=0.9929946, theta=-28.257049 -> V=1.0, theta=0.0
% INFO    : Bus 33017	: V=1.0242331, theta=-23.264348 -> V=1.0, theta=0.0
% INFO    : Bus 33018	: V=0.9577381, theta=-31.722172 -> V=1.0, theta=0.0
% INFO    : Bus 33019	: V=0.9647627, theta=-31.530674 -> V=1.0, theta=0.0
% INFO    : Bus 33020	: V=0.9589823, theta=-31.769702 -> V=1.0, theta=0.0
% INFO    : Bus 33021	: V=0.9710412, theta=-38.046522 -> V=1.0, theta=0.0
% INFO    : Bus 33022	: V=0.9772989, theta=-37.084334 -> V=1.0, theta=0.0
% INFO    : Bus 33023	: V=0.9789233, theta=-34.441786 -> V=1.0, theta=0.0
% INFO    : Bus 33024	: V=0.9849754, theta=-37.458129 -> V=1.0, theta=0.0
% INFO    : Bus 33025	: V=0.9720805, theta=-38.945254 -> V=1.0, theta=0.0
% INFO    : Bus 33026	: V=0.9595365, theta=-37.349378 -> V=1.0, theta=0.0
% INFO    : Bus 33027	: V=0.9601676, theta=-37.333661 -> V=1.0, theta=0.0
% INFO    : Bus 33028	: V=0.9564416, theta=-36.646395 -> V=1.0, theta=0.0
% INFO    : Bus 33029	: V=0.9546466, theta=-36.964313 -> V=1.0, theta=0.0
% INFO    : Bus 33030	: V=0.9616542, theta=-35.646596 -> V=1.0, theta=0.0
% INFO    : Bus 33031	: V=0.9713735, theta=-34.675339 -> V=1.0, theta=0.0
% INFO    : Bus 33032	: V=0.9731972, theta=-34.358925 -> V=1.0, theta=0.0
% INFO    : Bus 33033	: V=0.971779, theta=-34.844555 -> V=1.0, theta=0.0
% INFO    : Bus 33034	: V=0.9688334, theta=-35.169943 -> V=1.0, theta=0.0
% INFO    : Bus 33035	: V=0.9654019, theta=-35.870562 -> V=1.0, theta=0.0
% INFO    : Bus 33036	: V=0.9567619, theta=-36.734713 -> V=1.0, theta=0.0
% INFO    : Bus 33037	: V=0.9546796, theta=-36.759118 -> V=1.0, theta=0.0
% INFO    : Bus 33038	: V=0.9608005, theta=-36.995305 -> V=1.0, theta=0.0
% INFO    : Bus 33039	: V=0.962495, theta=-36.55407 -> V=1.0, theta=0.0
% INFO    : Bus 33040	: V=0.9575304, theta=-37.9452 -> V=1.0, theta=0.0
% INFO    : Bus 33041	: V=0.946941, theta=-39.128374 -> V=1.0, theta=0.0
% INFO    : Bus 33042	: V=0.9498736, theta=-39.015451 -> V=1.0, theta=0.0
% INFO    : Bus 33043	: V=0.9539568, theta=-38.572552 -> V=1.0, theta=0.0
% INFO    : Bus 33044	: V=0.949598, theta=-37.22016 -> V=1.0, theta=0.0
% INFO    : Bus 33045	: V=0.9454704, theta=-37.34452 -> V=1.0, theta=0.0
% INFO    : Bus 33046	: V=0.9881533, theta=-27.413913 -> V=1.0, theta=0.0
% INFO    : Bus 33047	: V=0.9965637, theta=-26.064111 -> V=1.0, theta=0.0
% INFO    : Bus 33048	: V=0.9684919, theta=-29.765785 -> V=1.0, theta=0.0
% INFO    : Bus 33049	: V=1.0062908, theta=-24.484552 -> V=1.0, theta=0.0
% INFO    : Bus 33050	: V=0.9950455, theta=-25.966135 -> V=1.0, theta=0.0
% INFO    : Bus 33051	: V=0.9978815, theta=-25.712485 -> V=1.0, theta=0.0
% INFO    : Bus 33052	: V=0.9842796, theta=-27.810067 -> V=1.0, theta=0.0
% INFO    : Bus 33053	: V=0.9745352, theta=-29.727506 -> V=1.0, theta=0.0
% INFO    : Bus 33054	: V=0.9812592, theta=-28.305183 -> V=1.0, theta=0.0
% INFO    : Bus 33055	: V=0.9828935, theta=-27.400823 -> V=1.0, theta=0.0
% INFO    : Bus 33056	: V=0.9956485, theta=-26.020107 -> V=1.0, theta=0.0
% INFO    : Bus 33057	: V=0.9897287, theta=-26.203582 -> V=1.0, theta=0.0
% INFO    : Bus 33058	: V=0.9916062, theta=-26.172285 -> V=1.0, theta=0.0
% INFO    : Bus 33059	: V=1.0183163, theta=-23.675987 -> V=1.0, theta=0.0
% INFO    : Bus 33060	: V=0.9947044, theta=-26.175315 -> V=1.0, theta=0.0
% INFO    : Bus 33061	: V=0.9971926, theta=-26.192209 -> V=1.0, theta=0.0
% INFO    : Bus 33062	: V=0.9828362, theta=-27.890723 -> V=1.0, theta=0.0
% INFO    : Bus 33063	: V=0.9945284, theta=-26.292452 -> V=1.0, theta=0.0
% INFO    : Bus 33064	: V=1.0161491, theta=-24.103407 -> V=1.0, theta=0.0
% INFO    : Bus 33065	: V=0.9832256, theta=-27.640043 -> V=1.0, theta=0.0
% INFO    : Bus 33066	: V=0.9549462, theta=-42.540167 -> V=1.0, theta=0.0
% INFO    : Bus 33067	: V=0.9536188, theta=-42.607733 -> V=1.0, theta=0.0
% INFO    : Bus 33068	: V=0.95288, theta=-42.668869 -> V=1.0, theta=0.0
% INFO    : Bus 33069	: V=0.9512515, theta=-43.045011 -> V=1.0, theta=0.0
% INFO    : Bus 33070	: V=0.9538822, theta=-42.560603 -> V=1.0, theta=0.0
% INFO    : Bus 33071	: V=0.9564823, theta=-40.259764 -> V=1.0, theta=0.0
% INFO    : Bus 33072	: V=0.954967, theta=-42.236004 -> V=1.0, theta=0.0
% INFO    : Bus 33073	: V=0.9547594, theta=-40.619765 -> V=1.0, theta=0.0
% INFO    : Bus 33074	: V=0.9530558, theta=-42.154197 -> V=1.0, theta=0.0
% INFO    : Bus 33075	: V=0.9546967, theta=-42.405434 -> V=1.0, theta=0.0
% INFO    : Bus 33076	: V=0.9518231, theta=-40.932316 -> V=1.0, theta=0.0
% INFO    : Bus 33077	: V=0.9531144, theta=-41.418442 -> V=1.0, theta=0.0
% INFO    : Bus 33078	: V=0.9497701, theta=-41.030317 -> V=1.0, theta=0.0
% INFO    : Bus 33079	: V=0.952122, theta=-41.666712 -> V=1.0, theta=0.0
% INFO    : Bus 33080	: V=0.9511408, theta=-42.618289 -> V=1.0, theta=0.0
% INFO    : Bus 33081	: V=0.9489118, theta=-43.108842 -> V=1.0, theta=0.0
% INFO    : Bus 33082	: V=0.95269, theta=-42.646026 -> V=1.0, theta=0.0
% INFO    : Bus 33083	: V=0.9544672, theta=-41.18971 -> V=1.0, theta=0.0
% INFO    : Bus 33084	: V=0.9500405, theta=-42.939621 -> V=1.0, theta=0.0
% INFO    : Bus 33085	: V=0.9527326, theta=-42.66658 -> V=1.0, theta=0.0
% INFO    : Bus 33086	: V=0.9490617, theta=-43.203337 -> V=1.0, theta=0.0
% INFO    : Bus 33087	: V=0.9521931, theta=-42.868069 -> V=1.0, theta=0.0
% INFO    : Bus 33088	: V=0.9541844, theta=-41.488537 -> V=1.0, theta=0.0
% INFO    : Bus 33089	: V=0.9534064, theta=-42.820371 -> V=1.0, theta=0.0
% INFO    : Bus 33090	: V=0.9528847, theta=-42.154271 -> V=1.0, theta=0.0
% INFO    : Bus 33091	: V=0.9557584, theta=-42.459258 -> V=1.0, theta=0.0
% INFO    : Bus 33092	: V=0.953773, theta=-41.937443 -> V=1.0, theta=0.0
% INFO    : Bus 33093	: V=0.954842, theta=-42.475594 -> V=1.0, theta=0.0
% INFO    : Bus 33094	: V=0.960794, theta=-42.10283 -> V=1.0, theta=0.0
% INFO    : Bus 33095	: V=0.9727466, theta=-38.620746 -> V=1.0, theta=0.0
% INFO    : Bus 33096	: V=0.9564961, theta=-42.518903 -> V=1.0, theta=0.0
% INFO    : Bus 33097	: V=0.9566683, theta=-43.007155 -> V=1.0, theta=0.0
% INFO    : Bus 33098	: V=0.951347, theta=-41.877925 -> V=1.0, theta=0.0
% INFO    : Bus 33099	: V=0.9383037, theta=-44.184004 -> V=1.0, theta=0.0
% INFO    : Bus 33100	: V=0.9505339, theta=-42.101923 -> V=1.0, theta=0.0
% INFO    : Bus 33101	: V=0.9472254, theta=-43.743996 -> V=1.0, theta=0.0
% INFO    : Bus 33102	: V=0.9478527, theta=-43.609343 -> V=1.0, theta=0.0
% INFO    : Bus 33103	: V=0.9442499, theta=-44.128704 -> V=1.0, theta=0.0
% INFO    : Bus 33104	: V=0.9540254, theta=-43.17274 -> V=1.0, theta=0.0
% INFO    : Bus 33105	: V=0.9508879, theta=-43.603305 -> V=1.0, theta=0.0
% INFO    : Bus 33106	: V=0.9531806, theta=-43.26305 -> V=1.0, theta=0.0
% INFO    : Bus 33107	: V=0.9514999, theta=-43.517146 -> V=1.0, theta=0.0
% INFO    : Bus 33108	: V=0.9530378, theta=-43.294703 -> V=1.0, theta=0.0
% INFO    : Bus 33109	: V=0.9467153, theta=-43.755418 -> V=1.0, theta=0.0
% INFO    : Bus 33110	: V=0.9481149, theta=-43.608183 -> V=1.0, theta=0.0
% INFO    : Bus 33111	: V=0.9959028, theta=-35.398867 -> V=1.0, theta=0.0
% INFO    : Bus 33112	: V=0.9960779, theta=-35.522929 -> V=1.0, theta=0.0
% INFO    : Bus 33113	: V=0.9722603, theta=-38.1526 -> V=1.0, theta=0.0
% INFO    : Bus 33114	: V=0.9963189, theta=-35.115505 -> V=1.0, theta=0.0
% INFO    : Bus 33115	: V=0.9984308, theta=-34.813608 -> V=1.0, theta=0.0
% INFO    : Bus 33116	: V=0.9488135, theta=-42.328106 -> V=1.0, theta=0.0
% INFO    : Bus 33117	: V=0.9501884, theta=-41.833293 -> V=1.0, theta=0.0
% INFO    : Bus 33118	: V=0.9504058, theta=-41.806612 -> V=1.0, theta=0.0
% INFO    : Bus 33119	: V=0.9507871, theta=-42.308865 -> V=1.0, theta=0.0
% INFO    : Bus 33120	: V=0.9517553, theta=-41.63102 -> V=1.0, theta=0.0
% INFO    : Bus 33121	: V=0.9572548, theta=-39.657764 -> V=1.0, theta=0.0
% INFO    : Bus 33122	: V=0.9509905, theta=-41.864739 -> V=1.0, theta=0.0
% INFO    : Bus 33123	: V=0.9509761, theta=-41.719085 -> V=1.0, theta=0.0
% INFO    : Bus 33124	: V=0.9505269, theta=-41.792873 -> V=1.0, theta=0.0
% INFO    : Bus 33125	: V=0.9504207, theta=-42.012312 -> V=1.0, theta=0.0
% INFO    : Bus 33126	: V=0.9507017, theta=-41.767272 -> V=1.0, theta=0.0
% INFO    : Bus 33127	: V=0.9498162, theta=-42.125146 -> V=1.0, theta=0.0
% INFO    : Bus 33128	: V=0.9495804, theta=-42.153934 -> V=1.0, theta=0.0
% INFO    : Bus 33129	: V=0.9502278, theta=-41.251383 -> V=1.0, theta=0.0
% INFO    : Bus 33130	: V=0.9504985, theta=-41.129378 -> V=1.0, theta=0.0
% INFO    : Bus 33131	: V=0.9509124, theta=-40.97071 -> V=1.0, theta=0.0
% INFO    : Bus 33132	: V=0.9479891, theta=-42.275912 -> V=1.0, theta=0.0
% INFO    : Bus 33133	: V=0.9487808, theta=-42.238375 -> V=1.0, theta=0.0
% INFO    : Bus 33134	: V=0.9482205, theta=-42.26494 -> V=1.0, theta=0.0
% INFO    : Bus 33135	: V=0.9514741, theta=-41.620341 -> V=1.0, theta=0.0
% INFO    : Bus 33136	: V=0.9517197, theta=-41.577966 -> V=1.0, theta=0.0
% INFO    : Bus 33137	: V=0.9519091, theta=-41.444795 -> V=1.0, theta=0.0
% INFO    : Bus 33138	: V=0.9516688, theta=-41.455334 -> V=1.0, theta=0.0
% INFO    : Bus 33139	: V=0.9484779, theta=-41.95792 -> V=1.0, theta=0.0
% INFO    : Bus 33140	: V=0.9484034, theta=-42.028222 -> V=1.0, theta=0.0
% INFO    : Bus 33141	: V=0.9486307, theta=-42.097837 -> V=1.0, theta=0.0
% INFO    : Bus 33142	: V=0.9471502, theta=-41.189498 -> V=1.0, theta=0.0
% INFO    : Bus 33143	: V=0.9473319, theta=-41.143897 -> V=1.0, theta=0.0
% INFO    : Bus 33144	: V=0.9490183, theta=-41.726073 -> V=1.0, theta=0.0
% INFO    : Bus 33145	: V=0.949777, theta=-41.46232 -> V=1.0, theta=0.0
% INFO    : Bus 33146	: V=0.9524006, theta=-40.32032 -> V=1.0, theta=0.0
% INFO    : Bus 33147	: V=0.9518751, theta=-41.413859 -> V=1.0, theta=0.0
% INFO    : Bus 33148	: V=0.9529794, theta=-40.635654 -> V=1.0, theta=0.0
% INFO    : Bus 33149	: V=0.9519771, theta=-40.746108 -> V=1.0, theta=0.0
% INFO    : Bus 33150	: V=0.9513242, theta=-40.93077 -> V=1.0, theta=0.0
% INFO    : Bus 33151	: V=0.9525406, theta=-40.290497 -> V=1.0, theta=0.0
% INFO    : Bus 33152	: V=0.9492933, theta=-41.437182 -> V=1.0, theta=0.0
% INFO    : Bus 33153	: V=0.9520018, theta=-40.490358 -> V=1.0, theta=0.0
% INFO    : Bus 33154	: V=0.9519404, theta=-40.536841 -> V=1.0, theta=0.0
% INFO    : Bus 33155	: V=0.9475104, theta=-41.102629 -> V=1.0, theta=0.0
% INFO    : Bus 33156	: V=0.9472462, theta=-42.075351 -> V=1.0, theta=0.0
% INFO    : Bus 33157	: V=0.9477781, theta=-41.000795 -> V=1.0, theta=0.0
% INFO    : Bus 33158	: V=0.9497147, theta=-41.438343 -> V=1.0, theta=0.0
% INFO    : Bus 33159	: V=0.949315, theta=-41.470911 -> V=1.0, theta=0.0
% INFO    : Bus 33160	: V=0.9527042, theta=-40.268526 -> V=1.0, theta=0.0
% INFO    : Bus 33161	: V=0.9530564, theta=-40.192729 -> V=1.0, theta=0.0
% INFO    : Bus 33162	: V=0.9528397, theta=-40.523146 -> V=1.0, theta=0.0
% INFO    : Bus 33163	: V=0.9547781, theta=-39.673603 -> V=1.0, theta=0.0
% INFO    : Bus 33164	: V=0.9537862, theta=-39.973185 -> V=1.0, theta=0.0
% INFO    : Bus 33165	: V=0.9523805, theta=-40.217485 -> V=1.0, theta=0.0
% INFO    : Bus 33166	: V=0.9481984, theta=-40.859094 -> V=1.0, theta=0.0
% INFO    : Bus 33167	: V=0.9527515, theta=-40.040169 -> V=1.0, theta=0.0
% INFO    : Bus 33168	: V=0.9532113, theta=-39.877719 -> V=1.0, theta=0.0
% INFO    : Bus 33169	: V=0.9532761, theta=-40.423269 -> V=1.0, theta=0.0
% INFO    : Bus 33170	: V=0.9485863, theta=-40.730771 -> V=1.0, theta=0.0
% INFO    : Bus 33171	: V=0.9488946, theta=-41.500038 -> V=1.0, theta=0.0
% INFO    : Bus 33172	: V=0.9487628, theta=-41.507875 -> V=1.0, theta=0.0
% INFO    : Bus 33173	: V=0.9484005, theta=-41.86677 -> V=1.0, theta=0.0
% INFO    : Bus 33174	: V=0.9491342, theta=-40.398419 -> V=1.0, theta=0.0
% INFO    : Bus 33175	: V=0.9484686, theta=-41.201087 -> V=1.0, theta=0.0
% INFO    : Bus 33176	: V=0.9480826, theta=-41.37261 -> V=1.0, theta=0.0
% INFO    : Bus 33177	: V=0.9450303, theta=-43.770969 -> V=1.0, theta=0.0
% INFO    : Bus 33178	: V=0.9494599, theta=-40.798804 -> V=1.0, theta=0.0
% INFO    : Bus 33179	: V=0.9501508, theta=-40.049864 -> V=1.0, theta=0.0
% INFO    : Bus 33180	: V=0.948278, theta=-40.487592 -> V=1.0, theta=0.0
% INFO    : Bus 33181	: V=0.9578267, theta=-38.815659 -> V=1.0, theta=0.0
% INFO    : Bus 33182	: V=0.9539837, theta=-39.594732 -> V=1.0, theta=0.0
% INFO    : Bus 33183	: V=0.9524155, theta=-39.759197 -> V=1.0, theta=0.0
% INFO    : Bus 33184	: V=0.9620369, theta=-37.874179 -> V=1.0, theta=0.0
% INFO    : Bus 33185	: V=0.9607874, theta=-38.136384 -> V=1.0, theta=0.0
% INFO    : Bus 33186	: V=0.9559977, theta=-38.460347 -> V=1.0, theta=0.0
% INFO    : Bus 33187	: V=0.9577075, theta=-38.135642 -> V=1.0, theta=0.0
% INFO    : Bus 33188	: V=0.9639447, theta=-37.516003 -> V=1.0, theta=0.0
% INFO    : Bus 33189	: V=0.9770434, theta=-34.952391 -> V=1.0, theta=0.0
% INFO    : Bus 33190	: V=0.9629762, theta=-38.380376 -> V=1.0, theta=0.0
% INFO    : Bus 33191	: V=0.9611545, theta=-38.815122 -> V=1.0, theta=0.0
% INFO    : Bus 33192	: V=0.961934, theta=-38.614729 -> V=1.0, theta=0.0
% INFO    : Bus 33193	: V=0.9567857, theta=-39.459411 -> V=1.0, theta=0.0
% INFO    : Bus 33194	: V=0.9562699, theta=-39.235269 -> V=1.0, theta=0.0
% INFO    : Bus 33195	: V=0.9537105, theta=-40.260116 -> V=1.0, theta=0.0
% INFO    : Bus 33196	: V=0.9564874, theta=-39.815881 -> V=1.0, theta=0.0
% INFO    : Bus 33197	: V=0.9601837, theta=-39.082091 -> V=1.0, theta=0.0
% INFO    : Bus 33198	: V=0.9775995, theta=-35.549422 -> V=1.0, theta=0.0
% INFO    : Bus 33199	: V=0.9545128, theta=-40.295221 -> V=1.0, theta=0.0
% INFO    : Bus 33200	: V=0.9541963, theta=-40.336909 -> V=1.0, theta=0.0
% INFO    : Bus 33201	: V=0.9519841, theta=-41.543255 -> V=1.0, theta=0.0
% INFO    : Bus 33202	: V=0.9581386, theta=-39.527807 -> V=1.0, theta=0.0
% INFO    : Bus 33203	: V=0.9590769, theta=-39.38755 -> V=1.0, theta=0.0
% INFO    : Bus 33204	: V=0.9783612, theta=-35.804322 -> V=1.0, theta=0.0
% INFO    : Bus 33205	: V=0.9592408, theta=-39.453596 -> V=1.0, theta=0.0
% INFO    : Bus 33206	: V=0.9599724, theta=-39.468545 -> V=1.0, theta=0.0
% INFO    : Bus 33207	: V=0.9547145, theta=-40.536049 -> V=1.0, theta=0.0
% INFO    : Bus 33208	: V=0.9512946, theta=-41.333794 -> V=1.0, theta=0.0
% INFO    : Bus 33209	: V=0.9581052, theta=-39.834327 -> V=1.0, theta=0.0
% INFO    : Bus 33210	: V=0.9547038, theta=-40.525529 -> V=1.0, theta=0.0
% INFO    : Bus 33211	: V=0.9533299, theta=-40.768833 -> V=1.0, theta=0.0
% INFO    : Bus 33212	: V=0.9528771, theta=-40.859571 -> V=1.0, theta=0.0
% INFO    : Bus 33213	: V=0.9491978, theta=-42.512271 -> V=1.0, theta=0.0
% INFO    : Bus 33214	: V=0.9523033, theta=-40.957004 -> V=1.0, theta=0.0
% INFO    : Bus 33215	: V=0.9518204, theta=-41.04036 -> V=1.0, theta=0.0
% INFO    : Bus 33216	: V=0.9495491, theta=-42.480433 -> V=1.0, theta=0.0
% INFO    : Bus 33217	: V=0.9495432, theta=-42.485595 -> V=1.0, theta=0.0
% INFO    : Bus 33218	: V=0.9548762, theta=-40.496452 -> V=1.0, theta=0.0
% INFO    : Bus 33219	: V=0.955141, theta=-40.463271 -> V=1.0, theta=0.0
% INFO    : Bus 33220	: V=0.9549015, theta=-40.542693 -> V=1.0, theta=0.0
% INFO    : Bus 33221	: V=0.9499805, theta=-42.396136 -> V=1.0, theta=0.0
% INFO    : Bus 33222	: V=0.9505307, theta=-42.295235 -> V=1.0, theta=0.0
% INFO    : Bus 33223	: V=0.9612682, theta=-39.422401 -> V=1.0, theta=0.0
% INFO    : Bus 33224	: V=0.9566776, theta=-40.122775 -> V=1.0, theta=0.0
% INFO    : Bus 33225	: V=0.9596004, theta=-39.70348 -> V=1.0, theta=0.0
% INFO    : Bus 33226	: V=0.9507244, theta=-41.779819 -> V=1.0, theta=0.0
% INFO    : Bus 33227	: V=0.9496361, theta=-42.050054 -> V=1.0, theta=0.0
% INFO    : Bus 33228	: V=0.9492809, theta=-42.184575 -> V=1.0, theta=0.0
% INFO    : Bus 33229	: V=0.9460215, theta=-42.732436 -> V=1.0, theta=0.0
% INFO    : Bus 33230	: V=0.9539549, theta=-41.525126 -> V=1.0, theta=0.0
% INFO    : Bus 33231	: V=0.9545212, theta=-41.500518 -> V=1.0, theta=0.0
% INFO    : Bus 33232	: V=0.9508596, theta=-42.076412 -> V=1.0, theta=0.0
% INFO    : Bus 33233	: V=0.954585, theta=-41.084266 -> V=1.0, theta=0.0
% INFO    : Bus 33234	: V=0.9489589, theta=-42.315076 -> V=1.0, theta=0.0
% INFO    : Bus 33235	: V=0.9502195, theta=-42.265856 -> V=1.0, theta=0.0
% INFO    : Bus 33236	: V=0.9500197, theta=-42.263097 -> V=1.0, theta=0.0
% INFO    : Bus 33237	: V=0.9456969, theta=-42.748539 -> V=1.0, theta=0.0
% INFO    : Bus 33238	: V=0.9471163, theta=-42.680235 -> V=1.0, theta=0.0
% INFO    : Bus 33239	: V=0.9467032, theta=-42.698128 -> V=1.0, theta=0.0
% INFO    : Bus 33240	: V=0.9516193, theta=-41.856481 -> V=1.0, theta=0.0
% INFO    : Bus 33241	: V=0.9510956, theta=-42.234644 -> V=1.0, theta=0.0
% INFO    : Bus 33242	: V=0.9518597, theta=-42.143281 -> V=1.0, theta=0.0
% INFO    : Bus 33243	: V=0.9508807, theta=-41.028743 -> V=1.0, theta=0.0
% INFO    : Bus 33244	: V=0.9555301, theta=-40.266585 -> V=1.0, theta=0.0
% INFO    : Bus 33245	: V=0.9489382, theta=-41.204143 -> V=1.0, theta=0.0
% INFO    : Bus 33246	: V=0.9478122, theta=-42.564765 -> V=1.0, theta=0.0
% INFO    : Bus 33247	: V=0.9490257, theta=-42.413465 -> V=1.0, theta=0.0
% INFO    : Bus 33248	: V=0.952157, theta=-40.161867 -> V=1.0, theta=0.0
% INFO    : Bus 33249	: V=0.9578019, theta=-39.957565 -> V=1.0, theta=0.0
% INFO    : Bus 33250	: V=0.9567465, theta=-40.122534 -> V=1.0, theta=0.0
% INFO    : Bus 33251	: V=0.9585714, theta=-35.397336 -> V=1.0, theta=0.0
% INFO    : Bus 33252	: V=0.9943963, theta=-30.512468 -> V=1.0, theta=0.0
% INFO    : Bus 33253	: V=0.9627973, theta=-37.235418 -> V=1.0, theta=0.0
% INFO    : Bus 33254	: V=0.9922543, theta=-31.008553 -> V=1.0, theta=0.0
% INFO    : Bus 33255	: V=0.9591348, theta=-37.856981 -> V=1.0, theta=0.0
% INFO    : Bus 33256	: V=0.9544942, theta=-38.548237 -> V=1.0, theta=0.0
% INFO    : Bus 33257	: V=1.0003136, theta=-30.197962 -> V=1.0, theta=0.0
% INFO    : Bus 33258	: V=0.9616059, theta=-37.436197 -> V=1.0, theta=0.0
% INFO    : Bus 33259	: V=0.9656409, theta=-36.755062 -> V=1.0, theta=0.0
% INFO    : Bus 33260	: V=0.9635629, theta=-36.90487 -> V=1.0, theta=0.0
% INFO    : Bus 33261	: V=0.9585128, theta=-36.212875 -> V=1.0, theta=0.0
% INFO    : Bus 33262	: V=0.9571528, theta=-37.396704 -> V=1.0, theta=0.0
% INFO    : Bus 33263	: V=0.961274, theta=-37.536956 -> V=1.0, theta=0.0
% INFO    : Bus 33264	: V=0.9534702, theta=-39.086315 -> V=1.0, theta=0.0
% INFO    : Bus 33265	: V=0.9562188, theta=-38.408613 -> V=1.0, theta=0.0
% INFO    : Bus 33266	: V=0.9572626, theta=-38.220155 -> V=1.0, theta=0.0
% INFO    : Bus 33267	: V=0.9455124, theta=-40.511032 -> V=1.0, theta=0.0
% INFO    : Bus 33268	: V=0.9510793, theta=-39.744008 -> V=1.0, theta=0.0
% INFO    : Bus 33269	: V=0.9542603, theta=-39.389613 -> V=1.0, theta=0.0
% INFO    : Bus 33270	: V=0.9549476, theta=-39.329778 -> V=1.0, theta=0.0
% INFO    : Bus 33271	: V=0.9495053, theta=-40.030752 -> V=1.0, theta=0.0
% INFO    : Bus 33272	: V=0.9509533, theta=-39.886719 -> V=1.0, theta=0.0
% INFO    : Bus 33273	: V=0.9553954, theta=-38.597661 -> V=1.0, theta=0.0
% INFO    : Bus 33274	: V=0.9574425, theta=-38.196406 -> V=1.0, theta=0.0
% INFO    : Bus 33275	: V=0.9586659, theta=-37.963493 -> V=1.0, theta=0.0
% INFO    : Bus 33276	: V=0.9468206, theta=-42.905655 -> V=1.0, theta=0.0
% INFO    : Bus 33277	: V=0.9472216, theta=-43.183019 -> V=1.0, theta=0.0
% INFO    : Bus 33278	: V=0.9463225, theta=-43.192951 -> V=1.0, theta=0.0
% INFO    : Bus 33279	: V=0.9456111, theta=-43.437041 -> V=1.0, theta=0.0
% INFO    : Bus 33280	: V=0.945292, theta=-43.467335 -> V=1.0, theta=0.0
% INFO    : Bus 33281	: V=0.9450404, theta=-43.218667 -> V=1.0, theta=0.0
% INFO    : Bus 33282	: V=0.9458133, theta=-43.043461 -> V=1.0, theta=0.0
% INFO    : Bus 33283	: V=0.9451619, theta=-42.931333 -> V=1.0, theta=0.0
% INFO    : Bus 33284	: V=0.9467357, theta=-42.855721 -> V=1.0, theta=0.0
% INFO    : Bus 33285	: V=0.9441687, theta=-43.369543 -> V=1.0, theta=0.0
% INFO    : Bus 33286	: V=0.9452801, theta=-43.313924 -> V=1.0, theta=0.0
% INFO    : Bus 33287	: V=0.9496317, theta=-40.637491 -> V=1.0, theta=0.0
% INFO    : Bus 33288	: V=0.950186, theta=-40.525704 -> V=1.0, theta=0.0
% INFO    : Bus 33289	: V=0.9457304, theta=-43.41423 -> V=1.0, theta=0.0
% INFO    : Bus 33290	: V=0.9524409, theta=-42.730637 -> V=1.0, theta=0.0
% INFO    : Bus 33291	: V=0.9468005, theta=-43.409116 -> V=1.0, theta=0.0
% INFO    : Bus 33292	: V=0.9457128, theta=-43.561034 -> V=1.0, theta=0.0
% INFO    : Bus 33293	: V=0.9468181, theta=-42.771028 -> V=1.0, theta=0.0
% INFO    : Bus 33294	: V=0.9426342, theta=-43.232106 -> V=1.0, theta=0.0
% INFO    : Bus 33295	: V=0.9465661, theta=-41.835234 -> V=1.0, theta=0.0
% INFO    : Bus 33296	: V=0.9481752, theta=-41.764185 -> V=1.0, theta=0.0
% INFO    : Bus 33297	: V=0.9421967, theta=-43.657244 -> V=1.0, theta=0.0
% INFO    : Bus 33298	: V=0.9505635, theta=-41.285133 -> V=1.0, theta=0.0
% INFO    : Bus 33299	: V=0.9537235, theta=-42.280261 -> V=1.0, theta=0.0
% INFO    : Bus 33300	: V=0.9481759, theta=-43.227751 -> V=1.0, theta=0.0
% INFO    : Bus 33301	: V=0.9398431, theta=-43.997854 -> V=1.0, theta=0.0
% INFO    : Bus 33302	: V=0.9397986, theta=-43.848022 -> V=1.0, theta=0.0
% INFO    : Bus 33303	: V=0.9404481, theta=-43.926673 -> V=1.0, theta=0.0
% INFO    : Bus 33304	: V=0.9449146, theta=-43.665126 -> V=1.0, theta=0.0
% INFO    : Bus 33305	: V=0.9448668, theta=-43.699203 -> V=1.0, theta=0.0
% INFO    : Bus 33306	: V=0.9451888, theta=-43.744025 -> V=1.0, theta=0.0
% INFO    : Bus 33307	: V=0.9482695, theta=-43.563857 -> V=1.0, theta=0.0
% INFO    : Bus 33308	: V=0.946411, theta=-43.689983 -> V=1.0, theta=0.0
% INFO    : Bus 33309	: V=0.9510933, theta=-43.564467 -> V=1.0, theta=0.0
% INFO    : Bus 33310	: V=0.9465622, theta=-43.726799 -> V=1.0, theta=0.0
% INFO    : Bus 33311	: V=0.9443647, theta=-44.104919 -> V=1.0, theta=0.0
% INFO    : Bus 33312	: V=0.9472859, theta=-43.519811 -> V=1.0, theta=0.0
% INFO    : Bus 33313	: V=0.9447871, theta=-44.041276 -> V=1.0, theta=0.0
% INFO    : Bus 33314	: V=0.9511858, theta=-41.665893 -> V=1.0, theta=0.0
% INFO    : Bus 33315	: V=0.951842, theta=-40.653297 -> V=1.0, theta=0.0
% INFO    : Bus 33316	: V=0.9521939, theta=-40.399218 -> V=1.0, theta=0.0
% INFO    : Bus 33317	: V=0.9522144, theta=-39.419335 -> V=1.0, theta=0.0
% INFO    : Bus 33318	: V=0.9478964, theta=-40.255162 -> V=1.0, theta=0.0
% INFO    : Bus 33319	: V=0.9783755, theta=-35.718706 -> V=1.0, theta=0.0
% INFO    : Bus 33320	: V=0.9787129, theta=-33.101491 -> V=1.0, theta=0.0
% INFO    : Bus 33321	: V=0.9945564, theta=-30.42355 -> V=1.0, theta=0.0
% INFO    : Bus 33322	: V=0.9982857, theta=-29.365738 -> V=1.0, theta=0.0
% INFO    : Bus 33323	: V=0.9816737, theta=-33.04703 -> V=1.0, theta=0.0
% INFO    : Bus 33324	: V=1.0137998, theta=-24.202035 -> V=1.0, theta=0.0
% INFO    : Bus 33325	: V=0.9663869, theta=-41.908633 -> V=1.0, theta=0.0
% INFO    : Bus 33326	: V=0.9672144, theta=-41.893475 -> V=1.0, theta=0.0
% INFO    : Bus 33327	: V=0.9700548, theta=-41.843656 -> V=1.0, theta=0.0
% INFO    : Bus 33328	: V=0.9802493, theta=-41.305503 -> V=1.0, theta=0.0
% INFO    : Bus 33329	: V=0.9942911, theta=-40.671905 -> V=1.0, theta=0.0
% INFO    : Bus 33330	: V=1.0042796, theta=-38.472622 -> V=1.0, theta=0.0
% INFO    : Bus 33331	: V=1.0149092, theta=-38.126463 -> V=1.0, theta=0.0
% INFO    : Bus 33332	: V=1.0133425, theta=-39.591433 -> V=1.0, theta=0.0
% INFO    : Bus 33333	: V=1.0086495, theta=-38.938881 -> V=1.0, theta=0.0
% INFO    : Bus 33334	: V=1.0039014, theta=-39.650742 -> V=1.0, theta=0.0
% INFO    : Bus 33335	: V=1.0192447, theta=-38.975379 -> V=1.0, theta=0.0
% INFO    : Bus 33336	: V=1.0153431, theta=-39.32534 -> V=1.0, theta=0.0
% INFO    : Bus 33337	: V=1.0126917, theta=-39.18051 -> V=1.0, theta=0.0
% INFO    : Bus 33338	: V=1.0109004, theta=-39.875749 -> V=1.0, theta=0.0
% INFO    : Bus 33339	: V=1.0181475, theta=-39.176862 -> V=1.0, theta=0.0
% INFO    : Bus 33340	: V=1.0032991, theta=-27.794007 -> V=1.0, theta=0.0
% INFO    : Bus 33341	: V=0.964875, theta=-31.415071 -> V=1.0, theta=0.0
% INFO    : Bus 33342	: V=0.9842374, theta=-28.502739 -> V=1.0, theta=0.0
% INFO    : Bus 33343	: V=0.9583274, theta=-31.674363 -> V=1.0, theta=0.0
% INFO    : Bus 33344	: V=0.9636702, theta=-31.581813 -> V=1.0, theta=0.0
% INFO    : Bus 33345	: V=0.9770143, theta=-29.436727 -> V=1.0, theta=0.0
% INFO    : Bus 33346	: V=0.9596081, theta=-31.281842 -> V=1.0, theta=0.0
% INFO    : Bus 33347	: V=0.9529189, theta=-31.969599 -> V=1.0, theta=0.0
% INFO    : Bus 33348	: V=0.968244, theta=-32.850994 -> V=1.0, theta=0.0
% INFO    : Bus 33349	: V=0.9634993, theta=-53.941203 -> V=1.0, theta=0.0
% INFO    : Bus 33350	: V=0.9543588, theta=-54.397386 -> V=1.0, theta=0.0
% INFO    : Bus 33351	: V=0.9587348, theta=-54.184498 -> V=1.0, theta=0.0
% INFO    : Bus 33352	: V=0.9652069, theta=-53.78757 -> V=1.0, theta=0.0
% INFO    : Bus 33353	: V=0.9648047, theta=-52.464915 -> V=1.0, theta=0.0
% INFO    : Bus 33354	: V=0.971523, theta=-51.701615 -> V=1.0, theta=0.0
% INFO    : Bus 33355	: V=0.9996359, theta=-30.773806 -> V=1.0, theta=0.0
% INFO    : Bus 33356	: V=1.0161626, theta=-27.392396 -> V=1.0, theta=0.0
% INFO    : Bus 33357	: V=1.0109788, theta=-26.563951 -> V=1.0, theta=0.0
% INFO    : Bus 33358	: V=1.0088106, theta=-27.057688 -> V=1.0, theta=0.0
% INFO    : Bus 33359	: V=1.0072174, theta=-27.534596 -> V=1.0, theta=0.0
% INFO    : Bus 33360	: V=1.0169542, theta=-26.643483 -> V=1.0, theta=0.0
% INFO    : Bus 33361	: V=1.0183288, theta=-25.789551 -> V=1.0, theta=0.0
% INFO    : Bus 33362	: V=0.9601167, theta=-42.312771 -> V=1.0, theta=0.0
% INFO    : Bus 33363	: V=0.9531876, theta=-42.790191 -> V=1.0, theta=0.0
% INFO    : Bus 33364	: V=0.952715, theta=-42.850831 -> V=1.0, theta=0.0
% INFO    : Bus 33365	: V=0.9608583, theta=-42.160279 -> V=1.0, theta=0.0
% INFO    : Bus 33366	: V=0.9548092, theta=-43.095978 -> V=1.0, theta=0.0
% INFO    : Bus 33367	: V=0.9496601, theta=-44.31618 -> V=1.0, theta=0.0
% INFO    : Bus 33368	: V=0.9516261, theta=-43.372721 -> V=1.0, theta=0.0
% INFO    : Bus 33369	: V=0.9518496, theta=-44.34442 -> V=1.0, theta=0.0
% INFO    : Bus 33370	: V=0.9515626, theta=-43.552123 -> V=1.0, theta=0.0
% INFO    : Bus 33371	: V=0.952848, theta=-42.644415 -> V=1.0, theta=0.0
% INFO    : Bus 33372	: V=0.9519776, theta=-43.497273 -> V=1.0, theta=0.0
% INFO    : Bus 33373	: V=0.9519296, theta=-43.741757 -> V=1.0, theta=0.0
% INFO    : Bus 33374	: V=0.9524998, theta=-42.833387 -> V=1.0, theta=0.0
% INFO    : Bus 33375	: V=0.9491372, theta=-43.719872 -> V=1.0, theta=0.0
% INFO    : Bus 33376	: V=0.9524841, theta=-42.323702 -> V=1.0, theta=0.0
% INFO    : Bus 33377	: V=0.9502961, theta=-44.11633 -> V=1.0, theta=0.0
% INFO    : Bus 33378	: V=0.9504651, theta=-44.038004 -> V=1.0, theta=0.0
% INFO    : Bus 33379	: V=0.951916, theta=-43.498761 -> V=1.0, theta=0.0
% INFO    : Bus 33380	: V=0.952508, theta=-43.412795 -> V=1.0, theta=0.0
% INFO    : Bus 33381	: V=0.9560393, theta=-41.435549 -> V=1.0, theta=0.0
% INFO    : Bus 33382	: V=0.9585681, theta=-40.085823 -> V=1.0, theta=0.0
% INFO    : Bus 33383	: V=0.9838597, theta=-32.634301 -> V=1.0, theta=0.0
% INFO    : Bus 33384	: V=0.9555327, theta=-42.193874 -> V=1.0, theta=0.0
% INFO    : Bus 33385	: V=0.96324, theta=-38.250948 -> V=1.0, theta=0.0
% INFO    : Bus 33386	: V=0.9546451, theta=-42.784841 -> V=1.0, theta=0.0
% INFO    : Bus 33387	: V=0.9552958, theta=-42.288259 -> V=1.0, theta=0.0
% INFO    : Bus 33388	: V=0.9540018, theta=-43.049528 -> V=1.0, theta=0.0
% INFO    : Bus 33389	: V=0.952985, theta=-43.309243 -> V=1.0, theta=0.0
% INFO    : Bus 33390	: V=0.952276, theta=-43.150148 -> V=1.0, theta=0.0
% INFO    : Bus 33391	: V=0.9535208, theta=-43.090627 -> V=1.0, theta=0.0
% INFO    : Bus 33392	: V=0.9540036, theta=-42.991221 -> V=1.0, theta=0.0
% INFO    : Bus 33393	: V=0.9566911, theta=-41.36994 -> V=1.0, theta=0.0
% INFO    : Bus 33394	: V=0.955956, theta=-42.408282 -> V=1.0, theta=0.0
% INFO    : Bus 33395	: V=0.9547999, theta=-42.630191 -> V=1.0, theta=0.0
% INFO    : Bus 33396	: V=0.9550944, theta=-42.440546 -> V=1.0, theta=0.0
% INFO    : Bus 33397	: V=0.9544518, theta=-41.807904 -> V=1.0, theta=0.0
% INFO    : Bus 33398	: V=0.9504945, theta=-43.158308 -> V=1.0, theta=0.0
% INFO    : Bus 33399	: V=0.9494809, theta=-43.321334 -> V=1.0, theta=0.0
% INFO    : Bus 33400	: V=0.9568878, theta=-41.306608 -> V=1.0, theta=0.0
% INFO    : Bus 33401	: V=0.9553388, theta=-42.274939 -> V=1.0, theta=0.0
% INFO    : Bus 33402	: V=0.955684, theta=-41.582236 -> V=1.0, theta=0.0
% INFO    : Bus 33403	: V=0.9540021, theta=-42.927537 -> V=1.0, theta=0.0
% INFO    : Bus 33404	: V=0.9525873, theta=-43.013057 -> V=1.0, theta=0.0
% INFO    : Bus 33405	: V=0.9547178, theta=-41.762002 -> V=1.0, theta=0.0
% INFO    : Bus 33406	: V=0.9522451, theta=-43.454038 -> V=1.0, theta=0.0
% INFO    : Bus 33407	: V=0.9522008, theta=-43.049069 -> V=1.0, theta=0.0
% INFO    : Bus 33408	: V=0.9537705, theta=-42.708402 -> V=1.0, theta=0.0
% INFO    : Bus 33409	: V=0.9493445, theta=-43.399582 -> V=1.0, theta=0.0
% INFO    : Bus 33410	: V=0.9508313, theta=-43.328362 -> V=1.0, theta=0.0
% INFO    : Bus 33411	: V=0.9502051, theta=-43.386565 -> V=1.0, theta=0.0
% INFO    : Bus 33412	: V=0.951907, theta=-43.02547 -> V=1.0, theta=0.0
% INFO    : Bus 33413	: V=0.9560698, theta=-41.507507 -> V=1.0, theta=0.0
% INFO    : Bus 33414	: V=0.9562608, theta=-41.471384 -> V=1.0, theta=0.0
% INFO    : Bus 33415	: V=0.955733, theta=-42.233977 -> V=1.0, theta=0.0
% INFO    : Bus 33416	: V=0.9565677, theta=-41.403709 -> V=1.0, theta=0.0
% INFO    : Bus 33417	: V=0.9511302, theta=-43.612121 -> V=1.0, theta=0.0
% INFO    : Bus 33418	: V=0.9500221, theta=-43.914829 -> V=1.0, theta=0.0
% INFO    : Bus 33419	: V=0.9511625, theta=-42.615864 -> V=1.0, theta=0.0
% INFO    : Bus 33420	: V=0.9478748, theta=-44.293094 -> V=1.0, theta=0.0
% INFO    : Bus 33421	: V=0.9483835, theta=-44.159702 -> V=1.0, theta=0.0
% INFO    : Bus 33422	: V=0.9503737, theta=-43.883874 -> V=1.0, theta=0.0
% INFO    : Bus 33423	: V=0.9508261, theta=-43.97646 -> V=1.0, theta=0.0
% INFO    : Bus 33424	: V=0.9505619, theta=-43.885477 -> V=1.0, theta=0.0
% INFO    : Bus 33425	: V=0.9508778, theta=-44.440569 -> V=1.0, theta=0.0
% INFO    : Bus 33426	: V=0.9511678, theta=-43.750933 -> V=1.0, theta=0.0
% INFO    : Bus 33427	: V=0.9523515, theta=-44.362094 -> V=1.0, theta=0.0
% INFO    : Bus 33428	: V=0.9520681, theta=-44.361782 -> V=1.0, theta=0.0
% INFO    : Bus 33429	: V=0.9496172, theta=-44.531233 -> V=1.0, theta=0.0
% INFO    : Bus 33430	: V=0.949542, theta=-44.476211 -> V=1.0, theta=0.0
% INFO    : Bus 33431	: V=0.9495491, theta=-44.094969 -> V=1.0, theta=0.0
% INFO    : Bus 33432	: V=0.9494933, theta=-44.170822 -> V=1.0, theta=0.0
% INFO    : Bus 33433	: V=0.9482708, theta=-44.093263 -> V=1.0, theta=0.0
% INFO    : Bus 33434	: V=0.9470534, theta=-44.416131 -> V=1.0, theta=0.0
% INFO    : Bus 33435	: V=0.9481658, theta=-44.348074 -> V=1.0, theta=0.0
% INFO    : Bus 33436	: V=0.9483018, theta=-44.312236 -> V=1.0, theta=0.0
% INFO    : Bus 33437	: V=0.9497889, theta=-44.047812 -> V=1.0, theta=0.0
% INFO    : Bus 33438	: V=0.949116, theta=-44.312291 -> V=1.0, theta=0.0
% INFO    : Bus 33439	: V=0.9500902, theta=-43.998541 -> V=1.0, theta=0.0
% INFO    : Bus 33440	: V=0.9491512, theta=-44.262237 -> V=1.0, theta=0.0
% INFO    : Bus 33441	: V=0.950848, theta=-43.849834 -> V=1.0, theta=0.0
% INFO    : Bus 33442	: V=0.9512857, theta=-43.778535 -> V=1.0, theta=0.0
% INFO    : Bus 33443	: V=0.9517384, theta=-43.732236 -> V=1.0, theta=0.0
% INFO    : Bus 33444	: V=0.950248, theta=-44.118443 -> V=1.0, theta=0.0
% INFO    : Bus 33445	: V=0.9518024, theta=-43.506309 -> V=1.0, theta=0.0
% INFO    : Bus 33446	: V=0.9515666, theta=-42.983901 -> V=1.0, theta=0.0
% INFO    : Bus 33447	: V=0.9665351, theta=-41.745731 -> V=1.0, theta=0.0
% INFO    : Bus 33448	: V=0.9680072, theta=-41.628877 -> V=1.0, theta=0.0
% INFO    : Bus 33449	: V=0.9476784, theta=-44.381366 -> V=1.0, theta=0.0
% INFO    : Bus 33450	: V=0.9522106, theta=-43.659732 -> V=1.0, theta=0.0
% INFO    : Bus 33451	: V=0.9517291, theta=-43.579893 -> V=1.0, theta=0.0
% INFO    : Bus 33452	: V=0.9529546, theta=-42.791147 -> V=1.0, theta=0.0
% INFO    : Bus 33453	: V=0.9664399, theta=-41.530754 -> V=1.0, theta=0.0
% INFO    : Bus 33454	: V=0.9631135, theta=-41.226338 -> V=1.0, theta=0.0
% INFO    : Bus 33455	: V=0.9661761, theta=-40.848963 -> V=1.0, theta=0.0
% INFO    : Bus 33456	: V=0.9482944, theta=-43.709689 -> V=1.0, theta=0.0
% INFO    : Bus 33457	: V=0.9478354, theta=-44.161419 -> V=1.0, theta=0.0
% INFO    : Bus 33458	: V=0.947334, theta=-44.162538 -> V=1.0, theta=0.0
% INFO    : Bus 33459	: V=0.9494706, theta=-43.575333 -> V=1.0, theta=0.0
% INFO    : Bus 33460	: V=0.9477606, theta=-43.678939 -> V=1.0, theta=0.0
% INFO    : Bus 33461	: V=0.9478796, theta=-44.029575 -> V=1.0, theta=0.0
% INFO    : Bus 33462	: V=0.948879, theta=-43.793909 -> V=1.0, theta=0.0
% INFO    : Bus 33463	: V=0.9485, theta=-43.900134 -> V=1.0, theta=0.0
% INFO    : Bus 33464	: V=0.9508262, theta=-43.516754 -> V=1.0, theta=0.0
% INFO    : Bus 33465	: V=0.9484316, theta=-43.767425 -> V=1.0, theta=0.0
% INFO    : Bus 33466	: V=0.9480622, theta=-43.705281 -> V=1.0, theta=0.0
% INFO    : Bus 33467	: V=0.9624823, theta=-40.935046 -> V=1.0, theta=0.0
% INFO    : Bus 33468	: V=0.9485864, theta=-43.749307 -> V=1.0, theta=0.0
% INFO    : Bus 33469	: V=0.9834701, theta=-39.423614 -> V=1.0, theta=0.0
% INFO    : Bus 33470	: V=0.952873, theta=-42.934799 -> V=1.0, theta=0.0
% INFO    : Bus 33471	: V=0.9486255, theta=-43.736756 -> V=1.0, theta=0.0
% INFO    : Bus 33472	: V=0.9480919, theta=-43.741968 -> V=1.0, theta=0.0
% INFO    : Bus 33473	: V=0.9552697, theta=-42.897507 -> V=1.0, theta=0.0
% INFO    : Bus 33474	: V=0.9658714, theta=-40.593973 -> V=1.0, theta=0.0
% INFO    : Bus 33475	: V=0.9628272, theta=-40.751084 -> V=1.0, theta=0.0
% INFO    : Bus 33476	: V=0.9521386, theta=-41.209559 -> V=1.0, theta=0.0
% INFO    : Bus 33477	: V=0.9627637, theta=-40.187869 -> V=1.0, theta=0.0
% INFO    : Bus 33478	: V=0.9582016, theta=-41.253682 -> V=1.0, theta=0.0
% INFO    : Bus 33479	: V=0.9401925, theta=-42.895669 -> V=1.0, theta=0.0
% INFO    : Bus 33480	: V=0.9565887, theta=-41.44357 -> V=1.0, theta=0.0
% INFO    : Bus 33481	: V=0.9553643, theta=-41.668795 -> V=1.0, theta=0.0
% INFO    : Bus 33482	: V=0.9568278, theta=-41.508025 -> V=1.0, theta=0.0
% INFO    : Bus 33483	: V=0.9547211, theta=-41.888473 -> V=1.0, theta=0.0
% INFO    : Bus 33484	: V=0.955338, theta=-41.859259 -> V=1.0, theta=0.0
% INFO    : Bus 33485	: V=0.9493183, theta=-42.986954 -> V=1.0, theta=0.0
% INFO    : Bus 33486	: V=0.951601, theta=-42.344756 -> V=1.0, theta=0.0
% INFO    : Bus 33487	: V=0.9512109, theta=-42.454549 -> V=1.0, theta=0.0
% INFO    : Bus 33488	: V=0.948207, theta=-43.400456 -> V=1.0, theta=0.0
% INFO    : Bus 33489	: V=0.9498862, theta=-42.495918 -> V=1.0, theta=0.0
% INFO    : Bus 33490	: V=0.9503633, theta=-42.700093 -> V=1.0, theta=0.0
% INFO    : Bus 33491	: V=0.9498157, theta=-42.621885 -> V=1.0, theta=0.0
% INFO    : Bus 33492	: V=0.9493409, theta=-42.847668 -> V=1.0, theta=0.0
% INFO    : Bus 33493	: V=0.9510581, theta=-42.523805 -> V=1.0, theta=0.0
% INFO    : Bus 33494	: V=0.9482686, theta=-43.284051 -> V=1.0, theta=0.0
% INFO    : Bus 33495	: V=0.950316, theta=-42.753089 -> V=1.0, theta=0.0
% INFO    : Bus 33496	: V=0.9559398, theta=-41.831577 -> V=1.0, theta=0.0
% INFO    : Bus 33497	: V=0.949983, theta=-43.041782 -> V=1.0, theta=0.0
% INFO    : Bus 33498	: V=0.9513015, theta=-42.509946 -> V=1.0, theta=0.0
% INFO    : Bus 33499	: V=0.9472253, theta=-43.457462 -> V=1.0, theta=0.0
% INFO    : Bus 33500	: V=0.9461756, theta=-43.51934 -> V=1.0, theta=0.0
% INFO    : Bus 33501	: V=0.9465661, theta=-43.513468 -> V=1.0, theta=0.0
% INFO    : Bus 33502	: V=0.9516567, theta=-42.445112 -> V=1.0, theta=0.0
% INFO    : Bus 33503	: V=0.9510537, theta=-42.530362 -> V=1.0, theta=0.0
% INFO    : Bus 33504	: V=0.9556385, theta=-41.819235 -> V=1.0, theta=0.0
% INFO    : Bus 33505	: V=0.9554273, theta=-41.86284 -> V=1.0, theta=0.0
% INFO    : Bus 33506	: V=0.9484986, theta=-43.136855 -> V=1.0, theta=0.0
% INFO    : Bus 33507	: V=0.9575417, theta=-41.691348 -> V=1.0, theta=0.0
% INFO    : Bus 33508	: V=0.951556, theta=-42.447933 -> V=1.0, theta=0.0
% INFO    : Bus 33509	: V=0.9510368, theta=-42.530611 -> V=1.0, theta=0.0
% INFO    : Bus 33510	: V=0.9536098, theta=-42.362029 -> V=1.0, theta=0.0
% INFO    : Bus 33511	: V=0.9509836, theta=-43.390968 -> V=1.0, theta=0.0
% INFO    : Bus 33512	: V=0.9556461, theta=-42.7426 -> V=1.0, theta=0.0
% INFO    : Bus 33513	: V=0.9591663, theta=-41.558546 -> V=1.0, theta=0.0
% INFO    : Bus 33514	: V=0.9543641, theta=-43.167612 -> V=1.0, theta=0.0
% INFO    : Bus 33515	: V=0.9558532, theta=-42.978337 -> V=1.0, theta=0.0
% INFO    : Bus 33516	: V=0.9533553, theta=-42.616831 -> V=1.0, theta=0.0
% INFO    : Bus 33517	: V=0.9532814, theta=-42.720623 -> V=1.0, theta=0.0
% INFO    : Bus 33518	: V=0.9610441, theta=-41.40095 -> V=1.0, theta=0.0
% INFO    : Bus 33519	: V=1.0179834, theta=-23.965021 -> V=1.0, theta=0.0
% INFO    : Bus 33520	: V=1.0082908, theta=-26.370289 -> V=1.0, theta=0.0
% INFO    : Bus 33521	: V=0.9920888, theta=-27.958508 -> V=1.0, theta=0.0
% INFO    : Bus 33522	: V=1.0026214, theta=-24.424353 -> V=1.0, theta=0.0
% INFO    : Bus 33523	: V=0.9813691, theta=-29.693562 -> V=1.0, theta=0.0
% INFO    : Bus 33524	: V=0.9727934, theta=-29.861992 -> V=1.0, theta=0.0
% INFO    : Bus 33525	: V=0.9940097, theta=-27.593569 -> V=1.0, theta=0.0
% INFO    : Bus 33526	: V=0.9661091, theta=-33.716237 -> V=1.0, theta=0.0
% INFO    : Bus 33527	: V=0.9871186, theta=-32.500308 -> V=1.0, theta=0.0
% INFO    : Bus 33528	: V=0.9757809, theta=-34.780838 -> V=1.0, theta=0.0
% INFO    : Bus 33529	: V=0.9719277, theta=-35.552893 -> V=1.0, theta=0.0
% INFO    : Bus 33530	: V=0.9917003, theta=-32.118106 -> V=1.0, theta=0.0
% INFO    : Bus 33531	: V=0.9978739, theta=-35.324272 -> V=1.0, theta=0.0
% INFO    : Bus 33532	: V=0.9938665, theta=-35.821225 -> V=1.0, theta=0.0
% INFO    : Bus 33533	: V=1.0054229, theta=-33.896637 -> V=1.0, theta=0.0
% INFO    : Bus 33534	: V=1.0095859, theta=-33.366097 -> V=1.0, theta=0.0
% INFO    : Bus 33535	: V=1.0051649, theta=-34.095925 -> V=1.0, theta=0.0
% INFO    : Bus 33536	: V=1.0070899, theta=-27.804508 -> V=1.0, theta=0.0
% INFO    : Bus 33537	: V=0.9994825, theta=-27.583491 -> V=1.0, theta=0.0
% INFO    : Bus 33538	: V=0.9909992, theta=-28.942259 -> V=1.0, theta=0.0
% INFO    : Bus 33539	: V=0.9469436, theta=-41.563331 -> V=1.0, theta=0.0
% INFO    : Bus 33540	: V=0.9457283, theta=-41.960187 -> V=1.0, theta=0.0
% INFO    : Bus 33541	: V=0.9450558, theta=-42.357326 -> V=1.0, theta=0.0
% INFO    : Bus 33542	: V=0.9424487, theta=-43.086234 -> V=1.0, theta=0.0
% INFO    : Bus 33543	: V=0.9437776, theta=-43.183234 -> V=1.0, theta=0.0
% INFO    : Bus 33544	: V=0.9451911, theta=-42.185523 -> V=1.0, theta=0.0
% INFO    : Bus 33545	: V=0.9451477, theta=-41.698902 -> V=1.0, theta=0.0
% INFO    : Bus 33546	: V=0.9458261, theta=-41.867806 -> V=1.0, theta=0.0
% INFO    : Bus 33547	: V=0.9461202, theta=-41.696623 -> V=1.0, theta=0.0
% INFO    : Bus 33548	: V=0.941535, theta=-41.858212 -> V=1.0, theta=0.0
% INFO    : Bus 33549	: V=0.9455733, theta=-40.954483 -> V=1.0, theta=0.0
% INFO    : Bus 33550	: V=0.9411503, theta=-43.242478 -> V=1.0, theta=0.0
% INFO    : Bus 33551	: V=0.9418615, theta=-42.191777 -> V=1.0, theta=0.0
% INFO    : Bus 33552	: V=0.9389413, theta=-42.380073 -> V=1.0, theta=0.0
% INFO    : Bus 33553	: V=0.9472313, theta=-40.802769 -> V=1.0, theta=0.0
% INFO    : Bus 33554	: V=0.9509756, theta=-40.389507 -> V=1.0, theta=0.0
% INFO    : Bus 33555	: V=0.9454008, theta=-42.239275 -> V=1.0, theta=0.0
% INFO    : Bus 33556	: V=0.9466264, theta=-41.468058 -> V=1.0, theta=0.0
% INFO    : Bus 33557	: V=0.9479058, theta=-41.155364 -> V=1.0, theta=0.0
% INFO    : Bus 33558	: V=0.9489, theta=-40.893792 -> V=1.0, theta=0.0
% INFO    : Bus 33559	: V=0.9495694, theta=-39.669413 -> V=1.0, theta=0.0
% INFO    : Bus 33560	: V=0.9414392, theta=-38.852598 -> V=1.0, theta=0.0
% INFO    : Bus 33561	: V=0.9560856, theta=-39.142762 -> V=1.0, theta=0.0
% INFO    : Bus 33562	: V=0.954335, theta=-38.517659 -> V=1.0, theta=0.0
% INFO    : Bus 33563	: V=0.944475, theta=-39.951944 -> V=1.0, theta=0.0
% INFO    : Bus 33564	: V=0.9884029, theta=-33.062337 -> V=1.0, theta=0.0
% INFO    : Bus 33565	: V=0.9991401, theta=-31.693348 -> V=1.0, theta=0.0
% INFO    : Bus 33566	: V=0.9975288, theta=-32.024516 -> V=1.0, theta=0.0
% INFO    : Bus 33567	: V=0.9882973, theta=-33.155759 -> V=1.0, theta=0.0
% INFO    : Bus 33568	: V=0.9966163, theta=-32.22132 -> V=1.0, theta=0.0
% INFO    : Bus 33569	: V=0.9958084, theta=-32.636395 -> V=1.0, theta=0.0
% INFO    : Bus 33570	: V=0.9933364, theta=-33.177314 -> V=1.0, theta=0.0
% INFO    : Bus 33571	: V=1.0056992, theta=-33.466156 -> V=1.0, theta=0.0
% INFO    : Bus 33572	: V=0.9995842, theta=-33.348863 -> V=1.0, theta=0.0
% INFO    : Bus 33573	: V=0.9990035, theta=-33.356397 -> V=1.0, theta=0.0
% INFO    : Bus 33574	: V=0.9958506, theta=-33.093964 -> V=1.0, theta=0.0
% INFO    : Bus 33575	: V=0.9959703, theta=-32.379866 -> V=1.0, theta=0.0
% INFO    : Bus 33576	: V=1.0052017, theta=-33.910815 -> V=1.0, theta=0.0
% INFO    : Bus 33577	: V=0.9911261, theta=-33.311157 -> V=1.0, theta=0.0
% INFO    : Bus 33578	: V=0.9957204, theta=-32.462767 -> V=1.0, theta=0.0
% INFO    : Bus 33579	: V=0.9945358, theta=-33.801081 -> V=1.0, theta=0.0
% INFO    : Bus 33580	: V=0.9953453, theta=-34.247125 -> V=1.0, theta=0.0
% INFO    : Bus 33581	: V=0.9929944, theta=-32.670493 -> V=1.0, theta=0.0
% INFO    : Bus 33582	: V=0.9891881, theta=-34.431211 -> V=1.0, theta=0.0
% INFO    : Bus 33583	: V=0.9891456, theta=-33.319468 -> V=1.0, theta=0.0
% INFO    : Bus 33584	: V=0.9846, theta=-36.321804 -> V=1.0, theta=0.0
% INFO    : Bus 33585	: V=0.9835455, theta=-35.804518 -> V=1.0, theta=0.0
% INFO    : Bus 33586	: V=0.9852909, theta=-36.279848 -> V=1.0, theta=0.0
% INFO    : Bus 33587	: V=0.9650495, theta=-50.675358 -> V=1.0, theta=0.0
% INFO    : Bus 33588	: V=0.9904143, theta=-49.665319 -> V=1.0, theta=0.0
% INFO    : Bus 33589	: V=0.9823243, theta=-39.843901 -> V=1.0, theta=0.0
% INFO    : Bus 33590	: V=0.9696489, theta=-40.387079 -> V=1.0, theta=0.0
% INFO    : Bus 33591	: V=0.9595085, theta=-41.501292 -> V=1.0, theta=0.0
% INFO    : Bus 33592	: V=0.9791231, theta=-39.879052 -> V=1.0, theta=0.0
% INFO    : Bus 33593	: V=0.9935993, theta=-35.479653 -> V=1.0, theta=0.0
% INFO    : Bus 33594	: V=0.9976046, theta=-34.930542 -> V=1.0, theta=0.0
% INFO    : Bus 33595	: V=1.0012764, theta=-34.424127 -> V=1.0, theta=0.0
% INFO    : Bus 33596	: V=0.9918469, theta=-36.010811 -> V=1.0, theta=0.0
% INFO    : Bus 33597	: V=0.9750214, theta=-37.661263 -> V=1.0, theta=0.0
% INFO    : Bus 33598	: V=0.9710006, theta=-38.4533 -> V=1.0, theta=0.0
% INFO    : Bus 33599	: V=0.9751492, theta=-38.730968 -> V=1.0, theta=0.0
% INFO    : Bus 33600	: V=0.9736201, theta=-32.390025 -> V=1.0, theta=0.0
% INFO    : Bus 33601	: V=0.9840877, theta=-33.62026 -> V=1.0, theta=0.0
% INFO    : Bus 33602	: V=1.0027297, theta=-28.851411 -> V=1.0, theta=0.0
% INFO    : Bus 33603	: V=1.0021003, theta=-27.414278 -> V=1.0, theta=0.0
% INFO    : Bus 33604	: V=0.9889221, theta=-33.964833 -> V=1.0, theta=0.0
% INFO    : Bus 33605	: V=0.9876269, theta=-37.337102 -> V=1.0, theta=0.0
% INFO    : Bus 33606	: V=0.9740931, theta=-29.472838 -> V=1.0, theta=0.0
% INFO    : Bus 33607	: V=0.992246, theta=-27.413698 -> V=1.0, theta=0.0
% INFO    : Bus 33608	: V=0.9669284, theta=-29.082083 -> V=1.0, theta=0.0
% INFO    : Bus 33609	: V=0.9901934, theta=-27.624018 -> V=1.0, theta=0.0
% INFO    : Bus 33610	: V=0.9968842, theta=-26.047375 -> V=1.0, theta=0.0
% INFO    : Bus 33611	: V=0.9843164, theta=-28.236084 -> V=1.0, theta=0.0
% INFO    : Bus 33612	: V=0.9958172, theta=-27.870104 -> V=1.0, theta=0.0
% INFO    : Bus 33613	: V=1.0022691, theta=-26.20099 -> V=1.0, theta=0.0
% INFO    : Bus 33614	: V=0.9917311, theta=-28.037316 -> V=1.0, theta=0.0
% INFO    : Bus 33615	: V=0.9839858, theta=-31.656002 -> V=1.0, theta=0.0
% INFO    : Bus 33616	: V=0.9815028, theta=-31.699555 -> V=1.0, theta=0.0
% INFO    : Bus 33617	: V=0.9830719, theta=-31.569085 -> V=1.0, theta=0.0
% INFO    : Bus 33618	: V=1.0135247, theta=-26.388969 -> V=1.0, theta=0.0
% INFO    : Bus 33619	: V=1.0109968, theta=-26.343943 -> V=1.0, theta=0.0
% INFO    : Bus 33620	: V=1.0095093, theta=-26.18892 -> V=1.0, theta=0.0
% INFO    : Bus 33621	: V=0.9811935, theta=-36.700019 -> V=1.0, theta=0.0
% INFO    : Bus 33622	: V=0.9874127, theta=-33.627239 -> V=1.0, theta=0.0
% INFO    : Bus 33623	: V=0.9949061, theta=-34.195974 -> V=1.0, theta=0.0
% INFO    : Bus 33624	: V=0.9792639, theta=-55.55283 -> V=1.0, theta=0.0
% INFO    : Bus 33625	: V=0.9817197, theta=-55.429993 -> V=1.0, theta=0.0
% INFO    : Bus 33626	: V=0.9886327, theta=-29.074329 -> V=1.0, theta=0.0
% INFO    : Bus 33627	: V=0.9857147, theta=-30.307238 -> V=1.0, theta=0.0
% INFO    : Bus 33628	: V=0.9909796, theta=-28.581222 -> V=1.0, theta=0.0
% INFO    : Bus 33629	: V=0.9876512, theta=-30.524576 -> V=1.0, theta=0.0
% INFO    : Bus 33630	: V=0.9851348, theta=-30.629394 -> V=1.0, theta=0.0
% INFO    : Bus 33631	: V=0.9884741, theta=-29.258171 -> V=1.0, theta=0.0
% INFO    : Bus 33632	: V=0.9728475, theta=-29.64973 -> V=1.0, theta=0.0
% INFO    : Bus 33633	: V=0.9846487, theta=-32.917278 -> V=1.0, theta=0.0
% INFO    : Bus 33634	: V=0.9900241, theta=-31.13165 -> V=1.0, theta=0.0
% INFO    : Bus 33635	: V=0.9819144, theta=-30.720411 -> V=1.0, theta=0.0
% INFO    : Bus 33636	: V=0.982272, theta=-31.94331 -> V=1.0, theta=0.0
% INFO    : Bus 33637	: V=0.9867269, theta=-32.667626 -> V=1.0, theta=0.0
% INFO    : Bus 33638	: V=0.9759402, theta=-33.478616 -> V=1.0, theta=0.0
% INFO    : Bus 33639	: V=0.9765158, theta=-49.45954 -> V=1.0, theta=0.0
% INFO    : Bus 33640	: V=0.9712996, theta=-48.149491 -> V=1.0, theta=0.0
% INFO    : Bus 33641	: V=0.9759782, theta=-49.41736 -> V=1.0, theta=0.0
% INFO    : Bus 33642	: V=0.9765002, theta=-50.125882 -> V=1.0, theta=0.0
% INFO    : Bus 33643	: V=0.9744169, theta=-49.939404 -> V=1.0, theta=0.0
% INFO    : Bus 33644	: V=0.9740354, theta=-33.331559 -> V=1.0, theta=0.0
% INFO    : Bus 33645	: V=0.9598149, theta=-34.492767 -> V=1.0, theta=0.0
% INFO    : Bus 33646	: V=0.9696135, theta=-34.298557 -> V=1.0, theta=0.0
% INFO    : Bus 33647	: V=0.9658568, theta=-34.667504 -> V=1.0, theta=0.0
% INFO    : Bus 33648	: V=0.9588624, theta=-34.977852 -> V=1.0, theta=0.0
% INFO    : Bus 33649	: V=0.963472, theta=-34.811245 -> V=1.0, theta=0.0
% INFO    : Bus 33650	: V=0.9589415, theta=-34.942281 -> V=1.0, theta=0.0
% INFO    : Bus 33651	: V=0.9615169, theta=-34.917131 -> V=1.0, theta=0.0
% INFO    : Bus 33652	: V=0.9605953, theta=-34.927929 -> V=1.0, theta=0.0
% INFO    : Bus 33653	: V=0.9730904, theta=-32.802851 -> V=1.0, theta=0.0
% INFO    : Bus 33654	: V=0.9759482, theta=-32.418137 -> V=1.0, theta=0.0
% INFO    : Bus 33655	: V=0.9911673, theta=-32.528167 -> V=1.0, theta=0.0
% INFO    : Bus 33656	: V=0.9797131, theta=-33.591726 -> V=1.0, theta=0.0
% INFO    : Bus 33657	: V=0.9773829, theta=-34.581876 -> V=1.0, theta=0.0
% INFO    : Bus 33658	: V=0.9936095, theta=-28.986472 -> V=1.0, theta=0.0
% INFO    : Bus 33659	: V=1.0088803, theta=-27.913716 -> V=1.0, theta=0.0
% INFO    : Bus 33660	: V=0.9872554, theta=-34.594972 -> V=1.0, theta=0.0
% INFO    : Bus 33661	: V=0.9461658, theta=-35.353566 -> V=1.0, theta=0.0
% INFO    : Bus 33662	: V=0.9835997, theta=-55.914574 -> V=1.0, theta=0.0
% INFO    : Bus 33663	: V=1.0094848, theta=-49.720177 -> V=1.0, theta=0.0
% INFO    : Bus 33664	: V=0.9929007, theta=-55.407581 -> V=1.0, theta=0.0
% INFO    : Bus 33665	: V=0.9811277, theta=-56.197295 -> V=1.0, theta=0.0
% INFO    : Bus 33666	: V=0.9851961, theta=-56.005263 -> V=1.0, theta=0.0
% INFO    : Bus 33667	: V=0.9914542, theta=-55.783516 -> V=1.0, theta=0.0
% INFO    : Bus 33668	: V=0.9879113, theta=-56.525424 -> V=1.0, theta=0.0
% INFO    : Bus 33669	: V=0.9888008, theta=-56.490412 -> V=1.0, theta=0.0
% INFO    : Bus 33670	: V=0.9910703, theta=-56.009588 -> V=1.0, theta=0.0
% INFO    : Bus 33671	: V=0.9911143, theta=-56.034044 -> V=1.0, theta=0.0
% INFO    : Bus 33672	: V=0.9910543, theta=-55.962449 -> V=1.0, theta=0.0
% INFO    : Bus 33673	: V=0.9959245, theta=-54.007642 -> V=1.0, theta=0.0
% INFO    : Bus 33674	: V=0.9949527, theta=-54.578269 -> V=1.0, theta=0.0
% INFO    : Bus 33675	: V=0.9947948, theta=-54.960962 -> V=1.0, theta=0.0
% INFO    : Bus 33676	: V=0.987086, theta=-56.767909 -> V=1.0, theta=0.0
% INFO    : Bus 33677	: V=0.9940067, theta=-55.071852 -> V=1.0, theta=0.0
% INFO    : Bus 33678	: V=0.9894863, theta=-56.411125 -> V=1.0, theta=0.0
% INFO    : Bus 33679	: V=0.9876249, theta=-56.4961 -> V=1.0, theta=0.0
% INFO    : Bus 33680	: V=0.9859697, theta=-56.838662 -> V=1.0, theta=0.0
% INFO    : Bus 33681	: V=0.9900999, theta=-56.197037 -> V=1.0, theta=0.0
% INFO    : Bus 33682	: V=0.9868905, theta=-55.423564 -> V=1.0, theta=0.0
% INFO    : Bus 33683	: V=0.9926439, theta=-55.310114 -> V=1.0, theta=0.0
% INFO    : Bus 33684	: V=0.9864892, theta=-56.455983 -> V=1.0, theta=0.0
% INFO    : Bus 33685	: V=0.9974812, theta=-54.448384 -> V=1.0, theta=0.0
% INFO    : Bus 33686	: V=1.0003411, theta=-53.871489 -> V=1.0, theta=0.0
% INFO    : Bus 33687	: V=0.950907, theta=-42.220713 -> V=1.0, theta=0.0
% INFO    : Bus 33688	: V=0.9526794, theta=-41.507802 -> V=1.0, theta=0.0
% INFO    : Bus 33689	: V=0.9567507, theta=-38.793775 -> V=1.0, theta=0.0
% INFO    : Bus 33690	: V=0.9534655, theta=-41.133702 -> V=1.0, theta=0.0
% INFO    : Bus 33691	: V=1.0041434, theta=-27.984701 -> V=1.0, theta=0.0
% INFO    : Bus 33692	: V=1.0093884, theta=-26.601874 -> V=1.0, theta=0.0
% INFO    : Bus 33693	: V=1.0044198, theta=-27.409455 -> V=1.0, theta=0.0
% INFO    : Bus 33694	: V=1.0103295, theta=-25.972205 -> V=1.0, theta=0.0
% INFO    : Bus 33695	: V=0.9946186, theta=-27.584203 -> V=1.0, theta=0.0
% INFO    : Bus 33696	: V=0.9822129, theta=-35.111112 -> V=1.0, theta=0.0
% INFO    : Bus 33697	: V=0.9875312, theta=-35.489247 -> V=1.0, theta=0.0
% INFO    : Bus 33698	: V=0.993763, theta=-36.732956 -> V=1.0, theta=0.0
% INFO    : Bus 33699	: V=0.9800489, theta=-37.762476 -> V=1.0, theta=0.0
% INFO    : Bus 33700	: V=0.9737511, theta=-40.335114 -> V=1.0, theta=0.0
% INFO    : Bus 33701	: V=0.9918591, theta=-41.323225 -> V=1.0, theta=0.0
% INFO    : Bus 33702	: V=0.9785158, theta=-39.565104 -> V=1.0, theta=0.0
% INFO    : Bus 33703	: V=0.9946984, theta=-35.343178 -> V=1.0, theta=0.0
% INFO    : Bus 33704	: V=1.0105609, theta=-32.76773 -> V=1.0, theta=0.0
% INFO    : Bus 33705	: V=1.0166317, theta=-31.099757 -> V=1.0, theta=0.0
% INFO    : Bus 33706	: V=1.0148856, theta=-31.92319 -> V=1.0, theta=0.0
% INFO    : Bus 33707	: V=1.0184704, theta=-31.505074 -> V=1.0, theta=0.0
% INFO    : Bus 33708	: V=1.0075322, theta=-33.354334 -> V=1.0, theta=0.0
% INFO    : Bus 33709	: V=0.9932386, theta=-29.467528 -> V=1.0, theta=0.0
% INFO    : Bus 33710	: V=0.980824, theta=-38.497638 -> V=1.0, theta=0.0
% INFO    : Bus 33711	: V=0.9859651, theta=-34.427835 -> V=1.0, theta=0.0
% INFO    : Bus 33712	: V=0.9849246, theta=-32.667293 -> V=1.0, theta=0.0
% INFO    : Bus 33713	: V=0.9874831, theta=-32.375672 -> V=1.0, theta=0.0
% INFO    : Bus 33714	: V=0.9853892, theta=-32.743078 -> V=1.0, theta=0.0
% INFO    : Bus 33715	: V=0.9619446, theta=-49.256077 -> V=1.0, theta=0.0
% INFO    : Bus 33716	: V=0.9670508, theta=-49.098558 -> V=1.0, theta=0.0
% INFO    : Bus 33717	: V=0.971836, theta=-49.473996 -> V=1.0, theta=0.0
% INFO    : Bus 33718	: V=1.0198522, theta=-48.308635 -> V=1.0, theta=0.0
% INFO    : Bus 33719	: V=1.0053837, theta=-50.596993 -> V=1.0, theta=0.0
% INFO    : Bus 33720	: V=0.9884812, theta=-51.483761 -> V=1.0, theta=0.0
% INFO    : Bus 33721	: V=0.9807956, theta=-52.443104 -> V=1.0, theta=0.0
% INFO    : Bus 33722	: V=0.9750372, theta=-53.374919 -> V=1.0, theta=0.0
% INFO    : Bus 33723	: V=0.9774216, theta=-33.872238 -> V=1.0, theta=0.0
% INFO    : Bus 33724	: V=1.0183167, theta=-26.052071 -> V=1.0, theta=0.0
% INFO    : Bus 33725	: V=0.9884398, theta=-32.608894 -> V=1.0, theta=0.0
% INFO    : Bus 33726	: V=1.0058761, theta=-27.781267 -> V=1.0, theta=0.0
% INFO    : Bus 33727	: V=1.0193319, theta=-27.020577 -> V=1.0, theta=0.0
% INFO    : Bus 33728	: V=0.994372, theta=-29.185351 -> V=1.0, theta=0.0
% INFO    : Bus 33729	: V=1.0013138, theta=-28.151618 -> V=1.0, theta=0.0
% INFO    : Bus 33730	: V=0.9875761, theta=-30.597794 -> V=1.0, theta=0.0
% INFO    : Bus 33731	: V=0.9925293, theta=-33.869411 -> V=1.0, theta=0.0
% INFO    : Bus 33732	: V=0.9910368, theta=-33.562158 -> V=1.0, theta=0.0
% INFO    : Bus 33733	: V=0.9922948, theta=-32.185483 -> V=1.0, theta=0.0
% INFO    : Bus 33734	: V=0.9825891, theta=-32.800598 -> V=1.0, theta=0.0
% INFO    : Bus 33735	: V=0.9941774, theta=-31.957149 -> V=1.0, theta=0.0
% INFO    : Bus 33736	: V=0.9799353, theta=-29.848309 -> V=1.0, theta=0.0
% INFO    : Bus 33737	: V=0.9845039, theta=-31.745185 -> V=1.0, theta=0.0
% INFO    : Bus 33738	: V=0.9994034, theta=-27.432415 -> V=1.0, theta=0.0
% INFO    : Bus 33739	: V=0.9928551, theta=-28.814028 -> V=1.0, theta=0.0
% INFO    : Bus 33740	: V=1.0052505, theta=-26.746058 -> V=1.0, theta=0.0
% INFO    : Bus 33741	: V=1.0001984, theta=-27.281104 -> V=1.0, theta=0.0
% INFO    : Bus 33742	: V=1.0078053, theta=-27.246108 -> V=1.0, theta=0.0
% INFO    : Bus 33743	: V=1.010654, theta=-26.39863 -> V=1.0, theta=0.0
% INFO    : Bus 33744	: V=0.9671704, theta=-37.421783 -> V=1.0, theta=0.0
% INFO    : Bus 33745	: V=0.9955317, theta=-36.662859 -> V=1.0, theta=0.0
% INFO    : Bus 33746	: V=1.0070069, theta=-36.341677 -> V=1.0, theta=0.0
% INFO    : Bus 33747	: V=0.9629634, theta=-38.30982 -> V=1.0, theta=0.0
% INFO    : Bus 33748	: V=0.9661484, theta=-37.551119 -> V=1.0, theta=0.0
% INFO    : Bus 33749	: V=0.9614686, theta=-38.032794 -> V=1.0, theta=0.0
% INFO    : Bus 33750	: V=0.9654762, theta=-37.642721 -> V=1.0, theta=0.0
% INFO    : Bus 33751	: V=0.9601252, theta=-38.142388 -> V=1.0, theta=0.0
% INFO    : Bus 33752	: V=0.9631578, theta=-38.457062 -> V=1.0, theta=0.0
% INFO    : Bus 33753	: V=0.9999997, theta=-36.387343 -> V=1.0, theta=0.0
% INFO    : Bus 33754	: V=0.9594917, theta=-38.158322 -> V=1.0, theta=0.0
% INFO    : Bus 33755	: V=0.9612383, theta=-38.627275 -> V=1.0, theta=0.0
% INFO    : Bus 33756	: V=0.9598966, theta=-38.133135 -> V=1.0, theta=0.0
% INFO    : Bus 33757	: V=0.9651577, theta=-37.738431 -> V=1.0, theta=0.0
% INFO    : Bus 33758	: V=0.9622449, theta=-38.647427 -> V=1.0, theta=0.0
% INFO    : Bus 33759	: V=0.9625824, theta=-38.67068 -> V=1.0, theta=0.0
% INFO    : Bus 33760	: V=0.9606544, theta=-38.975586 -> V=1.0, theta=0.0
% INFO    : Bus 33761	: V=0.9606148, theta=-38.946825 -> V=1.0, theta=0.0
% INFO    : Bus 33762	: V=0.9651666, theta=-37.757222 -> V=1.0, theta=0.0
% INFO    : Bus 33763	: V=0.960782, theta=-38.710547 -> V=1.0, theta=0.0
% INFO    : Bus 33764	: V=0.9655925, theta=-37.784234 -> V=1.0, theta=0.0
% INFO    : Bus 33765	: V=0.9652663, theta=-37.789629 -> V=1.0, theta=0.0
% INFO    : Bus 33766	: V=0.9603455, theta=-38.770281 -> V=1.0, theta=0.0
% INFO    : Bus 33767	: V=0.9587724, theta=-38.943584 -> V=1.0, theta=0.0
% INFO    : Bus 33768	: V=0.9589944, theta=-38.937467 -> V=1.0, theta=0.0
% INFO    : Bus 33769	: V=0.9591778, theta=-39.002444 -> V=1.0, theta=0.0
% INFO    : Bus 33770	: V=0.9634381, theta=-37.566515 -> V=1.0, theta=0.0
% INFO    : Bus 33771	: V=0.972692, theta=-35.749059 -> V=1.0, theta=0.0
% INFO    : Bus 33772	: V=0.9978664, theta=-31.482812 -> V=1.0, theta=0.0
% INFO    : Bus 33773	: V=0.9691404, theta=-36.569855 -> V=1.0, theta=0.0
% INFO    : Bus 33774	: V=0.9680582, theta=-36.05393 -> V=1.0, theta=0.0
% INFO    : Bus 33775	: V=0.9670763, theta=-36.17074 -> V=1.0, theta=0.0
% INFO    : Bus 33776	: V=0.9603243, theta=-38.048252 -> V=1.0, theta=0.0
% INFO    : Bus 33777	: V=0.9623292, theta=-37.226695 -> V=1.0, theta=0.0
% INFO    : Bus 33778	: V=0.9676381, theta=-37.102254 -> V=1.0, theta=0.0
% INFO    : Bus 33779	: V=0.960482, theta=-38.106404 -> V=1.0, theta=0.0
% INFO    : Bus 33780	: V=0.9672351, theta=-37.34443 -> V=1.0, theta=0.0
% INFO    : Bus 33781	: V=0.9627282, theta=-37.862194 -> V=1.0, theta=0.0
% INFO    : Bus 33782	: V=0.9739424, theta=-35.700094 -> V=1.0, theta=0.0
% INFO    : Bus 33783	: V=0.9617156, theta=-38.43404 -> V=1.0, theta=0.0
% INFO    : Bus 33784	: V=0.9724783, theta=-35.86411 -> V=1.0, theta=0.0
% INFO    : Bus 33785	: V=0.9656722, theta=-37.456796 -> V=1.0, theta=0.0
% INFO    : Bus 33786	: V=0.9621362, theta=-38.223146 -> V=1.0, theta=0.0
% INFO    : Bus 33787	: V=0.9612915, theta=-38.241489 -> V=1.0, theta=0.0
% INFO    : Bus 33788	: V=0.9608271, theta=-38.503033 -> V=1.0, theta=0.0
% INFO    : Bus 33789	: V=0.9596535, theta=-38.66263 -> V=1.0, theta=0.0
% INFO    : Bus 33790	: V=0.9591252, theta=-38.76694 -> V=1.0, theta=0.0
% INFO    : Bus 33791	: V=0.958634, theta=-39.014811 -> V=1.0, theta=0.0
% INFO    : Bus 33792	: V=0.9708516, theta=-36.337316 -> V=1.0, theta=0.0
% INFO    : Bus 33793	: V=0.9848279, theta=-37.364727 -> V=1.0, theta=0.0
% INFO    : Bus 33794	: V=0.9596996, theta=-38.153017 -> V=1.0, theta=0.0
% INFO    : Bus 33795	: V=0.9889663, theta=-37.194785 -> V=1.0, theta=0.0
% INFO    : Bus 33796	: V=0.9597439, theta=-39.153789 -> V=1.0, theta=0.0
% INFO    : Bus 33797	: V=0.9671522, theta=-38.72484 -> V=1.0, theta=0.0
% INFO    : Bus 33798	: V=0.9766925, theta=-35.48009 -> V=1.0, theta=0.0
% INFO    : Bus 33799	: V=0.9823299, theta=-35.172513 -> V=1.0, theta=0.0
% INFO    : Bus 33800	: V=0.9693779, theta=-37.427807 -> V=1.0, theta=0.0
% INFO    : Bus 33801	: V=0.9674176, theta=-38.092721 -> V=1.0, theta=0.0
% INFO    : Bus 33802	: V=0.9657258, theta=-36.841936 -> V=1.0, theta=0.0
% INFO    : Bus 33803	: V=0.9611051, theta=-38.496497 -> V=1.0, theta=0.0
% INFO    : Bus 33804	: V=0.9695609, theta=-36.085574 -> V=1.0, theta=0.0
% INFO    : Bus 33805	: V=0.9675642, theta=-37.63449 -> V=1.0, theta=0.0
% INFO    : Bus 33806	: V=0.9762147, theta=-34.340852 -> V=1.0, theta=0.0
% INFO    : Bus 33807	: V=0.9590422, theta=-39.279458 -> V=1.0, theta=0.0
% INFO    : Bus 33808	: V=0.956258, theta=-39.190074 -> V=1.0, theta=0.0
% INFO    : Bus 33809	: V=0.9530775, theta=-39.657242 -> V=1.0, theta=0.0
% INFO    : Bus 33810	: V=1.0156378, theta=-33.424404 -> V=1.0, theta=0.0
% INFO    : Bus 33811	: V=0.9906543, theta=-35.607445 -> V=1.0, theta=0.0
% INFO    : Bus 33812	: V=0.9952582, theta=-35.229301 -> V=1.0, theta=0.0
% INFO    : Bus 33813	: V=0.9860123, theta=-34.82237 -> V=1.0, theta=0.0
% INFO    : Bus 33814	: V=0.9923077, theta=-33.304044 -> V=1.0, theta=0.0
% INFO    : Bus 33815	: V=0.987711, theta=-34.612571 -> V=1.0, theta=0.0
% INFO    : Bus 33816	: V=1.0111618, theta=-30.098495 -> V=1.0, theta=0.0
% INFO    : Bus 33817	: V=0.9963304, theta=-32.893229 -> V=1.0, theta=0.0
% INFO    : Bus 33818	: V=1.0159809, theta=-29.229567 -> V=1.0, theta=0.0
% INFO    : Bus 33819	: V=1.015569, theta=-28.203278 -> V=1.0, theta=0.0
% INFO    : Bus 33820	: V=0.9637142, theta=-35.117914 -> V=1.0, theta=0.0
% INFO    : Bus 33821	: V=0.9607636, theta=-35.064093 -> V=1.0, theta=0.0
% INFO    : Bus 33822	: V=0.9643882, theta=-34.542519 -> V=1.0, theta=0.0
% INFO    : Bus 33823	: V=0.970228, theta=-33.759028 -> V=1.0, theta=0.0
% INFO    : Bus 33824	: V=0.9577884, theta=-35.278351 -> V=1.0, theta=0.0
% INFO    : Bus 33825	: V=0.9585445, theta=-35.357233 -> V=1.0, theta=0.0
% INFO    : Bus 33826	: V=0.9587869, theta=-35.121118 -> V=1.0, theta=0.0
% INFO    : Bus 33827	: V=0.9513093, theta=-33.966265 -> V=1.0, theta=0.0
% INFO    : Bus 33828	: V=0.9636013, theta=-33.86178 -> V=1.0, theta=0.0
% INFO    : Bus 33829	: V=0.9645447, theta=-33.467388 -> V=1.0, theta=0.0
% INFO    : Bus 33830	: V=0.9667923, theta=-32.654098 -> V=1.0, theta=0.0
% INFO    : Bus 33831	: V=0.9573102, theta=-35.320202 -> V=1.0, theta=0.0
% INFO    : Bus 33832	: V=0.9514244, theta=-34.52996 -> V=1.0, theta=0.0
% INFO    : Bus 33833	: V=0.9470785, theta=-34.646608 -> V=1.0, theta=0.0
% INFO    : Bus 33834	: V=0.9592909, theta=-34.492601 -> V=1.0, theta=0.0
% INFO    : Bus 33835	: V=0.9511861, theta=-35.138088 -> V=1.0, theta=0.0
% INFO    : Bus 33836	: V=0.9574541, theta=-35.293643 -> V=1.0, theta=0.0
% INFO    : Bus 33837	: V=0.9532802, theta=-35.307056 -> V=1.0, theta=0.0
% INFO    : Bus 33838	: V=0.9525134, theta=-34.517067 -> V=1.0, theta=0.0
% INFO    : Bus 33839	: V=0.9872072, theta=-33.655748 -> V=1.0, theta=0.0
% INFO    : Bus 33840	: V=0.9859936, theta=-33.288748 -> V=1.0, theta=0.0
% INFO    : Bus 33841	: V=0.9905356, theta=-34.181084 -> V=1.0, theta=0.0
% INFO    : Bus 33842	: V=0.9867795, theta=-35.544 -> V=1.0, theta=0.0
% INFO    : Bus 33843	: V=0.9842517, theta=-35.594346 -> V=1.0, theta=0.0
% INFO    : Bus 33844	: V=0.9836973, theta=-36.445446 -> V=1.0, theta=0.0
% INFO    : Bus 33845	: V=0.9651538, theta=-33.912275 -> V=1.0, theta=0.0
% INFO    : Bus 33846	: V=0.9775058, theta=-33.08086 -> V=1.0, theta=0.0
% INFO    : Bus 33847	: V=0.9853962, theta=-31.458468 -> V=1.0, theta=0.0
% INFO    : Bus 33848	: V=0.9664737, theta=-33.535468 -> V=1.0, theta=0.0
% INFO    : Bus 33849	: V=0.967072, theta=-33.789158 -> V=1.0, theta=0.0
% INFO    : Bus 33850	: V=0.9671032, theta=-36.571859 -> V=1.0, theta=0.0
% INFO    : Bus 33851	: V=0.9898328, theta=-37.51324 -> V=1.0, theta=0.0
% INFO    : Bus 33852	: V=1.0009042, theta=-36.037793 -> V=1.0, theta=0.0
% INFO    : Bus 33853	: V=1.0041475, theta=-37.569441 -> V=1.0, theta=0.0
% INFO    : Bus 33854	: V=1.0088523, theta=-38.932695 -> V=1.0, theta=0.0
% INFO    : Bus 33855	: V=0.9876939, theta=-35.515247 -> V=1.0, theta=0.0
% INFO    : Bus 33856	: V=0.9588753, theta=-36.574995 -> V=1.0, theta=0.0
% INFO    : Bus 33857	: V=0.9906063, theta=-33.928457 -> V=1.0, theta=0.0
% INFO    : Bus 33858	: V=1.0042176, theta=-34.469062 -> V=1.0, theta=0.0
% INFO    : Bus 33859	: V=0.9824033, theta=-28.486574 -> V=1.0, theta=0.0
% INFO    : Bus 33860	: V=1.0022998, theta=-25.815145 -> V=1.0, theta=0.0
% INFO    : Bus 33861	: V=1.0173809, theta=-23.999318 -> V=1.0, theta=0.0
% INFO    : Bus 33862	: V=1.0152186, theta=-24.333432 -> V=1.0, theta=0.0
% INFO    : Bus 33863	: V=1.0074865, theta=-25.229486 -> V=1.0, theta=0.0
% INFO    : Bus 33864	: V=1.0048806, theta=-25.198021 -> V=1.0, theta=0.0
% INFO    : Bus 33865	: V=0.9848543, theta=-28.121849 -> V=1.0, theta=0.0
% INFO    : Bus 33866	: V=0.9987084, theta=-38.261474 -> V=1.0, theta=0.0
% INFO    : Bus 33867	: V=0.9766056, theta=-38.146956 -> V=1.0, theta=0.0
% INFO    : Bus 33868	: V=0.9731237, theta=-38.19263 -> V=1.0, theta=0.0
% INFO    : Bus 33869	: V=1.0125313, theta=-26.17753 -> V=1.0, theta=0.0
% INFO    : Bus 33870	: V=1.0126792, theta=-26.14019 -> V=1.0, theta=0.0
% INFO    : Bus 33871	: V=0.9874542, theta=-29.529664 -> V=1.0, theta=0.0
% INFO    : Bus 33872	: V=1.0009484, theta=-29.320091 -> V=1.0, theta=0.0
% INFO    : Bus 33873	: V=1.000801, theta=-26.853753 -> V=1.0, theta=0.0
% INFO    : Bus 33874	: V=0.9706655, theta=-43.456908 -> V=1.0, theta=0.0
% INFO    : Bus 33875	: V=0.9978847, theta=-38.970461 -> V=1.0, theta=0.0
% INFO    : Bus 33876	: V=0.9906507, theta=-39.231283 -> V=1.0, theta=0.0
% INFO    : Bus 33877	: V=0.9909278, theta=-39.855723 -> V=1.0, theta=0.0
% INFO    : Bus 33878	: V=0.9817017, theta=-39.123194 -> V=1.0, theta=0.0
% INFO    : Bus 33879	: V=0.9801275, theta=-38.68589 -> V=1.0, theta=0.0
% INFO    : Bus 33880	: V=0.9688618, theta=-44.030367 -> V=1.0, theta=0.0
% INFO    : Bus 33881	: V=0.9703528, theta=-44.441555 -> V=1.0, theta=0.0
% INFO    : Bus 33882	: V=0.9725917, theta=-31.001812 -> V=1.0, theta=0.0
% INFO    : Bus 33883	: V=0.9753882, theta=-30.985768 -> V=1.0, theta=0.0
% INFO    : Bus 33884	: V=0.9878389, theta=-29.856636 -> V=1.0, theta=0.0
% INFO    : Bus 33885	: V=0.9760721, theta=-30.862951 -> V=1.0, theta=0.0
% INFO    : Bus 33886	: V=0.9771488, theta=-30.842359 -> V=1.0, theta=0.0
% INFO    : Bus 33887	: V=0.976753, theta=-30.848012 -> V=1.0, theta=0.0
% INFO    : Bus 33888	: V=0.9752819, theta=-30.98185 -> V=1.0, theta=0.0
% INFO    : Bus 33889	: V=0.9718111, theta=-30.992662 -> V=1.0, theta=0.0
% INFO    : Bus 33890	: V=0.9723243, theta=-30.961261 -> V=1.0, theta=0.0
% INFO    : Bus 33891	: V=0.9738432, theta=-30.978242 -> V=1.0, theta=0.0
% INFO    : Bus 33892	: V=0.9749112, theta=-30.88067 -> V=1.0, theta=0.0
% INFO    : Bus 33893	: V=0.9753427, theta=-30.875337 -> V=1.0, theta=0.0
% INFO    : Bus 33894	: V=0.9727468, theta=-30.894474 -> V=1.0, theta=0.0
% INFO    : Bus 33895	: V=0.9734641, theta=-30.876507 -> V=1.0, theta=0.0
% INFO    : Bus 33896	: V=0.9862428, theta=-29.942036 -> V=1.0, theta=0.0
% INFO    : Bus 33897	: V=0.9773176, theta=-30.737658 -> V=1.0, theta=0.0
% INFO    : Bus 33898	: V=0.985143, theta=-29.862757 -> V=1.0, theta=0.0
% INFO    : Bus 33899	: V=0.9772228, theta=-30.745296 -> V=1.0, theta=0.0
% INFO    : Bus 33900	: V=0.9755226, theta=-30.799114 -> V=1.0, theta=0.0
% INFO    : Bus 33901	: V=0.9843266, theta=-29.915255 -> V=1.0, theta=0.0
% INFO    : Bus 33902	: V=0.9705042, theta=-30.877941 -> V=1.0, theta=0.0
% INFO    : Bus 33903	: V=0.9706563, theta=-30.773426 -> V=1.0, theta=0.0
% INFO    : Bus 33904	: V=0.9728414, theta=-30.941462 -> V=1.0, theta=0.0
% INFO    : Bus 33905	: V=0.9741194, theta=-30.80737 -> V=1.0, theta=0.0
% INFO    : Bus 33906	: V=0.9681024, theta=-30.858005 -> V=1.0, theta=0.0
% INFO    : Bus 33907	: V=0.9705236, theta=-30.46439 -> V=1.0, theta=0.0
% INFO    : Bus 33908	: V=0.9708694, theta=-30.764826 -> V=1.0, theta=0.0
% INFO    : Bus 33909	: V=0.9715761, theta=-30.446581 -> V=1.0, theta=0.0
% INFO    : Bus 33910	: V=0.970657, theta=-30.532535 -> V=1.0, theta=0.0
% INFO    : Bus 33911	: V=0.9807239, theta=-28.917735 -> V=1.0, theta=0.0
% INFO    : Bus 33912	: V=0.9820252, theta=-28.816785 -> V=1.0, theta=0.0
% INFO    : Bus 33913	: V=0.9688741, theta=-30.764229 -> V=1.0, theta=0.0
% INFO    : Bus 33914	: V=0.969473, theta=-30.657985 -> V=1.0, theta=0.0
% INFO    : Bus 33915	: V=0.9955611, theta=-29.68569 -> V=1.0, theta=0.0
% INFO    : Bus 33916	: V=0.9861527, theta=-28.064425 -> V=1.0, theta=0.0
% INFO    : Bus 33917	: V=0.9687034, theta=-30.69785 -> V=1.0, theta=0.0
% INFO    : Bus 33918	: V=0.9696581, theta=-30.633837 -> V=1.0, theta=0.0
% INFO    : Bus 33919	: V=0.9705668, theta=-30.462056 -> V=1.0, theta=0.0
% INFO    : Bus 33920	: V=0.968914, theta=-30.469989 -> V=1.0, theta=0.0
% INFO    : Bus 33921	: V=0.9685952, theta=-30.344325 -> V=1.0, theta=0.0
% INFO    : Bus 33922	: V=0.9682359, theta=-30.393607 -> V=1.0, theta=0.0
% INFO    : Bus 33923	: V=0.9855221, theta=-28.12888 -> V=1.0, theta=0.0
% INFO    : Bus 33924	: V=0.9570393, theta=-30.783202 -> V=1.0, theta=0.0
% INFO    : Bus 33925	: V=0.9628253, theta=-30.682872 -> V=1.0, theta=0.0
% INFO    : Bus 33926	: V=0.994473, theta=-26.769016 -> V=1.0, theta=0.0
% INFO    : Bus 33927	: V=0.9826061, theta=-27.854906 -> V=1.0, theta=0.0
% INFO    : Bus 33928	: V=0.9896717, theta=-29.740943 -> V=1.0, theta=0.0
% INFO    : Bus 33929	: V=0.9498096, theta=-42.715763 -> V=1.0, theta=0.0
% INFO    : Bus 33930	: V=0.9543889, theta=-41.821256 -> V=1.0, theta=0.0
% INFO    : Bus 33931	: V=0.9516869, theta=-41.451531 -> V=1.0, theta=0.0
% INFO    : Bus 33932	: V=0.9460324, theta=-42.897121 -> V=1.0, theta=0.0
% INFO    : Bus 33933	: V=0.9464857, theta=-40.938505 -> V=1.0, theta=0.0
% INFO    : Bus 33934	: V=0.955035, theta=-40.54226 -> V=1.0, theta=0.0
% INFO    : Bus 33935	: V=0.9569929, theta=-40.064868 -> V=1.0, theta=0.0
% INFO    : Bus 33936	: V=0.9527853, theta=-39.760679 -> V=1.0, theta=0.0
% INFO    : Bus 33937	: V=0.9536883, theta=-40.882605 -> V=1.0, theta=0.0
% INFO    : Bus 33938	: V=0.9506652, theta=-42.417861 -> V=1.0, theta=0.0
% INFO    : Bus 33939	: V=0.9387959, theta=-42.645082 -> V=1.0, theta=0.0
% INFO    : Bus 33940	: V=0.949219, theta=-40.324505 -> V=1.0, theta=0.0
% INFO    : Bus 33941	: V=0.9403957, theta=-41.841313 -> V=1.0, theta=0.0
% INFO    : Bus 33942	: V=0.9510923, theta=-40.019813 -> V=1.0, theta=0.0
% INFO    : Bus 33943	: V=0.9528964, theta=-40.180884 -> V=1.0, theta=0.0
% INFO    : Bus 33944	: V=0.9775723, theta=-42.365965 -> V=1.0, theta=0.0
% INFO    : Bus 33945	: V=0.9733145, theta=-43.445482 -> V=1.0, theta=0.0
% INFO    : Bus 33946	: V=0.9951094, theta=-26.183635 -> V=1.0, theta=0.0
% INFO    : Bus 33947	: V=0.9842857, theta=-27.738766 -> V=1.0, theta=0.0
% INFO    : Bus 33948	: V=0.9735121, theta=-29.681585 -> V=1.0, theta=0.0
% INFO    : Bus 33949	: V=0.9687019, theta=-30.237762 -> V=1.0, theta=0.0
% INFO    : Bus 33950	: V=0.9794877, theta=-28.461474 -> V=1.0, theta=0.0
% INFO    : Bus 33951	: V=0.9730944, theta=-49.327617 -> V=1.0, theta=0.0
% INFO    : Bus 33952	: V=0.9709593, theta=-49.587266 -> V=1.0, theta=0.0
% INFO    : Bus 33953	: V=0.9698345, theta=-50.60398 -> V=1.0, theta=0.0
% INFO    : Bus 33954	: V=0.956548, theta=-38.272179 -> V=1.0, theta=0.0
% INFO    : Bus 33955	: V=0.9624716, theta=-38.490847 -> V=1.0, theta=0.0
% INFO    : Bus 33956	: V=0.9513396, theta=-39.311464 -> V=1.0, theta=0.0
% INFO    : Bus 33957	: V=0.9618128, theta=-37.722015 -> V=1.0, theta=0.0
% INFO    : Bus 33958	: V=0.9594636, theta=-37.963382 -> V=1.0, theta=0.0
% INFO    : Bus 33959	: V=0.9724247, theta=-35.715207 -> V=1.0, theta=0.0
% INFO    : Bus 33960	: V=0.9719679, theta=-36.223286 -> V=1.0, theta=0.0
% INFO    : Bus 33961	: V=0.9617607, theta=-38.51153 -> V=1.0, theta=0.0
% INFO    : Bus 33962	: V=0.9660918, theta=-37.305635 -> V=1.0, theta=0.0
% INFO    : Bus 33963	: V=0.9706624, theta=-37.758736 -> V=1.0, theta=0.0
% INFO    : Bus 33964	: V=0.9633522, theta=-38.326603 -> V=1.0, theta=0.0
% INFO    : Bus 33965	: V=0.9722887, theta=-36.485964 -> V=1.0, theta=0.0
% INFO    : Bus 33966	: V=0.9640688, theta=-39.873814 -> V=1.0, theta=0.0
% INFO    : Bus 33967	: V=0.9749716, theta=-36.791478 -> V=1.0, theta=0.0
% INFO    : Bus 33968	: V=0.9545657, theta=-40.77237 -> V=1.0, theta=0.0
% INFO    : Bus 33969	: V=0.9509277, theta=-41.134387 -> V=1.0, theta=0.0
% INFO    : Bus 33970	: V=0.9502018, theta=-41.211604 -> V=1.0, theta=0.0
% INFO    : Bus 33971	: V=0.9669323, theta=-41.403743 -> V=1.0, theta=0.0
% INFO    : Bus 33972	: V=0.9696279, theta=-41.920919 -> V=1.0, theta=0.0
% INFO    : Bus 33973	: V=0.9764246, theta=-43.480732 -> V=1.0, theta=0.0
% INFO    : Bus 33974	: V=0.9759404, theta=-45.012325 -> V=1.0, theta=0.0
% INFO    : Bus 33975	: V=0.9710678, theta=-44.062257 -> V=1.0, theta=0.0
% INFO    : Bus 33976	: V=0.9684279, theta=-45.093203 -> V=1.0, theta=0.0
% INFO    : Bus 33977	: V=0.975598, theta=-46.993922 -> V=1.0, theta=0.0
% INFO    : Bus 33978	: V=0.9686772, theta=-44.458045 -> V=1.0, theta=0.0
% INFO    : Bus 33979	: V=0.9766249, theta=-45.989642 -> V=1.0, theta=0.0
% INFO    : Bus 33980	: V=0.9732704, theta=-47.039314 -> V=1.0, theta=0.0
% INFO    : Bus 33981	: V=0.9784898, theta=-34.55874 -> V=1.0, theta=0.0
% INFO    : Bus 33982	: V=1.0131412, theta=-31.93634 -> V=1.0, theta=0.0
% INFO    : Bus 33983	: V=1.0113921, theta=-31.056176 -> V=1.0, theta=0.0
% INFO    : Bus 33984	: V=1.0095029, theta=-27.943569 -> V=1.0, theta=0.0
% INFO    : Bus 33985	: V=0.9831094, theta=-28.927183 -> V=1.0, theta=0.0
% INFO    : Bus 33986	: V=0.9783424, theta=-29.667814 -> V=1.0, theta=0.0
% INFO    : Bus 33987	: V=0.9857828, theta=-29.053073 -> V=1.0, theta=0.0
% INFO    : Bus 33988	: V=0.9647793, theta=-32.796149 -> V=1.0, theta=0.0
% INFO    : Bus 33989	: V=0.9752775, theta=-32.381111 -> V=1.0, theta=0.0
% INFO    : Bus 33990	: V=1.0029299, theta=-36.7942 -> V=1.0, theta=0.0
% INFO    : Bus 33991	: V=0.9759529, theta=-37.564677 -> V=1.0, theta=0.0
% INFO    : Bus 33992	: V=0.9948814, theta=-38.691605 -> V=1.0, theta=0.0
% INFO    : Bus 33993	: V=0.9863431, theta=-39.265849 -> V=1.0, theta=0.0
% INFO    : Bus 33994	: V=0.9892335, theta=-41.190782 -> V=1.0, theta=0.0
% INFO    : Bus 33995	: V=0.993334, theta=-41.005239 -> V=1.0, theta=0.0
% INFO    : Bus 33996	: V=0.9707346, theta=-45.700355 -> V=1.0, theta=0.0
% INFO    : Bus 33997	: V=0.9709353, theta=-46.361433 -> V=1.0, theta=0.0
% INFO    : Bus 33998	: V=0.9716797, theta=-47.536782 -> V=1.0, theta=0.0
% INFO    : Bus 33999	: V=0.9729544, theta=-48.777422 -> V=1.0, theta=0.0
% INFO    : Bus 34000	: V=0.9781395, theta=-53.598169 -> V=1.0, theta=0.0
% INFO    : Bus 34001	: V=0.9716322, theta=-53.808366 -> V=1.0, theta=0.0
% INFO    : Bus 34002	: V=0.9824355, theta=-54.16961 -> V=1.0, theta=0.0
% INFO    : Bus 34003	: V=0.9809458, theta=-54.566614 -> V=1.0, theta=0.0
% INFO    : Bus 34004	: V=0.9747667, theta=-54.233121 -> V=1.0, theta=0.0
% INFO    : Bus 34005	: V=0.9674158, theta=-54.054466 -> V=1.0, theta=0.0
% INFO    : Bus 34006	: V=0.9819234, theta=-52.133545 -> V=1.0, theta=0.0
% INFO    : Bus 34007	: V=0.9792189, theta=-52.346527 -> V=1.0, theta=0.0
% INFO    : Bus 34008	: V=0.9659951, theta=-54.081191 -> V=1.0, theta=0.0
% INFO    : Bus 34009	: V=0.9632775, theta=-54.100894 -> V=1.0, theta=0.0
% INFO    : Bus 34010	: V=0.9591848, theta=-54.305708 -> V=1.0, theta=0.0
% INFO    : Bus 34011	: V=0.9700953, theta=-50.952544 -> V=1.0, theta=0.0
% INFO    : Bus 34012	: V=0.9661095, theta=-53.100801 -> V=1.0, theta=0.0
% INFO    : Bus 34013	: V=0.9692738, theta=-51.55901 -> V=1.0, theta=0.0
% INFO    : Bus 34014	: V=0.968519, theta=-52.760439 -> V=1.0, theta=0.0
% INFO    : Bus 34015	: V=0.9683957, theta=-52.981855 -> V=1.0, theta=0.0
% INFO    : Bus 34016	: V=0.9686744, theta=-52.221382 -> V=1.0, theta=0.0
% INFO    : Bus 34017	: V=0.9688471, theta=-52.978699 -> V=1.0, theta=0.0
% INFO    : Bus 34018	: V=0.966708, theta=-53.759717 -> V=1.0, theta=0.0
% INFO    : Bus 34019	: V=0.9683582, theta=-52.749233 -> V=1.0, theta=0.0
% INFO    : Bus 34020	: V=0.995617, theta=-26.972459 -> V=1.0, theta=0.0
% INFO    : Bus 34021	: V=1.022855, theta=-23.16517 -> V=1.0, theta=0.0
% INFO    : Bus 34022	: V=1.022495, theta=-23.153695 -> V=1.0, theta=0.0
% INFO    : Bus 34023	: V=1.0223615, theta=-23.122506 -> V=1.0, theta=0.0
% INFO    : Bus 34024	: V=1.0219701, theta=-23.045355 -> V=1.0, theta=0.0
% INFO    : Bus 34025	: V=1.0208604, theta=-22.855471 -> V=1.0, theta=0.0
% INFO    : Bus 34026	: V=0.9587223, theta=-39.951128 -> V=1.0, theta=0.0
% INFO    : Bus 34027	: V=0.9816602, theta=-39.577125 -> V=1.0, theta=0.0
% INFO    : Bus 34028	: V=0.9849488, theta=-39.475102 -> V=1.0, theta=0.0
% INFO    : Bus 34029	: V=0.9908124, theta=-29.204755 -> V=1.0, theta=0.0
% INFO    : Bus 34030	: V=0.9893347, theta=-29.983814 -> V=1.0, theta=0.0
% INFO    : Bus 34031	: V=0.9977517, theta=-29.385169 -> V=1.0, theta=0.0
% INFO    : Bus 34032	: V=0.9963236, theta=-29.635035 -> V=1.0, theta=0.0
% INFO    : Bus 34033	: V=0.9880601, theta=-30.073129 -> V=1.0, theta=0.0
% INFO    : Bus 34034	: V=0.9747542, theta=-32.235319 -> V=1.0, theta=0.0
% INFO    : Bus 34035	: V=0.990889, theta=-30.647081 -> V=1.0, theta=0.0
% INFO    : Bus 34036	: V=0.9793101, theta=-32.157705 -> V=1.0, theta=0.0
% INFO    : Bus 34037	: V=0.9910875, theta=-30.16069 -> V=1.0, theta=0.0
% INFO    : Bus 34038	: V=0.9886722, theta=-30.447632 -> V=1.0, theta=0.0
% INFO    : Bus 34039	: V=0.9868864, theta=-30.709724 -> V=1.0, theta=0.0
% INFO    : Bus 34040	: V=0.9772026, theta=-32.046122 -> V=1.0, theta=0.0
% INFO    : Bus 34041	: V=0.9881986, theta=-31.193468 -> V=1.0, theta=0.0
% INFO    : Bus 34042	: V=0.9878765, theta=-31.527697 -> V=1.0, theta=0.0
% INFO    : Bus 34043	: V=0.9890339, theta=-31.928568 -> V=1.0, theta=0.0
% INFO    : Bus 34044	: V=0.982391, theta=-32.242897 -> V=1.0, theta=0.0
% INFO    : Bus 34045	: V=0.9743235, theta=-48.217349 -> V=1.0, theta=0.0
% INFO    : Bus 34046	: V=0.9721056, theta=-49.554092 -> V=1.0, theta=0.0
% INFO    : Bus 34047	: V=0.9619345, theta=-33.502501 -> V=1.0, theta=0.0
% INFO    : Bus 34048	: V=0.9910958, theta=-34.070202 -> V=1.0, theta=0.0
% INFO    : Bus 34049	: V=0.9673199, theta=-38.936235 -> V=1.0, theta=0.0
% INFO    : Bus 34050	: V=0.9653487, theta=-39.488495 -> V=1.0, theta=0.0
% INFO    : Bus 34051	: V=0.970692, theta=-39.52809 -> V=1.0, theta=0.0
% INFO    : Bus 34052	: V=0.9783237, theta=-39.642833 -> V=1.0, theta=0.0
% INFO    : Bus 34053	: V=0.9677746, theta=-39.021112 -> V=1.0, theta=0.0
% INFO    : Bus 34054	: V=0.9666623, theta=-39.805399 -> V=1.0, theta=0.0
% INFO    : Bus 34055	: V=0.9920382, theta=-37.055491 -> V=1.0, theta=0.0
% INFO    : Bus 34056	: V=1.015241, theta=-33.86072 -> V=1.0, theta=0.0
% INFO    : Bus 34057	: V=1.0111325, theta=-34.089942 -> V=1.0, theta=0.0
% INFO    : Bus 34058	: V=0.9996899, theta=-34.341578 -> V=1.0, theta=0.0
% INFO    : Bus 34059	: V=1.0181691, theta=-33.299639 -> V=1.0, theta=0.0
% INFO    : Bus 34060	: V=1.0187349, theta=-33.767814 -> V=1.0, theta=0.0
% INFO    : Bus 34061	: V=1.0100828, theta=-35.204249 -> V=1.0, theta=0.0
% INFO    : Bus 34062	: V=0.9377641, theta=-33.075672 -> V=1.0, theta=0.0
% INFO    : Bus 34063	: V=0.9533285, theta=-32.024214 -> V=1.0, theta=0.0
% INFO    : Bus 34064	: V=0.9474371, theta=-32.487819 -> V=1.0, theta=0.0
% INFO    : Bus 34065	: V=0.9432102, theta=-32.599603 -> V=1.0, theta=0.0
% INFO    : Bus 34066	: V=0.9423541, theta=-32.261694 -> V=1.0, theta=0.0
% INFO    : Bus 34067	: V=0.9413252, theta=-32.68864 -> V=1.0, theta=0.0
% INFO    : Bus 34068	: V=0.945297, theta=-32.172325 -> V=1.0, theta=0.0
% INFO    : Bus 34069	: V=0.9561102, theta=-30.803443 -> V=1.0, theta=0.0
% INFO    : Bus 34070	: V=0.9612948, theta=-30.243289 -> V=1.0, theta=0.0
% INFO    : Bus 34071	: V=0.9776141, theta=-27.613087 -> V=1.0, theta=0.0
% INFO    : Bus 34072	: V=0.9592208, theta=-29.673754 -> V=1.0, theta=0.0
% INFO    : Bus 34073	: V=0.9820955, theta=-27.201453 -> V=1.0, theta=0.0
% INFO    : Bus 34074	: V=0.9943045, theta=-26.285962 -> V=1.0, theta=0.0
% INFO    : Bus 34075	: V=0.9961452, theta=-37.118173 -> V=1.0, theta=0.0
% INFO    : Bus 34076	: V=0.9997499, theta=-34.828567 -> V=1.0, theta=0.0
% INFO    : Bus 34077	: V=1.0064827, theta=-35.142508 -> V=1.0, theta=0.0
% INFO    : Bus 34078	: V=1.0151322, theta=-34.66126 -> V=1.0, theta=0.0
% INFO    : Bus 34079	: V=0.9937163, theta=-38.491921 -> V=1.0, theta=0.0
% INFO    : Bus 34080	: V=0.9728048, theta=-39.950048 -> V=1.0, theta=0.0
% INFO    : Bus 34081	: V=0.9885972, theta=-38.949415 -> V=1.0, theta=0.0
% INFO    : Bus 34082	: V=0.9529263, theta=-43.231246 -> V=1.0, theta=0.0
% INFO    : Bus 34083	: V=0.9725659, theta=-39.77212 -> V=1.0, theta=0.0
% INFO    : Bus 34084	: V=0.9831013, theta=-39.140207 -> V=1.0, theta=0.0
% INFO    : Bus 34085	: V=0.9832803, theta=-39.301598 -> V=1.0, theta=0.0
% INFO    : Bus 34086	: V=0.9745782, theta=-37.230747 -> V=1.0, theta=0.0
% INFO    : Bus 34087	: V=0.969017, theta=-39.446285 -> V=1.0, theta=0.0
% INFO    : Bus 34088	: V=0.9965149, theta=-35.068766 -> V=1.0, theta=0.0
% INFO    : Bus 34089	: V=0.9898144, theta=-34.734046 -> V=1.0, theta=0.0
% INFO    : Bus 34090	: V=0.9846792, theta=-40.635164 -> V=1.0, theta=0.0
% INFO    : Bus 34091	: V=0.9832891, theta=-41.514665 -> V=1.0, theta=0.0
% INFO    : Bus 34092	: V=0.9962792, theta=-44.557579 -> V=1.0, theta=0.0
% INFO    : Bus 34093	: V=0.9950986, theta=-44.612552 -> V=1.0, theta=0.0
% INFO    : Bus 34094	: V=0.9937831, theta=-44.670737 -> V=1.0, theta=0.0
% INFO    : Bus 34095	: V=1.0054723, theta=-45.600203 -> V=1.0, theta=0.0
% INFO    : Bus 34096	: V=0.9945892, theta=-44.636052 -> V=1.0, theta=0.0
% INFO    : Bus 34097	: V=1.0046672, theta=-48.943177 -> V=1.0, theta=0.0
% INFO    : Bus 34098	: V=0.9924331, theta=-44.520112 -> V=1.0, theta=0.0
% INFO    : Bus 34099	: V=1.0115948, theta=-25.455066 -> V=1.0, theta=0.0
% INFO    : Bus 34100	: V=1.0063615, theta=-27.070855 -> V=1.0, theta=0.0
% INFO    : Bus 34101	: V=1.0197025, theta=-22.227756 -> V=1.0, theta=0.0
% INFO    : Bus 34102	: V=1.0071267, theta=-25.017176 -> V=1.0, theta=0.0
% INFO    : Bus 34103	: V=1.0115146, theta=-24.641009 -> V=1.0, theta=0.0
% INFO    : Bus 34104	: V=0.9982178, theta=-26.732908 -> V=1.0, theta=0.0
% INFO    : Bus 34105	: V=1.0010816, theta=-26.226412 -> V=1.0, theta=0.0
% INFO    : Bus 34106	: V=0.9975231, theta=-34.989899 -> V=1.0, theta=0.0
% INFO    : Bus 34107	: V=1.0139085, theta=-35.212182 -> V=1.0, theta=0.0
% INFO    : Bus 34108	: V=1.0082658, theta=-35.628524 -> V=1.0, theta=0.0
% INFO    : Bus 34109	: V=0.9834972, theta=-38.380481 -> V=1.0, theta=0.0
% INFO    : Bus 34110	: V=0.9908532, theta=-38.197534 -> V=1.0, theta=0.0
% INFO    : Bus 34111	: V=0.9809683, theta=-40.517468 -> V=1.0, theta=0.0
% INFO    : Bus 34112	: V=0.97531, theta=-40.952603 -> V=1.0, theta=0.0
% INFO    : Bus 34113	: V=0.9724271, theta=-42.976306 -> V=1.0, theta=0.0
% INFO    : Bus 34114	: V=0.9770256, theta=-33.41223 -> V=1.0, theta=0.0
% INFO    : Bus 34115	: V=0.9840972, theta=-37.090803 -> V=1.0, theta=0.0
% INFO    : Bus 34116	: V=0.9636953, theta=-40.157408 -> V=1.0, theta=0.0
% INFO    : Bus 34117	: V=0.9523202, theta=-42.228548 -> V=1.0, theta=0.0
% INFO    : Bus 34118	: V=0.9495115, theta=-41.636891 -> V=1.0, theta=0.0
% INFO    : Bus 34119	: V=0.9486689, theta=-41.951396 -> V=1.0, theta=0.0
% INFO    : Bus 34120	: V=0.9540231, theta=-41.950719 -> V=1.0, theta=0.0
% INFO    : Bus 34121	: V=0.9818185, theta=-30.375563 -> V=1.0, theta=0.0
% INFO    : Bus 34122	: V=0.9755598, theta=-29.65086 -> V=1.0, theta=0.0
% INFO    : Bus 34123	: V=0.9837268, theta=-28.613228 -> V=1.0, theta=0.0
% INFO    : Bus 34124	: V=0.9836571, theta=-29.431885 -> V=1.0, theta=0.0
% INFO    : Bus 34125	: V=0.974157, theta=-29.577943 -> V=1.0, theta=0.0
% INFO    : Bus 34126	: V=0.9983947, theta=-26.698302 -> V=1.0, theta=0.0
% INFO    : Bus 34127	: V=0.9911049, theta=-27.382086 -> V=1.0, theta=0.0
% INFO    : Bus 34128	: V=0.9955213, theta=-27.000887 -> V=1.0, theta=0.0
% INFO    : Bus 34129	: V=0.9736243, theta=-29.425681 -> V=1.0, theta=0.0
% INFO    : Bus 34130	: V=0.9759407, theta=-29.33705 -> V=1.0, theta=0.0
% INFO    : Bus 34131	: V=0.9986192, theta=-26.208445 -> V=1.0, theta=0.0
% INFO    : Bus 34132	: V=0.9881786, theta=-28.339527 -> V=1.0, theta=0.0
% INFO    : Bus 34133	: V=1.0002927, theta=-26.514397 -> V=1.0, theta=0.0
% INFO    : Bus 34134	: V=1.0024724, theta=-26.793667 -> V=1.0, theta=0.0
% INFO    : Bus 34135	: V=1.0172127, theta=-24.068213 -> V=1.0, theta=0.0
% INFO    : Bus 34136	: V=1.0018954, theta=-26.363725 -> V=1.0, theta=0.0
% INFO    : Bus 34137	: V=0.9924484, theta=-27.840961 -> V=1.0, theta=0.0
% INFO    : Bus 34138	: V=1.0157725, theta=-24.138965 -> V=1.0, theta=0.0
% INFO    : Bus 34139	: V=0.9885878, theta=-41.660891 -> V=1.0, theta=0.0
% INFO    : Bus 34140	: V=0.9919562, theta=-40.683536 -> V=1.0, theta=0.0
% INFO    : Bus 34141	: V=0.9761277, theta=-46.755447 -> V=1.0, theta=0.0
% INFO    : Bus 34142	: V=0.9887843, theta=-42.458783 -> V=1.0, theta=0.0
% INFO    : Bus 34143	: V=1.0028984, theta=-29.30525 -> V=1.0, theta=0.0
% INFO    : Bus 34144	: V=1.0122167, theta=-28.947231 -> V=1.0, theta=0.0
% INFO    : Bus 34145	: V=1.0032512, theta=-28.94012 -> V=1.0, theta=0.0
% INFO    : Bus 34146	: V=1.0066508, theta=-28.123488 -> V=1.0, theta=0.0
% INFO    : Bus 34147	: V=1.0222298, theta=-23.39019 -> V=1.0, theta=0.0
% INFO    : Bus 34148	: V=1.0137225, theta=-25.143471 -> V=1.0, theta=0.0
% INFO    : Bus 34149	: V=1.002659, theta=-26.719166 -> V=1.0, theta=0.0
% INFO    : Bus 34150	: V=0.973559, theta=-50.195455 -> V=1.0, theta=0.0
% INFO    : Bus 34151	: V=0.9731377, theta=-51.991663 -> V=1.0, theta=0.0
% INFO    : Bus 34152	: V=0.9698618, theta=-53.869257 -> V=1.0, theta=0.0
% INFO    : Bus 34153	: V=0.9729478, theta=-52.783353 -> V=1.0, theta=0.0
% INFO    : Bus 34154	: V=0.9714773, theta=-53.692363 -> V=1.0, theta=0.0
% INFO    : Bus 34155	: V=0.9754582, theta=-38.024707 -> V=1.0, theta=0.0
% INFO    : Bus 34156	: V=0.9937671, theta=-34.619507 -> V=1.0, theta=0.0
% INFO    : Bus 34157	: V=1.0047949, theta=-32.454215 -> V=1.0, theta=0.0
% INFO    : Bus 34158	: V=0.9765591, theta=-34.161886 -> V=1.0, theta=0.0
% INFO    : Bus 34159	: V=0.9827201, theta=-32.888628 -> V=1.0, theta=0.0
% INFO    : Bus 34160	: V=1.0073894, theta=-30.16667 -> V=1.0, theta=0.0
% INFO    : Bus 34161	: V=0.9832955, theta=-30.128417 -> V=1.0, theta=0.0
% INFO    : Bus 34162	: V=1.0007736, theta=-27.355221 -> V=1.0, theta=0.0
% INFO    : Bus 34163	: V=0.987102, theta=-29.474372 -> V=1.0, theta=0.0
% INFO    : Bus 34164	: V=0.9847404, theta=-29.575197 -> V=1.0, theta=0.0
% INFO    : Bus 34165	: V=0.9889376, theta=-29.283644 -> V=1.0, theta=0.0
% INFO    : Bus 34166	: V=0.9812426, theta=-30.016701 -> V=1.0, theta=0.0
% INFO    : Bus 34167	: V=0.9746174, theta=-30.62095 -> V=1.0, theta=0.0
% INFO    : Bus 34168	: V=0.9793634, theta=-30.170699 -> V=1.0, theta=0.0
% INFO    : Bus 34169	: V=0.9789825, theta=-30.219912 -> V=1.0, theta=0.0
% INFO    : Bus 34170	: V=0.9790814, theta=-30.629572 -> V=1.0, theta=0.0
% INFO    : Bus 34171	: V=0.9773189, theta=-30.689502 -> V=1.0, theta=0.0
% INFO    : Bus 34172	: V=0.9780353, theta=-30.726946 -> V=1.0, theta=0.0
% INFO    : Bus 34173	: V=1.0003059, theta=-28.86949 -> V=1.0, theta=0.0
% INFO    : Bus 34174	: V=1.0140868, theta=-27.185092 -> V=1.0, theta=0.0
% INFO    : Bus 34175	: V=0.9839903, theta=-30.127896 -> V=1.0, theta=0.0
% INFO    : Bus 34176	: V=0.9975751, theta=-29.143033 -> V=1.0, theta=0.0
% INFO    : Bus 34177	: V=0.9915859, theta=-28.908332 -> V=1.0, theta=0.0
% INFO    : Bus 34178	: V=0.9900277, theta=-28.998437 -> V=1.0, theta=0.0
% INFO    : Bus 34179	: V=0.994234, theta=-28.134017 -> V=1.0, theta=0.0
% INFO    : Bus 34180	: V=0.994471, theta=-27.969362 -> V=1.0, theta=0.0
% INFO    : Bus 34181	: V=0.9958301, theta=-27.306151 -> V=1.0, theta=0.0
% INFO    : Bus 34182	: V=0.9873974, theta=-29.145464 -> V=1.0, theta=0.0
% INFO    : Bus 34183	: V=0.9800116, theta=-29.657683 -> V=1.0, theta=0.0
% INFO    : Bus 34184	: V=0.9955779, theta=-27.696081 -> V=1.0, theta=0.0
% INFO    : Bus 34185	: V=1.004962, theta=-26.809775 -> V=1.0, theta=0.0
% INFO    : Bus 34186	: V=0.9857288, theta=-27.986036 -> V=1.0, theta=0.0
% INFO    : Bus 34187	: V=0.9585588, theta=-31.830617 -> V=1.0, theta=0.0
% INFO    : Bus 34188	: V=0.9492611, theta=-31.920463 -> V=1.0, theta=0.0
% INFO    : Bus 34189	: V=0.9866321, theta=-27.267826 -> V=1.0, theta=0.0
% INFO    : Bus 34190	: V=0.9799921, theta=-28.121825 -> V=1.0, theta=0.0
% INFO    : Bus 34191	: V=0.9824184, theta=-28.049182 -> V=1.0, theta=0.0
% INFO    : Bus 34192	: V=0.9810307, theta=-27.942618 -> V=1.0, theta=0.0
% INFO    : Bus 34193	: V=1.0016687, theta=-25.786229 -> V=1.0, theta=0.0
% INFO    : Bus 34194	: V=0.9917825, theta=-26.290285 -> V=1.0, theta=0.0
% INFO    : Bus 34195	: V=0.9969061, theta=-26.07488 -> V=1.0, theta=0.0
% INFO    : Bus 34196	: V=0.9854017, theta=-27.113184 -> V=1.0, theta=0.0
% INFO    : Bus 34197	: V=0.9797201, theta=-37.04485 -> V=1.0, theta=0.0
% INFO    : Bus 34198	: V=0.9784761, theta=-37.089889 -> V=1.0, theta=0.0
% INFO    : Bus 34199	: V=0.9839153, theta=-37.030738 -> V=1.0, theta=0.0
% INFO    : Bus 34200	: V=0.9857084, theta=-37.010407 -> V=1.0, theta=0.0
% INFO    : Bus 34201	: V=0.983438, theta=-36.891356 -> V=1.0, theta=0.0
% INFO    : Bus 34202	: V=0.99122, theta=-35.84702 -> V=1.0, theta=0.0
% INFO    : Bus 34203	: V=0.9811948, theta=-36.95449 -> V=1.0, theta=0.0
% INFO    : Bus 34204	: V=0.9909946, theta=-35.88897 -> V=1.0, theta=0.0
% INFO    : Bus 34205	: V=0.9747814, theta=-37.304624 -> V=1.0, theta=0.0
% INFO    : Bus 34206	: V=0.9718969, theta=-40.544124 -> V=1.0, theta=0.0
% INFO    : Bus 34207	: V=0.9690987, theta=-40.908719 -> V=1.0, theta=0.0
% INFO    : Bus 34208	: V=0.9657108, theta=-40.482207 -> V=1.0, theta=0.0
% INFO    : Bus 34209	: V=0.9712527, theta=-40.326564 -> V=1.0, theta=0.0
% INFO    : Bus 34210	: V=0.98173, theta=-39.052667 -> V=1.0, theta=0.0
% INFO    : Bus 34211	: V=0.9825188, theta=-38.768877 -> V=1.0, theta=0.0
% INFO    : Bus 34212	: V=0.9908916, theta=-37.970823 -> V=1.0, theta=0.0
% INFO    : Bus 34213	: V=0.9888732, theta=-37.970621 -> V=1.0, theta=0.0
% INFO    : Bus 34214	: V=0.9865571, theta=-37.425633 -> V=1.0, theta=0.0
% INFO    : Bus 34215	: V=1.0005495, theta=-35.664963 -> V=1.0, theta=0.0
% INFO    : Bus 34216	: V=1.0004586, theta=-35.584387 -> V=1.0, theta=0.0
% INFO    : Bus 34217	: V=0.9781787, theta=-36.102682 -> V=1.0, theta=0.0
% INFO    : Bus 34218	: V=0.9861575, theta=-35.92235 -> V=1.0, theta=0.0
% INFO    : Bus 34219	: V=0.9822225, theta=-36.873525 -> V=1.0, theta=0.0
% INFO    : Bus 34220	: V=0.9913032, theta=-35.892926 -> V=1.0, theta=0.0
% INFO    : Bus 34221	: V=0.9793951, theta=-38.663641 -> V=1.0, theta=0.0
% INFO    : Bus 34222	: V=0.9857655, theta=-37.75116 -> V=1.0, theta=0.0
% INFO    : Bus 34223	: V=0.9887038, theta=-36.646201 -> V=1.0, theta=0.0
% INFO    : Bus 34224	: V=0.9924481, theta=-37.227086 -> V=1.0, theta=0.0
% INFO    : Bus 34225	: V=0.9809149, theta=-38.751359 -> V=1.0, theta=0.0
% INFO    : Bus 34226	: V=0.9787581, theta=-37.81353 -> V=1.0, theta=0.0
% INFO    : Bus 34227	: V=0.9906335, theta=-35.740522 -> V=1.0, theta=0.0
% INFO    : Bus 34228	: V=1.0085654, theta=-32.918847 -> V=1.0, theta=0.0
% INFO    : Bus 34229	: V=0.9835481, theta=-37.062195 -> V=1.0, theta=0.0
% INFO    : Bus 34230	: V=1.0016269, theta=-35.451261 -> V=1.0, theta=0.0
% INFO    : Bus 34231	: V=0.985413, theta=-36.828978 -> V=1.0, theta=0.0
% INFO    : Bus 34232	: V=0.9924946, theta=-35.703 -> V=1.0, theta=0.0
% INFO    : Bus 34233	: V=0.995168, theta=-35.421085 -> V=1.0, theta=0.0
% INFO    : Bus 34234	: V=0.9986075, theta=-34.972249 -> V=1.0, theta=0.0
% INFO    : Bus 34235	: V=0.9888739, theta=-37.142409 -> V=1.0, theta=0.0
% INFO    : Bus 34236	: V=1.0197115, theta=-23.604656 -> V=1.0, theta=0.0
% INFO    : Bus 34237	: V=1.0052814, theta=-25.694299 -> V=1.0, theta=0.0
% INFO    : Bus 34238	: V=1.0014911, theta=-25.643828 -> V=1.0, theta=0.0
% INFO    : Bus 34239	: V=0.9820345, theta=-28.085114 -> V=1.0, theta=0.0
% INFO    : Bus 34240	: V=0.992579, theta=-26.202239 -> V=1.0, theta=0.0
% INFO    : Bus 34241	: V=0.9947351, theta=-26.087333 -> V=1.0, theta=0.0
% INFO    : Bus 34242	: V=0.994556, theta=-25.874592 -> V=1.0, theta=0.0
% INFO    : Bus 34243	: V=1.0197827, theta=-23.012724 -> V=1.0, theta=0.0
% INFO    : Bus 34244	: V=1.0197057, theta=-22.560683 -> V=1.0, theta=0.0
% INFO    : Bus 34245	: V=1.0079597, theta=-24.250771 -> V=1.0, theta=0.0
% INFO    : Bus 34246	: V=0.9949597, theta=-27.030114 -> V=1.0, theta=0.0
% INFO    : Bus 34247	: V=0.9855066, theta=-27.586151 -> V=1.0, theta=0.0
% INFO    : Bus 34248	: V=0.9810007, theta=-27.821267 -> V=1.0, theta=0.0
% INFO    : Bus 34249	: V=1.0134835, theta=-24.148297 -> V=1.0, theta=0.0
% INFO    : Bus 34250	: V=0.9804904, theta=-28.386167 -> V=1.0, theta=0.0
% INFO    : Bus 34251	: V=0.9839046, theta=-28.243024 -> V=1.0, theta=0.0
% INFO    : Bus 34252	: V=0.9841477, theta=-28.409214 -> V=1.0, theta=0.0
% INFO    : Bus 34253	: V=0.99409, theta=-26.935259 -> V=1.0, theta=0.0
% INFO    : Bus 34254	: V=0.9922656, theta=-27.152453 -> V=1.0, theta=0.0
% INFO    : Bus 34255	: V=0.990833, theta=-27.301696 -> V=1.0, theta=0.0
% INFO    : Bus 34256	: V=0.9886643, theta=-27.200548 -> V=1.0, theta=0.0
% INFO    : Bus 34257	: V=0.9876455, theta=-27.351021 -> V=1.0, theta=0.0
% INFO    : Bus 34258	: V=0.985467, theta=-28.198582 -> V=1.0, theta=0.0
% INFO    : Bus 34259	: V=0.9896932, theta=-28.212738 -> V=1.0, theta=0.0
% INFO    : Bus 34260	: V=0.9811075, theta=-27.458719 -> V=1.0, theta=0.0
% INFO    : Bus 34261	: V=0.9788923, theta=-27.730243 -> V=1.0, theta=0.0
% INFO    : Bus 34262	: V=0.9774044, theta=-27.742212 -> V=1.0, theta=0.0
% INFO    : Bus 34263	: V=0.9748788, theta=-31.036171 -> V=1.0, theta=0.0
% INFO    : Bus 34264	: V=0.9775652, theta=-30.504703 -> V=1.0, theta=0.0
% INFO    : Bus 34265	: V=0.9737018, theta=-29.782463 -> V=1.0, theta=0.0
% INFO    : Bus 34266	: V=0.976739, theta=-29.76433 -> V=1.0, theta=0.0
% INFO    : Bus 34267	: V=0.9764714, theta=-29.811415 -> V=1.0, theta=0.0
% INFO    : Bus 34268	: V=0.9771988, theta=-29.782022 -> V=1.0, theta=0.0
% INFO    : Bus 34269	: V=0.9920842, theta=-27.609615 -> V=1.0, theta=0.0
% INFO    : Bus 34270	: V=0.97651, theta=-29.590162 -> V=1.0, theta=0.0
% INFO    : Bus 34271	: V=0.9797677, theta=-29.259206 -> V=1.0, theta=0.0
% INFO    : Bus 34272	: V=0.9890875, theta=-27.810351 -> V=1.0, theta=0.0
% INFO    : Bus 34273	: V=0.9753314, theta=-30.435405 -> V=1.0, theta=0.0
% INFO    : Bus 34274	: V=0.976915, theta=-30.421649 -> V=1.0, theta=0.0
% INFO    : Bus 34275	: V=0.9777658, theta=-30.193711 -> V=1.0, theta=0.0
% INFO    : Bus 34276	: V=0.9806217, theta=-29.829109 -> V=1.0, theta=0.0
% INFO    : Bus 34277	: V=0.9809068, theta=-29.705123 -> V=1.0, theta=0.0
% INFO    : Bus 34278	: V=0.9821683, theta=-29.495612 -> V=1.0, theta=0.0
% INFO    : Bus 34279	: V=0.994063, theta=-28.379939 -> V=1.0, theta=0.0
% INFO    : Bus 34280	: V=0.9964175, theta=-28.338137 -> V=1.0, theta=0.0
% INFO    : Bus 34281	: V=0.9853647, theta=-29.257839 -> V=1.0, theta=0.0
% INFO    : Bus 34282	: V=0.9871365, theta=-29.318286 -> V=1.0, theta=0.0
% INFO    : Bus 34283	: V=0.9841913, theta=-29.551943 -> V=1.0, theta=0.0
% INFO    : Bus 34284	: V=0.9771758, theta=-30.198543 -> V=1.0, theta=0.0
% INFO    : Bus 34285	: V=0.9760522, theta=-30.428152 -> V=1.0, theta=0.0
% INFO    : Bus 34286	: V=1.0018785, theta=-24.571684 -> V=1.0, theta=0.0
% INFO    : Bus 34287	: V=0.986765, theta=-27.334785 -> V=1.0, theta=0.0
% INFO    : Bus 34288	: V=1.0151663, theta=-25.03753 -> V=1.0, theta=0.0
% INFO    : Bus 34289	: V=1.0120871, theta=-24.239459 -> V=1.0, theta=0.0
% INFO    : Bus 34290	: V=1.0027528, theta=-25.344556 -> V=1.0, theta=0.0
% INFO    : Bus 34291	: V=1.0157906, theta=-25.507204 -> V=1.0, theta=0.0
% INFO    : Bus 34292	: V=0.9878512, theta=-26.999654 -> V=1.0, theta=0.0
% INFO    : Bus 34293	: V=0.9527352, theta=-31.020401 -> V=1.0, theta=0.0
% INFO    : Bus 34294	: V=0.9809584, theta=-28.653664 -> V=1.0, theta=0.0
% INFO    : Bus 34295	: V=0.9852246, theta=-28.32202 -> V=1.0, theta=0.0
% INFO    : Bus 34296	: V=1.0021934, theta=-25.414919 -> V=1.0, theta=0.0
% INFO    : Bus 34297	: V=0.9877816, theta=-27.094454 -> V=1.0, theta=0.0
% INFO    : Bus 34298	: V=0.9798827, theta=-27.798954 -> V=1.0, theta=0.0
% INFO    : Bus 34299	: V=1.0155221, theta=-25.716742 -> V=1.0, theta=0.0
% INFO    : Bus 34300	: V=0.9917244, theta=-27.784716 -> V=1.0, theta=0.0
% INFO    : Bus 34301	: V=0.9683103, theta=-28.910853 -> V=1.0, theta=0.0
% INFO    : Bus 34302	: V=0.9695933, theta=-28.88013 -> V=1.0, theta=0.0
% INFO    : Bus 34303	: V=0.9754328, theta=-28.338083 -> V=1.0, theta=0.0
% INFO    : Bus 34304	: V=0.9712909, theta=-28.653018 -> V=1.0, theta=0.0
% INFO    : Bus 34305	: V=0.9668954, theta=-29.058897 -> V=1.0, theta=0.0
% INFO    : Bus 34306	: V=0.9621221, theta=-29.456749 -> V=1.0, theta=0.0
% INFO    : Bus 34307	: V=0.9635292, theta=-29.363567 -> V=1.0, theta=0.0
% INFO    : Bus 34308	: V=0.9493731, theta=-30.759133 -> V=1.0, theta=0.0
% INFO    : Bus 34309	: V=0.9563795, theta=-30.281437 -> V=1.0, theta=0.0
% INFO    : Bus 34310	: V=0.9572897, theta=-30.204013 -> V=1.0, theta=0.0
% INFO    : Bus 34311	: V=0.9541488, theta=-30.428329 -> V=1.0, theta=0.0
% INFO    : Bus 34312	: V=0.9544992, theta=-30.39413 -> V=1.0, theta=0.0
% INFO    : Bus 34313	: V=0.9562603, theta=-30.344257 -> V=1.0, theta=0.0
% INFO    : Bus 34314	: V=0.9557666, theta=-30.367464 -> V=1.0, theta=0.0
% INFO    : Bus 34315	: V=0.9576254, theta=-30.327623 -> V=1.0, theta=0.0
% INFO    : Bus 34316	: V=0.9907161, theta=-27.716298 -> V=1.0, theta=0.0
% INFO    : Bus 34317	: V=0.9686649, theta=-29.691776 -> V=1.0, theta=0.0
% INFO    : Bus 34318	: V=0.962789, theta=-30.054246 -> V=1.0, theta=0.0
% INFO    : Bus 34319	: V=0.9619802, theta=-30.004037 -> V=1.0, theta=0.0
% INFO    : Bus 34320	: V=0.9645615, theta=-29.96135 -> V=1.0, theta=0.0
% INFO    : Bus 34321	: V=0.9609354, theta=-30.154228 -> V=1.0, theta=0.0
% INFO    : Bus 34322	: V=0.9615151, theta=-30.116368 -> V=1.0, theta=0.0
% INFO    : Bus 34323	: V=0.9636339, theta=-29.946835 -> V=1.0, theta=0.0
% INFO    : Bus 34324	: V=0.9663852, theta=-29.669484 -> V=1.0, theta=0.0
% INFO    : Bus 34325	: V=0.9666393, theta=-29.648492 -> V=1.0, theta=0.0
% INFO    : Bus 34326	: V=0.9664889, theta=-29.640827 -> V=1.0, theta=0.0
% INFO    : Bus 34327	: V=0.966304, theta=-29.658594 -> V=1.0, theta=0.0
% INFO    : Bus 34328	: V=0.9688464, theta=-29.285232 -> V=1.0, theta=0.0
% INFO    : Bus 34329	: V=0.9748589, theta=-29.202077 -> V=1.0, theta=0.0
% INFO    : Bus 34330	: V=0.9980735, theta=-26.652282 -> V=1.0, theta=0.0
% INFO    : Bus 34331	: V=0.9973817, theta=-29.525387 -> V=1.0, theta=0.0
% INFO    : Bus 34332	: V=1.0127596, theta=-27.154057 -> V=1.0, theta=0.0
% INFO    : Bus 34333	: V=1.0150502, theta=-26.819394 -> V=1.0, theta=0.0
% INFO    : Bus 34334	: V=0.9633642, theta=-31.147502 -> V=1.0, theta=0.0
% INFO    : Bus 34335	: V=0.950492, theta=-32.333794 -> V=1.0, theta=0.0
% INFO    : Bus 34336	: V=0.9506445, theta=-32.305618 -> V=1.0, theta=0.0
% INFO    : Bus 34337	: V=0.9524604, theta=-32.080591 -> V=1.0, theta=0.0
% INFO    : Bus 34338	: V=0.9814626, theta=-27.997326 -> V=1.0, theta=0.0
% INFO    : Bus 34339	: V=0.9509303, theta=-32.256277 -> V=1.0, theta=0.0
% INFO    : Bus 34340	: V=0.9510599, theta=-32.206202 -> V=1.0, theta=0.0
% INFO    : Bus 34341	: V=0.9514636, theta=-32.20134 -> V=1.0, theta=0.0
% INFO    : Bus 34342	: V=0.9518969, theta=-32.122806 -> V=1.0, theta=0.0
% INFO    : Bus 34343	: V=0.9683746, theta=-31.016504 -> V=1.0, theta=0.0
% INFO    : Bus 34344	: V=0.9693653, theta=-30.985054 -> V=1.0, theta=0.0
% INFO    : Bus 34345	: V=0.9520768, theta=-31.534414 -> V=1.0, theta=0.0
% INFO    : Bus 34346	: V=0.9500637, theta=-31.939596 -> V=1.0, theta=0.0
% INFO    : Bus 34347	: V=0.9476306, theta=-32.038241 -> V=1.0, theta=0.0
% INFO    : Bus 34348	: V=0.9408188, theta=-33.081696 -> V=1.0, theta=0.0
% INFO    : Bus 34349	: V=0.9392457, theta=-33.128608 -> V=1.0, theta=0.0
% INFO    : Bus 34350	: V=0.9456323, theta=-32.780129 -> V=1.0, theta=0.0
% INFO    : Bus 34351	: V=0.9460795, theta=-32.740928 -> V=1.0, theta=0.0
% INFO    : Bus 34352	: V=0.9470771, theta=-32.673305 -> V=1.0, theta=0.0
% INFO    : Bus 34353	: V=0.9792022, theta=-27.977221 -> V=1.0, theta=0.0
% INFO    : Bus 34354	: V=0.9662709, theta=-29.189339 -> V=1.0, theta=0.0
% INFO    : Bus 34355	: V=0.9637851, theta=-29.198131 -> V=1.0, theta=0.0
% INFO    : Bus 34356	: V=0.9667919, theta=-28.734407 -> V=1.0, theta=0.0
% INFO    : Bus 34357	: V=0.9707076, theta=-28.705022 -> V=1.0, theta=0.0
% INFO    : Bus 34358	: V=0.9812197, theta=-27.728848 -> V=1.0, theta=0.0
% INFO    : Bus 34359	: V=0.968998, theta=-28.301826 -> V=1.0, theta=0.0
% INFO    : Bus 34360	: V=1.0102617, theta=-24.554865 -> V=1.0, theta=0.0
% INFO    : Bus 34361	: V=0.9617893, theta=-30.584989 -> V=1.0, theta=0.0
% INFO    : Bus 34362	: V=0.9563198, theta=-30.778543 -> V=1.0, theta=0.0
% INFO    : Bus 34363	: V=0.960246, theta=-30.760487 -> V=1.0, theta=0.0
% INFO    : Bus 34364	: V=0.9667012, theta=-29.747372 -> V=1.0, theta=0.0
% INFO    : Bus 34365	: V=0.971499, theta=-29.125741 -> V=1.0, theta=0.0
% INFO    : Bus 34366	: V=0.9736327, theta=-28.843288 -> V=1.0, theta=0.0
% INFO    : Bus 34367	: V=0.9761352, theta=-28.519568 -> V=1.0, theta=0.0
% INFO    : Bus 34368	: V=0.9594941, theta=-30.478239 -> V=1.0, theta=0.0
% INFO    : Bus 34369	: V=0.9692398, theta=-29.281136 -> V=1.0, theta=0.0
% INFO    : Bus 34370	: V=0.9578171, theta=-30.543825 -> V=1.0, theta=0.0
% INFO    : Bus 34371	: V=0.9558294, theta=-30.904751 -> V=1.0, theta=0.0
% INFO    : Bus 34372	: V=0.9548639, theta=-30.785882 -> V=1.0, theta=0.0
% INFO    : Bus 34373	: V=0.9503425, theta=-32.103668 -> V=1.0, theta=0.0
% INFO    : Bus 34374	: V=0.9575554, theta=-30.490642 -> V=1.0, theta=0.0
% INFO    : Bus 34375	: V=0.9574152, theta=-30.498633 -> V=1.0, theta=0.0
% INFO    : Bus 34376	: V=0.948365, theta=-30.864845 -> V=1.0, theta=0.0
% INFO    : Bus 34377	: V=0.9488198, theta=-30.97905 -> V=1.0, theta=0.0
% INFO    : Bus 34378	: V=0.9545643, theta=-30.715255 -> V=1.0, theta=0.0
% INFO    : Bus 34379	: V=0.9507385, theta=-31.042095 -> V=1.0, theta=0.0
% INFO    : Bus 34380	: V=0.9678058, theta=-29.476523 -> V=1.0, theta=0.0
% INFO    : Bus 34381	: V=0.9680025, theta=-29.514147 -> V=1.0, theta=0.0
% INFO    : Bus 34382	: V=0.952827, theta=-30.723318 -> V=1.0, theta=0.0
% INFO    : Bus 34383	: V=0.953587, theta=-30.691597 -> V=1.0, theta=0.0
% INFO    : Bus 34384	: V=0.958139, theta=-30.306506 -> V=1.0, theta=0.0
% INFO    : Bus 34385	: V=0.9574113, theta=-30.496427 -> V=1.0, theta=0.0
% INFO    : Bus 34386	: V=0.9669662, theta=-29.600189 -> V=1.0, theta=0.0
% INFO    : Bus 34387	: V=0.9691773, theta=-29.654782 -> V=1.0, theta=0.0
% INFO    : Bus 34388	: V=0.9689346, theta=-29.631685 -> V=1.0, theta=0.0
% INFO    : Bus 34389	: V=0.9687704, theta=-29.600011 -> V=1.0, theta=0.0
% INFO    : Bus 34390	: V=0.9687561, theta=-29.566241 -> V=1.0, theta=0.0
% INFO    : Bus 34391	: V=0.9626906, theta=-30.264435 -> V=1.0, theta=0.0
% INFO    : Bus 34392	: V=1.0114213, theta=-24.327688 -> V=1.0, theta=0.0
% INFO    : Bus 34393	: V=0.9603731, theta=-30.528052 -> V=1.0, theta=0.0
% INFO    : Bus 34394	: V=0.9578529, theta=-30.796136 -> V=1.0, theta=0.0
% INFO    : Bus 34395	: V=0.9574994, theta=-31.009736 -> V=1.0, theta=0.0
% INFO    : Bus 34396	: V=0.9523584, theta=-32.270321 -> V=1.0, theta=0.0
% INFO    : Bus 34397	: V=0.9495844, theta=-32.503633 -> V=1.0, theta=0.0
% INFO    : Bus 34398	: V=0.9580003, theta=-30.363205 -> V=1.0, theta=0.0
% INFO    : Bus 34399	: V=0.9536906, theta=-30.648783 -> V=1.0, theta=0.0
% INFO    : Bus 34400	: V=0.9490056, theta=-30.893775 -> V=1.0, theta=0.0
% INFO    : Bus 34401	: V=0.9478977, theta=-32.669634 -> V=1.0, theta=0.0
% INFO    : Bus 34402	: V=0.9513807, theta=-30.846868 -> V=1.0, theta=0.0
% INFO    : Bus 34403	: V=0.9684868, theta=-29.678935 -> V=1.0, theta=0.0
% INFO    : Bus 34404	: V=0.9712503, theta=-29.43689 -> V=1.0, theta=0.0
% INFO    : Bus 34405	: V=0.9474516, theta=-32.685143 -> V=1.0, theta=0.0
% INFO    : Bus 34406	: V=0.9485161, theta=-32.532242 -> V=1.0, theta=0.0
% INFO    : Bus 34407	: V=0.9463332, theta=-32.718308 -> V=1.0, theta=0.0
% INFO    : Bus 34408	: V=0.9462386, theta=-32.719502 -> V=1.0, theta=0.0
% INFO    : Bus 34409	: V=0.9496642, theta=-30.855637 -> V=1.0, theta=0.0
% INFO    : Bus 34410	: V=0.9863454, theta=-26.757677 -> V=1.0, theta=0.0
% INFO    : Bus 34411	: V=0.9508679, theta=-32.301919 -> V=1.0, theta=0.0
% INFO    : Bus 34412	: V=0.9668623, theta=-31.060197 -> V=1.0, theta=0.0
% INFO    : Bus 34413	: V=0.9506656, theta=-32.220542 -> V=1.0, theta=0.0
% INFO    : Bus 34414	: V=0.9706607, theta=-31.046566 -> V=1.0, theta=0.0
% INFO    : Bus 34415	: V=0.9568131, theta=-30.876921 -> V=1.0, theta=0.0
% INFO    : Bus 34416	: V=1.0102688, theta=-24.487676 -> V=1.0, theta=0.0
% INFO    : Bus 34417	: V=0.967869, theta=-29.371606 -> V=1.0, theta=0.0
% INFO    : Bus 34418	: V=0.9747783, theta=-28.544619 -> V=1.0, theta=0.0
% INFO    : Bus 34419	: V=0.9800728, theta=-42.219385 -> V=1.0, theta=0.0
% INFO    : Bus 34420	: V=0.9868414, theta=-41.364821 -> V=1.0, theta=0.0
% INFO    : Bus 34421	: V=0.9934458, theta=-39.494039 -> V=1.0, theta=0.0
% INFO    : Bus 34422	: V=0.9905203, theta=-40.875554 -> V=1.0, theta=0.0
% INFO    : Bus 34423	: V=1.0021674, theta=-39.323642 -> V=1.0, theta=0.0
% INFO    : Bus 34424	: V=1.0169983, theta=-36.730094 -> V=1.0, theta=0.0
% INFO    : Bus 34425	: V=0.999593, theta=-36.902685 -> V=1.0, theta=0.0
% INFO    : Bus 34426	: V=0.9815581, theta=-41.49026 -> V=1.0, theta=0.0
% INFO    : Bus 34427	: V=0.9975394, theta=-39.893483 -> V=1.0, theta=0.0
% INFO    : Bus 34428	: V=1.0056073, theta=-38.867946 -> V=1.0, theta=0.0
% INFO    : Bus 34429	: V=0.9916012, theta=-40.388143 -> V=1.0, theta=0.0
% INFO    : Bus 34430	: V=1.0002054, theta=-38.890491 -> V=1.0, theta=0.0
% INFO    : Bus 34431	: V=0.9681943, theta=-43.69354 -> V=1.0, theta=0.0
% INFO    : Bus 34432	: V=0.9814524, theta=-35.329146 -> V=1.0, theta=0.0
% INFO    : Bus 34433	: V=0.979515, theta=-35.284596 -> V=1.0, theta=0.0
% INFO    : Bus 34434	: V=0.9817021, theta=-35.442638 -> V=1.0, theta=0.0
% INFO    : Bus 34435	: V=0.9834509, theta=-35.708482 -> V=1.0, theta=0.0
% INFO    : Bus 34436	: V=0.9543919, theta=-37.504059 -> V=1.0, theta=0.0
% INFO    : Bus 34437	: V=0.9806255, theta=-34.808578 -> V=1.0, theta=0.0
% INFO    : Bus 34438	: V=1.0021332, theta=-32.704263 -> V=1.0, theta=0.0
% INFO    : Bus 34439	: V=0.9801469, theta=-35.101568 -> V=1.0, theta=0.0
% INFO    : Bus 34440	: V=0.978195, theta=-35.924858 -> V=1.0, theta=0.0
% INFO    : Bus 34441	: V=1.0036524, theta=-32.893857 -> V=1.0, theta=0.0
% INFO    : Bus 34442	: V=1.0119069, theta=-32.550374 -> V=1.0, theta=0.0
% INFO    : Bus 34443	: V=0.970498, theta=-32.752634 -> V=1.0, theta=0.0
% INFO    : Bus 34444	: V=0.974414, theta=-31.70933 -> V=1.0, theta=0.0
% INFO    : Bus 34445	: V=0.9852078, theta=-29.773511 -> V=1.0, theta=0.0
% INFO    : Bus 34446	: V=0.9647307, theta=-32.626379 -> V=1.0, theta=0.0
% INFO    : Bus 34447	: V=0.9607836, theta=-33.212928 -> V=1.0, theta=0.0
% INFO    : Bus 34448	: V=0.9502689, theta=-34.512518 -> V=1.0, theta=0.0
% INFO    : Bus 34449	: V=0.958559, theta=-33.515028 -> V=1.0, theta=0.0
% INFO    : Bus 34450	: V=0.9691908, theta=-33.322359 -> V=1.0, theta=0.0
% INFO    : Bus 34451	: V=1.0041843, theta=-26.784396 -> V=1.0, theta=0.0
% INFO    : Bus 34452	: V=1.0014759, theta=-27.526025 -> V=1.0, theta=0.0
% INFO    : Bus 34453	: V=0.9572554, theta=-31.213375 -> V=1.0, theta=0.0
% INFO    : Bus 34454	: V=0.9600041, theta=-30.60854 -> V=1.0, theta=0.0
% INFO    : Bus 34455	: V=0.9671735, theta=-29.65653 -> V=1.0, theta=0.0
% INFO    : Bus 34456	: V=0.9847194, theta=-28.421498 -> V=1.0, theta=0.0
% INFO    : Bus 34457	: V=0.9879394, theta=-26.674649 -> V=1.0, theta=0.0
% INFO    : Bus 34458	: V=0.9935812, theta=-26.535425 -> V=1.0, theta=0.0
% INFO    : Bus 34459	: V=0.9922693, theta=-26.184409 -> V=1.0, theta=0.0
% INFO    : Bus 34460	: V=0.9947537, theta=-26.079763 -> V=1.0, theta=0.0
% INFO    : Bus 34461	: V=0.9915144, theta=-26.427773 -> V=1.0, theta=0.0
% INFO    : Bus 34462	: V=0.9940648, theta=-27.292176 -> V=1.0, theta=0.0
% INFO    : Bus 34463	: V=0.999679, theta=-26.238205 -> V=1.0, theta=0.0
% INFO    : Bus 34464	: V=0.9877106, theta=-27.81836 -> V=1.0, theta=0.0
% INFO    : Bus 34465	: V=0.9816975, theta=-28.106319 -> V=1.0, theta=0.0
% INFO    : Bus 34466	: V=0.9984283, theta=-27.074406 -> V=1.0, theta=0.0
% INFO    : Bus 34467	: V=0.9841707, theta=-28.264847 -> V=1.0, theta=0.0
% INFO    : Bus 34468	: V=1.0088543, theta=-26.59973 -> V=1.0, theta=0.0
% INFO    : Bus 34469	: V=1.0047446, theta=-26.81033 -> V=1.0, theta=0.0
% INFO    : Bus 34470	: V=0.99478, theta=-27.574317 -> V=1.0, theta=0.0
% INFO    : Bus 34471	: V=0.9832612, theta=-28.455587 -> V=1.0, theta=0.0
% INFO    : Bus 34472	: V=1.011952, theta=-24.418382 -> V=1.0, theta=0.0
% INFO    : Bus 34473	: V=0.9718619, theta=-28.900701 -> V=1.0, theta=0.0
% INFO    : Bus 34474	: V=0.9900443, theta=-27.996448 -> V=1.0, theta=0.0
% INFO    : Bus 34475	: V=1.0105431, theta=-26.210094 -> V=1.0, theta=0.0
% INFO    : Bus 34476	: V=1.0028756, theta=-27.288369 -> V=1.0, theta=0.0
% INFO    : Bus 34477	: V=1.0035497, theta=-27.266921 -> V=1.0, theta=0.0
% INFO    : Bus 34478	: V=1.0128214, theta=-25.540837 -> V=1.0, theta=0.0
% INFO    : Bus 34479	: V=1.000048, theta=-27.669506 -> V=1.0, theta=0.0
% INFO    : Bus 34480	: V=0.9803026, theta=-29.663989 -> V=1.0, theta=0.0
% INFO    : Bus 34481	: V=0.98659, theta=-28.712752 -> V=1.0, theta=0.0
% INFO    : Bus 34482	: V=0.9623848, theta=-31.417392 -> V=1.0, theta=0.0
% INFO    : Bus 34483	: V=0.9660773, theta=-31.231714 -> V=1.0, theta=0.0
% INFO    : Bus 34484	: V=0.9668727, theta=-31.091975 -> V=1.0, theta=0.0
% INFO    : Bus 34485	: V=0.9550564, theta=-32.054264 -> V=1.0, theta=0.0
% INFO    : Bus 34486	: V=0.9660134, theta=-31.290174 -> V=1.0, theta=0.0
% INFO    : Bus 34487	: V=0.9911554, theta=-28.258274 -> V=1.0, theta=0.0
% INFO    : Bus 34488	: V=0.9683095, theta=-30.336301 -> V=1.0, theta=0.0
% INFO    : Bus 34489	: V=0.9478523, theta=-36.887879 -> V=1.0, theta=0.0
% INFO    : Bus 34490	: V=0.9420798, theta=-37.946432 -> V=1.0, theta=0.0
% INFO    : Bus 34491	: V=0.9453078, theta=-37.278759 -> V=1.0, theta=0.0
% INFO    : Bus 34492	: V=0.9397083, theta=-37.687372 -> V=1.0, theta=0.0
% INFO    : Bus 34493	: V=0.9415855, theta=-37.906903 -> V=1.0, theta=0.0
% INFO    : Bus 34494	: V=0.9445307, theta=-36.304871 -> V=1.0, theta=0.0
% INFO    : Bus 34495	: V=1.0061719, theta=-26.755643 -> V=1.0, theta=0.0
% INFO    : Bus 34496	: V=0.9912449, theta=-27.888994 -> V=1.0, theta=0.0
% INFO    : Bus 34497	: V=0.9909252, theta=-28.126318 -> V=1.0, theta=0.0
% INFO    : Bus 34498	: V=0.9744916, theta=-29.013898 -> V=1.0, theta=0.0
% INFO    : Bus 34499	: V=0.9590688, theta=-30.237206 -> V=1.0, theta=0.0
% INFO    : Bus 34500	: V=0.9486108, theta=-30.807297 -> V=1.0, theta=0.0
% INFO    : Bus 34501	: V=0.9511529, theta=-30.717498 -> V=1.0, theta=0.0
% INFO    : Bus 34502	: V=0.9508629, theta=-30.686883 -> V=1.0, theta=0.0
% INFO    : Bus 34503	: V=0.9657584, theta=-29.18468 -> V=1.0, theta=0.0
% INFO    : Bus 34504	: V=0.9643568, theta=-29.282991 -> V=1.0, theta=0.0
% INFO    : Bus 34505	: V=0.9534997, theta=-30.49665 -> V=1.0, theta=0.0
% INFO    : Bus 34506	: V=0.9531829, theta=-30.500482 -> V=1.0, theta=0.0
% INFO    : Bus 34507	: V=0.9606594, theta=-29.565261 -> V=1.0, theta=0.0
% INFO    : Bus 34508	: V=0.9561721, theta=-30.509069 -> V=1.0, theta=0.0
% INFO    : Bus 34509	: V=0.9488835, theta=-30.79559 -> V=1.0, theta=0.0
% INFO    : Bus 34510	: V=0.9497782, theta=-30.734797 -> V=1.0, theta=0.0
% INFO    : Bus 34511	: V=0.952196, theta=-30.569538 -> V=1.0, theta=0.0
% INFO    : Bus 34512	: V=0.9555236, theta=-30.221013 -> V=1.0, theta=0.0
% INFO    : Bus 34513	: V=0.9472678, theta=-30.956251 -> V=1.0, theta=0.0
% INFO    : Bus 34514	: V=0.956137, theta=-30.190717 -> V=1.0, theta=0.0
% INFO    : Bus 34515	: V=0.9568617, theta=-30.154973 -> V=1.0, theta=0.0
% INFO    : Bus 34516	: V=0.9583386, theta=-30.060538 -> V=1.0, theta=0.0
% INFO    : Bus 34517	: V=0.9602894, theta=-29.935579 -> V=1.0, theta=0.0
% INFO    : Bus 34518	: V=0.9475448, theta=-30.972663 -> V=1.0, theta=0.0
% INFO    : Bus 34519	: V=0.962836, theta=-29.745006 -> V=1.0, theta=0.0
% INFO    : Bus 34520	: V=0.9931316, theta=-29.351526 -> V=1.0, theta=0.0
% INFO    : Bus 34521	: V=1.0033652, theta=-27.919562 -> V=1.0, theta=0.0
% INFO    : Bus 34522	: V=0.9702804, theta=-31.685088 -> V=1.0, theta=0.0
% INFO    : Bus 34523	: V=0.9601659, theta=-32.263158 -> V=1.0, theta=0.0
% INFO    : Bus 34524	: V=0.9602343, theta=-32.17157 -> V=1.0, theta=0.0
% INFO    : Bus 34525	: V=0.988509, theta=-29.508041 -> V=1.0, theta=0.0
% INFO    : Bus 34526	: V=0.9986841, theta=-29.864529 -> V=1.0, theta=0.0
% INFO    : Bus 34527	: V=0.9822971, theta=-33.586445 -> V=1.0, theta=0.0
% INFO    : Bus 34528	: V=0.9770451, theta=-33.144934 -> V=1.0, theta=0.0
% INFO    : Bus 34529	: V=0.9845079, theta=-32.669591 -> V=1.0, theta=0.0
% INFO    : Bus 34530	: V=1.0097176, theta=-28.202276 -> V=1.0, theta=0.0
% INFO    : Bus 34531	: V=0.9737829, theta=-30.611473 -> V=1.0, theta=0.0
% INFO    : Bus 34532	: V=0.9723626, theta=-30.720658 -> V=1.0, theta=0.0
% INFO    : Bus 34533	: V=0.9877862, theta=-28.656261 -> V=1.0, theta=0.0
% INFO    : Bus 34534	: V=0.9759914, theta=-30.464045 -> V=1.0, theta=0.0
% INFO    : Bus 34535	: V=0.9565494, theta=-32.597236 -> V=1.0, theta=0.0
% INFO    : Bus 34536	: V=0.9676671, theta=-31.602558 -> V=1.0, theta=0.0
% INFO    : Bus 34537	: V=0.9897766, theta=-30.596578 -> V=1.0, theta=0.0
% INFO    : Bus 34538	: V=0.9572217, theta=-32.225927 -> V=1.0, theta=0.0
% INFO    : Bus 34539	: V=0.9787393, theta=-30.771337 -> V=1.0, theta=0.0
% INFO    : Bus 34540	: V=0.958223, theta=-32.460185 -> V=1.0, theta=0.0
% INFO    : Bus 34541	: V=0.9771931, theta=-30.648326 -> V=1.0, theta=0.0
% INFO    : Bus 34542	: V=0.961323, theta=-32.125116 -> V=1.0, theta=0.0
% INFO    : Bus 34543	: V=0.9750783, theta=-30.570872 -> V=1.0, theta=0.0
% INFO    : Bus 34544	: V=0.9626873, theta=-31.841181 -> V=1.0, theta=0.0
% INFO    : Bus 34545	: V=0.9731909, theta=-30.701964 -> V=1.0, theta=0.0
% INFO    : Bus 34546	: V=0.9717588, theta=-30.792076 -> V=1.0, theta=0.0
% INFO    : Bus 34547	: V=0.9716385, theta=-30.833978 -> V=1.0, theta=0.0
% INFO    : Bus 34548	: V=0.965242, theta=-31.568575 -> V=1.0, theta=0.0
% INFO    : Bus 34549	: V=0.9650209, theta=-31.589705 -> V=1.0, theta=0.0
% INFO    : Bus 34550	: V=0.9640702, theta=-31.459483 -> V=1.0, theta=0.0
% INFO    : Bus 34551	: V=0.9548991, theta=-32.394489 -> V=1.0, theta=0.0
% INFO    : Bus 34552	: V=0.9662559, theta=-32.365794 -> V=1.0, theta=0.0
% INFO    : Bus 34553	: V=0.9940885, theta=-30.695047 -> V=1.0, theta=0.0
% INFO    : Bus 34554	: V=0.960963, theta=-32.400592 -> V=1.0, theta=0.0
% INFO    : Bus 34555	: V=0.9636534, theta=-32.890951 -> V=1.0, theta=0.0
% INFO    : Bus 34556	: V=0.9499095, theta=-32.198489 -> V=1.0, theta=0.0
% INFO    : Bus 34557	: V=0.9691408, theta=-29.913849 -> V=1.0, theta=0.0
% INFO    : Bus 34558	: V=0.9537512, theta=-32.034501 -> V=1.0, theta=0.0
% INFO    : Bus 34559	: V=0.9660326, theta=-30.403864 -> V=1.0, theta=0.0
% INFO    : Bus 34560	: V=0.9561898, theta=-31.591074 -> V=1.0, theta=0.0
% INFO    : Bus 34561	: V=0.9531244, theta=-31.516743 -> V=1.0, theta=0.0
% INFO    : Bus 34562	: V=0.9530283, theta=-31.497697 -> V=1.0, theta=0.0
% INFO    : Bus 34563	: V=0.9616397, theta=-32.204248 -> V=1.0, theta=0.0
% INFO    : Bus 34564	: V=0.9602404, theta=-32.276205 -> V=1.0, theta=0.0
% INFO    : Bus 34565	: V=1.0117404, theta=-25.083829 -> V=1.0, theta=0.0
% INFO    : Bus 34566	: V=0.9893397, theta=-27.778629 -> V=1.0, theta=0.0
% INFO    : Bus 34567	: V=0.9961543, theta=-27.380554 -> V=1.0, theta=0.0
% INFO    : Bus 34568	: V=0.9945348, theta=-28.049607 -> V=1.0, theta=0.0
% INFO    : Bus 34569	: V=0.9843354, theta=-27.172083 -> V=1.0, theta=0.0
% INFO    : Bus 34570	: V=0.9722487, theta=-32.193128 -> V=1.0, theta=0.0
% INFO    : Bus 34571	: V=0.9684316, theta=-32.56201 -> V=1.0, theta=0.0
% INFO    : Bus 34572	: V=0.979026, theta=-30.847923 -> V=1.0, theta=0.0
% INFO    : Bus 34573	: V=0.9782911, theta=-29.441663 -> V=1.0, theta=0.0
% INFO    : Bus 34574	: V=0.978392, theta=-29.240188 -> V=1.0, theta=0.0
% INFO    : Bus 34575	: V=1.0204134, theta=-23.482427 -> V=1.0, theta=0.0
% INFO    : Bus 34576	: V=1.0115335, theta=-24.676654 -> V=1.0, theta=0.0
% INFO    : Bus 34577	: V=1.0105467, theta=-24.67167 -> V=1.0, theta=0.0
% INFO    : Bus 34578	: V=0.9535108, theta=-44.224845 -> V=1.0, theta=0.0
% INFO    : Bus 34579	: V=0.9540026, theta=-44.102009 -> V=1.0, theta=0.0
% INFO    : Bus 34580	: V=0.9546101, theta=-44.051192 -> V=1.0, theta=0.0
% INFO    : Bus 34581	: V=0.9555705, theta=-43.842335 -> V=1.0, theta=0.0
% INFO    : Bus 34582	: V=0.9545306, theta=-44.071153 -> V=1.0, theta=0.0
% INFO    : Bus 34583	: V=0.9566188, theta=-43.67477 -> V=1.0, theta=0.0
% INFO    : Bus 34584	: V=0.9546727, theta=-44.085653 -> V=1.0, theta=0.0
% INFO    : Bus 34585	: V=0.9541408, theta=-44.14062 -> V=1.0, theta=0.0
% INFO    : Bus 34586	: V=0.95851, theta=-43.015636 -> V=1.0, theta=0.0
% INFO    : Bus 34587	: V=0.9536964, theta=-44.153459 -> V=1.0, theta=0.0
% INFO    : Bus 34588	: V=0.9510815, theta=-44.676987 -> V=1.0, theta=0.0
% INFO    : Bus 34589	: V=0.9529844, theta=-44.318496 -> V=1.0, theta=0.0
% INFO    : Bus 34590	: V=0.9531029, theta=-44.287829 -> V=1.0, theta=0.0
% INFO    : Bus 34591	: V=0.9549079, theta=-44.15558 -> V=1.0, theta=0.0
% INFO    : Bus 34592	: V=0.9575871, theta=-43.83444 -> V=1.0, theta=0.0
% INFO    : Bus 34593	: V=0.9583391, theta=-43.6462 -> V=1.0, theta=0.0
% INFO    : Bus 34594	: V=0.9613363, theta=-43.378833 -> V=1.0, theta=0.0
% INFO    : Bus 34595	: V=0.9469134, theta=-45.107175 -> V=1.0, theta=0.0
% INFO    : Bus 34596	: V=0.948414, theta=-44.993868 -> V=1.0, theta=0.0
% INFO    : Bus 34597	: V=0.9486342, theta=-44.979956 -> V=1.0, theta=0.0
% INFO    : Bus 34598	: V=0.9530558, theta=-44.503769 -> V=1.0, theta=0.0
% INFO    : Bus 34599	: V=0.9497575, theta=-44.81811 -> V=1.0, theta=0.0
% INFO    : Bus 34600	: V=0.9583328, theta=-43.79064 -> V=1.0, theta=0.0
% INFO    : Bus 34601	: V=0.960041, theta=-43.578881 -> V=1.0, theta=0.0
% INFO    : Bus 34602	: V=0.9514101, theta=-44.684017 -> V=1.0, theta=0.0
% INFO    : Bus 34603	: V=0.9512318, theta=-44.704485 -> V=1.0, theta=0.0
% INFO    : Bus 34604	: V=0.9619151, theta=-43.308749 -> V=1.0, theta=0.0
% INFO    : Bus 34605	: V=0.9659995, theta=-42.604116 -> V=1.0, theta=0.0
% INFO    : Bus 34606	: V=0.9688271, theta=-41.111416 -> V=1.0, theta=0.0
% INFO    : Bus 34607	: V=0.9652499, theta=-42.825168 -> V=1.0, theta=0.0
% INFO    : Bus 34608	: V=0.9580106, theta=-43.619965 -> V=1.0, theta=0.0
% INFO    : Bus 34609	: V=0.955552, theta=-43.766924 -> V=1.0, theta=0.0
% INFO    : Bus 34610	: V=0.956341, theta=-43.709719 -> V=1.0, theta=0.0
% INFO    : Bus 34611	: V=0.9586366, theta=-43.499131 -> V=1.0, theta=0.0
% INFO    : Bus 34612	: V=0.9683928, theta=-41.835372 -> V=1.0, theta=0.0
% INFO    : Bus 34613	: V=0.9562713, theta=-43.826929 -> V=1.0, theta=0.0
% INFO    : Bus 34614	: V=0.9631101, theta=-42.403344 -> V=1.0, theta=0.0
% INFO    : Bus 34615	: V=0.9570968, theta=-43.613445 -> V=1.0, theta=0.0
% INFO    : Bus 34616	: V=0.9557133, theta=-43.687003 -> V=1.0, theta=0.0
% INFO    : Bus 34617	: V=0.9611863, theta=-42.692456 -> V=1.0, theta=0.0
% INFO    : Bus 34618	: V=0.9556102, theta=-43.962694 -> V=1.0, theta=0.0
% INFO    : Bus 34619	: V=0.9594265, theta=-42.91377 -> V=1.0, theta=0.0
% INFO    : Bus 34620	: V=0.9529199, theta=-44.420633 -> V=1.0, theta=0.0
% INFO    : Bus 34621	: V=0.9548328, theta=-44.220725 -> V=1.0, theta=0.0
% INFO    : Bus 34622	: V=0.9654596, theta=-42.644229 -> V=1.0, theta=0.0
% INFO    : Bus 34623	: V=0.9544563, theta=-44.389652 -> V=1.0, theta=0.0
% INFO    : Bus 34624	: V=0.9509196, theta=-45.13043 -> V=1.0, theta=0.0
% INFO    : Bus 34625	: V=0.9514981, theta=-45.095262 -> V=1.0, theta=0.0
% INFO    : Bus 34626	: V=0.9514623, theta=-44.862884 -> V=1.0, theta=0.0
% INFO    : Bus 34627	: V=0.9510143, theta=-45.023376 -> V=1.0, theta=0.0
% INFO    : Bus 34628	: V=0.9488404, theta=-44.984972 -> V=1.0, theta=0.0
% INFO    : Bus 34629	: V=0.948926, theta=-45.062085 -> V=1.0, theta=0.0
% INFO    : Bus 34630	: V=0.9579557, theta=-42.80596 -> V=1.0, theta=0.0
% INFO    : Bus 34631	: V=0.9558773, theta=-44.178529 -> V=1.0, theta=0.0
% INFO    : Bus 34632	: V=0.957305, theta=-43.979998 -> V=1.0, theta=0.0
% INFO    : Bus 34633	: V=0.9504123, theta=-44.773582 -> V=1.0, theta=0.0
% INFO    : Bus 34634	: V=0.9521519, theta=-44.537088 -> V=1.0, theta=0.0
% INFO    : Bus 34635	: V=0.9618306, theta=-42.695094 -> V=1.0, theta=0.0
% INFO    : Bus 34636	: V=0.9599108, theta=-42.918167 -> V=1.0, theta=0.0
% INFO    : Bus 34637	: V=0.9585862, theta=-43.858635 -> V=1.0, theta=0.0
% INFO    : Bus 34638	: V=0.9550926, theta=-44.32299 -> V=1.0, theta=0.0
% INFO    : Bus 34639	: V=0.957274, theta=-44.058581 -> V=1.0, theta=0.0
% INFO    : Bus 34640	: V=0.9708269, theta=-41.780986 -> V=1.0, theta=0.0
% INFO    : Bus 34641	: V=0.9673609, theta=-41.674304 -> V=1.0, theta=0.0
% INFO    : Bus 34642	: V=0.9568915, theta=-43.433379 -> V=1.0, theta=0.0
% INFO    : Bus 34643	: V=0.9614296, theta=-43.626805 -> V=1.0, theta=0.0
% INFO    : Bus 34644	: V=0.9602745, theta=-43.746387 -> V=1.0, theta=0.0
% INFO    : Bus 34645	: V=0.9552855, theta=-43.540829 -> V=1.0, theta=0.0
% INFO    : Bus 34646	: V=0.9607482, theta=-43.508261 -> V=1.0, theta=0.0
% INFO    : Bus 34647	: V=0.9795487, theta=-40.246619 -> V=1.0, theta=0.0
% INFO    : Bus 34648	: V=0.9567616, theta=-44.638323 -> V=1.0, theta=0.0
% INFO    : Bus 34649	: V=0.9621081, theta=-43.443919 -> V=1.0, theta=0.0
% INFO    : Bus 34650	: V=0.9629653, theta=-43.283636 -> V=1.0, theta=0.0
% INFO    : Bus 34651	: V=0.9741721, theta=-41.101416 -> V=1.0, theta=0.0
% INFO    : Bus 34652	: V=0.9635099, theta=-42.99384 -> V=1.0, theta=0.0
% INFO    : Bus 34653	: V=0.9587775, theta=-43.446027 -> V=1.0, theta=0.0
% INFO    : Bus 34654	: V=0.9652093, theta=-42.701655 -> V=1.0, theta=0.0
% INFO    : Bus 34655	: V=0.9649849, theta=-42.583326 -> V=1.0, theta=0.0
% INFO    : Bus 34656	: V=0.9674999, theta=-42.26015 -> V=1.0, theta=0.0
% INFO    : Bus 34657	: V=0.9649771, theta=-42.679421 -> V=1.0, theta=0.0
% INFO    : Bus 34658	: V=0.9648265, theta=-43.008783 -> V=1.0, theta=0.0
% INFO    : Bus 34659	: V=0.9695714, theta=-41.851243 -> V=1.0, theta=0.0
% INFO    : Bus 34660	: V=0.9633714, theta=-42.66383 -> V=1.0, theta=0.0
% INFO    : Bus 34661	: V=0.9651039, theta=-42.351324 -> V=1.0, theta=0.0
% INFO    : Bus 34662	: V=0.9675514, theta=-41.9562 -> V=1.0, theta=0.0
% INFO    : Bus 34663	: V=0.9751162, theta=-40.805946 -> V=1.0, theta=0.0
% INFO    : Bus 34664	: V=0.9757881, theta=-39.850616 -> V=1.0, theta=0.0
% INFO    : Bus 34665	: V=0.985211, theta=-38.999709 -> V=1.0, theta=0.0
% INFO    : Bus 34666	: V=0.9848406, theta=-39.282326 -> V=1.0, theta=0.0
% INFO    : Bus 34667	: V=0.9682715, theta=-42.08532 -> V=1.0, theta=0.0
% INFO    : Bus 34668	: V=0.998539, theta=-37.413298 -> V=1.0, theta=0.0
% INFO    : Bus 34669	: V=0.9693607, theta=-40.983668 -> V=1.0, theta=0.0
% INFO    : Bus 34670	: V=0.9597606, theta=-43.357128 -> V=1.0, theta=0.0
% INFO    : Bus 34671	: V=0.9610664, theta=-43.222792 -> V=1.0, theta=0.0
% INFO    : Bus 34672	: V=0.9600903, theta=-43.202561 -> V=1.0, theta=0.0
% INFO    : Bus 34673	: V=0.957821, theta=-43.51072 -> V=1.0, theta=0.0
% INFO    : Bus 34674	: V=0.9583916, theta=-43.472908 -> V=1.0, theta=0.0
% INFO    : Bus 34675	: V=0.9579141, theta=-43.499995 -> V=1.0, theta=0.0
% INFO    : Bus 34676	: V=0.9584962, theta=-43.41799 -> V=1.0, theta=0.0
% INFO    : Bus 34677	: V=0.9654847, theta=-42.255881 -> V=1.0, theta=0.0
% INFO    : Bus 34678	: V=0.9634568, theta=-42.505598 -> V=1.0, theta=0.0
% INFO    : Bus 34679	: V=0.9607663, theta=-42.418215 -> V=1.0, theta=0.0
% INFO    : Bus 34680	: V=0.952599, theta=-43.865564 -> V=1.0, theta=0.0
% INFO    : Bus 34681	: V=0.9638464, theta=-41.997957 -> V=1.0, theta=0.0
% INFO    : Bus 34682	: V=0.9522647, theta=-43.578551 -> V=1.0, theta=0.0
% INFO    : Bus 34683	: V=0.9742147, theta=-41.511995 -> V=1.0, theta=0.0
% INFO    : Bus 34684	: V=0.95471, theta=-43.615481 -> V=1.0, theta=0.0
% INFO    : Bus 34685	: V=0.9856211, theta=-40.13076 -> V=1.0, theta=0.0
% INFO    : Bus 34686	: V=0.9540174, theta=-44.100477 -> V=1.0, theta=0.0
% INFO    : Bus 34687	: V=0.9533851, theta=-44.165869 -> V=1.0, theta=0.0
% INFO    : Bus 34688	: V=0.9531225, theta=-44.339021 -> V=1.0, theta=0.0
% INFO    : Bus 34689	: V=0.9602581, theta=-38.996604 -> V=1.0, theta=0.0
% INFO    : Bus 34690	: V=0.9699023, theta=-35.473445 -> V=1.0, theta=0.0
% INFO    : Bus 34691	: V=0.9635034, theta=-39.007387 -> V=1.0, theta=0.0
% INFO    : Bus 34692	: V=0.9560728, theta=-39.462166 -> V=1.0, theta=0.0
% INFO    : Bus 34693	: V=0.9549829, theta=-39.539032 -> V=1.0, theta=0.0
% INFO    : Bus 34694	: V=0.9552729, theta=-36.821678 -> V=1.0, theta=0.0
% INFO    : Bus 34695	: V=0.9705037, theta=-34.285286 -> V=1.0, theta=0.0
% INFO    : Bus 34696	: V=0.9572247, theta=-39.190849 -> V=1.0, theta=0.0
% INFO    : Bus 34697	: V=0.9647339, theta=-38.006849 -> V=1.0, theta=0.0
% INFO    : Bus 34698	: V=1.016747, theta=-38.283603 -> V=1.0, theta=0.0
% INFO    : Bus 34699	: V=0.9669328, theta=-39.207182 -> V=1.0, theta=0.0
% INFO    : Bus 34700	: V=0.9688181, theta=-36.132827 -> V=1.0, theta=0.0
% INFO    : Bus 34701	: V=0.9768119, theta=-33.922454 -> V=1.0, theta=0.0
% INFO    : Bus 34702	: V=0.9599268, theta=-39.280416 -> V=1.0, theta=0.0
% INFO    : Bus 34703	: V=0.9917036, theta=-26.557742 -> V=1.0, theta=0.0
% INFO    : Bus 34704	: V=0.9838313, theta=-27.936228 -> V=1.0, theta=0.0
% INFO    : Bus 34705	: V=1.0001724, theta=-26.747324 -> V=1.0, theta=0.0
% INFO    : Bus 34706	: V=0.9888336, theta=-26.707901 -> V=1.0, theta=0.0
% INFO    : Bus 34707	: V=0.9882445, theta=-27.224724 -> V=1.0, theta=0.0
% INFO    : Bus 34708	: V=0.9473946, theta=-36.688827 -> V=1.0, theta=0.0
% INFO    : Bus 34709	: V=0.9475654, theta=-36.601373 -> V=1.0, theta=0.0
% INFO    : Bus 34710	: V=0.9517673, theta=-36.180178 -> V=1.0, theta=0.0
% INFO    : Bus 34711	: V=0.9717955, theta=-35.104333 -> V=1.0, theta=0.0
% INFO    : Bus 34712	: V=0.9546205, theta=-36.043832 -> V=1.0, theta=0.0
% INFO    : Bus 34713	: V=0.9590267, theta=-35.834261 -> V=1.0, theta=0.0
% INFO    : Bus 34714	: V=0.9532177, theta=-36.058811 -> V=1.0, theta=0.0
% INFO    : Bus 34715	: V=0.9603765, theta=-39.076773 -> V=1.0, theta=0.0
% INFO    : Bus 34716	: V=0.9601619, theta=-39.003061 -> V=1.0, theta=0.0
% INFO    : Bus 34717	: V=0.957329, theta=-39.56594 -> V=1.0, theta=0.0
% INFO    : Bus 34718	: V=0.9553457, theta=-39.661097 -> V=1.0, theta=0.0
% INFO    : Bus 34719	: V=0.955722, theta=-39.642893 -> V=1.0, theta=0.0
% INFO    : Bus 34720	: V=0.9544911, theta=-39.720796 -> V=1.0, theta=0.0
% INFO    : Bus 34721	: V=0.9607802, theta=-38.779902 -> V=1.0, theta=0.0
% INFO    : Bus 34722	: V=0.9617558, theta=-38.371758 -> V=1.0, theta=0.0
% INFO    : Bus 34723	: V=0.9639914, theta=-37.319779 -> V=1.0, theta=0.0
% INFO    : Bus 34724	: V=0.9717649, theta=-35.194731 -> V=1.0, theta=0.0
% INFO    : Bus 34725	: V=0.9665775, theta=-35.963284 -> V=1.0, theta=0.0
% INFO    : Bus 34726	: V=0.9677866, theta=-35.931856 -> V=1.0, theta=0.0
% INFO    : Bus 34727	: V=0.9690402, theta=-35.718126 -> V=1.0, theta=0.0
% INFO    : Bus 34728	: V=0.9703417, theta=-35.462176 -> V=1.0, theta=0.0
% INFO    : Bus 34729	: V=0.9886339, theta=-33.184915 -> V=1.0, theta=0.0
% INFO    : Bus 34730	: V=0.9907708, theta=-33.030259 -> V=1.0, theta=0.0
% INFO    : Bus 34731	: V=0.9772699, theta=-34.7051 -> V=1.0, theta=0.0
% INFO    : Bus 34732	: V=0.9728429, theta=-34.538234 -> V=1.0, theta=0.0
% INFO    : Bus 34733	: V=0.9690617, theta=-34.427673 -> V=1.0, theta=0.0
% INFO    : Bus 34734	: V=0.9645741, theta=-33.729601 -> V=1.0, theta=0.0
% INFO    : Bus 34735	: V=0.9651257, theta=-33.714087 -> V=1.0, theta=0.0
% INFO    : Bus 34736	: V=0.9656034, theta=-33.466542 -> V=1.0, theta=0.0
% INFO    : Bus 34737	: V=0.9661248, theta=-33.45176 -> V=1.0, theta=0.0
% INFO    : Bus 34738	: V=0.9684395, theta=-33.283169 -> V=1.0, theta=0.0
% INFO    : Bus 34739	: V=0.9690386, theta=-33.086084 -> V=1.0, theta=0.0
% INFO    : Bus 34740	: V=0.9696204, theta=-32.903178 -> V=1.0, theta=0.0
% INFO    : Bus 34741	: V=0.970485, theta=-32.648963 -> V=1.0, theta=0.0
% INFO    : Bus 34742	: V=0.9679732, theta=-33.521747 -> V=1.0, theta=0.0
% INFO    : Bus 34743	: V=0.9681555, theta=-33.46376 -> V=1.0, theta=0.0
% INFO    : Bus 34744	: V=0.9679495, theta=-33.567743 -> V=1.0, theta=0.0
% INFO    : Bus 34745	: V=0.9678309, theta=-34.396408 -> V=1.0, theta=0.0
% INFO    : Bus 34746	: V=0.9623018, theta=-34.230697 -> V=1.0, theta=0.0
% INFO    : Bus 34747	: V=0.965337, theta=-34.113711 -> V=1.0, theta=0.0
% INFO    : Bus 34748	: V=0.9644685, theta=-34.14604 -> V=1.0, theta=0.0
% INFO    : Bus 34749	: V=0.9676296, theta=-34.468063 -> V=1.0, theta=0.0
% INFO    : Bus 34750	: V=0.9707229, theta=-34.251556 -> V=1.0, theta=0.0
% INFO    : Bus 34751	: V=0.965682, theta=-34.610659 -> V=1.0, theta=0.0
% INFO    : Bus 34752	: V=0.9700082, theta=-34.488935 -> V=1.0, theta=0.0
% INFO    : Bus 34753	: V=0.972565, theta=-34.340298 -> V=1.0, theta=0.0
% INFO    : Bus 34754	: V=0.9712569, theta=-34.766292 -> V=1.0, theta=0.0
% INFO    : Bus 34755	: V=0.970273, theta=-35.121009 -> V=1.0, theta=0.0
% INFO    : Bus 34756	: V=0.9694161, theta=-34.817664 -> V=1.0, theta=0.0
% INFO    : Bus 34757	: V=0.9820254, theta=-33.00109 -> V=1.0, theta=0.0
% INFO    : Bus 34758	: V=0.9685418, theta=-34.328082 -> V=1.0, theta=0.0
% INFO    : Bus 34759	: V=0.9627416, theta=-37.850408 -> V=1.0, theta=0.0
% INFO    : Bus 34760	: V=0.9669333, theta=-35.33911 -> V=1.0, theta=0.0
% INFO    : Bus 34761	: V=1.0116755, theta=-32.469732 -> V=1.0, theta=0.0
% INFO    : Bus 34762	: V=0.9881073, theta=-30.785734 -> V=1.0, theta=0.0
% INFO    : Bus 34763	: V=0.9752661, theta=-34.097819 -> V=1.0, theta=0.0
% INFO    : Bus 34764	: V=0.9738981, theta=-34.26633 -> V=1.0, theta=0.0
% INFO    : Bus 34765	: V=0.9789116, theta=-34.535137 -> V=1.0, theta=0.0
% INFO    : Bus 34766	: V=0.9740902, theta=-34.171717 -> V=1.0, theta=0.0
% INFO    : Bus 34767	: V=0.9885109, theta=-34.022117 -> V=1.0, theta=0.0
% INFO    : Bus 34768	: V=0.986962, theta=-34.056903 -> V=1.0, theta=0.0
% INFO    : Bus 34769	: V=0.9859431, theta=-34.016846 -> V=1.0, theta=0.0
% INFO    : Bus 34770	: V=0.9939174, theta=-33.656927 -> V=1.0, theta=0.0
% INFO    : Bus 34771	: V=0.9692121, theta=-34.150078 -> V=1.0, theta=0.0
% INFO    : Bus 34772	: V=0.9673852, theta=-34.335763 -> V=1.0, theta=0.0
% INFO    : Bus 34773	: V=0.9760441, theta=-34.788969 -> V=1.0, theta=0.0
% INFO    : Bus 34774	: V=0.9735317, theta=-34.347951 -> V=1.0, theta=0.0
% INFO    : Bus 34775	: V=0.9620385, theta=-35.575633 -> V=1.0, theta=0.0
% INFO    : Bus 34776	: V=0.9640199, theta=-35.218914 -> V=1.0, theta=0.0
% INFO    : Bus 34777	: V=0.9671279, theta=-34.75634 -> V=1.0, theta=0.0
% INFO    : Bus 34778	: V=0.9712041, theta=-34.552301 -> V=1.0, theta=0.0
% INFO    : Bus 34779	: V=0.9933621, theta=-27.30481 -> V=1.0, theta=0.0
% INFO    : Bus 34780	: V=0.99714, theta=-26.946034 -> V=1.0, theta=0.0
% INFO    : Bus 34781	: V=1.0128696, theta=-25.154227 -> V=1.0, theta=0.0
% INFO    : Bus 34782	: V=0.9886015, theta=-28.830785 -> V=1.0, theta=0.0
% INFO    : Bus 34783	: V=0.9893073, theta=-29.307667 -> V=1.0, theta=0.0
% INFO    : Bus 34784	: V=0.947228, theta=-34.048834 -> V=1.0, theta=0.0
% INFO    : Bus 34785	: V=0.9997705, theta=-31.843646 -> V=1.0, theta=0.0
% INFO    : Bus 34786	: V=0.9837455, theta=-32.670674 -> V=1.0, theta=0.0
% INFO    : Bus 34787	: V=0.9713916, theta=-33.732699 -> V=1.0, theta=0.0
% INFO    : Bus 34788	: V=0.970846, theta=-33.826365 -> V=1.0, theta=0.0
% INFO    : Bus 34789	: V=0.9862753, theta=-31.935035 -> V=1.0, theta=0.0
% INFO    : Bus 34790	: V=0.9765872, theta=-33.017691 -> V=1.0, theta=0.0
% INFO    : Bus 34791	: V=0.9891792, theta=-31.949273 -> V=1.0, theta=0.0
% INFO    : Bus 34792	: V=0.9841959, theta=-31.167717 -> V=1.0, theta=0.0
% INFO    : Bus 34793	: V=0.9836185, theta=-31.665457 -> V=1.0, theta=0.0
% INFO    : Bus 34794	: V=0.9378902, theta=-38.27482 -> V=1.0, theta=0.0
% INFO    : Bus 34795	: V=0.9682415, theta=-33.988851 -> V=1.0, theta=0.0
% INFO    : Bus 34796	: V=0.9609556, theta=-34.299514 -> V=1.0, theta=0.0
% INFO    : Bus 34797	: V=0.9641254, theta=-33.996036 -> V=1.0, theta=0.0
% INFO    : Bus 34798	: V=0.9518321, theta=-35.167854 -> V=1.0, theta=0.0
% INFO    : Bus 34799	: V=0.9728549, theta=-32.218195 -> V=1.0, theta=0.0
% INFO    : Bus 34800	: V=0.9906728, theta=-33.737984 -> V=1.0, theta=0.0
% INFO    : Bus 34801	: V=1.0024056, theta=-32.598844 -> V=1.0, theta=0.0
% INFO    : Bus 34802	: V=0.9733292, theta=-34.705261 -> V=1.0, theta=0.0
% INFO    : Bus 34803	: V=0.9594354, theta=-35.293673 -> V=1.0, theta=0.0
% INFO    : Bus 34804	: V=0.9673549, theta=-35.024399 -> V=1.0, theta=0.0
% INFO    : Bus 34805	: V=0.9707748, theta=-34.91519 -> V=1.0, theta=0.0
% INFO    : Bus 34806	: V=0.9710346, theta=-34.910435 -> V=1.0, theta=0.0
% INFO    : Bus 34807	: V=0.9531396, theta=-35.494617 -> V=1.0, theta=0.0
% INFO    : Bus 34808	: V=0.9693602, theta=-34.129398 -> V=1.0, theta=0.0
% INFO    : Bus 34809	: V=0.9860186, theta=-35.00112 -> V=1.0, theta=0.0
% INFO    : Bus 34810	: V=0.9749448, theta=-37.438974 -> V=1.0, theta=0.0
% INFO    : Bus 34811	: V=0.9619146, theta=-38.356027 -> V=1.0, theta=0.0
% INFO    : Bus 34812	: V=0.9609878, theta=-42.944501 -> V=1.0, theta=0.0
% INFO    : Bus 34813	: V=0.9535312, theta=-44.118788 -> V=1.0, theta=0.0
% INFO    : Bus 34814	: V=0.9561215, theta=-43.591531 -> V=1.0, theta=0.0
% INFO    : Bus 34815	: V=0.9645557, theta=-42.310904 -> V=1.0, theta=0.0
% INFO    : Bus 34816	: V=0.9722314, theta=-39.855739 -> V=1.0, theta=0.0
% INFO    : Bus 34817	: V=0.9611046, theta=-39.585861 -> V=1.0, theta=0.0
% INFO    : Bus 34818	: V=0.9605014, theta=-41.469214 -> V=1.0, theta=0.0
% INFO    : Bus 34819	: V=0.9650067, theta=-41.317352 -> V=1.0, theta=0.0
% INFO    : Bus 34820	: V=0.961999, theta=-41.976914 -> V=1.0, theta=0.0
% INFO    : Bus 34821	: V=0.9574454, theta=-43.035059 -> V=1.0, theta=0.0
% INFO    : Bus 34822	: V=0.9599085, theta=-42.490827 -> V=1.0, theta=0.0
% INFO    : Bus 34823	: V=0.9444795, theta=-42.677538 -> V=1.0, theta=0.0
% INFO    : Bus 34824	: V=0.9509578, theta=-44.228255 -> V=1.0, theta=0.0
% INFO    : Bus 34825	: V=0.9481274, theta=-44.602017 -> V=1.0, theta=0.0
% INFO    : Bus 34826	: V=0.9509241, theta=-44.413149 -> V=1.0, theta=0.0
% INFO    : Bus 34827	: V=0.9781042, theta=-40.292087 -> V=1.0, theta=0.0
% INFO    : Bus 34828	: V=0.9948179, theta=-39.477524 -> V=1.0, theta=0.0
% INFO    : Bus 34829	: V=0.9753718, theta=-29.599749 -> V=1.0, theta=0.0
% INFO    : Bus 34830	: V=0.99579, theta=-28.372722 -> V=1.0, theta=0.0
% INFO    : Bus 34831	: V=0.9561974, theta=-31.340781 -> V=1.0, theta=0.0
% INFO    : Bus 34832	: V=0.9900434, theta=-29.343983 -> V=1.0, theta=0.0
% INFO    : Bus 34833	: V=0.9541011, theta=-32.005284 -> V=1.0, theta=0.0
% INFO    : Bus 34834	: V=0.9612393, theta=-30.903245 -> V=1.0, theta=0.0
% INFO    : Bus 34835	: V=0.9726246, theta=-33.420054 -> V=1.0, theta=0.0
% INFO    : Bus 34836	: V=0.9839436, theta=-32.923389 -> V=1.0, theta=0.0
% INFO    : Bus 34837	: V=0.988712, theta=-31.711961 -> V=1.0, theta=0.0
% INFO    : Bus 34838	: V=0.9821395, theta=-32.933725 -> V=1.0, theta=0.0
% INFO    : Bus 34839	: V=0.9880785, theta=-31.734644 -> V=1.0, theta=0.0
% INFO    : Bus 34840	: V=1.0032709, theta=-29.817334 -> V=1.0, theta=0.0
% INFO    : Bus 34841	: V=0.987803, theta=-31.673854 -> V=1.0, theta=0.0
% INFO    : Bus 34842	: V=0.9885025, theta=-31.70449 -> V=1.0, theta=0.0
% INFO    : Bus 34843	: V=0.9762371, theta=-33.004322 -> V=1.0, theta=0.0
% INFO    : Bus 34844	: V=0.9907828, theta=-32.161948 -> V=1.0, theta=0.0
% INFO    : Bus 34845	: V=0.9914722, theta=-32.139405 -> V=1.0, theta=0.0
% INFO    : Bus 34846	: V=0.9882734, theta=-31.734434 -> V=1.0, theta=0.0
% INFO    : Bus 34847	: V=0.9768793, theta=-32.735688 -> V=1.0, theta=0.0
% INFO    : Bus 34848	: V=0.9894936, theta=-31.670551 -> V=1.0, theta=0.0
% INFO    : Bus 34849	: V=0.9909201, theta=-31.581373 -> V=1.0, theta=0.0
% INFO    : Bus 34850	: V=0.9888449, theta=-30.858529 -> V=1.0, theta=0.0
% INFO    : Bus 34851	: V=0.9970976, theta=-30.287241 -> V=1.0, theta=0.0
% INFO    : Bus 34852	: V=1.0122107, theta=-29.484894 -> V=1.0, theta=0.0
% INFO    : Bus 34853	: V=0.9926824, theta=-30.599514 -> V=1.0, theta=0.0
% INFO    : Bus 34854	: V=0.9905549, theta=-30.743888 -> V=1.0, theta=0.0
% INFO    : Bus 34855	: V=0.996237, theta=-29.823594 -> V=1.0, theta=0.0
% INFO    : Bus 34856	: V=0.9955004, theta=-30.080635 -> V=1.0, theta=0.0
% INFO    : Bus 34857	: V=0.9998689, theta=-29.389318 -> V=1.0, theta=0.0
% INFO    : Bus 34858	: V=0.9735877, theta=-32.327631 -> V=1.0, theta=0.0
% INFO    : Bus 34859	: V=0.9773447, theta=-32.304211 -> V=1.0, theta=0.0
% INFO    : Bus 34860	: V=0.9740184, theta=-31.691992 -> V=1.0, theta=0.0
% INFO    : Bus 34861	: V=0.9852354, theta=-30.74297 -> V=1.0, theta=0.0
% INFO    : Bus 34862	: V=0.9721846, theta=-32.695246 -> V=1.0, theta=0.0
% INFO    : Bus 34863	: V=0.970464, theta=-32.057193 -> V=1.0, theta=0.0
% INFO    : Bus 34864	: V=0.9691035, theta=-32.220524 -> V=1.0, theta=0.0
% INFO    : Bus 34865	: V=0.968427, theta=-33.005635 -> V=1.0, theta=0.0
% INFO    : Bus 34866	: V=0.964175, theta=-33.288107 -> V=1.0, theta=0.0
% INFO    : Bus 34867	: V=0.9751499, theta=-32.965764 -> V=1.0, theta=0.0
% INFO    : Bus 34868	: V=0.9691423, theta=-33.138224 -> V=1.0, theta=0.0
% INFO    : Bus 34869	: V=0.9649872, theta=-33.177418 -> V=1.0, theta=0.0
% INFO    : Bus 34870	: V=0.9693989, theta=-32.97011 -> V=1.0, theta=0.0
% INFO    : Bus 34871	: V=0.9699588, theta=-32.966674 -> V=1.0, theta=0.0
% INFO    : Bus 34872	: V=0.9702205, theta=-32.882375 -> V=1.0, theta=0.0
% INFO    : Bus 34873	: V=0.978742, theta=-31.64994 -> V=1.0, theta=0.0
% INFO    : Bus 34874	: V=0.9765062, theta=-31.854723 -> V=1.0, theta=0.0
% INFO    : Bus 34875	: V=0.9747286, theta=-31.962999 -> V=1.0, theta=0.0
% INFO    : Bus 34876	: V=0.9869451, theta=-32.499435 -> V=1.0, theta=0.0
% INFO    : Bus 34877	: V=0.9702414, theta=-33.021479 -> V=1.0, theta=0.0
% INFO    : Bus 34878	: V=0.9705899, theta=-33.08962 -> V=1.0, theta=0.0
% INFO    : Bus 34879	: V=0.977271, theta=-32.719268 -> V=1.0, theta=0.0
% INFO    : Bus 34880	: V=0.9747108, theta=-33.014933 -> V=1.0, theta=0.0
% INFO    : Bus 34881	: V=0.9907943, theta=-32.712165 -> V=1.0, theta=0.0
% INFO    : Bus 34882	: V=0.973952, theta=-33.103544 -> V=1.0, theta=0.0
% INFO    : Bus 34883	: V=0.972797, theta=-33.084736 -> V=1.0, theta=0.0
% INFO    : Bus 34884	: V=0.9674883, theta=-33.089126 -> V=1.0, theta=0.0
% INFO    : Bus 34885	: V=0.9671916, theta=-33.061327 -> V=1.0, theta=0.0
% INFO    : Bus 34886	: V=0.9924388, theta=-32.099628 -> V=1.0, theta=0.0
% INFO    : Bus 34887	: V=0.9779681, theta=-32.991725 -> V=1.0, theta=0.0
% INFO    : Bus 34888	: V=0.9991482, theta=-31.868856 -> V=1.0, theta=0.0
% INFO    : Bus 34889	: V=0.9939346, theta=-32.025747 -> V=1.0, theta=0.0
% INFO    : Bus 34890	: V=0.9963495, theta=-31.896251 -> V=1.0, theta=0.0
% INFO    : Bus 34891	: V=0.9872614, theta=-32.31013 -> V=1.0, theta=0.0
% INFO    : Bus 34892	: V=0.9958351, theta=-31.801564 -> V=1.0, theta=0.0
% INFO    : Bus 34893	: V=0.9960299, theta=-32.012775 -> V=1.0, theta=0.0
% INFO    : Bus 34894	: V=1.0029132, theta=-31.82425 -> V=1.0, theta=0.0
% INFO    : Bus 34895	: V=0.9891683, theta=-30.764003 -> V=1.0, theta=0.0
% INFO    : Bus 34896	: V=0.9967026, theta=-30.166808 -> V=1.0, theta=0.0
% INFO    : Bus 34897	: V=0.9719649, theta=-32.025503 -> V=1.0, theta=0.0
% INFO    : Bus 34898	: V=0.9831063, theta=-31.188646 -> V=1.0, theta=0.0
% INFO    : Bus 34899	: V=0.9660383, theta=-32.22946 -> V=1.0, theta=0.0
% INFO    : Bus 34900	: V=0.9652, theta=-32.337923 -> V=1.0, theta=0.0
% INFO    : Bus 34901	: V=0.9741237, theta=-31.744368 -> V=1.0, theta=0.0
% INFO    : Bus 34902	: V=0.9741223, theta=-31.883254 -> V=1.0, theta=0.0
% INFO    : Bus 34903	: V=0.9750568, theta=-31.588679 -> V=1.0, theta=0.0
% INFO    : Bus 34904	: V=0.9764972, theta=-31.380734 -> V=1.0, theta=0.0
% INFO    : Bus 34905	: V=0.9752232, theta=-31.252304 -> V=1.0, theta=0.0
% INFO    : Bus 34906	: V=0.9646033, theta=-32.073429 -> V=1.0, theta=0.0
% INFO    : Bus 34907	: V=0.9667425, theta=-32.256561 -> V=1.0, theta=0.0
% INFO    : Bus 34908	: V=0.9874881, theta=-30.958233 -> V=1.0, theta=0.0
% INFO    : Bus 34909	: V=1.0103332, theta=-28.018102 -> V=1.0, theta=0.0
% INFO    : Bus 34910	: V=0.9895454, theta=-31.263022 -> V=1.0, theta=0.0
% INFO    : Bus 34911	: V=1.0030293, theta=-28.907246 -> V=1.0, theta=0.0
% INFO    : Bus 34912	: V=0.9990806, theta=-30.527985 -> V=1.0, theta=0.0
% INFO    : Bus 34913	: V=0.9381156, theta=-37.714633 -> V=1.0, theta=0.0
% INFO    : Bus 34914	: V=0.9388324, theta=-37.818902 -> V=1.0, theta=0.0
% INFO    : Bus 34915	: V=0.9424104, theta=-37.513771 -> V=1.0, theta=0.0
% INFO    : Bus 34916	: V=0.9432619, theta=-36.613486 -> V=1.0, theta=0.0
% INFO    : Bus 34917	: V=0.9479269, theta=-36.29028 -> V=1.0, theta=0.0
% INFO    : Bus 34918	: V=0.9727576, theta=-33.686761 -> V=1.0, theta=0.0
% INFO    : Bus 34919	: V=0.9684454, theta=-33.366729 -> V=1.0, theta=0.0
% INFO    : Bus 34920	: V=0.9783373, theta=-33.122154 -> V=1.0, theta=0.0
% INFO    : Bus 34921	: V=0.9967926, theta=-29.847577 -> V=1.0, theta=0.0
% INFO    : Bus 34922	: V=0.9767388, theta=-32.479107 -> V=1.0, theta=0.0
% INFO    : Bus 34923	: V=0.9561732, theta=-33.994594 -> V=1.0, theta=0.0
% INFO    : Bus 34924	: V=0.9598908, theta=-34.379615 -> V=1.0, theta=0.0
% INFO    : Bus 34925	: V=0.9568548, theta=-35.658959 -> V=1.0, theta=0.0
% INFO    : Bus 34926	: V=0.9593403, theta=-29.346335 -> V=1.0, theta=0.0
% INFO    : Bus 34927	: V=1.0034827, theta=-28.489365 -> V=1.0, theta=0.0
% INFO    : Bus 34928	: V=0.9640141, theta=-42.570053 -> V=1.0, theta=0.0
% INFO    : Bus 34929	: V=0.9918043, theta=-29.235883 -> V=1.0, theta=0.0
% INFO    : Bus 34930	: V=0.955322, theta=-42.849411 -> V=1.0, theta=0.0
% INFO    : Bus 34931	: V=0.9928943, theta=-40.092983 -> V=1.0, theta=0.0
% INFO    : Bus 34932	: V=0.9661628, theta=-31.973676 -> V=1.0, theta=0.0
% INFO    : Bus 34933	: V=0.9738398, theta=-31.821287 -> V=1.0, theta=0.0
% INFO    : Bus 34934	: V=0.9866279, theta=-40.714807 -> V=1.0, theta=0.0
% INFO    : Bus 34935	: V=0.989848, theta=-38.356934 -> V=1.0, theta=0.0
% INFO    : Bus 34936	: V=1.0058008, theta=-37.00215 -> V=1.0, theta=0.0
% INFO    : Bus 34937	: V=1.0106412, theta=-35.264992 -> V=1.0, theta=0.0
% INFO    : Bus 34938	: V=0.9944863, theta=-38.016254 -> V=1.0, theta=0.0
% INFO    : Bus 34939	: V=1.0005357, theta=-36.116164 -> V=1.0, theta=0.0
% INFO    : Bus 34940	: V=0.9982713, theta=-36.173088 -> V=1.0, theta=0.0
% INFO    : Bus 34941	: V=1.007651, theta=-35.168034 -> V=1.0, theta=0.0
% INFO    : Bus 34942	: V=1.0028289, theta=-35.813408 -> V=1.0, theta=0.0
% INFO    : Bus 34943	: V=0.9958842, theta=-36.158402 -> V=1.0, theta=0.0
% INFO    : Bus 34944	: V=0.992359, theta=-36.46469 -> V=1.0, theta=0.0
% INFO    : Bus 34945	: V=1.0082718, theta=-34.937303 -> V=1.0, theta=0.0
% INFO    : Bus 34946	: V=0.9970892, theta=-35.700042 -> V=1.0, theta=0.0
% INFO    : Bus 34947	: V=0.998731, theta=-35.648078 -> V=1.0, theta=0.0
% INFO    : Bus 34948	: V=0.9941491, theta=-36.442113 -> V=1.0, theta=0.0
% INFO    : Bus 34949	: V=0.9832059, theta=-37.933121 -> V=1.0, theta=0.0
% INFO    : Bus 34950	: V=1.0197309, theta=-22.815523 -> V=1.0, theta=0.0
% INFO    : Bus 34951	: V=0.9948143, theta=-25.742565 -> V=1.0, theta=0.0
% INFO    : Bus 34952	: V=1.0073721, theta=-25.098312 -> V=1.0, theta=0.0
% INFO    : Bus 34953	: V=1.0095282, theta=-25.470228 -> V=1.0, theta=0.0
% INFO    : Bus 34954	: V=0.991507, theta=-26.436363 -> V=1.0, theta=0.0
% INFO    : Bus 34955	: V=1.001573, theta=-27.405922 -> V=1.0, theta=0.0
% INFO    : Bus 34956	: V=1.0099237, theta=-26.110176 -> V=1.0, theta=0.0
% INFO    : Bus 34957	: V=1.0137891, theta=-26.413576 -> V=1.0, theta=0.0
% INFO    : Bus 34958	: V=1.0134553, theta=-26.54906 -> V=1.0, theta=0.0
% INFO    : Bus 34959	: V=1.0078807, theta=-26.721826 -> V=1.0, theta=0.0
% INFO    : Bus 34960	: V=1.0136805, theta=-26.308763 -> V=1.0, theta=0.0
% INFO    : Bus 34961	: V=1.0111219, theta=-26.364109 -> V=1.0, theta=0.0
% INFO    : Bus 34962	: V=1.0065319, theta=-26.833819 -> V=1.0, theta=0.0
% INFO    : Bus 34963	: V=1.0079926, theta=-26.687125 -> V=1.0, theta=0.0
% INFO    : Bus 34964	: V=1.0193804, theta=-24.831802 -> V=1.0, theta=0.0
% INFO    : Bus 34965	: V=1.0074844, theta=-26.411658 -> V=1.0, theta=0.0
% INFO    : Bus 34966	: V=1.003181, theta=-26.669861 -> V=1.0, theta=0.0
% INFO    : Bus 34967	: V=1.0064933, theta=-26.879877 -> V=1.0, theta=0.0
% INFO    : Bus 34968	: V=1.0035716, theta=-27.718013 -> V=1.0, theta=0.0
% INFO    : Bus 34969	: V=1.0015847, theta=-28.485897 -> V=1.0, theta=0.0
% INFO    : Bus 34970	: V=0.9908017, theta=-38.978054 -> V=1.0, theta=0.0
% INFO    : Bus 34971	: V=1.002675, theta=-36.286567 -> V=1.0, theta=0.0
% INFO    : Bus 34972	: V=0.9925291, theta=-37.601355 -> V=1.0, theta=0.0
% INFO    : Bus 34973	: V=0.983297, theta=-39.476655 -> V=1.0, theta=0.0
% INFO    : Bus 34974	: V=0.985386, theta=-39.766573 -> V=1.0, theta=0.0
% INFO    : Bus 34975	: V=0.9782489, theta=-39.761865 -> V=1.0, theta=0.0
% INFO    : Bus 34976	: V=0.9648696, theta=-42.598712 -> V=1.0, theta=0.0
% INFO    : Bus 34977	: V=0.9790517, theta=-40.553025 -> V=1.0, theta=0.0
% INFO    : Bus 34978	: V=0.9724045, theta=-41.377013 -> V=1.0, theta=0.0
% INFO    : Bus 34979	: V=0.9747925, theta=-40.538325 -> V=1.0, theta=0.0
% INFO    : Bus 34980	: V=0.9790197, theta=-39.46759 -> V=1.0, theta=0.0
% INFO    : Bus 34981	: V=0.994598, theta=-37.758833 -> V=1.0, theta=0.0
% INFO    : Bus 34982	: V=0.9782844, theta=-40.036826 -> V=1.0, theta=0.0
% INFO    : Bus 34983	: V=0.976463, theta=-39.669017 -> V=1.0, theta=0.0
% INFO    : Bus 34984	: V=0.9672882, theta=-41.344374 -> V=1.0, theta=0.0
% INFO    : Bus 34985	: V=0.9718664, theta=-40.060065 -> V=1.0, theta=0.0
% INFO    : Bus 34986	: V=0.9653093, theta=-41.465594 -> V=1.0, theta=0.0
% INFO    : Bus 34987	: V=0.9674805, theta=-41.133931 -> V=1.0, theta=0.0
% INFO    : Bus 34988	: V=0.986255, theta=-38.688279 -> V=1.0, theta=0.0
% INFO    : Bus 34989	: V=0.9780786, theta=-39.26228 -> V=1.0, theta=0.0
% INFO    : Bus 34990	: V=0.9792097, theta=-39.05891 -> V=1.0, theta=0.0
% INFO    : Bus 34991	: V=0.9949565, theta=-36.577052 -> V=1.0, theta=0.0
% INFO    : Bus 34992	: V=0.990944, theta=-36.987813 -> V=1.0, theta=0.0
% INFO    : Bus 34993	: V=0.989046, theta=-37.244976 -> V=1.0, theta=0.0
% INFO    : Bus 34994	: V=0.9898043, theta=-36.929754 -> V=1.0, theta=0.0
% INFO    : Bus 34995	: V=0.9905736, theta=-36.877124 -> V=1.0, theta=0.0
% INFO    : Bus 34996	: V=0.9987978, theta=-36.188808 -> V=1.0, theta=0.0
% INFO    : Bus 34997	: V=0.989887, theta=-36.924016 -> V=1.0, theta=0.0
% INFO    : Bus 34998	: V=0.9575647, theta=-35.195525 -> V=1.0, theta=0.0
% INFO    : Bus 34999	: V=0.9680029, theta=-33.833359 -> V=1.0, theta=0.0
% INFO    : Bus 35000	: V=0.9692864, theta=-33.699987 -> V=1.0, theta=0.0
% INFO    : Bus 35001	: V=0.9667441, theta=-33.980963 -> V=1.0, theta=0.0
% INFO    : Bus 35002	: V=0.9673916, theta=-33.898116 -> V=1.0, theta=0.0
% INFO    : Bus 35003	: V=0.9685415, theta=-33.828955 -> V=1.0, theta=0.0
% INFO    : Bus 35004	: V=0.9681997, theta=-33.85541 -> V=1.0, theta=0.0
% INFO    : Bus 35005	: V=0.9669256, theta=-33.937851 -> V=1.0, theta=0.0
% INFO    : Bus 35006	: V=0.9672397, theta=-33.919422 -> V=1.0, theta=0.0
% INFO    : Bus 35007	: V=0.9581251, theta=-35.083321 -> V=1.0, theta=0.0
% INFO    : Bus 35008	: V=0.9579402, theta=-35.059535 -> V=1.0, theta=0.0
% INFO    : Bus 35009	: V=0.9572314, theta=-35.146704 -> V=1.0, theta=0.0
% INFO    : Bus 35010	: V=0.9571749, theta=-35.182845 -> V=1.0, theta=0.0
% INFO    : Bus 35011	: V=0.959668, theta=-34.791377 -> V=1.0, theta=0.0
% INFO    : Bus 35012	: V=0.957423, theta=-35.088042 -> V=1.0, theta=0.0
% INFO    : Bus 35013	: V=0.9572263, theta=-35.077777 -> V=1.0, theta=0.0
% INFO    : Bus 35014	: V=0.9629484, theta=-34.160301 -> V=1.0, theta=0.0
% INFO    : Bus 35015	: V=0.9573795, theta=-35.018472 -> V=1.0, theta=0.0
% INFO    : Bus 35016	: V=0.9557269, theta=-35.16748 -> V=1.0, theta=0.0
% INFO    : Bus 35017	: V=0.955834, theta=-35.156607 -> V=1.0, theta=0.0
% INFO    : Bus 35018	: V=0.9554465, theta=-35.167114 -> V=1.0, theta=0.0
% INFO    : Bus 35019	: V=0.9617672, theta=-34.585872 -> V=1.0, theta=0.0
% INFO    : Bus 35020	: V=0.97188, theta=-33.564336 -> V=1.0, theta=0.0
% INFO    : Bus 35021	: V=0.9693612, theta=-33.764988 -> V=1.0, theta=0.0
% INFO    : Bus 35022	: V=0.9575545, theta=-35.156722 -> V=1.0, theta=0.0
% INFO    : Bus 35023	: V=0.9679924, theta=-33.872108 -> V=1.0, theta=0.0
% INFO    : Bus 35024	: V=0.9962242, theta=-30.07676 -> V=1.0, theta=0.0
% INFO    : Bus 35025	: V=0.9705878, theta=-33.052737 -> V=1.0, theta=0.0
% INFO    : Bus 35026	: V=0.9718422, theta=-33.422062 -> V=1.0, theta=0.0
% INFO    : Bus 35027	: V=0.9721798, theta=-32.526364 -> V=1.0, theta=0.0
% INFO    : Bus 35028	: V=0.9776419, theta=-33.153844 -> V=1.0, theta=0.0
% INFO    : Bus 35029	: V=0.9971209, theta=-31.526488 -> V=1.0, theta=0.0
% INFO    : Bus 35030	: V=1.0008428, theta=-30.729732 -> V=1.0, theta=0.0
% INFO    : Bus 35031	: V=1.0044651, theta=-30.069978 -> V=1.0, theta=0.0
% INFO    : Bus 35032	: V=0.9853876, theta=-32.416509 -> V=1.0, theta=0.0
% INFO    : Bus 35033	: V=0.9787761, theta=-32.750812 -> V=1.0, theta=0.0
% INFO    : Bus 35034	: V=0.9697737, theta=-33.745569 -> V=1.0, theta=0.0
% INFO    : Bus 35035	: V=0.9786747, theta=-32.887472 -> V=1.0, theta=0.0
% INFO    : Bus 35036	: V=0.9737837, theta=-33.24535 -> V=1.0, theta=0.0
% INFO    : Bus 35037	: V=0.9759922, theta=-33.127796 -> V=1.0, theta=0.0
% INFO    : Bus 35038	: V=0.9768612, theta=-33.092354 -> V=1.0, theta=0.0
% INFO    : Bus 35039	: V=0.9801044, theta=-32.80186 -> V=1.0, theta=0.0
% INFO    : Bus 35040	: V=0.9779389, theta=-32.922886 -> V=1.0, theta=0.0
% INFO    : Bus 35041	: V=0.9692939, theta=-33.778646 -> V=1.0, theta=0.0
% INFO    : Bus 35042	: V=0.9713855, theta=-33.483364 -> V=1.0, theta=0.0
% INFO    : Bus 35043	: V=0.9668878, theta=-33.97647 -> V=1.0, theta=0.0
% INFO    : Bus 35044	: V=0.9584945, theta=-35.153464 -> V=1.0, theta=0.0
% INFO    : Bus 35045	: V=0.9619724, theta=-34.720685 -> V=1.0, theta=0.0
% INFO    : Bus 35046	: V=0.9555686, theta=-35.401256 -> V=1.0, theta=0.0
% INFO    : Bus 35047	: V=0.9556116, theta=-35.385368 -> V=1.0, theta=0.0
% INFO    : Bus 35048	: V=0.9567929, theta=-35.383524 -> V=1.0, theta=0.0
% INFO    : Bus 35049	: V=0.9564882, theta=-35.322408 -> V=1.0, theta=0.0
% INFO    : Bus 35050	: V=0.9685633, theta=-33.592829 -> V=1.0, theta=0.0
% INFO    : Bus 35051	: V=0.9572326, theta=-35.320536 -> V=1.0, theta=0.0
% INFO    : Bus 35052	: V=0.9576377, theta=-35.194051 -> V=1.0, theta=0.0
% INFO    : Bus 35053	: V=0.9570625, theta=-35.257602 -> V=1.0, theta=0.0
% INFO    : Bus 35054	: V=0.9565904, theta=-35.301228 -> V=1.0, theta=0.0
% INFO    : Bus 35055	: V=0.9551017, theta=-35.434337 -> V=1.0, theta=0.0
% INFO    : Bus 35056	: V=0.9619249, theta=-34.251683 -> V=1.0, theta=0.0
% INFO    : Bus 35057	: V=0.9614171, theta=-34.303359 -> V=1.0, theta=0.0
% INFO    : Bus 35058	: V=0.9552259, theta=-35.430845 -> V=1.0, theta=0.0
% INFO    : Bus 35059	: V=0.9539466, theta=-35.598188 -> V=1.0, theta=0.0
% INFO    : Bus 35060	: V=0.954233, theta=-35.595885 -> V=1.0, theta=0.0
% INFO    : Bus 35061	: V=0.953301, theta=-35.659387 -> V=1.0, theta=0.0
% INFO    : Bus 35062	: V=0.9706411, theta=-33.394183 -> V=1.0, theta=0.0
% INFO    : Bus 35063	: V=0.9623404, theta=-34.187886 -> V=1.0, theta=0.0
% INFO    : Bus 35064	: V=0.9581068, theta=-35.203584 -> V=1.0, theta=0.0
% INFO    : Bus 35065	: V=0.9554034, theta=-35.456551 -> V=1.0, theta=0.0
% INFO    : Bus 35066	: V=0.9587379, theta=-34.667491 -> V=1.0, theta=0.0
% INFO    : Bus 35067	: V=0.9702761, theta=-33.486983 -> V=1.0, theta=0.0
% INFO    : Bus 35068	: V=0.9681577, theta=-33.814459 -> V=1.0, theta=0.0
% INFO    : Bus 35069	: V=0.9698075, theta=-33.524215 -> V=1.0, theta=0.0
% INFO    : Bus 35070	: V=0.9691969, theta=-33.583399 -> V=1.0, theta=0.0
% INFO    : Bus 35071	: V=0.9691861, theta=-33.599176 -> V=1.0, theta=0.0
% INFO    : Bus 35072	: V=0.9686705, theta=-33.634728 -> V=1.0, theta=0.0
% INFO    : Bus 35073	: V=0.9718272, theta=-33.117937 -> V=1.0, theta=0.0
% INFO    : Bus 35074	: V=0.9595523, theta=-34.662932 -> V=1.0, theta=0.0
% INFO    : Bus 35075	: V=0.964973, theta=-33.997587 -> V=1.0, theta=0.0
% INFO    : Bus 35076	: V=0.9669384, theta=-33.814442 -> V=1.0, theta=0.0
% INFO    : Bus 35077	: V=0.9750836, theta=-32.886162 -> V=1.0, theta=0.0
% INFO    : Bus 35078	: V=0.966734, theta=-33.703724 -> V=1.0, theta=0.0
% INFO    : Bus 35079	: V=0.9734624, theta=-32.999848 -> V=1.0, theta=0.0
% INFO    : Bus 35080	: V=1.002429, theta=-30.246848 -> V=1.0, theta=0.0
% INFO    : Bus 35081	: V=0.9715601, theta=-33.325922 -> V=1.0, theta=0.0
% INFO    : Bus 35082	: V=0.9906877, theta=-30.961124 -> V=1.0, theta=0.0
% INFO    : Bus 35083	: V=0.9775634, theta=-32.719629 -> V=1.0, theta=0.0
% INFO    : Bus 35084	: V=0.9841331, theta=-32.278514 -> V=1.0, theta=0.0
% INFO    : Bus 35085	: V=1.001128, theta=-31.677507 -> V=1.0, theta=0.0
% INFO    : Bus 35086	: V=0.9765595, theta=-32.94009 -> V=1.0, theta=0.0
% INFO    : Bus 35087	: V=0.9984314, theta=-38.560994 -> V=1.0, theta=0.0
% INFO    : Bus 35088	: V=0.9789561, theta=-36.331239 -> V=1.0, theta=0.0
% INFO    : Bus 35089	: V=0.9754901, theta=-34.494795 -> V=1.0, theta=0.0
% INFO    : Bus 35090	: V=0.9596414, theta=-36.994984 -> V=1.0, theta=0.0
% INFO    : Bus 35091	: V=0.9805645, theta=-30.852048 -> V=1.0, theta=0.0
% INFO    : Bus 35092	: V=0.9502746, theta=-47.468045 -> V=1.0, theta=0.0
% INFO    : Bus 35093	: V=0.9492278, theta=-47.21812 -> V=1.0, theta=0.0
% INFO    : Bus 35094	: V=0.9494893, theta=-47.205674 -> V=1.0, theta=0.0
% INFO    : Bus 35095	: V=0.9518601, theta=-46.662973 -> V=1.0, theta=0.0
% INFO    : Bus 35096	: V=0.9520736, theta=-46.583471 -> V=1.0, theta=0.0
% INFO    : Bus 35097	: V=0.9503448, theta=-47.037891 -> V=1.0, theta=0.0
% INFO    : Bus 35098	: V=0.9494072, theta=-47.104862 -> V=1.0, theta=0.0
% INFO    : Bus 35099	: V=0.9482694, theta=-47.152842 -> V=1.0, theta=0.0
% INFO    : Bus 35100	: V=0.949067, theta=-47.301299 -> V=1.0, theta=0.0
% INFO    : Bus 35101	: V=0.94889, theta=-47.285563 -> V=1.0, theta=0.0
% INFO    : Bus 35102	: V=0.9489706, theta=-47.248635 -> V=1.0, theta=0.0
% INFO    : Bus 35103	: V=0.9524008, theta=-46.072642 -> V=1.0, theta=0.0
% INFO    : Bus 35104	: V=0.9491374, theta=-47.416883 -> V=1.0, theta=0.0
% INFO    : Bus 35105	: V=0.9552588, theta=-45.683218 -> V=1.0, theta=0.0
% INFO    : Bus 35106	: V=0.951804, theta=-46.581457 -> V=1.0, theta=0.0
% INFO    : Bus 35107	: V=0.956185, theta=-45.564544 -> V=1.0, theta=0.0
% INFO    : Bus 35108	: V=0.9520839, theta=-47.124434 -> V=1.0, theta=0.0
% INFO    : Bus 35109	: V=0.9580752, theta=-44.81046 -> V=1.0, theta=0.0
% INFO    : Bus 35110	: V=0.9543165, theta=-45.808398 -> V=1.0, theta=0.0
% INFO    : Bus 35111	: V=0.9527021, theta=-47.158605 -> V=1.0, theta=0.0
% INFO    : Bus 35112	: V=0.9560351, theta=-45.472514 -> V=1.0, theta=0.0
% INFO    : Bus 35113	: V=0.9546214, theta=-46.297592 -> V=1.0, theta=0.0
% INFO    : Bus 35114	: V=0.9545759, theta=-46.836381 -> V=1.0, theta=0.0
% INFO    : Bus 35115	: V=0.9521404, theta=-47.303631 -> V=1.0, theta=0.0
% INFO    : Bus 35116	: V=0.9563778, theta=-45.353116 -> V=1.0, theta=0.0
% INFO    : Bus 35117	: V=0.966592, theta=-42.837226 -> V=1.0, theta=0.0
% INFO    : Bus 35118	: V=0.9564497, theta=-45.264224 -> V=1.0, theta=0.0
% INFO    : Bus 35119	: V=0.9483678, theta=-47.021532 -> V=1.0, theta=0.0
% INFO    : Bus 35120	: V=0.9642452, theta=-43.008516 -> V=1.0, theta=0.0
% INFO    : Bus 35121	: V=0.9513594, theta=-46.553134 -> V=1.0, theta=0.0
% INFO    : Bus 35122	: V=0.9495474, theta=-47.034511 -> V=1.0, theta=0.0
% INFO    : Bus 35123	: V=0.9480474, theta=-47.243915 -> V=1.0, theta=0.0
% INFO    : Bus 35124	: V=0.9531679, theta=-45.987323 -> V=1.0, theta=0.0
% INFO    : Bus 35125	: V=0.9558833, theta=-45.655391 -> V=1.0, theta=0.0
% INFO    : Bus 35126	: V=0.9609141, theta=-44.87976 -> V=1.0, theta=0.0
% INFO    : Bus 35127	: V=0.9664783, theta=-44.160699 -> V=1.0, theta=0.0
% INFO    : Bus 35128	: V=0.9616754, theta=-46.028569 -> V=1.0, theta=0.0
% INFO    : Bus 35129	: V=0.9608547, theta=-46.238167 -> V=1.0, theta=0.0
% INFO    : Bus 35130	: V=0.9549935, theta=-46.844939 -> V=1.0, theta=0.0
% INFO    : Bus 35131	: V=0.9472295, theta=-47.436745 -> V=1.0, theta=0.0
% INFO    : Bus 35132	: V=0.9609958, theta=-44.418059 -> V=1.0, theta=0.0
% INFO    : Bus 35133	: V=0.9508266, theta=-46.880702 -> V=1.0, theta=0.0
% INFO    : Bus 35134	: V=0.9512533, theta=-47.188623 -> V=1.0, theta=0.0
% INFO    : Bus 35135	: V=0.9520416, theta=-47.172598 -> V=1.0, theta=0.0
% INFO    : Bus 35136	: V=0.9527604, theta=-45.716819 -> V=1.0, theta=0.0
% INFO    : Bus 35137	: V=0.9605387, theta=-43.335583 -> V=1.0, theta=0.0
% INFO    : Bus 35138	: V=0.94375, theta=-47.51396 -> V=1.0, theta=0.0
% INFO    : Bus 35139	: V=0.9486852, theta=-47.349026 -> V=1.0, theta=0.0
% INFO    : Bus 35140	: V=0.9510446, theta=-46.711133 -> V=1.0, theta=0.0
% INFO    : Bus 35141	: V=0.9520551, theta=-46.140103 -> V=1.0, theta=0.0
% INFO    : Bus 35142	: V=0.9474217, theta=-47.033334 -> V=1.0, theta=0.0
% INFO    : Bus 35143	: V=0.9564363, theta=-45.103522 -> V=1.0, theta=0.0
% INFO    : Bus 35144	: V=0.9581327, theta=-44.206447 -> V=1.0, theta=0.0
% INFO    : Bus 35145	: V=0.956249, theta=-44.982039 -> V=1.0, theta=0.0
% INFO    : Bus 35146	: V=0.9501371, theta=-45.187011 -> V=1.0, theta=0.0
% INFO    : Bus 35147	: V=0.9675905, theta=-42.403916 -> V=1.0, theta=0.0
% INFO    : Bus 35148	: V=0.9521173, theta=-45.116294 -> V=1.0, theta=0.0
% INFO    : Bus 35149	: V=0.95378, theta=-44.96776 -> V=1.0, theta=0.0
% INFO    : Bus 35150	: V=0.950978, theta=-46.250822 -> V=1.0, theta=0.0
% INFO    : Bus 35151	: V=0.9530569, theta=-45.114658 -> V=1.0, theta=0.0
% INFO    : Bus 35152	: V=0.9509279, theta=-46.333047 -> V=1.0, theta=0.0
% INFO    : Bus 35153	: V=0.9559575, theta=-44.581089 -> V=1.0, theta=0.0
% INFO    : Bus 35154	: V=0.9587391, theta=-43.916514 -> V=1.0, theta=0.0
% INFO    : Bus 35155	: V=0.9503294, theta=-46.587003 -> V=1.0, theta=0.0
% INFO    : Bus 35156	: V=0.9523981, theta=-46.005686 -> V=1.0, theta=0.0
% INFO    : Bus 35157	: V=0.9550095, theta=-43.647501 -> V=1.0, theta=0.0
% INFO    : Bus 35158	: V=0.9462331, theta=-47.338557 -> V=1.0, theta=0.0
% INFO    : Bus 35159	: V=0.9507791, theta=-45.76617 -> V=1.0, theta=0.0
% INFO    : Bus 35160	: V=0.9504111, theta=-46.459579 -> V=1.0, theta=0.0
% INFO    : Bus 35161	: V=0.9858393, theta=-30.365238 -> V=1.0, theta=0.0
% INFO    : Bus 35162	: V=0.9891477, theta=-30.054337 -> V=1.0, theta=0.0
% INFO    : Bus 35163	: V=0.9825241, theta=-30.524003 -> V=1.0, theta=0.0
% INFO    : Bus 35164	: V=0.981733, theta=-30.543977 -> V=1.0, theta=0.0
% INFO    : Bus 35165	: V=0.9531609, theta=-32.639856 -> V=1.0, theta=0.0
% INFO    : Bus 35166	: V=0.9569139, theta=-31.246742 -> V=1.0, theta=0.0
% INFO    : Bus 35167	: V=0.9524383, theta=-32.68908 -> V=1.0, theta=0.0
% INFO    : Bus 35168	: V=0.9557397, theta=-32.474924 -> V=1.0, theta=0.0
% INFO    : Bus 35169	: V=0.9578757, theta=-32.568582 -> V=1.0, theta=0.0
% INFO    : Bus 35170	: V=0.9599712, theta=-32.501143 -> V=1.0, theta=0.0
% INFO    : Bus 35171	: V=0.9599915, theta=-32.477145 -> V=1.0, theta=0.0
% INFO    : Bus 35172	: V=0.9589221, theta=-31.458041 -> V=1.0, theta=0.0
% INFO    : Bus 35173	: V=0.9597718, theta=-32.187942 -> V=1.0, theta=0.0
% INFO    : Bus 35174	: V=0.9643572, theta=-31.123269 -> V=1.0, theta=0.0
% INFO    : Bus 35175	: V=0.9671141, theta=-30.906394 -> V=1.0, theta=0.0
% INFO    : Bus 35176	: V=0.9614906, theta=-32.425859 -> V=1.0, theta=0.0
% INFO    : Bus 35177	: V=0.9595347, theta=-32.556135 -> V=1.0, theta=0.0
% INFO    : Bus 35178	: V=0.9592913, theta=-32.118464 -> V=1.0, theta=0.0
% INFO    : Bus 35179	: V=0.9969582, theta=-29.288813 -> V=1.0, theta=0.0
% INFO    : Bus 35180	: V=0.9919379, theta=-29.801882 -> V=1.0, theta=0.0
% INFO    : Bus 35181	: V=1.0046867, theta=-27.46176 -> V=1.0, theta=0.0
% INFO    : Bus 35182	: V=0.9862792, theta=-28.677703 -> V=1.0, theta=0.0
% INFO    : Bus 35183	: V=0.958977, theta=-32.40342 -> V=1.0, theta=0.0
% INFO    : Bus 35184	: V=0.9566422, theta=-38.946585 -> V=1.0, theta=0.0
% INFO    : Bus 35185	: V=0.957787, theta=-38.60358 -> V=1.0, theta=0.0
% INFO    : Bus 35186	: V=0.9663799, theta=-35.510755 -> V=1.0, theta=0.0
% INFO    : Bus 35187	: V=0.9759506, theta=-39.010468 -> V=1.0, theta=0.0
% INFO    : Bus 35188	: V=0.9541899, theta=-38.645407 -> V=1.0, theta=0.0
% INFO    : Bus 35189	: V=0.9770009, theta=-33.329856 -> V=1.0, theta=0.0
% INFO    : Bus 35190	: V=0.9451086, theta=-41.60586 -> V=1.0, theta=0.0
% INFO    : Bus 35191	: V=0.9583254, theta=-45.30965 -> V=1.0, theta=0.0
% INFO    : Bus 35192	: V=0.9603182, theta=-38.160272 -> V=1.0, theta=0.0
% INFO    : Bus 35193	: V=0.9725173, theta=-29.448953 -> V=1.0, theta=0.0
% INFO    : Bus 35194	: V=0.9722246, theta=-30.533059 -> V=1.0, theta=0.0
% INFO    : Bus 35195	: V=0.9675563, theta=-31.992352 -> V=1.0, theta=0.0
% INFO    : Bus 35196	: V=0.9770903, theta=-27.892027 -> V=1.0, theta=0.0
% INFO    : Bus 35197	: V=0.9894681, theta=-27.264095 -> V=1.0, theta=0.0
% INFO    : Bus 35198	: V=0.984557, theta=-27.748069 -> V=1.0, theta=0.0
% INFO    : Bus 35199	: V=0.9772376, theta=-28.658882 -> V=1.0, theta=0.0
% INFO    : Bus 35200	: V=0.9871555, theta=-27.354269 -> V=1.0, theta=0.0
% INFO    : Bus 35201	: V=1.0101342, theta=-24.860938 -> V=1.0, theta=0.0
% INFO    : Bus 35202	: V=0.9977616, theta=-26.342688 -> V=1.0, theta=0.0
% INFO    : Bus 35203	: V=1.0111122, theta=-25.007567 -> V=1.0, theta=0.0
% INFO    : Bus 35204	: V=0.9781727, theta=-37.329937 -> V=1.0, theta=0.0
% INFO    : Bus 35205	: V=0.9767721, theta=-37.397925 -> V=1.0, theta=0.0
% INFO    : Bus 35206	: V=0.976413, theta=-37.421099 -> V=1.0, theta=0.0
% INFO    : Bus 35207	: V=0.9751417, theta=-37.484247 -> V=1.0, theta=0.0
% INFO    : Bus 35208	: V=0.9737583, theta=-37.528057 -> V=1.0, theta=0.0
% INFO    : Bus 35209	: V=0.9752163, theta=-37.440847 -> V=1.0, theta=0.0
% INFO    : Bus 35210	: V=0.9736339, theta=-37.451984 -> V=1.0, theta=0.0
% INFO    : Bus 35211	: V=0.9762137, theta=-37.395993 -> V=1.0, theta=0.0
% INFO    : Bus 35212	: V=0.9767766, theta=-37.342727 -> V=1.0, theta=0.0
% INFO    : Bus 35213	: V=0.9825263, theta=-37.025344 -> V=1.0, theta=0.0
% INFO    : Bus 35214	: V=0.9785652, theta=-37.252724 -> V=1.0, theta=0.0
% INFO    : Bus 35215	: V=0.9845161, theta=-36.949474 -> V=1.0, theta=0.0
% INFO    : Bus 35216	: V=1.0160825, theta=-33.814302 -> V=1.0, theta=0.0
% INFO    : Bus 35217	: V=0.9963528, theta=-35.632947 -> V=1.0, theta=0.0
% INFO    : Bus 35218	: V=0.9966769, theta=-35.697293 -> V=1.0, theta=0.0
% INFO    : Bus 35219	: V=1.0003242, theta=-35.538694 -> V=1.0, theta=0.0
% INFO    : Bus 35220	: V=0.9875271, theta=-36.822034 -> V=1.0, theta=0.0
% INFO    : Bus 35221	: V=1.00416, theta=-35.337093 -> V=1.0, theta=0.0
% INFO    : Bus 35222	: V=0.9886388, theta=-36.745924 -> V=1.0, theta=0.0
% INFO    : Bus 35223	: V=0.990364, theta=-36.490063 -> V=1.0, theta=0.0
% INFO    : Bus 35224	: V=0.9807221, theta=-37.167565 -> V=1.0, theta=0.0
% INFO    : Bus 35225	: V=0.9963484, theta=-35.810574 -> V=1.0, theta=0.0
% INFO    : Bus 35226	: V=0.9785561, theta=-37.331618 -> V=1.0, theta=0.0
% INFO    : Bus 35227	: V=0.9767465, theta=-37.325519 -> V=1.0, theta=0.0
% INFO    : Bus 35228	: V=0.9909772, theta=-36.256138 -> V=1.0, theta=0.0
% INFO    : Bus 35229	: V=0.9792748, theta=-37.237987 -> V=1.0, theta=0.0
% INFO    : Bus 35230	: V=0.9873844, theta=-36.549505 -> V=1.0, theta=0.0
% INFO    : Bus 35231	: V=0.975743, theta=-37.350014 -> V=1.0, theta=0.0
% INFO    : Bus 35232	: V=0.9938275, theta=-35.160836 -> V=1.0, theta=0.0
% INFO    : Bus 35233	: V=0.9726389, theta=-37.551799 -> V=1.0, theta=0.0
% INFO    : Bus 35234	: V=0.9706646, theta=-37.561113 -> V=1.0, theta=0.0
% INFO    : Bus 35235	: V=0.9721947, theta=-37.350946 -> V=1.0, theta=0.0
% INFO    : Bus 35236	: V=0.990938, theta=-35.709721 -> V=1.0, theta=0.0
% INFO    : Bus 35237	: V=0.9747964, theta=-37.385102 -> V=1.0, theta=0.0
% INFO    : Bus 35238	: V=1.0029951, theta=-35.96834 -> V=1.0, theta=0.0
% INFO    : Bus 35239	: V=0.9934667, theta=-35.956674 -> V=1.0, theta=0.0
% INFO    : Bus 35240	: V=0.9733792, theta=-38.014137 -> V=1.0, theta=0.0
% INFO    : Bus 35241	: V=0.9726985, theta=-37.925499 -> V=1.0, theta=0.0
% INFO    : Bus 35242	: V=1.0151892, theta=-35.429772 -> V=1.0, theta=0.0
% INFO    : Bus 35243	: V=0.996646, theta=-36.311237 -> V=1.0, theta=0.0
% INFO    : Bus 35244	: V=0.9948442, theta=-36.247717 -> V=1.0, theta=0.0
% INFO    : Bus 35245	: V=1.0048016, theta=-35.291555 -> V=1.0, theta=0.0
% INFO    : Bus 35246	: V=1.0065558, theta=-35.201 -> V=1.0, theta=0.0
% INFO    : Bus 35247	: V=0.999539, theta=-36.245851 -> V=1.0, theta=0.0
% INFO    : Bus 35248	: V=1.0124492, theta=-35.407244 -> V=1.0, theta=0.0
% INFO    : Bus 35249	: V=0.9625548, theta=-38.323452 -> V=1.0, theta=0.0
% INFO    : Bus 35250	: V=1.02, theta=-16.652858 -> V=1.0, theta=0.0
% INFO    : Bus 35251	: V=1.02, theta=-36.194136 -> V=1.0, theta=0.0
% INFO    : Bus 35252	: V=1.02, theta=-17.609558 -> V=1.0, theta=0.0
% INFO    : Bus 35253	: V=1.02, theta=-41.47997 -> V=1.0, theta=0.0
% INFO    : Bus 35254	: V=1.02, theta=-45.127588 -> V=1.0, theta=0.0
% INFO    : Bus 35255	: V=1.02, theta=-19.821838 -> V=1.0, theta=0.0
% INFO    : Bus 35256	: V=1.02, theta=-19.756394 -> V=1.0, theta=0.0
% INFO    : Bus 35257	: V=1.02, theta=-22.154475 -> V=1.0, theta=0.0
% INFO    : Bus 35258	: V=1.0163225, theta=-50.295904 -> V=1.0, theta=0.0
% INFO    : Bus 35259	: V=1.02, theta=-18.343098 -> V=1.0, theta=0.0
% INFO    : Bus 35260	: V=1.02, theta=-17.165879 -> V=1.0, theta=0.0
% INFO    : Bus 35261	: V=1.02, theta=-24.670799 -> V=1.0, theta=0.0
% INFO    : Bus 35262	: V=1.02, theta=-17.163438 -> V=1.0, theta=0.0
% INFO    : Bus 35263	: V=1.02, theta=-23.752801 -> V=1.0, theta=0.0
% INFO    : Bus 35264	: V=1.02, theta=-22.791568 -> V=1.0, theta=0.0
% INFO    : Bus 35265	: V=1.02, theta=-20.142591 -> V=1.0, theta=0.0
% INFO    : Bus 35266	: V=1.0199902, theta=-20.141064 -> V=1.0, theta=0.0
% INFO    : Bus 35267	: V=1.0199268, theta=-25.00659 -> V=1.0, theta=0.0
% INFO    : Bus 35268	: V=1.02, theta=-22.077975 -> V=1.0, theta=0.0
% INFO    : Bus 35269	: V=1.02, theta=-18.032518 -> V=1.0, theta=0.0
% INFO    : Bus 35270	: V=1.02, theta=-44.039091 -> V=1.0, theta=0.0
% INFO    : Bus 35271	: V=1.02, theta=-23.549184 -> V=1.0, theta=0.0
% INFO    : Bus 35272	: V=1.0009065, theta=-22.396516 -> V=1.0, theta=0.0
% INFO    : Bus 35273	: V=1.0198783, theta=-44.086909 -> V=1.0, theta=0.0
% INFO    : Bus 35274	: V=1.02, theta=-33.418996 -> V=1.0, theta=0.0
% INFO    : Bus 35275	: V=1.017678, theta=-23.501464 -> V=1.0, theta=0.0
% INFO    : Bus 35276	: V=0.9946254, theta=-27.966093 -> V=1.0, theta=0.0
% INFO    : Bus 35277	: V=1.02, theta=-23.03647 -> V=1.0, theta=0.0
% INFO    : Bus 35278	: V=1.02, theta=-40.350943 -> V=1.0, theta=0.0
% INFO    : Bus 35279	: V=1.0168919, theta=-26.726277 -> V=1.0, theta=0.0
% INFO    : Bus 35280	: V=1.0049659, theta=-22.763041 -> V=1.0, theta=0.0
% INFO    : Bus 35281	: V=1.02, theta=-25.447497 -> V=1.0, theta=0.0
% INFO    : Bus 35282	: V=1.02, theta=-23.558647 -> V=1.0, theta=0.0
% INFO    : Bus 35283	: V=1.0121199, theta=-23.902284 -> V=1.0, theta=0.0
% INFO    : Bus 35284	: V=1.0192049, theta=-41.015957 -> V=1.0, theta=0.0
% INFO    : Bus 35285	: V=1.0020234, theta=-22.705921 -> V=1.0, theta=0.0
% INFO    : Bus 35286	: V=0.9953125, theta=-25.111869 -> V=1.0, theta=0.0
% INFO    : Bus 35287	: V=1.0069146, theta=-49.466843 -> V=1.0, theta=0.0
% INFO    : Bus 35288	: V=1.0049256, theta=-26.293847 -> V=1.0, theta=0.0
% INFO    : Bus 35289	: V=1.02, theta=-23.988019 -> V=1.0, theta=0.0
% INFO    : Bus 35290	: V=1.02, theta=-24.75201 -> V=1.0, theta=0.0
% INFO    : Bus 35291	: V=1.02, theta=-33.312697 -> V=1.0, theta=0.0
% INFO    : Bus 35292	: V=0.9889417, theta=-52.273556 -> V=1.0, theta=0.0
% INFO    : Bus 35293	: V=1.02, theta=-16.298373 -> V=1.0, theta=0.0
% INFO    : Bus 35294	: V=1.02, theta=-30.821219 -> V=1.0, theta=0.0
% INFO    : Bus 35295	: V=1.007808, theta=-31.167352 -> V=1.0, theta=0.0
% INFO    : Bus 35296	: V=1.02, theta=-20.606479 -> V=1.0, theta=0.0
% INFO    : Bus 35297	: V=0.9979835, theta=-27.332841 -> V=1.0, theta=0.0
% INFO    : Bus 35298	: V=0.9799167, theta=-26.708142 -> V=1.0, theta=0.0
% INFO    : Bus 35299	: V=0.9698012, theta=-25.637884 -> V=1.0, theta=0.0
% INFO    : Bus 35300	: V=1.02, theta=-23.398533 -> V=1.0, theta=0.0
% INFO    : Bus 35301	: V=1.0101113, theta=-25.538924 -> V=1.0, theta=0.0
% INFO    : Bus 35302	: V=1.0195107, theta=-29.770008 -> V=1.0, theta=0.0
% INFO    : Bus 35303	: V=1.0004454, theta=-26.637393 -> V=1.0, theta=0.0
% INFO    : Bus 35304	: V=1.02, theta=-18.256833 -> V=1.0, theta=0.0
% INFO    : Bus 35305	: V=1.0170634, theta=-26.971347 -> V=1.0, theta=0.0
% INFO    : Bus 35306	: V=1.02, theta=-20.594461 -> V=1.0, theta=0.0
% INFO    : Bus 35307	: V=0.980869, theta=-24.37825 -> V=1.0, theta=0.0
% INFO    : Bus 35308	: V=1.0184435, theta=-10.061492 -> V=1.0, theta=0.0
% INFO    : Bus 35309	: V=1.02, theta=-8.963868 -> V=1.0, theta=0.0
% INFO    : Bus 35310	: V=1.02, theta=-9.031766 -> V=1.0, theta=0.0
% INFO    : Bus 35311	: V=1.02, theta=-10.248389 -> V=1.0, theta=0.0
% INFO    : Bus 35312	: V=1.02, theta=-8.229417 -> V=1.0, theta=0.0
% INFO    : Bus 35313	: V=1.02, theta=-8.247513 -> V=1.0, theta=0.0
% INFO    : Bus 35314	: V=1.02, theta=-14.83844 -> V=1.0, theta=0.0
% INFO    : Bus 35315	: V=1.02, theta=-6.913282 -> V=1.0, theta=0.0
% INFO    : Bus 35316	: V=1.02, theta=-31.473117 -> V=1.0, theta=0.0
% INFO    : Bus 35317	: V=1.02, theta=-31.434542 -> V=1.0, theta=0.0
% INFO    : Bus 35318	: V=1.02, theta=-8.089094 -> V=1.0, theta=0.0
% INFO    : Bus 35319	: V=1.02, theta=-6.384176 -> V=1.0, theta=0.0
% INFO    : Bus 35320	: V=1.02, theta=-8.326076 -> V=1.0, theta=0.0
% INFO    : Bus 35321	: V=1.02, theta=-8.113449 -> V=1.0, theta=0.0
% INFO    : Bus 35322	: V=1.0189958, theta=-8.23207 -> V=1.0, theta=0.0
% INFO    : Bus 35323	: V=1.02, theta=-6.394275 -> V=1.0, theta=0.0
% INFO    : Bus 35324	: V=1.02, theta=-18.010569 -> V=1.0, theta=0.0
% INFO    : Bus 35325	: V=0.948464, theta=-33.150725 -> V=1.0, theta=0.0
% INFO    : Bus 35326	: V=1.0200015, theta=-6.911866 -> V=1.0, theta=0.0
% INFO    : Bus 35327	: V=1.02, theta=-17.7085 -> V=1.0, theta=0.0
% INFO    : Bus 35328	: V=1.02, theta=-8.434876 -> V=1.0, theta=0.0
% INFO    : Bus 35329	: V=1.02, theta=-8.721446 -> V=1.0, theta=0.0
% INFO    : Bus 35330	: V=1.0164614, theta=-7.77331 -> V=1.0, theta=0.0
% INFO    : Bus 35331	: V=1.020321, theta=-8.576029 -> V=1.0, theta=0.0
% INFO    : Bus 35332	: V=0.9820962, theta=-16.199034 -> V=1.0, theta=0.0
% INFO    : Bus 35333	: V=0.9884835, theta=-32.393166 -> V=1.0, theta=0.0
% INFO    : Bus 35334	: V=1.02, theta=-8.358632 -> V=1.0, theta=0.0
% INFO    : Bus 35335	: V=1.0187309, theta=-24.54419 -> V=1.0, theta=0.0
% INFO    : Bus 35336	: V=1.0198481, theta=-8.74516 -> V=1.0, theta=0.0
% INFO    : Bus 35337	: V=1.0054377, theta=-8.037364 -> V=1.0, theta=0.0
% INFO    : Bus 35338	: V=1.0198503, theta=-8.731148 -> V=1.0, theta=0.0
% INFO    : Bus 35339	: V=1.0000036, theta=-18.627138 -> V=1.0, theta=0.0
% INFO    : Bus 35340	: V=1.0061147, theta=-18.389603 -> V=1.0, theta=0.0
% INFO    : Bus 35341	: V=1.0162023, theta=-8.711023 -> V=1.0, theta=0.0
% INFO    : Bus 35342	: V=0.9789973, theta=-17.043476 -> V=1.0, theta=0.0
% INFO    : Bus 35343	: V=0.9905676, theta=-39.563653 -> V=1.0, theta=0.0
% INFO    : Bus 35344	: V=1.02, theta=-23.536369 -> V=1.0, theta=0.0
% INFO    : Bus 35345	: V=1.02, theta=-48.722001 -> V=1.0, theta=0.0
% INFO    : Bus 35346	: V=1.02, theta=-27.743749 -> V=1.0, theta=0.0
% INFO    : Bus 35347	: V=1.02, theta=-20.021626 -> V=1.0, theta=0.0
% INFO    : Bus 35348	: V=1.0208499, theta=-20.652383 -> V=1.0, theta=0.0
% INFO    : Bus 35349	: V=1.02, theta=-49.136182 -> V=1.0, theta=0.0
% INFO    : Bus 35350	: V=1.02, theta=-22.539435 -> V=1.0, theta=0.0
% INFO    : Bus 35351	: V=1.0032631, theta=-25.456944 -> V=1.0, theta=0.0
% INFO    : Bus 35352	: V=1.02, theta=-21.219596 -> V=1.0, theta=0.0
% INFO    : Bus 35353	: V=1.02, theta=-21.99917 -> V=1.0, theta=0.0
% INFO    : Bus 35354	: V=1.02, theta=-37.02965 -> V=1.0, theta=0.0
% INFO    : Bus 35355	: V=1.02, theta=-23.676903 -> V=1.0, theta=0.0
% INFO    : Bus 35356	: V=1.02, theta=-50.223315 -> V=1.0, theta=0.0
% INFO    : Bus 35357	: V=1.02, theta=-19.266782 -> V=1.0, theta=0.0
% INFO    : Bus 35358	: V=1.0296336, theta=-24.708451 -> V=1.0, theta=0.0
% INFO    : Bus 35359	: V=1.02, theta=-23.42868 -> V=1.0, theta=0.0
% INFO    : Bus 35360	: V=1.02, theta=-44.573137 -> V=1.0, theta=0.0
% INFO    : Bus 35361	: V=1.0129827, theta=-20.329143 -> V=1.0, theta=0.0
% INFO    : Bus 35362	: V=1.02, theta=-21.964061 -> V=1.0, theta=0.0
% INFO    : Bus 35363	: V=1.0152513, theta=-47.184151 -> V=1.0, theta=0.0
% INFO    : Bus 35364	: V=1.02, theta=-45.174445 -> V=1.0, theta=0.0
% INFO    : Bus 35365	: V=1.0175003, theta=-28.088511 -> V=1.0, theta=0.0
% INFO    : Bus 35366	: V=1.0100235, theta=-44.16927 -> V=1.0, theta=0.0
% INFO    : Bus 35367	: V=1.02, theta=-22.686984 -> V=1.0, theta=0.0
% INFO    : Bus 35368	: V=0.9928619, theta=-40.043335 -> V=1.0, theta=0.0
% INFO    : Bus 35369	: V=1.02, theta=-52.654576 -> V=1.0, theta=0.0
% INFO    : Bus 35370	: V=0.9993736, theta=-29.942871 -> V=1.0, theta=0.0
% INFO    : Bus 35371	: V=1.0168739, theta=-45.049669 -> V=1.0, theta=0.0
% INFO    : Bus 35372	: V=1.0181301, theta=-49.749802 -> V=1.0, theta=0.0
% INFO    : Bus 35373	: V=1.0147788, theta=-50.149491 -> V=1.0, theta=0.0
% INFO    : Bus 35374	: V=1.0129379, theta=-20.338259 -> V=1.0, theta=0.0
% INFO    : Bus 35375	: V=0.9867857, theta=-28.156963 -> V=1.0, theta=0.0
% INFO    : Bus 35376	: V=0.9988882, theta=-43.694312 -> V=1.0, theta=0.0
% INFO    : Bus 35377	: V=1.02, theta=-13.274363 -> V=1.0, theta=0.0
% INFO    : Bus 35378	: V=1.02, theta=-29.765379 -> V=1.0, theta=0.0
% INFO    : Bus 35379	: V=1.02, theta=-23.527737 -> V=1.0, theta=0.0
% INFO    : Bus 35380	: V=1.0090734, theta=-35.755682 -> V=1.0, theta=0.0
% INFO    : Bus 35381	: V=1.02, theta=-22.97495 -> V=1.0, theta=0.0
% INFO    : Bus 35382	: V=1.02, theta=-22.180398 -> V=1.0, theta=0.0
% INFO    : Bus 35383	: V=1.0189813, theta=-45.547067 -> V=1.0, theta=0.0
% INFO    : Bus 35384	: V=0.9775436, theta=-48.209728 -> V=1.0, theta=0.0
% INFO    : Bus 35385	: V=1.02, theta=-14.939558 -> V=1.0, theta=0.0
% INFO    : Bus 35386	: V=1.02, theta=-32.780903 -> V=1.0, theta=0.0
% INFO    : Bus 35387	: V=1.02, theta=-16.433146 -> V=1.0, theta=0.0
% INFO    : Bus 35388	: V=1.02, theta=-13.366329 -> V=1.0, theta=0.0
% INFO    : Bus 35389	: V=1.02, theta=-17.753552 -> V=1.0, theta=0.0
% INFO    : Bus 35390	: V=1.0175774, theta=-29.98852 -> V=1.0, theta=0.0
% INFO    : Bus 35391	: V=0.9796096, theta=-33.751956 -> V=1.0, theta=0.0
% INFO    : Bus 35392	: V=1.0199441, theta=-29.870414 -> V=1.0, theta=0.0
% INFO    : Bus 35393	: V=1.0085995, theta=-36.402434 -> V=1.0, theta=0.0
% INFO    : Bus 35394	: V=1.0017922, theta=-38.653081 -> V=1.0, theta=0.0
% INFO    : Bus 35395	: V=0.9661305, theta=-51.608444 -> V=1.0, theta=0.0
% INFO    : Bus 35396	: V=1.0013869, theta=-39.511844 -> V=1.0, theta=0.0
% INFO    : Bus 35397	: V=0.9765759, theta=-30.149692 -> V=1.0, theta=0.0
% INFO    : Bus 35398	: V=0.9792302, theta=-39.863295 -> V=1.0, theta=0.0
% INFO    : Bus 35399	: V=1.0126188, theta=-37.880349 -> V=1.0, theta=0.0
% INFO    : Bus 35400	: V=1.02, theta=-21.743589 -> V=1.0, theta=0.0
% INFO    : Bus 35401	: V=0.9939225, theta=-28.075001 -> V=1.0, theta=0.0
% INFO    : Bus 35402	: V=0.9513215, theta=-63.77487 -> V=1.0, theta=0.0
% INFO    : Bus 35403	: V=0.9901307, theta=-19.015117 -> V=1.0, theta=0.0
% INFO    : Bus 35404	: V=0.9951473, theta=-38.286452 -> V=1.0, theta=0.0
% INFO    : Bus 35405	: V=0.9903898, theta=-38.925673 -> V=1.0, theta=0.0
% INFO    : Bus 35406	: V=0.9682653, theta=-39.92918 -> V=1.0, theta=0.0
% INFO    : Bus 35407	: V=1.0199151, theta=-29.958854 -> V=1.0, theta=0.0
% INFO    : Bus 35408	: V=1.0151072, theta=-33.512974 -> V=1.0, theta=0.0
% INFO    : Bus 35409	: V=0.9755178, theta=-47.082391 -> V=1.0, theta=0.0
% INFO    : Bus 35410	: V=0.9707932, theta=-46.281409 -> V=1.0, theta=0.0
% INFO    : Bus 35411	: V=0.9918043, theta=-49.816699 -> V=1.0, theta=0.0
% INFO    : Bus 35412	: V=0.9784612, theta=-50.807135 -> V=1.0, theta=0.0
% INFO    : Bus 35413	: V=1.0138767, theta=-37.683704 -> V=1.0, theta=0.0
% INFO    : Bus 35414	: V=0.9683765, theta=-61.38729 -> V=1.0, theta=0.0
% INFO    : Bus 35415	: V=0.9883193, theta=-33.221875 -> V=1.0, theta=0.0
% INFO    : Bus 35416	: V=0.9913452, theta=-38.258418 -> V=1.0, theta=0.0
% INFO    : Bus 35417	: V=0.9935936, theta=-33.006257 -> V=1.0, theta=0.0
% INFO    : Bus 35418	: V=0.9728827, theta=-29.052912 -> V=1.0, theta=0.0
% INFO    : Bus 35419	: V=1.0133462, theta=-24.340981 -> V=1.0, theta=0.0
% INFO    : Bus 35420	: V=0.9980077, theta=-37.652327 -> V=1.0, theta=0.0
% INFO    : Bus 35421	: V=1.02, theta=-22.198873 -> V=1.0, theta=0.0
% INFO    : Bus 35422	: V=1.0131852, theta=-46.458332 -> V=1.0, theta=0.0
% INFO    : Bus 35423	: V=0.9711298, theta=-37.744603 -> V=1.0, theta=0.0
% INFO    : Bus 35424	: V=1.0115021, theta=-23.540615 -> V=1.0, theta=0.0
% INFO    : Bus 35425	: V=1.0096745, theta=-23.946575 -> V=1.0, theta=0.0
% INFO    : Bus 35426	: V=1.0121873, theta=-24.020865 -> V=1.0, theta=0.0
% INFO    : Bus 35427	: V=1.0117001, theta=-24.064755 -> V=1.0, theta=0.0
% INFO    : Bus 35428	: V=1.0108597, theta=-24.142944 -> V=1.0, theta=0.0
% INFO    : Bus 35429	: V=1.0113462, theta=-24.278665 -> V=1.0, theta=0.0
% INFO    : Bus 35430	: V=1.0085361, theta=-25.418105 -> V=1.0, theta=0.0
% INFO    : Bus 35431	: V=1.0173732, theta=-23.247873 -> V=1.0, theta=0.0
% INFO    : Bus 35432	: V=1.0128646, theta=-23.133694 -> V=1.0, theta=0.0
% INFO    : Bus 35433	: V=1.0141078, theta=-22.244919 -> V=1.0, theta=0.0
% INFO    : Bus 35434	: V=1.0197642, theta=-21.76586 -> V=1.0, theta=0.0
% INFO    : Bus 35435	: V=1.0184222, theta=-25.088144 -> V=1.0, theta=0.0
% INFO    : Bus 35436	: V=1.0212244, theta=-44.57107 -> V=1.0, theta=0.0
% INFO    : Bus 35437	: V=0.9573045, theta=-52.468365 -> V=1.0, theta=0.0
% INFO    : Bus 35438	: V=0.9743942, theta=-52.048551 -> V=1.0, theta=0.0
% INFO    : Bus 35439	: V=0.9574325, theta=-54.141206 -> V=1.0, theta=0.0
% INFO    : Bus 35440	: V=0.9664005, theta=-52.181821 -> V=1.0, theta=0.0
% INFO    : Bus 35441	: V=0.9858223, theta=-49.282855 -> V=1.0, theta=0.0
% INFO    : Bus 35442	: V=0.9855499, theta=-51.352391 -> V=1.0, theta=0.0
% INFO    : Bus 35443	: V=0.9761821, theta=-53.078108 -> V=1.0, theta=0.0
% INFO    : Bus 35444	: V=0.9786607, theta=-52.494458 -> V=1.0, theta=0.0
% INFO    : Bus 35445	: V=0.9775984, theta=-52.692038 -> V=1.0, theta=0.0
% INFO    : Bus 35446	: V=0.968759, theta=-53.440681 -> V=1.0, theta=0.0
% INFO    : Bus 35447	: V=0.9740882, theta=-53.610133 -> V=1.0, theta=0.0
% INFO    : Bus 35448	: V=0.9624551, theta=-57.317159 -> V=1.0, theta=0.0
% INFO    : Bus 35449	: V=0.9707226, theta=-54.402649 -> V=1.0, theta=0.0
% INFO    : Bus 35450	: V=0.9461615, theta=-58.202006 -> V=1.0, theta=0.0
% INFO    : Bus 35451	: V=0.9537701, theta=-57.995752 -> V=1.0, theta=0.0
% INFO    : Bus 35452	: V=0.9781615, theta=-53.240575 -> V=1.0, theta=0.0
% INFO    : Bus 35453	: V=0.9673378, theta=-54.212261 -> V=1.0, theta=0.0
% INFO    : Bus 35454	: V=0.9687824, theta=-53.603355 -> V=1.0, theta=0.0
% INFO    : Bus 35455	: V=0.981122, theta=-52.840035 -> V=1.0, theta=0.0
% INFO    : Bus 35456	: V=0.9835984, theta=-52.735352 -> V=1.0, theta=0.0
% INFO    : Bus 35457	: V=0.9466505, theta=-58.81672 -> V=1.0, theta=0.0
% INFO    : Bus 35458	: V=0.9471531, theta=-59.438278 -> V=1.0, theta=0.0
% INFO    : Bus 35459	: V=0.931597, theta=-60.429988 -> V=1.0, theta=0.0
% INFO    : Bus 35460	: V=0.9431338, theta=-59.898959 -> V=1.0, theta=0.0
% INFO    : Bus 35461	: V=0.9382057, theta=-59.768027 -> V=1.0, theta=0.0
% INFO    : Bus 35462	: V=0.9592226, theta=-55.441902 -> V=1.0, theta=0.0
% INFO    : Bus 35463	: V=0.9679809, theta=-55.442279 -> V=1.0, theta=0.0
% INFO    : Bus 35464	: V=0.9642982, theta=-55.893429 -> V=1.0, theta=0.0
% INFO    : Bus 35465	: V=0.954974, theta=-58.285737 -> V=1.0, theta=0.0
% INFO    : Bus 35466	: V=0.9559717, theta=-58.355372 -> V=1.0, theta=0.0
% INFO    : Bus 35467	: V=1.0035828, theta=-33.645628 -> V=1.0, theta=0.0
% INFO    : Bus 35468	: V=0.9936292, theta=-38.122815 -> V=1.0, theta=0.0
% INFO    : Bus 35469	: V=0.9923619, theta=-39.149724 -> V=1.0, theta=0.0
% INFO    : Bus 35470	: V=0.9692664, theta=-42.007963 -> V=1.0, theta=0.0
% INFO    : Bus 35471	: V=1.0020899, theta=-37.631784 -> V=1.0, theta=0.0
% INFO    : Bus 35472	: V=0.9991768, theta=-36.84026 -> V=1.0, theta=0.0
% INFO    : Bus 35473	: V=1.0020687, theta=-35.158906 -> V=1.0, theta=0.0
% INFO    : Bus 35474	: V=0.9931029, theta=-38.679084 -> V=1.0, theta=0.0
% INFO    : Bus 35475	: V=1.0010878, theta=-36.551697 -> V=1.0, theta=0.0
% INFO    : Bus 35476	: V=0.9885611, theta=-25.39558 -> V=1.0, theta=0.0
% INFO    : Bus 35477	: V=0.9916556, theta=-23.833719 -> V=1.0, theta=0.0
% INFO    : Bus 35478	: V=0.9887683, theta=-24.617429 -> V=1.0, theta=0.0
% INFO    : Bus 35479	: V=0.9901951, theta=-25.43105 -> V=1.0, theta=0.0
% INFO    : Bus 35480	: V=0.9593568, theta=-28.731381 -> V=1.0, theta=0.0
% INFO    : Bus 35481	: V=0.9579269, theta=-29.049511 -> V=1.0, theta=0.0
% INFO    : Bus 35482	: V=0.9579249, theta=-28.534959 -> V=1.0, theta=0.0
% INFO    : Bus 35483	: V=0.9574169, theta=-29.525703 -> V=1.0, theta=0.0
% INFO    : Bus 35484	: V=0.9564417, theta=-29.071131 -> V=1.0, theta=0.0
% INFO    : Bus 35485	: V=0.9674827, theta=-26.578543 -> V=1.0, theta=0.0
% INFO    : Bus 35486	: V=0.9724978, theta=-25.212802 -> V=1.0, theta=0.0
% INFO    : Bus 35487	: V=0.9710493, theta=-25.457324 -> V=1.0, theta=0.0
% INFO    : Bus 35488	: V=0.9554692, theta=-27.573755 -> V=1.0, theta=0.0
% INFO    : Bus 35489	: V=0.9815619, theta=-39.02644 -> V=1.0, theta=0.0
% INFO    : Bus 35490	: V=0.9775956, theta=-33.922928 -> V=1.0, theta=0.0
% INFO    : Bus 35491	: V=0.976072, theta=-35.915207 -> V=1.0, theta=0.0
% INFO    : Bus 35492	: V=0.987886, theta=-41.109135 -> V=1.0, theta=0.0
% INFO    : Bus 35493	: V=0.9931544, theta=-40.753019 -> V=1.0, theta=0.0
% INFO    : Bus 35494	: V=1.0037735, theta=-40.199478 -> V=1.0, theta=0.0
% INFO    : Bus 35495	: V=1.0017526, theta=-38.940335 -> V=1.0, theta=0.0
% INFO    : Bus 35496	: V=0.9918712, theta=-40.789279 -> V=1.0, theta=0.0
% INFO    : Bus 35497	: V=0.9836537, theta=-41.584158 -> V=1.0, theta=0.0
% INFO    : Bus 35498	: V=1.0194653, theta=-41.723064 -> V=1.0, theta=0.0
% INFO    : Bus 35499	: V=1.019989, theta=-41.776627 -> V=1.0, theta=0.0
% INFO    : Bus 35500	: V=1.0002062, theta=-41.739072 -> V=1.0, theta=0.0
% INFO    : Bus 35501	: V=0.9882731, theta=-27.25695 -> V=1.0, theta=0.0
% INFO    : Bus 35502	: V=0.9820959, theta=-27.973981 -> V=1.0, theta=0.0
% INFO    : Bus 35503	: V=0.9905666, theta=-27.04554 -> V=1.0, theta=0.0
% INFO    : Bus 35504	: V=0.9899008, theta=-27.089445 -> V=1.0, theta=0.0
% INFO    : Bus 35505	: V=0.9899384, theta=-27.046169 -> V=1.0, theta=0.0
% INFO    : Bus 35506	: V=0.9864683, theta=-27.430368 -> V=1.0, theta=0.0
% INFO    : Bus 35507	: V=0.9766835, theta=-28.740018 -> V=1.0, theta=0.0
% INFO    : Bus 35508	: V=0.9840416, theta=-27.97821 -> V=1.0, theta=0.0
% INFO    : Bus 35509	: V=0.9889378, theta=-27.155758 -> V=1.0, theta=0.0
% INFO    : Bus 35510	: V=0.9866023, theta=-27.239952 -> V=1.0, theta=0.0
% INFO    : Bus 35511	: V=0.9922501, theta=-26.839811 -> V=1.0, theta=0.0
% INFO    : Bus 35512	: V=0.9942312, theta=-26.655801 -> V=1.0, theta=0.0
% INFO    : Bus 35513	: V=0.9919053, theta=-26.888833 -> V=1.0, theta=0.0
% INFO    : Bus 35514	: V=0.9820583, theta=-28.012731 -> V=1.0, theta=0.0
% INFO    : Bus 35515	: V=1.0041737, theta=-25.355768 -> V=1.0, theta=0.0
% INFO    : Bus 35516	: V=0.9888198, theta=-27.345156 -> V=1.0, theta=0.0
% INFO    : Bus 35517	: V=0.9809983, theta=-28.156806 -> V=1.0, theta=0.0
% INFO    : Bus 35518	: V=0.9850075, theta=-27.68267 -> V=1.0, theta=0.0
% INFO    : Bus 35519	: V=0.960673, theta=-29.908844 -> V=1.0, theta=0.0
% INFO    : Bus 35520	: V=0.9839643, theta=-27.944073 -> V=1.0, theta=0.0
% INFO    : Bus 35521	: V=0.9753772, theta=-28.7063 -> V=1.0, theta=0.0
% INFO    : Bus 35522	: V=0.9845207, theta=-27.809969 -> V=1.0, theta=0.0
% INFO    : Bus 35523	: V=0.9671494, theta=-29.100675 -> V=1.0, theta=0.0
% INFO    : Bus 35524	: V=0.9823036, theta=-28.035589 -> V=1.0, theta=0.0
% INFO    : Bus 35525	: V=0.9841624, theta=-28.006053 -> V=1.0, theta=0.0
% INFO    : Bus 35526	: V=0.987129, theta=-27.735365 -> V=1.0, theta=0.0
% INFO    : Bus 35527	: V=0.9875875, theta=-27.928422 -> V=1.0, theta=0.0
% INFO    : Bus 35528	: V=0.9999434, theta=-26.585849 -> V=1.0, theta=0.0
% INFO    : Bus 35529	: V=1.0179158, theta=-21.564587 -> V=1.0, theta=0.0
% INFO    : Bus 35530	: V=1.0037043, theta=-25.260689 -> V=1.0, theta=0.0
% INFO    : Bus 35531	: V=0.9843454, theta=-27.502801 -> V=1.0, theta=0.0
% INFO    : Bus 35532	: V=0.9975462, theta=-26.457458 -> V=1.0, theta=0.0
% INFO    : Bus 35533	: V=1.0110155, theta=-25.321103 -> V=1.0, theta=0.0
% INFO    : Bus 35534	: V=1.0090021, theta=-25.839192 -> V=1.0, theta=0.0
% INFO    : Bus 35535	: V=1.0028936, theta=-26.524043 -> V=1.0, theta=0.0
% INFO    : Bus 35536	: V=1.0098309, theta=-25.853693 -> V=1.0, theta=0.0
% INFO    : Bus 35537	: V=1.0151545, theta=-25.211208 -> V=1.0, theta=0.0
% INFO    : Bus 35538	: V=1.0212818, theta=-24.288749 -> V=1.0, theta=0.0
% INFO    : Bus 35539	: V=1.0204675, theta=-24.806796 -> V=1.0, theta=0.0
% INFO    : Bus 35540	: V=0.9864348, theta=-27.685013 -> V=1.0, theta=0.0
% INFO    : Bus 35541	: V=0.9854107, theta=-27.418519 -> V=1.0, theta=0.0
% INFO    : Bus 35542	: V=0.9900352, theta=-28.053396 -> V=1.0, theta=0.0
% INFO    : Bus 35543	: V=0.9867571, theta=-28.069868 -> V=1.0, theta=0.0
% INFO    : Bus 35544	: V=0.990486, theta=-27.712748 -> V=1.0, theta=0.0
% INFO    : Bus 35545	: V=0.9836287, theta=-27.938256 -> V=1.0, theta=0.0
% INFO    : Bus 35546	: V=1.0199024, theta=-20.849425 -> V=1.0, theta=0.0
% INFO    : Bus 35547	: V=1.0197085, theta=-21.021241 -> V=1.0, theta=0.0
% INFO    : Bus 35548	: V=1.0191047, theta=-20.77026 -> V=1.0, theta=0.0
% INFO    : Bus 35549	: V=1.0152598, theta=-21.19125 -> V=1.0, theta=0.0
% INFO    : Bus 35550	: V=1.0091197, theta=-22.068887 -> V=1.0, theta=0.0
% INFO    : Bus 35551	: V=1.0022956, theta=-22.657599 -> V=1.0, theta=0.0
% INFO    : Bus 35552	: V=0.9978102, theta=-23.725445 -> V=1.0, theta=0.0
% INFO    : Bus 35553	: V=1.0201679, theta=-20.585841 -> V=1.0, theta=0.0
% INFO    : Bus 35554	: V=1.0169645, theta=-21.227319 -> V=1.0, theta=0.0
% INFO    : Bus 35555	: V=0.9863462, theta=-36.376656 -> V=1.0, theta=0.0
% INFO    : Bus 35556	: V=0.9998076, theta=-38.878195 -> V=1.0, theta=0.0
% INFO    : Bus 35557	: V=0.9958472, theta=-41.162046 -> V=1.0, theta=0.0
% INFO    : Bus 35558	: V=0.9985203, theta=-42.913145 -> V=1.0, theta=0.0
% INFO    : Bus 35559	: V=1.0053088, theta=-38.853292 -> V=1.0, theta=0.0
% INFO    : Bus 35560	: V=1.0000494, theta=-37.526263 -> V=1.0, theta=0.0
% INFO    : Bus 35561	: V=0.9991195, theta=-36.962727 -> V=1.0, theta=0.0
% INFO    : Bus 35562	: V=0.9960614, theta=-39.021153 -> V=1.0, theta=0.0
% INFO    : Bus 35563	: V=1.011853, theta=-40.394535 -> V=1.0, theta=0.0
% INFO    : Bus 35564	: V=0.9934568, theta=-41.141074 -> V=1.0, theta=0.0
% INFO    : Bus 35565	: V=1.0187925, theta=-40.771489 -> V=1.0, theta=0.0
% INFO    : Bus 35566	: V=1.0082848, theta=-40.908406 -> V=1.0, theta=0.0
% INFO    : Bus 35567	: V=1.0188353, theta=-42.170772 -> V=1.0, theta=0.0
% INFO    : Bus 35568	: V=0.9930922, theta=-26.287217 -> V=1.0, theta=0.0
% INFO    : Bus 35569	: V=0.9961342, theta=-25.786832 -> V=1.0, theta=0.0
% INFO    : Bus 35570	: V=1.0044701, theta=-24.750193 -> V=1.0, theta=0.0
% INFO    : Bus 35571	: V=1.0067236, theta=-24.470068 -> V=1.0, theta=0.0
% INFO    : Bus 35572	: V=0.9457266, theta=-30.625512 -> V=1.0, theta=0.0
% INFO    : Bus 35573	: V=0.9593196, theta=-30.190789 -> V=1.0, theta=0.0
% INFO    : Bus 35574	: V=0.990184, theta=-26.618039 -> V=1.0, theta=0.0
% INFO    : Bus 35575	: V=0.9736169, theta=-26.50066 -> V=1.0, theta=0.0
% INFO    : Bus 35576	: V=0.9891095, theta=-41.326932 -> V=1.0, theta=0.0
% INFO    : Bus 35577	: V=0.9783827, theta=-41.962045 -> V=1.0, theta=0.0
% INFO    : Bus 35578	: V=0.9706602, theta=-43.108091 -> V=1.0, theta=0.0
% INFO    : Bus 35579	: V=0.9871905, theta=-41.923541 -> V=1.0, theta=0.0
% INFO    : Bus 35580	: V=0.9859496, theta=-42.200559 -> V=1.0, theta=0.0
% INFO    : Bus 35581	: V=0.9775362, theta=-43.580247 -> V=1.0, theta=0.0
% INFO    : Bus 35582	: V=0.9864892, theta=-42.3454 -> V=1.0, theta=0.0
% INFO    : Bus 35583	: V=0.9867129, theta=-41.980159 -> V=1.0, theta=0.0
% INFO    : Bus 35584	: V=0.9873008, theta=-41.860895 -> V=1.0, theta=0.0
% INFO    : Bus 35585	: V=0.9792661, theta=-42.822224 -> V=1.0, theta=0.0
% INFO    : Bus 35586	: V=0.9764148, theta=-42.952639 -> V=1.0, theta=0.0
% INFO    : Bus 35587	: V=0.9935833, theta=-41.163644 -> V=1.0, theta=0.0
% INFO    : Bus 35588	: V=0.9621473, theta=-44.783496 -> V=1.0, theta=0.0
% INFO    : Bus 35589	: V=0.988778, theta=-41.662577 -> V=1.0, theta=0.0
% INFO    : Bus 35590	: V=1.0131972, theta=-18.91538 -> V=1.0, theta=0.0
% INFO    : Bus 35591	: V=1.0036313, theta=-19.866255 -> V=1.0, theta=0.0
% INFO    : Bus 35592	: V=1.0123993, theta=-18.97837 -> V=1.0, theta=0.0
% INFO    : Bus 35593	: V=1.0121414, theta=-18.985432 -> V=1.0, theta=0.0
% INFO    : Bus 35594	: V=1.0121018, theta=-18.979552 -> V=1.0, theta=0.0
% INFO    : Bus 35595	: V=1.0107958, theta=-19.124342 -> V=1.0, theta=0.0
% INFO    : Bus 35596	: V=1.0079976, theta=-19.567774 -> V=1.0, theta=0.0
% INFO    : Bus 35597	: V=1.0084624, theta=-19.449448 -> V=1.0, theta=0.0
% INFO    : Bus 35598	: V=1.0092978, theta=-19.324314 -> V=1.0, theta=0.0
% INFO    : Bus 35599	: V=1.0167273, theta=-18.15641 -> V=1.0, theta=0.0
% INFO    : Bus 35600	: V=0.9989909, theta=-20.870285 -> V=1.0, theta=0.0
% INFO    : Bus 35601	: V=1.0057901, theta=-20.303812 -> V=1.0, theta=0.0
% INFO    : Bus 35602	: V=1.0093364, theta=-19.385995 -> V=1.0, theta=0.0
% INFO    : Bus 35603	: V=1.0146061, theta=-19.302555 -> V=1.0, theta=0.0
% INFO    : Bus 35604	: V=1.0100248, theta=-43.483072 -> V=1.0, theta=0.0
% INFO    : Bus 35605	: V=1.021852, theta=-43.122544 -> V=1.0, theta=0.0
% INFO    : Bus 35606	: V=0.9999157, theta=-45.116682 -> V=1.0, theta=0.0
% INFO    : Bus 35607	: V=1.0040684, theta=-44.38064 -> V=1.0, theta=0.0
% INFO    : Bus 35608	: V=1.021245, theta=-42.157856 -> V=1.0, theta=0.0
% INFO    : Bus 35609	: V=1.0131623, theta=-23.518946 -> V=1.0, theta=0.0
% INFO    : Bus 35610	: V=1.0115883, theta=-22.275373 -> V=1.0, theta=0.0
% INFO    : Bus 35611	: V=1.0172124, theta=-22.590263 -> V=1.0, theta=0.0
% INFO    : Bus 35612	: V=1.0028915, theta=-41.624553 -> V=1.0, theta=0.0
% INFO    : Bus 35613	: V=1.0207012, theta=-41.786489 -> V=1.0, theta=0.0
% INFO    : Bus 35614	: V=0.9999664, theta=-42.117563 -> V=1.0, theta=0.0
% INFO    : Bus 35615	: V=0.9992016, theta=-42.167691 -> V=1.0, theta=0.0
% INFO    : Bus 35616	: V=1.0041501, theta=-41.840385 -> V=1.0, theta=0.0
% INFO    : Bus 35617	: V=1.0022772, theta=-41.963712 -> V=1.0, theta=0.0
% INFO    : Bus 35618	: V=0.9848081, theta=-43.285665 -> V=1.0, theta=0.0
% INFO    : Bus 35619	: V=0.97163, theta=-43.867991 -> V=1.0, theta=0.0
% INFO    : Bus 35620	: V=0.9763796, theta=-43.631064 -> V=1.0, theta=0.0
% INFO    : Bus 35621	: V=0.977484, theta=-43.616565 -> V=1.0, theta=0.0
% INFO    : Bus 35622	: V=0.9887612, theta=-42.401298 -> V=1.0, theta=0.0
% INFO    : Bus 35623	: V=0.9756502, theta=-43.588971 -> V=1.0, theta=0.0
% INFO    : Bus 35624	: V=0.9881355, theta=-42.861963 -> V=1.0, theta=0.0
% INFO    : Bus 35625	: V=0.9862459, theta=-42.995871 -> V=1.0, theta=0.0
% INFO    : Bus 35626	: V=0.9670208, theta=-43.2663 -> V=1.0, theta=0.0
% INFO    : Bus 35627	: V=0.9616404, theta=-43.369161 -> V=1.0, theta=0.0
% INFO    : Bus 35628	: V=0.9806199, theta=-42.056132 -> V=1.0, theta=0.0
% INFO    : Bus 35629	: V=0.9874698, theta=-41.580143 -> V=1.0, theta=0.0
% INFO    : Bus 35630	: V=0.9931426, theta=-42.194867 -> V=1.0, theta=0.0
% INFO    : Bus 35631	: V=0.994842, theta=-41.490707 -> V=1.0, theta=0.0
% INFO    : Bus 35632	: V=0.9572028, theta=-28.718592 -> V=1.0, theta=0.0
% INFO    : Bus 35633	: V=0.964583, theta=-26.002409 -> V=1.0, theta=0.0
% INFO    : Bus 35634	: V=0.9447178, theta=-29.354047 -> V=1.0, theta=0.0
% INFO    : Bus 35635	: V=0.9739043, theta=-24.697465 -> V=1.0, theta=0.0
% INFO    : Bus 35636	: V=0.9798879, theta=-24.198885 -> V=1.0, theta=0.0
% INFO    : Bus 35637	: V=0.944741, theta=-28.992013 -> V=1.0, theta=0.0
% INFO    : Bus 35638	: V=0.9506559, theta=-28.815776 -> V=1.0, theta=0.0
% INFO    : Bus 35639	: V=0.969733, theta=-25.389985 -> V=1.0, theta=0.0
% INFO    : Bus 35640	: V=0.9659588, theta=-25.951651 -> V=1.0, theta=0.0
% INFO    : Bus 35641	: V=0.9689857, theta=-25.60164 -> V=1.0, theta=0.0
% INFO    : Bus 35642	: V=0.9694003, theta=-25.61656 -> V=1.0, theta=0.0
% INFO    : Bus 35643	: V=0.9586745, theta=-26.982177 -> V=1.0, theta=0.0
% INFO    : Bus 35644	: V=0.9468423, theta=-27.32368 -> V=1.0, theta=0.0
% INFO    : Bus 35645	: V=0.9498841, theta=-27.902105 -> V=1.0, theta=0.0
% INFO    : Bus 35646	: V=0.9728259, theta=-25.344796 -> V=1.0, theta=0.0
% INFO    : Bus 35647	: V=0.9815237, theta=-24.27472 -> V=1.0, theta=0.0
% INFO    : Bus 35648	: V=0.9884508, theta=-23.44019 -> V=1.0, theta=0.0
% INFO    : Bus 35649	: V=0.9902422, theta=-23.297332 -> V=1.0, theta=0.0
% INFO    : Bus 35650	: V=1.0176905, theta=-38.468205 -> V=1.0, theta=0.0
% INFO    : Bus 35651	: V=0.993704, theta=-40.408448 -> V=1.0, theta=0.0
% INFO    : Bus 35652	: V=0.9690592, theta=-41.885129 -> V=1.0, theta=0.0
% INFO    : Bus 35653	: V=0.9755281, theta=-41.761881 -> V=1.0, theta=0.0
% INFO    : Bus 35654	: V=0.9943896, theta=-40.491372 -> V=1.0, theta=0.0
% INFO    : Bus 35655	: V=0.9804401, theta=-41.620359 -> V=1.0, theta=0.0
% INFO    : Bus 35656	: V=0.9823431, theta=-41.52693 -> V=1.0, theta=0.0
% INFO    : Bus 35657	: V=0.9868382, theta=-41.354126 -> V=1.0, theta=0.0
% INFO    : Bus 35658	: V=0.9841446, theta=-41.474229 -> V=1.0, theta=0.0
% INFO    : Bus 35659	: V=0.958143, theta=-44.888909 -> V=1.0, theta=0.0
% INFO    : Bus 35660	: V=0.9929248, theta=-41.294762 -> V=1.0, theta=0.0
% INFO    : Bus 35661	: V=0.979827, theta=-42.279179 -> V=1.0, theta=0.0
% INFO    : Bus 35662	: V=0.9885167, theta=-41.886064 -> V=1.0, theta=0.0
% INFO    : Bus 35663	: V=0.9869806, theta=-42.176903 -> V=1.0, theta=0.0
% INFO    : Bus 35664	: V=1.0048769, theta=-28.380755 -> V=1.0, theta=0.0
% INFO    : Bus 35665	: V=1.0034873, theta=-29.902015 -> V=1.0, theta=0.0
% INFO    : Bus 35666	: V=0.9900355, theta=-28.125166 -> V=1.0, theta=0.0
% INFO    : Bus 35667	: V=0.9956617, theta=-30.003382 -> V=1.0, theta=0.0
% INFO    : Bus 35668	: V=1.0029086, theta=-29.265175 -> V=1.0, theta=0.0
% INFO    : Bus 35669	: V=1.0030697, theta=-29.275794 -> V=1.0, theta=0.0
% INFO    : Bus 35670	: V=1.0024683, theta=-29.402655 -> V=1.0, theta=0.0
% INFO    : Bus 35671	: V=1.0025434, theta=-29.73927 -> V=1.0, theta=0.0
% INFO    : Bus 35672	: V=1.000678, theta=-30.321316 -> V=1.0, theta=0.0
% INFO    : Bus 35673	: V=1.0021691, theta=-29.586792 -> V=1.0, theta=0.0
% INFO    : Bus 35674	: V=1.0073598, theta=-30.342645 -> V=1.0, theta=0.0
% INFO    : Bus 35675	: V=1.0030961, theta=-32.823088 -> V=1.0, theta=0.0
% INFO    : Bus 35676	: V=1.0047268, theta=-30.762824 -> V=1.0, theta=0.0
% INFO    : Bus 35677	: V=1.0004094, theta=-30.471081 -> V=1.0, theta=0.0
% INFO    : Bus 35678	: V=1.0084804, theta=-28.933824 -> V=1.0, theta=0.0
% INFO    : Bus 35679	: V=0.9965453, theta=-25.607793 -> V=1.0, theta=0.0
% INFO    : Bus 35680	: V=0.9906844, theta=-26.267225 -> V=1.0, theta=0.0
% INFO    : Bus 35681	: V=0.9596748, theta=-29.867953 -> V=1.0, theta=0.0
% INFO    : Bus 35682	: V=0.9818042, theta=-27.635935 -> V=1.0, theta=0.0
% INFO    : Bus 35683	: V=0.9695839, theta=-28.648888 -> V=1.0, theta=0.0
% INFO    : Bus 35684	: V=0.9704561, theta=-28.856218 -> V=1.0, theta=0.0
% INFO    : Bus 35685	: V=0.9736577, theta=-28.8663 -> V=1.0, theta=0.0
% INFO    : Bus 35686	: V=0.9788149, theta=-28.503856 -> V=1.0, theta=0.0
% INFO    : Bus 35687	: V=0.9835519, theta=-27.956289 -> V=1.0, theta=0.0
% INFO    : Bus 35688	: V=0.9737603, theta=-28.394792 -> V=1.0, theta=0.0
% INFO    : Bus 35689	: V=0.9837659, theta=-27.258704 -> V=1.0, theta=0.0
% INFO    : Bus 35690	: V=0.9870764, theta=-26.743821 -> V=1.0, theta=0.0
% INFO    : Bus 35691	: V=0.9852957, theta=-27.093755 -> V=1.0, theta=0.0
% INFO    : Bus 35692	: V=0.990334, theta=-26.321416 -> V=1.0, theta=0.0
% INFO    : Bus 35693	: V=1.0003287, theta=-24.640764 -> V=1.0, theta=0.0
% INFO    : Bus 35694	: V=1.0180638, theta=-23.097722 -> V=1.0, theta=0.0
% INFO    : Bus 35695	: V=1.0124244, theta=-24.381757 -> V=1.0, theta=0.0
% INFO    : Bus 35696	: V=1.0058583, theta=-25.933258 -> V=1.0, theta=0.0
% INFO    : Bus 35697	: V=1.0062058, theta=-24.997474 -> V=1.0, theta=0.0
% INFO    : Bus 35698	: V=1.0148157, theta=-23.822417 -> V=1.0, theta=0.0
% INFO    : Bus 35699	: V=0.996038, theta=-26.536635 -> V=1.0, theta=0.0
% INFO    : Bus 35700	: V=1.0062256, theta=-25.447226 -> V=1.0, theta=0.0
% INFO    : Bus 35701	: V=1.0156917, theta=-23.940909 -> V=1.0, theta=0.0
% INFO    : Bus 35702	: V=0.9804403, theta=-27.041527 -> V=1.0, theta=0.0
% INFO    : Bus 35703	: V=1.0112685, theta=-24.283025 -> V=1.0, theta=0.0
% INFO    : Bus 35704	: V=0.9985797, theta=-25.559498 -> V=1.0, theta=0.0
% INFO    : Bus 35705	: V=1.0032498, theta=-25.118121 -> V=1.0, theta=0.0
% INFO    : Bus 35706	: V=0.9876447, theta=-26.813162 -> V=1.0, theta=0.0
% INFO    : Bus 35707	: V=0.9908227, theta=-26.828631 -> V=1.0, theta=0.0
% INFO    : Bus 35708	: V=0.9879843, theta=-50.360346 -> V=1.0, theta=0.0
% INFO    : Bus 35709	: V=0.9966277, theta=-46.095654 -> V=1.0, theta=0.0
% INFO    : Bus 35710	: V=0.9953773, theta=-49.822377 -> V=1.0, theta=0.0
% INFO    : Bus 35711	: V=0.993364, theta=-49.069603 -> V=1.0, theta=0.0
% INFO    : Bus 35712	: V=0.9639599, theta=-48.576172 -> V=1.0, theta=0.0
% INFO    : Bus 35713	: V=1.0216831, theta=-43.902152 -> V=1.0, theta=0.0
% INFO    : Bus 35714	: V=1.0155596, theta=-44.588192 -> V=1.0, theta=0.0
% INFO    : Bus 35715	: V=0.9766073, theta=-48.288994 -> V=1.0, theta=0.0
% INFO    : Bus 35716	: V=0.9824618, theta=-47.925173 -> V=1.0, theta=0.0
% INFO    : Bus 35717	: V=0.978464, theta=-29.70723 -> V=1.0, theta=0.0
% INFO    : Bus 35718	: V=0.9613375, theta=-30.396054 -> V=1.0, theta=0.0
% INFO    : Bus 35719	: V=0.9588027, theta=-30.425316 -> V=1.0, theta=0.0
% INFO    : Bus 35720	: V=0.9657467, theta=-30.149759 -> V=1.0, theta=0.0
% INFO    : Bus 35721	: V=0.9673036, theta=-29.998807 -> V=1.0, theta=0.0
% INFO    : Bus 35722	: V=0.9661703, theta=-30.143789 -> V=1.0, theta=0.0
% INFO    : Bus 35723	: V=0.9649487, theta=-30.163363 -> V=1.0, theta=0.0
% INFO    : Bus 35724	: V=0.9825181, theta=-28.106828 -> V=1.0, theta=0.0
% INFO    : Bus 35725	: V=0.9645069, theta=-30.17012 -> V=1.0, theta=0.0
% INFO    : Bus 35726	: V=0.9786267, theta=-29.434209 -> V=1.0, theta=0.0
% INFO    : Bus 35727	: V=0.9645049, theta=-30.239718 -> V=1.0, theta=0.0
% INFO    : Bus 35728	: V=0.9924097, theta=-27.992888 -> V=1.0, theta=0.0
% INFO    : Bus 35729	: V=0.9909809, theta=-27.904492 -> V=1.0, theta=0.0
% INFO    : Bus 35730	: V=0.9903279, theta=-27.996711 -> V=1.0, theta=0.0
% INFO    : Bus 35731	: V=0.9625474, theta=-30.19877 -> V=1.0, theta=0.0
% INFO    : Bus 35732	: V=0.9809071, theta=-28.386989 -> V=1.0, theta=0.0
% INFO    : Bus 35733	: V=0.9608009, theta=-30.412861 -> V=1.0, theta=0.0
% INFO    : Bus 35734	: V=0.9861089, theta=-27.569333 -> V=1.0, theta=0.0
% INFO    : Bus 35735	: V=0.9969446, theta=-26.338197 -> V=1.0, theta=0.0
% INFO    : Bus 35736	: V=0.9930428, theta=-27.272684 -> V=1.0, theta=0.0
% INFO    : Bus 35737	: V=0.9886383, theta=-27.995722 -> V=1.0, theta=0.0
% INFO    : Bus 35738	: V=0.9749141, theta=-29.212447 -> V=1.0, theta=0.0
% INFO    : Bus 35739	: V=0.9864338, theta=-28.150568 -> V=1.0, theta=0.0
% INFO    : Bus 35740	: V=0.9721274, theta=-29.452723 -> V=1.0, theta=0.0
% INFO    : Bus 35741	: V=0.9724405, theta=-29.484487 -> V=1.0, theta=0.0
% INFO    : Bus 35742	: V=0.9797098, theta=-28.695639 -> V=1.0, theta=0.0
% INFO    : Bus 35743	: V=0.9553197, theta=-31.465725 -> V=1.0, theta=0.0
% INFO    : Bus 35744	: V=0.9685338, theta=-29.463488 -> V=1.0, theta=0.0
% INFO    : Bus 35745	: V=0.954218, theta=-30.535628 -> V=1.0, theta=0.0
% INFO    : Bus 35746	: V=0.993613, theta=-27.981058 -> V=1.0, theta=0.0
% INFO    : Bus 35747	: V=0.9968883, theta=-22.445796 -> V=1.0, theta=0.0
% INFO    : Bus 35748	: V=0.9965559, theta=-22.598949 -> V=1.0, theta=0.0
% INFO    : Bus 35749	: V=0.9973728, theta=-22.628608 -> V=1.0, theta=0.0
% INFO    : Bus 35750	: V=0.9935946, theta=-22.874232 -> V=1.0, theta=0.0
% INFO    : Bus 35751	: V=0.9954979, theta=-22.710434 -> V=1.0, theta=0.0
% INFO    : Bus 35752	: V=1.0044848, theta=-20.625101 -> V=1.0, theta=0.0
% INFO    : Bus 35753	: V=1.0045973, theta=-20.816192 -> V=1.0, theta=0.0
% INFO    : Bus 35754	: V=1.0027524, theta=-21.423417 -> V=1.0, theta=0.0
% INFO    : Bus 35755	: V=1.0035762, theta=-21.079756 -> V=1.0, theta=0.0
% INFO    : Bus 35756	: V=1.0077454, theta=-21.32758 -> V=1.0, theta=0.0
% INFO    : Bus 35757	: V=1.0028509, theta=-22.027136 -> V=1.0, theta=0.0
% INFO    : Bus 35758	: V=1.0016067, theta=-22.068978 -> V=1.0, theta=0.0
% INFO    : Bus 35759	: V=1.0005717, theta=-22.318225 -> V=1.0, theta=0.0
% INFO    : Bus 35760	: V=1.0077325, theta=-21.385279 -> V=1.0, theta=0.0
% INFO    : Bus 35761	: V=0.976148, theta=-43.466973 -> V=1.0, theta=0.0
% INFO    : Bus 35762	: V=0.9863647, theta=-42.140157 -> V=1.0, theta=0.0
% INFO    : Bus 35763	: V=0.9708495, theta=-43.657173 -> V=1.0, theta=0.0
% INFO    : Bus 35764	: V=0.970438, theta=-43.505441 -> V=1.0, theta=0.0
% INFO    : Bus 35765	: V=0.9725067, theta=-43.214346 -> V=1.0, theta=0.0
% INFO    : Bus 35766	: V=0.974493, theta=-42.970413 -> V=1.0, theta=0.0
% INFO    : Bus 35767	: V=0.9946216, theta=-24.815836 -> V=1.0, theta=0.0
% INFO    : Bus 35768	: V=1.0068481, theta=-23.367225 -> V=1.0, theta=0.0
% INFO    : Bus 35769	: V=0.9982826, theta=-26.567242 -> V=1.0, theta=0.0
% INFO    : Bus 35770	: V=1.0056329, theta=-22.934056 -> V=1.0, theta=0.0
% INFO    : Bus 35771	: V=1.0062669, theta=-23.383495 -> V=1.0, theta=0.0
% INFO    : Bus 35772	: V=1.0068827, theta=-23.366211 -> V=1.0, theta=0.0
% INFO    : Bus 35773	: V=1.0072249, theta=-23.397086 -> V=1.0, theta=0.0
% INFO    : Bus 35774	: V=1.0105844, theta=-22.61667 -> V=1.0, theta=0.0
% INFO    : Bus 35775	: V=0.9993275, theta=-23.618189 -> V=1.0, theta=0.0
% INFO    : Bus 35776	: V=1.0048146, theta=-38.764646 -> V=1.0, theta=0.0
% INFO    : Bus 35777	: V=1.0047579, theta=-39.02507 -> V=1.0, theta=0.0
% INFO    : Bus 35778	: V=0.9909922, theta=-40.152574 -> V=1.0, theta=0.0
% INFO    : Bus 35779	: V=0.9696947, theta=-42.645439 -> V=1.0, theta=0.0
% INFO    : Bus 35780	: V=0.9776985, theta=-42.48948 -> V=1.0, theta=0.0
% INFO    : Bus 35781	: V=1.0074898, theta=-39.221639 -> V=1.0, theta=0.0
% INFO    : Bus 35782	: V=0.9743616, theta=-43.352891 -> V=1.0, theta=0.0
% INFO    : Bus 35783	: V=0.9696489, theta=-43.551943 -> V=1.0, theta=0.0
% INFO    : Bus 35784	: V=0.9745461, theta=-43.302822 -> V=1.0, theta=0.0
% INFO    : Bus 35785	: V=0.9874705, theta=-42.276416 -> V=1.0, theta=0.0
% INFO    : Bus 35786	: V=0.9868879, theta=-42.267897 -> V=1.0, theta=0.0
% INFO    : Bus 35787	: V=0.9869446, theta=-42.299678 -> V=1.0, theta=0.0
% INFO    : Bus 35788	: V=0.977191, theta=-43.114353 -> V=1.0, theta=0.0
% INFO    : Bus 35789	: V=0.9796972, theta=-42.946346 -> V=1.0, theta=0.0
% INFO    : Bus 35790	: V=0.9760391, theta=-43.129857 -> V=1.0, theta=0.0
% INFO    : Bus 35791	: V=0.9825499, theta=-42.187294 -> V=1.0, theta=0.0
% INFO    : Bus 35792	: V=0.9891697, theta=-41.584306 -> V=1.0, theta=0.0
% INFO    : Bus 35793	: V=0.9882658, theta=-41.810998 -> V=1.0, theta=0.0
% INFO    : Bus 35794	: V=0.9854911, theta=-41.924738 -> V=1.0, theta=0.0
% INFO    : Bus 35795	: V=0.9806861, theta=-42.853379 -> V=1.0, theta=0.0
% INFO    : Bus 35796	: V=0.9882789, theta=-41.98493 -> V=1.0, theta=0.0
% INFO    : Bus 35797	: V=0.9984902, theta=-41.58538 -> V=1.0, theta=0.0
% INFO    : Bus 35798	: V=1.0035948, theta=-40.92757 -> V=1.0, theta=0.0
% INFO    : Bus 35799	: V=1.0188692, theta=-36.590182 -> V=1.0, theta=0.0
% INFO    : Bus 35800	: V=0.999575, theta=-38.312576 -> V=1.0, theta=0.0
% INFO    : Bus 35801	: V=0.9967162, theta=-40.191873 -> V=1.0, theta=0.0
% INFO    : Bus 35802	: V=0.9699403, theta=-42.142333 -> V=1.0, theta=0.0
% INFO    : Bus 35803	: V=0.9773937, theta=-42.652803 -> V=1.0, theta=0.0
% INFO    : Bus 35804	: V=1.0084202, theta=-24.043831 -> V=1.0, theta=0.0
% INFO    : Bus 35805	: V=1.0195792, theta=-22.480455 -> V=1.0, theta=0.0
% INFO    : Bus 35806	: V=0.9920305, theta=-25.363186 -> V=1.0, theta=0.0
% INFO    : Bus 35807	: V=0.9596271, theta=-29.198981 -> V=1.0, theta=0.0
% INFO    : Bus 35808	: V=0.9507332, theta=-29.156837 -> V=1.0, theta=0.0
% INFO    : Bus 35809	: V=0.9762209, theta=-26.861871 -> V=1.0, theta=0.0
% INFO    : Bus 35810	: V=0.9729246, theta=-27.470571 -> V=1.0, theta=0.0
% INFO    : Bus 35811	: V=0.9723805, theta=-27.416477 -> V=1.0, theta=0.0
% INFO    : Bus 35812	: V=0.9602061, theta=-28.840291 -> V=1.0, theta=0.0
% INFO    : Bus 35813	: V=0.9726303, theta=-26.841407 -> V=1.0, theta=0.0
% INFO    : Bus 35814	: V=0.9704409, theta=-28.126749 -> V=1.0, theta=0.0
% INFO    : Bus 35815	: V=0.9652457, theta=-26.066103 -> V=1.0, theta=0.0
% INFO    : Bus 35816	: V=0.9598143, theta=-26.695492 -> V=1.0, theta=0.0
% INFO    : Bus 35817	: V=0.9668873, theta=-25.859717 -> V=1.0, theta=0.0
% INFO    : Bus 35818	: V=0.9667577, theta=-25.846718 -> V=1.0, theta=0.0
% INFO    : Bus 35819	: V=0.9694493, theta=-25.637566 -> V=1.0, theta=0.0
% INFO    : Bus 35820	: V=0.9708285, theta=-25.48335 -> V=1.0, theta=0.0
% INFO    : Bus 35821	: V=0.9747305, theta=-24.983554 -> V=1.0, theta=0.0
% INFO    : Bus 35822	: V=0.9733915, theta=-25.14191 -> V=1.0, theta=0.0
% INFO    : Bus 35823	: V=0.9688682, theta=-25.589473 -> V=1.0, theta=0.0
% INFO    : Bus 35824	: V=0.9675583, theta=-25.658826 -> V=1.0, theta=0.0
% INFO    : Bus 35825	: V=0.9660826, theta=-25.685219 -> V=1.0, theta=0.0
% INFO    : Bus 35826	: V=0.9649573, theta=-26.01678 -> V=1.0, theta=0.0
% INFO    : Bus 35827	: V=0.9644248, theta=-26.098978 -> V=1.0, theta=0.0
% INFO    : Bus 35828	: V=0.9645254, theta=-26.100837 -> V=1.0, theta=0.0
% INFO    : Bus 35829	: V=0.9599762, theta=-26.645577 -> V=1.0, theta=0.0
% INFO    : Bus 35830	: V=0.9646095, theta=-26.07282 -> V=1.0, theta=0.0
% INFO    : Bus 35831	: V=0.9653624, theta=-25.990888 -> V=1.0, theta=0.0
% INFO    : Bus 35832	: V=0.9594266, theta=-26.709223 -> V=1.0, theta=0.0
% INFO    : Bus 35833	: V=0.9676503, theta=-25.729245 -> V=1.0, theta=0.0
% INFO    : Bus 35834	: V=0.9691456, theta=-25.559308 -> V=1.0, theta=0.0
% INFO    : Bus 35835	: V=0.9708683, theta=-25.376827 -> V=1.0, theta=0.0
% INFO    : Bus 35836	: V=0.9735982, theta=-25.107835 -> V=1.0, theta=0.0
% INFO    : Bus 35837	: V=0.9721934, theta=-25.247653 -> V=1.0, theta=0.0
% INFO    : Bus 35838	: V=0.9755325, theta=-24.859106 -> V=1.0, theta=0.0
% INFO    : Bus 35839	: V=0.9686575, theta=-25.582264 -> V=1.0, theta=0.0
% INFO    : Bus 35840	: V=0.9683102, theta=-25.587985 -> V=1.0, theta=0.0
% INFO    : Bus 35841	: V=0.9799341, theta=-24.414178 -> V=1.0, theta=0.0
% INFO    : Bus 35842	: V=0.9805829, theta=-24.358818 -> V=1.0, theta=0.0
% INFO    : Bus 35843	: V=0.9794131, theta=-24.456193 -> V=1.0, theta=0.0
% INFO    : Bus 35844	: V=0.9770557, theta=-24.697246 -> V=1.0, theta=0.0
% INFO    : Bus 35845	: V=0.9792909, theta=-24.468254 -> V=1.0, theta=0.0
% INFO    : Bus 35846	: V=0.9777132, theta=-24.646288 -> V=1.0, theta=0.0
% INFO    : Bus 35847	: V=0.976495, theta=-24.778525 -> V=1.0, theta=0.0
% INFO    : Bus 35848	: V=0.9713782, theta=-25.303889 -> V=1.0, theta=0.0
% INFO    : Bus 35849	: V=0.9706179, theta=-25.423772 -> V=1.0, theta=0.0
% INFO    : Bus 35850	: V=0.9691139, theta=-25.57908 -> V=1.0, theta=0.0
% INFO    : Bus 35851	: V=0.9675791, theta=-25.711605 -> V=1.0, theta=0.0
% INFO    : Bus 35852	: V=0.9581773, theta=-26.726903 -> V=1.0, theta=0.0
% INFO    : Bus 35853	: V=0.9588052, theta=-26.719878 -> V=1.0, theta=0.0
% INFO    : Bus 35854	: V=0.9679006, theta=-25.673743 -> V=1.0, theta=0.0
% INFO    : Bus 35855	: V=0.9694604, theta=-25.550175 -> V=1.0, theta=0.0
% INFO    : Bus 35856	: V=0.9700836, theta=-25.493496 -> V=1.0, theta=0.0
% INFO    : Bus 35857	: V=0.9714215, theta=-25.345684 -> V=1.0, theta=0.0
% INFO    : Bus 35858	: V=0.9722803, theta=-25.262363 -> V=1.0, theta=0.0
% INFO    : Bus 35859	: V=0.9721759, theta=-25.281441 -> V=1.0, theta=0.0
% INFO    : Bus 35860	: V=0.9738777, theta=-25.109849 -> V=1.0, theta=0.0
% INFO    : Bus 35861	: V=0.9641651, theta=-26.129418 -> V=1.0, theta=0.0
% INFO    : Bus 35862	: V=0.9696529, theta=-25.637798 -> V=1.0, theta=0.0
% INFO    : Bus 35863	: V=0.9641735, theta=-26.111694 -> V=1.0, theta=0.0
% INFO    : Bus 35864	: V=0.9789708, theta=-24.515928 -> V=1.0, theta=0.0
% INFO    : Bus 35865	: V=0.9793357, theta=-24.471081 -> V=1.0, theta=0.0
% INFO    : Bus 35866	: V=0.9705476, theta=-25.451772 -> V=1.0, theta=0.0
% INFO    : Bus 35867	: V=0.9538983, theta=-27.306583 -> V=1.0, theta=0.0
% INFO    : Bus 35868	: V=0.9552907, theta=-27.292396 -> V=1.0, theta=0.0
% INFO    : Bus 35869	: V=0.9692653, theta=-25.921439 -> V=1.0, theta=0.0
% INFO    : Bus 35870	: V=0.9691032, theta=-25.91476 -> V=1.0, theta=0.0
% INFO    : Bus 35871	: V=0.955496, theta=-27.235053 -> V=1.0, theta=0.0
% INFO    : Bus 35872	: V=0.9566001, theta=-27.224363 -> V=1.0, theta=0.0
% INFO    : Bus 35873	: V=0.9817711, theta=-23.951644 -> V=1.0, theta=0.0
% INFO    : Bus 35874	: V=0.9830027, theta=-23.845205 -> V=1.0, theta=0.0
% INFO    : Bus 35875	: V=0.9717838, theta=-25.059836 -> V=1.0, theta=0.0
% INFO    : Bus 35876	: V=0.9752919, theta=-24.84024 -> V=1.0, theta=0.0
% INFO    : Bus 35877	: V=0.9747659, theta=-24.900724 -> V=1.0, theta=0.0
% INFO    : Bus 35878	: V=0.9764181, theta=-24.754598 -> V=1.0, theta=0.0
% INFO    : Bus 35879	: V=0.9743918, theta=-24.945535 -> V=1.0, theta=0.0
% INFO    : Bus 35880	: V=0.9669162, theta=-26.043905 -> V=1.0, theta=0.0
% INFO    : Bus 35881	: V=0.9731786, theta=-24.854148 -> V=1.0, theta=0.0
% INFO    : Bus 35882	: V=0.9799509, theta=-24.404436 -> V=1.0, theta=0.0
% INFO    : Bus 35883	: V=0.9803683, theta=-24.319294 -> V=1.0, theta=0.0
% INFO    : Bus 35884	: V=0.9676224, theta=-25.796672 -> V=1.0, theta=0.0
% INFO    : Bus 35885	: V=0.9685654, theta=-25.609372 -> V=1.0, theta=0.0
% INFO    : Bus 35886	: V=0.9583835, theta=-26.728619 -> V=1.0, theta=0.0
% INFO    : Bus 35887	: V=0.9696019, theta=-25.524147 -> V=1.0, theta=0.0
% INFO    : Bus 35888	: V=0.970035, theta=-25.493094 -> V=1.0, theta=0.0
% INFO    : Bus 35889	: V=0.972576, theta=-25.215674 -> V=1.0, theta=0.0
% INFO    : Bus 35890	: V=0.9660115, theta=-25.832785 -> V=1.0, theta=0.0
% INFO    : Bus 35891	: V=0.9656408, theta=-25.857738 -> V=1.0, theta=0.0
% INFO    : Bus 35892	: V=0.9605196, theta=-26.522039 -> V=1.0, theta=0.0
% INFO    : Bus 35893	: V=0.9653841, theta=-25.877197 -> V=1.0, theta=0.0
% INFO    : Bus 35894	: V=0.9640817, theta=-26.137052 -> V=1.0, theta=0.0
% INFO    : Bus 35895	: V=0.9666187, theta=-25.878664 -> V=1.0, theta=0.0
% INFO    : Bus 35896	: V=0.9758143, theta=-25.725794 -> V=1.0, theta=0.0
% INFO    : Bus 35897	: V=0.9751687, theta=-25.75583 -> V=1.0, theta=0.0
% INFO    : Bus 35898	: V=0.9697384, theta=-25.927747 -> V=1.0, theta=0.0
% INFO    : Bus 35899	: V=0.9877079, theta=-24.069146 -> V=1.0, theta=0.0
% INFO    : Bus 35900	: V=0.9718818, theta=-25.83919 -> V=1.0, theta=0.0
% INFO    : Bus 35901	: V=0.973852, theta=-25.854918 -> V=1.0, theta=0.0
% INFO    : Bus 35902	: V=0.9493698, theta=-28.16075 -> V=1.0, theta=0.0
% INFO    : Bus 35903	: V=0.9505575, theta=-28.273775 -> V=1.0, theta=0.0
% INFO    : Bus 35904	: V=0.9553993, theta=-27.381111 -> V=1.0, theta=0.0
% INFO    : Bus 35905	: V=0.9505776, theta=-27.829494 -> V=1.0, theta=0.0
% INFO    : Bus 35906	: V=0.9675864, theta=-26.031191 -> V=1.0, theta=0.0
% INFO    : Bus 35907	: V=0.9560025, theta=-27.375965 -> V=1.0, theta=0.0
% INFO    : Bus 35908	: V=0.9569172, theta=-27.388664 -> V=1.0, theta=0.0
% INFO    : Bus 35909	: V=0.9677417, theta=-26.0034 -> V=1.0, theta=0.0
% INFO    : Bus 35910	: V=0.9583044, theta=-27.290699 -> V=1.0, theta=0.0
% INFO    : Bus 35911	: V=0.9631204, theta=-26.74603 -> V=1.0, theta=0.0
% INFO    : Bus 35912	: V=0.9737342, theta=-25.006549 -> V=1.0, theta=0.0
% INFO    : Bus 35913	: V=0.9787006, theta=-24.120923 -> V=1.0, theta=0.0
% INFO    : Bus 35914	: V=0.9814715, theta=-23.979966 -> V=1.0, theta=0.0
% INFO    : Bus 35915	: V=0.9765525, theta=-24.661472 -> V=1.0, theta=0.0
% INFO    : Bus 35916	: V=0.9763374, theta=-24.656741 -> V=1.0, theta=0.0
% INFO    : Bus 35917	: V=0.9750176, theta=-25.042072 -> V=1.0, theta=0.0
% INFO    : Bus 35918	: V=0.9508465, theta=-27.661508 -> V=1.0, theta=0.0
% INFO    : Bus 35919	: V=0.9683625, theta=-25.996288 -> V=1.0, theta=0.0
% INFO    : Bus 35920	: V=0.9691171, theta=-25.888287 -> V=1.0, theta=0.0
% INFO    : Bus 35921	: V=0.9573752, theta=-27.298566 -> V=1.0, theta=0.0
% INFO    : Bus 35922	: V=0.9834645, theta=-23.79007 -> V=1.0, theta=0.0
% INFO    : Bus 35923	: V=0.967659, theta=-25.909331 -> V=1.0, theta=0.0
% INFO    : Bus 35924	: V=0.9770068, theta=-24.636513 -> V=1.0, theta=0.0
% INFO    : Bus 35925	: V=0.9723598, theta=-25.248825 -> V=1.0, theta=0.0
% INFO    : Bus 35926	: V=0.9829017, theta=-23.866246 -> V=1.0, theta=0.0
% INFO    : Bus 35927	: V=0.9880687, theta=-23.147757 -> V=1.0, theta=0.0
% INFO    : Bus 35928	: V=1.0078918, theta=-20.190988 -> V=1.0, theta=0.0
% INFO    : Bus 35929	: V=0.9895963, theta=-23.070664 -> V=1.0, theta=0.0
% INFO    : Bus 35930	: V=0.9708213, theta=-24.976971 -> V=1.0, theta=0.0
% INFO    : Bus 35931	: V=0.9824863, theta=-23.937281 -> V=1.0, theta=0.0
% INFO    : Bus 35932	: V=0.9763685, theta=-24.770504 -> V=1.0, theta=0.0
% INFO    : Bus 35933	: V=0.9782227, theta=-24.537193 -> V=1.0, theta=0.0
% INFO    : Bus 35934	: V=0.9833161, theta=-23.857116 -> V=1.0, theta=0.0
% INFO    : Bus 35935	: V=0.9817654, theta=-24.136703 -> V=1.0, theta=0.0
% INFO    : Bus 35936	: V=0.9630379, theta=-26.216347 -> V=1.0, theta=0.0
% INFO    : Bus 35937	: V=0.9627674, theta=-26.278223 -> V=1.0, theta=0.0
% INFO    : Bus 35938	: V=0.9647712, theta=-26.111122 -> V=1.0, theta=0.0
% INFO    : Bus 35939	: V=0.9643715, theta=-26.204846 -> V=1.0, theta=0.0
% INFO    : Bus 35940	: V=0.9652964, theta=-25.885695 -> V=1.0, theta=0.0
% INFO    : Bus 35941	: V=0.9653372, theta=-25.884576 -> V=1.0, theta=0.0
% INFO    : Bus 35942	: V=0.9682944, theta=-25.641463 -> V=1.0, theta=0.0
% INFO    : Bus 35943	: V=0.9684308, theta=-25.542058 -> V=1.0, theta=0.0
% INFO    : Bus 35944	: V=0.9530219, theta=-27.172914 -> V=1.0, theta=0.0
% INFO    : Bus 35945	: V=0.9678668, theta=-25.601743 -> V=1.0, theta=0.0
% INFO    : Bus 35946	: V=0.966547, theta=-25.791897 -> V=1.0, theta=0.0
% INFO    : Bus 35947	: V=0.9672325, theta=-25.726654 -> V=1.0, theta=0.0
% INFO    : Bus 35948	: V=0.9678735, theta=-25.606378 -> V=1.0, theta=0.0
% INFO    : Bus 35949	: V=0.9681455, theta=-25.594459 -> V=1.0, theta=0.0
% INFO    : Bus 35950	: V=0.9599766, theta=-26.613631 -> V=1.0, theta=0.0
% INFO    : Bus 35951	: V=0.9695075, theta=-25.480848 -> V=1.0, theta=0.0
% INFO    : Bus 35952	: V=0.9743648, theta=-25.072533 -> V=1.0, theta=0.0
% INFO    : Bus 35953	: V=1.0102551, theta=-20.312629 -> V=1.0, theta=0.0
% INFO    : Bus 35954	: V=0.9809695, theta=-24.264891 -> V=1.0, theta=0.0
% INFO    : Bus 35955	: V=0.9745599, theta=-24.831429 -> V=1.0, theta=0.0
% INFO    : Bus 35956	: V=0.9803151, theta=-24.296787 -> V=1.0, theta=0.0
% INFO    : Bus 35957	: V=0.9736178, theta=-24.845036 -> V=1.0, theta=0.0
% INFO    : Bus 35958	: V=0.9727966, theta=-24.922151 -> V=1.0, theta=0.0
% INFO    : Bus 35959	: V=0.9806596, theta=-24.235825 -> V=1.0, theta=0.0
% INFO    : Bus 35960	: V=0.9817053, theta=-23.932391 -> V=1.0, theta=0.0
% INFO    : Bus 35961	: V=0.9879572, theta=-23.310874 -> V=1.0, theta=0.0
% INFO    : Bus 35962	: V=0.9872142, theta=-23.449644 -> V=1.0, theta=0.0
% INFO    : Bus 35963	: V=1.000316, theta=-22.047887 -> V=1.0, theta=0.0
% INFO    : Bus 35964	: V=0.9730794, theta=-25.159366 -> V=1.0, theta=0.0
% INFO    : Bus 35965	: V=0.972699, theta=-25.170719 -> V=1.0, theta=0.0
% INFO    : Bus 35966	: V=0.9721916, theta=-25.218245 -> V=1.0, theta=0.0
% INFO    : Bus 35967	: V=0.9726227, theta=-25.203449 -> V=1.0, theta=0.0
% INFO    : Bus 35968	: V=0.9734257, theta=-25.096646 -> V=1.0, theta=0.0
% INFO    : Bus 35969	: V=0.9770942, theta=-24.735049 -> V=1.0, theta=0.0
% INFO    : Bus 35970	: V=0.9576729, theta=-26.987771 -> V=1.0, theta=0.0
% INFO    : Bus 35971	: V=0.9562689, theta=-27.005062 -> V=1.0, theta=0.0
% INFO    : Bus 35972	: V=0.9575024, theta=-26.970252 -> V=1.0, theta=0.0
% INFO    : Bus 35973	: V=0.9533688, theta=-27.197042 -> V=1.0, theta=0.0
% INFO    : Bus 35974	: V=0.9558759, theta=-27.076881 -> V=1.0, theta=0.0
% INFO    : Bus 35975	: V=0.9736965, theta=-25.150104 -> V=1.0, theta=0.0
% INFO    : Bus 35976	: V=0.9599136, theta=-26.796758 -> V=1.0, theta=0.0
% INFO    : Bus 35977	: V=0.974218, theta=-25.06873 -> V=1.0, theta=0.0
% INFO    : Bus 35978	: V=0.9821171, theta=-22.674331 -> V=1.0, theta=0.0
% INFO    : Bus 35979	: V=1.0203452, theta=-19.568649 -> V=1.0, theta=0.0
% INFO    : Bus 35980	: V=0.9912609, theta=-23.188596 -> V=1.0, theta=0.0
% INFO    : Bus 35981	: V=1.0154499, theta=-18.735381 -> V=1.0, theta=0.0
% INFO    : Bus 35982	: V=0.9997258, theta=-20.813265 -> V=1.0, theta=0.0
% INFO    : Bus 35983	: V=0.9992194, theta=-20.818457 -> V=1.0, theta=0.0
% INFO    : Bus 35984	: V=1.0157429, theta=-18.904824 -> V=1.0, theta=0.0
% INFO    : Bus 35985	: V=1.0006725, theta=-20.808989 -> V=1.0, theta=0.0
% INFO    : Bus 35986	: V=1.0127426, theta=-18.965588 -> V=1.0, theta=0.0
% INFO    : Bus 35987	: V=1.0130593, theta=-18.926728 -> V=1.0, theta=0.0
% INFO    : Bus 35988	: V=1.0172968, theta=-18.718042 -> V=1.0, theta=0.0
% INFO    : Bus 35989	: V=1.0162558, theta=-18.837327 -> V=1.0, theta=0.0
% INFO    : Bus 35990	: V=1.0148131, theta=-18.99258 -> V=1.0, theta=0.0
% INFO    : Bus 35991	: V=1.0022521, theta=-20.208557 -> V=1.0, theta=0.0
% INFO    : Bus 35992	: V=1.013859, theta=-19.192172 -> V=1.0, theta=0.0
% INFO    : Bus 35993	: V=1.0111427, theta=-20.511197 -> V=1.0, theta=0.0
% INFO    : Bus 35994	: V=1.0072274, theta=-20.316468 -> V=1.0, theta=0.0
% INFO    : Bus 35995	: V=1.0137569, theta=-18.864992 -> V=1.0, theta=0.0
% INFO    : Bus 35996	: V=1.0079942, theta=-19.443899 -> V=1.0, theta=0.0
% INFO    : Bus 35997	: V=1.0014067, theta=-20.059478 -> V=1.0, theta=0.0
% INFO    : Bus 35998	: V=1.0049258, theta=-19.576805 -> V=1.0, theta=0.0
% INFO    : Bus 35999	: V=1.0093353, theta=-18.998216 -> V=1.0, theta=0.0
% INFO    : Bus 36000	: V=1.0029699, theta=-19.727252 -> V=1.0, theta=0.0
% INFO    : Bus 36001	: V=1.0042108, theta=-19.381798 -> V=1.0, theta=0.0
% INFO    : Bus 36002	: V=1.0181545, theta=-16.785093 -> V=1.0, theta=0.0
% INFO    : Bus 36003	: V=1.0117343, theta=-18.244223 -> V=1.0, theta=0.0
% INFO    : Bus 36004	: V=0.9980625, theta=-19.908377 -> V=1.0, theta=0.0
% INFO    : Bus 36005	: V=0.9956371, theta=-21.480597 -> V=1.0, theta=0.0
% INFO    : Bus 36006	: V=1.0058325, theta=-20.768352 -> V=1.0, theta=0.0
% INFO    : Bus 36007	: V=1.0062044, theta=-19.065363 -> V=1.0, theta=0.0
% INFO    : Bus 36008	: V=0.9949814, theta=-19.598475 -> V=1.0, theta=0.0
% INFO    : Bus 36009	: V=0.992797, theta=-22.351381 -> V=1.0, theta=0.0
% INFO    : Bus 36010	: V=1.0056762, theta=-21.004335 -> V=1.0, theta=0.0
% INFO    : Bus 36011	: V=1.0031931, theta=-21.623395 -> V=1.0, theta=0.0
% INFO    : Bus 36012	: V=0.981451, theta=-28.593674 -> V=1.0, theta=0.0
% INFO    : Bus 36013	: V=0.974651, theta=-29.501836 -> V=1.0, theta=0.0
% INFO    : Bus 36014	: V=0.9730766, theta=-29.873055 -> V=1.0, theta=0.0
% INFO    : Bus 36015	: V=0.9829323, theta=-28.730256 -> V=1.0, theta=0.0
% INFO    : Bus 36016	: V=0.9711451, theta=-29.722189 -> V=1.0, theta=0.0
% INFO    : Bus 36017	: V=0.9830303, theta=-28.546458 -> V=1.0, theta=0.0
% INFO    : Bus 36018	: V=0.9832849, theta=-28.642777 -> V=1.0, theta=0.0
% INFO    : Bus 36019	: V=0.9821811, theta=-28.603928 -> V=1.0, theta=0.0
% INFO    : Bus 36020	: V=0.9818413, theta=-28.614117 -> V=1.0, theta=0.0
% INFO    : Bus 36021	: V=0.9786851, theta=-29.136857 -> V=1.0, theta=0.0
% INFO    : Bus 36022	: V=0.9814473, theta=-28.615692 -> V=1.0, theta=0.0
% INFO    : Bus 36023	: V=0.9639547, theta=-30.183134 -> V=1.0, theta=0.0
% INFO    : Bus 36024	: V=0.9830979, theta=-28.41848 -> V=1.0, theta=0.0
% INFO    : Bus 36025	: V=0.9870657, theta=-27.89246 -> V=1.0, theta=0.0
% INFO    : Bus 36026	: V=0.9804141, theta=-28.677859 -> V=1.0, theta=0.0
% INFO    : Bus 36027	: V=0.9701937, theta=-29.98567 -> V=1.0, theta=0.0
% INFO    : Bus 36028	: V=0.9784485, theta=-28.871107 -> V=1.0, theta=0.0
% INFO    : Bus 36029	: V=0.9772358, theta=-28.980231 -> V=1.0, theta=0.0
% INFO    : Bus 36030	: V=0.9957882, theta=-27.190823 -> V=1.0, theta=0.0
% INFO    : Bus 36031	: V=1.0193372, theta=-25.242836 -> V=1.0, theta=0.0
% INFO    : Bus 36032	: V=1.0207293, theta=-25.480254 -> V=1.0, theta=0.0
% INFO    : Bus 36033	: V=1.0048573, theta=-27.359102 -> V=1.0, theta=0.0
% INFO    : Bus 36034	: V=1.0143081, theta=-26.726256 -> V=1.0, theta=0.0
% INFO    : Bus 36035	: V=1.0141256, theta=-26.641799 -> V=1.0, theta=0.0
% INFO    : Bus 36036	: V=1.0143469, theta=-26.552372 -> V=1.0, theta=0.0
% INFO    : Bus 36037	: V=0.9878435, theta=-28.718848 -> V=1.0, theta=0.0
% INFO    : Bus 36038	: V=0.997859, theta=-27.687067 -> V=1.0, theta=0.0
% INFO    : Bus 36039	: V=0.9731793, theta=-24.467924 -> V=1.0, theta=0.0
% INFO    : Bus 36040	: V=0.9704527, theta=-25.715455 -> V=1.0, theta=0.0
% INFO    : Bus 36041	: V=0.9994331, theta=-19.769087 -> V=1.0, theta=0.0
% INFO    : Bus 36042	: V=0.9900107, theta=-22.447544 -> V=1.0, theta=0.0
% INFO    : Bus 36043	: V=1.0009054, theta=-19.75815 -> V=1.0, theta=0.0
% INFO    : Bus 36044	: V=1.019766, theta=-16.864802 -> V=1.0, theta=0.0
% INFO    : Bus 36045	: V=1.0070257, theta=-19.128748 -> V=1.0, theta=0.0
% INFO    : Bus 36046	: V=1.0059673, theta=-19.281585 -> V=1.0, theta=0.0
% INFO    : Bus 36047	: V=1.0058925, theta=-19.282914 -> V=1.0, theta=0.0
% INFO    : Bus 36048	: V=1.005198, theta=-19.382882 -> V=1.0, theta=0.0
% INFO    : Bus 36049	: V=0.9809308, theta=-23.569898 -> V=1.0, theta=0.0
% INFO    : Bus 36050	: V=0.9757891, theta=-24.32319 -> V=1.0, theta=0.0
% INFO    : Bus 36051	: V=1.0073097, theta=-19.094916 -> V=1.0, theta=0.0
% INFO    : Bus 36052	: V=0.9967952, theta=-20.609889 -> V=1.0, theta=0.0
% INFO    : Bus 36053	: V=1.0181747, theta=-17.399513 -> V=1.0, theta=0.0
% INFO    : Bus 36054	: V=0.9838769, theta=-23.009911 -> V=1.0, theta=0.0
% INFO    : Bus 36055	: V=0.985756, theta=-31.089029 -> V=1.0, theta=0.0
% INFO    : Bus 36056	: V=1.0085751, theta=-27.349717 -> V=1.0, theta=0.0
% INFO    : Bus 36057	: V=0.994077, theta=-36.026803 -> V=1.0, theta=0.0
% INFO    : Bus 36058	: V=0.9884451, theta=-33.709653 -> V=1.0, theta=0.0
% INFO    : Bus 36059	: V=0.9846902, theta=-29.779215 -> V=1.0, theta=0.0
% INFO    : Bus 36060	: V=0.9887912, theta=-28.442228 -> V=1.0, theta=0.0
% INFO    : Bus 36061	: V=0.9772716, theta=-30.209894 -> V=1.0, theta=0.0
% INFO    : Bus 36062	: V=0.9808267, theta=-30.264839 -> V=1.0, theta=0.0
% INFO    : Bus 36063	: V=0.9729236, theta=-30.509684 -> V=1.0, theta=0.0
% INFO    : Bus 36064	: V=0.9831661, theta=-29.552598 -> V=1.0, theta=0.0
% INFO    : Bus 36065	: V=0.9787009, theta=-30.041801 -> V=1.0, theta=0.0
% INFO    : Bus 36066	: V=0.9814468, theta=-29.832057 -> V=1.0, theta=0.0
% INFO    : Bus 36067	: V=0.9792817, theta=-30.035481 -> V=1.0, theta=0.0
% INFO    : Bus 36068	: V=0.9808318, theta=-29.958054 -> V=1.0, theta=0.0
% INFO    : Bus 36069	: V=0.9736211, theta=-30.439859 -> V=1.0, theta=0.0
% INFO    : Bus 36070	: V=0.9815059, theta=-31.173249 -> V=1.0, theta=0.0
% INFO    : Bus 36071	: V=0.9570281, theta=-27.834256 -> V=1.0, theta=0.0
% INFO    : Bus 36072	: V=0.9567005, theta=-27.784108 -> V=1.0, theta=0.0
% INFO    : Bus 36073	: V=0.9566421, theta=-27.732743 -> V=1.0, theta=0.0
% INFO    : Bus 36074	: V=0.9567382, theta=-27.669142 -> V=1.0, theta=0.0
% INFO    : Bus 36075	: V=0.9490343, theta=-28.483183 -> V=1.0, theta=0.0
% INFO    : Bus 36076	: V=0.9494193, theta=-28.188448 -> V=1.0, theta=0.0
% INFO    : Bus 36077	: V=0.9488106, theta=-28.206139 -> V=1.0, theta=0.0
% INFO    : Bus 36078	: V=0.9509426, theta=-28.031495 -> V=1.0, theta=0.0
% INFO    : Bus 36079	: V=0.9514114, theta=-28.01936 -> V=1.0, theta=0.0
% INFO    : Bus 36080	: V=0.9576519, theta=-27.416904 -> V=1.0, theta=0.0
% INFO    : Bus 36081	: V=0.9569816, theta=-27.58587 -> V=1.0, theta=0.0
% INFO    : Bus 36082	: V=0.9572635, theta=-27.513514 -> V=1.0, theta=0.0
% INFO    : Bus 36083	: V=0.9573104, theta=-27.658253 -> V=1.0, theta=0.0
% INFO    : Bus 36084	: V=0.9578542, theta=-27.441419 -> V=1.0, theta=0.0
% INFO    : Bus 36085	: V=0.9584648, theta=-27.321192 -> V=1.0, theta=0.0
% INFO    : Bus 36086	: V=0.9530881, theta=-28.186843 -> V=1.0, theta=0.0
% INFO    : Bus 36087	: V=0.9585917, theta=-27.21639 -> V=1.0, theta=0.0
% INFO    : Bus 36088	: V=0.958022, theta=-27.333026 -> V=1.0, theta=0.0
% INFO    : Bus 36089	: V=0.9612037, theta=-26.625169 -> V=1.0, theta=0.0
% INFO    : Bus 36090	: V=0.9608, theta=-26.834645 -> V=1.0, theta=0.0
% INFO    : Bus 36091	: V=0.9543578, theta=-27.803779 -> V=1.0, theta=0.0
% INFO    : Bus 36092	: V=0.9585294, theta=-27.264963 -> V=1.0, theta=0.0
% INFO    : Bus 36093	: V=0.9533619, theta=-28.223002 -> V=1.0, theta=0.0
% INFO    : Bus 36094	: V=0.9594462, theta=-27.083715 -> V=1.0, theta=0.0
% INFO    : Bus 36095	: V=0.9534627, theta=-28.025492 -> V=1.0, theta=0.0
% INFO    : Bus 36096	: V=0.954423, theta=-27.997773 -> V=1.0, theta=0.0
% INFO    : Bus 36097	: V=0.9538922, theta=-28.021096 -> V=1.0, theta=0.0
% INFO    : Bus 36098	: V=0.9595158, theta=-26.994268 -> V=1.0, theta=0.0
% INFO    : Bus 36099	: V=0.9559087, theta=-27.653294 -> V=1.0, theta=0.0
% INFO    : Bus 36100	: V=0.9552598, theta=-27.769184 -> V=1.0, theta=0.0
% INFO    : Bus 36101	: V=0.9544815, theta=-27.749842 -> V=1.0, theta=0.0
% INFO    : Bus 36102	: V=0.9604617, theta=-26.889586 -> V=1.0, theta=0.0
% INFO    : Bus 36103	: V=0.9620411, theta=-26.566136 -> V=1.0, theta=0.0
% INFO    : Bus 36104	: V=0.9607134, theta=-26.824044 -> V=1.0, theta=0.0
% INFO    : Bus 36105	: V=0.9621618, theta=-26.553737 -> V=1.0, theta=0.0
% INFO    : Bus 36106	: V=0.9624237, theta=-26.529618 -> V=1.0, theta=0.0
% INFO    : Bus 36107	: V=0.9548863, theta=-27.572809 -> V=1.0, theta=0.0
% INFO    : Bus 36108	: V=0.9619207, theta=-26.577712 -> V=1.0, theta=0.0
% INFO    : Bus 36109	: V=0.9535992, theta=-27.828245 -> V=1.0, theta=0.0
% INFO    : Bus 36110	: V=0.9633133, theta=-26.445182 -> V=1.0, theta=0.0
% INFO    : Bus 36111	: V=0.9541242, theta=-27.655238 -> V=1.0, theta=0.0
% INFO    : Bus 36112	: V=0.9648069, theta=-26.308208 -> V=1.0, theta=0.0
% INFO    : Bus 36113	: V=0.9545403, theta=-27.704822 -> V=1.0, theta=0.0
% INFO    : Bus 36114	: V=0.9533406, theta=-28.344928 -> V=1.0, theta=0.0
% INFO    : Bus 36115	: V=0.9591193, theta=-27.187431 -> V=1.0, theta=0.0
% INFO    : Bus 36116	: V=0.9636187, theta=-28.771804 -> V=1.0, theta=0.0
% INFO    : Bus 36117	: V=0.9402735, theta=-29.787128 -> V=1.0, theta=0.0
% INFO    : Bus 36118	: V=0.9539472, theta=-29.269018 -> V=1.0, theta=0.0
% INFO    : Bus 36119	: V=0.9418399, theta=-30.645908 -> V=1.0, theta=0.0
% INFO    : Bus 36120	: V=0.959262, theta=-28.112124 -> V=1.0, theta=0.0
% INFO    : Bus 36121	: V=0.9603584, theta=-27.340743 -> V=1.0, theta=0.0
% INFO    : Bus 36122	: V=0.964977, theta=-26.266753 -> V=1.0, theta=0.0
% INFO    : Bus 36123	: V=0.9598157, theta=-27.233834 -> V=1.0, theta=0.0
% INFO    : Bus 36124	: V=0.9622663, theta=-26.169702 -> V=1.0, theta=0.0
% INFO    : Bus 36125	: V=0.9596821, theta=-27.113574 -> V=1.0, theta=0.0
% INFO    : Bus 36126	: V=0.9594857, theta=-27.064403 -> V=1.0, theta=0.0
% INFO    : Bus 36127	: V=0.9608694, theta=-26.697202 -> V=1.0, theta=0.0
% INFO    : Bus 36128	: V=0.9694243, theta=-25.372671 -> V=1.0, theta=0.0
% INFO    : Bus 36129	: V=0.9549728, theta=-28.735724 -> V=1.0, theta=0.0
% INFO    : Bus 36130	: V=0.958141, theta=-28.130975 -> V=1.0, theta=0.0
% INFO    : Bus 36131	: V=0.9477228, theta=-29.116516 -> V=1.0, theta=0.0
% INFO    : Bus 36132	: V=0.9461337, theta=-29.145155 -> V=1.0, theta=0.0
% INFO    : Bus 36133	: V=0.9436726, theta=-29.389252 -> V=1.0, theta=0.0
% INFO    : Bus 36134	: V=0.9705874, theta=-25.098982 -> V=1.0, theta=0.0
% INFO    : Bus 36135	: V=0.962093, theta=-26.475721 -> V=1.0, theta=0.0
% INFO    : Bus 36136	: V=0.9613287, theta=-26.373177 -> V=1.0, theta=0.0
% INFO    : Bus 36137	: V=0.9720784, theta=-24.885816 -> V=1.0, theta=0.0
% INFO    : Bus 36138	: V=0.9745623, theta=-24.490646 -> V=1.0, theta=0.0
% INFO    : Bus 36139	: V=0.9725147, theta=-24.70931 -> V=1.0, theta=0.0
% INFO    : Bus 36140	: V=0.9976267, theta=-19.994176 -> V=1.0, theta=0.0
% INFO    : Bus 36141	: V=0.9628313, theta=-25.688046 -> V=1.0, theta=0.0
% INFO    : Bus 36142	: V=0.9662763, theta=-26.726949 -> V=1.0, theta=0.0
% INFO    : Bus 36143	: V=0.969302, theta=-26.998226 -> V=1.0, theta=0.0
% INFO    : Bus 36144	: V=1.0004841, theta=-26.574235 -> V=1.0, theta=0.0
% INFO    : Bus 36145	: V=0.9941405, theta=-30.469452 -> V=1.0, theta=0.0
% INFO    : Bus 36146	: V=0.9775428, theta=-31.716993 -> V=1.0, theta=0.0
% INFO    : Bus 36147	: V=0.9954539, theta=-34.442967 -> V=1.0, theta=0.0
% INFO    : Bus 36148	: V=1.0099129, theta=-35.689352 -> V=1.0, theta=0.0
% INFO    : Bus 36149	: V=1.0092288, theta=-30.319302 -> V=1.0, theta=0.0
% INFO    : Bus 36150	: V=1.0075912, theta=-21.395629 -> V=1.0, theta=0.0
% INFO    : Bus 36151	: V=1.0084644, theta=-21.36944 -> V=1.0, theta=0.0
% INFO    : Bus 36152	: V=0.9996606, theta=-22.786838 -> V=1.0, theta=0.0
% INFO    : Bus 36153	: V=1.0094613, theta=-21.298938 -> V=1.0, theta=0.0
% INFO    : Bus 36154	: V=1.0108821, theta=-21.172768 -> V=1.0, theta=0.0
% INFO    : Bus 36155	: V=1.0026454, theta=-21.823035 -> V=1.0, theta=0.0
% INFO    : Bus 36156	: V=1.0183969, theta=-19.962802 -> V=1.0, theta=0.0
% INFO    : Bus 36157	: V=1.0064741, theta=-21.540246 -> V=1.0, theta=0.0
% INFO    : Bus 36158	: V=0.9643485, theta=-28.781646 -> V=1.0, theta=0.0
% INFO    : Bus 36159	: V=0.9696609, theta=-27.849056 -> V=1.0, theta=0.0
% INFO    : Bus 36160	: V=0.9728757, theta=-27.180842 -> V=1.0, theta=0.0
% INFO    : Bus 36161	: V=0.9617526, theta=-28.177595 -> V=1.0, theta=0.0
% INFO    : Bus 36162	: V=0.9682493, theta=-27.338426 -> V=1.0, theta=0.0
% INFO    : Bus 36163	: V=0.9616827, theta=-28.297789 -> V=1.0, theta=0.0
% INFO    : Bus 36164	: V=0.9706795, theta=-27.273249 -> V=1.0, theta=0.0
% INFO    : Bus 36165	: V=0.9541673, theta=-30.213444 -> V=1.0, theta=0.0
% INFO    : Bus 36166	: V=0.9549735, theta=-30.439332 -> V=1.0, theta=0.0
% INFO    : Bus 36167	: V=0.9543019, theta=-30.502034 -> V=1.0, theta=0.0
% INFO    : Bus 36168	: V=0.9505372, theta=-31.043799 -> V=1.0, theta=0.0
% INFO    : Bus 36169	: V=0.9582338, theta=-30.05669 -> V=1.0, theta=0.0
% INFO    : Bus 36170	: V=0.9599475, theta=-29.879057 -> V=1.0, theta=0.0
% INFO    : Bus 36171	: V=0.9598982, theta=-29.703348 -> V=1.0, theta=0.0
% INFO    : Bus 36172	: V=0.9584949, theta=-29.871397 -> V=1.0, theta=0.0
% INFO    : Bus 36173	: V=0.9576351, theta=-29.758659 -> V=1.0, theta=0.0
% INFO    : Bus 36174	: V=0.9622486, theta=-29.79388 -> V=1.0, theta=0.0
% INFO    : Bus 36175	: V=0.9456798, theta=-32.161083 -> V=1.0, theta=0.0
% INFO    : Bus 36176	: V=0.984861, theta=-52.507178 -> V=1.0, theta=0.0
% INFO    : Bus 36177	: V=0.9849139, theta=-52.510671 -> V=1.0, theta=0.0
% INFO    : Bus 36178	: V=0.9854237, theta=-52.460139 -> V=1.0, theta=0.0
% INFO    : Bus 36179	: V=0.9796898, theta=-53.169198 -> V=1.0, theta=0.0
% INFO    : Bus 36180	: V=0.9791271, theta=-53.190005 -> V=1.0, theta=0.0
% INFO    : Bus 36181	: V=0.980291, theta=-53.121251 -> V=1.0, theta=0.0
% INFO    : Bus 36182	: V=0.9851603, theta=-52.506166 -> V=1.0, theta=0.0
% INFO    : Bus 36183	: V=0.9794335, theta=-53.184217 -> V=1.0, theta=0.0
% INFO    : Bus 36184	: V=0.9840184, theta=-52.58443 -> V=1.0, theta=0.0
% INFO    : Bus 36185	: V=0.9773914, theta=-53.218639 -> V=1.0, theta=0.0
% INFO    : Bus 36186	: V=0.9770358, theta=-53.224948 -> V=1.0, theta=0.0
% INFO    : Bus 36187	: V=0.9761197, theta=-53.239319 -> V=1.0, theta=0.0
% INFO    : Bus 36188	: V=0.9765139, theta=-53.22291 -> V=1.0, theta=0.0
% INFO    : Bus 36189	: V=0.9765213, theta=-53.22352 -> V=1.0, theta=0.0
% INFO    : Bus 36190	: V=0.9986965, theta=-50.033233 -> V=1.0, theta=0.0
% INFO    : Bus 36191	: V=0.9855811, theta=-52.458398 -> V=1.0, theta=0.0
% INFO    : Bus 36192	: V=0.9770288, theta=-53.199953 -> V=1.0, theta=0.0
% INFO    : Bus 36193	: V=0.9783163, theta=-53.04891 -> V=1.0, theta=0.0
% INFO    : Bus 36194	: V=0.9776137, theta=-53.119139 -> V=1.0, theta=0.0
% INFO    : Bus 36195	: V=0.97481, theta=-53.519556 -> V=1.0, theta=0.0
% INFO    : Bus 36196	: V=0.9755495, theta=-53.512953 -> V=1.0, theta=0.0
% INFO    : Bus 36197	: V=0.9843314, theta=-52.622846 -> V=1.0, theta=0.0
% INFO    : Bus 36198	: V=0.9833036, theta=-52.680219 -> V=1.0, theta=0.0
% INFO    : Bus 36199	: V=0.9827503, theta=-52.70622 -> V=1.0, theta=0.0
% INFO    : Bus 36200	: V=0.9827255, theta=-52.704487 -> V=1.0, theta=0.0
% INFO    : Bus 36201	: V=0.9805902, theta=-52.893155 -> V=1.0, theta=0.0
% INFO    : Bus 36202	: V=0.9792515, theta=-52.971434 -> V=1.0, theta=0.0
% INFO    : Bus 36203	: V=0.9737073, theta=-53.977403 -> V=1.0, theta=0.0
% INFO    : Bus 36204	: V=0.9828528, theta=-52.684388 -> V=1.0, theta=0.0
% INFO    : Bus 36205	: V=0.9833582, theta=-52.641183 -> V=1.0, theta=0.0
% INFO    : Bus 36206	: V=0.9846291, theta=-52.560261 -> V=1.0, theta=0.0
% INFO    : Bus 36207	: V=0.984374, theta=-52.583928 -> V=1.0, theta=0.0
% INFO    : Bus 36208	: V=0.9844236, theta=-52.586446 -> V=1.0, theta=0.0
% INFO    : Bus 36209	: V=0.9847586, theta=-52.572146 -> V=1.0, theta=0.0
% INFO    : Bus 36210	: V=0.9751026, theta=-53.656372 -> V=1.0, theta=0.0
% INFO    : Bus 36211	: V=0.9855819, theta=-52.520817 -> V=1.0, theta=0.0
% INFO    : Bus 36212	: V=0.9744821, theta=-53.663891 -> V=1.0, theta=0.0
% INFO    : Bus 36213	: V=0.9770717, theta=-53.337273 -> V=1.0, theta=0.0
% INFO    : Bus 36214	: V=0.9845157, theta=-52.585527 -> V=1.0, theta=0.0
% INFO    : Bus 36215	: V=0.9847776, theta=-52.571233 -> V=1.0, theta=0.0
% INFO    : Bus 36216	: V=0.9843302, theta=-52.59367 -> V=1.0, theta=0.0
% INFO    : Bus 36217	: V=0.9842195, theta=-52.595853 -> V=1.0, theta=0.0
% INFO    : Bus 36218	: V=0.9841668, theta=-52.527327 -> V=1.0, theta=0.0
% INFO    : Bus 36219	: V=0.9753238, theta=-53.328587 -> V=1.0, theta=0.0
% INFO    : Bus 36220	: V=0.9837369, theta=-52.593791 -> V=1.0, theta=0.0
% INFO    : Bus 36221	: V=0.9840296, theta=-52.563367 -> V=1.0, theta=0.0
% INFO    : Bus 36222	: V=0.983579, theta=-52.525771 -> V=1.0, theta=0.0
% INFO    : Bus 36223	: V=0.9838054, theta=-52.57615 -> V=1.0, theta=0.0
% INFO    : Bus 36224	: V=0.9840954, theta=-52.58053 -> V=1.0, theta=0.0
% INFO    : Bus 36225	: V=0.9842371, theta=-52.579991 -> V=1.0, theta=0.0
% INFO    : Bus 36226	: V=0.9769813, theta=-53.307145 -> V=1.0, theta=0.0
% INFO    : Bus 36227	: V=0.9839328, theta=-52.592099 -> V=1.0, theta=0.0
% INFO    : Bus 36228	: V=0.9778596, theta=-53.292543 -> V=1.0, theta=0.0
% INFO    : Bus 36229	: V=0.984447, theta=-52.567825 -> V=1.0, theta=0.0
% INFO    : Bus 36230	: V=0.9838111, theta=-52.59407 -> V=1.0, theta=0.0
% INFO    : Bus 36231	: V=0.9852513, theta=-52.530002 -> V=1.0, theta=0.0
% INFO    : Bus 36232	: V=0.9848278, theta=-52.554201 -> V=1.0, theta=0.0
% INFO    : Bus 36233	: V=0.9862888, theta=-52.461993 -> V=1.0, theta=0.0
% INFO    : Bus 36234	: V=0.9773055, theta=-53.329141 -> V=1.0, theta=0.0
% INFO    : Bus 36235	: V=0.9768654, theta=-53.334968 -> V=1.0, theta=0.0
% INFO    : Bus 36236	: V=0.9873932, theta=-52.397333 -> V=1.0, theta=0.0
% INFO    : Bus 36237	: V=0.9886006, theta=-52.323597 -> V=1.0, theta=0.0
% INFO    : Bus 36238	: V=0.9872251, theta=-52.412837 -> V=1.0, theta=0.0
% INFO    : Bus 36239	: V=1.0151165, theta=-46.71703 -> V=1.0, theta=0.0
% INFO    : Bus 36240	: V=0.978716, theta=-53.324119 -> V=1.0, theta=0.0
% INFO    : Bus 36241	: V=0.9848679, theta=-52.535548 -> V=1.0, theta=0.0
% INFO    : Bus 36242	: V=0.9821035, theta=-52.986003 -> V=1.0, theta=0.0
% INFO    : Bus 36243	: V=0.9818207, theta=-53.008728 -> V=1.0, theta=0.0
% INFO    : Bus 36244	: V=0.9824106, theta=-52.931615 -> V=1.0, theta=0.0
% INFO    : Bus 36245	: V=0.9849185, theta=-52.395016 -> V=1.0, theta=0.0
% INFO    : Bus 36246	: V=0.9859556, theta=-52.244762 -> V=1.0, theta=0.0
% INFO    : Bus 36247	: V=0.9828532, theta=-52.674266 -> V=1.0, theta=0.0
% INFO    : Bus 36248	: V=0.9871273, theta=-52.168584 -> V=1.0, theta=0.0
% INFO    : Bus 36249	: V=0.9876125, theta=-52.017818 -> V=1.0, theta=0.0
% INFO    : Bus 36250	: V=0.9977944, theta=-49.482755 -> V=1.0, theta=0.0
% INFO    : Bus 36251	: V=0.9885825, theta=-51.067102 -> V=1.0, theta=0.0
% INFO    : Bus 36252	: V=0.9886147, theta=-50.970993 -> V=1.0, theta=0.0
% INFO    : Bus 36253	: V=1.0181121, theta=-45.74017 -> V=1.0, theta=0.0
% INFO    : Bus 36254	: V=1.019095, theta=-44.982374 -> V=1.0, theta=0.0
% INFO    : Bus 36255	: V=1.001842, theta=-48.617667 -> V=1.0, theta=0.0
% INFO    : Bus 36256	: V=1.0067138, theta=-47.168332 -> V=1.0, theta=0.0
% INFO    : Bus 36257	: V=0.9842756, theta=-52.39143 -> V=1.0, theta=0.0
% INFO    : Bus 36258	: V=0.96825, theta=-53.883379 -> V=1.0, theta=0.0
% INFO    : Bus 36259	: V=0.9853366, theta=-52.299056 -> V=1.0, theta=0.0
% INFO    : Bus 36260	: V=0.9855082, theta=-52.185088 -> V=1.0, theta=0.0
% INFO    : Bus 36261	: V=0.9873184, theta=-52.259373 -> V=1.0, theta=0.0
% INFO    : Bus 36262	: V=0.9857907, theta=-52.535257 -> V=1.0, theta=0.0
% INFO    : Bus 36263	: V=0.9656613, theta=-54.558564 -> V=1.0, theta=0.0
% INFO    : Bus 36264	: V=0.9839917, theta=-52.581085 -> V=1.0, theta=0.0
% INFO    : Bus 36265	: V=0.9771932, theta=-53.314202 -> V=1.0, theta=0.0
% INFO    : Bus 36266	: V=0.9935533, theta=-51.739288 -> V=1.0, theta=0.0
% INFO    : Bus 36267	: V=0.9927646, theta=-51.798921 -> V=1.0, theta=0.0
% INFO    : Bus 36268	: V=0.9782556, theta=-53.248771 -> V=1.0, theta=0.0
% INFO    : Bus 36269	: V=0.9903991, theta=-52.263825 -> V=1.0, theta=0.0
% INFO    : Bus 36270	: V=0.9989899, theta=-51.518653 -> V=1.0, theta=0.0
% INFO    : Bus 36271	: V=1.0028, theta=-51.00987 -> V=1.0, theta=0.0
% INFO    : Bus 36272	: V=1.0026669, theta=-51.52958 -> V=1.0, theta=0.0
% INFO    : Bus 36273	: V=1.0024219, theta=-51.497563 -> V=1.0, theta=0.0
% INFO    : Bus 36274	: V=1.0040291, theta=-51.257205 -> V=1.0, theta=0.0
% INFO    : Bus 36275	: V=0.9792349, theta=-53.200243 -> V=1.0, theta=0.0
% INFO    : Bus 36276	: V=0.9919774, theta=-52.05863 -> V=1.0, theta=0.0
% INFO    : Bus 36277	: V=0.9991458, theta=-51.502623 -> V=1.0, theta=0.0
% INFO    : Bus 36278	: V=0.9783337, theta=-53.522001 -> V=1.0, theta=0.0
% INFO    : Bus 36279	: V=1.0021792, theta=-50.694035 -> V=1.0, theta=0.0
% INFO    : Bus 36280	: V=0.9998459, theta=-51.443265 -> V=1.0, theta=0.0
% INFO    : Bus 36281	: V=1.0151212, theta=-48.341085 -> V=1.0, theta=0.0
% INFO    : Bus 36282	: V=1.0088864, theta=-50.788215 -> V=1.0, theta=0.0
% INFO    : Bus 36283	: V=0.9890262, theta=-52.552501 -> V=1.0, theta=0.0
% INFO    : Bus 36284	: V=0.9686745, theta=-55.192452 -> V=1.0, theta=0.0
% INFO    : Bus 36285	: V=1.000375, theta=-51.710054 -> V=1.0, theta=0.0
% INFO    : Bus 36286	: V=0.9996825, theta=-50.909802 -> V=1.0, theta=0.0
% INFO    : Bus 36287	: V=0.9864407, theta=-52.369654 -> V=1.0, theta=0.0
% INFO    : Bus 36288	: V=0.9867544, theta=-52.347767 -> V=1.0, theta=0.0
% INFO    : Bus 36289	: V=0.9858358, theta=-52.438584 -> V=1.0, theta=0.0
% INFO    : Bus 36290	: V=0.9609032, theta=-55.388602 -> V=1.0, theta=0.0
% INFO    : Bus 36291	: V=1.0057898, theta=-39.379611 -> V=1.0, theta=0.0
% INFO    : Bus 36292	: V=1.0111924, theta=-40.958998 -> V=1.0, theta=0.0
% INFO    : Bus 36293	: V=1.010152, theta=-41.197507 -> V=1.0, theta=0.0
% INFO    : Bus 36294	: V=1.005621, theta=-42.024548 -> V=1.0, theta=0.0
% INFO    : Bus 36295	: V=1.0105621, theta=-42.140145 -> V=1.0, theta=0.0
% INFO    : Bus 36296	: V=1.0128577, theta=-42.076851 -> V=1.0, theta=0.0
% INFO    : Bus 36297	: V=1.0067179, theta=-44.871503 -> V=1.0, theta=0.0
% INFO    : Bus 36298	: V=0.9783011, theta=-28.904174 -> V=1.0, theta=0.0
% INFO    : Bus 36299	: V=0.9693244, theta=-29.697073 -> V=1.0, theta=0.0
% INFO    : Bus 36300	: V=0.9835866, theta=-28.001459 -> V=1.0, theta=0.0
% INFO    : Bus 36301	: V=0.9776603, theta=-28.832881 -> V=1.0, theta=0.0
% INFO    : Bus 36302	: V=0.9668897, theta=-29.888991 -> V=1.0, theta=0.0
% INFO    : Bus 36303	: V=0.9637324, theta=-30.404077 -> V=1.0, theta=0.0
% INFO    : Bus 36304	: V=0.9688333, theta=-30.158015 -> V=1.0, theta=0.0
% INFO    : Bus 36305	: V=0.96946, theta=-30.082072 -> V=1.0, theta=0.0
% INFO    : Bus 36306	: V=0.9804645, theta=-28.881052 -> V=1.0, theta=0.0
% INFO    : Bus 36307	: V=0.9701741, theta=-30.094956 -> V=1.0, theta=0.0
% INFO    : Bus 36308	: V=0.9692162, theta=-30.155023 -> V=1.0, theta=0.0
% INFO    : Bus 36309	: V=0.9685538, theta=-30.186881 -> V=1.0, theta=0.0
% INFO    : Bus 36310	: V=0.9673352, theta=-30.24109 -> V=1.0, theta=0.0
% INFO    : Bus 36311	: V=0.966865, theta=-30.238845 -> V=1.0, theta=0.0
% INFO    : Bus 36312	: V=0.9632609, theta=-30.435946 -> V=1.0, theta=0.0
% INFO    : Bus 36313	: V=0.9630364, theta=-30.451466 -> V=1.0, theta=0.0
% INFO    : Bus 36314	: V=0.9775094, theta=-28.773065 -> V=1.0, theta=0.0
% INFO    : Bus 36315	: V=0.9776594, theta=-28.7127 -> V=1.0, theta=0.0
% INFO    : Bus 36316	: V=0.9733836, theta=-29.769172 -> V=1.0, theta=0.0
% INFO    : Bus 36317	: V=0.9744118, theta=-29.698032 -> V=1.0, theta=0.0
% INFO    : Bus 36318	: V=0.9754429, theta=-29.616721 -> V=1.0, theta=0.0
% INFO    : Bus 36319	: V=0.9692052, theta=-30.155609 -> V=1.0, theta=0.0
% INFO    : Bus 36320	: V=0.9774249, theta=-29.400273 -> V=1.0, theta=0.0
% INFO    : Bus 36321	: V=0.9794152, theta=-29.180489 -> V=1.0, theta=0.0
% INFO    : Bus 36322	: V=0.9704703, theta=-29.329423 -> V=1.0, theta=0.0
% INFO    : Bus 36323	: V=0.9780053, theta=-28.610937 -> V=1.0, theta=0.0
% INFO    : Bus 36324	: V=0.9585967, theta=-31.074195 -> V=1.0, theta=0.0
% INFO    : Bus 36325	: V=0.9724942, theta=-29.825265 -> V=1.0, theta=0.0
% INFO    : Bus 36326	: V=0.9718985, theta=-30.158411 -> V=1.0, theta=0.0
% INFO    : Bus 36327	: V=0.9990321, theta=-26.509658 -> V=1.0, theta=0.0
% INFO    : Bus 36328	: V=0.9739792, theta=-29.822755 -> V=1.0, theta=0.0
% INFO    : Bus 36329	: V=0.9726343, theta=-30.02618 -> V=1.0, theta=0.0
% INFO    : Bus 36330	: V=0.9656634, theta=-30.464644 -> V=1.0, theta=0.0
% INFO    : Bus 36331	: V=0.9574712, theta=-31.247127 -> V=1.0, theta=0.0
% INFO    : Bus 36332	: V=0.9753934, theta=-28.995382 -> V=1.0, theta=0.0
% INFO    : Bus 36333	: V=0.970802, theta=-29.354261 -> V=1.0, theta=0.0
% INFO    : Bus 36334	: V=0.9681742, theta=-29.441536 -> V=1.0, theta=0.0
% INFO    : Bus 36335	: V=0.978494, theta=-28.501058 -> V=1.0, theta=0.0
% INFO    : Bus 36336	: V=0.9810799, theta=-28.171636 -> V=1.0, theta=0.0
% INFO    : Bus 36337	: V=0.9595465, theta=-31.16534 -> V=1.0, theta=0.0
% INFO    : Bus 36338	: V=0.9680872, theta=-30.616342 -> V=1.0, theta=0.0
% INFO    : Bus 36339	: V=0.9584989, theta=-31.404589 -> V=1.0, theta=0.0
% INFO    : Bus 36340	: V=0.9863259, theta=-27.56041 -> V=1.0, theta=0.0
% INFO    : Bus 36341	: V=0.958047, theta=-31.241221 -> V=1.0, theta=0.0
% INFO    : Bus 36342	: V=0.9572284, theta=-31.269069 -> V=1.0, theta=0.0
% INFO    : Bus 36343	: V=0.9688891, theta=-30.679518 -> V=1.0, theta=0.0
% INFO    : Bus 36344	: V=0.9509243, theta=-32.006861 -> V=1.0, theta=0.0
% INFO    : Bus 36345	: V=0.9541323, theta=-31.922042 -> V=1.0, theta=0.0
% INFO    : Bus 36346	: V=0.9514915, theta=-31.989642 -> V=1.0, theta=0.0
% INFO    : Bus 36347	: V=0.9711495, theta=-30.312558 -> V=1.0, theta=0.0
% INFO    : Bus 36348	: V=0.9513162, theta=-31.59916 -> V=1.0, theta=0.0
% INFO    : Bus 36349	: V=0.9572624, theta=-31.357324 -> V=1.0, theta=0.0
% INFO    : Bus 36350	: V=0.9569502, theta=-31.325773 -> V=1.0, theta=0.0
% INFO    : Bus 36351	: V=0.9569337, theta=-31.559134 -> V=1.0, theta=0.0
% INFO    : Bus 36352	: V=0.9564929, theta=-31.529238 -> V=1.0, theta=0.0
% INFO    : Bus 36353	: V=0.9584523, theta=-31.372417 -> V=1.0, theta=0.0
% INFO    : Bus 36354	: V=0.9622708, theta=-31.11134 -> V=1.0, theta=0.0
% INFO    : Bus 36355	: V=0.9576753, theta=-31.457491 -> V=1.0, theta=0.0
% INFO    : Bus 36356	: V=0.957119, theta=-31.517201 -> V=1.0, theta=0.0
% INFO    : Bus 36357	: V=0.9494361, theta=-43.752239 -> V=1.0, theta=0.0
% INFO    : Bus 36358	: V=0.9537706, theta=-43.631398 -> V=1.0, theta=0.0
% INFO    : Bus 36359	: V=0.9912543, theta=-29.669322 -> V=1.0, theta=0.0
% INFO    : Bus 36360	: V=0.9716121, theta=-30.205817 -> V=1.0, theta=0.0
% INFO    : Bus 36361	: V=1.0065855, theta=-25.061277 -> V=1.0, theta=0.0
% INFO    : Bus 36362	: V=0.9821716, theta=-29.131035 -> V=1.0, theta=0.0
% INFO    : Bus 36363	: V=1.0133132, theta=-18.944644 -> V=1.0, theta=0.0
% INFO    : Bus 36364	: V=0.9986403, theta=-21.02226 -> V=1.0, theta=0.0
% INFO    : Bus 36365	: V=0.9951626, theta=-21.573442 -> V=1.0, theta=0.0
% INFO    : Bus 36366	: V=1.0054348, theta=-19.963021 -> V=1.0, theta=0.0
% INFO    : Bus 36367	: V=1.0102837, theta=-19.30092 -> V=1.0, theta=0.0
% INFO    : Bus 36368	: V=0.9920107, theta=-21.777901 -> V=1.0, theta=0.0
% INFO    : Bus 36369	: V=0.9892358, theta=-21.850418 -> V=1.0, theta=0.0
% INFO    : Bus 36370	: V=0.968151, theta=-24.597453 -> V=1.0, theta=0.0
% INFO    : Bus 36371	: V=0.9905744, theta=-21.837783 -> V=1.0, theta=0.0
% INFO    : Bus 36372	: V=1.0169779, theta=-17.473228 -> V=1.0, theta=0.0
% INFO    : Bus 36373	: V=0.9671219, theta=-25.175803 -> V=1.0, theta=0.0
% INFO    : Bus 36374	: V=0.9684473, theta=-25.152401 -> V=1.0, theta=0.0
% INFO    : Bus 36375	: V=0.9876863, theta=-22.018944 -> V=1.0, theta=0.0
% INFO    : Bus 36376	: V=0.9830969, theta=-22.091737 -> V=1.0, theta=0.0
% INFO    : Bus 36377	: V=0.965982, theta=-24.621624 -> V=1.0, theta=0.0
% INFO    : Bus 36378	: V=0.990012, theta=-22.356633 -> V=1.0, theta=0.0
% INFO    : Bus 36379	: V=0.9907495, theta=-22.41916 -> V=1.0, theta=0.0
% INFO    : Bus 36380	: V=0.9798247, theta=-23.384154 -> V=1.0, theta=0.0
% INFO    : Bus 36381	: V=0.964647, theta=-24.891836 -> V=1.0, theta=0.0
% INFO    : Bus 36382	: V=0.9747654, theta=-23.944199 -> V=1.0, theta=0.0
% INFO    : Bus 36383	: V=0.9731416, theta=-24.137387 -> V=1.0, theta=0.0
% INFO    : Bus 36384	: V=0.9659271, theta=-24.49459 -> V=1.0, theta=0.0
% INFO    : Bus 36385	: V=0.9594609, theta=-24.759336 -> V=1.0, theta=0.0
% INFO    : Bus 36386	: V=0.9720297, theta=-24.416009 -> V=1.0, theta=0.0
% INFO    : Bus 36387	: V=0.9646318, theta=-25.878441 -> V=1.0, theta=0.0
% INFO    : Bus 36388	: V=0.9657978, theta=-25.650207 -> V=1.0, theta=0.0
% INFO    : Bus 36389	: V=0.9670581, theta=-25.42224 -> V=1.0, theta=0.0
% INFO    : Bus 36390	: V=0.9851779, theta=-27.449266 -> V=1.0, theta=0.0
% INFO    : Bus 36391	: V=1.002142, theta=-25.666303 -> V=1.0, theta=0.0
% INFO    : Bus 36392	: V=1.0064669, theta=-27.907457 -> V=1.0, theta=0.0
% INFO    : Bus 36393	: V=0.9899625, theta=-24.403599 -> V=1.0, theta=0.0
% INFO    : Bus 36394	: V=0.9920354, theta=-24.255404 -> V=1.0, theta=0.0
% INFO    : Bus 36395	: V=0.9968079, theta=-24.024608 -> V=1.0, theta=0.0
% INFO    : Bus 36396	: V=0.99748, theta=-24.193649 -> V=1.0, theta=0.0
% INFO    : Bus 36397	: V=0.9834021, theta=-25.410583 -> V=1.0, theta=0.0
% INFO    : Bus 36398	: V=0.959379, theta=-41.107072 -> V=1.0, theta=0.0
% INFO    : Bus 36399	: V=0.9750551, theta=-38.34277 -> V=1.0, theta=0.0
% INFO    : Bus 36400	: V=0.9597208, theta=-43.411014 -> V=1.0, theta=0.0
% INFO    : Bus 36401	: V=0.9765411, theta=-39.897898 -> V=1.0, theta=0.0
% INFO    : Bus 36402	: V=0.979385, theta=-40.777428 -> V=1.0, theta=0.0
% INFO    : Bus 36403	: V=0.9843271, theta=-40.983047 -> V=1.0, theta=0.0
% INFO    : Bus 36404	: V=0.9846957, theta=-41.12627 -> V=1.0, theta=0.0
% INFO    : Bus 36405	: V=0.9853239, theta=-41.083056 -> V=1.0, theta=0.0
% INFO    : Bus 36406	: V=1.0001195, theta=-25.385635 -> V=1.0, theta=0.0
% INFO    : Bus 36407	: V=0.9909399, theta=-24.967852 -> V=1.0, theta=0.0
% INFO    : Bus 36408	: V=1.0106232, theta=-24.055172 -> V=1.0, theta=0.0
% INFO    : Bus 36409	: V=0.9710565, theta=-27.890523 -> V=1.0, theta=0.0
% INFO    : Bus 36410	: V=0.9788393, theta=-27.706551 -> V=1.0, theta=0.0
% INFO    : Bus 36411	: V=1.0168261, theta=-23.300777 -> V=1.0, theta=0.0
% INFO    : Bus 36412	: V=1.0195617, theta=-26.255875 -> V=1.0, theta=0.0
% INFO    : Bus 36413	: V=1.0195462, theta=-26.241687 -> V=1.0, theta=0.0
% INFO    : Bus 36414	: V=1.0197721, theta=-25.658459 -> V=1.0, theta=0.0
% INFO    : Bus 36415	: V=1.0200802, theta=-25.893326 -> V=1.0, theta=0.0
% INFO    : Bus 36416	: V=1.0200989, theta=-26.116867 -> V=1.0, theta=0.0
% INFO    : Bus 36417	: V=1.0204083, theta=-26.347183 -> V=1.0, theta=0.0
% INFO    : Bus 36418	: V=1.0205094, theta=-26.123355 -> V=1.0, theta=0.0
% INFO    : Bus 36419	: V=1.0203544, theta=-26.610932 -> V=1.0, theta=0.0
% INFO    : Bus 36420	: V=1.0185196, theta=-26.396315 -> V=1.0, theta=0.0
% INFO    : Bus 36421	: V=1.0192398, theta=-28.18337 -> V=1.0, theta=0.0
% INFO    : Bus 36422	: V=1.0047086, theta=-28.549009 -> V=1.0, theta=0.0
% INFO    : Bus 36423	: V=0.9931117, theta=-30.72671 -> V=1.0, theta=0.0
% INFO    : Bus 36424	: V=1.0115144, theta=-31.413769 -> V=1.0, theta=0.0
% INFO    : Bus 36425	: V=0.9716963, theta=-26.132121 -> V=1.0, theta=0.0
% INFO    : Bus 36426	: V=0.9713302, theta=-26.107913 -> V=1.0, theta=0.0
% INFO    : Bus 36427	: V=0.953993, theta=-28.146263 -> V=1.0, theta=0.0
% INFO    : Bus 36428	: V=0.9559162, theta=-28.113167 -> V=1.0, theta=0.0
% INFO    : Bus 36429	: V=0.9649681, theta=-28.03035 -> V=1.0, theta=0.0
% INFO    : Bus 36430	: V=0.9685064, theta=-27.743563 -> V=1.0, theta=0.0
% INFO    : Bus 36431	: V=0.9766787, theta=-27.038014 -> V=1.0, theta=0.0
% INFO    : Bus 36432	: V=0.9918536, theta=-25.288862 -> V=1.0, theta=0.0
% INFO    : Bus 36433	: V=0.9628681, theta=-28.360688 -> V=1.0, theta=0.0
% INFO    : Bus 36434	: V=0.9583362, theta=-28.759251 -> V=1.0, theta=0.0
% INFO    : Bus 36435	: V=0.9440178, theta=-31.15905 -> V=1.0, theta=0.0
% INFO    : Bus 36436	: V=0.9634424, theta=-27.909057 -> V=1.0, theta=0.0
% INFO    : Bus 36437	: V=0.9543498, theta=-28.95576 -> V=1.0, theta=0.0
% INFO    : Bus 36438	: V=0.9927678, theta=-24.713212 -> V=1.0, theta=0.0
% INFO    : Bus 36439	: V=1.0013838, theta=-23.058019 -> V=1.0, theta=0.0
% INFO    : Bus 36440	: V=0.9682762, theta=-25.903174 -> V=1.0, theta=0.0
% INFO    : Bus 36441	: V=0.9519238, theta=-27.350346 -> V=1.0, theta=0.0
% INFO    : Bus 36442	: V=0.9500806, theta=-27.413591 -> V=1.0, theta=0.0
% INFO    : Bus 36443	: V=0.9872684, theta=-23.877188 -> V=1.0, theta=0.0
% INFO    : Bus 36444	: V=0.9705776, theta=-25.74242 -> V=1.0, theta=0.0
% INFO    : Bus 36445	: V=0.9694298, theta=-25.815855 -> V=1.0, theta=0.0
% INFO    : Bus 36446	: V=0.9667261, theta=-26.005488 -> V=1.0, theta=0.0
% INFO    : Bus 36447	: V=0.9662239, theta=-25.829106 -> V=1.0, theta=0.0
% INFO    : Bus 36448	: V=0.9534626, theta=-27.139113 -> V=1.0, theta=0.0
% INFO    : Bus 36449	: V=0.9619128, theta=-26.095646 -> V=1.0, theta=0.0
% INFO    : Bus 36450	: V=0.9805094, theta=-24.637088 -> V=1.0, theta=0.0
% INFO    : Bus 36451	: V=0.9688215, theta=-25.560182 -> V=1.0, theta=0.0
% INFO    : Bus 36452	: V=0.9710405, theta=-25.439312 -> V=1.0, theta=0.0
% INFO    : Bus 36453	: V=0.9852633, theta=-23.993151 -> V=1.0, theta=0.0
% INFO    : Bus 36454	: V=0.9816269, theta=-24.55067 -> V=1.0, theta=0.0
% INFO    : Bus 36455	: V=0.9806703, theta=-24.622153 -> V=1.0, theta=0.0
% INFO    : Bus 36456	: V=0.9816837, theta=-24.546748 -> V=1.0, theta=0.0
% INFO    : Bus 36457	: V=0.9554386, theta=-27.202677 -> V=1.0, theta=0.0
% INFO    : Bus 36458	: V=0.9669056, theta=-25.819749 -> V=1.0, theta=0.0
% INFO    : Bus 36459	: V=0.9744192, theta=-25.147305 -> V=1.0, theta=0.0
% INFO    : Bus 36460	: V=0.9664616, theta=-25.956992 -> V=1.0, theta=0.0
% INFO    : Bus 36461	: V=0.9735957, theta=-25.116914 -> V=1.0, theta=0.0
% INFO    : Bus 36462	: V=0.9762573, theta=-24.92891 -> V=1.0, theta=0.0
% INFO    : Bus 36463	: V=0.982036, theta=-24.350577 -> V=1.0, theta=0.0
% INFO    : Bus 36464	: V=0.9868051, theta=-23.868292 -> V=1.0, theta=0.0
% INFO    : Bus 36465	: V=0.9811724, theta=-24.585378 -> V=1.0, theta=0.0
% INFO    : Bus 36466	: V=0.9675706, theta=-25.789418 -> V=1.0, theta=0.0
% INFO    : Bus 36467	: V=0.9694045, theta=-25.699725 -> V=1.0, theta=0.0
% INFO    : Bus 36468	: V=0.9517427, theta=-27.701507 -> V=1.0, theta=0.0
% INFO    : Bus 36469	: V=0.99589, theta=-23.209748 -> V=1.0, theta=0.0
% INFO    : Bus 36470	: V=0.9935272, theta=-23.3894 -> V=1.0, theta=0.0
% INFO    : Bus 36471	: V=0.992221, theta=-23.483615 -> V=1.0, theta=0.0
% INFO    : Bus 36472	: V=0.9909569, theta=-23.792282 -> V=1.0, theta=0.0
% INFO    : Bus 36473	: V=0.9887822, theta=-23.821107 -> V=1.0, theta=0.0
% INFO    : Bus 36474	: V=0.9906859, theta=-23.774069 -> V=1.0, theta=0.0
% INFO    : Bus 36475	: V=0.9902349, theta=-23.602969 -> V=1.0, theta=0.0
% INFO    : Bus 36476	: V=0.9876456, theta=-23.906914 -> V=1.0, theta=0.0
% INFO    : Bus 36477	: V=0.9887308, theta=-23.679254 -> V=1.0, theta=0.0
% INFO    : Bus 36478	: V=0.98031, theta=-24.615676 -> V=1.0, theta=0.0
% INFO    : Bus 36479	: V=0.9635643, theta=-26.612765 -> V=1.0, theta=0.0
% INFO    : Bus 36480	: V=0.9925456, theta=-23.412749 -> V=1.0, theta=0.0
% INFO    : Bus 36481	: V=0.9991854, theta=-22.776636 -> V=1.0, theta=0.0
% INFO    : Bus 36482	: V=1.0100319, theta=-21.491462 -> V=1.0, theta=0.0
% INFO    : Bus 36483	: V=1.0013622, theta=-23.174408 -> V=1.0, theta=0.0
% INFO    : Bus 36484	: V=0.9833915, theta=-25.298313 -> V=1.0, theta=0.0
% INFO    : Bus 36485	: V=0.9618939, theta=-26.096751 -> V=1.0, theta=0.0
% INFO    : Bus 36486	: V=0.9875473, theta=-30.191585 -> V=1.0, theta=0.0
% INFO    : Bus 36487	: V=0.9909159, theta=-25.214047 -> V=1.0, theta=0.0
% INFO    : Bus 36488	: V=0.9942425, theta=-33.883718 -> V=1.0, theta=0.0
% INFO    : Bus 36489	: V=0.9753892, theta=-34.852974 -> V=1.0, theta=0.0
% INFO    : Bus 36490	: V=0.9933585, theta=-26.591132 -> V=1.0, theta=0.0
% INFO    : Bus 36491	: V=1.0030417, theta=-25.413397 -> V=1.0, theta=0.0
% INFO    : Bus 36492	: V=0.9975572, theta=-26.159488 -> V=1.0, theta=0.0
% INFO    : Bus 36493	: V=0.9940543, theta=-26.184298 -> V=1.0, theta=0.0
% INFO    : Bus 36494	: V=0.991017, theta=-25.987165 -> V=1.0, theta=0.0
% INFO    : Bus 36495	: V=0.9855522, theta=-26.179301 -> V=1.0, theta=0.0
% INFO    : Bus 36496	: V=0.998019, theta=-25.392846 -> V=1.0, theta=0.0
% INFO    : Bus 36497	: V=0.9805575, theta=-26.877461 -> V=1.0, theta=0.0
% INFO    : Bus 36498	: V=0.9813684, theta=-26.858613 -> V=1.0, theta=0.0
% INFO    : Bus 36499	: V=0.9801526, theta=-26.884205 -> V=1.0, theta=0.0
% INFO    : Bus 36500	: V=0.993809, theta=-25.605274 -> V=1.0, theta=0.0
% INFO    : Bus 36501	: V=0.9948915, theta=-25.480669 -> V=1.0, theta=0.0
% INFO    : Bus 36502	: V=1.0004315, theta=-24.850477 -> V=1.0, theta=0.0
% INFO    : Bus 36503	: V=0.9960105, theta=-25.002295 -> V=1.0, theta=0.0
% INFO    : Bus 36504	: V=1.0046401, theta=-23.501482 -> V=1.0, theta=0.0
% INFO    : Bus 36505	: V=1.0058365, theta=-23.81654 -> V=1.0, theta=0.0
% INFO    : Bus 36506	: V=1.0074472, theta=-23.367468 -> V=1.0, theta=0.0
% INFO    : Bus 36507	: V=1.0115496, theta=-23.881399 -> V=1.0, theta=0.0
% INFO    : Bus 36508	: V=1.0080037, theta=-24.038333 -> V=1.0, theta=0.0
% INFO    : Bus 36509	: V=1.0115814, theta=-23.919441 -> V=1.0, theta=0.0
% INFO    : Bus 36510	: V=1.0120038, theta=-23.910021 -> V=1.0, theta=0.0
% INFO    : Bus 36511	: V=1.0038738, theta=-24.639997 -> V=1.0, theta=0.0
% INFO    : Bus 36512	: V=1.0169279, theta=-23.393415 -> V=1.0, theta=0.0
% INFO    : Bus 36513	: V=1.0144489, theta=-23.697816 -> V=1.0, theta=0.0
% INFO    : Bus 36514	: V=1.0133341, theta=-23.643792 -> V=1.0, theta=0.0
% INFO    : Bus 36515	: V=1.0109205, theta=-23.976108 -> V=1.0, theta=0.0
% INFO    : Bus 36516	: V=0.9998087, theta=-24.770777 -> V=1.0, theta=0.0
% INFO    : Bus 36517	: V=1.0130948, theta=-24.575466 -> V=1.0, theta=0.0
% INFO    : Bus 36518	: V=0.9993586, theta=-24.150657 -> V=1.0, theta=0.0
% INFO    : Bus 36519	: V=1.0127572, theta=-24.634301 -> V=1.0, theta=0.0
% INFO    : Bus 36520	: V=1.0126958, theta=-24.629118 -> V=1.0, theta=0.0
% INFO    : Bus 36521	: V=1.0054208, theta=-25.776193 -> V=1.0, theta=0.0
% INFO    : Bus 36522	: V=0.9717188, theta=-25.536718 -> V=1.0, theta=0.0
% INFO    : Bus 36523	: V=1.0002079, theta=-23.193239 -> V=1.0, theta=0.0
% INFO    : Bus 36524	: V=0.9922605, theta=-23.922289 -> V=1.0, theta=0.0
% INFO    : Bus 36525	: V=0.9925745, theta=-23.862944 -> V=1.0, theta=0.0
% INFO    : Bus 36526	: V=0.9932487, theta=-23.79572 -> V=1.0, theta=0.0
% INFO    : Bus 36527	: V=0.9943498, theta=-23.694637 -> V=1.0, theta=0.0
% INFO    : Bus 36528	: V=0.992901, theta=-23.825398 -> V=1.0, theta=0.0
% INFO    : Bus 36529	: V=0.9735437, theta=-25.991087 -> V=1.0, theta=0.0
% INFO    : Bus 36530	: V=0.9973943, theta=-23.485706 -> V=1.0, theta=0.0
% INFO    : Bus 36531	: V=1.0081206, theta=-22.396843 -> V=1.0, theta=0.0
% INFO    : Bus 36532	: V=0.9933602, theta=-23.810447 -> V=1.0, theta=0.0
% INFO    : Bus 36533	: V=0.9938359, theta=-23.780857 -> V=1.0, theta=0.0
% INFO    : Bus 36534	: V=0.9743792, theta=-25.513597 -> V=1.0, theta=0.0
% INFO    : Bus 36535	: V=0.9769928, theta=-25.406941 -> V=1.0, theta=0.0
% INFO    : Bus 36536	: V=0.9812366, theta=-25.305851 -> V=1.0, theta=0.0
% INFO    : Bus 36537	: V=0.996227, theta=-23.625194 -> V=1.0, theta=0.0
% INFO    : Bus 36538	: V=0.9986898, theta=-22.798306 -> V=1.0, theta=0.0
% INFO    : Bus 36539	: V=0.9756736, theta=-25.101983 -> V=1.0, theta=0.0
% INFO    : Bus 36540	: V=1.00385, theta=-22.917219 -> V=1.0, theta=0.0
% INFO    : Bus 36541	: V=0.9939827, theta=-23.781253 -> V=1.0, theta=0.0
% INFO    : Bus 36542	: V=0.9986924, theta=-23.080376 -> V=1.0, theta=0.0
% INFO    : Bus 36543	: V=0.9856034, theta=-24.604762 -> V=1.0, theta=0.0
% INFO    : Bus 36544	: V=0.9855809, theta=-24.602418 -> V=1.0, theta=0.0
% INFO    : Bus 36545	: V=0.9846711, theta=-24.611776 -> V=1.0, theta=0.0
% INFO    : Bus 36546	: V=0.9937932, theta=-23.755672 -> V=1.0, theta=0.0
% INFO    : Bus 36547	: V=0.9942973, theta=-23.72253 -> V=1.0, theta=0.0
% INFO    : Bus 36548	: V=0.9870596, theta=-24.399653 -> V=1.0, theta=0.0
% INFO    : Bus 36549	: V=0.9948869, theta=-23.709221 -> V=1.0, theta=0.0
% INFO    : Bus 36550	: V=0.9867118, theta=-24.733923 -> V=1.0, theta=0.0
% INFO    : Bus 36551	: V=0.9982808, theta=-23.377435 -> V=1.0, theta=0.0
% INFO    : Bus 36552	: V=0.9960563, theta=-23.599402 -> V=1.0, theta=0.0
% INFO    : Bus 36553	: V=0.9944679, theta=-23.710911 -> V=1.0, theta=0.0
% INFO    : Bus 36554	: V=0.9949461, theta=-23.681455 -> V=1.0, theta=0.0
% INFO    : Bus 36555	: V=0.994195, theta=-23.732409 -> V=1.0, theta=0.0
% INFO    : Bus 36556	: V=0.9941241, theta=-23.740972 -> V=1.0, theta=0.0
% INFO    : Bus 36557	: V=0.9937279, theta=-23.764105 -> V=1.0, theta=0.0
% INFO    : Bus 36558	: V=0.9944223, theta=-23.706448 -> V=1.0, theta=0.0
% INFO    : Bus 36559	: V=0.9938346, theta=-23.750101 -> V=1.0, theta=0.0
% INFO    : Bus 36560	: V=0.9966633, theta=-23.532148 -> V=1.0, theta=0.0
% INFO    : Bus 36561	: V=0.9951108, theta=-23.657969 -> V=1.0, theta=0.0
% INFO    : Bus 36562	: V=0.994497, theta=-23.702643 -> V=1.0, theta=0.0
% INFO    : Bus 36563	: V=1.0172479, theta=-20.845427 -> V=1.0, theta=0.0
% INFO    : Bus 36564	: V=0.9791397, theta=-25.459658 -> V=1.0, theta=0.0
% INFO    : Bus 36565	: V=0.9958478, theta=-23.613941 -> V=1.0, theta=0.0
% INFO    : Bus 36566	: V=0.9934005, theta=-23.778642 -> V=1.0, theta=0.0
% INFO    : Bus 36567	: V=0.9941689, theta=-23.739113 -> V=1.0, theta=0.0
% INFO    : Bus 36568	: V=0.9947288, theta=-23.708453 -> V=1.0, theta=0.0
% INFO    : Bus 36569	: V=1.0016316, theta=-21.710422 -> V=1.0, theta=0.0
% INFO    : Bus 36570	: V=0.9988264, theta=-21.969475 -> V=1.0, theta=0.0
% INFO    : Bus 36571	: V=0.9999056, theta=-22.02689 -> V=1.0, theta=0.0
% INFO    : Bus 36572	: V=1.004207, theta=-21.269286 -> V=1.0, theta=0.0
% INFO    : Bus 36573	: V=1.0025232, theta=-21.578491 -> V=1.0, theta=0.0
% INFO    : Bus 36574	: V=1.0012681, theta=-21.877718 -> V=1.0, theta=0.0
% INFO    : Bus 36575	: V=1.0004898, theta=-22.142033 -> V=1.0, theta=0.0
% INFO    : Bus 36576	: V=0.9974362, theta=-22.114281 -> V=1.0, theta=0.0
% INFO    : Bus 36577	: V=0.9969191, theta=-22.245571 -> V=1.0, theta=0.0
% INFO    : Bus 36578	: V=0.9962077, theta=-22.379678 -> V=1.0, theta=0.0
% INFO    : Bus 36579	: V=0.9993426, theta=-22.020308 -> V=1.0, theta=0.0
% INFO    : Bus 36580	: V=1.0015764, theta=-21.606674 -> V=1.0, theta=0.0
% INFO    : Bus 36581	: V=1.0050388, theta=-21.014854 -> V=1.0, theta=0.0
% INFO    : Bus 36582	: V=1.0088358, theta=-20.491267 -> V=1.0, theta=0.0
% INFO    : Bus 36583	: V=0.9924942, theta=-22.257106 -> V=1.0, theta=0.0
% INFO    : Bus 36584	: V=0.9919041, theta=-22.765197 -> V=1.0, theta=0.0
% INFO    : Bus 36585	: V=0.9911153, theta=-22.947652 -> V=1.0, theta=0.0
% INFO    : Bus 36586	: V=0.9906414, theta=-23.110656 -> V=1.0, theta=0.0
% INFO    : Bus 36587	: V=0.9871721, theta=-43.640781 -> V=1.0, theta=0.0
% INFO    : Bus 36588	: V=1.0029699, theta=-43.314806 -> V=1.0, theta=0.0
% INFO    : Bus 36589	: V=1.0147085, theta=-42.261611 -> V=1.0, theta=0.0
% INFO    : Bus 36590	: V=1.0195411, theta=-44.280958 -> V=1.0, theta=0.0
% INFO    : Bus 36591	: V=0.9906657, theta=-48.168 -> V=1.0, theta=0.0
% INFO    : Bus 36592	: V=1.0180106, theta=-31.252683 -> V=1.0, theta=0.0
% INFO    : Bus 36593	: V=1.0028799, theta=-34.840602 -> V=1.0, theta=0.0
% INFO    : Bus 36594	: V=1.0159261, theta=-34.355173 -> V=1.0, theta=0.0
% INFO    : Bus 36595	: V=1.0015649, theta=-36.609483 -> V=1.0, theta=0.0
% INFO    : Bus 36596	: V=0.9966011, theta=-22.176069 -> V=1.0, theta=0.0
% INFO    : Bus 36597	: V=0.9733912, theta=-24.778144 -> V=1.0, theta=0.0
% INFO    : Bus 36598	: V=0.987521, theta=-23.497999 -> V=1.0, theta=0.0
% INFO    : Bus 36599	: V=0.9960565, theta=-22.25807 -> V=1.0, theta=0.0
% INFO    : Bus 36600	: V=0.9893152, theta=-22.749757 -> V=1.0, theta=0.0
% INFO    : Bus 36601	: V=1.0003932, theta=-21.89408 -> V=1.0, theta=0.0
% INFO    : Bus 36602	: V=0.998736, theta=-22.082541 -> V=1.0, theta=0.0
% INFO    : Bus 36603	: V=0.9748243, theta=-23.608337 -> V=1.0, theta=0.0
% INFO    : Bus 36604	: V=0.9710868, theta=-23.668448 -> V=1.0, theta=0.0
% INFO    : Bus 36605	: V=0.9768458, theta=-23.974043 -> V=1.0, theta=0.0
% INFO    : Bus 36606	: V=0.9738665, theta=-24.501566 -> V=1.0, theta=0.0
% INFO    : Bus 36607	: V=0.9731296, theta=-24.078343 -> V=1.0, theta=0.0
% INFO    : Bus 36608	: V=0.9736986, theta=-24.552767 -> V=1.0, theta=0.0
% INFO    : Bus 36609	: V=0.9822744, theta=-24.645019 -> V=1.0, theta=0.0
% INFO    : Bus 36610	: V=0.9746398, theta=-23.259587 -> V=1.0, theta=0.0
% INFO    : Bus 36611	: V=0.9769647, theta=-18.013078 -> V=1.0, theta=0.0
% INFO    : Bus 36612	: V=0.9769242, theta=-24.384704 -> V=1.0, theta=0.0
% INFO    : Bus 36613	: V=0.9767032, theta=-24.473113 -> V=1.0, theta=0.0
% INFO    : Bus 36614	: V=0.9803474, theta=-37.196502 -> V=1.0, theta=0.0
% INFO    : Bus 36615	: V=0.9787711, theta=-27.655314 -> V=1.0, theta=0.0
% INFO    : Bus 36616	: V=0.9775237, theta=-15.785333 -> V=1.0, theta=0.0
% INFO    : Bus 36617	: V=0.9752716, theta=-15.811298 -> V=1.0, theta=0.0
% INFO    : Bus 36618	: V=0.9805562, theta=-16.693099 -> V=1.0, theta=0.0
% INFO    : Bus 36619	: V=0.9730687, theta=-15.867259 -> V=1.0, theta=0.0
% INFO    : Bus 36620	: V=0.9721534, theta=-16.237817 -> V=1.0, theta=0.0
% INFO    : Bus 36621	: V=0.9341529, theta=-8.901117 -> V=1.0, theta=0.0
% INFO    : Bus 36622	: V=0.9323123, theta=-8.792601 -> V=1.0, theta=0.0
% INFO    : Bus 36623	: V=1.0214691, theta=-9.265947 -> V=1.0, theta=0.0
% INFO    : Bus 36624	: V=0.9772447, theta=-23.558887 -> V=1.0, theta=0.0
% INFO    : Bus 36625	: V=0.9735471, theta=-23.1033 -> V=1.0, theta=0.0
% INFO    : Bus 36626	: V=0.9737515, theta=-23.053159 -> V=1.0, theta=0.0
% INFO    : Bus 36627	: V=0.9794308, theta=-23.521784 -> V=1.0, theta=0.0
% INFO    : Bus 36628	: V=0.9738221, theta=-22.668954 -> V=1.0, theta=0.0
% INFO    : Bus 36629	: V=0.9746143, theta=-22.978262 -> V=1.0, theta=0.0
% INFO    : Bus 36630	: V=0.9737457, theta=-22.67608 -> V=1.0, theta=0.0
% INFO    : Bus 36631	: V=0.9749512, theta=-24.713345 -> V=1.0, theta=0.0
% INFO    : Bus 36632	: V=0.9759529, theta=-24.616217 -> V=1.0, theta=0.0
% INFO    : Bus 36633	: V=0.9742355, theta=-21.570418 -> V=1.0, theta=0.0
% INFO    : Bus 36634	: V=0.9698218, theta=-19.520705 -> V=1.0, theta=0.0
% INFO    : Bus 36635	: V=0.9647104, theta=-20.386359 -> V=1.0, theta=0.0
% INFO    : Bus 36636	: V=0.9617939, theta=-21.724595 -> V=1.0, theta=0.0
% INFO    : Bus 36637	: V=0.9686393, theta=-43.374391 -> V=1.0, theta=0.0
% INFO    : Bus 36638	: V=0.9623005, theta=-41.89959 -> V=1.0, theta=0.0
% INFO    : Bus 36639	: V=0.9693959, theta=-43.277155 -> V=1.0, theta=0.0
% INFO    : Bus 36640	: V=0.972093, theta=-43.337829 -> V=1.0, theta=0.0
% INFO    : Bus 36641	: V=0.9667729, theta=-43.209837 -> V=1.0, theta=0.0
% INFO    : Bus 36642	: V=0.9636052, theta=-42.608836 -> V=1.0, theta=0.0
% INFO    : Bus 36643	: V=0.9644508, theta=-43.140606 -> V=1.0, theta=0.0
% INFO    : Bus 36644	: V=0.962255, theta=-42.867201 -> V=1.0, theta=0.0
% INFO    : Bus 36645	: V=0.9636927, theta=-41.601699 -> V=1.0, theta=0.0
% INFO    : Bus 36646	: V=0.982812, theta=-11.378219 -> V=1.0, theta=0.0
% INFO    : Bus 36647	: V=0.9952413, theta=-11.443416 -> V=1.0, theta=0.0
% INFO    : Bus 36648	: V=1.0108044, theta=-12.304715 -> V=1.0, theta=0.0
% INFO    : Bus 36649	: V=0.9902285, theta=-11.201003 -> V=1.0, theta=0.0
% INFO    : Bus 36650	: V=1.0029506, theta=-11.106905 -> V=1.0, theta=0.0
% INFO    : Bus 36651	: V=0.9998291, theta=-11.368855 -> V=1.0, theta=0.0
% INFO    : Bus 36652	: V=0.9837391, theta=-11.471883 -> V=1.0, theta=0.0
% INFO    : Bus 36653	: V=0.9946767, theta=-11.174629 -> V=1.0, theta=0.0
% INFO    : Bus 36654	: V=0.9882377, theta=-11.197219 -> V=1.0, theta=0.0
% INFO    : Bus 36655	: V=0.9887533, theta=-11.198167 -> V=1.0, theta=0.0
% INFO    : Bus 36656	: V=0.9893502, theta=-11.199499 -> V=1.0, theta=0.0
% INFO    : Bus 36657	: V=0.9727325, theta=-10.680638 -> V=1.0, theta=0.0
% INFO    : Bus 36658	: V=0.9950724, theta=-10.493686 -> V=1.0, theta=0.0
% INFO    : Bus 36659	: V=0.9971805, theta=-10.768407 -> V=1.0, theta=0.0
% INFO    : Bus 36660	: V=0.9881618, theta=-11.100736 -> V=1.0, theta=0.0
% INFO    : Bus 36661	: V=0.9904039, theta=-11.003315 -> V=1.0, theta=0.0
% INFO    : Bus 36662	: V=1.0082167, theta=-10.160221 -> V=1.0, theta=0.0
% INFO    : Bus 36663	: V=1.0012984, theta=-10.766297 -> V=1.0, theta=0.0
% INFO    : Bus 36664	: V=0.9820902, theta=-11.672272 -> V=1.0, theta=0.0
% INFO    : Bus 36665	: V=0.9797529, theta=-12.35776 -> V=1.0, theta=0.0
% INFO    : Bus 36666	: V=0.9830702, theta=-11.532351 -> V=1.0, theta=0.0
% INFO    : Bus 36667	: V=0.9851366, theta=-11.252474 -> V=1.0, theta=0.0
% INFO    : Bus 36668	: V=0.9774299, theta=-16.535286 -> V=1.0, theta=0.0
% INFO    : Bus 36669	: V=0.9788159, theta=-16.628969 -> V=1.0, theta=0.0
% INFO    : Bus 36670	: V=0.9829247, theta=-17.068968 -> V=1.0, theta=0.0
% INFO    : Bus 36671	: V=0.9793659, theta=-16.147257 -> V=1.0, theta=0.0
% INFO    : Bus 36672	: V=0.9787331, theta=-16.292243 -> V=1.0, theta=0.0
% INFO    : Bus 36673	: V=0.9849599, theta=-18.476412 -> V=1.0, theta=0.0
% INFO    : Bus 36674	: V=0.9773778, theta=-30.104634 -> V=1.0, theta=0.0
% INFO    : Bus 36675	: V=0.9648545, theta=-30.193991 -> V=1.0, theta=0.0
% INFO    : Bus 36676	: V=0.9734482, theta=-31.208745 -> V=1.0, theta=0.0
% INFO    : Bus 36677	: V=0.9738554, theta=-31.222517 -> V=1.0, theta=0.0
% INFO    : Bus 36678	: V=0.9735175, theta=-31.221546 -> V=1.0, theta=0.0
% INFO    : Bus 36679	: V=0.9729765, theta=-31.199779 -> V=1.0, theta=0.0
% INFO    : Bus 36680	: V=0.9726708, theta=-31.199873 -> V=1.0, theta=0.0
% INFO    : Bus 36681	: V=0.9631814, theta=-30.180372 -> V=1.0, theta=0.0
% INFO    : Bus 36682	: V=0.9711979, theta=-31.186209 -> V=1.0, theta=0.0
% INFO    : Bus 36683	: V=0.9882777, theta=-31.12885 -> V=1.0, theta=0.0
% INFO    : Bus 36684	: V=1.0087831, theta=-30.131001 -> V=1.0, theta=0.0
% INFO    : Bus 36685	: V=1.0195266, theta=-31.995733 -> V=1.0, theta=0.0
% INFO    : Bus 36686	: V=0.9776863, theta=-31.219642 -> V=1.0, theta=0.0
% INFO    : Bus 36687	: V=0.9897166, theta=-18.97903 -> V=1.0, theta=0.0
% INFO    : Bus 36688	: V=0.9698195, theta=-20.051352 -> V=1.0, theta=0.0
% INFO    : Bus 36689	: V=0.9732472, theta=-19.941533 -> V=1.0, theta=0.0
% INFO    : Bus 36690	: V=0.9717667, theta=-20.239028 -> V=1.0, theta=0.0
% INFO    : Bus 36691	: V=0.9803248, theta=-19.331107 -> V=1.0, theta=0.0
% INFO    : Bus 36692	: V=0.9853854, theta=-19.490549 -> V=1.0, theta=0.0
% INFO    : Bus 36693	: V=0.9834218, theta=-19.530826 -> V=1.0, theta=0.0
% INFO    : Bus 36694	: V=1.0017708, theta=-15.525312 -> V=1.0, theta=0.0
% INFO    : Bus 36695	: V=0.9973823, theta=-14.490312 -> V=1.0, theta=0.0
% INFO    : Bus 36696	: V=0.988677, theta=-16.564889 -> V=1.0, theta=0.0
% INFO    : Bus 36697	: V=0.9688069, theta=-32.186949 -> V=1.0, theta=0.0
% INFO    : Bus 36698	: V=0.9621782, theta=-31.036182 -> V=1.0, theta=0.0
% INFO    : Bus 36699	: V=0.9664123, theta=-32.306392 -> V=1.0, theta=0.0
% INFO    : Bus 36700	: V=0.9681108, theta=-33.898333 -> V=1.0, theta=0.0
% INFO    : Bus 36701	: V=0.9649404, theta=-39.057661 -> V=1.0, theta=0.0
% INFO    : Bus 36702	: V=0.9651661, theta=-39.038533 -> V=1.0, theta=0.0
% INFO    : Bus 36703	: V=0.9671051, theta=-34.904581 -> V=1.0, theta=0.0
% INFO    : Bus 36704	: V=1.0188997, theta=-8.842382 -> V=1.0, theta=0.0
% INFO    : Bus 36705	: V=1.018735, theta=-9.074746 -> V=1.0, theta=0.0
% INFO    : Bus 36706	: V=1.0177498, theta=-8.629448 -> V=1.0, theta=0.0
% INFO    : Bus 36707	: V=1.0052857, theta=-9.019745 -> V=1.0, theta=0.0
% INFO    : Bus 36708	: V=1.0086826, theta=-9.388458 -> V=1.0, theta=0.0
% INFO    : Bus 36709	: V=1.0006946, theta=-9.962665 -> V=1.0, theta=0.0
% INFO    : Bus 36710	: V=0.9655163, theta=-9.707691 -> V=1.0, theta=0.0
% INFO    : Bus 36711	: V=0.9736852, theta=-9.353941 -> V=1.0, theta=0.0
% INFO    : Bus 36712	: V=0.9657605, theta=-9.412348 -> V=1.0, theta=0.0
% INFO    : Bus 36713	: V=0.9662542, theta=-9.691611 -> V=1.0, theta=0.0
% INFO    : Bus 36714	: V=0.96457, theta=-9.920262 -> V=1.0, theta=0.0
% INFO    : Bus 36715	: V=0.9670868, theta=-9.627603 -> V=1.0, theta=0.0
% INFO    : Bus 36716	: V=0.9759117, theta=-9.308048 -> V=1.0, theta=0.0
% INFO    : Bus 36717	: V=0.9778228, theta=-9.223096 -> V=1.0, theta=0.0
% INFO    : Bus 36718	: V=0.9784054, theta=-9.246402 -> V=1.0, theta=0.0
% INFO    : Bus 36719	: V=0.9715799, theta=-9.031975 -> V=1.0, theta=0.0
% INFO    : Bus 36720	: V=0.9824815, theta=-9.324814 -> V=1.0, theta=0.0
% INFO    : Bus 36721	: V=0.9739507, theta=-9.395821 -> V=1.0, theta=0.0
% INFO    : Bus 36722	: V=0.9843075, theta=-9.228965 -> V=1.0, theta=0.0
% INFO    : Bus 36723	: V=1.0041078, theta=-8.297135 -> V=1.0, theta=0.0
% INFO    : Bus 36724	: V=0.9814387, theta=-9.470275 -> V=1.0, theta=0.0
% INFO    : Bus 36725	: V=0.9679734, theta=-9.89036 -> V=1.0, theta=0.0
% INFO    : Bus 36726	: V=0.9816983, theta=-9.709611 -> V=1.0, theta=0.0
% INFO    : Bus 36727	: V=1.0040234, theta=-8.294192 -> V=1.0, theta=0.0
% INFO    : Bus 36728	: V=0.9907554, theta=-11.748465 -> V=1.0, theta=0.0
% INFO    : Bus 36729	: V=0.9821834, theta=-12.9311 -> V=1.0, theta=0.0
% INFO    : Bus 36730	: V=1.0106318, theta=-9.868627 -> V=1.0, theta=0.0
% INFO    : Bus 36731	: V=0.9969343, theta=-11.45671 -> V=1.0, theta=0.0
% INFO    : Bus 36732	: V=0.9969782, theta=-11.858145 -> V=1.0, theta=0.0
% INFO    : Bus 36733	: V=1.0085342, theta=-9.026342 -> V=1.0, theta=0.0
% INFO    : Bus 36734	: V=1.0089626, theta=-9.310254 -> V=1.0, theta=0.0
% INFO    : Bus 36735	: V=1.0114952, theta=-9.906514 -> V=1.0, theta=0.0
% INFO    : Bus 36736	: V=1.0071006, theta=-12.052373 -> V=1.0, theta=0.0
% INFO    : Bus 36737	: V=1.012998, theta=-11.461038 -> V=1.0, theta=0.0
% INFO    : Bus 36738	: V=1.007731, theta=-11.985643 -> V=1.0, theta=0.0
% INFO    : Bus 36739	: V=1.0114963, theta=-11.452255 -> V=1.0, theta=0.0
% INFO    : Bus 36740	: V=1.0110503, theta=-11.399151 -> V=1.0, theta=0.0
% INFO    : Bus 36741	: V=1.0066843, theta=-12.330319 -> V=1.0, theta=0.0
% INFO    : Bus 36742	: V=1.0067797, theta=-12.339321 -> V=1.0, theta=0.0
% INFO    : Bus 36743	: V=1.0068138, theta=-12.938195 -> V=1.0, theta=0.0
% INFO    : Bus 36744	: V=0.9908536, theta=-13.466234 -> V=1.0, theta=0.0
% INFO    : Bus 36745	: V=0.9599059, theta=-11.652882 -> V=1.0, theta=0.0
% INFO    : Bus 36746	: V=0.958138, theta=-11.670036 -> V=1.0, theta=0.0
% INFO    : Bus 36747	: V=0.9645028, theta=-11.561909 -> V=1.0, theta=0.0
% INFO    : Bus 36748	: V=0.9647755, theta=-11.56181 -> V=1.0, theta=0.0
% INFO    : Bus 36749	: V=0.9559101, theta=-11.66812 -> V=1.0, theta=0.0
% INFO    : Bus 36750	: V=0.9558236, theta=-11.663723 -> V=1.0, theta=0.0
% INFO    : Bus 36751	: V=0.9555008, theta=-11.66119 -> V=1.0, theta=0.0
% INFO    : Bus 36752	: V=0.9545665, theta=-11.720692 -> V=1.0, theta=0.0
% INFO    : Bus 36753	: V=0.9537997, theta=-12.201836 -> V=1.0, theta=0.0
% INFO    : Bus 36754	: V=0.9670364, theta=-12.497274 -> V=1.0, theta=0.0
% INFO    : Bus 36755	: V=0.9682529, theta=-12.653417 -> V=1.0, theta=0.0
% INFO    : Bus 36756	: V=0.9716934, theta=-12.88639 -> V=1.0, theta=0.0
% INFO    : Bus 36757	: V=0.9567557, theta=-12.593149 -> V=1.0, theta=0.0
% INFO    : Bus 36758	: V=0.9567005, theta=-11.677296 -> V=1.0, theta=0.0
% INFO    : Bus 36759	: V=0.9564587, theta=-11.663883 -> V=1.0, theta=0.0
% INFO    : Bus 36760	: V=0.9553603, theta=-11.738703 -> V=1.0, theta=0.0
% INFO    : Bus 36761	: V=0.9556281, theta=-11.981424 -> V=1.0, theta=0.0
% INFO    : Bus 36762	: V=0.9564889, theta=-11.754284 -> V=1.0, theta=0.0
% INFO    : Bus 36763	: V=0.9669381, theta=-11.968447 -> V=1.0, theta=0.0
% INFO    : Bus 36764	: V=0.9566237, theta=-12.000224 -> V=1.0, theta=0.0
% INFO    : Bus 36765	: V=0.9646486, theta=-12.394656 -> V=1.0, theta=0.0
% INFO    : Bus 36766	: V=0.9650143, theta=-12.418486 -> V=1.0, theta=0.0
% INFO    : Bus 36767	: V=0.9643006, theta=-11.562488 -> V=1.0, theta=0.0
% INFO    : Bus 36768	: V=0.9572794, theta=-12.004552 -> V=1.0, theta=0.0
% INFO    : Bus 36769	: V=0.9680483, theta=-12.002461 -> V=1.0, theta=0.0
% INFO    : Bus 36770	: V=1.0218171, theta=-9.849583 -> V=1.0, theta=0.0
% INFO    : Bus 36771	: V=1.0095969, theta=-10.679826 -> V=1.0, theta=0.0
% INFO    : Bus 36772	: V=1.0230965, theta=-10.807251 -> V=1.0, theta=0.0
% INFO    : Bus 36773	: V=1.0197375, theta=-10.047282 -> V=1.0, theta=0.0
% INFO    : Bus 36774	: V=1.0196794, theta=-9.859964 -> V=1.0, theta=0.0
% INFO    : Bus 36775	: V=1.0198235, theta=-9.627001 -> V=1.0, theta=0.0
% INFO    : Bus 36776	: V=0.9860104, theta=-25.163552 -> V=1.0, theta=0.0
% INFO    : Bus 36777	: V=0.9964943, theta=-26.157697 -> V=1.0, theta=0.0
% INFO    : Bus 36778	: V=0.9971253, theta=-27.147425 -> V=1.0, theta=0.0
% INFO    : Bus 36779	: V=0.9822317, theta=-26.160182 -> V=1.0, theta=0.0
% INFO    : Bus 36780	: V=0.9995652, theta=-27.886351 -> V=1.0, theta=0.0
% INFO    : Bus 36781	: V=1.0032101, theta=-29.085483 -> V=1.0, theta=0.0
% INFO    : Bus 36782	: V=0.9988652, theta=-28.737062 -> V=1.0, theta=0.0
% INFO    : Bus 36783	: V=0.9909106, theta=-20.244991 -> V=1.0, theta=0.0
% INFO    : Bus 36784	: V=0.9606956, theta=-24.314255 -> V=1.0, theta=0.0
% INFO    : Bus 36785	: V=0.9589526, theta=-24.288529 -> V=1.0, theta=0.0
% INFO    : Bus 36786	: V=0.9583985, theta=-26.722812 -> V=1.0, theta=0.0
% INFO    : Bus 36787	: V=0.9629804, theta=-27.080433 -> V=1.0, theta=0.0
% INFO    : Bus 36788	: V=0.9944856, theta=-11.954101 -> V=1.0, theta=0.0
% INFO    : Bus 36789	: V=0.9948293, theta=-11.843422 -> V=1.0, theta=0.0
% INFO    : Bus 36790	: V=1.0117572, theta=-13.517265 -> V=1.0, theta=0.0
% INFO    : Bus 36791	: V=0.9949705, theta=-12.046971 -> V=1.0, theta=0.0
% INFO    : Bus 36792	: V=0.9902618, theta=-12.239075 -> V=1.0, theta=0.0
% INFO    : Bus 36793	: V=0.9892792, theta=-12.218314 -> V=1.0, theta=0.0
% INFO    : Bus 36794	: V=0.9846619, theta=-12.002074 -> V=1.0, theta=0.0
% INFO    : Bus 36795	: V=0.9962676, theta=-11.796792 -> V=1.0, theta=0.0
% INFO    : Bus 36796	: V=0.9984457, theta=-11.512183 -> V=1.0, theta=0.0
% INFO    : Bus 36797	: V=1.0101157, theta=-10.026202 -> V=1.0, theta=0.0
% INFO    : Bus 36798	: V=1.0014989, theta=-10.831946 -> V=1.0, theta=0.0
% INFO    : Bus 36799	: V=0.9905187, theta=-12.122786 -> V=1.0, theta=0.0
% INFO    : Bus 36800	: V=0.9947301, theta=-14.585782 -> V=1.0, theta=0.0
% INFO    : Bus 36801	: V=0.9954836, theta=-15.633142 -> V=1.0, theta=0.0
% INFO    : Bus 36802	: V=0.9907859, theta=-15.144826 -> V=1.0, theta=0.0
% INFO    : Bus 36803	: V=0.9967035, theta=-15.371602 -> V=1.0, theta=0.0
% INFO    : Bus 36804	: V=1.0136059, theta=-13.713275 -> V=1.0, theta=0.0
% INFO    : Bus 36805	: V=0.9960577, theta=-15.35282 -> V=1.0, theta=0.0
% INFO    : Bus 36806	: V=0.9960066, theta=-15.350033 -> V=1.0, theta=0.0
% INFO    : Bus 36807	: V=0.9954037, theta=-18.212513 -> V=1.0, theta=0.0
% INFO    : Bus 36808	: V=0.9980014, theta=-18.306798 -> V=1.0, theta=0.0
% INFO    : Bus 36809	: V=0.9991668, theta=-18.349622 -> V=1.0, theta=0.0
% INFO    : Bus 36810	: V=1.0034658, theta=-18.638499 -> V=1.0, theta=0.0
% INFO    : Bus 36811	: V=0.9932509, theta=-18.106045 -> V=1.0, theta=0.0
% INFO    : Bus 36812	: V=1.0013997, theta=-18.383094 -> V=1.0, theta=0.0
% INFO    : Bus 36813	: V=0.9911757, theta=-18.527357 -> V=1.0, theta=0.0
% INFO    : Bus 36814	: V=1.0188184, theta=-17.740852 -> V=1.0, theta=0.0
% INFO    : Bus 36815	: V=0.9994495, theta=-18.358398 -> V=1.0, theta=0.0
% INFO    : Bus 36816	: V=0.9992918, theta=-17.878641 -> V=1.0, theta=0.0
% INFO    : Bus 36817	: V=0.9570898, theta=-34.480211 -> V=1.0, theta=0.0
% INFO    : Bus 36818	: V=0.9580168, theta=-35.972995 -> V=1.0, theta=0.0
% INFO    : Bus 36819	: V=0.9618728, theta=-36.801107 -> V=1.0, theta=0.0
% INFO    : Bus 36820	: V=0.9592748, theta=-36.742789 -> V=1.0, theta=0.0
% INFO    : Bus 36821	: V=0.9624835, theta=-36.844376 -> V=1.0, theta=0.0
% INFO    : Bus 36822	: V=0.962912, theta=-41.328137 -> V=1.0, theta=0.0
% INFO    : Bus 36823	: V=1.0006757, theta=-25.998083 -> V=1.0, theta=0.0
% INFO    : Bus 36824	: V=0.9891844, theta=-28.128886 -> V=1.0, theta=0.0
% INFO    : Bus 36825	: V=0.9744224, theta=-30.253618 -> V=1.0, theta=0.0
% INFO    : Bus 36826	: V=1.006644, theta=-7.800138 -> V=1.0, theta=0.0
% INFO    : Bus 36827	: V=1.0106329, theta=-7.846368 -> V=1.0, theta=0.0
% INFO    : Bus 36828	: V=1.0064096, theta=-7.80964 -> V=1.0, theta=0.0
% INFO    : Bus 36829	: V=1.0127818, theta=-8.123381 -> V=1.0, theta=0.0
% INFO    : Bus 36830	: V=0.9832995, theta=-29.45075 -> V=1.0, theta=0.0
% INFO    : Bus 36831	: V=0.9774402, theta=-29.042327 -> V=1.0, theta=0.0
% INFO    : Bus 36832	: V=1.0005189, theta=-6.893786 -> V=1.0, theta=0.0
% INFO    : Bus 36833	: V=1.0082103, theta=-6.773787 -> V=1.0, theta=0.0
% INFO    : Bus 36834	: V=0.9951243, theta=-6.937549 -> V=1.0, theta=0.0
% INFO    : Bus 36835	: V=1.0116558, theta=-6.629416 -> V=1.0, theta=0.0
% INFO    : Bus 36836	: V=1.0063901, theta=-6.851143 -> V=1.0, theta=0.0
% INFO    : Bus 36837	: V=1.0048553, theta=-6.831358 -> V=1.0, theta=0.0
% INFO    : Bus 36838	: V=1.0062591, theta=-6.849393 -> V=1.0, theta=0.0
% INFO    : Bus 36839	: V=1.0019889, theta=-6.885575 -> V=1.0, theta=0.0
% INFO    : Bus 36840	: V=1.0091812, theta=-6.724134 -> V=1.0, theta=0.0
% INFO    : Bus 36841	: V=1.0058043, theta=-6.836052 -> V=1.0, theta=0.0
% INFO    : Bus 36842	: V=1.0054242, theta=-6.834478 -> V=1.0, theta=0.0
% INFO    : Bus 36843	: V=0.9999097, theta=-6.842223 -> V=1.0, theta=0.0
% INFO    : Bus 36844	: V=1.0043914, theta=-6.943512 -> V=1.0, theta=0.0
% INFO    : Bus 36845	: V=1.0188102, theta=-6.509929 -> V=1.0, theta=0.0
% INFO    : Bus 36846	: V=1.0176375, theta=-7.630249 -> V=1.0, theta=0.0
% INFO    : Bus 36847	: V=1.0174288, theta=-7.860103 -> V=1.0, theta=0.0
% INFO    : Bus 36848	: V=1.0162002, theta=-7.296416 -> V=1.0, theta=0.0
% INFO    : Bus 36849	: V=1.0174635, theta=-6.764818 -> V=1.0, theta=0.0
% INFO    : Bus 36850	: V=1.015463, theta=-7.375334 -> V=1.0, theta=0.0
% INFO    : Bus 36851	: V=1.0058466, theta=-7.07852 -> V=1.0, theta=0.0
% INFO    : Bus 36852	: V=1.0071139, theta=-6.842887 -> V=1.0, theta=0.0
% INFO    : Bus 36853	: V=1.0064915, theta=-7.181615 -> V=1.0, theta=0.0
% INFO    : Bus 36854	: V=1.0002363, theta=-7.203192 -> V=1.0, theta=0.0
% INFO    : Bus 36855	: V=0.9734429, theta=-15.3254 -> V=1.0, theta=0.0
% INFO    : Bus 36856	: V=0.9727399, theta=-15.674943 -> V=1.0, theta=0.0
% INFO    : Bus 36857	: V=0.9752738, theta=-14.633109 -> V=1.0, theta=0.0
% INFO    : Bus 36858	: V=0.9657734, theta=-14.6698 -> V=1.0, theta=0.0
% INFO    : Bus 36859	: V=0.984562, theta=-28.905967 -> V=1.0, theta=0.0
% INFO    : Bus 36860	: V=0.989603, theta=-29.508691 -> V=1.0, theta=0.0
% INFO    : Bus 36861	: V=0.9649159, theta=-24.573517 -> V=1.0, theta=0.0
% INFO    : Bus 36862	: V=0.978314, theta=-20.367376 -> V=1.0, theta=0.0
% INFO    : Bus 36863	: V=0.9603578, theta=-24.496954 -> V=1.0, theta=0.0
% INFO    : Bus 36864	: V=0.9579142, theta=-24.35786 -> V=1.0, theta=0.0
% INFO    : Bus 36865	: V=0.9694959, theta=-17.167459 -> V=1.0, theta=0.0
% INFO    : Bus 36866	: V=0.973366, theta=-17.13694 -> V=1.0, theta=0.0
% INFO    : Bus 36867	: V=0.9786125, theta=-17.095929 -> V=1.0, theta=0.0
% INFO    : Bus 36868	: V=0.9787637, theta=-17.105886 -> V=1.0, theta=0.0
% INFO    : Bus 36869	: V=0.9790078, theta=-17.116043 -> V=1.0, theta=0.0
% INFO    : Bus 36870	: V=0.9794046, theta=-17.12632 -> V=1.0, theta=0.0
% INFO    : Bus 36871	: V=0.9698468, theta=-17.177079 -> V=1.0, theta=0.0
% INFO    : Bus 36872	: V=0.9698836, theta=-17.176135 -> V=1.0, theta=0.0
% INFO    : Bus 36873	: V=0.9701704, theta=-17.176151 -> V=1.0, theta=0.0
% INFO    : Bus 36874	: V=0.9787456, theta=-17.097031 -> V=1.0, theta=0.0
% INFO    : Bus 36875	: V=0.978239, theta=-17.086421 -> V=1.0, theta=0.0
% INFO    : Bus 36876	: V=0.9777196, theta=-17.065662 -> V=1.0, theta=0.0
% INFO    : Bus 36877	: V=0.9786109, theta=-17.066859 -> V=1.0, theta=0.0
% INFO    : Bus 36878	: V=0.9785848, theta=-17.086454 -> V=1.0, theta=0.0
% INFO    : Bus 36879	: V=0.9726139, theta=-17.176425 -> V=1.0, theta=0.0
% INFO    : Bus 36880	: V=0.9794053, theta=-17.12896 -> V=1.0, theta=0.0
% INFO    : Bus 36881	: V=0.9801457, theta=-17.142241 -> V=1.0, theta=0.0
% INFO    : Bus 36882	: V=0.9713047, theta=-17.21471 -> V=1.0, theta=0.0
% INFO    : Bus 36883	: V=0.9786253, theta=-17.093924 -> V=1.0, theta=0.0
% INFO    : Bus 36884	: V=0.9742481, theta=-17.130565 -> V=1.0, theta=0.0
% INFO    : Bus 36885	: V=0.9777576, theta=-17.07287 -> V=1.0, theta=0.0
% INFO    : Bus 36886	: V=0.9788492, theta=-17.071727 -> V=1.0, theta=0.0
% INFO    : Bus 36887	: V=0.9787983, theta=-17.053957 -> V=1.0, theta=0.0
% INFO    : Bus 36888	: V=0.9719664, theta=-17.340265 -> V=1.0, theta=0.0
% INFO    : Bus 36889	: V=0.9705437, theta=-17.319556 -> V=1.0, theta=0.0
% INFO    : Bus 36890	: V=0.9710835, theta=-17.329086 -> V=1.0, theta=0.0
% INFO    : Bus 36891	: V=0.9772121, theta=-17.170215 -> V=1.0, theta=0.0
% INFO    : Bus 36892	: V=0.987555, theta=-17.049627 -> V=1.0, theta=0.0
% INFO    : Bus 36893	: V=0.9748691, theta=-17.127586 -> V=1.0, theta=0.0
% INFO    : Bus 36894	: V=0.9745307, theta=-17.296433 -> V=1.0, theta=0.0
% INFO    : Bus 36895	: V=0.9870296, theta=-17.060806 -> V=1.0, theta=0.0
% INFO    : Bus 36896	: V=0.9761001, theta=-17.205646 -> V=1.0, theta=0.0
% INFO    : Bus 36897	: V=0.9800624, theta=-17.104979 -> V=1.0, theta=0.0
% INFO    : Bus 36898	: V=0.9709469, theta=-17.111682 -> V=1.0, theta=0.0
% INFO    : Bus 36899	: V=0.9781979, theta=-17.076482 -> V=1.0, theta=0.0
% INFO    : Bus 36900	: V=0.9784253, theta=-17.091664 -> V=1.0, theta=0.0
% INFO    : Bus 36901	: V=0.9787474, theta=-17.109437 -> V=1.0, theta=0.0
% INFO    : Bus 36902	: V=0.9695294, theta=-17.222345 -> V=1.0, theta=0.0
% INFO    : Bus 36903	: V=0.9703545, theta=-17.323994 -> V=1.0, theta=0.0
% INFO    : Bus 36904	: V=0.9811737, theta=-17.526818 -> V=1.0, theta=0.0
% INFO    : Bus 36905	: V=0.9707595, theta=-17.384795 -> V=1.0, theta=0.0
% INFO    : Bus 36906	: V=0.9701936, theta=-17.366606 -> V=1.0, theta=0.0
% INFO    : Bus 36907	: V=0.9698867, theta=-17.322848 -> V=1.0, theta=0.0
% INFO    : Bus 36908	: V=0.9745342, theta=-17.307704 -> V=1.0, theta=0.0
% INFO    : Bus 36909	: V=0.9745925, theta=-17.313314 -> V=1.0, theta=0.0
% INFO    : Bus 36910	: V=0.9814206, theta=-17.529331 -> V=1.0, theta=0.0
% INFO    : Bus 36911	: V=0.9780416, theta=-17.163799 -> V=1.0, theta=0.0
% INFO    : Bus 36912	: V=0.9519425, theta=-17.204351 -> V=1.0, theta=0.0
% INFO    : Bus 36913	: V=0.9778509, theta=-17.041646 -> V=1.0, theta=0.0
% INFO    : Bus 36914	: V=0.9774793, theta=-17.001288 -> V=1.0, theta=0.0
% INFO    : Bus 36915	: V=0.9843133, theta=-16.626061 -> V=1.0, theta=0.0
% INFO    : Bus 36916	: V=0.9647097, theta=-16.31552 -> V=1.0, theta=0.0
% INFO    : Bus 36917	: V=0.9779029, theta=-17.015105 -> V=1.0, theta=0.0
% INFO    : Bus 36918	: V=0.9781578, theta=-17.062438 -> V=1.0, theta=0.0
% INFO    : Bus 36919	: V=0.9863347, theta=-17.325329 -> V=1.0, theta=0.0
% INFO    : Bus 36920	: V=0.9815657, theta=-17.155712 -> V=1.0, theta=0.0
% INFO    : Bus 36921	: V=0.9907106, theta=-16.987975 -> V=1.0, theta=0.0
% INFO    : Bus 36922	: V=0.9842131, theta=-17.115965 -> V=1.0, theta=0.0
% INFO    : Bus 36923	: V=0.9826084, theta=-17.222112 -> V=1.0, theta=0.0
% INFO    : Bus 36924	: V=0.984496, theta=-17.30964 -> V=1.0, theta=0.0
% INFO    : Bus 36925	: V=0.9854932, theta=-17.438521 -> V=1.0, theta=0.0
% INFO    : Bus 36926	: V=0.9827351, theta=-17.376048 -> V=1.0, theta=0.0
% INFO    : Bus 36927	: V=0.9880275, theta=-17.339718 -> V=1.0, theta=0.0
% INFO    : Bus 36928	: V=0.9828048, theta=-17.379251 -> V=1.0, theta=0.0
% INFO    : Bus 36929	: V=0.9692092, theta=-17.205634 -> V=1.0, theta=0.0
% INFO    : Bus 36930	: V=1.0137262, theta=-17.327305 -> V=1.0, theta=0.0
% INFO    : Bus 36931	: V=0.9816121, theta=-17.541072 -> V=1.0, theta=0.0
% INFO    : Bus 36932	: V=0.9753041, theta=-17.619619 -> V=1.0, theta=0.0
% INFO    : Bus 36933	: V=0.9747144, theta=-17.582199 -> V=1.0, theta=0.0
% INFO    : Bus 36934	: V=0.9745668, theta=-17.574107 -> V=1.0, theta=0.0
% INFO    : Bus 36935	: V=0.989051, theta=-17.772449 -> V=1.0, theta=0.0
% INFO    : Bus 36936	: V=0.9796566, theta=-17.256133 -> V=1.0, theta=0.0
% INFO    : Bus 36937	: V=0.9751068, theta=-17.317 -> V=1.0, theta=0.0
% INFO    : Bus 36938	: V=0.9744, theta=-17.308363 -> V=1.0, theta=0.0
% INFO    : Bus 36939	: V=0.9740062, theta=-17.298147 -> V=1.0, theta=0.0
% INFO    : Bus 36940	: V=0.9829226, theta=-17.571808 -> V=1.0, theta=0.0
% INFO    : Bus 36941	: V=0.9899131, theta=-17.249512 -> V=1.0, theta=0.0
% INFO    : Bus 36942	: V=0.9828555, theta=-17.204642 -> V=1.0, theta=0.0
% INFO    : Bus 36943	: V=0.9811672, theta=-17.077052 -> V=1.0, theta=0.0
% INFO    : Bus 36944	: V=0.980358, theta=-17.109418 -> V=1.0, theta=0.0
% INFO    : Bus 36945	: V=0.98357, theta=-17.242899 -> V=1.0, theta=0.0
% INFO    : Bus 36946	: V=0.9792609, theta=-17.260572 -> V=1.0, theta=0.0
% INFO    : Bus 36947	: V=0.9821781, theta=-21.011571 -> V=1.0, theta=0.0
% INFO    : Bus 36948	: V=0.9745237, theta=-19.987681 -> V=1.0, theta=0.0
% INFO    : Bus 36949	: V=0.9755097, theta=-19.052546 -> V=1.0, theta=0.0
% INFO    : Bus 36950	: V=0.9799623, theta=-22.549374 -> V=1.0, theta=0.0
% INFO    : Bus 36951	: V=0.9882815, theta=-35.327801 -> V=1.0, theta=0.0
% INFO    : Bus 36952	: V=0.9745879, theta=-35.323558 -> V=1.0, theta=0.0
% INFO    : Bus 36953	: V=0.9856874, theta=-36.966178 -> V=1.0, theta=0.0
% INFO    : Bus 36954	: V=0.9733616, theta=-39.008256 -> V=1.0, theta=0.0
% INFO    : Bus 36955	: V=0.9679022, theta=-41.132674 -> V=1.0, theta=0.0
% INFO    : Bus 36956	: V=0.9708138, theta=-39.621005 -> V=1.0, theta=0.0
% INFO    : Bus 36957	: V=0.9783302, theta=-39.215571 -> V=1.0, theta=0.0
% INFO    : Bus 36958	: V=0.9813532, theta=-36.439188 -> V=1.0, theta=0.0
% INFO    : Bus 36959	: V=0.9835174, theta=-36.051655 -> V=1.0, theta=0.0
% INFO    : Bus 36960	: V=0.994549, theta=-34.149941 -> V=1.0, theta=0.0
% INFO    : Bus 36961	: V=0.9585207, theta=-14.595293 -> V=1.0, theta=0.0
% INFO    : Bus 36962	: V=0.976462, theta=-13.826252 -> V=1.0, theta=0.0
% INFO    : Bus 36963	: V=0.9759053, theta=-14.394532 -> V=1.0, theta=0.0
% INFO    : Bus 36964	: V=0.9632087, theta=-14.592767 -> V=1.0, theta=0.0
% INFO    : Bus 36965	: V=0.9769924, theta=-14.355834 -> V=1.0, theta=0.0
% INFO    : Bus 36966	: V=0.9877339, theta=-13.70072 -> V=1.0, theta=0.0
% INFO    : Bus 36967	: V=0.9787469, theta=-14.743425 -> V=1.0, theta=0.0
% INFO    : Bus 36968	: V=0.9779035, theta=-14.40493 -> V=1.0, theta=0.0
% INFO    : Bus 36969	: V=0.9659451, theta=-15.303602 -> V=1.0, theta=0.0
% INFO    : Bus 36970	: V=0.9770341, theta=-13.130357 -> V=1.0, theta=0.0
% INFO    : Bus 36971	: V=0.9599619, theta=-14.617646 -> V=1.0, theta=0.0
% INFO    : Bus 36972	: V=1.0231245, theta=-12.347262 -> V=1.0, theta=0.0
% INFO    : Bus 36973	: V=1.0197852, theta=-12.658988 -> V=1.0, theta=0.0
% INFO    : Bus 36974	: V=1.0172774, theta=-10.777206 -> V=1.0, theta=0.0
% INFO    : Bus 36975	: V=1.0045189, theta=-10.783985 -> V=1.0, theta=0.0
% INFO    : Bus 36976	: V=0.9938583, theta=-18.668691 -> V=1.0, theta=0.0
% INFO    : Bus 36977	: V=0.977194, theta=-18.991431 -> V=1.0, theta=0.0
% INFO    : Bus 36978	: V=0.9626491, theta=-20.762837 -> V=1.0, theta=0.0
% INFO    : Bus 36979	: V=0.9666992, theta=-21.088191 -> V=1.0, theta=0.0
% INFO    : Bus 36980	: V=0.9796454, theta=-11.515886 -> V=1.0, theta=0.0
% INFO    : Bus 36981	: V=0.9897064, theta=-12.409706 -> V=1.0, theta=0.0
% INFO    : Bus 36982	: V=0.9910211, theta=-12.580856 -> V=1.0, theta=0.0
% INFO    : Bus 36983	: V=0.96674, theta=-12.663179 -> V=1.0, theta=0.0
% INFO    : Bus 36984	: V=1.0126746, theta=-11.505191 -> V=1.0, theta=0.0
% INFO    : Bus 36985	: V=1.0244062, theta=-11.365361 -> V=1.0, theta=0.0
% INFO    : Bus 36986	: V=1.0180252, theta=-11.644522 -> V=1.0, theta=0.0
% INFO    : Bus 36987	: V=0.9991919, theta=-12.768734 -> V=1.0, theta=0.0
% INFO    : Bus 36988	: V=1.0239937, theta=-11.841965 -> V=1.0, theta=0.0
% INFO    : Bus 36989	: V=1.0078961, theta=-11.754347 -> V=1.0, theta=0.0
% INFO    : Bus 36990	: V=1.0115368, theta=-10.881138 -> V=1.0, theta=0.0
% INFO    : Bus 36991	: V=1.0139715, theta=-9.60497 -> V=1.0, theta=0.0
% INFO    : Bus 36992	: V=1.0160532, theta=-11.472324 -> V=1.0, theta=0.0
% INFO    : Bus 36993	: V=0.9810617, theta=-13.49488 -> V=1.0, theta=0.0
% INFO    : Bus 36994	: V=0.9830963, theta=-10.444315 -> V=1.0, theta=0.0
% INFO    : Bus 36995	: V=0.982519, theta=-10.322266 -> V=1.0, theta=0.0
% INFO    : Bus 36996	: V=0.9843286, theta=-10.186321 -> V=1.0, theta=0.0
% INFO    : Bus 36997	: V=0.9854226, theta=-12.973675 -> V=1.0, theta=0.0
% INFO    : Bus 36998	: V=0.9944891, theta=-11.407423 -> V=1.0, theta=0.0
% INFO    : Bus 36999	: V=1.0012811, theta=-10.468234 -> V=1.0, theta=0.0
% INFO    : Bus 37000	: V=0.9659379, theta=-21.477236 -> V=1.0, theta=0.0
% INFO    : Bus 37001	: V=0.9680774, theta=-22.949893 -> V=1.0, theta=0.0
% INFO    : Bus 37002	: V=0.9732573, theta=-23.26191 -> V=1.0, theta=0.0
% INFO    : Bus 37003	: V=0.9717935, theta=-23.201558 -> V=1.0, theta=0.0
% INFO    : Bus 37004	: V=0.9756929, theta=-29.739977 -> V=1.0, theta=0.0
% INFO    : Bus 37005	: V=0.966262, theta=-29.654569 -> V=1.0, theta=0.0
% INFO    : Bus 37006	: V=0.9755582, theta=-29.594913 -> V=1.0, theta=0.0
% INFO    : Bus 37007	: V=0.9640305, theta=-29.766572 -> V=1.0, theta=0.0
% INFO    : Bus 37008	: V=0.9767989, theta=-29.061828 -> V=1.0, theta=0.0
% INFO    : Bus 37009	: V=0.9467421, theta=-27.138802 -> V=1.0, theta=0.0
% INFO    : Bus 37010	: V=0.975542, theta=-28.24793 -> V=1.0, theta=0.0
% INFO    : Bus 37011	: V=0.9524548, theta=-27.194445 -> V=1.0, theta=0.0
% INFO    : Bus 37012	: V=0.9755121, theta=-27.175275 -> V=1.0, theta=0.0
% INFO    : Bus 37013	: V=1.0197352, theta=-8.523037 -> V=1.0, theta=0.0
% INFO    : Bus 37014	: V=1.0173055, theta=-8.122915 -> V=1.0, theta=0.0
% INFO    : Bus 37015	: V=1.0161484, theta=-7.7367 -> V=1.0, theta=0.0
% INFO    : Bus 37016	: V=1.0192216, theta=-8.369688 -> V=1.0, theta=0.0
% INFO    : Bus 37017	: V=1.0056281, theta=-9.246988 -> V=1.0, theta=0.0
% INFO    : Bus 37018	: V=0.9980481, theta=-9.295288 -> V=1.0, theta=0.0
% INFO    : Bus 37019	: V=0.9910635, theta=-10.057174 -> V=1.0, theta=0.0
% INFO    : Bus 37020	: V=0.9910748, theta=-10.029866 -> V=1.0, theta=0.0
% INFO    : Bus 37021	: V=0.977421, theta=-10.131151 -> V=1.0, theta=0.0
% INFO    : Bus 37022	: V=0.9888283, theta=-10.115553 -> V=1.0, theta=0.0
% INFO    : Bus 37023	: V=0.9896109, theta=-10.075948 -> V=1.0, theta=0.0
% INFO    : Bus 37024	: V=0.9913677, theta=-10.145459 -> V=1.0, theta=0.0
% INFO    : Bus 37025	: V=0.9924878, theta=-10.285322 -> V=1.0, theta=0.0
% INFO    : Bus 37026	: V=0.9881269, theta=-10.166313 -> V=1.0, theta=0.0
% INFO    : Bus 37027	: V=0.9850082, theta=-10.158389 -> V=1.0, theta=0.0
% INFO    : Bus 37028	: V=0.9736432, theta=-12.104115 -> V=1.0, theta=0.0
% INFO    : Bus 37029	: V=0.9697456, theta=-11.720047 -> V=1.0, theta=0.0
% INFO    : Bus 37030	: V=0.9921582, theta=-10.620562 -> V=1.0, theta=0.0
% INFO    : Bus 37031	: V=0.9905796, theta=-10.8796 -> V=1.0, theta=0.0
% INFO    : Bus 37032	: V=0.983144, theta=-11.25466 -> V=1.0, theta=0.0
% INFO    : Bus 37033	: V=0.9706501, theta=-11.739556 -> V=1.0, theta=0.0
% INFO    : Bus 37034	: V=0.9708306, theta=-11.926797 -> V=1.0, theta=0.0
% INFO    : Bus 37035	: V=0.9772551, theta=-12.733691 -> V=1.0, theta=0.0
% INFO    : Bus 37036	: V=0.9851529, theta=-10.667717 -> V=1.0, theta=0.0
% INFO    : Bus 37037	: V=0.9917206, theta=-9.352731 -> V=1.0, theta=0.0
% INFO    : Bus 37038	: V=0.9698065, theta=-45.220173 -> V=1.0, theta=0.0
% INFO    : Bus 37039	: V=0.974383, theta=-45.105852 -> V=1.0, theta=0.0
% INFO    : Bus 37040	: V=0.975387, theta=-45.281673 -> V=1.0, theta=0.0
% INFO    : Bus 37041	: V=0.9759978, theta=-43.661085 -> V=1.0, theta=0.0
% INFO    : Bus 37042	: V=0.9764301, theta=-43.284565 -> V=1.0, theta=0.0
% INFO    : Bus 37043	: V=0.9762797, theta=-43.427329 -> V=1.0, theta=0.0
% INFO    : Bus 37044	: V=0.9774836, theta=-43.103212 -> V=1.0, theta=0.0
% INFO    : Bus 37045	: V=0.9768484, theta=-43.267604 -> V=1.0, theta=0.0
% INFO    : Bus 37046	: V=0.9788048, theta=-43.480509 -> V=1.0, theta=0.0
% INFO    : Bus 37047	: V=0.9772748, theta=-43.993433 -> V=1.0, theta=0.0
% INFO    : Bus 37048	: V=0.9780844, theta=-45.766576 -> V=1.0, theta=0.0
% INFO    : Bus 37049	: V=0.9848256, theta=-15.389122 -> V=1.0, theta=0.0
% INFO    : Bus 37050	: V=0.9843592, theta=-14.429584 -> V=1.0, theta=0.0
% INFO    : Bus 37051	: V=0.9813834, theta=-15.567214 -> V=1.0, theta=0.0
% INFO    : Bus 37052	: V=0.9702165, theta=-16.049898 -> V=1.0, theta=0.0
% INFO    : Bus 37053	: V=0.9811689, theta=-15.986451 -> V=1.0, theta=0.0
% INFO    : Bus 37054	: V=0.9657562, theta=-20.625836 -> V=1.0, theta=0.0
% INFO    : Bus 37055	: V=0.9762285, theta=-14.183029 -> V=1.0, theta=0.0
% INFO    : Bus 37056	: V=0.972335, theta=-16.038153 -> V=1.0, theta=0.0
% INFO    : Bus 37057	: V=0.9714316, theta=-18.357421 -> V=1.0, theta=0.0
% INFO    : Bus 37058	: V=0.9666889, theta=-19.614051 -> V=1.0, theta=0.0
% INFO    : Bus 37059	: V=0.9801507, theta=-7.345938 -> V=1.0, theta=0.0
% INFO    : Bus 37060	: V=0.9897365, theta=-7.28185 -> V=1.0, theta=0.0
% INFO    : Bus 37061	: V=0.9898652, theta=-7.283539 -> V=1.0, theta=0.0
% INFO    : Bus 37062	: V=0.9900303, theta=-7.285418 -> V=1.0, theta=0.0
% INFO    : Bus 37063	: V=0.9903299, theta=-7.287764 -> V=1.0, theta=0.0
% INFO    : Bus 37064	: V=0.9895912, theta=-7.274011 -> V=1.0, theta=0.0
% INFO    : Bus 37065	: V=0.9912253, theta=-7.288099 -> V=1.0, theta=0.0
% INFO    : Bus 37066	: V=0.9738114, theta=-7.181095 -> V=1.0, theta=0.0
% INFO    : Bus 37067	: V=0.979299, theta=-7.28092 -> V=1.0, theta=0.0
% INFO    : Bus 37068	: V=0.9978731, theta=-7.27296 -> V=1.0, theta=0.0
% INFO    : Bus 37069	: V=1.006045, theta=-6.941267 -> V=1.0, theta=0.0
% INFO    : Bus 37070	: V=0.9867662, theta=-9.977453 -> V=1.0, theta=0.0
% INFO    : Bus 37071	: V=0.9904034, theta=-9.938084 -> V=1.0, theta=0.0
% INFO    : Bus 37072	: V=0.9969141, theta=-9.542537 -> V=1.0, theta=0.0
% INFO    : Bus 37073	: V=0.9900661, theta=-10.108636 -> V=1.0, theta=0.0
% INFO    : Bus 37074	: V=0.9614769, theta=-10.045489 -> V=1.0, theta=0.0
% INFO    : Bus 37075	: V=1.0230298, theta=-11.620758 -> V=1.0, theta=0.0
% INFO    : Bus 37076	: V=1.004033, theta=-8.076576 -> V=1.0, theta=0.0
% INFO    : Bus 37077	: V=1.0031687, theta=-8.282638 -> V=1.0, theta=0.0
% INFO    : Bus 37078	: V=0.9998421, theta=-8.808356 -> V=1.0, theta=0.0
% INFO    : Bus 37079	: V=1.0004238, theta=-8.94327 -> V=1.0, theta=0.0
% INFO    : Bus 37080	: V=1.0013067, theta=-8.967132 -> V=1.0, theta=0.0
% INFO    : Bus 37081	: V=1.000527, theta=-9.021286 -> V=1.0, theta=0.0
% INFO    : Bus 37082	: V=1.0014053, theta=-8.863854 -> V=1.0, theta=0.0
% INFO    : Bus 37083	: V=1.0012556, theta=-9.180628 -> V=1.0, theta=0.0
% INFO    : Bus 37084	: V=1.0032806, theta=-9.482491 -> V=1.0, theta=0.0
% INFO    : Bus 37085	: V=1.0041111, theta=-9.000012 -> V=1.0, theta=0.0
% INFO    : Bus 37086	: V=1.0044132, theta=-9.638363 -> V=1.0, theta=0.0
% INFO    : Bus 37087	: V=1.0101388, theta=-9.877748 -> V=1.0, theta=0.0
% INFO    : Bus 37088	: V=0.951537, theta=-32.016875 -> V=1.0, theta=0.0
% INFO    : Bus 37089	: V=0.9639667, theta=-22.95325 -> V=1.0, theta=0.0
% INFO    : Bus 37090	: V=0.9588901, theta=-35.616345 -> V=1.0, theta=0.0
% INFO    : Bus 37091	: V=1.0149308, theta=-7.793406 -> V=1.0, theta=0.0
% INFO    : Bus 37092	: V=0.9859956, theta=-8.447219 -> V=1.0, theta=0.0
% INFO    : Bus 37093	: V=0.985526, theta=-8.439351 -> V=1.0, theta=0.0
% INFO    : Bus 37094	: V=0.9857242, theta=-8.329773 -> V=1.0, theta=0.0
% INFO    : Bus 37095	: V=0.9860254, theta=-8.313099 -> V=1.0, theta=0.0
% INFO    : Bus 37096	: V=0.9861203, theta=-8.316308 -> V=1.0, theta=0.0
% INFO    : Bus 37097	: V=0.9862926, theta=-8.326985 -> V=1.0, theta=0.0
% INFO    : Bus 37098	: V=1.0016273, theta=-8.072224 -> V=1.0, theta=0.0
% INFO    : Bus 37099	: V=0.9860008, theta=-8.319513 -> V=1.0, theta=0.0
% INFO    : Bus 37100	: V=1.0029074, theta=-8.057884 -> V=1.0, theta=0.0
% INFO    : Bus 37101	: V=1.0036137, theta=-8.05224 -> V=1.0, theta=0.0
% INFO    : Bus 37102	: V=0.9864562, theta=-8.388098 -> V=1.0, theta=0.0
% INFO    : Bus 37103	: V=0.9861384, theta=-8.376114 -> V=1.0, theta=0.0
% INFO    : Bus 37104	: V=1.0009362, theta=-8.080842 -> V=1.0, theta=0.0
% INFO    : Bus 37105	: V=1.0004823, theta=-8.086622 -> V=1.0, theta=0.0
% INFO    : Bus 37106	: V=0.9855858, theta=-8.43154 -> V=1.0, theta=0.0
% INFO    : Bus 37107	: V=0.9871447, theta=-8.429012 -> V=1.0, theta=0.0
% INFO    : Bus 37108	: V=0.9856674, theta=-8.450731 -> V=1.0, theta=0.0
% INFO    : Bus 37109	: V=1.0150284, theta=-8.37436 -> V=1.0, theta=0.0
% INFO    : Bus 37110	: V=0.9822737, theta=-8.563805 -> V=1.0, theta=0.0
% INFO    : Bus 37111	: V=0.9835735, theta=-8.616399 -> V=1.0, theta=0.0
% INFO    : Bus 37112	: V=0.9844961, theta=-8.619944 -> V=1.0, theta=0.0
% INFO    : Bus 37113	: V=0.9820705, theta=-8.576096 -> V=1.0, theta=0.0
% INFO    : Bus 37114	: V=0.9816266, theta=-8.566682 -> V=1.0, theta=0.0
% INFO    : Bus 37115	: V=0.9922448, theta=-8.542221 -> V=1.0, theta=0.0
% INFO    : Bus 37116	: V=0.9923915, theta=-8.539085 -> V=1.0, theta=0.0
% INFO    : Bus 37117	: V=0.9922394, theta=-8.544804 -> V=1.0, theta=0.0
% INFO    : Bus 37118	: V=0.9922569, theta=-8.547388 -> V=1.0, theta=0.0
% INFO    : Bus 37119	: V=1.0009955, theta=-8.465274 -> V=1.0, theta=0.0
% INFO    : Bus 37120	: V=0.9941287, theta=-8.513098 -> V=1.0, theta=0.0
% INFO    : Bus 37121	: V=0.9924332, theta=-8.555611 -> V=1.0, theta=0.0
% INFO    : Bus 37122	: V=1.0008745, theta=-8.497772 -> V=1.0, theta=0.0
% INFO    : Bus 37123	: V=0.9928211, theta=-8.562993 -> V=1.0, theta=0.0
% INFO    : Bus 37124	: V=0.9829062, theta=-8.616129 -> V=1.0, theta=0.0
% INFO    : Bus 37125	: V=0.9838652, theta=-8.622559 -> V=1.0, theta=0.0
% INFO    : Bus 37126	: V=0.9721292, theta=-8.742176 -> V=1.0, theta=0.0
% INFO    : Bus 37127	: V=0.9838945, theta=-8.627001 -> V=1.0, theta=0.0
% INFO    : Bus 37128	: V=0.9832346, theta=-8.60944 -> V=1.0, theta=0.0
% INFO    : Bus 37129	: V=0.9927224, theta=-8.554051 -> V=1.0, theta=0.0
% INFO    : Bus 37130	: V=0.9961857, theta=-8.509438 -> V=1.0, theta=0.0
% INFO    : Bus 37131	: V=0.9717904, theta=-8.740087 -> V=1.0, theta=0.0
% INFO    : Bus 37132	: V=0.9837876, theta=-8.590173 -> V=1.0, theta=0.0
% INFO    : Bus 37133	: V=0.9840006, theta=-8.598374 -> V=1.0, theta=0.0
% INFO    : Bus 37134	: V=0.9834525, theta=-8.629285 -> V=1.0, theta=0.0
% INFO    : Bus 37135	: V=0.983645, theta=-8.628263 -> V=1.0, theta=0.0
% INFO    : Bus 37136	: V=0.9737537, theta=-8.686473 -> V=1.0, theta=0.0
% INFO    : Bus 37137	: V=0.9829222, theta=-8.636273 -> V=1.0, theta=0.0
% INFO    : Bus 37138	: V=0.9739246, theta=-8.695669 -> V=1.0, theta=0.0
% INFO    : Bus 37139	: V=0.9822218, theta=-8.637518 -> V=1.0, theta=0.0
% INFO    : Bus 37140	: V=0.9806409, theta=-8.656948 -> V=1.0, theta=0.0
% INFO    : Bus 37141	: V=0.9794331, theta=-8.659113 -> V=1.0, theta=0.0
% INFO    : Bus 37142	: V=0.9711492, theta=-8.599176 -> V=1.0, theta=0.0
% INFO    : Bus 37143	: V=0.974219, theta=-8.672187 -> V=1.0, theta=0.0
% INFO    : Bus 37144	: V=0.9803296, theta=-8.656256 -> V=1.0, theta=0.0
% INFO    : Bus 37145	: V=0.9801839, theta=-8.656344 -> V=1.0, theta=0.0
% INFO    : Bus 37146	: V=0.9741689, theta=-8.669108 -> V=1.0, theta=0.0
% INFO    : Bus 37147	: V=0.9816117, theta=-8.662133 -> V=1.0, theta=0.0
% INFO    : Bus 37148	: V=0.9741278, theta=-8.670719 -> V=1.0, theta=0.0
% INFO    : Bus 37149	: V=0.9821132, theta=-8.649857 -> V=1.0, theta=0.0
% INFO    : Bus 37150	: V=0.9821624, theta=-8.648854 -> V=1.0, theta=0.0
% INFO    : Bus 37151	: V=0.9826665, theta=-8.641393 -> V=1.0, theta=0.0
% INFO    : Bus 37152	: V=0.9824528, theta=-8.64777 -> V=1.0, theta=0.0
% INFO    : Bus 37153	: V=0.9822145, theta=-8.650087 -> V=1.0, theta=0.0
% INFO    : Bus 37154	: V=0.9818401, theta=-8.657556 -> V=1.0, theta=0.0
% INFO    : Bus 37155	: V=0.9819271, theta=-8.653771 -> V=1.0, theta=0.0
% INFO    : Bus 37156	: V=0.9828404, theta=-8.650221 -> V=1.0, theta=0.0
% INFO    : Bus 37157	: V=0.9937188, theta=-8.578607 -> V=1.0, theta=0.0
% INFO    : Bus 37158	: V=0.9936345, theta=-8.606538 -> V=1.0, theta=0.0
% INFO    : Bus 37159	: V=0.991429, theta=-8.616017 -> V=1.0, theta=0.0
% INFO    : Bus 37160	: V=0.9924061, theta=-8.609042 -> V=1.0, theta=0.0
% INFO    : Bus 37161	: V=0.9761883, theta=-8.693436 -> V=1.0, theta=0.0
% INFO    : Bus 37162	: V=0.98225, theta=-8.643099 -> V=1.0, theta=0.0
% INFO    : Bus 37163	: V=0.9834912, theta=-8.656686 -> V=1.0, theta=0.0
% INFO    : Bus 37164	: V=0.9822599, theta=-8.666269 -> V=1.0, theta=0.0
% INFO    : Bus 37165	: V=0.9717592, theta=-8.722778 -> V=1.0, theta=0.0
% INFO    : Bus 37166	: V=0.9814496, theta=-8.671644 -> V=1.0, theta=0.0
% INFO    : Bus 37167	: V=0.9746193, theta=-8.687833 -> V=1.0, theta=0.0
% INFO    : Bus 37168	: V=0.9780572, theta=-8.699791 -> V=1.0, theta=0.0
% INFO    : Bus 37169	: V=0.9789877, theta=-8.716796 -> V=1.0, theta=0.0
% INFO    : Bus 37170	: V=0.9792529, theta=-8.719191 -> V=1.0, theta=0.0
% INFO    : Bus 37171	: V=0.9788575, theta=-8.663026 -> V=1.0, theta=0.0
% INFO    : Bus 37172	: V=0.9786176, theta=-8.663383 -> V=1.0, theta=0.0
% INFO    : Bus 37173	: V=0.9964762, theta=-8.596646 -> V=1.0, theta=0.0
% INFO    : Bus 37174	: V=0.9834386, theta=-8.693698 -> V=1.0, theta=0.0
% INFO    : Bus 37175	: V=0.9824383, theta=-8.684834 -> V=1.0, theta=0.0
% INFO    : Bus 37176	: V=0.9830871, theta=-9.023067 -> V=1.0, theta=0.0
% INFO    : Bus 37177	: V=0.9788247, theta=-8.670857 -> V=1.0, theta=0.0
% INFO    : Bus 37178	: V=0.9956999, theta=-8.61748 -> V=1.0, theta=0.0
% INFO    : Bus 37179	: V=0.9743773, theta=-8.557483 -> V=1.0, theta=0.0
% INFO    : Bus 37180	: V=0.976733, theta=-8.656419 -> V=1.0, theta=0.0
% INFO    : Bus 37181	: V=1.0025728, theta=-8.570904 -> V=1.0, theta=0.0
% INFO    : Bus 37182	: V=0.9883661, theta=-8.747106 -> V=1.0, theta=0.0
% INFO    : Bus 37183	: V=0.9843131, theta=-8.922375 -> V=1.0, theta=0.0
% INFO    : Bus 37184	: V=0.9738912, theta=-8.59431 -> V=1.0, theta=0.0
% INFO    : Bus 37185	: V=0.9731083, theta=-8.619591 -> V=1.0, theta=0.0
% INFO    : Bus 37186	: V=0.9807651, theta=-8.734928 -> V=1.0, theta=0.0
% INFO    : Bus 37187	: V=0.9816526, theta=-8.735062 -> V=1.0, theta=0.0
% INFO    : Bus 37188	: V=0.9822661, theta=-8.824846 -> V=1.0, theta=0.0
% INFO    : Bus 37189	: V=0.9864943, theta=-8.768922 -> V=1.0, theta=0.0
% INFO    : Bus 37190	: V=0.9979052, theta=-8.59147 -> V=1.0, theta=0.0
% INFO    : Bus 37191	: V=0.9992255, theta=-8.590856 -> V=1.0, theta=0.0
% INFO    : Bus 37192	: V=0.9817335, theta=-8.66866 -> V=1.0, theta=0.0
% INFO    : Bus 37193	: V=0.9816329, theta=-8.672461 -> V=1.0, theta=0.0
% INFO    : Bus 37194	: V=0.9818607, theta=-8.676785 -> V=1.0, theta=0.0
% INFO    : Bus 37195	: V=0.9833818, theta=-8.699013 -> V=1.0, theta=0.0
% INFO    : Bus 37196	: V=0.9830614, theta=-8.698149 -> V=1.0, theta=0.0
% INFO    : Bus 37197	: V=0.9816117, theta=-8.891804 -> V=1.0, theta=0.0
% INFO    : Bus 37198	: V=0.9809752, theta=-8.871904 -> V=1.0, theta=0.0
% INFO    : Bus 37199	: V=0.9818757, theta=-8.673594 -> V=1.0, theta=0.0
% INFO    : Bus 37200	: V=0.9827645, theta=-8.670626 -> V=1.0, theta=0.0
% INFO    : Bus 37201	: V=0.9822152, theta=-8.672192 -> V=1.0, theta=0.0
% INFO    : Bus 37202	: V=0.9857534, theta=-8.663949 -> V=1.0, theta=0.0
% INFO    : Bus 37203	: V=0.9832987, theta=-8.697054 -> V=1.0, theta=0.0
% INFO    : Bus 37204	: V=0.9829622, theta=-8.697291 -> V=1.0, theta=0.0
% INFO    : Bus 37205	: V=0.9683494, theta=-8.81379 -> V=1.0, theta=0.0
% INFO    : Bus 37206	: V=0.9797237, theta=-8.78777 -> V=1.0, theta=0.0
% INFO    : Bus 37207	: V=0.9804311, theta=-8.740578 -> V=1.0, theta=0.0
% INFO    : Bus 37208	: V=0.9808809, theta=-8.71783 -> V=1.0, theta=0.0
% INFO    : Bus 37209	: V=0.9804489, theta=-8.728734 -> V=1.0, theta=0.0
% INFO    : Bus 37210	: V=0.982855, theta=-8.697594 -> V=1.0, theta=0.0
% INFO    : Bus 37211	: V=0.9777713, theta=-8.733793 -> V=1.0, theta=0.0
% INFO    : Bus 37212	: V=0.9810168, theta=-8.727181 -> V=1.0, theta=0.0
% INFO    : Bus 37213	: V=0.9817381, theta=-8.715388 -> V=1.0, theta=0.0
% INFO    : Bus 37214	: V=0.9966794, theta=-8.556706 -> V=1.0, theta=0.0
% INFO    : Bus 37215	: V=0.9972434, theta=-8.547176 -> V=1.0, theta=0.0
% INFO    : Bus 37216	: V=0.9858957, theta=-8.663301 -> V=1.0, theta=0.0
% INFO    : Bus 37217	: V=0.9828167, theta=-8.648716 -> V=1.0, theta=0.0
% INFO    : Bus 37218	: V=0.98364, theta=-8.653527 -> V=1.0, theta=0.0
% INFO    : Bus 37219	: V=0.9839673, theta=-8.654763 -> V=1.0, theta=0.0
% INFO    : Bus 37220	: V=0.9835606, theta=-8.655766 -> V=1.0, theta=0.0
% INFO    : Bus 37221	: V=0.9833716, theta=-8.688945 -> V=1.0, theta=0.0
% INFO    : Bus 37222	: V=0.9750323, theta=-8.751902 -> V=1.0, theta=0.0
% INFO    : Bus 37223	: V=0.9820534, theta=-8.701361 -> V=1.0, theta=0.0
% INFO    : Bus 37224	: V=0.9812771, theta=-8.71022 -> V=1.0, theta=0.0
% INFO    : Bus 37225	: V=0.9842619, theta=-8.666058 -> V=1.0, theta=0.0
% INFO    : Bus 37226	: V=0.9836195, theta=-8.665906 -> V=1.0, theta=0.0
% INFO    : Bus 37227	: V=0.9760727, theta=-8.745539 -> V=1.0, theta=0.0
% INFO    : Bus 37228	: V=0.9829775, theta=-8.66531 -> V=1.0, theta=0.0
% INFO    : Bus 37229	: V=0.9739254, theta=-8.793938 -> V=1.0, theta=0.0
% INFO    : Bus 37230	: V=0.974066, theta=-8.81293 -> V=1.0, theta=0.0
% INFO    : Bus 37231	: V=0.9739786, theta=-8.732316 -> V=1.0, theta=0.0
% INFO    : Bus 37232	: V=0.9745265, theta=-8.842786 -> V=1.0, theta=0.0
% INFO    : Bus 37233	: V=0.9739093, theta=-9.570427 -> V=1.0, theta=0.0
% INFO    : Bus 37234	: V=0.9715883, theta=-8.669449 -> V=1.0, theta=0.0
% INFO    : Bus 37235	: V=0.9695937, theta=-9.1731 -> V=1.0, theta=0.0
% INFO    : Bus 37236	: V=0.9687687, theta=-8.992114 -> V=1.0, theta=0.0
% INFO    : Bus 37237	: V=0.9677456, theta=-9.006561 -> V=1.0, theta=0.0
% INFO    : Bus 37238	: V=0.9736235, theta=-8.726707 -> V=1.0, theta=0.0
% INFO    : Bus 37239	: V=0.9724705, theta=-8.692219 -> V=1.0, theta=0.0
% INFO    : Bus 37240	: V=0.9676849, theta=-9.01964 -> V=1.0, theta=0.0
% INFO    : Bus 37241	: V=0.9768834, theta=-9.177196 -> V=1.0, theta=0.0
% INFO    : Bus 37242	: V=0.9772711, theta=-9.191536 -> V=1.0, theta=0.0
% INFO    : Bus 37243	: V=0.9746991, theta=-9.051851 -> V=1.0, theta=0.0
% INFO    : Bus 37244	: V=0.99819, theta=-8.532866 -> V=1.0, theta=0.0
% INFO    : Bus 37245	: V=0.988881, theta=-8.636555 -> V=1.0, theta=0.0
% INFO    : Bus 37246	: V=0.9774243, theta=-8.694666 -> V=1.0, theta=0.0
% INFO    : Bus 37247	: V=0.9871208, theta=-8.651752 -> V=1.0, theta=0.0
% INFO    : Bus 37248	: V=0.9858197, theta=-8.6663 -> V=1.0, theta=0.0
% INFO    : Bus 37249	: V=0.9852773, theta=-8.669274 -> V=1.0, theta=0.0
% INFO    : Bus 37250	: V=0.9785132, theta=-8.956892 -> V=1.0, theta=0.0
% INFO    : Bus 37251	: V=0.98495, theta=-8.67853 -> V=1.0, theta=0.0
% INFO    : Bus 37252	: V=0.9977601, theta=-8.477336 -> V=1.0, theta=0.0
% INFO    : Bus 37253	: V=1.0194063, theta=-8.247187 -> V=1.0, theta=0.0
% INFO    : Bus 37254	: V=1.0198701, theta=-8.265146 -> V=1.0, theta=0.0
% INFO    : Bus 37255	: V=1.0192158, theta=-8.248197 -> V=1.0, theta=0.0
% INFO    : Bus 37256	: V=1.0192488, theta=-8.249578 -> V=1.0, theta=0.0
% INFO    : Bus 37257	: V=1.0197074, theta=-8.247531 -> V=1.0, theta=0.0
% INFO    : Bus 37258	: V=0.9939819, theta=-8.598071 -> V=1.0, theta=0.0
% INFO    : Bus 37259	: V=0.9985792, theta=-8.541708 -> V=1.0, theta=0.0
% INFO    : Bus 37260	: V=0.9962993, theta=-8.571005 -> V=1.0, theta=0.0
% INFO    : Bus 37261	: V=0.9928329, theta=-8.492722 -> V=1.0, theta=0.0
% INFO    : Bus 37262	: V=1.0016158, theta=-8.504541 -> V=1.0, theta=0.0
% INFO    : Bus 37263	: V=1.0048383, theta=-8.521155 -> V=1.0, theta=0.0
% INFO    : Bus 37264	: V=1.0190492, theta=-8.244356 -> V=1.0, theta=0.0
% INFO    : Bus 37265	: V=1.0119758, theta=-8.376827 -> V=1.0, theta=0.0
% INFO    : Bus 37266	: V=1.0191905, theta=-8.246785 -> V=1.0, theta=0.0
% INFO    : Bus 37267	: V=1.0040137, theta=-8.516405 -> V=1.0, theta=0.0
% INFO    : Bus 37268	: V=1.0008705, theta=-8.47488 -> V=1.0, theta=0.0
% INFO    : Bus 37269	: V=0.9933363, theta=-8.513347 -> V=1.0, theta=0.0
% INFO    : Bus 37270	: V=1.0027505, theta=-8.509591 -> V=1.0, theta=0.0
% INFO    : Bus 37271	: V=1.0008177, theta=-8.473591 -> V=1.0, theta=0.0
% INFO    : Bus 37272	: V=1.0014762, theta=-8.440164 -> V=1.0, theta=0.0
% INFO    : Bus 37273	: V=0.9961568, theta=-8.492092 -> V=1.0, theta=0.0
% INFO    : Bus 37274	: V=1.0008997, theta=-8.472702 -> V=1.0, theta=0.0
% INFO    : Bus 37275	: V=1.0163841, theta=-8.295757 -> V=1.0, theta=0.0
% INFO    : Bus 37276	: V=1.001754, theta=-8.475536 -> V=1.0, theta=0.0
% INFO    : Bus 37277	: V=1.0189468, theta=-8.239867 -> V=1.0, theta=0.0
% INFO    : Bus 37278	: V=0.9940893, theta=-8.525511 -> V=1.0, theta=0.0
% INFO    : Bus 37279	: V=0.9927761, theta=-8.539073 -> V=1.0, theta=0.0
% INFO    : Bus 37280	: V=0.9737536, theta=-8.705817 -> V=1.0, theta=0.0
% INFO    : Bus 37281	: V=1.0138381, theta=-8.361498 -> V=1.0, theta=0.0
% INFO    : Bus 37282	: V=1.0144105, theta=-17.711635 -> V=1.0, theta=0.0
% INFO    : Bus 37283	: V=0.9893694, theta=-17.66875 -> V=1.0, theta=0.0
% INFO    : Bus 37284	: V=0.9883842, theta=-17.661326 -> V=1.0, theta=0.0
% INFO    : Bus 37285	: V=0.9707838, theta=-17.753113 -> V=1.0, theta=0.0
% INFO    : Bus 37286	: V=1.0013014, theta=-18.032538 -> V=1.0, theta=0.0
% INFO    : Bus 37287	: V=0.9910005, theta=-17.672618 -> V=1.0, theta=0.0
% INFO    : Bus 37288	: V=0.9914734, theta=-17.686978 -> V=1.0, theta=0.0
% INFO    : Bus 37289	: V=0.9918313, theta=-17.695206 -> V=1.0, theta=0.0
% INFO    : Bus 37290	: V=0.986634, theta=-17.379513 -> V=1.0, theta=0.0
% INFO    : Bus 37291	: V=1.0012517, theta=-31.277654 -> V=1.0, theta=0.0
% INFO    : Bus 37292	: V=0.988355, theta=-31.155906 -> V=1.0, theta=0.0
% INFO    : Bus 37293	: V=0.9903458, theta=-32.449041 -> V=1.0, theta=0.0
% INFO    : Bus 37294	: V=0.9983838, theta=-32.302075 -> V=1.0, theta=0.0
% INFO    : Bus 37295	: V=0.9790349, theta=-34.969877 -> V=1.0, theta=0.0
% INFO    : Bus 37296	: V=0.9932108, theta=-34.946534 -> V=1.0, theta=0.0
% INFO    : Bus 37297	: V=0.9570518, theta=-11.632436 -> V=1.0, theta=0.0
% INFO    : Bus 37298	: V=0.9664788, theta=-11.551059 -> V=1.0, theta=0.0
% INFO    : Bus 37299	: V=0.9596375, theta=-11.781231 -> V=1.0, theta=0.0
% INFO    : Bus 37300	: V=0.9588185, theta=-11.777363 -> V=1.0, theta=0.0
% INFO    : Bus 37301	: V=0.9554541, theta=-11.753888 -> V=1.0, theta=0.0
% INFO    : Bus 37302	: V=0.9596347, theta=-11.959321 -> V=1.0, theta=0.0
% INFO    : Bus 37303	: V=0.9599977, theta=-11.923698 -> V=1.0, theta=0.0
% INFO    : Bus 37304	: V=0.9709715, theta=-11.563104 -> V=1.0, theta=0.0
% INFO    : Bus 37305	: V=0.967129, theta=-11.546526 -> V=1.0, theta=0.0
% INFO    : Bus 37306	: V=0.9743706, theta=-12.243551 -> V=1.0, theta=0.0
% INFO    : Bus 37307	: V=0.9756277, theta=-12.258299 -> V=1.0, theta=0.0
% INFO    : Bus 37308	: V=0.9740938, theta=-12.362674 -> V=1.0, theta=0.0
% INFO    : Bus 37309	: V=0.9611533, theta=-12.404042 -> V=1.0, theta=0.0
% INFO    : Bus 37310	: V=0.9798153, theta=-12.710828 -> V=1.0, theta=0.0
% INFO    : Bus 37311	: V=0.9723344, theta=-12.644541 -> V=1.0, theta=0.0
% INFO    : Bus 37312	: V=0.9610773, theta=-11.720119 -> V=1.0, theta=0.0
% INFO    : Bus 37313	: V=0.9727949, theta=-11.452445 -> V=1.0, theta=0.0
% INFO    : Bus 37314	: V=0.9774742, theta=-11.387735 -> V=1.0, theta=0.0
% INFO    : Bus 37315	: V=0.9830222, theta=-11.348637 -> V=1.0, theta=0.0
% INFO    : Bus 37316	: V=0.9830241, theta=-11.364437 -> V=1.0, theta=0.0
% INFO    : Bus 37317	: V=0.9749644, theta=-11.443502 -> V=1.0, theta=0.0
% INFO    : Bus 37318	: V=0.9794273, theta=-11.420069 -> V=1.0, theta=0.0
% INFO    : Bus 37319	: V=0.9766036, theta=-11.469906 -> V=1.0, theta=0.0
% INFO    : Bus 37320	: V=0.9751411, theta=-11.490977 -> V=1.0, theta=0.0
% INFO    : Bus 37321	: V=0.9704318, theta=-11.509701 -> V=1.0, theta=0.0
% INFO    : Bus 37322	: V=0.9682059, theta=-11.537852 -> V=1.0, theta=0.0
% INFO    : Bus 37323	: V=0.9711084, theta=-11.557777 -> V=1.0, theta=0.0
% INFO    : Bus 37324	: V=0.9715864, theta=-11.55266 -> V=1.0, theta=0.0
% INFO    : Bus 37325	: V=0.9732259, theta=-11.52381 -> V=1.0, theta=0.0
% INFO    : Bus 37326	: V=0.9722936, theta=-12.25439 -> V=1.0, theta=0.0
% INFO    : Bus 37327	: V=0.9682094, theta=-11.771141 -> V=1.0, theta=0.0
% INFO    : Bus 37328	: V=0.9669845, theta=-11.903381 -> V=1.0, theta=0.0
% INFO    : Bus 37329	: V=0.9675242, theta=-11.822698 -> V=1.0, theta=0.0
% INFO    : Bus 37330	: V=0.9803952, theta=-11.41663 -> V=1.0, theta=0.0
% INFO    : Bus 37331	: V=0.9665463, theta=-11.513384 -> V=1.0, theta=0.0
% INFO    : Bus 37332	: V=0.9613272, theta=-12.391626 -> V=1.0, theta=0.0
% INFO    : Bus 37333	: V=0.9691151, theta=-12.418169 -> V=1.0, theta=0.0
% INFO    : Bus 37334	: V=0.9714055, theta=-12.350291 -> V=1.0, theta=0.0
% INFO    : Bus 37335	: V=0.973032, theta=-11.479079 -> V=1.0, theta=0.0
% INFO    : Bus 37336	: V=0.9657844, theta=-11.556558 -> V=1.0, theta=0.0
% INFO    : Bus 37337	: V=0.9652505, theta=-11.559976 -> V=1.0, theta=0.0
% INFO    : Bus 37338	: V=0.9753042, theta=-39.782865 -> V=1.0, theta=0.0
% INFO    : Bus 37339	: V=0.9721569, theta=-40.495745 -> V=1.0, theta=0.0
% INFO    : Bus 37340	: V=0.9711394, theta=-41.050674 -> V=1.0, theta=0.0
% INFO    : Bus 37341	: V=0.9669834, theta=-42.084151 -> V=1.0, theta=0.0
% INFO    : Bus 37342	: V=0.9710038, theta=-41.161355 -> V=1.0, theta=0.0
% INFO    : Bus 37343	: V=0.9632349, theta=-41.305893 -> V=1.0, theta=0.0
% INFO    : Bus 37344	: V=0.9619705, theta=-37.977856 -> V=1.0, theta=0.0
% INFO    : Bus 37345	: V=0.9626237, theta=-37.940117 -> V=1.0, theta=0.0
% INFO    : Bus 37346	: V=0.9635171, theta=-37.744938 -> V=1.0, theta=0.0
% INFO    : Bus 37347	: V=0.9626857, theta=-38.920773 -> V=1.0, theta=0.0
% INFO    : Bus 37348	: V=0.9636274, theta=-41.258386 -> V=1.0, theta=0.0
% INFO    : Bus 37349	: V=0.9638055, theta=-41.235278 -> V=1.0, theta=0.0
% INFO    : Bus 37350	: V=0.9629207, theta=-40.150806 -> V=1.0, theta=0.0
% INFO    : Bus 37351	: V=0.9721378, theta=-12.558466 -> V=1.0, theta=0.0
% INFO    : Bus 37352	: V=0.971287, theta=-12.97278 -> V=1.0, theta=0.0
% INFO    : Bus 37353	: V=0.9649165, theta=-21.525102 -> V=1.0, theta=0.0
% INFO    : Bus 37354	: V=0.9724656, theta=-13.466913 -> V=1.0, theta=0.0
% INFO    : Bus 37355	: V=0.9585782, theta=-36.458188 -> V=1.0, theta=0.0
% INFO    : Bus 37356	: V=0.9475147, theta=-32.855985 -> V=1.0, theta=0.0
% INFO    : Bus 37357	: V=0.9588927, theta=-31.795609 -> V=1.0, theta=0.0
% INFO    : Bus 37358	: V=0.9563059, theta=-35.901388 -> V=1.0, theta=0.0
% INFO    : Bus 37359	: V=0.9598042, theta=-36.248755 -> V=1.0, theta=0.0
% INFO    : Bus 37360	: V=0.9600586, theta=-36.321836 -> V=1.0, theta=0.0
% INFO    : Bus 37361	: V=0.961302, theta=-36.538408 -> V=1.0, theta=0.0
% INFO    : Bus 37362	: V=0.9632377, theta=-36.895758 -> V=1.0, theta=0.0
% INFO    : Bus 37363	: V=0.9577457, theta=-36.629682 -> V=1.0, theta=0.0
% INFO    : Bus 37364	: V=0.9636147, theta=-36.915856 -> V=1.0, theta=0.0
% INFO    : Bus 37365	: V=0.967274, theta=-36.948241 -> V=1.0, theta=0.0
% INFO    : Bus 37366	: V=0.9780072, theta=-33.718787 -> V=1.0, theta=0.0
% INFO    : Bus 37367	: V=0.9665027, theta=-35.445098 -> V=1.0, theta=0.0
% INFO    : Bus 37368	: V=1.0096502, theta=-30.622448 -> V=1.0, theta=0.0
% INFO    : Bus 37369	: V=0.9922307, theta=-30.611533 -> V=1.0, theta=0.0
% INFO    : Bus 37370	: V=0.9975823, theta=-30.845402 -> V=1.0, theta=0.0
% INFO    : Bus 37371	: V=1.0008954, theta=-31.01433 -> V=1.0, theta=0.0
% INFO    : Bus 37372	: V=1.0076168, theta=-31.169712 -> V=1.0, theta=0.0
% INFO    : Bus 37373	: V=0.9634147, theta=-28.067882 -> V=1.0, theta=0.0
% INFO    : Bus 37374	: V=0.9608132, theta=-28.253187 -> V=1.0, theta=0.0
% INFO    : Bus 37375	: V=0.963129, theta=-29.702302 -> V=1.0, theta=0.0
% INFO    : Bus 37376	: V=0.9644075, theta=-39.539282 -> V=1.0, theta=0.0
% INFO    : Bus 37377	: V=0.9753166, theta=-42.415566 -> V=1.0, theta=0.0
% INFO    : Bus 37378	: V=0.9723191, theta=-41.544405 -> V=1.0, theta=0.0
% INFO    : Bus 37379	: V=0.9678458, theta=-43.652134 -> V=1.0, theta=0.0
% INFO    : Bus 37380	: V=0.9673065, theta=-44.100542 -> V=1.0, theta=0.0
% INFO    : Bus 37381	: V=0.9663389, theta=-43.291413 -> V=1.0, theta=0.0
% INFO    : Bus 37382	: V=0.9658273, theta=-44.799409 -> V=1.0, theta=0.0
% INFO    : Bus 37383	: V=0.9665764, theta=-44.634151 -> V=1.0, theta=0.0
% INFO    : Bus 37384	: V=0.9649297, theta=-45.246258 -> V=1.0, theta=0.0
% INFO    : Bus 37385	: V=0.9737323, theta=-44.737638 -> V=1.0, theta=0.0
% INFO    : Bus 37386	: V=0.9772155, theta=-25.269067 -> V=1.0, theta=0.0
% INFO    : Bus 37387	: V=0.982726, theta=-22.815941 -> V=1.0, theta=0.0
% INFO    : Bus 37388	: V=0.9670845, theta=-19.414764 -> V=1.0, theta=0.0
% INFO    : Bus 37389	: V=0.9795006, theta=-24.374365 -> V=1.0, theta=0.0
% INFO    : Bus 37390	: V=0.965562, theta=-23.580675 -> V=1.0, theta=0.0
% INFO    : Bus 37391	: V=0.9730682, theta=-22.025351 -> V=1.0, theta=0.0
% INFO    : Bus 37392	: V=0.9595442, theta=-20.986032 -> V=1.0, theta=0.0
% INFO    : Bus 37393	: V=0.9861077, theta=-19.870021 -> V=1.0, theta=0.0
% INFO    : Bus 37394	: V=0.9560322, theta=-26.060897 -> V=1.0, theta=0.0
% INFO    : Bus 37395	: V=0.9352009, theta=-27.205719 -> V=1.0, theta=0.0
% INFO    : Bus 37396	: V=1.0034086, theta=-8.485225 -> V=1.0, theta=0.0
% INFO    : Bus 37397	: V=1.0162008, theta=-8.588439 -> V=1.0, theta=0.0
% INFO    : Bus 37398	: V=0.9878004, theta=-14.737072 -> V=1.0, theta=0.0
% INFO    : Bus 37399	: V=0.9882895, theta=-12.571139 -> V=1.0, theta=0.0
% INFO    : Bus 37400	: V=0.9887967, theta=-14.294659 -> V=1.0, theta=0.0
% INFO    : Bus 37401	: V=0.9870563, theta=-13.568569 -> V=1.0, theta=0.0
% INFO    : Bus 37402	: V=0.9934134, theta=-15.692304 -> V=1.0, theta=0.0
% INFO    : Bus 37403	: V=0.9907729, theta=-17.312646 -> V=1.0, theta=0.0
% INFO    : Bus 37404	: V=1.0161277, theta=-8.572727 -> V=1.0, theta=0.0
% INFO    : Bus 37405	: V=1.0137617, theta=-9.807245 -> V=1.0, theta=0.0
% INFO    : Bus 37406	: V=1.0152906, theta=-9.919191 -> V=1.0, theta=0.0
% INFO    : Bus 37407	: V=1.0172563, theta=-8.091962 -> V=1.0, theta=0.0
% INFO    : Bus 37408	: V=1.0199566, theta=-8.558275 -> V=1.0, theta=0.0
% INFO    : Bus 37409	: V=1.0048481, theta=-8.558135 -> V=1.0, theta=0.0
% INFO    : Bus 37410	: V=1.0068879, theta=-8.581345 -> V=1.0, theta=0.0
% INFO    : Bus 37411	: V=1.0200343, theta=-8.58149 -> V=1.0, theta=0.0
% INFO    : Bus 37412	: V=1.0178216, theta=-8.241383 -> V=1.0, theta=0.0
% INFO    : Bus 37413	: V=1.0200889, theta=-8.597992 -> V=1.0, theta=0.0
% INFO    : Bus 37414	: V=1.0098764, theta=-8.524464 -> V=1.0, theta=0.0
% INFO    : Bus 37415	: V=1.0188362, theta=-8.305306 -> V=1.0, theta=0.0
% INFO    : Bus 37416	: V=1.0167664, theta=-8.28295 -> V=1.0, theta=0.0
% INFO    : Bus 37417	: V=1.0158041, theta=-8.646835 -> V=1.0, theta=0.0
% INFO    : Bus 37418	: V=1.015644, theta=-8.786712 -> V=1.0, theta=0.0
% INFO    : Bus 37419	: V=1.0106222, theta=-8.537795 -> V=1.0, theta=0.0
% INFO    : Bus 37420	: V=1.0162675, theta=-8.221455 -> V=1.0, theta=0.0
% INFO    : Bus 37421	: V=1.0200332, theta=-8.415429 -> V=1.0, theta=0.0
% INFO    : Bus 37422	: V=1.0211127, theta=-8.185994 -> V=1.0, theta=0.0
% INFO    : Bus 37423	: V=1.0155008, theta=-8.432761 -> V=1.0, theta=0.0
% INFO    : Bus 37424	: V=0.9439203, theta=-34.26352 -> V=1.0, theta=0.0
% INFO    : Bus 37425	: V=0.9483866, theta=-37.478659 -> V=1.0, theta=0.0
% INFO    : Bus 37426	: V=0.9450445, theta=-35.537388 -> V=1.0, theta=0.0
% INFO    : Bus 37427	: V=0.948584, theta=-36.520717 -> V=1.0, theta=0.0
% INFO    : Bus 37428	: V=1.0165527, theta=-7.732708 -> V=1.0, theta=0.0
% INFO    : Bus 37429	: V=1.0078532, theta=-7.613729 -> V=1.0, theta=0.0
% INFO    : Bus 37430	: V=1.0089929, theta=-8.178067 -> V=1.0, theta=0.0
% INFO    : Bus 37431	: V=0.9972519, theta=-18.71377 -> V=1.0, theta=0.0
% INFO    : Bus 37432	: V=0.9950064, theta=-18.460775 -> V=1.0, theta=0.0
% INFO    : Bus 37433	: V=0.9887089, theta=-18.899783 -> V=1.0, theta=0.0
% INFO    : Bus 37434	: V=0.9863916, theta=-19.106373 -> V=1.0, theta=0.0
% INFO    : Bus 37435	: V=0.9709307, theta=-19.403191 -> V=1.0, theta=0.0
% INFO    : Bus 37436	: V=0.9704093, theta=-19.42226 -> V=1.0, theta=0.0
% INFO    : Bus 37437	: V=0.9773867, theta=-19.587454 -> V=1.0, theta=0.0
% INFO    : Bus 37438	: V=0.9693759, theta=-19.291323 -> V=1.0, theta=0.0
% INFO    : Bus 37439	: V=0.9686871, theta=-19.461833 -> V=1.0, theta=0.0
% INFO    : Bus 37440	: V=0.9705423, theta=-19.16867 -> V=1.0, theta=0.0
% INFO    : Bus 37441	: V=0.9762519, theta=-21.03358 -> V=1.0, theta=0.0
% INFO    : Bus 37442	: V=0.9783897, theta=-19.648068 -> V=1.0, theta=0.0
% INFO    : Bus 37443	: V=0.9700129, theta=-19.500745 -> V=1.0, theta=0.0
% INFO    : Bus 37444	: V=0.9727857, theta=-20.684523 -> V=1.0, theta=0.0
% INFO    : Bus 37445	: V=0.9673348, theta=-23.00455 -> V=1.0, theta=0.0
% INFO    : Bus 37446	: V=0.9899685, theta=-21.193336 -> V=1.0, theta=0.0
% INFO    : Bus 37447	: V=0.9690277, theta=-23.025598 -> V=1.0, theta=0.0
% INFO    : Bus 37448	: V=0.9701838, theta=-23.073481 -> V=1.0, theta=0.0
% INFO    : Bus 37449	: V=0.9712708, theta=-21.570287 -> V=1.0, theta=0.0
% INFO    : Bus 37450	: V=0.9726591, theta=-31.980725 -> V=1.0, theta=0.0
% INFO    : Bus 37451	: V=0.9850514, theta=-31.251878 -> V=1.0, theta=0.0
% INFO    : Bus 37452	: V=0.9719129, theta=-32.571746 -> V=1.0, theta=0.0
% INFO    : Bus 37453	: V=0.9693846, theta=-32.449228 -> V=1.0, theta=0.0
% INFO    : Bus 37454	: V=0.9958716, theta=-20.576541 -> V=1.0, theta=0.0
% INFO    : Bus 37455	: V=0.9693417, theta=-19.921707 -> V=1.0, theta=0.0
% INFO    : Bus 37456	: V=0.9690564, theta=-16.780765 -> V=1.0, theta=0.0
% INFO    : Bus 37457	: V=0.9662684, theta=-20.567667 -> V=1.0, theta=0.0
% INFO    : Bus 37458	: V=1.0152425, theta=-21.572111 -> V=1.0, theta=0.0
% INFO    : Bus 37459	: V=0.9953262, theta=-20.591472 -> V=1.0, theta=0.0
% INFO    : Bus 37460	: V=1.0198897, theta=-8.76542 -> V=1.0, theta=0.0
% INFO    : Bus 37461	: V=1.0136067, theta=-9.280674 -> V=1.0, theta=0.0
% INFO    : Bus 37462	: V=1.0097233, theta=-9.370342 -> V=1.0, theta=0.0
% INFO    : Bus 37463	: V=1.0117755, theta=-9.921553 -> V=1.0, theta=0.0
% INFO    : Bus 37464	: V=0.9947558, theta=-10.000129 -> V=1.0, theta=0.0
% INFO    : Bus 37465	: V=1.0128377, theta=-10.478094 -> V=1.0, theta=0.0
% INFO    : Bus 37466	: V=0.9981717, theta=-34.120617 -> V=1.0, theta=0.0
% INFO    : Bus 37467	: V=1.01521, theta=-33.781731 -> V=1.0, theta=0.0
% INFO    : Bus 37468	: V=0.9966279, theta=-34.031686 -> V=1.0, theta=0.0
% INFO    : Bus 37469	: V=0.990056, theta=-19.376351 -> V=1.0, theta=0.0
% INFO    : Bus 37470	: V=1.0025343, theta=-17.898968 -> V=1.0, theta=0.0
% INFO    : Bus 37471	: V=1.0012769, theta=-17.275785 -> V=1.0, theta=0.0
% INFO    : Bus 37472	: V=0.9986008, theta=-16.688708 -> V=1.0, theta=0.0
% INFO    : Bus 37473	: V=0.9813732, theta=-18.18793 -> V=1.0, theta=0.0
% INFO    : Bus 37474	: V=1.0185979, theta=-8.461269 -> V=1.0, theta=0.0
% INFO    : Bus 37475	: V=1.0081927, theta=-9.095658 -> V=1.0, theta=0.0
% INFO    : Bus 37476	: V=1.0184962, theta=-8.542832 -> V=1.0, theta=0.0
% INFO    : Bus 37477	: V=1.0053169, theta=-9.536977 -> V=1.0, theta=0.0
% INFO    : Bus 37478	: V=1.0189342, theta=-8.594017 -> V=1.0, theta=0.0
% INFO    : Bus 37479	: V=1.0191224, theta=-8.508384 -> V=1.0, theta=0.0
% INFO    : Bus 37480	: V=1.0046791, theta=-8.45202 -> V=1.0, theta=0.0
% INFO    : Bus 37481	: V=1.0183954, theta=-8.492092 -> V=1.0, theta=0.0
% INFO    : Bus 37482	: V=0.9601159, theta=-20.672434 -> V=1.0, theta=0.0
% INFO    : Bus 37483	: V=0.9651496, theta=-20.776304 -> V=1.0, theta=0.0
% INFO    : Bus 37484	: V=0.9807811, theta=-17.559335 -> V=1.0, theta=0.0
% INFO    : Bus 37485	: V=0.9832814, theta=-18.329196 -> V=1.0, theta=0.0
% INFO    : Bus 37486	: V=0.9835078, theta=-18.791286 -> V=1.0, theta=0.0
% INFO    : Bus 37487	: V=0.9887398, theta=-18.517967 -> V=1.0, theta=0.0
% INFO    : Bus 37488	: V=0.9982127, theta=-18.585574 -> V=1.0, theta=0.0
% INFO    : Bus 37489	: V=0.9745445, theta=-23.097345 -> V=1.0, theta=0.0
% INFO    : Bus 37490	: V=0.9740756, theta=-24.768591 -> V=1.0, theta=0.0
% INFO    : Bus 37491	: V=0.9740565, theta=-24.625017 -> V=1.0, theta=0.0
% INFO    : Bus 37492	: V=0.9795622, theta=-28.831305 -> V=1.0, theta=0.0
% INFO    : Bus 37493	: V=0.9871592, theta=-31.353494 -> V=1.0, theta=0.0
% INFO    : Bus 37494	: V=0.9955887, theta=-32.593539 -> V=1.0, theta=0.0
% INFO    : Bus 37495	: V=0.9954273, theta=-32.615377 -> V=1.0, theta=0.0
% INFO    : Bus 37496	: V=0.9959023, theta=-18.577545 -> V=1.0, theta=0.0
% INFO    : Bus 37497	: V=0.9858141, theta=-18.91584 -> V=1.0, theta=0.0
% INFO    : Bus 37498	: V=0.9889701, theta=-18.786251 -> V=1.0, theta=0.0
% INFO    : Bus 37499	: V=0.9879692, theta=-18.948775 -> V=1.0, theta=0.0
% INFO    : Bus 37500	: V=0.9834512, theta=-19.426853 -> V=1.0, theta=0.0
% INFO    : Bus 37501	: V=0.9856789, theta=-19.129433 -> V=1.0, theta=0.0
% INFO    : Bus 37502	: V=0.9864955, theta=-30.426787 -> V=1.0, theta=0.0
% INFO    : Bus 37503	: V=0.96401, theta=-26.819741 -> V=1.0, theta=0.0
% INFO    : Bus 37504	: V=0.9629454, theta=-28.300285 -> V=1.0, theta=0.0
% INFO    : Bus 37505	: V=0.9799825, theta=-30.578307 -> V=1.0, theta=0.0
% INFO    : Bus 37506	: V=0.9659624, theta=-28.451438 -> V=1.0, theta=0.0
% INFO    : Bus 37507	: V=1.0203158, theta=-8.857844 -> V=1.0, theta=0.0
% INFO    : Bus 37508	: V=1.0185316, theta=-8.615267 -> V=1.0, theta=0.0
% INFO    : Bus 37509	: V=1.0101199, theta=-8.654452 -> V=1.0, theta=0.0
% INFO    : Bus 37510	: V=1.0138482, theta=-9.616815 -> V=1.0, theta=0.0
% INFO    : Bus 37511	: V=1.0204748, theta=-9.088998 -> V=1.0, theta=0.0
% INFO    : Bus 37512	: V=1.0129542, theta=-10.171171 -> V=1.0, theta=0.0
% INFO    : Bus 37513	: V=1.0168284, theta=-9.784228 -> V=1.0, theta=0.0
% INFO    : Bus 37514	: V=1.0032821, theta=-11.938378 -> V=1.0, theta=0.0
% INFO    : Bus 37515	: V=1.0088551, theta=-10.926924 -> V=1.0, theta=0.0
% INFO    : Bus 37516	: V=0.9545632, theta=-11.635908 -> V=1.0, theta=0.0
% INFO    : Bus 37517	: V=0.966521, theta=-11.119752 -> V=1.0, theta=0.0
% INFO    : Bus 37518	: V=0.9650744, theta=-11.534982 -> V=1.0, theta=0.0
% INFO    : Bus 37519	: V=0.970492, theta=-12.606008 -> V=1.0, theta=0.0
% INFO    : Bus 37520	: V=0.9695247, theta=-13.114492 -> V=1.0, theta=0.0
% INFO    : Bus 37521	: V=0.9691496, theta=-13.655163 -> V=1.0, theta=0.0
% INFO    : Bus 37522	: V=0.9693281, theta=-14.900629 -> V=1.0, theta=0.0
% INFO    : Bus 37523	: V=0.9701717, theta=-13.018462 -> V=1.0, theta=0.0
% INFO    : Bus 37524	: V=0.9662014, theta=-15.118083 -> V=1.0, theta=0.0
% INFO    : Bus 37525	: V=0.9828152, theta=-17.73234 -> V=1.0, theta=0.0
% INFO    : Bus 37526	: V=0.9808872, theta=-18.195195 -> V=1.0, theta=0.0
% INFO    : Bus 37527	: V=1.0197501, theta=-8.802609 -> V=1.0, theta=0.0
% INFO    : Bus 37528	: V=1.0105666, theta=-8.077589 -> V=1.0, theta=0.0
% INFO    : Bus 37529	: V=1.0199816, theta=-8.700654 -> V=1.0, theta=0.0
% INFO    : Bus 37530	: V=1.0070825, theta=-9.833421 -> V=1.0, theta=0.0
% INFO    : Bus 37531	: V=1.0144792, theta=-9.266795 -> V=1.0, theta=0.0
% INFO    : Bus 37532	: V=1.0198899, theta=-8.918199 -> V=1.0, theta=0.0
% INFO    : Bus 37533	: V=1.0202221, theta=-8.251638 -> V=1.0, theta=0.0
% INFO    : Bus 37534	: V=1.0086924, theta=-8.987299 -> V=1.0, theta=0.0
% INFO    : Bus 37535	: V=1.0075917, theta=-8.75259 -> V=1.0, theta=0.0
% INFO    : Bus 37536	: V=1.0062479, theta=-8.86375 -> V=1.0, theta=0.0
% INFO    : Bus 37537	: V=1.0031972, theta=-9.135258 -> V=1.0, theta=0.0
% INFO    : Bus 37538	: V=1.0086909, theta=-8.379649 -> V=1.0, theta=0.0
% INFO    : Bus 37539	: V=0.984335, theta=-9.169378 -> V=1.0, theta=0.0
% INFO    : Bus 37540	: V=0.9996867, theta=-8.631805 -> V=1.0, theta=0.0
% INFO    : Bus 37541	: V=0.9892024, theta=-8.690243 -> V=1.0, theta=0.0
% INFO    : Bus 37542	: V=0.9981975, theta=-8.630857 -> V=1.0, theta=0.0
% INFO    : Bus 37543	: V=1.0032887, theta=-8.629447 -> V=1.0, theta=0.0
% INFO    : Bus 37544	: V=0.980434, theta=-8.611099 -> V=1.0, theta=0.0
% INFO    : Bus 37545	: V=1.0004889, theta=-8.62639 -> V=1.0, theta=0.0
% INFO    : Bus 37546	: V=0.9763271, theta=-8.531664 -> V=1.0, theta=0.0
% INFO    : Bus 37547	: V=0.9822798, theta=-8.749828 -> V=1.0, theta=0.0
% INFO    : Bus 37548	: V=0.9957484, theta=-11.323874 -> V=1.0, theta=0.0
% INFO    : Bus 37549	: V=0.9946284, theta=-12.373306 -> V=1.0, theta=0.0
% INFO    : Bus 37550	: V=0.9864733, theta=-13.237153 -> V=1.0, theta=0.0
% INFO    : Bus 37551	: V=0.9595622, theta=-30.925796 -> V=1.0, theta=0.0
% INFO    : Bus 37552	: V=0.9566037, theta=-32.553086 -> V=1.0, theta=0.0
% INFO    : Bus 37553	: V=0.9811001, theta=-13.578137 -> V=1.0, theta=0.0
% INFO    : Bus 37554	: V=0.9828597, theta=-13.96767 -> V=1.0, theta=0.0
% INFO    : Bus 37555	: V=0.9834463, theta=-14.457966 -> V=1.0, theta=0.0
% INFO    : Bus 37556	: V=0.9656644, theta=-37.294606 -> V=1.0, theta=0.0
% INFO    : Bus 37557	: V=0.9706459, theta=-40.256525 -> V=1.0, theta=0.0
% INFO    : Bus 37558	: V=0.9662801, theta=-39.832799 -> V=1.0, theta=0.0
% INFO    : Bus 37559	: V=0.9705215, theta=-40.619355 -> V=1.0, theta=0.0
% INFO    : Bus 37560	: V=0.971116, theta=-41.234462 -> V=1.0, theta=0.0
% INFO    : Bus 37561	: V=0.9713553, theta=-41.270589 -> V=1.0, theta=0.0
% INFO    : Bus 37562	: V=0.9699409, theta=-41.767356 -> V=1.0, theta=0.0
% INFO    : Bus 37563	: V=0.9653866, theta=-38.980122 -> V=1.0, theta=0.0
% INFO    : Bus 37564	: V=0.9955292, theta=-34.86363 -> V=1.0, theta=0.0
% INFO    : Bus 37565	: V=0.9865595, theta=-36.872909 -> V=1.0, theta=0.0
% INFO    : Bus 37566	: V=0.9778, theta=-38.603801 -> V=1.0, theta=0.0
% INFO    : Bus 37567	: V=0.9820336, theta=-37.416598 -> V=1.0, theta=0.0
% INFO    : Bus 37568	: V=0.9752802, theta=-38.999819 -> V=1.0, theta=0.0
% INFO    : Bus 37569	: V=0.9710385, theta=-40.289699 -> V=1.0, theta=0.0
% INFO    : Bus 37570	: V=0.9674279, theta=-41.26986 -> V=1.0, theta=0.0
% INFO    : Bus 37571	: V=0.9687007, theta=-42.989925 -> V=1.0, theta=0.0
% INFO    : Bus 37572	: V=0.9689585, theta=-40.589602 -> V=1.0, theta=0.0
% INFO    : Bus 37573	: V=0.9711794, theta=-40.180567 -> V=1.0, theta=0.0
% INFO    : Bus 37574	: V=0.9749236, theta=-39.491128 -> V=1.0, theta=0.0
% INFO    : Bus 37575	: V=0.9786802, theta=-38.230505 -> V=1.0, theta=0.0
% INFO    : Bus 37576	: V=0.9918411, theta=-35.233236 -> V=1.0, theta=0.0
% INFO    : Bus 37577	: V=0.9859327, theta=-35.98157 -> V=1.0, theta=0.0
% INFO    : Bus 37578	: V=0.9840516, theta=-36.42572 -> V=1.0, theta=0.0
% INFO    : Bus 37579	: V=0.9837205, theta=-36.696473 -> V=1.0, theta=0.0
% INFO    : Bus 37580	: V=0.98169, theta=-37.186839 -> V=1.0, theta=0.0
% INFO    : Bus 37581	: V=0.9745226, theta=-39.547064 -> V=1.0, theta=0.0
% INFO    : Bus 37582	: V=0.9715626, theta=-40.103209 -> V=1.0, theta=0.0
% INFO    : Bus 37583	: V=0.9772978, theta=-21.310972 -> V=1.0, theta=0.0
% INFO    : Bus 37584	: V=0.9858018, theta=-19.709944 -> V=1.0, theta=0.0
% INFO    : Bus 37585	: V=0.9451515, theta=-28.401222 -> V=1.0, theta=0.0
% INFO    : Bus 37586	: V=0.9363222, theta=-31.871745 -> V=1.0, theta=0.0
% INFO    : Bus 37587	: V=0.962095, theta=-28.67428 -> V=1.0, theta=0.0
% INFO    : Bus 37588	: V=0.9377955, theta=-31.563636 -> V=1.0, theta=0.0
% INFO    : Bus 37589	: V=0.9396366, theta=-30.270557 -> V=1.0, theta=0.0
% INFO    : Bus 37590	: V=0.9520245, theta=-30.982822 -> V=1.0, theta=0.0
% INFO    : Bus 37591	: V=0.9385825, theta=-32.17209 -> V=1.0, theta=0.0
% INFO    : Bus 37592	: V=0.945842, theta=-32.821252 -> V=1.0, theta=0.0
% INFO    : Bus 37593	: V=0.9386926, theta=-31.884049 -> V=1.0, theta=0.0
% INFO    : Bus 37594	: V=0.9472113, theta=-31.94302 -> V=1.0, theta=0.0
% INFO    : Bus 37595	: V=0.9471646, theta=-30.746475 -> V=1.0, theta=0.0
% INFO    : Bus 37596	: V=0.9492784, theta=-31.467604 -> V=1.0, theta=0.0
% INFO    : Bus 37597	: V=0.9458551, theta=-32.425752 -> V=1.0, theta=0.0
% INFO    : Bus 37598	: V=0.9448218, theta=-33.102003 -> V=1.0, theta=0.0
% INFO    : Bus 37599	: V=0.9855706, theta=-17.12822 -> V=1.0, theta=0.0
% INFO    : Bus 37600	: V=0.9586521, theta=-25.913934 -> V=1.0, theta=0.0
% INFO    : Bus 37601	: V=0.9467917, theta=-28.775946 -> V=1.0, theta=0.0
% INFO    : Bus 37602	: V=0.9462027, theta=-29.713441 -> V=1.0, theta=0.0
% INFO    : Bus 37603	: V=0.9521244, theta=-29.319283 -> V=1.0, theta=0.0
% INFO    : Bus 37604	: V=0.9789707, theta=-24.183634 -> V=1.0, theta=0.0
% INFO    : Bus 37605	: V=0.9761095, theta=-23.7883 -> V=1.0, theta=0.0
% INFO    : Bus 37606	: V=0.9789432, theta=-27.863067 -> V=1.0, theta=0.0
% INFO    : Bus 37607	: V=0.9633022, theta=-26.944682 -> V=1.0, theta=0.0
% INFO    : Bus 37608	: V=0.9986846, theta=-24.365503 -> V=1.0, theta=0.0
% INFO    : Bus 37609	: V=1.0039196, theta=-24.436402 -> V=1.0, theta=0.0
% INFO    : Bus 37610	: V=0.9938918, theta=-25.285884 -> V=1.0, theta=0.0
% INFO    : Bus 37611	: V=1.0001807, theta=-25.969838 -> V=1.0, theta=0.0
% INFO    : Bus 37612	: V=0.9824558, theta=-27.030346 -> V=1.0, theta=0.0
% INFO    : Bus 37613	: V=0.9720841, theta=-15.339568 -> V=1.0, theta=0.0
% INFO    : Bus 37614	: V=0.9733953, theta=-15.473098 -> V=1.0, theta=0.0
% INFO    : Bus 37615	: V=0.9736101, theta=-15.374762 -> V=1.0, theta=0.0
% INFO    : Bus 37616	: V=0.974873, theta=-15.655215 -> V=1.0, theta=0.0
% INFO    : Bus 37617	: V=0.9833207, theta=-15.709125 -> V=1.0, theta=0.0
% INFO    : Bus 37618	: V=0.9713105, theta=-15.896472 -> V=1.0, theta=0.0
% INFO    : Bus 37619	: V=0.9705606, theta=-15.856904 -> V=1.0, theta=0.0
% INFO    : Bus 37620	: V=0.9715361, theta=-15.1227 -> V=1.0, theta=0.0
% INFO    : Bus 37621	: V=0.9751586, theta=-14.505796 -> V=1.0, theta=0.0
% INFO    : Bus 37622	: V=0.9782664, theta=-14.244014 -> V=1.0, theta=0.0
% INFO    : Bus 37623	: V=0.9790283, theta=-14.099011 -> V=1.0, theta=0.0
% INFO    : Bus 37624	: V=0.9742255, theta=-15.554307 -> V=1.0, theta=0.0
% INFO    : Bus 37625	: V=0.9754069, theta=-15.117711 -> V=1.0, theta=0.0
% INFO    : Bus 37626	: V=0.9507936, theta=-15.288865 -> V=1.0, theta=0.0
% INFO    : Bus 37627	: V=0.970502, theta=-12.822339 -> V=1.0, theta=0.0
% INFO    : Bus 37628	: V=0.9792869, theta=-12.109416 -> V=1.0, theta=0.0
% INFO    : Bus 37629	: V=0.9839978, theta=-10.875998 -> V=1.0, theta=0.0
% INFO    : Bus 37630	: V=0.9837055, theta=-10.733516 -> V=1.0, theta=0.0
% INFO    : Bus 37631	: V=0.9788091, theta=-11.01185 -> V=1.0, theta=0.0
% INFO    : Bus 37632	: V=0.9974923, theta=-10.286223 -> V=1.0, theta=0.0
% INFO    : Bus 37633	: V=0.9818494, theta=-10.459689 -> V=1.0, theta=0.0
% INFO    : Bus 37634	: V=0.9793465, theta=-10.707505 -> V=1.0, theta=0.0
% INFO    : Bus 37635	: V=0.98177, theta=-9.18796 -> V=1.0, theta=0.0
% INFO    : Bus 37636	: V=0.9776013, theta=-17.969399 -> V=1.0, theta=0.0
% INFO    : Bus 37637	: V=0.9885892, theta=-18.121306 -> V=1.0, theta=0.0
% INFO    : Bus 37638	: V=0.9761173, theta=-16.682997 -> V=1.0, theta=0.0
% INFO    : Bus 37639	: V=0.9606366, theta=-39.502533 -> V=1.0, theta=0.0
% INFO    : Bus 37640	: V=0.9749551, theta=-10.741761 -> V=1.0, theta=0.0
% INFO    : Bus 37641	: V=0.9716478, theta=-10.770299 -> V=1.0, theta=0.0
% INFO    : Bus 37642	: V=0.969111, theta=-10.849782 -> V=1.0, theta=0.0
% INFO    : Bus 37643	: V=0.9523823, theta=-11.06783 -> V=1.0, theta=0.0
% INFO    : Bus 37644	: V=0.9805575, theta=-21.482854 -> V=1.0, theta=0.0
% INFO    : Bus 37645	: V=0.9659905, theta=-21.484537 -> V=1.0, theta=0.0
% INFO    : Bus 37646	: V=0.971777, theta=-22.473703 -> V=1.0, theta=0.0
% INFO    : Bus 37647	: V=0.9715733, theta=-22.566031 -> V=1.0, theta=0.0
% INFO    : Bus 37648	: V=0.9715251, theta=-22.720759 -> V=1.0, theta=0.0
% INFO    : Bus 37649	: V=1.0023404, theta=-12.361455 -> V=1.0, theta=0.0
% INFO    : Bus 37650	: V=0.997046, theta=-13.871325 -> V=1.0, theta=0.0
% INFO    : Bus 37651	: V=0.9801719, theta=-17.846746 -> V=1.0, theta=0.0
% INFO    : Bus 37652	: V=0.9967756, theta=-14.765971 -> V=1.0, theta=0.0
% INFO    : Bus 37653	: V=1.0042695, theta=-10.926682 -> V=1.0, theta=0.0
% INFO    : Bus 37654	: V=1.0022095, theta=-11.835876 -> V=1.0, theta=0.0
% INFO    : Bus 37655	: V=1.0026893, theta=-11.997767 -> V=1.0, theta=0.0
% INFO    : Bus 37656	: V=1.0048833, theta=-12.026638 -> V=1.0, theta=0.0
% INFO    : Bus 37657	: V=0.9919162, theta=-13.506793 -> V=1.0, theta=0.0
% INFO    : Bus 37658	: V=1.0071774, theta=-9.259982 -> V=1.0, theta=0.0
% INFO    : Bus 37659	: V=1.0199416, theta=-9.267527 -> V=1.0, theta=0.0
% INFO    : Bus 37660	: V=0.9887646, theta=-7.289663 -> V=1.0, theta=0.0
% INFO    : Bus 37661	: V=1.0068077, theta=-7.261574 -> V=1.0, theta=0.0
% INFO    : Bus 37662	: V=0.9781586, theta=-7.598558 -> V=1.0, theta=0.0
% INFO    : Bus 37663	: V=1.0031745, theta=-7.576631 -> V=1.0, theta=0.0
% INFO    : Bus 37664	: V=0.9793003, theta=-15.569163 -> V=1.0, theta=0.0
% INFO    : Bus 37665	: V=0.978404, theta=-15.655024 -> V=1.0, theta=0.0
% INFO    : Bus 37666	: V=0.9797905, theta=-15.521362 -> V=1.0, theta=0.0
% INFO    : Bus 37667	: V=0.9801823, theta=-15.5226 -> V=1.0, theta=0.0
% INFO    : Bus 37668	: V=0.9795975, theta=-15.550311 -> V=1.0, theta=0.0
% INFO    : Bus 37669	: V=0.9808474, theta=-15.50443 -> V=1.0, theta=0.0
% INFO    : Bus 37670	: V=0.9813103, theta=-15.611008 -> V=1.0, theta=0.0
% INFO    : Bus 37671	: V=0.9817738, theta=-15.665331 -> V=1.0, theta=0.0
% INFO    : Bus 37672	: V=0.9741653, theta=-16.056003 -> V=1.0, theta=0.0
% INFO    : Bus 37673	: V=0.9843803, theta=-15.840254 -> V=1.0, theta=0.0
% INFO    : Bus 37674	: V=0.9827695, theta=-15.743662 -> V=1.0, theta=0.0
% INFO    : Bus 37675	: V=0.9809409, theta=-15.494337 -> V=1.0, theta=0.0
% INFO    : Bus 37676	: V=0.9813148, theta=-15.418511 -> V=1.0, theta=0.0
% INFO    : Bus 37677	: V=0.9827302, theta=-15.334603 -> V=1.0, theta=0.0
% INFO    : Bus 37678	: V=1.0036791, theta=-13.414771 -> V=1.0, theta=0.0
% INFO    : Bus 37679	: V=0.9746541, theta=-13.649564 -> V=1.0, theta=0.0
% INFO    : Bus 37680	: V=0.9770554, theta=-15.884896 -> V=1.0, theta=0.0
% INFO    : Bus 37681	: V=0.9795097, theta=-15.786445 -> V=1.0, theta=0.0
% INFO    : Bus 37682	: V=0.9792956, theta=-15.793122 -> V=1.0, theta=0.0
% INFO    : Bus 37683	: V=0.9691936, theta=-15.994332 -> V=1.0, theta=0.0
% INFO    : Bus 37684	: V=0.9735271, theta=-18.994813 -> V=1.0, theta=0.0
% INFO    : Bus 37685	: V=0.9731445, theta=-15.45328 -> V=1.0, theta=0.0
% INFO    : Bus 37686	: V=0.9768257, theta=-12.908347 -> V=1.0, theta=0.0
% INFO    : Bus 37687	: V=0.9823516, theta=-16.81814 -> V=1.0, theta=0.0
% INFO    : Bus 37688	: V=0.971503, theta=-16.74438 -> V=1.0, theta=0.0
% INFO    : Bus 37689	: V=0.9715803, theta=-17.353123 -> V=1.0, theta=0.0
% INFO    : Bus 37690	: V=0.9719875, theta=-17.792646 -> V=1.0, theta=0.0
% INFO    : Bus 37691	: V=0.9503835, theta=-32.287454 -> V=1.0, theta=0.0
% INFO    : Bus 37692	: V=0.9562977, theta=-33.142845 -> V=1.0, theta=0.0
% INFO    : Bus 37693	: V=0.9554957, theta=-33.459376 -> V=1.0, theta=0.0
% INFO    : Bus 37694	: V=0.9581665, theta=-31.818667 -> V=1.0, theta=0.0
% INFO    : Bus 37695	: V=0.955321, theta=-34.395336 -> V=1.0, theta=0.0
% INFO    : Bus 37696	: V=1.0050562, theta=-7.570903 -> V=1.0, theta=0.0
% INFO    : Bus 37697	: V=1.006356, theta=-7.648952 -> V=1.0, theta=0.0
% INFO    : Bus 37698	: V=1.0088429, theta=-7.394089 -> V=1.0, theta=0.0
% INFO    : Bus 37699	: V=1.0103204, theta=-7.405699 -> V=1.0, theta=0.0
% INFO    : Bus 37700	: V=0.9623113, theta=-37.900012 -> V=1.0, theta=0.0
% INFO    : Bus 37701	: V=0.963111, theta=-37.735013 -> V=1.0, theta=0.0
% INFO    : Bus 37702	: V=0.9628372, theta=-37.714143 -> V=1.0, theta=0.0
% INFO    : Bus 37703	: V=0.972574, theta=-34.493135 -> V=1.0, theta=0.0
% INFO    : Bus 37704	: V=0.9620468, theta=-37.633941 -> V=1.0, theta=0.0
% INFO    : Bus 37705	: V=0.963673, theta=-37.524881 -> V=1.0, theta=0.0
% INFO    : Bus 37706	: V=0.9600692, theta=-39.556944 -> V=1.0, theta=0.0
% INFO    : Bus 37707	: V=0.9610939, theta=-39.805334 -> V=1.0, theta=0.0
% INFO    : Bus 37708	: V=0.9652878, theta=-26.744703 -> V=1.0, theta=0.0
% INFO    : Bus 37709	: V=0.9707768, theta=-22.741876 -> V=1.0, theta=0.0
% INFO    : Bus 37710	: V=0.9804671, theta=-16.461015 -> V=1.0, theta=0.0
% INFO    : Bus 37711	: V=0.9789647, theta=-16.432581 -> V=1.0, theta=0.0
% INFO    : Bus 37712	: V=0.9817271, theta=-16.639344 -> V=1.0, theta=0.0
% INFO    : Bus 37713	: V=0.979784, theta=-16.736613 -> V=1.0, theta=0.0
% INFO    : Bus 37714	: V=0.979478, theta=-16.645114 -> V=1.0, theta=0.0
% INFO    : Bus 37715	: V=0.985655, theta=-17.07827 -> V=1.0, theta=0.0
% INFO    : Bus 37716	: V=0.9776589, theta=-15.742828 -> V=1.0, theta=0.0
% INFO    : Bus 37717	: V=0.9754778, theta=-15.641366 -> V=1.0, theta=0.0
% INFO    : Bus 37718	: V=0.9780126, theta=-47.116814 -> V=1.0, theta=0.0
% INFO    : Bus 37719	: V=1.0039972, theta=-47.869447 -> V=1.0, theta=0.0
% INFO    : Bus 37720	: V=0.9895971, theta=-47.360126 -> V=1.0, theta=0.0
% INFO    : Bus 37721	: V=1.0103239, theta=-47.179144 -> V=1.0, theta=0.0
% INFO    : Bus 37722	: V=1.0064648, theta=-47.823338 -> V=1.0, theta=0.0
% INFO    : Bus 37723	: V=1.0090764, theta=-47.167184 -> V=1.0, theta=0.0
% INFO    : Bus 37724	: V=0.9886583, theta=-47.365319 -> V=1.0, theta=0.0
% INFO    : Bus 37725	: V=0.9680203, theta=-44.601845 -> V=1.0, theta=0.0
% INFO    : Bus 37726	: V=0.9872672, theta=-47.255801 -> V=1.0, theta=0.0
% INFO    : Bus 37727	: V=0.9769932, theta=-24.894595 -> V=1.0, theta=0.0
% INFO    : Bus 37728	: V=1.0025078, theta=-22.983082 -> V=1.0, theta=0.0
% INFO    : Bus 37729	: V=0.9935798, theta=-23.585131 -> V=1.0, theta=0.0
% INFO    : Bus 37730	: V=0.9873917, theta=-24.666688 -> V=1.0, theta=0.0
% INFO    : Bus 37731	: V=1.0003698, theta=-23.084972 -> V=1.0, theta=0.0
% INFO    : Bus 37732	: V=1.0023565, theta=-22.685158 -> V=1.0, theta=0.0
% INFO    : Bus 37733	: V=1.0027197, theta=-22.937796 -> V=1.0, theta=0.0
% INFO    : Bus 37734	: V=0.9343045, theta=-48.3518 -> V=1.0, theta=0.0
% INFO    : Bus 37735	: V=0.9392376, theta=-47.331831 -> V=1.0, theta=0.0
% INFO    : Bus 37736	: V=0.9214308, theta=-49.020283 -> V=1.0, theta=0.0
% INFO    : Bus 37737	: V=1.017902, theta=-22.814816 -> V=1.0, theta=0.0
% INFO    : Bus 37738	: V=1.0086189, theta=-23.99273 -> V=1.0, theta=0.0
% INFO    : Bus 37739	: V=1.0134533, theta=-25.686771 -> V=1.0, theta=0.0
% INFO    : Bus 37740	: V=1.0095441, theta=-24.489992 -> V=1.0, theta=0.0
% INFO    : Bus 37741	: V=1.0182089, theta=-23.433344 -> V=1.0, theta=0.0
% INFO    : Bus 37742	: V=1.0184092, theta=-23.51273 -> V=1.0, theta=0.0
% INFO    : Bus 37743	: V=1.001874, theta=-23.918668 -> V=1.0, theta=0.0
% INFO    : Bus 37744	: V=1.0020007, theta=-23.992344 -> V=1.0, theta=0.0
% INFO    : Bus 37745	: V=1.0135343, theta=-22.644814 -> V=1.0, theta=0.0
% INFO    : Bus 37746	: V=1.0162606, theta=-23.817881 -> V=1.0, theta=0.0
% INFO    : Bus 37747	: V=1.0122109, theta=-24.387039 -> V=1.0, theta=0.0
% INFO    : Bus 37748	: V=1.0210788, theta=-24.368321 -> V=1.0, theta=0.0
% INFO    : Bus 37749	: V=1.0161846, theta=-24.709101 -> V=1.0, theta=0.0
% INFO    : Bus 37750	: V=1.0232817, theta=-24.707461 -> V=1.0, theta=0.0
% INFO    : Bus 37751	: V=1.0174038, theta=-24.694201 -> V=1.0, theta=0.0
% INFO    : Bus 37752	: V=1.0168098, theta=-24.704874 -> V=1.0, theta=0.0
% INFO    : Bus 37753	: V=0.987731, theta=-25.06444 -> V=1.0, theta=0.0
% INFO    : Bus 37754	: V=0.9884263, theta=-24.998624 -> V=1.0, theta=0.0
% INFO    : Bus 37755	: V=0.9937252, theta=-24.545929 -> V=1.0, theta=0.0
% INFO    : Bus 37756	: V=0.9825759, theta=-25.280447 -> V=1.0, theta=0.0
% INFO    : Bus 37757	: V=0.9911636, theta=-24.746089 -> V=1.0, theta=0.0
% INFO    : Bus 37758	: V=0.9884026, theta=-26.861765 -> V=1.0, theta=0.0
% INFO    : Bus 37759	: V=0.9976025, theta=-26.244507 -> V=1.0, theta=0.0
% INFO    : Bus 37760	: V=0.9951602, theta=-23.660329 -> V=1.0, theta=0.0
% INFO    : Bus 37761	: V=0.9920387, theta=-24.06856 -> V=1.0, theta=0.0
% INFO    : Bus 37762	: V=0.9946658, theta=-23.887234 -> V=1.0, theta=0.0
% INFO    : Bus 37763	: V=0.999856, theta=-23.086793 -> V=1.0, theta=0.0
% INFO    : Bus 37764	: V=1.0139274, theta=-20.681789 -> V=1.0, theta=0.0
% INFO    : Bus 37765	: V=1.0206584, theta=-20.938284 -> V=1.0, theta=0.0
% INFO    : Bus 37766	: V=1.0208028, theta=-20.795431 -> V=1.0, theta=0.0
% INFO    : Bus 37767	: V=0.9849321, theta=-39.180086 -> V=1.0, theta=0.0
% INFO    : Bus 37768	: V=0.9787501, theta=-40.301899 -> V=1.0, theta=0.0
% INFO    : Bus 37769	: V=0.9722078, theta=-40.425511 -> V=1.0, theta=0.0
% INFO    : Bus 37770	: V=0.9901135, theta=-41.62186 -> V=1.0, theta=0.0
% INFO    : Bus 37771	: V=0.9922991, theta=-42.094436 -> V=1.0, theta=0.0
% INFO    : Bus 37772	: V=0.9901893, theta=-43.644709 -> V=1.0, theta=0.0
% INFO    : Bus 37773	: V=0.9887426, theta=-42.529821 -> V=1.0, theta=0.0
% INFO    : Bus 37774	: V=0.9929088, theta=-22.902004 -> V=1.0, theta=0.0
% INFO    : Bus 37775	: V=1.0070273, theta=-22.262314 -> V=1.0, theta=0.0
% INFO    : Bus 37776	: V=1.0132336, theta=-21.318096 -> V=1.0, theta=0.0
% INFO    : Bus 37777	: V=1.0005081, theta=-22.549046 -> V=1.0, theta=0.0
% INFO    : Bus 37778	: V=1.012653, theta=-21.377036 -> V=1.0, theta=0.0
% INFO    : Bus 37779	: V=1.0097602, theta=-21.772374 -> V=1.0, theta=0.0
% INFO    : Bus 37780	: V=1.0119761, theta=-21.390567 -> V=1.0, theta=0.0
% INFO    : Bus 37781	: V=1.0100934, theta=-21.891376 -> V=1.0, theta=0.0
% INFO    : Bus 37782	: V=1.0072789, theta=-20.852006 -> V=1.0, theta=0.0
% INFO    : Bus 37783	: V=1.0123713, theta=-20.58332 -> V=1.0, theta=0.0
% INFO    : Bus 37784	: V=1.0120763, theta=-21.037319 -> V=1.0, theta=0.0
% INFO    : Bus 37785	: V=1.0116758, theta=-21.061949 -> V=1.0, theta=0.0
% INFO    : Bus 37786	: V=0.9643699, theta=-42.430079 -> V=1.0, theta=0.0
% INFO    : Bus 37787	: V=0.9612269, theta=-42.61512 -> V=1.0, theta=0.0
% INFO    : Bus 37788	: V=0.9678647, theta=-42.123184 -> V=1.0, theta=0.0
% INFO    : Bus 37789	: V=0.9627053, theta=-42.766577 -> V=1.0, theta=0.0
% INFO    : Bus 37790	: V=0.9610797, theta=-44.263998 -> V=1.0, theta=0.0
% INFO    : Bus 37791	: V=0.94826, theta=-43.274917 -> V=1.0, theta=0.0
% INFO    : Bus 37792	: V=0.9803883, theta=-47.421603 -> V=1.0, theta=0.0
% INFO    : Bus 37793	: V=0.9882428, theta=-46.856147 -> V=1.0, theta=0.0
% INFO    : Bus 37794	: V=0.9816167, theta=-46.623607 -> V=1.0, theta=0.0
% INFO    : Bus 37795	: V=0.9992113, theta=-46.392802 -> V=1.0, theta=0.0
% INFO    : Bus 37796	: V=0.9989783, theta=-24.658033 -> V=1.0, theta=0.0
% INFO    : Bus 37797	: V=1.0013604, theta=-24.482012 -> V=1.0, theta=0.0
% INFO    : Bus 37798	: V=0.9918839, theta=-26.308203 -> V=1.0, theta=0.0
% INFO    : Bus 37799	: V=0.991937, theta=-26.12274 -> V=1.0, theta=0.0
% INFO    : Bus 37800	: V=0.9973884, theta=-25.651162 -> V=1.0, theta=0.0
% INFO    : Bus 37801	: V=0.9924652, theta=-26.432687 -> V=1.0, theta=0.0
% INFO    : Bus 37802	: V=0.9940717, theta=-26.320394 -> V=1.0, theta=0.0
% INFO    : Bus 37803	: V=1.0025914, theta=-25.432504 -> V=1.0, theta=0.0
% INFO    : Bus 37804	: V=0.9933231, theta=-26.305772 -> V=1.0, theta=0.0
% INFO    : Bus 37805	: V=0.9947307, theta=-26.271095 -> V=1.0, theta=0.0
% INFO    : Bus 37806	: V=0.9908964, theta=-26.639375 -> V=1.0, theta=0.0
% INFO    : Bus 37807	: V=0.9918025, theta=-26.545642 -> V=1.0, theta=0.0
% INFO    : Bus 37808	: V=0.9945915, theta=-26.308271 -> V=1.0, theta=0.0
% INFO    : Bus 37809	: V=0.9906573, theta=-26.549138 -> V=1.0, theta=0.0
% INFO    : Bus 37810	: V=0.9753941, theta=-27.774476 -> V=1.0, theta=0.0
% INFO    : Bus 37811	: V=0.9896537, theta=-26.601616 -> V=1.0, theta=0.0
% INFO    : Bus 37812	: V=0.9910237, theta=-26.581818 -> V=1.0, theta=0.0
% INFO    : Bus 37813	: V=0.9917698, theta=-26.497843 -> V=1.0, theta=0.0
% INFO    : Bus 37814	: V=0.9900871, theta=-26.068572 -> V=1.0, theta=0.0
% INFO    : Bus 37815	: V=0.9927965, theta=-25.908178 -> V=1.0, theta=0.0
% INFO    : Bus 37816	: V=0.9709242, theta=-28.150617 -> V=1.0, theta=0.0
% INFO    : Bus 37817	: V=0.9579814, theta=-29.186567 -> V=1.0, theta=0.0
% INFO    : Bus 37818	: V=0.9736128, theta=-27.523532 -> V=1.0, theta=0.0
% INFO    : Bus 37819	: V=0.9679069, theta=-28.375523 -> V=1.0, theta=0.0
% INFO    : Bus 37820	: V=0.9690999, theta=-28.069537 -> V=1.0, theta=0.0
% INFO    : Bus 37821	: V=0.9704172, theta=-27.888895 -> V=1.0, theta=0.0
% INFO    : Bus 37822	: V=0.9697527, theta=-27.973181 -> V=1.0, theta=0.0
% INFO    : Bus 37823	: V=0.955778, theta=-29.398754 -> V=1.0, theta=0.0
% INFO    : Bus 37824	: V=0.9780559, theta=-27.047642 -> V=1.0, theta=0.0
% INFO    : Bus 37825	: V=0.9860051, theta=-26.225048 -> V=1.0, theta=0.0
% INFO    : Bus 37826	: V=0.99827, theta=-25.461555 -> V=1.0, theta=0.0
% INFO    : Bus 37827	: V=1.000365, theta=-25.110693 -> V=1.0, theta=0.0
% INFO    : Bus 37828	: V=0.9961973, theta=-24.876009 -> V=1.0, theta=0.0
% INFO    : Bus 37829	: V=1.0139956, theta=-49.585454 -> V=1.0, theta=0.0
% INFO    : Bus 37830	: V=1.0139215, theta=-49.507348 -> V=1.0, theta=0.0
% INFO    : Bus 37831	: V=1.0147591, theta=-49.676291 -> V=1.0, theta=0.0
% INFO    : Bus 37832	: V=1.0061856, theta=-50.166818 -> V=1.0, theta=0.0
% INFO    : Bus 37833	: V=1.0065192, theta=-50.059918 -> V=1.0, theta=0.0
% INFO    : Bus 37834	: V=1.0145393, theta=-49.370118 -> V=1.0, theta=0.0
% INFO    : Bus 37835	: V=1.0138878, theta=-49.369493 -> V=1.0, theta=0.0
% INFO    : Bus 37836	: V=1.0133631, theta=-49.389441 -> V=1.0, theta=0.0
% INFO    : Bus 37837	: V=1.0127604, theta=-49.409769 -> V=1.0, theta=0.0
% INFO    : Bus 37838	: V=1.0156216, theta=-49.903026 -> V=1.0, theta=0.0
% INFO    : Bus 37839	: V=0.9997424, theta=-50.627394 -> V=1.0, theta=0.0
% INFO    : Bus 37840	: V=1.0144187, theta=-48.11592 -> V=1.0, theta=0.0
% INFO    : Bus 37841	: V=1.0065896, theta=-50.251795 -> V=1.0, theta=0.0
% INFO    : Bus 37842	: V=1.0165438, theta=-49.745122 -> V=1.0, theta=0.0
% INFO    : Bus 37843	: V=1.0038957, theta=-50.697302 -> V=1.0, theta=0.0
% INFO    : Bus 37844	: V=1.0017306, theta=-50.9863 -> V=1.0, theta=0.0
% INFO    : Bus 37845	: V=1.0068637, theta=-50.10919 -> V=1.0, theta=0.0
% INFO    : Bus 37846	: V=0.9570881, theta=-45.155097 -> V=1.0, theta=0.0
% INFO    : Bus 37847	: V=0.9530738, theta=-46.259068 -> V=1.0, theta=0.0
% INFO    : Bus 37848	: V=0.9908838, theta=-52.078448 -> V=1.0, theta=0.0
% INFO    : Bus 37849	: V=0.9966483, theta=-50.217059 -> V=1.0, theta=0.0
% INFO    : Bus 37850	: V=0.9840161, theta=-50.990908 -> V=1.0, theta=0.0
% INFO    : Bus 37851	: V=0.9894185, theta=-52.695304 -> V=1.0, theta=0.0
% INFO    : Bus 37852	: V=0.9761318, theta=-53.465063 -> V=1.0, theta=0.0
% INFO    : Bus 37853	: V=1.0013063, theta=-47.971381 -> V=1.0, theta=0.0
% INFO    : Bus 37854	: V=0.9765577, theta=-51.386397 -> V=1.0, theta=0.0
% INFO    : Bus 37855	: V=0.9918125, theta=-25.413649 -> V=1.0, theta=0.0
% INFO    : Bus 37856	: V=0.9887016, theta=-26.304703 -> V=1.0, theta=0.0
% INFO    : Bus 37857	: V=0.9749104, theta=-27.564923 -> V=1.0, theta=0.0
% INFO    : Bus 37858	: V=0.9889206, theta=-26.035573 -> V=1.0, theta=0.0
% INFO    : Bus 37859	: V=0.9890452, theta=-25.933309 -> V=1.0, theta=0.0
% INFO    : Bus 37860	: V=0.9538221, theta=-58.555231 -> V=1.0, theta=0.0
% INFO    : Bus 37861	: V=0.9554333, theta=-58.578384 -> V=1.0, theta=0.0
% INFO    : Bus 37862	: V=0.9575007, theta=-58.44756 -> V=1.0, theta=0.0
% INFO    : Bus 37863	: V=0.9618513, theta=-59.099299 -> V=1.0, theta=0.0
% INFO    : Bus 37864	: V=0.9651873, theta=-58.251292 -> V=1.0, theta=0.0
% INFO    : Bus 37865	: V=0.9631157, theta=-55.870334 -> V=1.0, theta=0.0
% INFO    : Bus 37866	: V=0.9676373, theta=-58.528782 -> V=1.0, theta=0.0
% INFO    : Bus 37867	: V=1.0004275, theta=-52.635249 -> V=1.0, theta=0.0
% INFO    : Bus 37868	: V=1.0061512, theta=-52.696249 -> V=1.0, theta=0.0
% INFO    : Bus 37869	: V=0.9969873, theta=-53.58968 -> V=1.0, theta=0.0
% INFO    : Bus 37870	: V=1.0068262, theta=-52.707185 -> V=1.0, theta=0.0
% INFO    : Bus 37871	: V=1.0078211, theta=-52.78993 -> V=1.0, theta=0.0
% INFO    : Bus 37872	: V=1.0068673, theta=-53.432273 -> V=1.0, theta=0.0
% INFO    : Bus 37873	: V=1.0047222, theta=-53.285532 -> V=1.0, theta=0.0
% INFO    : Bus 37874	: V=0.9781654, theta=-56.327054 -> V=1.0, theta=0.0
% INFO    : Bus 37875	: V=1.006635, theta=-53.578613 -> V=1.0, theta=0.0
% INFO    : Bus 37876	: V=1.0065899, theta=-53.657168 -> V=1.0, theta=0.0
% INFO    : Bus 37877	: V=1.003388, theta=-53.853631 -> V=1.0, theta=0.0
% INFO    : Bus 37878	: V=0.9898071, theta=-54.891896 -> V=1.0, theta=0.0
% INFO    : Bus 37879	: V=1.0006156, theta=-53.923436 -> V=1.0, theta=0.0
% INFO    : Bus 37880	: V=0.977658, theta=-56.334435 -> V=1.0, theta=0.0
% INFO    : Bus 37881	: V=0.9794123, theta=-56.302623 -> V=1.0, theta=0.0
% INFO    : Bus 37882	: V=0.9767732, theta=-56.450407 -> V=1.0, theta=0.0
% INFO    : Bus 37883	: V=0.9810839, theta=-56.175571 -> V=1.0, theta=0.0
% INFO    : Bus 37884	: V=0.9790397, theta=-56.314054 -> V=1.0, theta=0.0
% INFO    : Bus 37885	: V=0.9779248, theta=-56.386319 -> V=1.0, theta=0.0
% INFO    : Bus 37886	: V=0.97236, theta=-56.835363 -> V=1.0, theta=0.0
% INFO    : Bus 37887	: V=0.9717725, theta=-56.865211 -> V=1.0, theta=0.0
% INFO    : Bus 37888	: V=0.9694176, theta=-57.031171 -> V=1.0, theta=0.0
% INFO    : Bus 37889	: V=0.9694194, theta=-57.059203 -> V=1.0, theta=0.0
% INFO    : Bus 37890	: V=0.9791717, theta=-56.302725 -> V=1.0, theta=0.0
% INFO    : Bus 37891	: V=0.9882327, theta=-55.189301 -> V=1.0, theta=0.0
% INFO    : Bus 37892	: V=1.001765, theta=-53.773063 -> V=1.0, theta=0.0
% INFO    : Bus 37893	: V=1.0031381, theta=-53.644376 -> V=1.0, theta=0.0
% INFO    : Bus 37894	: V=1.0082896, theta=-53.034483 -> V=1.0, theta=0.0
% INFO    : Bus 37895	: V=1.0058021, theta=-53.403279 -> V=1.0, theta=0.0
% INFO    : Bus 37896	: V=1.0198041, theta=-52.667476 -> V=1.0, theta=0.0
% INFO    : Bus 37897	: V=0.9995975, theta=-53.330445 -> V=1.0, theta=0.0
% INFO    : Bus 37898	: V=0.9946491, theta=-53.757882 -> V=1.0, theta=0.0
% INFO    : Bus 37899	: V=0.9925415, theta=-53.785168 -> V=1.0, theta=0.0
% INFO    : Bus 37900	: V=0.9988592, theta=-53.60884 -> V=1.0, theta=0.0
% INFO    : Bus 37901	: V=0.9993808, theta=-53.616018 -> V=1.0, theta=0.0
% INFO    : Bus 37902	: V=0.976983, theta=-55.260575 -> V=1.0, theta=0.0
% INFO    : Bus 37903	: V=0.9896297, theta=-54.100325 -> V=1.0, theta=0.0
% INFO    : Bus 37904	: V=0.9716893, theta=-55.192118 -> V=1.0, theta=0.0
% INFO    : Bus 37905	: V=0.9787628, theta=-55.089544 -> V=1.0, theta=0.0
% INFO    : Bus 37906	: V=0.9835185, theta=-55.042239 -> V=1.0, theta=0.0
% INFO    : Bus 37907	: V=0.9602455, theta=-56.971391 -> V=1.0, theta=0.0
% INFO    : Bus 37908	: V=0.9972696, theta=-53.585283 -> V=1.0, theta=0.0
% INFO    : Bus 37909	: V=0.9761529, theta=-56.452569 -> V=1.0, theta=0.0
% INFO    : Bus 37910	: V=0.9959764, theta=-53.597086 -> V=1.0, theta=0.0
% INFO    : Bus 37911	: V=0.9850078, theta=-55.801175 -> V=1.0, theta=0.0
% INFO    : Bus 37912	: V=1.0083273, theta=-37.579647 -> V=1.0, theta=0.0
% INFO    : Bus 37913	: V=0.9921317, theta=-39.04664 -> V=1.0, theta=0.0
% INFO    : Bus 37914	: V=1.0088605, theta=-37.693635 -> V=1.0, theta=0.0
% INFO    : Bus 37915	: V=1.0094042, theta=-37.650338 -> V=1.0, theta=0.0
% INFO    : Bus 37916	: V=1.0080683, theta=-37.759812 -> V=1.0, theta=0.0
% INFO    : Bus 37917	: V=1.0020812, theta=-38.250122 -> V=1.0, theta=0.0
% INFO    : Bus 37918	: V=1.0034794, theta=-38.238836 -> V=1.0, theta=0.0
% INFO    : Bus 37919	: V=0.9960789, theta=-37.70803 -> V=1.0, theta=0.0
% INFO    : Bus 37920	: V=1.0123027, theta=-37.513106 -> V=1.0, theta=0.0
% INFO    : Bus 37921	: V=1.0032129, theta=-38.242511 -> V=1.0, theta=0.0
% INFO    : Bus 37922	: V=1.0051677, theta=-38.154047 -> V=1.0, theta=0.0
% INFO    : Bus 37923	: V=0.9901729, theta=-39.190203 -> V=1.0, theta=0.0
% INFO    : Bus 37924	: V=0.9909539, theta=-39.185699 -> V=1.0, theta=0.0
% INFO    : Bus 37925	: V=1.0070542, theta=-37.847347 -> V=1.0, theta=0.0
% INFO    : Bus 37926	: V=0.9865968, theta=-39.564258 -> V=1.0, theta=0.0
% INFO    : Bus 37927	: V=1.0051107, theta=-37.9376 -> V=1.0, theta=0.0
% INFO    : Bus 37928	: V=1.0040883, theta=-37.987757 -> V=1.0, theta=0.0
% INFO    : Bus 37929	: V=0.990401, theta=-39.146224 -> V=1.0, theta=0.0
% INFO    : Bus 37930	: V=0.9901894, theta=-39.16556 -> V=1.0, theta=0.0
% INFO    : Bus 37931	: V=1.0078736, theta=-37.780418 -> V=1.0, theta=0.0
% INFO    : Bus 37932	: V=1.0096389, theta=-37.672275 -> V=1.0, theta=0.0
% INFO    : Bus 37933	: V=1.0061003, theta=-37.963644 -> V=1.0, theta=0.0
% INFO    : Bus 37934	: V=0.9951833, theta=-38.882608 -> V=1.0, theta=0.0
% INFO    : Bus 37935	: V=1.0064965, theta=-37.85117 -> V=1.0, theta=0.0
% INFO    : Bus 37936	: V=0.9845687, theta=-39.509761 -> V=1.0, theta=0.0
% INFO    : Bus 37937	: V=0.9856548, theta=-38.895251 -> V=1.0, theta=0.0
% INFO    : Bus 37938	: V=0.9930419, theta=-38.96932 -> V=1.0, theta=0.0
% INFO    : Bus 37939	: V=0.9828898, theta=-39.15969 -> V=1.0, theta=0.0
% INFO    : Bus 37940	: V=0.9903344, theta=-39.088273 -> V=1.0, theta=0.0
% INFO    : Bus 37941	: V=0.9853865, theta=-38.835931 -> V=1.0, theta=0.0
% INFO    : Bus 37942	: V=0.9824847, theta=-39.125098 -> V=1.0, theta=0.0
% INFO    : Bus 37943	: V=0.9822917, theta=-39.122633 -> V=1.0, theta=0.0
% INFO    : Bus 37944	: V=0.9853221, theta=-38.822791 -> V=1.0, theta=0.0
% INFO    : Bus 37945	: V=0.990591, theta=-39.175244 -> V=1.0, theta=0.0
% INFO    : Bus 37946	: V=1.0077315, theta=-37.554288 -> V=1.0, theta=0.0
% INFO    : Bus 37947	: V=1.0107265, theta=-37.542297 -> V=1.0, theta=0.0
% INFO    : Bus 37948	: V=1.0028254, theta=-38.238181 -> V=1.0, theta=0.0
% INFO    : Bus 37949	: V=1.0195046, theta=-37.039334 -> V=1.0, theta=0.0
% INFO    : Bus 37950	: V=0.9957576, theta=-38.08002 -> V=1.0, theta=0.0
% INFO    : Bus 37951	: V=0.9956206, theta=-36.516998 -> V=1.0, theta=0.0
% INFO    : Bus 37952	: V=1.0006054, theta=-37.496943 -> V=1.0, theta=0.0
% INFO    : Bus 37953	: V=0.9963765, theta=-37.589044 -> V=1.0, theta=0.0
% INFO    : Bus 37954	: V=0.9977849, theta=-35.481366 -> V=1.0, theta=0.0
% INFO    : Bus 37955	: V=0.9930027, theta=-36.66181 -> V=1.0, theta=0.0
% INFO    : Bus 37956	: V=0.9806585, theta=-38.976972 -> V=1.0, theta=0.0
% INFO    : Bus 37957	: V=0.9965974, theta=-37.789896 -> V=1.0, theta=0.0
% INFO    : Bus 37958	: V=0.998406, theta=-37.624344 -> V=1.0, theta=0.0
% INFO    : Bus 37959	: V=0.9971736, theta=-37.632695 -> V=1.0, theta=0.0
% INFO    : Bus 37960	: V=0.9870449, theta=-38.787729 -> V=1.0, theta=0.0
% INFO    : Bus 37961	: V=0.9760424, theta=-39.425412 -> V=1.0, theta=0.0
% INFO    : Bus 37962	: V=0.9830667, theta=-39.018149 -> V=1.0, theta=0.0
% INFO    : Bus 37963	: V=0.9818811, theta=-39.031841 -> V=1.0, theta=0.0
% INFO    : Bus 37964	: V=0.9941504, theta=-38.025155 -> V=1.0, theta=0.0
% INFO    : Bus 37965	: V=0.9919919, theta=-38.216832 -> V=1.0, theta=0.0
% INFO    : Bus 37966	: V=0.9904106, theta=-38.359404 -> V=1.0, theta=0.0
% INFO    : Bus 37967	: V=0.9887962, theta=-38.482527 -> V=1.0, theta=0.0
% INFO    : Bus 37968	: V=0.982168, theta=-39.088089 -> V=1.0, theta=0.0
% INFO    : Bus 37969	: V=0.9865816, theta=-38.658795 -> V=1.0, theta=0.0
% INFO    : Bus 37970	: V=0.9873441, theta=-38.286583 -> V=1.0, theta=0.0
% INFO    : Bus 37971	: V=0.9796567, theta=-38.954075 -> V=1.0, theta=0.0
% INFO    : Bus 37972	: V=0.9778451, theta=-40.264055 -> V=1.0, theta=0.0
% INFO    : Bus 37973	: V=0.9843208, theta=-38.064744 -> V=1.0, theta=0.0
% INFO    : Bus 37974	: V=0.9889101, theta=-39.21912 -> V=1.0, theta=0.0
% INFO    : Bus 37975	: V=0.9895037, theta=-39.156149 -> V=1.0, theta=0.0
% INFO    : Bus 37976	: V=0.998441, theta=-27.558833 -> V=1.0, theta=0.0
% INFO    : Bus 37977	: V=0.9956935, theta=-26.964817 -> V=1.0, theta=0.0
% INFO    : Bus 37978	: V=0.9951703, theta=-27.167402 -> V=1.0, theta=0.0
% INFO    : Bus 37979	: V=0.9818298, theta=-29.618175 -> V=1.0, theta=0.0
% INFO    : Bus 37980	: V=0.9892654, theta=-29.163469 -> V=1.0, theta=0.0
% INFO    : Bus 37981	: V=0.9951319, theta=-27.307617 -> V=1.0, theta=0.0
% INFO    : Bus 37982	: V=0.9984583, theta=-27.307124 -> V=1.0, theta=0.0
% INFO    : Bus 37983	: V=0.9844577, theta=-27.780865 -> V=1.0, theta=0.0
% INFO    : Bus 37984	: V=1.0158078, theta=-27.155181 -> V=1.0, theta=0.0
% INFO    : Bus 37985	: V=0.9699413, theta=-25.246663 -> V=1.0, theta=0.0
% INFO    : Bus 37986	: V=0.9710626, theta=-24.614199 -> V=1.0, theta=0.0
% INFO    : Bus 37987	: V=0.9911915, theta=-23.7337 -> V=1.0, theta=0.0
% INFO    : Bus 37988	: V=0.9941438, theta=-23.435368 -> V=1.0, theta=0.0
% INFO    : Bus 37989	: V=0.9923788, theta=-23.773691 -> V=1.0, theta=0.0
% INFO    : Bus 37990	: V=0.9975662, theta=-51.678114 -> V=1.0, theta=0.0
% INFO    : Bus 37991	: V=0.9969351, theta=-51.846545 -> V=1.0, theta=0.0
% INFO    : Bus 37992	: V=1.0005472, theta=-52.261148 -> V=1.0, theta=0.0
% INFO    : Bus 37993	: V=0.9992675, theta=-52.78516 -> V=1.0, theta=0.0
% INFO    : Bus 37994	: V=0.9989963, theta=-53.075483 -> V=1.0, theta=0.0
% INFO    : Bus 37995	: V=0.9991759, theta=-53.268665 -> V=1.0, theta=0.0
% INFO    : Bus 37996	: V=0.99882, theta=-52.512735 -> V=1.0, theta=0.0
% INFO    : Bus 37997	: V=0.9992014, theta=-52.561951 -> V=1.0, theta=0.0
% INFO    : Bus 37998	: V=0.9988099, theta=-52.513489 -> V=1.0, theta=0.0
% INFO    : Bus 37999	: V=0.9987033, theta=-52.419725 -> V=1.0, theta=0.0
% INFO    : Bus 38000	: V=1.00016, theta=-52.101149 -> V=1.0, theta=0.0
% INFO    : Bus 38001	: V=0.9986121, theta=-52.324284 -> V=1.0, theta=0.0
% INFO    : Bus 38002	: V=0.9846104, theta=-53.337857 -> V=1.0, theta=0.0
% INFO    : Bus 38003	: V=0.999434, theta=-52.122309 -> V=1.0, theta=0.0
% INFO    : Bus 38004	: V=1.0079685, theta=-50.84819 -> V=1.0, theta=0.0
% INFO    : Bus 38005	: V=0.9988556, theta=-51.702094 -> V=1.0, theta=0.0
% INFO    : Bus 38006	: V=1.0002381, theta=-51.688446 -> V=1.0, theta=0.0
% INFO    : Bus 38007	: V=1.0105569, theta=-51.015953 -> V=1.0, theta=0.0
% INFO    : Bus 38008	: V=1.0020868, theta=-51.733328 -> V=1.0, theta=0.0
% INFO    : Bus 38009	: V=1.0007257, theta=-51.704477 -> V=1.0, theta=0.0
% INFO    : Bus 38010	: V=1.0017749, theta=-51.689577 -> V=1.0, theta=0.0
% INFO    : Bus 38011	: V=1.0139334, theta=-50.727106 -> V=1.0, theta=0.0
% INFO    : Bus 38012	: V=1.015186, theta=-50.64017 -> V=1.0, theta=0.0
% INFO    : Bus 38013	: V=1.000523, theta=-51.735008 -> V=1.0, theta=0.0
% INFO    : Bus 38014	: V=0.9996443, theta=-51.742743 -> V=1.0, theta=0.0
% INFO    : Bus 38015	: V=1.0163639, theta=-50.564523 -> V=1.0, theta=0.0
% INFO    : Bus 38016	: V=1.0102273, theta=-51.098857 -> V=1.0, theta=0.0
% INFO    : Bus 38017	: V=1.0006996, theta=-51.891526 -> V=1.0, theta=0.0
% INFO    : Bus 38018	: V=0.9975198, theta=-43.82342 -> V=1.0, theta=0.0
% INFO    : Bus 38019	: V=1.002098, theta=-44.225923 -> V=1.0, theta=0.0
% INFO    : Bus 38020	: V=0.9860799, theta=-45.943518 -> V=1.0, theta=0.0
% INFO    : Bus 38021	: V=0.9969491, theta=-44.494713 -> V=1.0, theta=0.0
% INFO    : Bus 38022	: V=0.9696213, theta=-44.696572 -> V=1.0, theta=0.0
% INFO    : Bus 38023	: V=0.9665185, theta=-44.951163 -> V=1.0, theta=0.0
% INFO    : Bus 38024	: V=1.0126594, theta=-44.746484 -> V=1.0, theta=0.0
% INFO    : Bus 38025	: V=1.0009166, theta=-47.619902 -> V=1.0, theta=0.0
% INFO    : Bus 38026	: V=1.0106738, theta=-45.797884 -> V=1.0, theta=0.0
% INFO    : Bus 38027	: V=0.9987374, theta=-45.27589 -> V=1.0, theta=0.0
% INFO    : Bus 38028	: V=1.0006802, theta=-45.280888 -> V=1.0, theta=0.0
% INFO    : Bus 38029	: V=0.9666962, theta=-48.096109 -> V=1.0, theta=0.0
% INFO    : Bus 38030	: V=0.9734081, theta=-48.01142 -> V=1.0, theta=0.0
% INFO    : Bus 38031	: V=0.9879235, theta=-46.296019 -> V=1.0, theta=0.0
% INFO    : Bus 38032	: V=0.9997214, theta=-45.461868 -> V=1.0, theta=0.0
% INFO    : Bus 38033	: V=1.0005628, theta=-45.51241 -> V=1.0, theta=0.0
% INFO    : Bus 38034	: V=1.0026486, theta=-45.571888 -> V=1.0, theta=0.0
% INFO    : Bus 38035	: V=0.999338, theta=-45.638394 -> V=1.0, theta=0.0
% INFO    : Bus 38036	: V=0.997245, theta=-45.511058 -> V=1.0, theta=0.0
% INFO    : Bus 38037	: V=1.0005833, theta=-46.303452 -> V=1.0, theta=0.0
% INFO    : Bus 38038	: V=1.0091, theta=-45.429262 -> V=1.0, theta=0.0
% INFO    : Bus 38039	: V=1.0181219, theta=-45.57633 -> V=1.0, theta=0.0
% INFO    : Bus 38040	: V=1.0163567, theta=-46.630332 -> V=1.0, theta=0.0
% INFO    : Bus 38041	: V=1.0111559, theta=-23.9877 -> V=1.0, theta=0.0
% INFO    : Bus 38042	: V=1.0082781, theta=-24.659845 -> V=1.0, theta=0.0
% INFO    : Bus 38043	: V=0.9963616, theta=-24.442098 -> V=1.0, theta=0.0
% INFO    : Bus 38044	: V=0.9839648, theta=-25.500248 -> V=1.0, theta=0.0
% INFO    : Bus 38045	: V=0.9951917, theta=-24.5946 -> V=1.0, theta=0.0
% INFO    : Bus 38046	: V=0.9954746, theta=-24.581064 -> V=1.0, theta=0.0
% INFO    : Bus 38047	: V=0.98567, theta=-25.483277 -> V=1.0, theta=0.0
% INFO    : Bus 38048	: V=0.9972522, theta=-24.473646 -> V=1.0, theta=0.0
% INFO    : Bus 38049	: V=0.9985548, theta=-24.414009 -> V=1.0, theta=0.0
% INFO    : Bus 38050	: V=0.9767422, theta=-25.668418 -> V=1.0, theta=0.0
% INFO    : Bus 38051	: V=0.9937561, theta=-24.788511 -> V=1.0, theta=0.0
% INFO    : Bus 38052	: V=0.9955261, theta=-24.544136 -> V=1.0, theta=0.0
% INFO    : Bus 38053	: V=0.9984094, theta=-49.034036 -> V=1.0, theta=0.0
% INFO    : Bus 38054	: V=1.0175382, theta=-49.138769 -> V=1.0, theta=0.0
% INFO    : Bus 38055	: V=1.0152678, theta=-49.098717 -> V=1.0, theta=0.0
% INFO    : Bus 38056	: V=1.0171541, theta=-49.274621 -> V=1.0, theta=0.0
% INFO    : Bus 38057	: V=1.0146693, theta=-49.021933 -> V=1.0, theta=0.0
% INFO    : Bus 38058	: V=1.0096218, theta=-50.140581 -> V=1.0, theta=0.0
% INFO    : Bus 38059	: V=1.0049101, theta=-50.223231 -> V=1.0, theta=0.0
% INFO    : Bus 38060	: V=0.9823104, theta=-53.347193 -> V=1.0, theta=0.0
% INFO    : Bus 38061	: V=0.9729475, theta=-39.460294 -> V=1.0, theta=0.0
% INFO    : Bus 38062	: V=0.9723582, theta=-39.316305 -> V=1.0, theta=0.0
% INFO    : Bus 38063	: V=0.9713335, theta=-39.253561 -> V=1.0, theta=0.0
% INFO    : Bus 38064	: V=0.9812861, theta=-39.736101 -> V=1.0, theta=0.0
% INFO    : Bus 38065	: V=0.9837114, theta=-40.019747 -> V=1.0, theta=0.0
% INFO    : Bus 38066	: V=0.9726119, theta=-39.596093 -> V=1.0, theta=0.0
% INFO    : Bus 38067	: V=0.9668525, theta=-38.900254 -> V=1.0, theta=0.0
% INFO    : Bus 38068	: V=0.9658936, theta=-38.457802 -> V=1.0, theta=0.0
% INFO    : Bus 38069	: V=0.9719521, theta=-39.103838 -> V=1.0, theta=0.0
% INFO    : Bus 38070	: V=0.9721935, theta=-38.697596 -> V=1.0, theta=0.0
% INFO    : Bus 38071	: V=0.9708793, theta=-37.087721 -> V=1.0, theta=0.0
% INFO    : Bus 38072	: V=0.9821167, theta=-29.697894 -> V=1.0, theta=0.0
% INFO    : Bus 38073	: V=0.9673946, theta=-36.766953 -> V=1.0, theta=0.0
% INFO    : Bus 38074	: V=0.9775181, theta=-40.614002 -> V=1.0, theta=0.0
% INFO    : Bus 38075	: V=0.9923979, theta=-40.70535 -> V=1.0, theta=0.0
% INFO    : Bus 38076	: V=0.9898386, theta=-40.030948 -> V=1.0, theta=0.0
% INFO    : Bus 38077	: V=0.9852317, theta=-38.711568 -> V=1.0, theta=0.0
% INFO    : Bus 38078	: V=0.9803671, theta=-39.558684 -> V=1.0, theta=0.0
% INFO    : Bus 38079	: V=0.9830442, theta=-40.042297 -> V=1.0, theta=0.0
% INFO    : Bus 38080	: V=1.01736, theta=-44.901835 -> V=1.0, theta=0.0
% INFO    : Bus 38081	: V=1.0073966, theta=-45.2794 -> V=1.0, theta=0.0
% INFO    : Bus 38082	: V=0.9643578, theta=-48.294313 -> V=1.0, theta=0.0
% INFO    : Bus 38083	: V=0.9817013, theta=-29.665219 -> V=1.0, theta=0.0
% INFO    : Bus 38084	: V=0.9624068, theta=-32.227401 -> V=1.0, theta=0.0
% INFO    : Bus 38085	: V=0.9673064, theta=-34.043082 -> V=1.0, theta=0.0
% INFO    : Bus 38086	: V=0.9750211, theta=-31.815992 -> V=1.0, theta=0.0
% INFO    : Bus 38087	: V=0.9862977, theta=-29.957556 -> V=1.0, theta=0.0
% INFO    : Bus 38088	: V=0.9926657, theta=-23.977402 -> V=1.0, theta=0.0
% INFO    : Bus 38089	: V=0.9949428, theta=-23.767154 -> V=1.0, theta=0.0
% INFO    : Bus 38090	: V=0.9922329, theta=-24.076689 -> V=1.0, theta=0.0
% INFO    : Bus 38091	: V=0.9940271, theta=-23.832925 -> V=1.0, theta=0.0
% INFO    : Bus 38092	: V=0.9817242, theta=-24.419618 -> V=1.0, theta=0.0
% INFO    : Bus 38093	: V=0.9942468, theta=-23.762371 -> V=1.0, theta=0.0
% INFO    : Bus 38094	: V=0.9899332, theta=-24.178275 -> V=1.0, theta=0.0
% INFO    : Bus 38095	: V=0.9933518, theta=-24.09115 -> V=1.0, theta=0.0
% INFO    : Bus 38096	: V=0.9940779, theta=-23.836582 -> V=1.0, theta=0.0
% INFO    : Bus 38097	: V=0.9889695, theta=-24.187241 -> V=1.0, theta=0.0
% INFO    : Bus 38098	: V=0.992638, theta=-24.100885 -> V=1.0, theta=0.0
% INFO    : Bus 38099	: V=1.0019714, theta=-23.097112 -> V=1.0, theta=0.0
% INFO    : Bus 38100	: V=0.9926722, theta=-24.031442 -> V=1.0, theta=0.0
% INFO    : Bus 38101	: V=0.9901046, theta=-24.105805 -> V=1.0, theta=0.0
% INFO    : Bus 38102	: V=0.9918623, theta=-24.092899 -> V=1.0, theta=0.0
% INFO    : Bus 38103	: V=0.993591, theta=-23.915576 -> V=1.0, theta=0.0
% INFO    : Bus 38104	: V=0.9942128, theta=-23.869782 -> V=1.0, theta=0.0
% INFO    : Bus 38105	: V=0.9901536, theta=-23.872865 -> V=1.0, theta=0.0
% INFO    : Bus 38106	: V=0.9886853, theta=-24.189822 -> V=1.0, theta=0.0
% INFO    : Bus 38107	: V=0.9816816, theta=-27.729369 -> V=1.0, theta=0.0
% INFO    : Bus 38108	: V=0.9874189, theta=-27.290438 -> V=1.0, theta=0.0
% INFO    : Bus 38109	: V=0.9908247, theta=-27.477046 -> V=1.0, theta=0.0
% INFO    : Bus 38110	: V=0.9875257, theta=-27.608358 -> V=1.0, theta=0.0
% INFO    : Bus 38111	: V=0.9867394, theta=-27.530158 -> V=1.0, theta=0.0
% INFO    : Bus 38112	: V=0.983906, theta=-28.210427 -> V=1.0, theta=0.0
% INFO    : Bus 38113	: V=0.9870158, theta=-27.580639 -> V=1.0, theta=0.0
% INFO    : Bus 38114	: V=0.9868999, theta=-27.537183 -> V=1.0, theta=0.0
% INFO    : Bus 38115	: V=0.9575129, theta=-47.486768 -> V=1.0, theta=0.0
% INFO    : Bus 38116	: V=0.9421354, theta=-47.548125 -> V=1.0, theta=0.0
% INFO    : Bus 38117	: V=0.9322969, theta=-48.50418 -> V=1.0, theta=0.0
% INFO    : Bus 38118	: V=0.948096, theta=-46.411441 -> V=1.0, theta=0.0
% INFO    : Bus 38119	: V=0.9446587, theta=-47.579015 -> V=1.0, theta=0.0
% INFO    : Bus 38120	: V=0.9411522, theta=-47.880153 -> V=1.0, theta=0.0
% INFO    : Bus 38121	: V=1.0145618, theta=-20.822569 -> V=1.0, theta=0.0
% INFO    : Bus 38122	: V=1.0120537, theta=-21.189697 -> V=1.0, theta=0.0
% INFO    : Bus 38123	: V=1.0113289, theta=-21.293248 -> V=1.0, theta=0.0
% INFO    : Bus 38124	: V=1.0043761, theta=-22.440597 -> V=1.0, theta=0.0
% INFO    : Bus 38125	: V=1.0065924, theta=-22.213028 -> V=1.0, theta=0.0
% INFO    : Bus 38126	: V=1.0032882, theta=-23.537137 -> V=1.0, theta=0.0
% INFO    : Bus 38127	: V=0.9894055, theta=-24.651786 -> V=1.0, theta=0.0
% INFO    : Bus 38128	: V=1.0134026, theta=-22.219863 -> V=1.0, theta=0.0
% INFO    : Bus 38129	: V=1.0129093, theta=-22.304558 -> V=1.0, theta=0.0
% INFO    : Bus 38130	: V=1.0148341, theta=-22.292462 -> V=1.0, theta=0.0
% INFO    : Bus 38131	: V=1.0136675, theta=-21.511581 -> V=1.0, theta=0.0
% INFO    : Bus 38132	: V=1.0132821, theta=-21.520166 -> V=1.0, theta=0.0
% INFO    : Bus 38133	: V=1.0145896, theta=-21.445223 -> V=1.0, theta=0.0
% INFO    : Bus 38134	: V=1.0137355, theta=-22.790972 -> V=1.0, theta=0.0
% INFO    : Bus 38135	: V=1.0079155, theta=-37.331167 -> V=1.0, theta=0.0
% INFO    : Bus 38136	: V=0.9948611, theta=-38.989397 -> V=1.0, theta=0.0
% INFO    : Bus 38137	: V=1.0022924, theta=-38.218199 -> V=1.0, theta=0.0
% INFO    : Bus 38138	: V=0.9954746, theta=-38.981618 -> V=1.0, theta=0.0
% INFO    : Bus 38139	: V=0.9880451, theta=-39.21827 -> V=1.0, theta=0.0
% INFO    : Bus 38140	: V=0.9887253, theta=-39.211996 -> V=1.0, theta=0.0
% INFO    : Bus 38141	: V=1.0077554, theta=-36.415066 -> V=1.0, theta=0.0
% INFO    : Bus 38142	: V=1.0083969, theta=-37.199586 -> V=1.0, theta=0.0
% INFO    : Bus 38143	: V=1.0088862, theta=-37.089922 -> V=1.0, theta=0.0
% INFO    : Bus 38144	: V=1.0095238, theta=-36.98251 -> V=1.0, theta=0.0
% INFO    : Bus 38145	: V=1.0040218, theta=-37.812186 -> V=1.0, theta=0.0
% INFO    : Bus 38146	: V=1.0055819, theta=-37.793918 -> V=1.0, theta=0.0
% INFO    : Bus 38147	: V=0.9968385, theta=-37.81506 -> V=1.0, theta=0.0
% INFO    : Bus 38148	: V=0.99332, theta=-32.523814 -> V=1.0, theta=0.0
% INFO    : Bus 38149	: V=1.0063909, theta=-35.696276 -> V=1.0, theta=0.0
% INFO    : Bus 38150	: V=1.0054509, theta=-35.135807 -> V=1.0, theta=0.0
% INFO    : Bus 38151	: V=1.0056752, theta=-34.694441 -> V=1.0, theta=0.0
% INFO    : Bus 38152	: V=1.0056158, theta=-35.314466 -> V=1.0, theta=0.0
% INFO    : Bus 38153	: V=1.0031776, theta=-35.497069 -> V=1.0, theta=0.0
% INFO    : Bus 38154	: V=1.0032531, theta=-32.760053 -> V=1.0, theta=0.0
% INFO    : Bus 38155	: V=1.0034045, theta=-29.655482 -> V=1.0, theta=0.0
% INFO    : Bus 38156	: V=1.0006614, theta=-47.108478 -> V=1.0, theta=0.0
% INFO    : Bus 38157	: V=0.9673454, theta=-49.668246 -> V=1.0, theta=0.0
% INFO    : Bus 38158	: V=0.9812671, theta=-49.326623 -> V=1.0, theta=0.0
% INFO    : Bus 38159	: V=0.9934636, theta=-47.717619 -> V=1.0, theta=0.0
% INFO    : Bus 38160	: V=0.9779902, theta=-50.594754 -> V=1.0, theta=0.0
% INFO    : Bus 38161	: V=0.9636407, theta=-51.877169 -> V=1.0, theta=0.0
% INFO    : Bus 38162	: V=0.9688748, theta=-26.741356 -> V=1.0, theta=0.0
% INFO    : Bus 38163	: V=0.9716982, theta=-27.376288 -> V=1.0, theta=0.0
% INFO    : Bus 38164	: V=0.9842874, theta=-25.667019 -> V=1.0, theta=0.0
% INFO    : Bus 38165	: V=0.9814804, theta=-25.990379 -> V=1.0, theta=0.0
% INFO    : Bus 38166	: V=0.9906517, theta=-25.127497 -> V=1.0, theta=0.0
% INFO    : Bus 38167	: V=0.9926444, theta=-24.947253 -> V=1.0, theta=0.0
% INFO    : Bus 38168	: V=0.9595177, theta=-25.250683 -> V=1.0, theta=0.0
% INFO    : Bus 38169	: V=0.9856031, theta=-24.011899 -> V=1.0, theta=0.0
% INFO    : Bus 38170	: V=0.9714267, theta=-25.15237 -> V=1.0, theta=0.0
% INFO    : Bus 38171	: V=0.9834367, theta=-24.010935 -> V=1.0, theta=0.0
% INFO    : Bus 38172	: V=0.9957422, theta=-23.028766 -> V=1.0, theta=0.0
% INFO    : Bus 38173	: V=0.9869324, theta=-23.818593 -> V=1.0, theta=0.0
% INFO    : Bus 38174	: V=0.9684673, theta=-25.273379 -> V=1.0, theta=0.0
% INFO    : Bus 38175	: V=0.9720134, theta=-24.80763 -> V=1.0, theta=0.0
% INFO    : Bus 38176	: V=0.9894685, theta=-23.329945 -> V=1.0, theta=0.0
% INFO    : Bus 38177	: V=1.0014055, theta=-24.787532 -> V=1.0, theta=0.0
% INFO    : Bus 38178	: V=1.0093126, theta=-23.878605 -> V=1.0, theta=0.0
% INFO    : Bus 38179	: V=1.000755, theta=-25.382649 -> V=1.0, theta=0.0
% INFO    : Bus 38180	: V=0.9976882, theta=-25.880463 -> V=1.0, theta=0.0
% INFO    : Bus 38181	: V=0.9747031, theta=-29.477599 -> V=1.0, theta=0.0
% INFO    : Bus 38182	: V=0.9918113, theta=-26.582501 -> V=1.0, theta=0.0
% INFO    : Bus 38183	: V=0.9750006, theta=-30.362874 -> V=1.0, theta=0.0
% INFO    : Bus 38184	: V=0.9640901, theta=-30.617228 -> V=1.0, theta=0.0
% INFO    : Bus 38185	: V=0.9586275, theta=-34.137192 -> V=1.0, theta=0.0
% INFO    : Bus 38186	: V=0.9764914, theta=-29.581315 -> V=1.0, theta=0.0
% INFO    : Bus 38187	: V=0.9747171, theta=-40.961281 -> V=1.0, theta=0.0
% INFO    : Bus 38188	: V=0.9574292, theta=-38.115212 -> V=1.0, theta=0.0
% INFO    : Bus 38189	: V=0.9726036, theta=-41.281375 -> V=1.0, theta=0.0
% INFO    : Bus 38190	: V=0.9692025, theta=-42.652871 -> V=1.0, theta=0.0
% INFO    : Bus 38191	: V=0.9657196, theta=-42.115476 -> V=1.0, theta=0.0
% INFO    : Bus 38192	: V=1.0039944, theta=-24.093899 -> V=1.0, theta=0.0
% INFO    : Bus 38193	: V=1.0037724, theta=-23.868919 -> V=1.0, theta=0.0
% INFO    : Bus 38194	: V=0.9899406, theta=-25.331984 -> V=1.0, theta=0.0
% INFO    : Bus 38195	: V=1.0167284, theta=-21.026208 -> V=1.0, theta=0.0
% INFO    : Bus 38196	: V=1.0174538, theta=-20.832795 -> V=1.0, theta=0.0
% INFO    : Bus 38197	: V=1.0170708, theta=-20.957695 -> V=1.0, theta=0.0
% INFO    : Bus 38198	: V=1.0202042, theta=-20.363685 -> V=1.0, theta=0.0
% INFO    : Bus 38199	: V=1.0164846, theta=-21.148719 -> V=1.0, theta=0.0
% INFO    : Bus 38200	: V=1.0102239, theta=-21.632655 -> V=1.0, theta=0.0
% INFO    : Bus 38201	: V=1.020351, theta=-20.429602 -> V=1.0, theta=0.0
% INFO    : Bus 38202	: V=1.0124593, theta=-21.986835 -> V=1.0, theta=0.0
% INFO    : Bus 38203	: V=0.9984242, theta=-24.227261 -> V=1.0, theta=0.0
% INFO    : Bus 38204	: V=0.9966747, theta=-24.453161 -> V=1.0, theta=0.0
% INFO    : Bus 38205	: V=1.0065423, theta=-23.852747 -> V=1.0, theta=0.0
% INFO    : Bus 38206	: V=1.0053311, theta=-23.560286 -> V=1.0, theta=0.0
% INFO    : Bus 38207	: V=1.0036338, theta=-22.830126 -> V=1.0, theta=0.0
% INFO    : Bus 38208	: V=1.0201899, theta=-22.61664 -> V=1.0, theta=0.0
% INFO    : Bus 38209	: V=0.9779723, theta=-54.735901 -> V=1.0, theta=0.0
% INFO    : Bus 38210	: V=0.955592, theta=-57.652559 -> V=1.0, theta=0.0
% INFO    : Bus 38211	: V=0.9671394, theta=-55.350013 -> V=1.0, theta=0.0
% INFO    : Bus 38212	: V=0.9447296, theta=-60.353021 -> V=1.0, theta=0.0
% INFO    : Bus 38213	: V=0.9417776, theta=-59.836014 -> V=1.0, theta=0.0
% INFO    : Bus 38214	: V=0.9438758, theta=-61.727421 -> V=1.0, theta=0.0
% INFO    : Bus 38215	: V=0.9456873, theta=-59.470728 -> V=1.0, theta=0.0
% INFO    : Bus 38216	: V=0.9457313, theta=-61.284353 -> V=1.0, theta=0.0
% INFO    : Bus 38217	: V=0.9600192, theta=-59.203306 -> V=1.0, theta=0.0
% INFO    : Bus 38218	: V=1.0091439, theta=-49.566682 -> V=1.0, theta=0.0
% INFO    : Bus 38219	: V=1.0121299, theta=-50.349376 -> V=1.0, theta=0.0
% INFO    : Bus 38220	: V=1.0030709, theta=-51.005577 -> V=1.0, theta=0.0
% INFO    : Bus 38221	: V=0.9390833, theta=-49.935573 -> V=1.0, theta=0.0
% INFO    : Bus 38222	: V=0.9432076, theta=-47.154863 -> V=1.0, theta=0.0
% INFO    : Bus 38223	: V=0.9354563, theta=-49.442256 -> V=1.0, theta=0.0
% INFO    : Bus 38224	: V=0.9364023, theta=-49.365075 -> V=1.0, theta=0.0
% INFO    : Bus 38225	: V=0.9416466, theta=-47.373906 -> V=1.0, theta=0.0
% INFO    : Bus 38226	: V=0.9389653, theta=-49.650717 -> V=1.0, theta=0.0
% INFO    : Bus 38227	: V=0.9504849, theta=-47.520905 -> V=1.0, theta=0.0
% INFO    : Bus 38228	: V=0.9399375, theta=-49.722628 -> V=1.0, theta=0.0
% INFO    : Bus 38229	: V=0.9912841, theta=-24.28256 -> V=1.0, theta=0.0
% INFO    : Bus 38230	: V=0.9690816, theta=-26.040844 -> V=1.0, theta=0.0
% INFO    : Bus 38231	: V=0.9921809, theta=-24.483127 -> V=1.0, theta=0.0
% INFO    : Bus 38232	: V=0.9894252, theta=-24.447969 -> V=1.0, theta=0.0
% INFO    : Bus 38233	: V=0.9911577, theta=-24.197245 -> V=1.0, theta=0.0
% INFO    : Bus 38234	: V=0.9879311, theta=-24.78305 -> V=1.0, theta=0.0
% INFO    : Bus 38235	: V=1.0100386, theta=-21.699886 -> V=1.0, theta=0.0
% INFO    : Bus 38236	: V=1.0029713, theta=-23.016017 -> V=1.0, theta=0.0
% INFO    : Bus 38237	: V=1.0102047, theta=-22.016705 -> V=1.0, theta=0.0
% INFO    : Bus 38238	: V=0.9638977, theta=-25.439652 -> V=1.0, theta=0.0
% INFO    : Bus 38239	: V=0.9962299, theta=-23.670417 -> V=1.0, theta=0.0
% INFO    : Bus 38240	: V=1.0084383, theta=-23.159894 -> V=1.0, theta=0.0
% INFO    : Bus 38241	: V=1.0179071, theta=-23.454528 -> V=1.0, theta=0.0
% INFO    : Bus 38242	: V=1.0192908, theta=-23.655251 -> V=1.0, theta=0.0
% INFO    : Bus 38243	: V=0.9619628, theta=-39.336734 -> V=1.0, theta=0.0
% INFO    : Bus 38244	: V=0.9701604, theta=-41.022528 -> V=1.0, theta=0.0
% INFO    : Bus 38245	: V=0.96635, theta=-40.494808 -> V=1.0, theta=0.0
% INFO    : Bus 38246	: V=0.9719432, theta=-40.785212 -> V=1.0, theta=0.0
% INFO    : Bus 38247	: V=0.9676787, theta=-41.129761 -> V=1.0, theta=0.0
% INFO    : Bus 38248	: V=0.9668473, theta=-40.333381 -> V=1.0, theta=0.0
% INFO    : Bus 38249	: V=0.9635045, theta=-40.065321 -> V=1.0, theta=0.0
% INFO    : Bus 38250	: V=0.9702065, theta=-40.343068 -> V=1.0, theta=0.0
% INFO    : Bus 38251	: V=0.9660122, theta=-40.34371 -> V=1.0, theta=0.0
% INFO    : Bus 38252	: V=0.9652062, theta=-41.304687 -> V=1.0, theta=0.0
% INFO    : Bus 38253	: V=0.9716199, theta=-40.698306 -> V=1.0, theta=0.0
% INFO    : Bus 38254	: V=1.000807, theta=-38.224021 -> V=1.0, theta=0.0
% INFO    : Bus 38255	: V=0.9833726, theta=-38.9643 -> V=1.0, theta=0.0
% INFO    : Bus 38256	: V=0.984221, theta=-38.661267 -> V=1.0, theta=0.0
% INFO    : Bus 38257	: V=0.9637497, theta=-41.344879 -> V=1.0, theta=0.0
% INFO    : Bus 38258	: V=0.9697398, theta=-40.901573 -> V=1.0, theta=0.0
% INFO    : Bus 38259	: V=0.9767705, theta=-40.287053 -> V=1.0, theta=0.0
% INFO    : Bus 38260	: V=0.9669059, theta=-40.92882 -> V=1.0, theta=0.0
% INFO    : Bus 38261	: V=0.9728662, theta=-40.646587 -> V=1.0, theta=0.0
% INFO    : Bus 38262	: V=0.9616426, theta=-41.491143 -> V=1.0, theta=0.0
% INFO    : Bus 38263	: V=0.957872, theta=-41.688155 -> V=1.0, theta=0.0
% INFO    : Bus 38264	: V=0.9562236, theta=-41.713898 -> V=1.0, theta=0.0
% INFO    : Bus 38265	: V=0.9471215, theta=-43.338775 -> V=1.0, theta=0.0
% INFO    : Bus 38266	: V=0.967217, theta=-41.756447 -> V=1.0, theta=0.0
% INFO    : Bus 38267	: V=0.960122, theta=-42.768525 -> V=1.0, theta=0.0
% INFO    : Bus 38268	: V=0.9663745, theta=-42.467448 -> V=1.0, theta=0.0
% INFO    : Bus 38269	: V=0.9748297, theta=-40.513408 -> V=1.0, theta=0.0
% INFO    : Bus 38270	: V=0.9466244, theta=-39.775348 -> V=1.0, theta=0.0
% INFO    : Bus 38271	: V=0.9588947, theta=-34.155329 -> V=1.0, theta=0.0
% INFO    : Bus 38272	: V=0.950665, theta=-42.41854 -> V=1.0, theta=0.0
% INFO    : Bus 38273	: V=0.9470702, theta=-42.6114 -> V=1.0, theta=0.0
% INFO    : Bus 38274	: V=0.9534535, theta=-42.014953 -> V=1.0, theta=0.0
% INFO    : Bus 38275	: V=0.9753984, theta=-42.181437 -> V=1.0, theta=0.0
% INFO    : Bus 38276	: V=1.0062821, theta=-27.252119 -> V=1.0, theta=0.0
% INFO    : Bus 38277	: V=1.0070935, theta=-27.03616 -> V=1.0, theta=0.0
% INFO    : Bus 38278	: V=0.9704283, theta=-45.546878 -> V=1.0, theta=0.0
% INFO    : Bus 38279	: V=0.9654316, theta=-44.916403 -> V=1.0, theta=0.0
% INFO    : Bus 38280	: V=0.968049, theta=-43.891234 -> V=1.0, theta=0.0
% INFO    : Bus 38281	: V=1.003228, theta=-44.862077 -> V=1.0, theta=0.0
% INFO    : Bus 38282	: V=0.9999814, theta=-44.886252 -> V=1.0, theta=0.0
% INFO    : Bus 38283	: V=0.9923217, theta=-43.276867 -> V=1.0, theta=0.0
% INFO    : Bus 38284	: V=1.0035523, theta=-44.612959 -> V=1.0, theta=0.0
% INFO    : Bus 38285	: V=1.0031303, theta=-44.84892 -> V=1.0, theta=0.0
% INFO    : Bus 38286	: V=0.9844458, theta=-53.731219 -> V=1.0, theta=0.0
% INFO    : Bus 38287	: V=0.9851699, theta=-53.459033 -> V=1.0, theta=0.0
% INFO    : Bus 38288	: V=0.985802, theta=-53.936582 -> V=1.0, theta=0.0
% INFO    : Bus 38289	: V=1.0281028, theta=-24.319607 -> V=1.0, theta=0.0
% INFO    : Bus 38290	: V=1.0115786, theta=-25.046824 -> V=1.0, theta=0.0
% INFO    : Bus 38291	: V=1.006919, theta=-25.416703 -> V=1.0, theta=0.0
% INFO    : Bus 38292	: V=0.9989678, theta=-26.559281 -> V=1.0, theta=0.0
% INFO    : Bus 38293	: V=0.9982279, theta=-26.68743 -> V=1.0, theta=0.0
% INFO    : Bus 38294	: V=0.9962214, theta=-27.178774 -> V=1.0, theta=0.0
% INFO    : Bus 38295	: V=1.0018536, theta=-26.845576 -> V=1.0, theta=0.0
% INFO    : Bus 38296	: V=0.9957378, theta=-25.530667 -> V=1.0, theta=0.0
% INFO    : Bus 38297	: V=0.9947698, theta=-25.645681 -> V=1.0, theta=0.0
% INFO    : Bus 38298	: V=1.0219454, theta=-23.995157 -> V=1.0, theta=0.0
% INFO    : Bus 38299	: V=0.9910043, theta=-26.497138 -> V=1.0, theta=0.0
% INFO    : Bus 38300	: V=0.9783008, theta=-26.562197 -> V=1.0, theta=0.0
% INFO    : Bus 38301	: V=0.9861879, theta=-26.08902 -> V=1.0, theta=0.0
% INFO    : Bus 38302	: V=0.9934202, theta=-25.067899 -> V=1.0, theta=0.0
% INFO    : Bus 38303	: V=0.9944396, theta=-24.838403 -> V=1.0, theta=0.0
% INFO    : Bus 38304	: V=1.0059847, theta=-24.40285 -> V=1.0, theta=0.0
% INFO    : Bus 38305	: V=0.9959233, theta=-24.142812 -> V=1.0, theta=0.0
% INFO    : Bus 38306	: V=1.0005309, theta=-23.744147 -> V=1.0, theta=0.0
% INFO    : Bus 38307	: V=1.0022252, theta=-23.634915 -> V=1.0, theta=0.0
% INFO    : Bus 38308	: V=1.0049203, theta=-23.456708 -> V=1.0, theta=0.0
% INFO    : Bus 38309	: V=1.0121358, theta=-21.803359 -> V=1.0, theta=0.0
% INFO    : Bus 38310	: V=1.0092849, theta=-21.701499 -> V=1.0, theta=0.0
% INFO    : Bus 38311	: V=1.0072016, theta=-21.977341 -> V=1.0, theta=0.0
% INFO    : Bus 38312	: V=1.0107462, theta=-20.98334 -> V=1.0, theta=0.0
% INFO    : Bus 38313	: V=0.9944463, theta=-24.191835 -> V=1.0, theta=0.0
% INFO    : Bus 38314	: V=0.9721224, theta=-26.034226 -> V=1.0, theta=0.0
% INFO    : Bus 38315	: V=0.9718841, theta=-26.038136 -> V=1.0, theta=0.0
% INFO    : Bus 38316	: V=1.0174549, theta=-22.15404 -> V=1.0, theta=0.0
% INFO    : Bus 38317	: V=1.0001152, theta=-24.13858 -> V=1.0, theta=0.0
% INFO    : Bus 38318	: V=1.0023755, theta=-23.962114 -> V=1.0, theta=0.0
% INFO    : Bus 38319	: V=1.0071596, theta=-23.384778 -> V=1.0, theta=0.0
% INFO    : Bus 38320	: V=1.0019917, theta=-23.583276 -> V=1.0, theta=0.0
% INFO    : Bus 38321	: V=0.9927416, theta=-24.621462 -> V=1.0, theta=0.0
% INFO    : Bus 38322	: V=0.950283, theta=-49.978442 -> V=1.0, theta=0.0
% INFO    : Bus 38323	: V=0.9454224, theta=-53.317972 -> V=1.0, theta=0.0
% INFO    : Bus 38324	: V=0.949385, theta=-53.203239 -> V=1.0, theta=0.0
% INFO    : Bus 38325	: V=1.0236246, theta=-26.821817 -> V=1.0, theta=0.0
% INFO    : Bus 38326	: V=0.9775545, theta=-36.624582 -> V=1.0, theta=0.0
% INFO    : Bus 38327	: V=0.9796337, theta=-36.607332 -> V=1.0, theta=0.0
% INFO    : Bus 38328	: V=0.9940453, theta=-35.398746 -> V=1.0, theta=0.0
% INFO    : Bus 38329	: V=0.9824313, theta=-36.510284 -> V=1.0, theta=0.0
% INFO    : Bus 38330	: V=0.994535, theta=-35.336216 -> V=1.0, theta=0.0
% INFO    : Bus 38331	: V=0.9796784, theta=-36.576759 -> V=1.0, theta=0.0
% INFO    : Bus 38332	: V=1.0040948, theta=-32.924148 -> V=1.0, theta=0.0
% INFO    : Bus 38333	: V=0.9928211, theta=-35.843835 -> V=1.0, theta=0.0
% INFO    : Bus 38334	: V=0.9933904, theta=-35.654014 -> V=1.0, theta=0.0
% INFO    : Bus 38335	: V=0.9912862, theta=-36.14837 -> V=1.0, theta=0.0
% INFO    : Bus 38336	: V=0.9950079, theta=-35.195619 -> V=1.0, theta=0.0
% INFO    : Bus 38337	: V=1.0065234, theta=-26.149307 -> V=1.0, theta=0.0
% INFO    : Bus 38338	: V=1.0190184, theta=-24.012205 -> V=1.0, theta=0.0
% INFO    : Bus 38339	: V=1.0185604, theta=-23.891768 -> V=1.0, theta=0.0
% INFO    : Bus 38340	: V=1.0184711, theta=-23.86766 -> V=1.0, theta=0.0
% INFO    : Bus 38341	: V=1.0185106, theta=-23.804402 -> V=1.0, theta=0.0
% INFO    : Bus 38342	: V=1.0117789, theta=-24.851336 -> V=1.0, theta=0.0
% INFO    : Bus 38343	: V=1.019366, theta=-23.627999 -> V=1.0, theta=0.0
% INFO    : Bus 38344	: V=0.9905513, theta=-25.863983 -> V=1.0, theta=0.0
% INFO    : Bus 38345	: V=1.0122372, theta=-24.574063 -> V=1.0, theta=0.0
% INFO    : Bus 38346	: V=1.0183658, theta=-23.838846 -> V=1.0, theta=0.0
% INFO    : Bus 38347	: V=1.0184059, theta=-23.851282 -> V=1.0, theta=0.0
% INFO    : Bus 38348	: V=1.0116086, theta=-24.587069 -> V=1.0, theta=0.0
% INFO    : Bus 38349	: V=1.0000359, theta=-25.949394 -> V=1.0, theta=0.0
% INFO    : Bus 38350	: V=1.0108569, theta=-24.959801 -> V=1.0, theta=0.0
% INFO    : Bus 38351	: V=1.017171, theta=-24.18827 -> V=1.0, theta=0.0
% INFO    : Bus 38352	: V=1.0038674, theta=-25.886954 -> V=1.0, theta=0.0
% INFO    : Bus 38353	: V=1.0084062, theta=-25.573554 -> V=1.0, theta=0.0
% INFO    : Bus 38354	: V=1.0102112, theta=-26.064585 -> V=1.0, theta=0.0
% INFO    : Bus 38355	: V=1.0094865, theta=-26.083062 -> V=1.0, theta=0.0
% INFO    : Bus 38356	: V=0.9964288, theta=-44.597459 -> V=1.0, theta=0.0
% INFO    : Bus 38357	: V=0.9965178, theta=-45.327081 -> V=1.0, theta=0.0
% INFO    : Bus 38358	: V=0.9954273, theta=-45.048718 -> V=1.0, theta=0.0
% INFO    : Bus 38359	: V=0.9974617, theta=-46.502632 -> V=1.0, theta=0.0
% INFO    : Bus 38360	: V=0.9853468, theta=-24.257333 -> V=1.0, theta=0.0
% INFO    : Bus 38361	: V=1.0028881, theta=-23.76551 -> V=1.0, theta=0.0
% INFO    : Bus 38362	: V=1.0072517, theta=-22.765026 -> V=1.0, theta=0.0
% INFO    : Bus 38363	: V=0.9343559, theta=-47.87535 -> V=1.0, theta=0.0
% INFO    : Bus 38364	: V=0.9445548, theta=-47.495884 -> V=1.0, theta=0.0
% INFO    : Bus 38365	: V=1.0067089, theta=-23.41999 -> V=1.0, theta=0.0
% INFO    : Bus 38366	: V=1.0062743, theta=-24.309637 -> V=1.0, theta=0.0
% INFO    : Bus 38367	: V=1.0049561, theta=-24.159273 -> V=1.0, theta=0.0
% INFO    : Bus 38368	: V=1.0049526, theta=-24.009663 -> V=1.0, theta=0.0
% INFO    : Bus 38369	: V=0.9945611, theta=-25.067862 -> V=1.0, theta=0.0
% INFO    : Bus 38370	: V=0.9904776, theta=-25.457292 -> V=1.0, theta=0.0
% INFO    : Bus 38371	: V=0.9920879, theta=-25.069451 -> V=1.0, theta=0.0
% INFO    : Bus 38372	: V=0.990649, theta=-25.653271 -> V=1.0, theta=0.0
% INFO    : Bus 38373	: V=0.9960742, theta=-28.769245 -> V=1.0, theta=0.0
% INFO    : Bus 38374	: V=0.9891143, theta=-30.516627 -> V=1.0, theta=0.0
% INFO    : Bus 38375	: V=0.9982919, theta=-29.793083 -> V=1.0, theta=0.0
% INFO    : Bus 38376	: V=1.0062015, theta=-29.274789 -> V=1.0, theta=0.0
% INFO    : Bus 38377	: V=0.9992171, theta=-29.974663 -> V=1.0, theta=0.0
% INFO    : Bus 38378	: V=0.9952595, theta=-31.202197 -> V=1.0, theta=0.0
% INFO    : Bus 38379	: V=0.9920252, theta=-37.074438 -> V=1.0, theta=0.0
% INFO    : Bus 38380	: V=0.9928564, theta=-37.668567 -> V=1.0, theta=0.0
% INFO    : Bus 38381	: V=0.9863686, theta=-37.70617 -> V=1.0, theta=0.0
% INFO    : Bus 38382	: V=0.9674235, theta=-40.247598 -> V=1.0, theta=0.0
% INFO    : Bus 38383	: V=0.9659329, theta=-40.385217 -> V=1.0, theta=0.0
% INFO    : Bus 38384	: V=0.9910499, theta=-37.06806 -> V=1.0, theta=0.0
% INFO    : Bus 38385	: V=0.9921521, theta=-36.905762 -> V=1.0, theta=0.0
% INFO    : Bus 38386	: V=0.9793261, theta=-38.046767 -> V=1.0, theta=0.0
% INFO    : Bus 38387	: V=0.9731474, theta=-38.883628 -> V=1.0, theta=0.0
% INFO    : Bus 38388	: V=0.9518107, theta=-42.40025 -> V=1.0, theta=0.0
% INFO    : Bus 38389	: V=0.9606647, theta=-41.816905 -> V=1.0, theta=0.0
% INFO    : Bus 38390	: V=0.9854551, theta=-37.47941 -> V=1.0, theta=0.0
% INFO    : Bus 38391	: V=0.9853082, theta=-37.979079 -> V=1.0, theta=0.0
% INFO    : Bus 38392	: V=0.9774347, theta=-38.383207 -> V=1.0, theta=0.0
% INFO    : Bus 38393	: V=0.9821095, theta=-38.795635 -> V=1.0, theta=0.0
% INFO    : Bus 38394	: V=0.9914389, theta=-37.769037 -> V=1.0, theta=0.0
% INFO    : Bus 38395	: V=0.9870866, theta=-38.947815 -> V=1.0, theta=0.0
% INFO    : Bus 38396	: V=1.0058814, theta=-34.964678 -> V=1.0, theta=0.0
% INFO    : Bus 38397	: V=0.9585627, theta=-35.945751 -> V=1.0, theta=0.0
% INFO    : Bus 38398	: V=0.9539718, theta=-39.921932 -> V=1.0, theta=0.0
% INFO    : Bus 38399	: V=0.9533766, theta=-33.885834 -> V=1.0, theta=0.0
% INFO    : Bus 38400	: V=0.9542149, theta=-34.799227 -> V=1.0, theta=0.0
% INFO    : Bus 38401	: V=0.9547298, theta=-35.905331 -> V=1.0, theta=0.0
% INFO    : Bus 38402	: V=0.9437417, theta=-38.399317 -> V=1.0, theta=0.0
% INFO    : Bus 38403	: V=0.9603458, theta=-33.800245 -> V=1.0, theta=0.0
% INFO    : Bus 38404	: V=0.9604612, theta=-34.321106 -> V=1.0, theta=0.0
% INFO    : Bus 38405	: V=0.9608704, theta=-32.992553 -> V=1.0, theta=0.0
% INFO    : Bus 38406	: V=1.021788, theta=-12.679029 -> V=1.0, theta=0.0
% INFO    : Bus 38407	: V=1.0084439, theta=-14.901729 -> V=1.0, theta=0.0
% INFO    : Bus 38408	: V=0.9957433, theta=-17.672162 -> V=1.0, theta=0.0
% INFO    : Bus 38409	: V=1.0056866, theta=-15.267196 -> V=1.0, theta=0.0
% INFO    : Bus 38410	: V=1.0039911, theta=-15.587113 -> V=1.0, theta=0.0
% INFO    : Bus 38411	: V=0.9530542, theta=-36.754175 -> V=1.0, theta=0.0
% INFO    : Bus 38412	: V=0.9516145, theta=-38.886083 -> V=1.0, theta=0.0
% INFO    : Bus 38413	: V=0.945984, theta=-39.823485 -> V=1.0, theta=0.0
% INFO    : Bus 38414	: V=0.9745522, theta=-40.967069 -> V=1.0, theta=0.0
% INFO    : Bus 38415	: V=0.9734602, theta=-41.02718 -> V=1.0, theta=0.0
% INFO    : Bus 38416	: V=0.9564235, theta=-43.246898 -> V=1.0, theta=0.0
% INFO    : Bus 38417	: V=0.9729851, theta=-41.020341 -> V=1.0, theta=0.0
% INFO    : Bus 38418	: V=0.9682904, theta=-42.258732 -> V=1.0, theta=0.0
% INFO    : Bus 38419	: V=0.9610745, theta=-43.023793 -> V=1.0, theta=0.0
% INFO    : Bus 38420	: V=0.9748519, theta=-41.133379 -> V=1.0, theta=0.0
% INFO    : Bus 38421	: V=0.973315, theta=-41.36175 -> V=1.0, theta=0.0
% INFO    : Bus 38422	: V=0.9672704, theta=-42.573464 -> V=1.0, theta=0.0
% INFO    : Bus 38423	: V=0.9633382, theta=-42.738005 -> V=1.0, theta=0.0
% INFO    : Bus 38424	: V=0.9743597, theta=-41.246881 -> V=1.0, theta=0.0
% INFO    : Bus 38425	: V=0.9763304, theta=-41.068458 -> V=1.0, theta=0.0
% INFO    : Bus 38426	: V=0.9696323, theta=-41.019837 -> V=1.0, theta=0.0
% INFO    : Bus 38427	: V=0.9725362, theta=-40.896924 -> V=1.0, theta=0.0
% INFO    : Bus 38428	: V=0.9870831, theta=-39.237017 -> V=1.0, theta=0.0
% INFO    : Bus 38429	: V=0.9647852, theta=-43.316947 -> V=1.0, theta=0.0
% INFO    : Bus 38430	: V=0.9670062, theta=-43.282778 -> V=1.0, theta=0.0
% INFO    : Bus 38431	: V=0.9716271, theta=-43.104951 -> V=1.0, theta=0.0
% INFO    : Bus 38432	: V=0.9817137, theta=-40.604919 -> V=1.0, theta=0.0
% INFO    : Bus 38433	: V=1.0026086, theta=-39.19258 -> V=1.0, theta=0.0
% INFO    : Bus 38434	: V=0.9828608, theta=-40.622271 -> V=1.0, theta=0.0
% INFO    : Bus 38435	: V=0.9865101, theta=-40.074722 -> V=1.0, theta=0.0
% INFO    : Bus 38436	: V=0.9806978, theta=-40.21116 -> V=1.0, theta=0.0
% INFO    : Bus 38437	: V=0.9811782, theta=-39.773783 -> V=1.0, theta=0.0
% INFO    : Bus 38438	: V=0.9780613, theta=-40.582428 -> V=1.0, theta=0.0
% INFO    : Bus 38439	: V=0.9783005, theta=-40.461748 -> V=1.0, theta=0.0
% INFO    : Bus 38440	: V=0.9734201, theta=-41.008015 -> V=1.0, theta=0.0
% INFO    : Bus 38441	: V=0.9907812, theta=-39.824944 -> V=1.0, theta=0.0
% INFO    : Bus 38442	: V=0.9667824, theta=-33.218923 -> V=1.0, theta=0.0
% INFO    : Bus 38443	: V=0.9653037, theta=-33.211175 -> V=1.0, theta=0.0
% INFO    : Bus 38444	: V=0.9622985, theta=-33.187308 -> V=1.0, theta=0.0
% INFO    : Bus 38445	: V=0.9501271, theta=-35.345856 -> V=1.0, theta=0.0
% INFO    : Bus 38446	: V=0.9495936, theta=-35.312828 -> V=1.0, theta=0.0
% INFO    : Bus 38447	: V=0.9505374, theta=-35.191642 -> V=1.0, theta=0.0
% INFO    : Bus 38448	: V=0.9646565, theta=-32.964052 -> V=1.0, theta=0.0
% INFO    : Bus 38449	: V=0.9518937, theta=-35.206697 -> V=1.0, theta=0.0
% INFO    : Bus 38450	: V=0.9491084, theta=-35.269125 -> V=1.0, theta=0.0
% INFO    : Bus 38451	: V=0.963829, theta=-33.025564 -> V=1.0, theta=0.0
% INFO    : Bus 38452	: V=0.9453301, theta=-35.968968 -> V=1.0, theta=0.0
% INFO    : Bus 38453	: V=0.9741756, theta=-34.269526 -> V=1.0, theta=0.0
% INFO    : Bus 38454	: V=0.9747515, theta=-33.922074 -> V=1.0, theta=0.0
% INFO    : Bus 38455	: V=0.9725265, theta=-32.645653 -> V=1.0, theta=0.0
% INFO    : Bus 38456	: V=0.9710434, theta=-33.064693 -> V=1.0, theta=0.0
% INFO    : Bus 38457	: V=0.9514099, theta=-35.026647 -> V=1.0, theta=0.0
% INFO    : Bus 38458	: V=0.9665972, theta=-32.10678 -> V=1.0, theta=0.0
% INFO    : Bus 38459	: V=0.9575071, theta=-34.856313 -> V=1.0, theta=0.0
% INFO    : Bus 38460	: V=0.9492587, theta=-35.274668 -> V=1.0, theta=0.0
% INFO    : Bus 38461	: V=0.9612137, theta=-39.601375 -> V=1.0, theta=0.0
% INFO    : Bus 38462	: V=0.9597237, theta=-39.540916 -> V=1.0, theta=0.0
% INFO    : Bus 38463	: V=0.9419127, theta=-38.2466 -> V=1.0, theta=0.0
% INFO    : Bus 38464	: V=0.967271, theta=-38.76034 -> V=1.0, theta=0.0
% INFO    : Bus 38465	: V=0.9650303, theta=-39.233619 -> V=1.0, theta=0.0
% INFO    : Bus 38466	: V=0.9645378, theta=-39.461414 -> V=1.0, theta=0.0
% INFO    : Bus 38467	: V=0.9630843, theta=-39.562448 -> V=1.0, theta=0.0
% INFO    : Bus 38468	: V=0.9428914, theta=-41.592776 -> V=1.0, theta=0.0
% INFO    : Bus 38469	: V=0.9512424, theta=-41.344872 -> V=1.0, theta=0.0
% INFO    : Bus 38470	: V=0.9568666, theta=-40.769011 -> V=1.0, theta=0.0
% INFO    : Bus 38471	: V=0.9692751, theta=-39.324009 -> V=1.0, theta=0.0
% INFO    : Bus 38472	: V=0.9719312, theta=-38.848212 -> V=1.0, theta=0.0
% INFO    : Bus 38473	: V=0.9693903, theta=-38.102383 -> V=1.0, theta=0.0
% INFO    : Bus 38474	: V=0.9709001, theta=-38.169082 -> V=1.0, theta=0.0
% INFO    : Bus 38475	: V=0.9957303, theta=-16.856922 -> V=1.0, theta=0.0
% INFO    : Bus 38476	: V=0.9891663, theta=-18.086586 -> V=1.0, theta=0.0
% INFO    : Bus 38477	: V=0.9981975, theta=-17.599107 -> V=1.0, theta=0.0
% INFO    : Bus 38478	: V=0.993626, theta=-17.718197 -> V=1.0, theta=0.0
% INFO    : Bus 38479	: V=0.990144, theta=-18.731434 -> V=1.0, theta=0.0
% INFO    : Bus 38480	: V=0.9721672, theta=-20.741362 -> V=1.0, theta=0.0
% INFO    : Bus 38481	: V=0.9594855, theta=-21.100188 -> V=1.0, theta=0.0
% INFO    : Bus 38482	: V=0.987076, theta=-19.652168 -> V=1.0, theta=0.0
% INFO    : Bus 38483	: V=0.9363859, theta=-59.840288 -> V=1.0, theta=0.0
% INFO    : Bus 38484	: V=0.9243645, theta=-58.958864 -> V=1.0, theta=0.0
% INFO    : Bus 38485	: V=0.9361112, theta=-59.79741 -> V=1.0, theta=0.0
% INFO    : Bus 38486	: V=0.9403439, theta=-60.273536 -> V=1.0, theta=0.0
% INFO    : Bus 38487	: V=0.9555704, theta=-61.536806 -> V=1.0, theta=0.0
% INFO    : Bus 38488	: V=0.9290193, theta=-58.260372 -> V=1.0, theta=0.0
% INFO    : Bus 38489	: V=0.9361187, theta=-57.299723 -> V=1.0, theta=0.0
% INFO    : Bus 38490	: V=0.9482099, theta=-53.297808 -> V=1.0, theta=0.0
% INFO    : Bus 38491	: V=0.9412367, theta=-56.561581 -> V=1.0, theta=0.0
% INFO    : Bus 38492	: V=0.945509, theta=-56.807649 -> V=1.0, theta=0.0
% INFO    : Bus 38493	: V=0.9436415, theta=-58.357375 -> V=1.0, theta=0.0
% INFO    : Bus 38494	: V=0.9403076, theta=-57.477014 -> V=1.0, theta=0.0
% INFO    : Bus 38495	: V=0.9198003, theta=-63.75532 -> V=1.0, theta=0.0
% INFO    : Bus 38496	: V=0.9511555, theta=-62.019364 -> V=1.0, theta=0.0
% INFO    : Bus 38497	: V=0.9460649, theta=-62.26725 -> V=1.0, theta=0.0
% INFO    : Bus 38498	: V=0.9501024, theta=-61.811688 -> V=1.0, theta=0.0
% INFO    : Bus 38499	: V=0.9465613, theta=-62.440634 -> V=1.0, theta=0.0
% INFO    : Bus 38500	: V=0.9679346, theta=-27.055406 -> V=1.0, theta=0.0
% INFO    : Bus 38501	: V=0.953625, theta=-28.150658 -> V=1.0, theta=0.0
% INFO    : Bus 38502	: V=0.9705423, theta=-28.117071 -> V=1.0, theta=0.0
% INFO    : Bus 38503	: V=0.9739319, theta=-22.331533 -> V=1.0, theta=0.0
% INFO    : Bus 38504	: V=0.977574, theta=-21.420635 -> V=1.0, theta=0.0
% INFO    : Bus 38505	: V=0.9832503, theta=-20.28576 -> V=1.0, theta=0.0
% INFO    : Bus 38506	: V=0.9685688, theta=-27.72824 -> V=1.0, theta=0.0
% INFO    : Bus 38507	: V=0.9683084, theta=-26.060995 -> V=1.0, theta=0.0
% INFO    : Bus 38508	: V=0.9664438, theta=-27.656744 -> V=1.0, theta=0.0
% INFO    : Bus 38509	: V=0.9646237, theta=-24.085485 -> V=1.0, theta=0.0
% INFO    : Bus 38510	: V=0.9666406, theta=-24.596934 -> V=1.0, theta=0.0
% INFO    : Bus 38511	: V=0.9656622, theta=-25.297969 -> V=1.0, theta=0.0
% INFO    : Bus 38512	: V=0.9430321, theta=-47.969723 -> V=1.0, theta=0.0
% INFO    : Bus 38513	: V=0.9610126, theta=-44.059461 -> V=1.0, theta=0.0
% INFO    : Bus 38514	: V=0.9584378, theta=-44.967733 -> V=1.0, theta=0.0
% INFO    : Bus 38515	: V=0.9565018, theta=-43.836639 -> V=1.0, theta=0.0
% INFO    : Bus 38516	: V=0.9541751, theta=-44.536211 -> V=1.0, theta=0.0
% INFO    : Bus 38517	: V=0.9584135, theta=-45.069599 -> V=1.0, theta=0.0
% INFO    : Bus 38518	: V=0.9579849, theta=-45.700188 -> V=1.0, theta=0.0
% INFO    : Bus 38519	: V=0.9488846, theta=-47.795344 -> V=1.0, theta=0.0
% INFO    : Bus 38520	: V=0.961699, theta=-46.976319 -> V=1.0, theta=0.0
% INFO    : Bus 38521	: V=1.0068179, theta=-36.662211 -> V=1.0, theta=0.0
% INFO    : Bus 38522	: V=0.9991079, theta=-33.077722 -> V=1.0, theta=0.0
% INFO    : Bus 38523	: V=0.9461893, theta=-48.261351 -> V=1.0, theta=0.0
% INFO    : Bus 38524	: V=0.9578501, theta=-48.365833 -> V=1.0, theta=0.0
% INFO    : Bus 38525	: V=0.9579097, theta=-48.686145 -> V=1.0, theta=0.0
% INFO    : Bus 38526	: V=0.9510215, theta=-47.718583 -> V=1.0, theta=0.0
% INFO    : Bus 38527	: V=0.9630788, theta=-47.370158 -> V=1.0, theta=0.0
% INFO    : Bus 38528	: V=0.9613175, theta=-47.745953 -> V=1.0, theta=0.0
% INFO    : Bus 38529	: V=0.9602566, theta=-47.859152 -> V=1.0, theta=0.0
% INFO    : Bus 38530	: V=0.9628445, theta=-47.021089 -> V=1.0, theta=0.0
% INFO    : Bus 38531	: V=0.9689791, theta=-46.164207 -> V=1.0, theta=0.0
% INFO    : Bus 38532	: V=0.9726275, theta=-34.465227 -> V=1.0, theta=0.0
% INFO    : Bus 38533	: V=0.9730296, theta=-35.10585 -> V=1.0, theta=0.0
% INFO    : Bus 38534	: V=0.9676022, theta=-35.955255 -> V=1.0, theta=0.0
% INFO    : Bus 38535	: V=0.9723203, theta=-32.250016 -> V=1.0, theta=0.0
% INFO    : Bus 38536	: V=0.975591, theta=-33.527314 -> V=1.0, theta=0.0
% INFO    : Bus 38537	: V=0.9864647, theta=-30.932819 -> V=1.0, theta=0.0
% INFO    : Bus 38538	: V=0.9918737, theta=-29.110554 -> V=1.0, theta=0.0
% INFO    : Bus 38539	: V=0.9649785, theta=-32.548029 -> V=1.0, theta=0.0
% INFO    : Bus 38540	: V=0.9791567, theta=-31.068485 -> V=1.0, theta=0.0
% INFO    : Bus 38541	: V=0.9754237, theta=-31.014914 -> V=1.0, theta=0.0
% INFO    : Bus 38542	: V=0.9705273, theta=-31.315464 -> V=1.0, theta=0.0
% INFO    : Bus 38543	: V=1.0054958, theta=-27.003144 -> V=1.0, theta=0.0
% INFO    : Bus 38544	: V=0.9716776, theta=-22.276501 -> V=1.0, theta=0.0
% INFO    : Bus 38545	: V=0.9534008, theta=-24.755187 -> V=1.0, theta=0.0
% INFO    : Bus 38546	: V=0.991952, theta=-19.422678 -> V=1.0, theta=0.0
% INFO    : Bus 38547	: V=0.9956841, theta=-19.461146 -> V=1.0, theta=0.0
% INFO    : Bus 38548	: V=0.9760881, theta=-22.161016 -> V=1.0, theta=0.0
% INFO    : Bus 38549	: V=0.9399205, theta=-40.72054 -> V=1.0, theta=0.0
% INFO    : Bus 38550	: V=0.9482288, theta=-40.472386 -> V=1.0, theta=0.0
% INFO    : Bus 38551	: V=0.9554271, theta=-38.248355 -> V=1.0, theta=0.0
% INFO    : Bus 38552	: V=0.9490858, theta=-41.911821 -> V=1.0, theta=0.0
% INFO    : Bus 38553	: V=0.9529394, theta=-42.324471 -> V=1.0, theta=0.0
% INFO    : Bus 38554	: V=0.9589417, theta=-38.683568 -> V=1.0, theta=0.0
% INFO    : Bus 38555	: V=0.9451823, theta=-41.158216 -> V=1.0, theta=0.0
% INFO    : Bus 38556	: V=0.9545605, theta=-39.15263 -> V=1.0, theta=0.0
% INFO    : Bus 38557	: V=0.9533966, theta=-41.239163 -> V=1.0, theta=0.0
% INFO    : Bus 38558	: V=0.9439781, theta=-41.467608 -> V=1.0, theta=0.0
% INFO    : Bus 38559	: V=0.9421381, theta=-41.296171 -> V=1.0, theta=0.0
% INFO    : Bus 38560	: V=0.9413309, theta=-41.577355 -> V=1.0, theta=0.0
% INFO    : Bus 38561	: V=0.9368818, theta=-42.335541 -> V=1.0, theta=0.0
% INFO    : Bus 38562	: V=0.958042, theta=-38.985224 -> V=1.0, theta=0.0
% INFO    : Bus 38563	: V=0.9673328, theta=-28.562765 -> V=1.0, theta=0.0
% INFO    : Bus 38564	: V=0.9717028, theta=-29.504818 -> V=1.0, theta=0.0
% INFO    : Bus 38565	: V=0.9770201, theta=-30.251177 -> V=1.0, theta=0.0
% INFO    : Bus 38566	: V=0.9821737, theta=-31.893754 -> V=1.0, theta=0.0
% INFO    : Bus 38567	: V=0.9813912, theta=-33.840458 -> V=1.0, theta=0.0
% INFO    : Bus 38568	: V=0.9779567, theta=-34.851001 -> V=1.0, theta=0.0
% INFO    : Bus 38569	: V=0.9813614, theta=-34.486329 -> V=1.0, theta=0.0
% INFO    : Bus 38570	: V=0.9830908, theta=-34.410918 -> V=1.0, theta=0.0
% INFO    : Bus 38571	: V=0.9906711, theta=-32.91596 -> V=1.0, theta=0.0
% INFO    : Bus 38572	: V=0.9979808, theta=-31.153092 -> V=1.0, theta=0.0
% INFO    : Bus 38573	: V=0.9846154, theta=-34.426398 -> V=1.0, theta=0.0
% INFO    : Bus 38574	: V=0.9874837, theta=-33.236139 -> V=1.0, theta=0.0
% INFO    : Bus 38575	: V=0.9887615, theta=-31.729669 -> V=1.0, theta=0.0
% INFO    : Bus 38576	: V=0.98622, theta=-32.561744 -> V=1.0, theta=0.0
% INFO    : Bus 38577	: V=0.9872881, theta=-32.830284 -> V=1.0, theta=0.0
% INFO    : Bus 38578	: V=0.9872096, theta=-32.441505 -> V=1.0, theta=0.0
% INFO    : Bus 38579	: V=0.987825, theta=-32.142791 -> V=1.0, theta=0.0
% INFO    : Bus 38580	: V=0.9894304, theta=-32.50434 -> V=1.0, theta=0.0
% INFO    : Bus 38581	: V=0.9877846, theta=-32.088955 -> V=1.0, theta=0.0
% INFO    : Bus 38582	: V=0.9844259, theta=-34.135352 -> V=1.0, theta=0.0
% INFO    : Bus 38583	: V=0.9877951, theta=-31.945581 -> V=1.0, theta=0.0
% INFO    : Bus 38584	: V=0.9832166, theta=-31.974309 -> V=1.0, theta=0.0
% INFO    : Bus 38585	: V=0.9817258, theta=-32.098015 -> V=1.0, theta=0.0
% INFO    : Bus 38586	: V=0.9802383, theta=-32.190749 -> V=1.0, theta=0.0
% INFO    : Bus 38587	: V=0.9838979, theta=-32.911114 -> V=1.0, theta=0.0
% INFO    : Bus 38588	: V=0.9864178, theta=-31.245199 -> V=1.0, theta=0.0
% INFO    : Bus 38589	: V=0.9847775, theta=-30.600373 -> V=1.0, theta=0.0
% INFO    : Bus 38590	: V=0.985874, theta=-30.861533 -> V=1.0, theta=0.0
% INFO    : Bus 38591	: V=0.9884273, theta=-32.295131 -> V=1.0, theta=0.0
% INFO    : Bus 38592	: V=0.987268, theta=-30.5403 -> V=1.0, theta=0.0
% INFO    : Bus 38593	: V=0.985509, theta=-30.684371 -> V=1.0, theta=0.0
% INFO    : Bus 38594	: V=0.9870826, theta=-31.520812 -> V=1.0, theta=0.0
% INFO    : Bus 38595	: V=0.9886279, theta=-31.442633 -> V=1.0, theta=0.0
% INFO    : Bus 38596	: V=0.9861166, theta=-30.548788 -> V=1.0, theta=0.0
% INFO    : Bus 38597	: V=0.9877389, theta=-30.365921 -> V=1.0, theta=0.0
% INFO    : Bus 38598	: V=0.9864576, theta=-31.555326 -> V=1.0, theta=0.0
% INFO    : Bus 38599	: V=0.9888537, theta=-29.499895 -> V=1.0, theta=0.0
% INFO    : Bus 38600	: V=0.9892945, theta=-29.326287 -> V=1.0, theta=0.0
% INFO    : Bus 38601	: V=0.9837255, theta=-30.605865 -> V=1.0, theta=0.0
% INFO    : Bus 38602	: V=0.9949477, theta=-25.29976 -> V=1.0, theta=0.0
% INFO    : Bus 38603	: V=0.9949497, theta=-25.32442 -> V=1.0, theta=0.0
% INFO    : Bus 38604	: V=0.9762121, theta=-29.721984 -> V=1.0, theta=0.0
% INFO    : Bus 38605	: V=0.9769709, theta=-30.621932 -> V=1.0, theta=0.0
% INFO    : Bus 38606	: V=0.9809643, theta=-30.050725 -> V=1.0, theta=0.0
% INFO    : Bus 38607	: V=0.9863333, theta=-28.722585 -> V=1.0, theta=0.0
% INFO    : Bus 38608	: V=0.9812905, theta=-30.605177 -> V=1.0, theta=0.0
% INFO    : Bus 38609	: V=0.9863795, theta=-29.018932 -> V=1.0, theta=0.0
% INFO    : Bus 38610	: V=0.9865278, theta=-28.901641 -> V=1.0, theta=0.0
% INFO    : Bus 38611	: V=0.986705, theta=-28.798898 -> V=1.0, theta=0.0
% INFO    : Bus 38612	: V=0.9838985, theta=-30.275929 -> V=1.0, theta=0.0
% INFO    : Bus 38613	: V=0.9864801, theta=-28.893887 -> V=1.0, theta=0.0
% INFO    : Bus 38614	: V=0.9864216, theta=-28.92007 -> V=1.0, theta=0.0
% INFO    : Bus 38615	: V=0.9828623, theta=-30.270356 -> V=1.0, theta=0.0
% INFO    : Bus 38616	: V=0.9821253, theta=-29.995105 -> V=1.0, theta=0.0
% INFO    : Bus 38617	: V=0.9831994, theta=-31.559696 -> V=1.0, theta=0.0
% INFO    : Bus 38618	: V=0.9842989, theta=-31.821677 -> V=1.0, theta=0.0
% INFO    : Bus 38619	: V=0.9893225, theta=-30.920677 -> V=1.0, theta=0.0
% INFO    : Bus 38620	: V=0.9887915, theta=-32.252917 -> V=1.0, theta=0.0
% INFO    : Bus 38621	: V=0.9888743, theta=-31.117242 -> V=1.0, theta=0.0
% INFO    : Bus 38622	: V=0.9887986, theta=-32.018419 -> V=1.0, theta=0.0
% INFO    : Bus 38623	: V=0.9857732, theta=-33.614144 -> V=1.0, theta=0.0
% INFO    : Bus 38624	: V=0.9894864, theta=-31.899146 -> V=1.0, theta=0.0
% INFO    : Bus 38625	: V=0.9896921, theta=-32.103655 -> V=1.0, theta=0.0
% INFO    : Bus 38626	: V=0.9895024, theta=-31.452518 -> V=1.0, theta=0.0
% INFO    : Bus 38627	: V=0.9882669, theta=-31.072275 -> V=1.0, theta=0.0
% INFO    : Bus 38628	: V=0.9868676, theta=-33.391142 -> V=1.0, theta=0.0
% INFO    : Bus 38629	: V=0.9856465, theta=-33.752853 -> V=1.0, theta=0.0
% INFO    : Bus 38630	: V=0.9792225, theta=-32.42022 -> V=1.0, theta=0.0
% INFO    : Bus 38631	: V=0.9956268, theta=-26.689226 -> V=1.0, theta=0.0
% INFO    : Bus 38632	: V=0.976325, theta=-33.595075 -> V=1.0, theta=0.0
% INFO    : Bus 38633	: V=0.9770397, theta=-33.580321 -> V=1.0, theta=0.0
% INFO    : Bus 38634	: V=0.9741002, theta=-35.633912 -> V=1.0, theta=0.0
% INFO    : Bus 38635	: V=0.9701133, theta=-36.711752 -> V=1.0, theta=0.0
% INFO    : Bus 38636	: V=0.9692063, theta=-37.539569 -> V=1.0, theta=0.0
% INFO    : Bus 38637	: V=0.9757503, theta=-33.025577 -> V=1.0, theta=0.0
% INFO    : Bus 38638	: V=0.9838528, theta=-33.521955 -> V=1.0, theta=0.0
% INFO    : Bus 38639	: V=0.9859148, theta=-33.436712 -> V=1.0, theta=0.0
% INFO    : Bus 38640	: V=0.9881523, theta=-32.963617 -> V=1.0, theta=0.0
% INFO    : Bus 38641	: V=0.9850642, theta=-32.711176 -> V=1.0, theta=0.0
% INFO    : Bus 38642	: V=0.9720694, theta=-35.988355 -> V=1.0, theta=0.0
% INFO    : Bus 38643	: V=0.9728143, theta=-36.037933 -> V=1.0, theta=0.0
% INFO    : Bus 38644	: V=0.9722661, theta=-36.161207 -> V=1.0, theta=0.0
% INFO    : Bus 38645	: V=0.9654989, theta=-36.115857 -> V=1.0, theta=0.0
% INFO    : Bus 38646	: V=0.9651685, theta=-36.25894 -> V=1.0, theta=0.0
% INFO    : Bus 38647	: V=0.9714824, theta=-35.466852 -> V=1.0, theta=0.0
% INFO    : Bus 38648	: V=0.978801, theta=-34.830397 -> V=1.0, theta=0.0
% INFO    : Bus 38649	: V=0.9868012, theta=-30.403496 -> V=1.0, theta=0.0
% INFO    : Bus 38650	: V=0.988114, theta=-30.254484 -> V=1.0, theta=0.0
% INFO    : Bus 38651	: V=0.987791, theta=-31.976801 -> V=1.0, theta=0.0
% INFO    : Bus 38652	: V=0.9979663, theta=-29.549709 -> V=1.0, theta=0.0
% INFO    : Bus 38653	: V=0.9834809, theta=-31.8594 -> V=1.0, theta=0.0
% INFO    : Bus 38654	: V=0.982109, theta=-31.594146 -> V=1.0, theta=0.0
% INFO    : Bus 38655	: V=0.9822711, theta=-31.489006 -> V=1.0, theta=0.0
% INFO    : Bus 38656	: V=0.9823243, theta=-31.406275 -> V=1.0, theta=0.0
% INFO    : Bus 38657	: V=0.9866914, theta=-29.53385 -> V=1.0, theta=0.0
% INFO    : Bus 38658	: V=0.9864369, theta=-29.37585 -> V=1.0, theta=0.0
% INFO    : Bus 38659	: V=0.9863995, theta=-29.227342 -> V=1.0, theta=0.0
% INFO    : Bus 38660	: V=0.9816899, theta=-31.098727 -> V=1.0, theta=0.0
% INFO    : Bus 38661	: V=0.981938, theta=-31.252322 -> V=1.0, theta=0.0
% INFO    : Bus 38662	: V=0.979579, theta=-33.137927 -> V=1.0, theta=0.0
% INFO    : Bus 38663	: V=0.9821706, theta=-31.493908 -> V=1.0, theta=0.0
% INFO    : Bus 38664	: V=0.9820397, theta=-31.568755 -> V=1.0, theta=0.0
% INFO    : Bus 38665	: V=0.9819419, theta=-31.670195 -> V=1.0, theta=0.0
% INFO    : Bus 38666	: V=0.9791987, theta=-32.390481 -> V=1.0, theta=0.0
% INFO    : Bus 38667	: V=0.9857058, theta=-30.538505 -> V=1.0, theta=0.0
% INFO    : Bus 38668	: V=0.9769657, theta=-34.684492 -> V=1.0, theta=0.0
% INFO    : Bus 38669	: V=0.990675, theta=-30.097678 -> V=1.0, theta=0.0
% INFO    : Bus 38670	: V=0.9790996, theta=-32.504003 -> V=1.0, theta=0.0
% INFO    : Bus 38671	: V=0.980123, theta=-32.005874 -> V=1.0, theta=0.0
% INFO    : Bus 38672	: V=0.9795932, theta=-32.220006 -> V=1.0, theta=0.0
% INFO    : Bus 38673	: V=0.9808877, theta=-31.583857 -> V=1.0, theta=0.0
% INFO    : Bus 38674	: V=0.975574, theta=-32.164377 -> V=1.0, theta=0.0
% INFO    : Bus 38675	: V=0.9813001, theta=-31.336114 -> V=1.0, theta=0.0
% INFO    : Bus 38676	: V=0.9806859, theta=-30.29273 -> V=1.0, theta=0.0
% INFO    : Bus 38677	: V=0.9790667, theta=-30.554482 -> V=1.0, theta=0.0
% INFO    : Bus 38678	: V=0.9769753, theta=-30.894709 -> V=1.0, theta=0.0
% INFO    : Bus 38679	: V=0.9757129, theta=-31.078801 -> V=1.0, theta=0.0
% INFO    : Bus 38680	: V=0.9766104, theta=-30.954168 -> V=1.0, theta=0.0
% INFO    : Bus 38681	: V=0.9630679, theta=-33.623612 -> V=1.0, theta=0.0
% INFO    : Bus 38682	: V=0.9763731, theta=-29.972161 -> V=1.0, theta=0.0
% INFO    : Bus 38683	: V=0.9750203, theta=-30.767244 -> V=1.0, theta=0.0
% INFO    : Bus 38684	: V=0.9762044, theta=-31.697256 -> V=1.0, theta=0.0
% INFO    : Bus 38685	: V=0.975266, theta=-30.551538 -> V=1.0, theta=0.0
% INFO    : Bus 38686	: V=0.975456, theta=-30.435848 -> V=1.0, theta=0.0
% INFO    : Bus 38687	: V=0.9731563, theta=-31.943475 -> V=1.0, theta=0.0
% INFO    : Bus 38688	: V=0.9753812, theta=-30.507141 -> V=1.0, theta=0.0
% INFO    : Bus 38689	: V=0.9671625, theta=-32.439488 -> V=1.0, theta=0.0
% INFO    : Bus 38690	: V=0.9761502, theta=-31.030434 -> V=1.0, theta=0.0
% INFO    : Bus 38691	: V=0.9742163, theta=-32.891881 -> V=1.0, theta=0.0
% INFO    : Bus 38692	: V=0.9768857, theta=-32.199774 -> V=1.0, theta=0.0
% INFO    : Bus 38693	: V=0.9774152, theta=-32.441883 -> V=1.0, theta=0.0
% INFO    : Bus 38694	: V=0.9735406, theta=-35.43273 -> V=1.0, theta=0.0
% INFO    : Bus 38695	: V=0.9702238, theta=-35.63632 -> V=1.0, theta=0.0
% INFO    : Bus 38696	: V=0.971203, theta=-34.329479 -> V=1.0, theta=0.0
% INFO    : Bus 38697	: V=0.9766684, theta=-35.006584 -> V=1.0, theta=0.0
% INFO    : Bus 38698	: V=0.9763022, theta=-35.017892 -> V=1.0, theta=0.0
% INFO    : Bus 38699	: V=0.9736314, theta=-34.14668 -> V=1.0, theta=0.0
% INFO    : Bus 38700	: V=0.9728506, theta=-34.250025 -> V=1.0, theta=0.0
% INFO    : Bus 38701	: V=0.9776391, theta=-33.211553 -> V=1.0, theta=0.0
% INFO    : Bus 38702	: V=0.9745911, theta=-34.030087 -> V=1.0, theta=0.0
% INFO    : Bus 38703	: V=0.9767817, theta=-35.00271 -> V=1.0, theta=0.0
% INFO    : Bus 38704	: V=0.9786054, theta=-33.082289 -> V=1.0, theta=0.0
% INFO    : Bus 38705	: V=0.9719083, theta=-34.350533 -> V=1.0, theta=0.0
% INFO    : Bus 38706	: V=0.9712525, theta=-34.410554 -> V=1.0, theta=0.0
% INFO    : Bus 38707	: V=0.9746098, theta=-35.628725 -> V=1.0, theta=0.0
% INFO    : Bus 38708	: V=0.9735493, theta=-35.955949 -> V=1.0, theta=0.0
% INFO    : Bus 38709	: V=0.9705581, theta=-36.573056 -> V=1.0, theta=0.0
% INFO    : Bus 38710	: V=0.9722338, theta=-36.239551 -> V=1.0, theta=0.0
% INFO    : Bus 38711	: V=0.9691477, theta=-36.699579 -> V=1.0, theta=0.0
% INFO    : Bus 38712	: V=0.9659272, theta=-35.755166 -> V=1.0, theta=0.0
% INFO    : Bus 38713	: V=0.9658028, theta=-35.913045 -> V=1.0, theta=0.0
% INFO    : Bus 38714	: V=0.9705273, theta=-34.502057 -> V=1.0, theta=0.0
% INFO    : Bus 38715	: V=0.9652809, theta=-36.880517 -> V=1.0, theta=0.0
% INFO    : Bus 38716	: V=0.9707732, theta=-36.494839 -> V=1.0, theta=0.0
% INFO    : Bus 38717	: V=0.9855592, theta=-30.573808 -> V=1.0, theta=0.0
% INFO    : Bus 38718	: V=0.9927661, theta=-29.563949 -> V=1.0, theta=0.0
% INFO    : Bus 38719	: V=0.9911754, theta=-29.488278 -> V=1.0, theta=0.0
% INFO    : Bus 38720	: V=0.9816666, theta=-30.49888 -> V=1.0, theta=0.0
% INFO    : Bus 38721	: V=0.9981191, theta=-26.141067 -> V=1.0, theta=0.0
% INFO    : Bus 38722	: V=0.996405, theta=-26.512919 -> V=1.0, theta=0.0
% INFO    : Bus 38723	: V=0.9787942, theta=-32.68451 -> V=1.0, theta=0.0
% INFO    : Bus 38724	: V=0.9821598, theta=-20.399309 -> V=1.0, theta=0.0
% INFO    : Bus 38725	: V=0.9779759, theta=-21.638294 -> V=1.0, theta=0.0
% INFO    : Bus 38726	: V=0.9766071, theta=-22.533972 -> V=1.0, theta=0.0
% INFO    : Bus 38727	: V=0.9788469, theta=-22.998085 -> V=1.0, theta=0.0
% INFO    : Bus 38728	: V=0.9621768, theta=-44.187893 -> V=1.0, theta=0.0
% INFO    : Bus 38729	: V=0.9610572, theta=-40.623936 -> V=1.0, theta=0.0
% INFO    : Bus 38730	: V=0.9718709, theta=-39.840263 -> V=1.0, theta=0.0
% INFO    : Bus 38731	: V=0.9756576, theta=-39.6342 -> V=1.0, theta=0.0
% INFO    : Bus 38732	: V=0.98692, theta=-19.815649 -> V=1.0, theta=0.0
% INFO    : Bus 38733	: V=0.9495951, theta=-28.296411 -> V=1.0, theta=0.0
% INFO    : Bus 38734	: V=0.9696103, theta=-24.697001 -> V=1.0, theta=0.0
% INFO    : Bus 38735	: V=0.9529031, theta=-25.328043 -> V=1.0, theta=0.0
% INFO    : Bus 38736	: V=0.9836525, theta=-23.585803 -> V=1.0, theta=0.0
% INFO    : Bus 38737	: V=0.9761628, theta=-22.569807 -> V=1.0, theta=0.0
% INFO    : Bus 38738	: V=0.9793206, theta=-21.513274 -> V=1.0, theta=0.0
% INFO    : Bus 38739	: V=0.9795757, theta=-22.064871 -> V=1.0, theta=0.0
% INFO    : Bus 38740	: V=0.9873357, theta=-21.631848 -> V=1.0, theta=0.0
% INFO    : Bus 38741	: V=0.9824026, theta=-20.699116 -> V=1.0, theta=0.0
% INFO    : Bus 38742	: V=0.9979129, theta=-17.797005 -> V=1.0, theta=0.0
% INFO    : Bus 38743	: V=1.0090667, theta=-16.567909 -> V=1.0, theta=0.0
% INFO    : Bus 38744	: V=1.0140527, theta=-15.986016 -> V=1.0, theta=0.0
% INFO    : Bus 38745	: V=1.0194591, theta=-15.553183 -> V=1.0, theta=0.0
% INFO    : Bus 38746	: V=1.000379, theta=-17.130455 -> V=1.0, theta=0.0
% INFO    : Bus 38747	: V=1.0056121, theta=-17.570393 -> V=1.0, theta=0.0
% INFO    : Bus 38748	: V=0.9757035, theta=-19.642684 -> V=1.0, theta=0.0
% INFO    : Bus 38749	: V=1.0070718, theta=-16.466002 -> V=1.0, theta=0.0
% INFO    : Bus 38750	: V=0.9391515, theta=-30.15203 -> V=1.0, theta=0.0
% INFO    : Bus 38751	: V=0.9398112, theta=-31.166902 -> V=1.0, theta=0.0
% INFO    : Bus 38752	: V=0.9421189, theta=-30.769506 -> V=1.0, theta=0.0
% INFO    : Bus 38753	: V=0.9513866, theta=-29.609255 -> V=1.0, theta=0.0
% INFO    : Bus 38754	: V=0.9462675, theta=-30.09848 -> V=1.0, theta=0.0
% INFO    : Bus 38755	: V=0.9497475, theta=-29.538775 -> V=1.0, theta=0.0
% INFO    : Bus 38756	: V=0.961189, theta=-26.223281 -> V=1.0, theta=0.0
% INFO    : Bus 38757	: V=0.9830379, theta=-25.402121 -> V=1.0, theta=0.0
% INFO    : Bus 38758	: V=0.9639122, theta=-28.667426 -> V=1.0, theta=0.0
% INFO    : Bus 38759	: V=0.9883475, theta=-25.604743 -> V=1.0, theta=0.0
% INFO    : Bus 38760	: V=0.9656156, theta=-24.699103 -> V=1.0, theta=0.0
% INFO    : Bus 38761	: V=0.9418949, theta=-37.395877 -> V=1.0, theta=0.0
% INFO    : Bus 38762	: V=0.9440111, theta=-37.863518 -> V=1.0, theta=0.0
% INFO    : Bus 38763	: V=0.9604959, theta=-35.890182 -> V=1.0, theta=0.0
% INFO    : Bus 38764	: V=0.9560652, theta=-37.397299 -> V=1.0, theta=0.0
% INFO    : Bus 38765	: V=0.9661611, theta=-31.125068 -> V=1.0, theta=0.0
% INFO    : Bus 38766	: V=0.9779527, theta=-30.160622 -> V=1.0, theta=0.0
% INFO    : Bus 38767	: V=0.9814082, theta=-30.005933 -> V=1.0, theta=0.0
% INFO    : Bus 38768	: V=0.9825676, theta=-28.891796 -> V=1.0, theta=0.0
% INFO    : Bus 38769	: V=0.9808806, theta=-29.646536 -> V=1.0, theta=0.0
% INFO    : Bus 38770	: V=0.9803364, theta=-29.465523 -> V=1.0, theta=0.0
% INFO    : Bus 38771	: V=0.9811662, theta=-29.019455 -> V=1.0, theta=0.0
% INFO    : Bus 38772	: V=0.9885498, theta=-27.733692 -> V=1.0, theta=0.0
% INFO    : Bus 38773	: V=0.9739594, theta=-29.408763 -> V=1.0, theta=0.0
% INFO    : Bus 38774	: V=0.9667058, theta=-20.534408 -> V=1.0, theta=0.0
% INFO    : Bus 38775	: V=0.9882766, theta=-18.93803 -> V=1.0, theta=0.0
% INFO    : Bus 38776	: V=0.9892396, theta=-18.795593 -> V=1.0, theta=0.0
% INFO    : Bus 38777	: V=0.9860761, theta=-19.387145 -> V=1.0, theta=0.0
% INFO    : Bus 38778	: V=0.973439, theta=-21.356128 -> V=1.0, theta=0.0
% INFO    : Bus 38779	: V=0.9557383, theta=-23.72848 -> V=1.0, theta=0.0
% INFO    : Bus 38780	: V=0.9868661, theta=-19.212667 -> V=1.0, theta=0.0
% INFO    : Bus 38781	: V=0.9891494, theta=-19.329297 -> V=1.0, theta=0.0
% INFO    : Bus 38782	: V=0.9684191, theta=-22.327932 -> V=1.0, theta=0.0
% INFO    : Bus 38783	: V=0.9684652, theta=-22.124055 -> V=1.0, theta=0.0
% INFO    : Bus 38784	: V=0.9735703, theta=-21.597564 -> V=1.0, theta=0.0
% INFO    : Bus 38785	: V=0.9811504, theta=-20.01085 -> V=1.0, theta=0.0
% INFO    : Bus 38786	: V=0.993407, theta=-18.192399 -> V=1.0, theta=0.0
% INFO    : Bus 38787	: V=0.9792217, theta=-20.682283 -> V=1.0, theta=0.0
% INFO    : Bus 38788	: V=0.9677774, theta=-26.538578 -> V=1.0, theta=0.0
% INFO    : Bus 38789	: V=0.9730084, theta=-24.829991 -> V=1.0, theta=0.0
% INFO    : Bus 38790	: V=0.976094, theta=-25.729594 -> V=1.0, theta=0.0
% INFO    : Bus 38791	: V=0.9784747, theta=-24.814245 -> V=1.0, theta=0.0
% INFO    : Bus 38792	: V=0.9781871, theta=-23.716364 -> V=1.0, theta=0.0
% INFO    : Bus 38793	: V=0.9872481, theta=-22.015563 -> V=1.0, theta=0.0
% INFO    : Bus 38794	: V=0.9834783, theta=-23.74001 -> V=1.0, theta=0.0
% INFO    : Bus 38795	: V=0.9627841, theta=-25.839796 -> V=1.0, theta=0.0
% INFO    : Bus 38796	: V=0.9658021, theta=-47.167993 -> V=1.0, theta=0.0
% INFO    : Bus 38797	: V=0.9313952, theta=-49.235201 -> V=1.0, theta=0.0
% INFO    : Bus 38798	: V=0.9697908, theta=-47.217182 -> V=1.0, theta=0.0
% INFO    : Bus 38799	: V=0.9645259, theta=-47.780635 -> V=1.0, theta=0.0
% INFO    : Bus 38800	: V=0.9665807, theta=-48.094755 -> V=1.0, theta=0.0
% INFO    : Bus 38801	: V=0.9881131, theta=-47.205192 -> V=1.0, theta=0.0
% INFO    : Bus 38802	: V=0.9663879, theta=-50.399956 -> V=1.0, theta=0.0
% INFO    : Bus 38803	: V=0.9682276, theta=-50.12931 -> V=1.0, theta=0.0
% INFO    : Bus 38804	: V=0.9561331, theta=-51.240923 -> V=1.0, theta=0.0
% INFO    : Bus 38805	: V=0.9570294, theta=-49.87933 -> V=1.0, theta=0.0
% INFO    : Bus 38806	: V=0.9564302, theta=-49.6709 -> V=1.0, theta=0.0
% INFO    : Bus 38807	: V=0.9679262, theta=-49.669009 -> V=1.0, theta=0.0
% INFO    : Bus 38808	: V=0.9669278, theta=-50.229638 -> V=1.0, theta=0.0
% INFO    : Bus 38809	: V=0.9628865, theta=-50.943536 -> V=1.0, theta=0.0
% INFO    : Bus 38810	: V=0.9441305, theta=-52.275558 -> V=1.0, theta=0.0
% INFO    : Bus 38811	: V=0.9567201, theta=-49.283822 -> V=1.0, theta=0.0
% INFO    : Bus 38812	: V=0.968913, theta=-49.07016 -> V=1.0, theta=0.0
% INFO    : Bus 38813	: V=0.9709736, theta=-48.947789 -> V=1.0, theta=0.0
% INFO    : Bus 38814	: V=0.9872976, theta=-48.849365 -> V=1.0, theta=0.0
% INFO    : Bus 38815	: V=0.9710052, theta=-50.400655 -> V=1.0, theta=0.0
% INFO    : Bus 38816	: V=0.9764697, theta=-33.401912 -> V=1.0, theta=0.0
% INFO    : Bus 38817	: V=0.9946138, theta=-28.414288 -> V=1.0, theta=0.0
% INFO    : Bus 38818	: V=0.9812313, theta=-31.166909 -> V=1.0, theta=0.0
% INFO    : Bus 38819	: V=0.9971224, theta=-27.893843 -> V=1.0, theta=0.0
% INFO    : Bus 38820	: V=0.9655774, theta=-48.641084 -> V=1.0, theta=0.0
% INFO    : Bus 38821	: V=0.9681924, theta=-48.527646 -> V=1.0, theta=0.0
% INFO    : Bus 38822	: V=0.9650104, theta=-48.624301 -> V=1.0, theta=0.0
% INFO    : Bus 38823	: V=0.9644349, theta=-48.633881 -> V=1.0, theta=0.0
% INFO    : Bus 38824	: V=0.9649807, theta=-48.533264 -> V=1.0, theta=0.0
% INFO    : Bus 38825	: V=0.9414575, theta=-52.803211 -> V=1.0, theta=0.0
% INFO    : Bus 38826	: V=0.986461, theta=-46.397759 -> V=1.0, theta=0.0
% INFO    : Bus 38827	: V=0.9633457, theta=-48.63222 -> V=1.0, theta=0.0
% INFO    : Bus 38828	: V=0.9408609, theta=-52.862811 -> V=1.0, theta=0.0
% INFO    : Bus 38829	: V=0.9819585, theta=-48.023428 -> V=1.0, theta=0.0
% INFO    : Bus 38830	: V=0.9659773, theta=-47.856934 -> V=1.0, theta=0.0
% INFO    : Bus 38831	: V=0.9630738, theta=-48.675455 -> V=1.0, theta=0.0
% INFO    : Bus 38832	: V=0.9900434, theta=-28.044842 -> V=1.0, theta=0.0
% INFO    : Bus 38833	: V=0.9958797, theta=-27.191779 -> V=1.0, theta=0.0
% INFO    : Bus 38834	: V=0.997991, theta=-27.187804 -> V=1.0, theta=0.0
% INFO    : Bus 38835	: V=1.0020503, theta=-26.142769 -> V=1.0, theta=0.0
% INFO    : Bus 38836	: V=0.9757382, theta=-29.734409 -> V=1.0, theta=0.0
% INFO    : Bus 38837	: V=0.9924508, theta=-27.734831 -> V=1.0, theta=0.0
% INFO    : Bus 38838	: V=0.9909952, theta=-27.85297 -> V=1.0, theta=0.0
% INFO    : Bus 38839	: V=0.9730273, theta=-29.824011 -> V=1.0, theta=0.0
% INFO    : Bus 38840	: V=0.9876144, theta=-28.204816 -> V=1.0, theta=0.0
% INFO    : Bus 38841	: V=1.001523, theta=-25.918642 -> V=1.0, theta=0.0
% INFO    : Bus 38842	: V=1.0004106, theta=-26.05699 -> V=1.0, theta=0.0
% INFO    : Bus 38843	: V=0.9577928, theta=-32.059837 -> V=1.0, theta=0.0
% INFO    : Bus 38844	: V=0.9995774, theta=-26.178124 -> V=1.0, theta=0.0
% INFO    : Bus 38845	: V=0.9879688, theta=-28.223947 -> V=1.0, theta=0.0
% INFO    : Bus 38846	: V=0.9992395, theta=-26.216535 -> V=1.0, theta=0.0
% INFO    : Bus 38847	: V=0.9898058, theta=-27.947208 -> V=1.0, theta=0.0
% INFO    : Bus 38848	: V=0.9853743, theta=-28.627772 -> V=1.0, theta=0.0
% INFO    : Bus 38849	: V=0.9853758, theta=-28.649384 -> V=1.0, theta=0.0
% INFO    : Bus 38850	: V=0.9717806, theta=-30.338276 -> V=1.0, theta=0.0
% INFO    : Bus 38851	: V=0.9893606, theta=-28.09639 -> V=1.0, theta=0.0
% INFO    : Bus 38852	: V=0.989205, theta=-28.254089 -> V=1.0, theta=0.0
% INFO    : Bus 38853	: V=0.985643, theta=-28.670897 -> V=1.0, theta=0.0
% INFO    : Bus 38854	: V=0.9809123, theta=-29.368742 -> V=1.0, theta=0.0
% INFO    : Bus 38855	: V=0.9804778, theta=-30.627178 -> V=1.0, theta=0.0
% INFO    : Bus 38856	: V=0.9680389, theta=-32.871262 -> V=1.0, theta=0.0
% INFO    : Bus 38857	: V=0.9859635, theta=-31.031469 -> V=1.0, theta=0.0
% INFO    : Bus 38858	: V=0.979775, theta=-31.59291 -> V=1.0, theta=0.0
% INFO    : Bus 38859	: V=0.9785317, theta=-32.274151 -> V=1.0, theta=0.0
% INFO    : Bus 38860	: V=0.9904593, theta=-28.017468 -> V=1.0, theta=0.0
% INFO    : Bus 38861	: V=0.9987557, theta=-26.999468 -> V=1.0, theta=0.0
% INFO    : Bus 38862	: V=0.9773516, theta=-31.358714 -> V=1.0, theta=0.0
% INFO    : Bus 38863	: V=0.986093, theta=-29.405486 -> V=1.0, theta=0.0
% INFO    : Bus 38864	: V=0.9846897, theta=-29.717017 -> V=1.0, theta=0.0
% INFO    : Bus 38865	: V=0.9900706, theta=-28.581126 -> V=1.0, theta=0.0
% INFO    : Bus 38866	: V=0.9894977, theta=-28.733571 -> V=1.0, theta=0.0
% INFO    : Bus 38867	: V=0.9749768, theta=-30.369611 -> V=1.0, theta=0.0
% INFO    : Bus 38868	: V=0.9912518, theta=-28.340466 -> V=1.0, theta=0.0
% INFO    : Bus 38869	: V=0.9921061, theta=-28.264158 -> V=1.0, theta=0.0
% INFO    : Bus 38870	: V=0.986177, theta=-29.319837 -> V=1.0, theta=0.0
% INFO    : Bus 38871	: V=0.9784434, theta=-29.920139 -> V=1.0, theta=0.0
% INFO    : Bus 38872	: V=0.9924102, theta=-28.133725 -> V=1.0, theta=0.0
% INFO    : Bus 38873	: V=0.9946396, theta=-27.670301 -> V=1.0, theta=0.0
% INFO    : Bus 38874	: V=0.986533, theta=-28.994585 -> V=1.0, theta=0.0
% INFO    : Bus 38875	: V=1.0004124, theta=-26.546238 -> V=1.0, theta=0.0
% INFO    : Bus 38876	: V=0.9916667, theta=-28.753188 -> V=1.0, theta=0.0
% INFO    : Bus 38877	: V=0.9982618, theta=-27.08787 -> V=1.0, theta=0.0
% INFO    : Bus 38878	: V=1.0028639, theta=-25.941283 -> V=1.0, theta=0.0
% INFO    : Bus 38879	: V=1.004979, theta=-25.632261 -> V=1.0, theta=0.0
% INFO    : Bus 38880	: V=1.0007183, theta=-26.461305 -> V=1.0, theta=0.0
% INFO    : Bus 38881	: V=0.9711437, theta=-32.385787 -> V=1.0, theta=0.0
% INFO    : Bus 38882	: V=0.9812936, theta=-29.952262 -> V=1.0, theta=0.0
% INFO    : Bus 38883	: V=0.9954109, theta=-27.082216 -> V=1.0, theta=0.0
% INFO    : Bus 38884	: V=0.9778222, theta=-30.633886 -> V=1.0, theta=0.0
% INFO    : Bus 38885	: V=0.9744091, theta=-30.455601 -> V=1.0, theta=0.0
% INFO    : Bus 38886	: V=0.9712347, theta=-31.071133 -> V=1.0, theta=0.0
% INFO    : Bus 38887	: V=0.9776941, theta=-30.102578 -> V=1.0, theta=0.0
% INFO    : Bus 38888	: V=0.9757166, theta=-30.191235 -> V=1.0, theta=0.0
% INFO    : Bus 38889	: V=0.9786233, theta=-29.670312 -> V=1.0, theta=0.0
% INFO    : Bus 38890	: V=0.9773635, theta=-29.878256 -> V=1.0, theta=0.0
% INFO    : Bus 38891	: V=0.964711, theta=-30.72115 -> V=1.0, theta=0.0
% INFO    : Bus 38892	: V=0.9676987, theta=-30.629607 -> V=1.0, theta=0.0
% INFO    : Bus 38893	: V=0.9691527, theta=-30.442703 -> V=1.0, theta=0.0
% INFO    : Bus 38894	: V=0.9872083, theta=-28.911885 -> V=1.0, theta=0.0
% INFO    : Bus 38895	: V=0.9924158, theta=-28.164147 -> V=1.0, theta=0.0
% INFO    : Bus 38896	: V=0.9807409, theta=-30.286303 -> V=1.0, theta=0.0
% INFO    : Bus 38897	: V=0.9654556, theta=-31.478089 -> V=1.0, theta=0.0
% INFO    : Bus 38898	: V=0.9956617, theta=-27.165081 -> V=1.0, theta=0.0
% INFO    : Bus 38899	: V=0.9990137, theta=-26.739451 -> V=1.0, theta=0.0
% INFO    : Bus 38900	: V=0.9822281, theta=-29.346934 -> V=1.0, theta=0.0
% INFO    : Bus 38901	: V=0.9797112, theta=-29.515212 -> V=1.0, theta=0.0
% INFO    : Bus 38902	: V=0.9788761, theta=-30.431703 -> V=1.0, theta=0.0
% INFO    : Bus 38903	: V=0.9822817, theta=-28.973431 -> V=1.0, theta=0.0
% INFO    : Bus 38904	: V=0.984612, theta=-28.621815 -> V=1.0, theta=0.0
% INFO    : Bus 38905	: V=0.9857587, theta=-28.474376 -> V=1.0, theta=0.0
% INFO    : Bus 38906	: V=0.9860141, theta=-28.52517 -> V=1.0, theta=0.0
% INFO    : Bus 38907	: V=1.0026357, theta=-25.776315 -> V=1.0, theta=0.0
% INFO    : Bus 38908	: V=1.0060099, theta=-25.3508 -> V=1.0, theta=0.0
% INFO    : Bus 38909	: V=0.9922462, theta=-27.893724 -> V=1.0, theta=0.0
% INFO    : Bus 38910	: V=1.0156333, theta=-24.028643 -> V=1.0, theta=0.0
% INFO    : Bus 38911	: V=0.9892998, theta=-28.107633 -> V=1.0, theta=0.0
% INFO    : Bus 38912	: V=0.9839964, theta=-28.990778 -> V=1.0, theta=0.0
% INFO    : Bus 38913	: V=0.9818583, theta=-30.043355 -> V=1.0, theta=0.0
% INFO    : Bus 38914	: V=0.9915619, theta=-46.376462 -> V=1.0, theta=0.0
% INFO    : Bus 38915	: V=0.9809068, theta=-46.679659 -> V=1.0, theta=0.0
% INFO    : Bus 38916	: V=0.9680281, theta=-25.889203 -> V=1.0, theta=0.0
% INFO    : Bus 38917	: V=0.970793, theta=-24.137022 -> V=1.0, theta=0.0
% INFO    : Bus 38918	: V=0.9719153, theta=-25.640131 -> V=1.0, theta=0.0
% INFO    : Bus 38919	: V=0.9772311, theta=-25.52505 -> V=1.0, theta=0.0
% INFO    : Bus 38920	: V=0.9766776, theta=-25.890857 -> V=1.0, theta=0.0
% INFO    : Bus 38921	: V=0.9859471, theta=-25.078207 -> V=1.0, theta=0.0
% INFO    : Bus 38922	: V=0.9887035, theta=-23.949251 -> V=1.0, theta=0.0
% INFO    : Bus 38923	: V=0.9860292, theta=-23.794408 -> V=1.0, theta=0.0
% INFO    : Bus 38924	: V=0.9935378, theta=-23.565788 -> V=1.0, theta=0.0
% INFO    : Bus 38925	: V=1.0019156, theta=-23.000495 -> V=1.0, theta=0.0
% INFO    : Bus 38926	: V=1.0089616, theta=-22.343285 -> V=1.0, theta=0.0
% INFO    : Bus 38927	: V=1.0167806, theta=-22.195042 -> V=1.0, theta=0.0
% INFO    : Bus 38928	: V=0.9262896, theta=-53.469042 -> V=1.0, theta=0.0
% INFO    : Bus 38929	: V=0.996484, theta=-46.128991 -> V=1.0, theta=0.0
% INFO    : Bus 38930	: V=1.0113372, theta=-45.249815 -> V=1.0, theta=0.0
% INFO    : Bus 38931	: V=1.0049795, theta=-46.644707 -> V=1.0, theta=0.0
% INFO    : Bus 38932	: V=0.9795835, theta=-49.54443 -> V=1.0, theta=0.0
% INFO    : Bus 38933	: V=0.9556819, theta=-51.849057 -> V=1.0, theta=0.0
% INFO    : Bus 38934	: V=0.9662394, theta=-50.740894 -> V=1.0, theta=0.0
% INFO    : Bus 38935	: V=0.9617039, theta=-51.084716 -> V=1.0, theta=0.0
% INFO    : Bus 38936	: V=0.9527649, theta=-51.97992 -> V=1.0, theta=0.0
% INFO    : Bus 38937	: V=0.9579399, theta=-51.350471 -> V=1.0, theta=0.0
% INFO    : Bus 38938	: V=0.9662206, theta=-51.134281 -> V=1.0, theta=0.0
% INFO    : Bus 38939	: V=1.0003437, theta=-47.326205 -> V=1.0, theta=0.0
% INFO    : Bus 38940	: V=0.9902334, theta=-47.756577 -> V=1.0, theta=0.0
% INFO    : Bus 38941	: V=0.9929501, theta=-20.709425 -> V=1.0, theta=0.0
% INFO    : Bus 38942	: V=1.0033793, theta=-19.394529 -> V=1.0, theta=0.0
% INFO    : Bus 38943	: V=0.9996693, theta=-19.912606 -> V=1.0, theta=0.0
% INFO    : Bus 38944	: V=0.9978841, theta=-20.180666 -> V=1.0, theta=0.0
% INFO    : Bus 38945	: V=1.0036154, theta=-19.567062 -> V=1.0, theta=0.0
% INFO    : Bus 38946	: V=0.9767928, theta=-22.770948 -> V=1.0, theta=0.0
% INFO    : Bus 38947	: V=0.970377, theta=-21.695586 -> V=1.0, theta=0.0
% INFO    : Bus 38948	: V=0.9313222, theta=-27.119932 -> V=1.0, theta=0.0
% INFO    : Bus 38949	: V=0.9610533, theta=-23.666418 -> V=1.0, theta=0.0
% INFO    : Bus 38950	: V=0.9624994, theta=-22.710251 -> V=1.0, theta=0.0
% INFO    : Bus 38951	: V=0.9601838, theta=-23.327652 -> V=1.0, theta=0.0
% INFO    : Bus 38952	: V=0.9704969, theta=-23.262448 -> V=1.0, theta=0.0
% INFO    : Bus 38953	: V=0.9824262, theta=-15.338815 -> V=1.0, theta=0.0
% INFO    : Bus 38954	: V=1.0074302, theta=-13.965245 -> V=1.0, theta=0.0
% INFO    : Bus 38955	: V=1.0091585, theta=-14.964907 -> V=1.0, theta=0.0
% INFO    : Bus 38956	: V=1.0067041, theta=-15.673351 -> V=1.0, theta=0.0
% INFO    : Bus 38957	: V=1.0007466, theta=-16.312947 -> V=1.0, theta=0.0
% INFO    : Bus 38958	: V=1.0029709, theta=-15.354453 -> V=1.0, theta=0.0
% INFO    : Bus 38959	: V=1.0048604, theta=-14.743179 -> V=1.0, theta=0.0
% INFO    : Bus 38960	: V=1.0083726, theta=-14.560138 -> V=1.0, theta=0.0
% INFO    : Bus 38961	: V=0.9953327, theta=-17.214522 -> V=1.0, theta=0.0
% INFO    : Bus 38962	: V=0.9684284, theta=-25.46209 -> V=1.0, theta=0.0
% INFO    : Bus 38963	: V=0.9780586, theta=-22.710356 -> V=1.0, theta=0.0
% INFO    : Bus 38964	: V=0.9673241, theta=-24.689312 -> V=1.0, theta=0.0
% INFO    : Bus 38965	: V=0.9751556, theta=-23.054935 -> V=1.0, theta=0.0
% INFO    : Bus 38966	: V=0.9713755, theta=-23.536988 -> V=1.0, theta=0.0
% INFO    : Bus 38967	: V=0.9825046, theta=-21.352528 -> V=1.0, theta=0.0
% INFO    : Bus 38968	: V=0.9974669, theta=-17.139227 -> V=1.0, theta=0.0
% INFO    : Bus 38969	: V=1.0035963, theta=-16.033491 -> V=1.0, theta=0.0
% INFO    : Bus 38970	: V=1.0211689, theta=-12.956501 -> V=1.0, theta=0.0
% INFO    : Bus 38971	: V=0.9893636, theta=-18.896792 -> V=1.0, theta=0.0
% INFO    : Bus 38972	: V=0.9678451, theta=-21.023363 -> V=1.0, theta=0.0
% INFO    : Bus 38973	: V=0.9947448, theta=-18.22651 -> V=1.0, theta=0.0
% INFO    : Bus 38974	: V=0.9933618, theta=-19.26671 -> V=1.0, theta=0.0
% INFO    : Bus 38975	: V=1.0195205, theta=-13.848244 -> V=1.0, theta=0.0
% INFO    : Bus 38976	: V=0.95456, theta=-44.27535 -> V=1.0, theta=0.0
% INFO    : Bus 38977	: V=0.9641646, theta=-42.90337 -> V=1.0, theta=0.0
% INFO    : Bus 38978	: V=0.9590071, theta=-43.857163 -> V=1.0, theta=0.0
% INFO    : Bus 38979	: V=0.9550315, theta=-46.073079 -> V=1.0, theta=0.0
% INFO    : Bus 38980	: V=0.9615496, theta=-48.294495 -> V=1.0, theta=0.0
% INFO    : Bus 38981	: V=0.967316, theta=-47.683048 -> V=1.0, theta=0.0
% INFO    : Bus 38982	: V=0.9706549, theta=-47.271692 -> V=1.0, theta=0.0
% INFO    : Bus 38983	: V=0.9623621, theta=-47.004755 -> V=1.0, theta=0.0
% INFO    : Bus 38984	: V=0.9584513, theta=-46.82414 -> V=1.0, theta=0.0
% INFO    : Bus 38985	: V=0.9669185, theta=-47.095479 -> V=1.0, theta=0.0
% INFO    : Bus 38986	: V=0.9638238, theta=-47.622175 -> V=1.0, theta=0.0
% INFO    : Bus 38987	: V=0.9685177, theta=-46.702023 -> V=1.0, theta=0.0
% INFO    : Bus 38988	: V=0.9267169, theta=-49.757784 -> V=1.0, theta=0.0
% INFO    : Bus 38989	: V=0.9413518, theta=-64.374867 -> V=1.0, theta=0.0
% INFO    : Bus 38990	: V=0.9124642, theta=-64.923021 -> V=1.0, theta=0.0
% INFO    : Bus 38991	: V=0.9048828, theta=-65.408185 -> V=1.0, theta=0.0
% INFO    : Bus 38992	: V=0.9483695, theta=-68.067462 -> V=1.0, theta=0.0
% INFO    : Bus 38993	: V=0.9462381, theta=-68.951106 -> V=1.0, theta=0.0
% INFO    : Bus 38994	: V=0.9506216, theta=-44.363659 -> V=1.0, theta=0.0
% INFO    : Bus 38995	: V=0.9617022, theta=-43.18203 -> V=1.0, theta=0.0
% INFO    : Bus 38996	: V=0.9520332, theta=-44.046411 -> V=1.0, theta=0.0
% INFO    : Bus 38997	: V=0.9526348, theta=-43.963395 -> V=1.0, theta=0.0
% INFO    : Bus 38998	: V=0.9653512, theta=-42.382934 -> V=1.0, theta=0.0
% INFO    : Bus 38999	: V=0.9626318, theta=-42.723242 -> V=1.0, theta=0.0
% INFO    : Bus 39000	: V=0.9594943, theta=-43.121171 -> V=1.0, theta=0.0
% INFO    : Bus 39001	: V=0.9602489, theta=-43.344454 -> V=1.0, theta=0.0
% INFO    : Bus 39002	: V=0.949457, theta=-44.738975 -> V=1.0, theta=0.0
% INFO    : Bus 39003	: V=0.9481151, theta=-44.822884 -> V=1.0, theta=0.0
% INFO    : Bus 39004	: V=0.9474243, theta=-44.823193 -> V=1.0, theta=0.0
% INFO    : Bus 39005	: V=0.9451733, theta=-44.871029 -> V=1.0, theta=0.0
% INFO    : Bus 39006	: V=0.9411807, theta=-47.059022 -> V=1.0, theta=0.0
% INFO    : Bus 39007	: V=0.9607489, theta=-43.460806 -> V=1.0, theta=0.0
% INFO    : Bus 39008	: V=0.9499274, theta=-44.165632 -> V=1.0, theta=0.0
% INFO    : Bus 39009	: V=0.956338, theta=-43.466527 -> V=1.0, theta=0.0
% INFO    : Bus 39010	: V=0.9576267, theta=-43.291611 -> V=1.0, theta=0.0
% INFO    : Bus 39011	: V=0.9664613, theta=-42.202026 -> V=1.0, theta=0.0
% INFO    : Bus 39012	: V=0.9611306, theta=-42.917243 -> V=1.0, theta=0.0
% INFO    : Bus 39013	: V=0.9582581, theta=-43.266006 -> V=1.0, theta=0.0
% INFO    : Bus 39014	: V=0.9571611, theta=-43.946554 -> V=1.0, theta=0.0
% INFO    : Bus 39015	: V=0.9474974, theta=-44.974616 -> V=1.0, theta=0.0
% INFO    : Bus 39016	: V=0.9458159, theta=-45.010426 -> V=1.0, theta=0.0
% INFO    : Bus 39017	: V=0.9607664, theta=-43.481064 -> V=1.0, theta=0.0
% INFO    : Bus 39018	: V=0.966498, theta=-42.266327 -> V=1.0, theta=0.0
% INFO    : Bus 39019	: V=0.9695148, theta=-41.78524 -> V=1.0, theta=0.0
% INFO    : Bus 39020	: V=0.970784, theta=-41.592744 -> V=1.0, theta=0.0
% INFO    : Bus 39021	: V=0.9972483, theta=-37.707767 -> V=1.0, theta=0.0
% INFO    : Bus 39022	: V=0.9712317, theta=-41.544779 -> V=1.0, theta=0.0
% INFO    : Bus 39023	: V=0.9683664, theta=-41.924465 -> V=1.0, theta=0.0
% INFO    : Bus 39024	: V=0.9639264, theta=-42.420373 -> V=1.0, theta=0.0
% INFO    : Bus 39025	: V=0.9501752, theta=-44.617605 -> V=1.0, theta=0.0
% INFO    : Bus 39026	: V=0.9456949, theta=-44.922795 -> V=1.0, theta=0.0
% INFO    : Bus 39027	: V=0.9459651, theta=-45.37518 -> V=1.0, theta=0.0
% INFO    : Bus 39028	: V=0.9626756, theta=-42.504252 -> V=1.0, theta=0.0
% INFO    : Bus 39029	: V=0.9697857, theta=-41.48757 -> V=1.0, theta=0.0
% INFO    : Bus 39030	: V=0.9694249, theta=-41.614673 -> V=1.0, theta=0.0
% INFO    : Bus 39031	: V=0.9674759, theta=-42.083845 -> V=1.0, theta=0.0
% INFO    : Bus 39032	: V=0.9892721, theta=-38.06868 -> V=1.0, theta=0.0
% INFO    : Bus 39033	: V=0.977317, theta=-40.578064 -> V=1.0, theta=0.0
% INFO    : Bus 39034	: V=0.9757978, theta=-40.869434 -> V=1.0, theta=0.0
% INFO    : Bus 39035	: V=0.9786834, theta=-39.963201 -> V=1.0, theta=0.0
% INFO    : Bus 39036	: V=0.9777423, theta=-40.081592 -> V=1.0, theta=0.0
% INFO    : Bus 39037	: V=0.9797853, theta=-39.808756 -> V=1.0, theta=0.0
% INFO    : Bus 39038	: V=0.9777937, theta=-39.109671 -> V=1.0, theta=0.0
% INFO    : Bus 39039	: V=0.9878861, theta=-38.269416 -> V=1.0, theta=0.0
% INFO    : Bus 39040	: V=0.9762826, theta=-40.73502 -> V=1.0, theta=0.0
% INFO    : Bus 39041	: V=0.9755395, theta=-40.888305 -> V=1.0, theta=0.0
% INFO    : Bus 39042	: V=0.9709484, theta=-41.352312 -> V=1.0, theta=0.0
% INFO    : Bus 39043	: V=0.9731562, theta=-41.128796 -> V=1.0, theta=0.0
% INFO    : Bus 39044	: V=0.9495034, theta=-43.808038 -> V=1.0, theta=0.0
% INFO    : Bus 39045	: V=0.9480404, theta=-44.830959 -> V=1.0, theta=0.0
% INFO    : Bus 39046	: V=0.9435585, theta=-45.496956 -> V=1.0, theta=0.0
% INFO    : Bus 39047	: V=0.9527869, theta=-46.417236 -> V=1.0, theta=0.0
% INFO    : Bus 39048	: V=0.9555394, theta=-44.532024 -> V=1.0, theta=0.0
% INFO    : Bus 39049	: V=0.9565665, theta=-45.891442 -> V=1.0, theta=0.0
% INFO    : Bus 39050	: V=0.9590505, theta=-46.103844 -> V=1.0, theta=0.0
% INFO    : Bus 39051	: V=0.9561141, theta=-44.803034 -> V=1.0, theta=0.0
% INFO    : Bus 39052	: V=0.9427167, theta=-46.224895 -> V=1.0, theta=0.0
% INFO    : Bus 39053	: V=0.9586161, theta=-44.044835 -> V=1.0, theta=0.0
% INFO    : Bus 39054	: V=0.95751, theta=-44.552326 -> V=1.0, theta=0.0
% INFO    : Bus 39055	: V=0.9624812, theta=-43.43027 -> V=1.0, theta=0.0
% INFO    : Bus 39056	: V=0.9612741, theta=-43.475251 -> V=1.0, theta=0.0
% INFO    : Bus 39057	: V=0.9667663, theta=-42.287635 -> V=1.0, theta=0.0
% INFO    : Bus 39058	: V=0.9597214, theta=-42.597709 -> V=1.0, theta=0.0
% INFO    : Bus 39059	: V=0.9764063, theta=-40.247344 -> V=1.0, theta=0.0
% INFO    : Bus 39060	: V=0.9763364, theta=-40.277926 -> V=1.0, theta=0.0
% INFO    : Bus 39061	: V=0.9713398, theta=-41.154053 -> V=1.0, theta=0.0
% INFO    : Bus 39062	: V=0.9755488, theta=-40.560729 -> V=1.0, theta=0.0
% INFO    : Bus 39063	: V=0.9749863, theta=-40.666907 -> V=1.0, theta=0.0
% INFO    : Bus 39064	: V=0.9741553, theta=-40.830769 -> V=1.0, theta=0.0
% INFO    : Bus 39065	: V=0.9725223, theta=-41.044181 -> V=1.0, theta=0.0
% INFO    : Bus 39066	: V=0.9710672, theta=-41.261082 -> V=1.0, theta=0.0
% INFO    : Bus 39067	: V=0.9786026, theta=-40.003185 -> V=1.0, theta=0.0
% INFO    : Bus 39068	: V=0.9768707, theta=-40.261911 -> V=1.0, theta=0.0
% INFO    : Bus 39069	: V=0.9774994, theta=-40.21125 -> V=1.0, theta=0.0
% INFO    : Bus 39070	: V=0.9815362, theta=-39.671916 -> V=1.0, theta=0.0
% INFO    : Bus 39071	: V=0.983846, theta=-39.427146 -> V=1.0, theta=0.0
% INFO    : Bus 39072	: V=0.9815315, theta=-39.868839 -> V=1.0, theta=0.0
% INFO    : Bus 39073	: V=0.9814671, theta=-40.024743 -> V=1.0, theta=0.0
% INFO    : Bus 39074	: V=0.9791823, theta=-40.065963 -> V=1.0, theta=0.0
% INFO    : Bus 39075	: V=0.9814893, theta=-38.739482 -> V=1.0, theta=0.0
% INFO    : Bus 39076	: V=0.9798482, theta=-39.85074 -> V=1.0, theta=0.0
% INFO    : Bus 39077	: V=0.9821606, theta=-39.11883 -> V=1.0, theta=0.0
% INFO    : Bus 39078	: V=0.9851633, theta=-38.631923 -> V=1.0, theta=0.0
% INFO    : Bus 39079	: V=0.9935029, theta=-37.375731 -> V=1.0, theta=0.0
% INFO    : Bus 39080	: V=0.9936977, theta=-37.150109 -> V=1.0, theta=0.0
% INFO    : Bus 39081	: V=0.9800964, theta=-39.355547 -> V=1.0, theta=0.0
% INFO    : Bus 39082	: V=0.9795385, theta=-40.306792 -> V=1.0, theta=0.0
% INFO    : Bus 39083	: V=0.982304, theta=-39.782178 -> V=1.0, theta=0.0
% INFO    : Bus 39084	: V=0.9783181, theta=-40.346104 -> V=1.0, theta=0.0
% INFO    : Bus 39085	: V=0.9798142, theta=-40.079529 -> V=1.0, theta=0.0
% INFO    : Bus 39086	: V=0.9778156, theta=-40.409054 -> V=1.0, theta=0.0
% INFO    : Bus 39087	: V=0.9385141, theta=-46.471471 -> V=1.0, theta=0.0
% INFO    : Bus 39088	: V=0.941175, theta=-46.309549 -> V=1.0, theta=0.0
% INFO    : Bus 39089	: V=0.9672928, theta=-42.061687 -> V=1.0, theta=0.0
% INFO    : Bus 39090	: V=0.9683023, theta=-41.870716 -> V=1.0, theta=0.0
% INFO    : Bus 39091	: V=0.9519359, theta=-43.696491 -> V=1.0, theta=0.0
% INFO    : Bus 39092	: V=0.9485983, theta=-44.789546 -> V=1.0, theta=0.0
% INFO    : Bus 39093	: V=0.9663707, theta=-42.270465 -> V=1.0, theta=0.0
% INFO    : Bus 39094	: V=0.9655436, theta=-42.512291 -> V=1.0, theta=0.0
% INFO    : Bus 39095	: V=0.9397716, theta=-46.579566 -> V=1.0, theta=0.0
% INFO    : Bus 39096	: V=0.940967, theta=-46.663024 -> V=1.0, theta=0.0
% INFO    : Bus 39097	: V=0.9439594, theta=-46.551435 -> V=1.0, theta=0.0
% INFO    : Bus 39098	: V=0.9537823, theta=-46.467306 -> V=1.0, theta=0.0
% INFO    : Bus 39099	: V=0.9550445, theta=-46.448223 -> V=1.0, theta=0.0
% INFO    : Bus 39100	: V=0.9617835, theta=-43.031845 -> V=1.0, theta=0.0
% INFO    : Bus 39101	: V=0.9481415, theta=-44.608092 -> V=1.0, theta=0.0
% INFO    : Bus 39102	: V=0.9488285, theta=-44.536014 -> V=1.0, theta=0.0
% INFO    : Bus 39103	: V=0.9642422, theta=-42.58266 -> V=1.0, theta=0.0
% INFO    : Bus 39104	: V=0.9647354, theta=-42.487387 -> V=1.0, theta=0.0
% INFO    : Bus 39105	: V=0.9680712, theta=-42.023125 -> V=1.0, theta=0.0
% INFO    : Bus 39106	: V=1.0087447, theta=-15.033804 -> V=1.0, theta=0.0
% INFO    : Bus 39107	: V=0.9909141, theta=-16.595587 -> V=1.0, theta=0.0
% INFO    : Bus 39108	: V=0.9741013, theta=-24.080225 -> V=1.0, theta=0.0
% INFO    : Bus 39109	: V=0.9988406, theta=-18.975793 -> V=1.0, theta=0.0
% INFO    : Bus 39110	: V=0.9964159, theta=-19.593095 -> V=1.0, theta=0.0
% INFO    : Bus 39111	: V=0.9842166, theta=-22.050767 -> V=1.0, theta=0.0
% INFO    : Bus 39112	: V=0.9876189, theta=-21.443091 -> V=1.0, theta=0.0
% INFO    : Bus 39113	: V=0.9913111, theta=-20.840212 -> V=1.0, theta=0.0
% INFO    : Bus 39114	: V=0.9933151, theta=-20.510128 -> V=1.0, theta=0.0
% INFO    : Bus 39115	: V=0.9965287, theta=-20.17578 -> V=1.0, theta=0.0
% INFO    : Bus 39116	: V=0.9839938, theta=-21.048332 -> V=1.0, theta=0.0
% INFO    : Bus 39117	: V=0.9528226, theta=-27.35179 -> V=1.0, theta=0.0
% INFO    : Bus 39118	: V=0.9788702, theta=-24.108174 -> V=1.0, theta=0.0
% INFO    : Bus 39119	: V=0.9709723, theta=-25.468885 -> V=1.0, theta=0.0
% INFO    : Bus 39120	: V=0.9781642, theta=-23.813731 -> V=1.0, theta=0.0
% INFO    : Bus 39121	: V=0.9815457, theta=-23.147579 -> V=1.0, theta=0.0
% INFO    : Bus 39122	: V=0.9754431, theta=-24.367933 -> V=1.0, theta=0.0
% INFO    : Bus 39123	: V=0.9806626, theta=-23.665547 -> V=1.0, theta=0.0
% INFO    : Bus 39124	: V=0.9916234, theta=-21.907808 -> V=1.0, theta=0.0
% INFO    : Bus 39125	: V=0.9949101, theta=-20.844408 -> V=1.0, theta=0.0
% INFO    : Bus 39126	: V=0.9871858, theta=-22.190494 -> V=1.0, theta=0.0
% INFO    : Bus 39127	: V=0.9927749, theta=-21.256515 -> V=1.0, theta=0.0
% INFO    : Bus 39128	: V=0.9401146, theta=-28.103839 -> V=1.0, theta=0.0
% INFO    : Bus 39129	: V=0.96533, theta=-24.433587 -> V=1.0, theta=0.0
% INFO    : Bus 39130	: V=0.9584705, theta=-31.185879 -> V=1.0, theta=0.0
% INFO    : Bus 39131	: V=0.952702, theta=-31.747811 -> V=1.0, theta=0.0
% INFO    : Bus 39132	: V=0.9572206, theta=-29.842908 -> V=1.0, theta=0.0
% INFO    : Bus 39133	: V=0.9532017, theta=-30.153236 -> V=1.0, theta=0.0
% INFO    : Bus 39134	: V=0.9545643, theta=-30.602785 -> V=1.0, theta=0.0
% INFO    : Bus 39135	: V=0.9410491, theta=-32.087817 -> V=1.0, theta=0.0
% INFO    : Bus 39136	: V=0.9537668, theta=-29.747884 -> V=1.0, theta=0.0
% INFO    : Bus 39137	: V=0.9557298, theta=-29.153035 -> V=1.0, theta=0.0
% INFO    : Bus 39138	: V=0.9594895, theta=-28.502649 -> V=1.0, theta=0.0
% INFO    : Bus 39139	: V=0.9962115, theta=-37.707163 -> V=1.0, theta=0.0
% INFO    : Bus 39140	: V=0.9910116, theta=-38.012757 -> V=1.0, theta=0.0
% INFO    : Bus 39141	: V=0.9899887, theta=-38.639834 -> V=1.0, theta=0.0
% INFO    : Bus 39142	: V=0.9886727, theta=-38.917942 -> V=1.0, theta=0.0
% INFO    : Bus 39143	: V=0.9853989, theta=-39.540978 -> V=1.0, theta=0.0
% INFO    : Bus 39144	: V=0.9837965, theta=-38.878552 -> V=1.0, theta=0.0
% INFO    : Bus 39145	: V=0.9874558, theta=-37.921646 -> V=1.0, theta=0.0
% INFO    : Bus 39146	: V=0.9879508, theta=-37.511748 -> V=1.0, theta=0.0
% INFO    : Bus 39147	: V=0.9978552, theta=-36.582254 -> V=1.0, theta=0.0
% INFO    : Bus 39148	: V=0.9980182, theta=-36.317489 -> V=1.0, theta=0.0
% INFO    : Bus 39149	: V=0.9927913, theta=-33.842257 -> V=1.0, theta=0.0
% INFO    : Bus 39150	: V=0.9859183, theta=-35.221004 -> V=1.0, theta=0.0
% INFO    : Bus 39151	: V=0.9585712, theta=-38.763231 -> V=1.0, theta=0.0
% INFO    : Bus 39152	: V=0.9797569, theta=-35.476326 -> V=1.0, theta=0.0
% INFO    : Bus 39153	: V=0.9716515, theta=-37.754486 -> V=1.0, theta=0.0
% INFO    : Bus 39154	: V=0.9703171, theta=-37.590213 -> V=1.0, theta=0.0
% INFO    : Bus 39155	: V=0.9746169, theta=-37.84304 -> V=1.0, theta=0.0
% INFO    : Bus 39156	: V=0.9709957, theta=-37.208331 -> V=1.0, theta=0.0
% INFO    : Bus 39157	: V=0.9734255, theta=-37.36006 -> V=1.0, theta=0.0
% INFO    : Bus 39158	: V=0.9760461, theta=-34.551002 -> V=1.0, theta=0.0
% INFO    : Bus 39159	: V=0.9796743, theta=-24.515863 -> V=1.0, theta=0.0
% INFO    : Bus 39160	: V=0.9738652, theta=-24.735226 -> V=1.0, theta=0.0
% INFO    : Bus 39161	: V=0.9761812, theta=-24.973414 -> V=1.0, theta=0.0
% INFO    : Bus 39162	: V=0.9805431, theta=-24.700999 -> V=1.0, theta=0.0
% INFO    : Bus 39163	: V=0.9785688, theta=-25.064088 -> V=1.0, theta=0.0
% INFO    : Bus 39164	: V=0.9814385, theta=-24.966787 -> V=1.0, theta=0.0
% INFO    : Bus 39165	: V=1.0077315, theta=-22.714318 -> V=1.0, theta=0.0
% INFO    : Bus 39166	: V=1.0036368, theta=-33.428461 -> V=1.0, theta=0.0
% INFO    : Bus 39167	: V=0.9806127, theta=-37.172149 -> V=1.0, theta=0.0
% INFO    : Bus 39168	: V=0.9804089, theta=-34.530417 -> V=1.0, theta=0.0
% INFO    : Bus 39169	: V=0.9901889, theta=-33.468599 -> V=1.0, theta=0.0
% INFO    : Bus 39170	: V=0.9488536, theta=-26.187469 -> V=1.0, theta=0.0
% INFO    : Bus 39171	: V=0.9683314, theta=-22.976702 -> V=1.0, theta=0.0
% INFO    : Bus 39172	: V=0.9686155, theta=-23.03223 -> V=1.0, theta=0.0
% INFO    : Bus 39173	: V=0.9519212, theta=-25.912066 -> V=1.0, theta=0.0
% INFO    : Bus 39174	: V=0.9502757, theta=-26.024806 -> V=1.0, theta=0.0
% INFO    : Bus 39175	: V=0.9528464, theta=-25.835925 -> V=1.0, theta=0.0
% INFO    : Bus 39176	: V=0.9543244, theta=-25.713763 -> V=1.0, theta=0.0
% INFO    : Bus 39177	: V=0.9672144, theta=-23.399707 -> V=1.0, theta=0.0
% INFO    : Bus 39178	: V=0.9656347, theta=-23.508065 -> V=1.0, theta=0.0
% INFO    : Bus 39179	: V=0.9652783, theta=-23.530842 -> V=1.0, theta=0.0
% INFO    : Bus 39180	: V=0.95396, theta=-25.603151 -> V=1.0, theta=0.0
% INFO    : Bus 39181	: V=0.9674057, theta=-23.609872 -> V=1.0, theta=0.0
% INFO    : Bus 39182	: V=0.9854177, theta=-20.907813 -> V=1.0, theta=0.0
% INFO    : Bus 39183	: V=0.9643914, theta=-23.58879 -> V=1.0, theta=0.0
% INFO    : Bus 39184	: V=0.9419862, theta=-26.482356 -> V=1.0, theta=0.0
% INFO    : Bus 39185	: V=0.9618731, theta=-23.724583 -> V=1.0, theta=0.0
% INFO    : Bus 39186	: V=0.9672526, theta=-22.894418 -> V=1.0, theta=0.0
% INFO    : Bus 39187	: V=0.967442, theta=-22.953707 -> V=1.0, theta=0.0
% INFO    : Bus 39188	: V=0.9546373, theta=-24.794796 -> V=1.0, theta=0.0
% INFO    : Bus 39189	: V=0.9668545, theta=-22.897511 -> V=1.0, theta=0.0
% INFO    : Bus 39190	: V=0.9672349, theta=-22.758803 -> V=1.0, theta=0.0
% INFO    : Bus 39191	: V=0.9504588, theta=-25.18748 -> V=1.0, theta=0.0
% INFO    : Bus 39192	: V=0.9695793, theta=-22.712584 -> V=1.0, theta=0.0
% INFO    : Bus 39193	: V=0.9674793, theta=-22.872379 -> V=1.0, theta=0.0
% INFO    : Bus 39194	: V=0.9810595, theta=-21.998987 -> V=1.0, theta=0.0
% INFO    : Bus 39195	: V=0.9346416, theta=-29.389725 -> V=1.0, theta=0.0
% INFO    : Bus 39196	: V=0.9665515, theta=-24.074295 -> V=1.0, theta=0.0
% INFO    : Bus 39197	: V=0.9973941, theta=-27.280357 -> V=1.0, theta=0.0
% INFO    : Bus 39198	: V=0.9937055, theta=-28.010963 -> V=1.0, theta=0.0
% INFO    : Bus 39199	: V=1.0096864, theta=-24.846702 -> V=1.0, theta=0.0
% INFO    : Bus 39200	: V=1.0050371, theta=-26.552005 -> V=1.0, theta=0.0
% INFO    : Bus 39201	: V=1.0188062, theta=-22.816443 -> V=1.0, theta=0.0
% INFO    : Bus 39202	: V=0.9975858, theta=-27.047963 -> V=1.0, theta=0.0
% INFO    : Bus 39203	: V=0.9572811, theta=-36.012031 -> V=1.0, theta=0.0
% INFO    : Bus 39204	: V=0.9553242, theta=-34.431501 -> V=1.0, theta=0.0
% INFO    : Bus 39205	: V=0.9544253, theta=-32.620052 -> V=1.0, theta=0.0
% INFO    : Bus 39206	: V=0.9504418, theta=-34.994768 -> V=1.0, theta=0.0
% INFO    : Bus 39207	: V=0.9544642, theta=-32.432801 -> V=1.0, theta=0.0
% INFO    : Bus 39208	: V=0.9553405, theta=-31.553338 -> V=1.0, theta=0.0
% INFO    : Bus 39209	: V=0.9653223, theta=-27.450224 -> V=1.0, theta=0.0
% INFO    : Bus 39210	: V=0.9469347, theta=-35.622901 -> V=1.0, theta=0.0
% INFO    : Bus 39211	: V=0.9759402, theta=-30.484972 -> V=1.0, theta=0.0
% INFO    : Bus 39212	: V=0.976313, theta=-30.197598 -> V=1.0, theta=0.0
% INFO    : Bus 39213	: V=0.959176, theta=-30.336423 -> V=1.0, theta=0.0
% INFO    : Bus 39214	: V=0.9611073, theta=-30.194673 -> V=1.0, theta=0.0
% INFO    : Bus 39215	: V=0.9752731, theta=-29.815969 -> V=1.0, theta=0.0
% INFO    : Bus 39216	: V=0.963374, theta=-29.881703 -> V=1.0, theta=0.0
% INFO    : Bus 39217	: V=0.9625295, theta=-29.779803 -> V=1.0, theta=0.0
% INFO    : Bus 39218	: V=0.9616472, theta=-29.432832 -> V=1.0, theta=0.0
% INFO    : Bus 39219	: V=0.9620375, theta=-29.720101 -> V=1.0, theta=0.0
% INFO    : Bus 39220	: V=0.9620281, theta=-27.133112 -> V=1.0, theta=0.0
% INFO    : Bus 39221	: V=0.9596949, theta=-28.081119 -> V=1.0, theta=0.0
% INFO    : Bus 39222	: V=0.9606053, theta=-28.491926 -> V=1.0, theta=0.0
% INFO    : Bus 39223	: V=0.9619622, theta=-29.066634 -> V=1.0, theta=0.0
% INFO    : Bus 39224	: V=0.9618589, theta=-29.448775 -> V=1.0, theta=0.0
% INFO    : Bus 39225	: V=0.9703366, theta=-28.675276 -> V=1.0, theta=0.0
% INFO    : Bus 39226	: V=1.017922, theta=-31.20335 -> V=1.0, theta=0.0
% INFO    : Bus 39227	: V=1.0010178, theta=-31.491783 -> V=1.0, theta=0.0
% INFO    : Bus 39228	: V=0.9911742, theta=-31.380306 -> V=1.0, theta=0.0
% INFO    : Bus 39229	: V=0.9923818, theta=-38.77843 -> V=1.0, theta=0.0
% INFO    : Bus 39230	: V=0.9898083, theta=-36.454026 -> V=1.0, theta=0.0
% INFO    : Bus 39231	: V=0.9921111, theta=-35.946909 -> V=1.0, theta=0.0
% INFO    : Bus 39232	: V=0.9777055, theta=-37.979108 -> V=1.0, theta=0.0
% INFO    : Bus 39233	: V=0.982126, theta=-37.932149 -> V=1.0, theta=0.0
% INFO    : Bus 39234	: V=0.9974939, theta=-38.646022 -> V=1.0, theta=0.0
% INFO    : Bus 39235	: V=1.0035242, theta=-38.389317 -> V=1.0, theta=0.0
% INFO    : Bus 39236	: V=0.9937065, theta=-16.856225 -> V=1.0, theta=0.0
% INFO    : Bus 39237	: V=0.9926994, theta=-16.868376 -> V=1.0, theta=0.0
% INFO    : Bus 39238	: V=0.9975523, theta=-16.459007 -> V=1.0, theta=0.0
% INFO    : Bus 39239	: V=0.9907857, theta=-16.917107 -> V=1.0, theta=0.0
% INFO    : Bus 39240	: V=0.9959183, theta=-16.624824 -> V=1.0, theta=0.0
% INFO    : Bus 39241	: V=0.9962702, theta=-16.536742 -> V=1.0, theta=0.0
% INFO    : Bus 39242	: V=0.9956962, theta=-16.65439 -> V=1.0, theta=0.0
% INFO    : Bus 39243	: V=0.9946421, theta=-16.684487 -> V=1.0, theta=0.0
% INFO    : Bus 39244	: V=1.0024852, theta=-15.586215 -> V=1.0, theta=0.0
% INFO    : Bus 39245	: V=0.9992448, theta=-15.978293 -> V=1.0, theta=0.0
% INFO    : Bus 39246	: V=1.00054, theta=-15.854651 -> V=1.0, theta=0.0
% INFO    : Bus 39247	: V=1.0002365, theta=-15.829957 -> V=1.0, theta=0.0
% INFO    : Bus 39248	: V=1.0013064, theta=-15.758248 -> V=1.0, theta=0.0
% INFO    : Bus 39249	: V=1.0147027, theta=-13.821125 -> V=1.0, theta=0.0
% INFO    : Bus 39250	: V=1.0023829, theta=-15.163601 -> V=1.0, theta=0.0
% INFO    : Bus 39251	: V=1.0054626, theta=-15.074397 -> V=1.0, theta=0.0
% INFO    : Bus 39252	: V=1.0061777, theta=-14.949886 -> V=1.0, theta=0.0
% INFO    : Bus 39253	: V=0.998042, theta=-15.488879 -> V=1.0, theta=0.0
% INFO    : Bus 39254	: V=1.0047029, theta=-15.25483 -> V=1.0, theta=0.0
% INFO    : Bus 39255	: V=0.9956111, theta=-16.265361 -> V=1.0, theta=0.0
% INFO    : Bus 39256	: V=1.0017774, theta=-15.62902 -> V=1.0, theta=0.0
% INFO    : Bus 39257	: V=1.0019016, theta=-15.638582 -> V=1.0, theta=0.0
% INFO    : Bus 39258	: V=1.0137027, theta=-13.759645 -> V=1.0, theta=0.0
% INFO    : Bus 39259	: V=1.0159943, theta=-13.667835 -> V=1.0, theta=0.0
% INFO    : Bus 39260	: V=0.9987128, theta=-16.327979 -> V=1.0, theta=0.0
% INFO    : Bus 39261	: V=0.9963916, theta=-18.10276 -> V=1.0, theta=0.0
% INFO    : Bus 39262	: V=0.9904139, theta=-18.084092 -> V=1.0, theta=0.0
% INFO    : Bus 39263	: V=0.9921358, theta=-17.537882 -> V=1.0, theta=0.0
% INFO    : Bus 39264	: V=0.991951, theta=-17.488933 -> V=1.0, theta=0.0
% INFO    : Bus 39265	: V=0.9894188, theta=-17.391589 -> V=1.0, theta=0.0
% INFO    : Bus 39266	: V=0.9899478, theta=-16.752238 -> V=1.0, theta=0.0
% INFO    : Bus 39267	: V=0.9939153, theta=-17.749405 -> V=1.0, theta=0.0
% INFO    : Bus 39268	: V=1.001824, theta=-15.661921 -> V=1.0, theta=0.0
% INFO    : Bus 39269	: V=1.0007896, theta=-15.862287 -> V=1.0, theta=0.0
% INFO    : Bus 39270	: V=0.9969474, theta=-15.546647 -> V=1.0, theta=0.0
% INFO    : Bus 39271	: V=0.9970523, theta=-15.474779 -> V=1.0, theta=0.0
% INFO    : Bus 39272	: V=0.9989049, theta=-16.223403 -> V=1.0, theta=0.0
% INFO    : Bus 39273	: V=0.9953385, theta=-16.763936 -> V=1.0, theta=0.0
% INFO    : Bus 39274	: V=1.0010548, theta=-15.818071 -> V=1.0, theta=0.0
% INFO    : Bus 39275	: V=0.9701002, theta=-30.883875 -> V=1.0, theta=0.0
% INFO    : Bus 39276	: V=0.9628984, theta=-31.768607 -> V=1.0, theta=0.0
% INFO    : Bus 39277	: V=0.9690722, theta=-36.04486 -> V=1.0, theta=0.0
% INFO    : Bus 39278	: V=0.9780056, theta=-35.905982 -> V=1.0, theta=0.0
% INFO    : Bus 39279	: V=0.9875785, theta=-35.664502 -> V=1.0, theta=0.0
% INFO    : Bus 39280	: V=0.9947595, theta=-36.24456 -> V=1.0, theta=0.0
% INFO    : Bus 39281	: V=0.990459, theta=-35.534843 -> V=1.0, theta=0.0
% INFO    : Bus 39282	: V=1.0200657, theta=-12.935212 -> V=1.0, theta=0.0
% INFO    : Bus 39283	: V=1.002202, theta=-15.496382 -> V=1.0, theta=0.0
% INFO    : Bus 39284	: V=0.9982212, theta=-15.077681 -> V=1.0, theta=0.0
% INFO    : Bus 39285	: V=1.0054677, theta=-15.918147 -> V=1.0, theta=0.0
% INFO    : Bus 39286	: V=1.0037245, theta=-16.135456 -> V=1.0, theta=0.0
% INFO    : Bus 39287	: V=1.0228118, theta=-13.382472 -> V=1.0, theta=0.0
% INFO    : Bus 39288	: V=1.019721, theta=-13.425116 -> V=1.0, theta=0.0
% INFO    : Bus 39289	: V=1.0224355, theta=-13.587559 -> V=1.0, theta=0.0
% INFO    : Bus 39290	: V=1.0134148, theta=-14.999669 -> V=1.0, theta=0.0
% INFO    : Bus 39291	: V=1.0069011, theta=-15.98346 -> V=1.0, theta=0.0
% INFO    : Bus 39292	: V=0.935532, theta=-46.220001 -> V=1.0, theta=0.0
% INFO    : Bus 39293	: V=0.9738339, theta=-41.041097 -> V=1.0, theta=0.0
% INFO    : Bus 39294	: V=0.9568488, theta=-43.799884 -> V=1.0, theta=0.0
% INFO    : Bus 39295	: V=0.9432337, theta=-45.841823 -> V=1.0, theta=0.0
% INFO    : Bus 39296	: V=0.9515094, theta=-44.061068 -> V=1.0, theta=0.0
% INFO    : Bus 39297	: V=0.9333483, theta=-48.507532 -> V=1.0, theta=0.0
% INFO    : Bus 39298	: V=0.9383814, theta=-48.760285 -> V=1.0, theta=0.0
% INFO    : Bus 39299	: V=0.9814517, theta=-21.113808 -> V=1.0, theta=0.0
% INFO    : Bus 39300	: V=0.9512824, theta=-27.65901 -> V=1.0, theta=0.0
% INFO    : Bus 39301	: V=0.9661508, theta=-32.255787 -> V=1.0, theta=0.0
% INFO    : Bus 39302	: V=1.0078665, theta=-37.82402 -> V=1.0, theta=0.0
% INFO    : Bus 39303	: V=0.9782785, theta=-37.40599 -> V=1.0, theta=0.0
% INFO    : Bus 39304	: V=0.984811, theta=-37.381747 -> V=1.0, theta=0.0
% INFO    : Bus 39305	: V=0.9624845, theta=-35.326057 -> V=1.0, theta=0.0
% INFO    : Bus 39306	: V=1.0006844, theta=-38.319808 -> V=1.0, theta=0.0
% INFO    : Bus 39307	: V=0.9377124, theta=-47.210747 -> V=1.0, theta=0.0
% INFO    : Bus 39308	: V=0.9426789, theta=-46.255756 -> V=1.0, theta=0.0
% INFO    : Bus 39309	: V=0.9437446, theta=-46.288722 -> V=1.0, theta=0.0
% INFO    : Bus 39310	: V=0.9447889, theta=-47.041481 -> V=1.0, theta=0.0
% INFO    : Bus 39311	: V=0.9439097, theta=-46.056753 -> V=1.0, theta=0.0
% INFO    : Bus 39312	: V=0.9448436, theta=-45.902227 -> V=1.0, theta=0.0
% INFO    : Bus 39313	: V=0.9418185, theta=-48.273087 -> V=1.0, theta=0.0
% INFO    : Bus 39314	: V=0.9466088, theta=-45.402046 -> V=1.0, theta=0.0
% INFO    : Bus 39315	: V=0.9484445, theta=-45.184941 -> V=1.0, theta=0.0
% INFO    : Bus 39316	: V=0.9434502, theta=-47.352189 -> V=1.0, theta=0.0
% INFO    : Bus 39317	: V=0.9522858, theta=-44.631126 -> V=1.0, theta=0.0
% INFO    : Bus 39318	: V=0.9716131, theta=-41.350073 -> V=1.0, theta=0.0
% INFO    : Bus 39319	: V=0.9619465, theta=-42.987868 -> V=1.0, theta=0.0
% INFO    : Bus 39320	: V=0.9481987, theta=-44.807357 -> V=1.0, theta=0.0
% INFO    : Bus 39321	: V=0.9411179, theta=-47.101363 -> V=1.0, theta=0.0
% INFO    : Bus 39322	: V=0.9839246, theta=-35.19123 -> V=1.0, theta=0.0
% INFO    : Bus 39323	: V=0.9969114, theta=-32.045887 -> V=1.0, theta=0.0
% INFO    : Bus 39324	: V=0.9859118, theta=-33.007686 -> V=1.0, theta=0.0
% INFO    : Bus 39325	: V=0.9609055, theta=-36.577101 -> V=1.0, theta=0.0
% INFO    : Bus 39326	: V=0.9771199, theta=-33.597849 -> V=1.0, theta=0.0
% INFO    : Bus 39327	: V=0.9772054, theta=-33.342029 -> V=1.0, theta=0.0
% INFO    : Bus 39328	: V=0.9942278, theta=-36.621819 -> V=1.0, theta=0.0
% INFO    : Bus 39329	: V=1.008712, theta=-34.292463 -> V=1.0, theta=0.0
% INFO    : Bus 39330	: V=1.0014296, theta=-34.947583 -> V=1.0, theta=0.0
% INFO    : Bus 39331	: V=1.0117613, theta=-33.008393 -> V=1.0, theta=0.0
% INFO    : Bus 39332	: V=0.9673536, theta=-36.652428 -> V=1.0, theta=0.0
% INFO    : Bus 39333	: V=1.014618, theta=-32.690464 -> V=1.0, theta=0.0
% INFO    : Bus 39334	: V=1.0195196, theta=-32.662862 -> V=1.0, theta=0.0
% INFO    : Bus 39335	: V=1.0024487, theta=-34.976461 -> V=1.0, theta=0.0
% INFO    : Bus 39336	: V=1.0001313, theta=-35.357565 -> V=1.0, theta=0.0
% INFO    : Bus 39337	: V=0.9979678, theta=-35.885085 -> V=1.0, theta=0.0
% INFO    : Bus 39338	: V=1.0065844, theta=-34.479839 -> V=1.0, theta=0.0
% INFO    : Bus 39339	: V=0.9524816, theta=-40.549405 -> V=1.0, theta=0.0
% INFO    : Bus 39340	: V=0.9731188, theta=-38.152396 -> V=1.0, theta=0.0
% INFO    : Bus 39341	: V=0.9681482, theta=-38.731284 -> V=1.0, theta=0.0
% INFO    : Bus 39342	: V=0.9881944, theta=-20.428141 -> V=1.0, theta=0.0
% INFO    : Bus 39343	: V=0.9606158, theta=-24.931485 -> V=1.0, theta=0.0
% INFO    : Bus 39344	: V=0.9755773, theta=-22.960227 -> V=1.0, theta=0.0
% INFO    : Bus 39345	: V=0.9826602, theta=-22.874903 -> V=1.0, theta=0.0
% INFO    : Bus 39346	: V=0.9670825, theta=-25.349188 -> V=1.0, theta=0.0
% INFO    : Bus 39347	: V=0.9662012, theta=-24.915453 -> V=1.0, theta=0.0
% INFO    : Bus 39348	: V=0.963812, theta=-27.222722 -> V=1.0, theta=0.0
% INFO    : Bus 39349	: V=0.9533002, theta=-25.956335 -> V=1.0, theta=0.0
% INFO    : Bus 39350	: V=0.9582176, theta=-25.82691 -> V=1.0, theta=0.0
% INFO    : Bus 39351	: V=0.9721086, theta=-38.285372 -> V=1.0, theta=0.0
% INFO    : Bus 39352	: V=0.9733019, theta=-22.707196 -> V=1.0, theta=0.0
% INFO    : Bus 39353	: V=0.964687, theta=-40.158843 -> V=1.0, theta=0.0
% INFO    : Bus 39354	: V=0.9664537, theta=-39.504874 -> V=1.0, theta=0.0
% INFO    : Bus 39355	: V=0.9642173, theta=-39.814831 -> V=1.0, theta=0.0
% INFO    : Bus 39356	: V=0.9652015, theta=-37.884314 -> V=1.0, theta=0.0
% INFO    : Bus 39357	: V=0.9623529, theta=-40.05276 -> V=1.0, theta=0.0
% INFO    : Bus 39358	: V=0.9728951, theta=-34.036608 -> V=1.0, theta=0.0
% INFO    : Bus 39359	: V=0.9592203, theta=-41.016299 -> V=1.0, theta=0.0
% INFO    : Bus 39360	: V=0.9547953, theta=-42.549589 -> V=1.0, theta=0.0
% INFO    : Bus 39361	: V=0.9557323, theta=-42.50799 -> V=1.0, theta=0.0
% INFO    : Bus 39362	: V=0.9547583, theta=-42.550405 -> V=1.0, theta=0.0
% INFO    : Bus 39363	: V=0.9634584, theta=-38.077558 -> V=1.0, theta=0.0
% INFO    : Bus 39364	: V=0.9572155, theta=-42.300688 -> V=1.0, theta=0.0
% INFO    : Bus 39365	: V=0.9560354, theta=-42.401901 -> V=1.0, theta=0.0
% INFO    : Bus 39366	: V=0.9605908, theta=-41.755458 -> V=1.0, theta=0.0
% INFO    : Bus 39367	: V=0.9572402, theta=-42.674181 -> V=1.0, theta=0.0
% INFO    : Bus 39368	: V=0.9528193, theta=-45.617239 -> V=1.0, theta=0.0
% INFO    : Bus 39369	: V=0.9596614, theta=-39.32628 -> V=1.0, theta=0.0
% INFO    : Bus 39370	: V=0.9549921, theta=-37.768594 -> V=1.0, theta=0.0
% INFO    : Bus 39371	: V=0.9572342, theta=-37.513197 -> V=1.0, theta=0.0
% INFO    : Bus 39372	: V=0.9630842, theta=-38.062571 -> V=1.0, theta=0.0
% INFO    : Bus 39373	: V=0.9609338, theta=-38.262676 -> V=1.0, theta=0.0
% INFO    : Bus 39374	: V=0.9559185, theta=-40.405957 -> V=1.0, theta=0.0
% INFO    : Bus 39375	: V=0.9570664, theta=-38.506326 -> V=1.0, theta=0.0
% INFO    : Bus 39376	: V=0.955214, theta=-38.437258 -> V=1.0, theta=0.0
% INFO    : Bus 39377	: V=0.9558214, theta=-37.594308 -> V=1.0, theta=0.0
% INFO    : Bus 39378	: V=0.9500825, theta=-42.539522 -> V=1.0, theta=0.0
% INFO    : Bus 39379	: V=0.9535029, theta=-39.765032 -> V=1.0, theta=0.0
% INFO    : Bus 39380	: V=0.9532591, theta=-39.722507 -> V=1.0, theta=0.0
% INFO    : Bus 39381	: V=0.9526889, theta=-39.912848 -> V=1.0, theta=0.0
% INFO    : Bus 39382	: V=0.9470302, theta=-42.678173 -> V=1.0, theta=0.0
% INFO    : Bus 39383	: V=0.9493946, theta=-42.698339 -> V=1.0, theta=0.0
% INFO    : Bus 39384	: V=0.9446423, theta=-43.952707 -> V=1.0, theta=0.0
% INFO    : Bus 39385	: V=0.9470414, theta=-42.764402 -> V=1.0, theta=0.0
% INFO    : Bus 39386	: V=0.9537492, theta=-38.991144 -> V=1.0, theta=0.0
% INFO    : Bus 39387	: V=0.955449, theta=-39.831088 -> V=1.0, theta=0.0
% INFO    : Bus 39388	: V=0.9474602, theta=-42.814101 -> V=1.0, theta=0.0
% INFO    : Bus 39389	: V=0.9491341, theta=-40.815964 -> V=1.0, theta=0.0
% INFO    : Bus 39390	: V=0.9457783, theta=-43.556057 -> V=1.0, theta=0.0
% INFO    : Bus 39391	: V=0.9465954, theta=-43.307006 -> V=1.0, theta=0.0
% INFO    : Bus 39392	: V=0.9463153, theta=-43.271564 -> V=1.0, theta=0.0
% INFO    : Bus 39393	: V=0.9476061, theta=-43.032993 -> V=1.0, theta=0.0
% INFO    : Bus 39394	: V=0.9506497, theta=-40.539667 -> V=1.0, theta=0.0
% INFO    : Bus 39395	: V=0.9496901, theta=-40.729411 -> V=1.0, theta=0.0
% INFO    : Bus 39396	: V=0.9518435, theta=-40.144043 -> V=1.0, theta=0.0
% INFO    : Bus 39397	: V=0.948429, theta=-42.859531 -> V=1.0, theta=0.0
% INFO    : Bus 39398	: V=0.9471012, theta=-42.982593 -> V=1.0, theta=0.0
% INFO    : Bus 39399	: V=0.9530801, theta=-40.103277 -> V=1.0, theta=0.0
% INFO    : Bus 39400	: V=0.9621044, theta=-38.900794 -> V=1.0, theta=0.0
% INFO    : Bus 39401	: V=0.9550245, theta=-39.75489 -> V=1.0, theta=0.0
% INFO    : Bus 39402	: V=0.9534615, theta=-37.407134 -> V=1.0, theta=0.0
% INFO    : Bus 39403	: V=0.9563695, theta=-36.497084 -> V=1.0, theta=0.0
% INFO    : Bus 39404	: V=0.9634671, theta=-36.595942 -> V=1.0, theta=0.0
% INFO    : Bus 39405	: V=0.9467876, theta=-40.161237 -> V=1.0, theta=0.0
% INFO    : Bus 39406	: V=0.9589478, theta=-37.439858 -> V=1.0, theta=0.0
% INFO    : Bus 39407	: V=0.975987, theta=-31.349866 -> V=1.0, theta=0.0
% INFO    : Bus 39408	: V=0.9780829, theta=-31.299419 -> V=1.0, theta=0.0
% INFO    : Bus 39409	: V=0.9595193, theta=-32.29219 -> V=1.0, theta=0.0
% INFO    : Bus 39410	: V=0.9624796, theta=-46.267692 -> V=1.0, theta=0.0
% INFO    : Bus 39411	: V=0.9663347, theta=-46.32226 -> V=1.0, theta=0.0
% INFO    : Bus 39412	: V=0.9580779, theta=-44.613711 -> V=1.0, theta=0.0
% INFO    : Bus 39413	: V=0.9592926, theta=-44.595655 -> V=1.0, theta=0.0
% INFO    : Bus 39414	: V=0.961104, theta=-44.027663 -> V=1.0, theta=0.0
% INFO    : Bus 39415	: V=0.9596468, theta=-44.772062 -> V=1.0, theta=0.0
% INFO    : Bus 39416	: V=0.9611882, theta=-44.86754 -> V=1.0, theta=0.0
% INFO    : Bus 39417	: V=0.9671589, theta=-45.535897 -> V=1.0, theta=0.0
% INFO    : Bus 39418	: V=0.9380561, theta=-48.711123 -> V=1.0, theta=0.0
% INFO    : Bus 39419	: V=0.9742332, theta=-45.13968 -> V=1.0, theta=0.0
% INFO    : Bus 39420	: V=0.9624928, theta=-44.848237 -> V=1.0, theta=0.0
% INFO    : Bus 39421	: V=0.9648215, theta=-44.761586 -> V=1.0, theta=0.0
% INFO    : Bus 39422	: V=0.9769431, theta=-42.869201 -> V=1.0, theta=0.0
% INFO    : Bus 39423	: V=0.9814484, theta=-42.641625 -> V=1.0, theta=0.0
% INFO    : Bus 39424	: V=0.9688643, theta=-44.260167 -> V=1.0, theta=0.0
% INFO    : Bus 39425	: V=0.9932648, theta=-40.921874 -> V=1.0, theta=0.0
% INFO    : Bus 39426	: V=0.9751048, theta=-43.555033 -> V=1.0, theta=0.0
% INFO    : Bus 39427	: V=1.0016853, theta=-39.704885 -> V=1.0, theta=0.0
% INFO    : Bus 39428	: V=0.9532054, theta=-31.197615 -> V=1.0, theta=0.0
% INFO    : Bus 39429	: V=0.9544239, theta=-31.041317 -> V=1.0, theta=0.0
% INFO    : Bus 39430	: V=0.9513107, theta=-31.431373 -> V=1.0, theta=0.0
% INFO    : Bus 39431	: V=0.9480412, theta=-32.050246 -> V=1.0, theta=0.0
% INFO    : Bus 39432	: V=0.9489581, theta=-31.647459 -> V=1.0, theta=0.0
% INFO    : Bus 39433	: V=0.9503247, theta=-31.487553 -> V=1.0, theta=0.0
% INFO    : Bus 39434	: V=0.9464783, theta=-32.295614 -> V=1.0, theta=0.0
% INFO    : Bus 39435	: V=0.9473476, theta=-32.163231 -> V=1.0, theta=0.0
% INFO    : Bus 39436	: V=0.9450184, theta=-32.361814 -> V=1.0, theta=0.0
% INFO    : Bus 39437	: V=0.9513563, theta=-31.031817 -> V=1.0, theta=0.0
% INFO    : Bus 39438	: V=0.9467073, theta=-32.110534 -> V=1.0, theta=0.0
% INFO    : Bus 39439	: V=0.9538543, theta=-30.876991 -> V=1.0, theta=0.0
% INFO    : Bus 39440	: V=0.9551824, theta=-30.75181 -> V=1.0, theta=0.0
% INFO    : Bus 39441	: V=0.9485682, theta=-31.981308 -> V=1.0, theta=0.0
% INFO    : Bus 39442	: V=0.9516318, theta=-31.328456 -> V=1.0, theta=0.0
% INFO    : Bus 39443	: V=0.9485731, theta=-31.978232 -> V=1.0, theta=0.0
% INFO    : Bus 39444	: V=0.9487664, theta=-31.977519 -> V=1.0, theta=0.0
% INFO    : Bus 39445	: V=0.9492214, theta=-31.956889 -> V=1.0, theta=0.0
% INFO    : Bus 39446	: V=0.9545409, theta=-30.976958 -> V=1.0, theta=0.0
% INFO    : Bus 39447	: V=0.9532155, theta=-31.139905 -> V=1.0, theta=0.0
% INFO    : Bus 39448	: V=0.9493118, theta=-31.898959 -> V=1.0, theta=0.0
% INFO    : Bus 39449	: V=0.9568113, theta=-30.577357 -> V=1.0, theta=0.0
% INFO    : Bus 39450	: V=0.9553173, theta=-30.674542 -> V=1.0, theta=0.0
% INFO    : Bus 39451	: V=0.954315, theta=-30.673809 -> V=1.0, theta=0.0
% INFO    : Bus 39452	: V=0.9565204, theta=-30.47483 -> V=1.0, theta=0.0
% INFO    : Bus 39453	: V=0.9587596, theta=-30.378132 -> V=1.0, theta=0.0
% INFO    : Bus 39454	: V=0.9482941, theta=-31.881356 -> V=1.0, theta=0.0
% INFO    : Bus 39455	: V=0.9525826, theta=-31.386118 -> V=1.0, theta=0.0
% INFO    : Bus 39456	: V=0.9501301, theta=-31.816638 -> V=1.0, theta=0.0
% INFO    : Bus 39457	: V=0.9599802, theta=-30.291874 -> V=1.0, theta=0.0
% INFO    : Bus 39458	: V=0.958825, theta=-30.416321 -> V=1.0, theta=0.0
% INFO    : Bus 39459	: V=0.9572483, theta=-30.651294 -> V=1.0, theta=0.0
% INFO    : Bus 39460	: V=0.956098, theta=-30.789658 -> V=1.0, theta=0.0
% INFO    : Bus 39461	: V=0.9550663, theta=-31.246775 -> V=1.0, theta=0.0
% INFO    : Bus 39462	: V=0.9579, theta=-31.013821 -> V=1.0, theta=0.0
% INFO    : Bus 39463	: V=0.9612499, theta=-30.583394 -> V=1.0, theta=0.0
% INFO    : Bus 39464	: V=0.9606951, theta=-30.245119 -> V=1.0, theta=0.0
% INFO    : Bus 39465	: V=0.9586723, theta=-30.482997 -> V=1.0, theta=0.0
% INFO    : Bus 39466	: V=0.9821678, theta=-26.97721 -> V=1.0, theta=0.0
% INFO    : Bus 39467	: V=0.9887429, theta=-26.313273 -> V=1.0, theta=0.0
% INFO    : Bus 39468	: V=0.9872085, theta=-26.517201 -> V=1.0, theta=0.0
% INFO    : Bus 39469	: V=0.9865902, theta=-26.637656 -> V=1.0, theta=0.0
% INFO    : Bus 39470	: V=0.9851491, theta=-26.728097 -> V=1.0, theta=0.0
% INFO    : Bus 39471	: V=0.9742102, theta=-28.449761 -> V=1.0, theta=0.0
% INFO    : Bus 39472	: V=0.9771929, theta=-27.952283 -> V=1.0, theta=0.0
% INFO    : Bus 39473	: V=0.9636764, theta=-29.492604 -> V=1.0, theta=0.0
% INFO    : Bus 39474	: V=0.9611262, theta=-30.149477 -> V=1.0, theta=0.0
% INFO    : Bus 39475	: V=0.9535697, theta=-31.530348 -> V=1.0, theta=0.0
% INFO    : Bus 39476	: V=0.9539902, theta=-31.525064 -> V=1.0, theta=0.0
% INFO    : Bus 39477	: V=0.9635147, theta=-29.959679 -> V=1.0, theta=0.0
% INFO    : Bus 39478	: V=0.9609481, theta=-30.199973 -> V=1.0, theta=0.0
% INFO    : Bus 39479	: V=0.9608626, theta=-29.983749 -> V=1.0, theta=0.0
% INFO    : Bus 39480	: V=0.9627147, theta=-29.801339 -> V=1.0, theta=0.0
% INFO    : Bus 39481	: V=0.9643809, theta=-29.629704 -> V=1.0, theta=0.0
% INFO    : Bus 39482	: V=0.9521256, theta=-31.168206 -> V=1.0, theta=0.0
% INFO    : Bus 39483	: V=0.958758, theta=-30.232145 -> V=1.0, theta=0.0
% INFO    : Bus 39484	: V=0.9512494, theta=-31.210821 -> V=1.0, theta=0.0
% INFO    : Bus 39485	: V=0.9571868, theta=-30.347056 -> V=1.0, theta=0.0
% INFO    : Bus 39486	: V=0.9583815, theta=-30.219565 -> V=1.0, theta=0.0
% INFO    : Bus 39487	: V=0.9606511, theta=-30.435772 -> V=1.0, theta=0.0
% INFO    : Bus 39488	: V=0.9831766, theta=-27.259844 -> V=1.0, theta=0.0
% INFO    : Bus 39489	: V=0.9736284, theta=-28.521199 -> V=1.0, theta=0.0
% INFO    : Bus 39490	: V=0.9822682, theta=-27.317583 -> V=1.0, theta=0.0
% INFO    : Bus 39491	: V=0.9626315, theta=-29.785222 -> V=1.0, theta=0.0
% INFO    : Bus 39492	: V=0.9600245, theta=-30.038886 -> V=1.0, theta=0.0
% INFO    : Bus 39493	: V=0.9667024, theta=-29.364117 -> V=1.0, theta=0.0
% INFO    : Bus 39494	: V=0.9647059, theta=-29.516267 -> V=1.0, theta=0.0
% INFO    : Bus 39495	: V=0.9653345, theta=-29.350045 -> V=1.0, theta=0.0
% INFO    : Bus 39496	: V=0.955513, theta=-30.494719 -> V=1.0, theta=0.0
% INFO    : Bus 39497	: V=0.9545585, theta=-30.566043 -> V=1.0, theta=0.0
% INFO    : Bus 39498	: V=0.9493559, theta=-31.199508 -> V=1.0, theta=0.0
% INFO    : Bus 39499	: V=0.9502998, theta=-31.136936 -> V=1.0, theta=0.0
% INFO    : Bus 39500	: V=0.941672, theta=-32.797809 -> V=1.0, theta=0.0
% INFO    : Bus 39501	: V=0.9423928, theta=-32.552961 -> V=1.0, theta=0.0
% INFO    : Bus 39502	: V=0.9552333, theta=-30.322905 -> V=1.0, theta=0.0
% INFO    : Bus 39503	: V=0.9623199, theta=-29.529655 -> V=1.0, theta=0.0
% INFO    : Bus 39504	: V=0.9618846, theta=-29.547516 -> V=1.0, theta=0.0
% INFO    : Bus 39505	: V=0.9614351, theta=-29.559221 -> V=1.0, theta=0.0
% INFO    : Bus 39506	: V=0.9580571, theta=-29.988622 -> V=1.0, theta=0.0
% INFO    : Bus 39507	: V=0.954658, theta=-30.364591 -> V=1.0, theta=0.0
% INFO    : Bus 39508	: V=0.9475083, theta=-31.368126 -> V=1.0, theta=0.0
% INFO    : Bus 39509	: V=0.9408077, theta=-33.110608 -> V=1.0, theta=0.0
% INFO    : Bus 39510	: V=0.9379824, theta=-33.822206 -> V=1.0, theta=0.0
% INFO    : Bus 39511	: V=0.9446102, theta=-32.149225 -> V=1.0, theta=0.0
% INFO    : Bus 39512	: V=0.9466638, theta=-31.969939 -> V=1.0, theta=0.0
% INFO    : Bus 39513	: V=0.9485722, theta=-31.78002 -> V=1.0, theta=0.0
% INFO    : Bus 39514	: V=0.9450024, theta=-32.087516 -> V=1.0, theta=0.0
% INFO    : Bus 39515	: V=0.9469552, theta=-31.87608 -> V=1.0, theta=0.0
% INFO    : Bus 39516	: V=0.9433693, theta=-32.242538 -> V=1.0, theta=0.0
% INFO    : Bus 39517	: V=0.968059, theta=-28.927649 -> V=1.0, theta=0.0
% INFO    : Bus 39518	: V=0.9660373, theta=-28.843926 -> V=1.0, theta=0.0
% INFO    : Bus 39519	: V=0.9544824, theta=-30.956445 -> V=1.0, theta=0.0
% INFO    : Bus 39520	: V=0.9667431, theta=-28.769253 -> V=1.0, theta=0.0
% INFO    : Bus 39521	: V=0.9647651, theta=-29.116153 -> V=1.0, theta=0.0
% INFO    : Bus 39522	: V=0.9505721, theta=-30.843171 -> V=1.0, theta=0.0
% INFO    : Bus 39523	: V=0.9677709, theta=-28.663931 -> V=1.0, theta=0.0
% INFO    : Bus 39524	: V=0.9660509, theta=-28.825278 -> V=1.0, theta=0.0
% INFO    : Bus 39525	: V=0.9737758, theta=-28.229219 -> V=1.0, theta=0.0
% INFO    : Bus 39526	: V=0.9718938, theta=-28.38508 -> V=1.0, theta=0.0
% INFO    : Bus 39527	: V=0.9504304, theta=-31.374028 -> V=1.0, theta=0.0
% INFO    : Bus 39528	: V=0.9487155, theta=-31.962068 -> V=1.0, theta=0.0
% INFO    : Bus 39529	: V=0.9567347, theta=-30.746975 -> V=1.0, theta=0.0
% INFO    : Bus 39530	: V=0.9778529, theta=-27.446545 -> V=1.0, theta=0.0
% INFO    : Bus 39531	: V=0.9616935, theta=-30.097764 -> V=1.0, theta=0.0
% INFO    : Bus 39532	: V=0.9826882, theta=-26.937661 -> V=1.0, theta=0.0
% INFO    : Bus 39533	: V=0.9814189, theta=-27.03342 -> V=1.0, theta=0.0
% INFO    : Bus 39534	: V=0.9633022, theta=-29.48065 -> V=1.0, theta=0.0
% INFO    : Bus 39535	: V=0.932748, theta=-33.528462 -> V=1.0, theta=0.0
% INFO    : Bus 39536	: V=0.9289329, theta=-33.533618 -> V=1.0, theta=0.0
% INFO    : Bus 39537	: V=0.9404153, theta=-31.829321 -> V=1.0, theta=0.0
% INFO    : Bus 39538	: V=0.9382592, theta=-32.813603 -> V=1.0, theta=0.0
% INFO    : Bus 39539	: V=0.9402089, theta=-32.193085 -> V=1.0, theta=0.0
% INFO    : Bus 39540	: V=0.9389815, theta=-32.278801 -> V=1.0, theta=0.0
% INFO    : Bus 39541	: V=0.9212602, theta=-35.872925 -> V=1.0, theta=0.0
% INFO    : Bus 39542	: V=0.9395406, theta=-33.114984 -> V=1.0, theta=0.0
% INFO    : Bus 39543	: V=0.9466542, theta=-31.725018 -> V=1.0, theta=0.0
% INFO    : Bus 39544	: V=0.9364353, theta=-33.162046 -> V=1.0, theta=0.0
% INFO    : Bus 39545	: V=0.9434158, theta=-31.969724 -> V=1.0, theta=0.0
% INFO    : Bus 39546	: V=0.9445299, theta=-31.893158 -> V=1.0, theta=0.0
% INFO    : Bus 39547	: V=0.9417826, theta=-32.069807 -> V=1.0, theta=0.0
% INFO    : Bus 39548	: V=0.9428117, theta=-31.973366 -> V=1.0, theta=0.0
% INFO    : Bus 39549	: V=0.9439979, theta=-31.859732 -> V=1.0, theta=0.0
% INFO    : Bus 39550	: V=0.9388303, theta=-33.001112 -> V=1.0, theta=0.0
% INFO    : Bus 39551	: V=0.9455513, theta=-31.551699 -> V=1.0, theta=0.0
% INFO    : Bus 39552	: V=0.9440012, theta=-31.702778 -> V=1.0, theta=0.0
% INFO    : Bus 39553	: V=0.9433546, theta=-31.758529 -> V=1.0, theta=0.0
% INFO    : Bus 39554	: V=0.9464283, theta=-30.987108 -> V=1.0, theta=0.0
% INFO    : Bus 39555	: V=0.9424973, theta=-31.715715 -> V=1.0, theta=0.0
% INFO    : Bus 39556	: V=0.9426198, theta=-31.770182 -> V=1.0, theta=0.0
% INFO    : Bus 39557	: V=0.9425717, theta=-31.65139 -> V=1.0, theta=0.0
% INFO    : Bus 39558	: V=0.9432847, theta=-31.442355 -> V=1.0, theta=0.0
% INFO    : Bus 39559	: V=0.9369466, theta=-32.674594 -> V=1.0, theta=0.0
% INFO    : Bus 39560	: V=0.9411999, theta=-32.105689 -> V=1.0, theta=0.0
% INFO    : Bus 39561	: V=0.9430942, theta=-31.849993 -> V=1.0, theta=0.0
% INFO    : Bus 39562	: V=0.9428425, theta=-31.801465 -> V=1.0, theta=0.0
% INFO    : Bus 39563	: V=0.9378921, theta=-31.231677 -> V=1.0, theta=0.0
% INFO    : Bus 39564	: V=0.9500515, theta=-29.943794 -> V=1.0, theta=0.0
% INFO    : Bus 39565	: V=0.9472417, theta=-30.624007 -> V=1.0, theta=0.0
% INFO    : Bus 39566	: V=0.9485899, theta=-30.589256 -> V=1.0, theta=0.0
% INFO    : Bus 39567	: V=0.9462529, theta=-30.899769 -> V=1.0, theta=0.0
% INFO    : Bus 39568	: V=0.9494231, theta=-30.283817 -> V=1.0, theta=0.0
% INFO    : Bus 39569	: V=0.9478551, theta=-30.5693 -> V=1.0, theta=0.0
% INFO    : Bus 39570	: V=0.9653657, theta=-28.326906 -> V=1.0, theta=0.0
% INFO    : Bus 39571	: V=0.9501283, theta=-30.780842 -> V=1.0, theta=0.0
% INFO    : Bus 39572	: V=0.9479801, theta=-30.943767 -> V=1.0, theta=0.0
% INFO    : Bus 39573	: V=0.9470157, theta=-30.980987 -> V=1.0, theta=0.0
% INFO    : Bus 39574	: V=0.9526011, theta=-30.278589 -> V=1.0, theta=0.0
% INFO    : Bus 39575	: V=0.9447588, theta=-32.022306 -> V=1.0, theta=0.0
% INFO    : Bus 39576	: V=0.9537626, theta=-30.145516 -> V=1.0, theta=0.0
% INFO    : Bus 39577	: V=0.9534484, theta=-30.161573 -> V=1.0, theta=0.0
% INFO    : Bus 39578	: V=0.9523419, theta=-30.239698 -> V=1.0, theta=0.0
% INFO    : Bus 39579	: V=0.9516113, theta=-30.29837 -> V=1.0, theta=0.0
% INFO    : Bus 39580	: V=0.9526792, theta=-30.22476 -> V=1.0, theta=0.0
% INFO    : Bus 39581	: V=0.9548667, theta=-30.035834 -> V=1.0, theta=0.0
% INFO    : Bus 39582	: V=0.9469341, theta=-31.440529 -> V=1.0, theta=0.0
% INFO    : Bus 39583	: V=0.960637, theta=-29.28969 -> V=1.0, theta=0.0
% INFO    : Bus 39584	: V=0.957576, theta=-29.673454 -> V=1.0, theta=0.0
% INFO    : Bus 39585	: V=0.9493881, theta=-30.513919 -> V=1.0, theta=0.0
% INFO    : Bus 39586	: V=0.9444261, theta=-31.594339 -> V=1.0, theta=0.0
% INFO    : Bus 39587	: V=0.9528359, theta=-30.538887 -> V=1.0, theta=0.0
% INFO    : Bus 39588	: V=0.9594702, theta=-29.55354 -> V=1.0, theta=0.0
% INFO    : Bus 39589	: V=0.9521657, theta=-30.793535 -> V=1.0, theta=0.0
% INFO    : Bus 39590	: V=0.9524177, theta=-30.714938 -> V=1.0, theta=0.0
% INFO    : Bus 39591	: V=0.9496618, theta=-30.856607 -> V=1.0, theta=0.0
% INFO    : Bus 39592	: V=0.9622158, theta=-29.198318 -> V=1.0, theta=0.0
% INFO    : Bus 39593	: V=0.9529431, theta=-30.243894 -> V=1.0, theta=0.0
% INFO    : Bus 39594	: V=0.9538475, theta=-30.251296 -> V=1.0, theta=0.0
% INFO    : Bus 39595	: V=0.96488, theta=-28.629486 -> V=1.0, theta=0.0
% INFO    : Bus 39596	: V=0.9583638, theta=-29.58476 -> V=1.0, theta=0.0
% INFO    : Bus 39597	: V=0.9530589, theta=-30.29428 -> V=1.0, theta=0.0
% INFO    : Bus 39598	: V=0.9668997, theta=-28.460795 -> V=1.0, theta=0.0
% INFO    : Bus 39599	: V=0.9523844, theta=-30.776547 -> V=1.0, theta=0.0
% INFO    : Bus 39600	: V=0.9591063, theta=-29.512063 -> V=1.0, theta=0.0
% INFO    : Bus 39601	: V=0.9607575, theta=-29.354113 -> V=1.0, theta=0.0
% INFO    : Bus 39602	: V=0.9636773, theta=-28.709124 -> V=1.0, theta=0.0
% INFO    : Bus 39603	: V=0.9640665, theta=-28.496262 -> V=1.0, theta=0.0
% INFO    : Bus 39604	: V=0.9644622, theta=-28.485948 -> V=1.0, theta=0.0
% INFO    : Bus 39605	: V=0.9838196, theta=-26.013479 -> V=1.0, theta=0.0
% INFO    : Bus 39606	: V=0.9645272, theta=-28.486594 -> V=1.0, theta=0.0
% INFO    : Bus 39607	: V=0.9633348, theta=-28.535111 -> V=1.0, theta=0.0
% INFO    : Bus 39608	: V=0.9679275, theta=-28.249036 -> V=1.0, theta=0.0
% INFO    : Bus 39609	: V=0.9663779, theta=-28.38458 -> V=1.0, theta=0.0
% INFO    : Bus 39610	: V=0.9513322, theta=-30.804113 -> V=1.0, theta=0.0
% INFO    : Bus 39611	: V=0.9649269, theta=-28.92243 -> V=1.0, theta=0.0
% INFO    : Bus 39612	: V=0.9532606, theta=-30.242534 -> V=1.0, theta=0.0
% INFO    : Bus 39613	: V=0.9644034, theta=-28.969647 -> V=1.0, theta=0.0
% INFO    : Bus 39614	: V=0.9651269, theta=-28.894611 -> V=1.0, theta=0.0
% INFO    : Bus 39615	: V=0.9539186, theta=-30.53326 -> V=1.0, theta=0.0
% INFO    : Bus 39616	: V=0.9665407, theta=-28.76845 -> V=1.0, theta=0.0
% INFO    : Bus 39617	: V=0.9685563, theta=-28.528053 -> V=1.0, theta=0.0
% INFO    : Bus 39618	: V=0.9542949, theta=-30.201883 -> V=1.0, theta=0.0
% INFO    : Bus 39619	: V=0.9636462, theta=-28.699971 -> V=1.0, theta=0.0
% INFO    : Bus 39620	: V=0.9562136, theta=-30.153628 -> V=1.0, theta=0.0
% INFO    : Bus 39621	: V=0.95378, theta=-30.318627 -> V=1.0, theta=0.0
% INFO    : Bus 39622	: V=0.964328, theta=-28.641003 -> V=1.0, theta=0.0
% INFO    : Bus 39623	: V=0.9651796, theta=-28.580279 -> V=1.0, theta=0.0
% INFO    : Bus 39624	: V=0.9511686, theta=-30.494138 -> V=1.0, theta=0.0
% INFO    : Bus 39625	: V=0.9528732, theta=-30.46079 -> V=1.0, theta=0.0
% INFO    : Bus 39626	: V=0.9730271, theta=-28.199108 -> V=1.0, theta=0.0
% INFO    : Bus 39627	: V=0.9820541, theta=-27.56 -> V=1.0, theta=0.0
% INFO    : Bus 39628	: V=0.9825687, theta=-27.529429 -> V=1.0, theta=0.0
% INFO    : Bus 39629	: V=0.9975517, theta=-25.907148 -> V=1.0, theta=0.0
% INFO    : Bus 39630	: V=0.9986318, theta=-25.815527 -> V=1.0, theta=0.0
% INFO    : Bus 39631	: V=0.9849659, theta=-27.25883 -> V=1.0, theta=0.0
% INFO    : Bus 39632	: V=0.9829359, theta=-27.736311 -> V=1.0, theta=0.0
% INFO    : Bus 39633	: V=0.9874659, theta=-26.998565 -> V=1.0, theta=0.0
% INFO    : Bus 39634	: V=0.9903416, theta=-26.698348 -> V=1.0, theta=0.0
% INFO    : Bus 39635	: V=1.0174922, theta=-22.173489 -> V=1.0, theta=0.0
% INFO    : Bus 39636	: V=1.0139339, theta=-22.247129 -> V=1.0, theta=0.0
% INFO    : Bus 39637	: V=1.0153423, theta=-22.230211 -> V=1.0, theta=0.0
% INFO    : Bus 39638	: V=0.9811089, theta=-27.946684 -> V=1.0, theta=0.0
% INFO    : Bus 39639	: V=0.9791614, theta=-28.007904 -> V=1.0, theta=0.0
% INFO    : Bus 39640	: V=1.0049958, theta=-24.182533 -> V=1.0, theta=0.0
% INFO    : Bus 39641	: V=1.0035123, theta=-24.339927 -> V=1.0, theta=0.0
% INFO    : Bus 39642	: V=0.9884672, theta=-26.670246 -> V=1.0, theta=0.0
% INFO    : Bus 39643	: V=1.008359, theta=-22.46683 -> V=1.0, theta=0.0
% INFO    : Bus 39644	: V=1.0016278, theta=-25.561153 -> V=1.0, theta=0.0
% INFO    : Bus 39645	: V=0.9772901, theta=-27.923259 -> V=1.0, theta=0.0
% INFO    : Bus 39646	: V=1.018411, theta=-22.338283 -> V=1.0, theta=0.0
% INFO    : Bus 39647	: V=1.0125351, theta=-23.233796 -> V=1.0, theta=0.0
% INFO    : Bus 39648	: V=0.9564239, theta=-29.883738 -> V=1.0, theta=0.0
% INFO    : Bus 39649	: V=1.0116742, theta=-33.569959 -> V=1.0, theta=0.0
% INFO    : Bus 39650	: V=1.0114602, theta=-33.772985 -> V=1.0, theta=0.0
% INFO    : Bus 39651	: V=1.0056665, theta=-34.024285 -> V=1.0, theta=0.0
% INFO    : Bus 39652	: V=0.9946224, theta=-37.74368 -> V=1.0, theta=0.0
% INFO    : Bus 39653	: V=0.9839221, theta=-38.661572 -> V=1.0, theta=0.0
% INFO    : Bus 39654	: V=0.9846927, theta=-14.621708 -> V=1.0, theta=0.0
% INFO    : Bus 39655	: V=1.0204168, theta=-13.145695 -> V=1.0, theta=0.0
% INFO    : Bus 39656	: V=1.0057147, theta=-13.318285 -> V=1.0, theta=0.0
% INFO    : Bus 39657	: V=1.0065926, theta=-12.787039 -> V=1.0, theta=0.0
% INFO    : Bus 39658	: V=0.9895726, theta=-44.868314 -> V=1.0, theta=0.0
% INFO    : Bus 39659	: V=0.9608527, theta=-51.5216 -> V=1.0, theta=0.0
% INFO    : Bus 39660	: V=0.9637651, theta=-51.827666 -> V=1.0, theta=0.0
% INFO    : Bus 39661	: V=0.9580086, theta=-51.539133 -> V=1.0, theta=0.0
% INFO    : Bus 39662	: V=0.9372267, theta=-54.536849 -> V=1.0, theta=0.0
% INFO    : Bus 39663	: V=0.9831083, theta=-49.59005 -> V=1.0, theta=0.0
% INFO    : Bus 39664	: V=0.9347039, theta=-54.655037 -> V=1.0, theta=0.0
% INFO    : Bus 39665	: V=0.9889935, theta=-50.033422 -> V=1.0, theta=0.0
% INFO    : Bus 39666	: V=0.9935382, theta=-49.612364 -> V=1.0, theta=0.0
% INFO    : Bus 39667	: V=1.0011511, theta=-50.033539 -> V=1.0, theta=0.0
% INFO    : Bus 39668	: V=0.995509, theta=-50.266411 -> V=1.0, theta=0.0
% INFO    : Bus 39669	: V=0.9522847, theta=-52.128906 -> V=1.0, theta=0.0
% INFO    : Bus 39670	: V=0.9588445, theta=-51.732126 -> V=1.0, theta=0.0
% INFO    : Bus 39671	: V=0.9609407, theta=-51.888337 -> V=1.0, theta=0.0
% INFO    : Bus 39672	: V=0.9609012, theta=-51.894806 -> V=1.0, theta=0.0
% INFO    : Bus 39673	: V=0.9376861, theta=-54.479182 -> V=1.0, theta=0.0
% INFO    : Bus 39674	: V=0.937777, theta=-54.46135 -> V=1.0, theta=0.0
% INFO    : Bus 39675	: V=0.9323794, theta=-54.919765 -> V=1.0, theta=0.0
% INFO    : Bus 39676	: V=0.9534835, theta=-51.973179 -> V=1.0, theta=0.0
% INFO    : Bus 39677	: V=0.9291401, theta=-55.11708 -> V=1.0, theta=0.0
% INFO    : Bus 39678	: V=0.9303303, theta=-55.936911 -> V=1.0, theta=0.0
% INFO    : Bus 39679	: V=0.9212846, theta=-57.854035 -> V=1.0, theta=0.0
% INFO    : Bus 39680	: V=0.9317186, theta=-57.22811 -> V=1.0, theta=0.0
% INFO    : Bus 39681	: V=0.9303032, theta=-57.803135 -> V=1.0, theta=0.0
% INFO    : Bus 39682	: V=0.9288184, theta=-61.528222 -> V=1.0, theta=0.0
% INFO    : Bus 39683	: V=0.9286479, theta=-58.388722 -> V=1.0, theta=0.0
% INFO    : Bus 39684	: V=0.9278413, theta=-58.58315 -> V=1.0, theta=0.0
% INFO    : Bus 39685	: V=0.9352126, theta=-63.191316 -> V=1.0, theta=0.0
% INFO    : Bus 39686	: V=0.9389844, theta=-63.474397 -> V=1.0, theta=0.0
% INFO    : Bus 39687	: V=0.930961, theta=-63.20535 -> V=1.0, theta=0.0
% INFO    : Bus 39688	: V=0.9444295, theta=-64.214948 -> V=1.0, theta=0.0
% INFO    : Bus 39689	: V=0.9315227, theta=-61.825489 -> V=1.0, theta=0.0
% INFO    : Bus 39690	: V=0.9448795, theta=-64.0245 -> V=1.0, theta=0.0
% INFO    : Bus 39691	: V=0.9644527, theta=-51.981783 -> V=1.0, theta=0.0
% INFO    : Bus 39692	: V=0.9414599, theta=-57.24119 -> V=1.0, theta=0.0
% INFO    : Bus 39693	: V=0.9263104, theta=-57.127261 -> V=1.0, theta=0.0
% INFO    : Bus 39694	: V=0.9342312, theta=-56.335974 -> V=1.0, theta=0.0
% INFO    : Bus 39695	: V=0.9825281, theta=-50.523083 -> V=1.0, theta=0.0
% INFO    : Bus 39696	: V=0.9878649, theta=-49.877094 -> V=1.0, theta=0.0
% INFO    : Bus 39697	: V=0.9847476, theta=-31.015169 -> V=1.0, theta=0.0
% INFO    : Bus 39698	: V=0.9832683, theta=-30.018279 -> V=1.0, theta=0.0
% INFO    : Bus 39699	: V=0.9708073, theta=-36.850782 -> V=1.0, theta=0.0
% INFO    : Bus 39700	: V=0.9548064, theta=-38.769499 -> V=1.0, theta=0.0
% INFO    : Bus 39701	: V=0.9675116, theta=-37.142322 -> V=1.0, theta=0.0
% INFO    : Bus 39702	: V=0.9611788, theta=-39.850606 -> V=1.0, theta=0.0
% INFO    : Bus 39703	: V=0.9693393, theta=-38.88664 -> V=1.0, theta=0.0
% INFO    : Bus 39704	: V=0.9707178, theta=-38.825898 -> V=1.0, theta=0.0
% INFO    : Bus 39705	: V=0.965812, theta=-39.420634 -> V=1.0, theta=0.0
% INFO    : Bus 39706	: V=0.9583219, theta=-40.123144 -> V=1.0, theta=0.0
% INFO    : Bus 39707	: V=0.9659412, theta=-39.123611 -> V=1.0, theta=0.0
% INFO    : Bus 39708	: V=0.9646802, theta=-39.486559 -> V=1.0, theta=0.0
% INFO    : Bus 39709	: V=0.9689139, theta=-38.982125 -> V=1.0, theta=0.0
% INFO    : Bus 39710	: V=0.9775666, theta=-37.469649 -> V=1.0, theta=0.0
% INFO    : Bus 39711	: V=0.975085, theta=-37.93911 -> V=1.0, theta=0.0
% INFO    : Bus 39712	: V=0.9852391, theta=-35.216115 -> V=1.0, theta=0.0
% INFO    : Bus 39713	: V=0.9790832, theta=-37.584436 -> V=1.0, theta=0.0
% INFO    : Bus 39714	: V=0.9791347, theta=-37.441012 -> V=1.0, theta=0.0
% INFO    : Bus 39715	: V=0.9864842, theta=-31.863832 -> V=1.0, theta=0.0
% INFO    : Bus 39716	: V=0.9875544, theta=-32.11275 -> V=1.0, theta=0.0
% INFO    : Bus 39717	: V=1.0018935, theta=-31.41173 -> V=1.0, theta=0.0
% INFO    : Bus 39718	: V=0.9895017, theta=-32.941568 -> V=1.0, theta=0.0
% INFO    : Bus 39719	: V=0.9889677, theta=-33.406138 -> V=1.0, theta=0.0
% INFO    : Bus 39720	: V=1.0147858, theta=-30.236917 -> V=1.0, theta=0.0
% INFO    : Bus 39721	: V=0.9909329, theta=-33.036787 -> V=1.0, theta=0.0
% INFO    : Bus 39722	: V=0.9905404, theta=-32.98849 -> V=1.0, theta=0.0
% INFO    : Bus 39723	: V=0.984209, theta=-35.577987 -> V=1.0, theta=0.0
% INFO    : Bus 39724	: V=0.9755047, theta=-37.89394 -> V=1.0, theta=0.0
% INFO    : Bus 39725	: V=0.980301, theta=-37.110778 -> V=1.0, theta=0.0
% INFO    : Bus 39726	: V=0.9808674, theta=-36.664193 -> V=1.0, theta=0.0
% INFO    : Bus 39727	: V=0.984602, theta=-35.357385 -> V=1.0, theta=0.0
% INFO    : Bus 39728	: V=0.9811103, theta=-37.44284 -> V=1.0, theta=0.0
% INFO    : Bus 39729	: V=0.9873475, theta=-33.83142 -> V=1.0, theta=0.0
% INFO    : Bus 39730	: V=0.9887275, theta=-33.377459 -> V=1.0, theta=0.0
% INFO    : Bus 39731	: V=0.9866524, theta=-34.943716 -> V=1.0, theta=0.0
% INFO    : Bus 39732	: V=0.9889306, theta=-33.576773 -> V=1.0, theta=0.0
% INFO    : Bus 39733	: V=0.9912506, theta=-33.355751 -> V=1.0, theta=0.0
% INFO    : Bus 39734	: V=0.9899232, theta=-33.38132 -> V=1.0, theta=0.0
% INFO    : Bus 39735	: V=0.9852419, theta=-35.28704 -> V=1.0, theta=0.0
% INFO    : Bus 39736	: V=0.9789166, theta=-37.608079 -> V=1.0, theta=0.0
% INFO    : Bus 39737	: V=0.9889144, theta=-33.749066 -> V=1.0, theta=0.0
% INFO    : Bus 39738	: V=0.9898513, theta=-33.63874 -> V=1.0, theta=0.0
% INFO    : Bus 39739	: V=0.9241459, theta=-33.289386 -> V=1.0, theta=0.0
% INFO    : Bus 39740	: V=0.9543388, theta=-28.398031 -> V=1.0, theta=0.0
% INFO    : Bus 39741	: V=0.9488622, theta=-29.825639 -> V=1.0, theta=0.0
% INFO    : Bus 39742	: V=0.9442652, theta=-30.863778 -> V=1.0, theta=0.0
% INFO    : Bus 39743	: V=0.9511037, theta=-29.119324 -> V=1.0, theta=0.0
% INFO    : Bus 39744	: V=0.9598165, theta=-27.281479 -> V=1.0, theta=0.0
% INFO    : Bus 39745	: V=0.9559589, theta=-28.594602 -> V=1.0, theta=0.0
% INFO    : Bus 39746	: V=0.9656064, theta=-26.269726 -> V=1.0, theta=0.0
% INFO    : Bus 39747	: V=0.9984699, theta=-20.42817 -> V=1.0, theta=0.0
% INFO    : Bus 39748	: V=0.967609, theta=-26.180036 -> V=1.0, theta=0.0
% INFO    : Bus 39749	: V=0.9531637, theta=-29.138025 -> V=1.0, theta=0.0
% INFO    : Bus 39750	: V=0.9535465, theta=-27.454235 -> V=1.0, theta=0.0
% INFO    : Bus 39751	: V=0.9447176, theta=-28.937905 -> V=1.0, theta=0.0
% INFO    : Bus 39752	: V=0.9815633, theta=-34.162053 -> V=1.0, theta=0.0
% INFO    : Bus 39753	: V=0.9833897, theta=-33.426014 -> V=1.0, theta=0.0
% INFO    : Bus 39754	: V=0.928366, theta=-55.275852 -> V=1.0, theta=0.0
% INFO    : Bus 39755	: V=0.9215737, theta=-55.996554 -> V=1.0, theta=0.0
% INFO    : Bus 39756	: V=0.9411123, theta=-53.747823 -> V=1.0, theta=0.0
% INFO    : Bus 39757	: V=0.9200003, theta=-56.145825 -> V=1.0, theta=0.0
% INFO    : Bus 39758	: V=0.9510408, theta=-45.931286 -> V=1.0, theta=0.0
% INFO    : Bus 39759	: V=0.9613747, theta=-43.63979 -> V=1.0, theta=0.0
% INFO    : Bus 39760	: V=0.9649134, theta=-42.760862 -> V=1.0, theta=0.0
% INFO    : Bus 39761	: V=0.9455949, theta=-45.392578 -> V=1.0, theta=0.0
% INFO    : Bus 39762	: V=0.9427692, theta=-40.472774 -> V=1.0, theta=0.0
% INFO    : Bus 39763	: V=0.9468062, theta=-40.500478 -> V=1.0, theta=0.0
% INFO    : Bus 39764	: V=0.9689799, theta=-38.759999 -> V=1.0, theta=0.0
% INFO    : Bus 39765	: V=0.9714075, theta=-38.513856 -> V=1.0, theta=0.0
% INFO    : Bus 39766	: V=0.9695026, theta=-38.687447 -> V=1.0, theta=0.0
% INFO    : Bus 39767	: V=0.9713712, theta=-37.28535 -> V=1.0, theta=0.0
% INFO    : Bus 39768	: V=0.9711274, theta=-37.536504 -> V=1.0, theta=0.0
% INFO    : Bus 39769	: V=0.9715199, theta=-36.988293 -> V=1.0, theta=0.0
% INFO    : Bus 39770	: V=0.9715627, theta=-37.009414 -> V=1.0, theta=0.0
% INFO    : Bus 39771	: V=0.9722574, theta=-36.235047 -> V=1.0, theta=0.0
% INFO    : Bus 39772	: V=0.9730925, theta=-35.491677 -> V=1.0, theta=0.0
% INFO    : Bus 39773	: V=0.9596626, theta=-52.031177 -> V=1.0, theta=0.0
% INFO    : Bus 39774	: V=0.963202, theta=-51.761215 -> V=1.0, theta=0.0
% INFO    : Bus 39775	: V=0.9607852, theta=-51.824168 -> V=1.0, theta=0.0
% INFO    : Bus 39776	: V=0.9440541, theta=-54.37891 -> V=1.0, theta=0.0
% INFO    : Bus 39777	: V=0.9508763, theta=-53.142899 -> V=1.0, theta=0.0
% INFO    : Bus 39778	: V=0.9582253, theta=-52.016124 -> V=1.0, theta=0.0
% INFO    : Bus 39779	: V=0.9477441, theta=-55.575368 -> V=1.0, theta=0.0
% INFO    : Bus 39780	: V=0.9569186, theta=-52.366321 -> V=1.0, theta=0.0
% INFO    : Bus 39781	: V=0.9456132, theta=-55.70796 -> V=1.0, theta=0.0
% INFO    : Bus 39782	: V=0.9442985, theta=-55.782344 -> V=1.0, theta=0.0
% INFO    : Bus 39783	: V=0.9553933, theta=-52.458739 -> V=1.0, theta=0.0
% INFO    : Bus 39784	: V=0.9665457, theta=-51.610159 -> V=1.0, theta=0.0
% INFO    : Bus 39785	: V=0.9765091, theta=-50.940799 -> V=1.0, theta=0.0
% INFO    : Bus 39786	: V=0.9648939, theta=-52.165757 -> V=1.0, theta=0.0
% INFO    : Bus 39787	: V=0.9686499, theta=-52.047041 -> V=1.0, theta=0.0
% INFO    : Bus 39788	: V=0.9624685, theta=-51.490247 -> V=1.0, theta=0.0
% INFO    : Bus 39789	: V=0.9650755, theta=-51.092656 -> V=1.0, theta=0.0
% INFO    : Bus 39790	: V=0.9611323, theta=-51.716578 -> V=1.0, theta=0.0
% INFO    : Bus 39791	: V=0.9565648, theta=-51.757637 -> V=1.0, theta=0.0
% INFO    : Bus 39792	: V=0.9445448, theta=-53.488359 -> V=1.0, theta=0.0
% INFO    : Bus 39793	: V=0.9398981, theta=-53.952976 -> V=1.0, theta=0.0
% INFO    : Bus 39794	: V=0.959301, theta=-51.406483 -> V=1.0, theta=0.0
% INFO    : Bus 39795	: V=0.9693643, theta=-49.702653 -> V=1.0, theta=0.0
% INFO    : Bus 39796	: V=0.9813153, theta=-24.431603 -> V=1.0, theta=0.0
% INFO    : Bus 39797	: V=0.9826663, theta=-24.206845 -> V=1.0, theta=0.0
% INFO    : Bus 39798	: V=0.9957247, theta=-21.81944 -> V=1.0, theta=0.0
% INFO    : Bus 39799	: V=1.001828, theta=-21.50734 -> V=1.0, theta=0.0
% INFO    : Bus 39800	: V=0.9834429, theta=-18.174628 -> V=1.0, theta=0.0
% INFO    : Bus 39801	: V=1.0059592, theta=-16.175979 -> V=1.0, theta=0.0
% INFO    : Bus 39802	: V=0.9948089, theta=-17.712853 -> V=1.0, theta=0.0
% INFO    : Bus 39803	: V=1.0079261, theta=-15.76029 -> V=1.0, theta=0.0
% INFO    : Bus 39804	: V=1.0064661, theta=-16.010707 -> V=1.0, theta=0.0
% INFO    : Bus 39805	: V=0.998348, theta=-17.184502 -> V=1.0, theta=0.0
% INFO    : Bus 39806	: V=1.0016882, theta=-16.908997 -> V=1.0, theta=0.0
% INFO    : Bus 39807	: V=1.0133864, theta=-15.675239 -> V=1.0, theta=0.0
% INFO    : Bus 39808	: V=1.0133851, theta=-16.008398 -> V=1.0, theta=0.0
% INFO    : Bus 39809	: V=0.9981451, theta=-17.61501 -> V=1.0, theta=0.0
% INFO    : Bus 39810	: V=0.9878516, theta=-18.080591 -> V=1.0, theta=0.0
% INFO    : Bus 39811	: V=0.9540225, theta=-43.06942 -> V=1.0, theta=0.0
% INFO    : Bus 39812	: V=0.9515336, theta=-44.223403 -> V=1.0, theta=0.0
% INFO    : Bus 39813	: V=0.9551576, theta=-43.511828 -> V=1.0, theta=0.0
% INFO    : Bus 39814	: V=0.9548203, theta=-43.487458 -> V=1.0, theta=0.0
% INFO    : Bus 39815	: V=0.956929, theta=-42.872311 -> V=1.0, theta=0.0
% INFO    : Bus 39816	: V=0.9633161, theta=-41.141112 -> V=1.0, theta=0.0
% INFO    : Bus 39817	: V=0.9673067, theta=-35.14116 -> V=1.0, theta=0.0
% INFO    : Bus 39818	: V=0.9568095, theta=-37.368276 -> V=1.0, theta=0.0
% INFO    : Bus 39819	: V=0.9642746, theta=-35.495957 -> V=1.0, theta=0.0
% INFO    : Bus 39820	: V=0.9714578, theta=-34.179923 -> V=1.0, theta=0.0
% INFO    : Bus 39821	: V=0.9696199, theta=-34.624123 -> V=1.0, theta=0.0
% INFO    : Bus 39822	: V=0.9703264, theta=-34.940103 -> V=1.0, theta=0.0
% INFO    : Bus 39823	: V=0.9686024, theta=-35.020346 -> V=1.0, theta=0.0
% INFO    : Bus 39824	: V=0.9690714, theta=-34.683592 -> V=1.0, theta=0.0
% INFO    : Bus 39825	: V=0.9709697, theta=-34.104489 -> V=1.0, theta=0.0
% INFO    : Bus 39826	: V=0.9676485, theta=-36.876371 -> V=1.0, theta=0.0
% INFO    : Bus 39827	: V=0.9728355, theta=-33.662438 -> V=1.0, theta=0.0
% INFO    : Bus 39828	: V=0.9701639, theta=-34.873034 -> V=1.0, theta=0.0
% INFO    : Bus 39829	: V=0.9721832, theta=-33.844655 -> V=1.0, theta=0.0
% INFO    : Bus 39830	: V=0.9725759, theta=-33.550185 -> V=1.0, theta=0.0
% INFO    : Bus 39831	: V=0.9725026, theta=-31.976529 -> V=1.0, theta=0.0
% INFO    : Bus 39832	: V=0.9749959, theta=-32.021357 -> V=1.0, theta=0.0
% INFO    : Bus 39833	: V=0.9689066, theta=-32.145182 -> V=1.0, theta=0.0
% INFO    : Bus 39834	: V=0.9742798, theta=-32.283691 -> V=1.0, theta=0.0
% INFO    : Bus 39835	: V=0.9760439, theta=-29.111464 -> V=1.0, theta=0.0
% INFO    : Bus 39836	: V=0.9814133, theta=-25.47134 -> V=1.0, theta=0.0
% INFO    : Bus 39837	: V=0.9774429, theta=-28.264531 -> V=1.0, theta=0.0
% INFO    : Bus 39838	: V=0.9745945, theta=-32.005888 -> V=1.0, theta=0.0
% INFO    : Bus 39839	: V=0.9784987, theta=-31.116174 -> V=1.0, theta=0.0
% INFO    : Bus 39840	: V=0.9741075, theta=-32.406406 -> V=1.0, theta=0.0
% INFO    : Bus 39841	: V=0.9734738, theta=-32.883161 -> V=1.0, theta=0.0
% INFO    : Bus 39842	: V=0.9796676, theta=-31.146585 -> V=1.0, theta=0.0
% INFO    : Bus 39843	: V=0.9796776, theta=-31.276633 -> V=1.0, theta=0.0
% INFO    : Bus 39844	: V=0.9792398, theta=-31.368359 -> V=1.0, theta=0.0
% INFO    : Bus 39845	: V=0.9765476, theta=-32.79005 -> V=1.0, theta=0.0
% INFO    : Bus 39846	: V=0.9758039, theta=-32.639334 -> V=1.0, theta=0.0
% INFO    : Bus 39847	: V=0.9696406, theta=-35.775909 -> V=1.0, theta=0.0
% INFO    : Bus 39848	: V=0.9663049, theta=-35.978256 -> V=1.0, theta=0.0
% INFO    : Bus 39849	: V=0.9668564, theta=-36.321613 -> V=1.0, theta=0.0
% INFO    : Bus 39850	: V=0.9646748, theta=-36.332698 -> V=1.0, theta=0.0
% INFO    : Bus 39851	: V=0.9602604, theta=-35.868558 -> V=1.0, theta=0.0
% INFO    : Bus 39852	: V=0.9702885, theta=-29.558064 -> V=1.0, theta=0.0
% INFO    : Bus 39853	: V=0.9759242, theta=-30.771946 -> V=1.0, theta=0.0
% INFO    : Bus 39854	: V=1.0054194, theta=-32.67319 -> V=1.0, theta=0.0
% INFO    : Bus 39855	: V=1.0020258, theta=-33.66896 -> V=1.0, theta=0.0
% INFO    : Bus 39856	: V=0.9962191, theta=-33.198894 -> V=1.0, theta=0.0
% INFO    : Bus 39857	: V=0.9960722, theta=-32.691028 -> V=1.0, theta=0.0
% INFO    : Bus 39858	: V=1.0025787, theta=-32.352989 -> V=1.0, theta=0.0
% INFO    : Bus 39859	: V=0.9892383, theta=-32.653611 -> V=1.0, theta=0.0
% INFO    : Bus 39860	: V=0.9890713, theta=-32.497402 -> V=1.0, theta=0.0
% INFO    : Bus 39861	: V=0.9891607, theta=-32.269835 -> V=1.0, theta=0.0
% INFO    : Bus 39862	: V=0.9786426, theta=-34.447294 -> V=1.0, theta=0.0
% INFO    : Bus 39863	: V=0.9899399, theta=-32.282329 -> V=1.0, theta=0.0
% INFO    : Bus 39864	: V=0.9920965, theta=-32.572033 -> V=1.0, theta=0.0
% INFO    : Bus 39865	: V=0.9975626, theta=-33.454553 -> V=1.0, theta=0.0
% INFO    : Bus 39866	: V=0.9961176, theta=-33.676595 -> V=1.0, theta=0.0
% INFO    : Bus 39867	: V=0.9972948, theta=-33.77132 -> V=1.0, theta=0.0
% INFO    : Bus 39868	: V=0.9966088, theta=-33.598098 -> V=1.0, theta=0.0
% INFO    : Bus 39869	: V=0.9984245, theta=-33.931553 -> V=1.0, theta=0.0
% INFO    : Bus 39870	: V=0.9961987, theta=-34.964741 -> V=1.0, theta=0.0
% INFO    : Bus 39871	: V=0.9750059, theta=-33.330806 -> V=1.0, theta=0.0
% INFO    : Bus 39872	: V=0.9677469, theta=-35.96516 -> V=1.0, theta=0.0
% INFO    : Bus 39873	: V=0.9550873, theta=-43.688689 -> V=1.0, theta=0.0
% INFO    : Bus 39874	: V=0.9900365, theta=-36.758882 -> V=1.0, theta=0.0
% INFO    : Bus 39875	: V=1.02, theta=30.033058 -> V=1.0, theta=0.0
% INFO    : Bus 39876	: V=1.02, theta=11.972019 -> V=1.0, theta=0.0
% INFO    : Bus 39877	: V=1.02, theta=29.258929 -> V=1.0, theta=0.0
% INFO    : Bus 39878	: V=1.02, theta=40.236386 -> V=1.0, theta=0.0
% INFO    : Bus 39879	: V=1.0195109, theta=33.722574 -> V=1.0, theta=0.0
% INFO    : Bus 39880	: V=1.02, theta=35.087307 -> V=1.0, theta=0.0
% INFO    : Bus 39881	: V=1.017973, theta=34.457597 -> V=1.0, theta=0.0
% INFO    : Bus 39882	: V=1.02, theta=17.632276 -> V=1.0, theta=0.0
% INFO    : Bus 39883	: V=1.02, theta=11.16627 -> V=1.0, theta=0.0
% INFO    : Bus 39884	: V=1.02, theta=37.411149 -> V=1.0, theta=0.0
% INFO    : Bus 39885	: V=1.02, theta=8.338408 -> V=1.0, theta=0.0
% INFO    : Bus 39886	: V=1.0199532, theta=17.181021 -> V=1.0, theta=0.0
% INFO    : Bus 39887	: V=1.0220211, theta=36.541588 -> V=1.0, theta=0.0
% INFO    : Bus 39888	: V=1.02, theta=23.74776 -> V=1.0, theta=0.0
% INFO    : Bus 39889	: V=1.02, theta=23.722275 -> V=1.0, theta=0.0
% INFO    : Bus 39890	: V=1.0200049, theta=11.961839 -> V=1.0, theta=0.0
% INFO    : Bus 39891	: V=1.0093958, theta=30.868135 -> V=1.0, theta=0.0
% INFO    : Bus 39892	: V=1.0026948, theta=15.751188 -> V=1.0, theta=0.0
% INFO    : Bus 39893	: V=1.0197922, theta=14.500218 -> V=1.0, theta=0.0
% INFO    : Bus 39894	: V=1.02, theta=18.298258 -> V=1.0, theta=0.0
% INFO    : Bus 39895	: V=1.0160184, theta=26.670975 -> V=1.0, theta=0.0
% INFO    : Bus 39896	: V=1.02, theta=26.833133 -> V=1.0, theta=0.0
% INFO    : Bus 39897	: V=1.0157027, theta=15.009888 -> V=1.0, theta=0.0
% INFO    : Bus 39898	: V=1.02, theta=36.327882 -> V=1.0, theta=0.0
% INFO    : Bus 39899	: V=1.02, theta=32.534041 -> V=1.0, theta=0.0
% INFO    : Bus 39900	: V=1.02, theta=11.735697 -> V=1.0, theta=0.0
% INFO    : Bus 39901	: V=1.0148246, theta=28.716289 -> V=1.0, theta=0.0
% INFO    : Bus 39902	: V=1.02, theta=24.35996 -> V=1.0, theta=0.0
% INFO    : Bus 39903	: V=1.02, theta=19.969253 -> V=1.0, theta=0.0
% INFO    : Bus 39904	: V=1.02, theta=37.218539 -> V=1.0, theta=0.0
% INFO    : Bus 39905	: V=1.02, theta=37.730355 -> V=1.0, theta=0.0
% INFO    : Bus 39906	: V=1.02, theta=23.055087 -> V=1.0, theta=0.0
% INFO    : Bus 39907	: V=1.0153454, theta=22.741315 -> V=1.0, theta=0.0
% INFO    : Bus 39908	: V=0.9977607, theta=14.982684 -> V=1.0, theta=0.0
% INFO    : Bus 39909	: V=1.02, theta=33.604216 -> V=1.0, theta=0.0
% INFO    : Bus 39910	: V=1.0087092, theta=32.119052 -> V=1.0, theta=0.0
% INFO    : Bus 39911	: V=1.0135491, theta=28.198452 -> V=1.0, theta=0.0
% INFO    : Bus 39912	: V=1.02, theta=28.635515 -> V=1.0, theta=0.0
% INFO    : Bus 39913	: V=1.02, theta=33.836964 -> V=1.0, theta=0.0
% INFO    : Bus 39914	: V=1.02, theta=27.307841 -> V=1.0, theta=0.0
% INFO    : Bus 39915	: V=1.02, theta=12.762925 -> V=1.0, theta=0.0
% INFO    : Bus 39916	: V=1.011705, theta=18.253057 -> V=1.0, theta=0.0
% INFO    : Bus 39917	: V=1.02, theta=21.880646 -> V=1.0, theta=0.0
% INFO    : Bus 39918	: V=1.0162826, theta=16.464128 -> V=1.0, theta=0.0
% INFO    : Bus 39919	: V=1.02, theta=14.372289 -> V=1.0, theta=0.0
% INFO    : Bus 39920	: V=1.02, theta=6.092574 -> V=1.0, theta=0.0
% INFO    : Bus 39921	: V=0.9999743, theta=20.196993 -> V=1.0, theta=0.0
% INFO    : Bus 39922	: V=1.0155978, theta=37.67601 -> V=1.0, theta=0.0
% INFO    : Bus 39923	: V=1.02, theta=26.734812 -> V=1.0, theta=0.0
% INFO    : Bus 39924	: V=1.02, theta=34.789372 -> V=1.0, theta=0.0
% INFO    : Bus 39925	: V=1.0196186, theta=17.585609 -> V=1.0, theta=0.0
% INFO    : Bus 39926	: V=1.02, theta=39.87138 -> V=1.0, theta=0.0
% INFO    : Bus 39927	: V=1.0199975, theta=27.307445 -> V=1.0, theta=0.0
% INFO    : Bus 39928	: V=1.0004159, theta=20.114057 -> V=1.0, theta=0.0
% INFO    : Bus 39929	: V=1.0054803, theta=32.463553 -> V=1.0, theta=0.0
% INFO    : Bus 39930	: V=1.0150743, theta=28.666874 -> V=1.0, theta=0.0
% INFO    : Bus 39931	: V=1.02, theta=26.71688 -> V=1.0, theta=0.0
% INFO    : Bus 39932	: V=1.02, theta=37.60063 -> V=1.0, theta=0.0
% INFO    : Bus 39933	: V=1.0095514, theta=34.962519 -> V=1.0, theta=0.0
% INFO    : Bus 39934	: V=1.0069164, theta=19.007106 -> V=1.0, theta=0.0
% INFO    : Bus 39935	: V=1.02, theta=38.374314 -> V=1.0, theta=0.0
% INFO    : Bus 39936	: V=1.0059135, theta=18.550857 -> V=1.0, theta=0.0
% INFO    : Bus 39937	: V=1.0154746, theta=30.450866 -> V=1.0, theta=0.0
% INFO    : Bus 39938	: V=1.0178868, theta=30.456252 -> V=1.0, theta=0.0
% INFO    : Bus 39939	: V=1.0000048, theta=20.926676 -> V=1.0, theta=0.0
% INFO    : Bus 39940	: V=1.0154767, theta=28.830808 -> V=1.0, theta=0.0
% INFO    : Bus 39941	: V=1.0191609, theta=25.254881 -> V=1.0, theta=0.0
% INFO    : Bus 39942	: V=1.02, theta=22.774717 -> V=1.0, theta=0.0
% INFO    : Bus 39943	: V=1.02, theta=28.619918 -> V=1.0, theta=0.0
% INFO    : Bus 39944	: V=1.0144373, theta=28.509108 -> V=1.0, theta=0.0
% INFO    : Bus 39945	: V=1.02, theta=17.020914 -> V=1.0, theta=0.0
% INFO    : Bus 39946	: V=1.0146367, theta=34.942099 -> V=1.0, theta=0.0
% INFO    : Bus 39947	: V=1.0139283, theta=24.63574 -> V=1.0, theta=0.0
% INFO    : Bus 39948	: V=1.005687, theta=27.797496 -> V=1.0, theta=0.0
% INFO    : Bus 39949	: V=1.02, theta=23.627741 -> V=1.0, theta=0.0
% INFO    : Bus 39950	: V=1.0093896, theta=2.779537 -> V=1.0, theta=0.0
% INFO    : Bus 39951	: V=1.02, theta=17.474799 -> V=1.0, theta=0.0
% INFO    : Bus 39952	: V=1.02, theta=35.020464 -> V=1.0, theta=0.0
% INFO    : Bus 39953	: V=1.019011, theta=21.426332 -> V=1.0, theta=0.0
% INFO    : Bus 39954	: V=1.02, theta=34.011386 -> V=1.0, theta=0.0
% INFO    : Bus 39955	: V=1.02, theta=25.413443 -> V=1.0, theta=0.0
% INFO    : Bus 39956	: V=1.02, theta=20.62196 -> V=1.0, theta=0.0
% INFO    : Bus 39957	: V=1.0157853, theta=21.822273 -> V=1.0, theta=0.0
% INFO    : Bus 39958	: V=1.02, theta=33.980476 -> V=1.0, theta=0.0
% INFO    : Bus 39959	: V=1.02, theta=25.901307 -> V=1.0, theta=0.0
% INFO    : Bus 39960	: V=1.0116573, theta=21.106394 -> V=1.0, theta=0.0
% INFO    : Bus 39961	: V=1.02, theta=19.627569 -> V=1.0, theta=0.0
% INFO    : Bus 39962	: V=1.02, theta=2.85262 -> V=1.0, theta=0.0
% INFO    : Bus 39963	: V=1.02, theta=4.579787 -> V=1.0, theta=0.0
% INFO    : Bus 39964	: V=1.02, theta=20.947298 -> V=1.0, theta=0.0
% INFO    : Bus 39965	: V=1.02, theta=26.622315 -> V=1.0, theta=0.0
% INFO    : Bus 39966	: V=1.02, theta=13.859557 -> V=1.0, theta=0.0
% INFO    : Bus 39967	: V=0.9883279, theta=19.841262 -> V=1.0, theta=0.0
% INFO    : Bus 39968	: V=1.0109789, theta=21.032512 -> V=1.0, theta=0.0
% INFO    : Bus 39969	: V=0.9933861, theta=25.409526 -> V=1.0, theta=0.0
% INFO    : Bus 39970	: V=1.02, theta=20.528126 -> V=1.0, theta=0.0
% INFO    : Bus 39971	: V=0.9853047, theta=19.984552 -> V=1.0, theta=0.0
% INFO    : Bus 39972	: V=1.02, theta=2.412418 -> V=1.0, theta=0.0
% INFO    : Bus 39973	: V=1.0050735, theta=26.64934 -> V=1.0, theta=0.0
% INFO    : Bus 39974	: V=1.02, theta=33.903388 -> V=1.0, theta=0.0
% INFO    : Bus 39975	: V=1.02, theta=21.520843 -> V=1.0, theta=0.0
% INFO    : Bus 39976	: V=0.9984646, theta=26.710158 -> V=1.0, theta=0.0
% INFO    : Bus 39977	: V=1.02, theta=19.529721 -> V=1.0, theta=0.0
% INFO    : Bus 39978	: V=1.0126179, theta=21.150247 -> V=1.0, theta=0.0
% INFO    : Bus 39979	: V=1.0059235, theta=21.326328 -> V=1.0, theta=0.0
% INFO    : Bus 39980	: V=1.02, theta=-2.539494 -> V=1.0, theta=0.0
% INFO    : Bus 39981	: V=1.02, theta=23.097996 -> V=1.0, theta=0.0
% INFO    : Bus 39982	: V=1.02, theta=10.962889 -> V=1.0, theta=0.0
% INFO    : Bus 39983	: V=0.9981495, theta=32.867215 -> V=1.0, theta=0.0
% INFO    : Bus 39984	: V=0.9981322, theta=32.867207 -> V=1.0, theta=0.0
% INFO    : Bus 39985	: V=0.9814139, theta=20.698747 -> V=1.0, theta=0.0
% INFO    : Bus 39986	: V=1.02, theta=30.385125 -> V=1.0, theta=0.0
% INFO    : Bus 39987	: V=1.018712, theta=19.525038 -> V=1.0, theta=0.0
% INFO    : Bus 39988	: V=1.02, theta=25.882508 -> V=1.0, theta=0.0
% INFO    : Bus 39989	: V=1.02, theta=18.641877 -> V=1.0, theta=0.0
% INFO    : Bus 39990	: V=1.02, theta=6.063748 -> V=1.0, theta=0.0
% INFO    : Bus 39991	: V=0.9772693, theta=22.686757 -> V=1.0, theta=0.0
% INFO    : Bus 39992	: V=1.02, theta=7.036124 -> V=1.0, theta=0.0
% INFO    : Bus 39993	: V=1.02, theta=17.438987 -> V=1.0, theta=0.0
% INFO    : Bus 39994	: V=1.02, theta=2.008783 -> V=1.0, theta=0.0
% INFO    : Bus 39995	: V=1.02, theta=23.763369 -> V=1.0, theta=0.0
% INFO    : Bus 39996	: V=1.02, theta=32.444142 -> V=1.0, theta=0.0
% INFO    : Bus 39997	: V=1.0087647, theta=34.123222 -> V=1.0, theta=0.0
% INFO    : Bus 39998	: V=1.011672, theta=20.934006 -> V=1.0, theta=0.0
% INFO    : Bus 39999	: V=1.02, theta=19.76568 -> V=1.0, theta=0.0
% INFO    : Bus 40000	: V=1.0046522, theta=19.152796 -> V=1.0, theta=0.0
% INFO    : Bus 40001	: V=1.0054241, theta=17.85409 -> V=1.0, theta=0.0
% INFO    : Bus 40002	: V=1.0164006, theta=27.798484 -> V=1.0, theta=0.0
% INFO    : Bus 40003	: V=1.0053099, theta=0.514679 -> V=1.0, theta=0.0
% INFO    : Bus 40004	: V=1.02, theta=29.04472 -> V=1.0, theta=0.0
% INFO    : Bus 40005	: V=1.02, theta=14.278404 -> V=1.0, theta=0.0
% INFO    : Bus 40006	: V=1.0059306, theta=30.645375 -> V=1.0, theta=0.0
% INFO    : Bus 40007	: V=1.02, theta=28.58859 -> V=1.0, theta=0.0
% INFO    : Bus 40008	: V=1.016623, theta=8.630954 -> V=1.0, theta=0.0
% INFO    : Bus 40009	: V=0.9892535, theta=22.32778 -> V=1.0, theta=0.0
% INFO    : Bus 40010	: V=1.0160193, theta=26.890251 -> V=1.0, theta=0.0
% INFO    : Bus 40011	: V=1.0145432, theta=18.115165 -> V=1.0, theta=0.0
% INFO    : Bus 40012	: V=1.0164711, theta=-1.056697 -> V=1.0, theta=0.0
% INFO    : Bus 40013	: V=1.02, theta=7.316073 -> V=1.0, theta=0.0
% INFO    : Bus 40014	: V=1.0009789, theta=18.336314 -> V=1.0, theta=0.0
% INFO    : Bus 40015	: V=1.019909, theta=-2.642432 -> V=1.0, theta=0.0
% INFO    : Bus 40016	: V=1.0190067, theta=28.603283 -> V=1.0, theta=0.0
% INFO    : Bus 40017	: V=0.9825027, theta=19.194094 -> V=1.0, theta=0.0
% INFO    : Bus 40018	: V=1.0113491, theta=27.238318 -> V=1.0, theta=0.0
% INFO    : Bus 40019	: V=1.0199827, theta=25.396313 -> V=1.0, theta=0.0
% INFO    : Bus 40020	: V=1.0072237, theta=25.075999 -> V=1.0, theta=0.0
% INFO    : Bus 40021	: V=1.0184488, theta=13.634271 -> V=1.0, theta=0.0
% INFO    : Bus 40022	: V=1.02, theta=2.673763 -> V=1.0, theta=0.0
% INFO    : Bus 40023	: V=0.9602165, theta=23.585967 -> V=1.0, theta=0.0
% INFO    : Bus 40024	: V=1.0103828, theta=21.529088 -> V=1.0, theta=0.0
% INFO    : Bus 40025	: V=1.0156946, theta=22.370026 -> V=1.0, theta=0.0
% INFO    : Bus 40026	: V=1.0187219, theta=28.746913 -> V=1.0, theta=0.0
% INFO    : Bus 40027	: V=1.0199153, theta=-1.386529 -> V=1.0, theta=0.0
% INFO    : Bus 40028	: V=1.02, theta=18.407537 -> V=1.0, theta=0.0
% INFO    : Bus 40029	: V=1.0049922, theta=15.989446 -> V=1.0, theta=0.0
% INFO    : Bus 40030	: V=1.0118328, theta=26.943877 -> V=1.0, theta=0.0
% INFO    : Bus 40031	: V=0.96787, theta=22.209679 -> V=1.0, theta=0.0
% INFO    : Bus 40032	: V=0.9680389, theta=20.054077 -> V=1.0, theta=0.0
% INFO    : Bus 40033	: V=1.0104989, theta=19.084928 -> V=1.0, theta=0.0
% INFO    : Bus 40034	: V=1.0022633, theta=14.719998 -> V=1.0, theta=0.0
% INFO    : Bus 40035	: V=1.0098446, theta=30.538296 -> V=1.0, theta=0.0
% INFO    : Bus 40036	: V=1.0074969, theta=1.038896 -> V=1.0, theta=0.0
% INFO    : Bus 40037	: V=0.9691887, theta=19.346708 -> V=1.0, theta=0.0
% INFO    : Bus 40038	: V=0.9987516, theta=8.016506 -> V=1.0, theta=0.0
% INFO    : Bus 40039	: V=0.9661683, theta=21.67642 -> V=1.0, theta=0.0
% INFO    : Bus 40040	: V=1.0032206, theta=11.700405 -> V=1.0, theta=0.0
% INFO    : Bus 40041	: V=1.02, theta=43.429578 -> V=1.0, theta=0.0
% INFO    : Bus 40042	: V=1.02, theta=45.524798 -> V=1.0, theta=0.0
% INFO    : Bus 40043	: V=1.02, theta=44.222167 -> V=1.0, theta=0.0
% INFO    : Bus 40044	: V=1.02, theta=41.930505 -> V=1.0, theta=0.0
% INFO    : Bus 40045	: V=1.02, theta=37.06491 -> V=1.0, theta=0.0
% INFO    : Bus 40046	: V=1.02, theta=31.464237 -> V=1.0, theta=0.0
% INFO    : Bus 40047	: V=1.02, theta=42.768814 -> V=1.0, theta=0.0
% INFO    : Bus 40048	: V=1.02, theta=24.932514 -> V=1.0, theta=0.0
% INFO    : Bus 40049	: V=1.0080554, theta=42.530142 -> V=1.0, theta=0.0
% INFO    : Bus 40050	: V=1.0011522, theta=41.723873 -> V=1.0, theta=0.0
% INFO    : Bus 40051	: V=1.0130985, theta=43.199943 -> V=1.0, theta=0.0
% INFO    : Bus 40052	: V=1.02, theta=32.406822 -> V=1.0, theta=0.0
% INFO    : Bus 40053	: V=1.02, theta=41.603946 -> V=1.0, theta=0.0
% INFO    : Bus 40054	: V=1.011607, theta=22.614769 -> V=1.0, theta=0.0
% INFO    : Bus 40055	: V=1.02, theta=33.999047 -> V=1.0, theta=0.0
% INFO    : Bus 40056	: V=1.02, theta=24.59847 -> V=1.0, theta=0.0
% INFO    : Bus 40057	: V=1.02, theta=34.097172 -> V=1.0, theta=0.0
% INFO    : Bus 40058	: V=1.0199492, theta=41.403496 -> V=1.0, theta=0.0
% INFO    : Bus 40059	: V=1.02, theta=40.951105 -> V=1.0, theta=0.0
% INFO    : Bus 40060	: V=1.0196361, theta=42.012561 -> V=1.0, theta=0.0
% INFO    : Bus 40061	: V=1.02, theta=31.146924 -> V=1.0, theta=0.0
% INFO    : Bus 40062	: V=1.02, theta=40.039594 -> V=1.0, theta=0.0
% INFO    : Bus 40063	: V=1.02, theta=34.31447 -> V=1.0, theta=0.0
% INFO    : Bus 40064	: V=1.0172698, theta=29.908217 -> V=1.0, theta=0.0
% INFO    : Bus 40065	: V=1.02, theta=50.135612 -> V=1.0, theta=0.0
% INFO    : Bus 40066	: V=1.02, theta=45.033434 -> V=1.0, theta=0.0
% INFO    : Bus 40067	: V=1.0187212, theta=44.248499 -> V=1.0, theta=0.0
% INFO    : Bus 40068	: V=1.0049218, theta=40.515651 -> V=1.0, theta=0.0
% INFO    : Bus 40069	: V=1.0129922, theta=37.515152 -> V=1.0, theta=0.0
% INFO    : Bus 40070	: V=1.02, theta=37.215129 -> V=1.0, theta=0.0
% INFO    : Bus 40071	: V=1.0040577, theta=23.896865 -> V=1.0, theta=0.0
% INFO    : Bus 40072	: V=0.9912997, theta=39.63668 -> V=1.0, theta=0.0
% INFO    : Bus 40073	: V=1.0228604, theta=46.399568 -> V=1.0, theta=0.0
% INFO    : Bus 40074	: V=0.9974565, theta=40.936886 -> V=1.0, theta=0.0
% INFO    : Bus 40075	: V=1.02, theta=20.073454 -> V=1.0, theta=0.0
% INFO    : Bus 40076	: V=1.02, theta=25.648942 -> V=1.0, theta=0.0
% INFO    : Bus 40077	: V=1.0013543, theta=31.494512 -> V=1.0, theta=0.0
% INFO    : Bus 40078	: V=1.0240343, theta=46.969579 -> V=1.0, theta=0.0
% INFO    : Bus 40079	: V=1.0152043, theta=27.679826 -> V=1.0, theta=0.0
% INFO    : Bus 40080	: V=1.02, theta=24.59847 -> V=1.0, theta=0.0
% INFO    : Bus 40081	: V=0.9915575, theta=40.286092 -> V=1.0, theta=0.0
% INFO    : Bus 40082	: V=1.0103413, theta=42.037485 -> V=1.0, theta=0.0
% INFO    : Bus 40083	: V=1.02, theta=39.00685 -> V=1.0, theta=0.0
% INFO    : Bus 40084	: V=0.9815691, theta=41.562542 -> V=1.0, theta=0.0
% INFO    : Bus 40085	: V=1.0161992, theta=43.915375 -> V=1.0, theta=0.0
% INFO    : Bus 40086	: V=1.0115016, theta=45.02714 -> V=1.0, theta=0.0
% INFO    : Bus 40087	: V=1.0197183, theta=42.456698 -> V=1.0, theta=0.0
% INFO    : Bus 40088	: V=1.0143552, theta=40.742799 -> V=1.0, theta=0.0
% INFO    : Bus 40089	: V=1.02, theta=39.747076 -> V=1.0, theta=0.0
% INFO    : Bus 40090	: V=1.02, theta=41.187591 -> V=1.0, theta=0.0
% INFO    : Bus 40091	: V=1.0039832, theta=39.970011 -> V=1.0, theta=0.0
% INFO    : Bus 40092	: V=1.02, theta=43.908966 -> V=1.0, theta=0.0
% INFO    : Bus 40093	: V=1.0188026, theta=39.438534 -> V=1.0, theta=0.0
% INFO    : Bus 40094	: V=1.0137367, theta=33.510694 -> V=1.0, theta=0.0
% INFO    : Bus 40095	: V=1.02, theta=44.098134 -> V=1.0, theta=0.0
% INFO    : Bus 40096	: V=1.0155491, theta=45.054414 -> V=1.0, theta=0.0
% INFO    : Bus 40097	: V=1.0153349, theta=37.26093 -> V=1.0, theta=0.0
% INFO    : Bus 40098	: V=0.9872218, theta=41.867359 -> V=1.0, theta=0.0
% INFO    : Bus 40099	: V=0.9912822, theta=42.564125 -> V=1.0, theta=0.0
% INFO    : Bus 40100	: V=1.02, theta=45.098944 -> V=1.0, theta=0.0
% INFO    : Bus 40101	: V=1.02, theta=39.691322 -> V=1.0, theta=0.0
% INFO    : Bus 40102	: V=0.9919047, theta=40.399864 -> V=1.0, theta=0.0
% INFO    : Bus 40103	: V=1.02, theta=43.864173 -> V=1.0, theta=0.0
% INFO    : Bus 40104	: V=1.0163022, theta=23.846318 -> V=1.0, theta=0.0
% INFO    : Bus 40105	: V=0.9916499, theta=40.14758 -> V=1.0, theta=0.0
% INFO    : Bus 40106	: V=1.0040235, theta=39.618617 -> V=1.0, theta=0.0
% INFO    : Bus 40107	: V=1.02, theta=30.893583 -> V=1.0, theta=0.0
% INFO    : Bus 40108	: V=0.9848821, theta=17.105961 -> V=1.0, theta=0.0
% INFO    : Bus 40109	: V=1.02, theta=30.597252 -> V=1.0, theta=0.0
% INFO    : Bus 40110	: V=1.02, theta=56.505166 -> V=1.0, theta=0.0
% INFO    : Bus 40111	: V=1.0141959, theta=28.654341 -> V=1.0, theta=0.0
% INFO    : Bus 40112	: V=1.02, theta=43.839969 -> V=1.0, theta=0.0
% INFO    : Bus 40113	: V=1.02, theta=42.049391 -> V=1.0, theta=0.0
% INFO    : Bus 40114	: V=1.0138786, theta=30.165119 -> V=1.0, theta=0.0
% INFO    : Bus 40115	: V=1.02, theta=35.243569 -> V=1.0, theta=0.0
% INFO    : Bus 40116	: V=1.02, theta=54.432188 -> V=1.0, theta=0.0
% INFO    : Bus 40117	: V=1.02, theta=53.692738 -> V=1.0, theta=0.0
% INFO    : Bus 40118	: V=1.02, theta=37.791044 -> V=1.0, theta=0.0
% INFO    : Bus 40119	: V=1.0080008, theta=49.676507 -> V=1.0, theta=0.0
% INFO    : Bus 40120	: V=1.02, theta=43.840169 -> V=1.0, theta=0.0
% INFO    : Bus 40121	: V=1.0130842, theta=35.276621 -> V=1.0, theta=0.0
% INFO    : Bus 40122	: V=1.02, theta=37.499202 -> V=1.0, theta=0.0
% INFO    : Bus 40123	: V=1.02, theta=32.926586 -> V=1.0, theta=0.0
% INFO    : Bus 40124	: V=1.02, theta=39.977514 -> V=1.0, theta=0.0
% INFO    : Bus 40125	: V=1.0095913, theta=30.489441 -> V=1.0, theta=0.0
% INFO    : Bus 40126	: V=1.0196685, theta=53.497826 -> V=1.0, theta=0.0
% INFO    : Bus 40127	: V=1.02, theta=35.834471 -> V=1.0, theta=0.0
% INFO    : Bus 40128	: V=1.02, theta=35.625342 -> V=1.0, theta=0.0
% INFO    : Bus 40129	: V=1.02, theta=38.941247 -> V=1.0, theta=0.0
% INFO    : Bus 40130	: V=0.9997467, theta=28.665835 -> V=1.0, theta=0.0
% INFO    : Bus 40131	: V=1.0189209, theta=32.585891 -> V=1.0, theta=0.0
% INFO    : Bus 40132	: V=1.02, theta=56.878067 -> V=1.0, theta=0.0
% INFO    : Bus 40133	: V=1.02, theta=36.163722 -> V=1.0, theta=0.0
% INFO    : Bus 40134	: V=1.02, theta=36.789437 -> V=1.0, theta=0.0
% INFO    : Bus 40135	: V=1.0139312, theta=53.006061 -> V=1.0, theta=0.0
% INFO    : Bus 40136	: V=1.016664, theta=55.702727 -> V=1.0, theta=0.0
% INFO    : Bus 40137	: V=1.0111246, theta=50.605284 -> V=1.0, theta=0.0
% INFO    : Bus 40138	: V=1.0156402, theta=53.421316 -> V=1.0, theta=0.0
% INFO    : Bus 40139	: V=1.02, theta=51.373436 -> V=1.0, theta=0.0
% INFO    : Bus 40140	: V=1.0074964, theta=35.985233 -> V=1.0, theta=0.0
% INFO    : Bus 40141	: V=1.0167195, theta=34.764238 -> V=1.0, theta=0.0
% INFO    : Bus 40142	: V=1.02, theta=45.256262 -> V=1.0, theta=0.0
% INFO    : Bus 40143	: V=1.02, theta=53.125204 -> V=1.0, theta=0.0
% INFO    : Bus 40144	: V=1.02, theta=57.161449 -> V=1.0, theta=0.0
% INFO    : Bus 40145	: V=1.0115549, theta=35.897948 -> V=1.0, theta=0.0
% INFO    : Bus 40146	: V=1.0113004, theta=44.830449 -> V=1.0, theta=0.0
% INFO    : Bus 40147	: V=1.02, theta=34.800807 -> V=1.0, theta=0.0
% INFO    : Bus 40148	: V=1.02, theta=45.225875 -> V=1.0, theta=0.0
% INFO    : Bus 40149	: V=1.0155448, theta=45.213949 -> V=1.0, theta=0.0
% INFO    : Bus 40150	: V=1.0093946, theta=30.438966 -> V=1.0, theta=0.0
% INFO    : Bus 40151	: V=1.02, theta=35.715905 -> V=1.0, theta=0.0
% INFO    : Bus 40152	: V=1.0159396, theta=45.211981 -> V=1.0, theta=0.0
% INFO    : Bus 40153	: V=1.02, theta=53.421467 -> V=1.0, theta=0.0
% INFO    : Bus 40154	: V=1.0119664, theta=50.629495 -> V=1.0, theta=0.0
% INFO    : Bus 40155	: V=0.989431, theta=35.863249 -> V=1.0, theta=0.0
% INFO    : Bus 40156	: V=0.9991522, theta=41.503286 -> V=1.0, theta=0.0
% INFO    : Bus 40157	: V=1.0032652, theta=35.067802 -> V=1.0, theta=0.0
% INFO    : Bus 40158	: V=1.02, theta=36.603584 -> V=1.0, theta=0.0
% INFO    : Bus 40159	: V=0.9988327, theta=35.822609 -> V=1.0, theta=0.0
% INFO    : Bus 40160	: V=1.02, theta=49.950674 -> V=1.0, theta=0.0
% INFO    : Bus 40161	: V=1.0091317, theta=33.964487 -> V=1.0, theta=0.0
% INFO    : Bus 40162	: V=1.02, theta=55.60289 -> V=1.0, theta=0.0
% INFO    : Bus 40163	: V=0.9954149, theta=35.906131 -> V=1.0, theta=0.0
% INFO    : Bus 40164	: V=0.9745333, theta=43.539419 -> V=1.0, theta=0.0
% INFO    : Bus 40165	: V=1.014376, theta=44.909752 -> V=1.0, theta=0.0
% INFO    : Bus 40166	: V=1.0085831, theta=49.696904 -> V=1.0, theta=0.0
% INFO    : Bus 40167	: V=1.0138341, theta=44.820128 -> V=1.0, theta=0.0
% INFO    : Bus 40168	: V=1.0157026, theta=50.134687 -> V=1.0, theta=0.0
% INFO    : Bus 40169	: V=0.9838025, theta=39.579001 -> V=1.0, theta=0.0
% INFO    : Bus 40170	: V=1.0082343, theta=49.87666 -> V=1.0, theta=0.0
% INFO    : Bus 40171	: V=1.0073409, theta=35.988578 -> V=1.0, theta=0.0
% INFO    : Bus 40172	: V=1.0025458, theta=11.671811 -> V=1.0, theta=0.0
% INFO    : Bus 40173	: V=0.9883535, theta=11.456437 -> V=1.0, theta=0.0
% INFO    : Bus 40174	: V=0.9898254, theta=11.477368 -> V=1.0, theta=0.0
% INFO    : Bus 40175	: V=0.989087, theta=11.441179 -> V=1.0, theta=0.0
% INFO    : Bus 40176	: V=0.9890801, theta=11.447939 -> V=1.0, theta=0.0
% INFO    : Bus 40177	: V=0.9901893, theta=11.46781 -> V=1.0, theta=0.0
% INFO    : Bus 40178	: V=0.9893382, theta=11.453315 -> V=1.0, theta=0.0
% INFO    : Bus 40179	: V=0.9899524, theta=11.482468 -> V=1.0, theta=0.0
% INFO    : Bus 40180	: V=0.9897684, theta=11.483881 -> V=1.0, theta=0.0
% INFO    : Bus 40181	: V=0.9897498, theta=11.479715 -> V=1.0, theta=0.0
% INFO    : Bus 40182	: V=0.989418, theta=11.490832 -> V=1.0, theta=0.0
% INFO    : Bus 40183	: V=0.9923149, theta=11.508775 -> V=1.0, theta=0.0
% INFO    : Bus 40184	: V=1.0043671, theta=12.60973 -> V=1.0, theta=0.0
% INFO    : Bus 40185	: V=0.9848215, theta=14.750252 -> V=1.0, theta=0.0
% INFO    : Bus 40186	: V=0.9901383, theta=12.417788 -> V=1.0, theta=0.0
% INFO    : Bus 40187	: V=0.9944554, theta=11.858728 -> V=1.0, theta=0.0
% INFO    : Bus 40188	: V=0.9875527, theta=11.482101 -> V=1.0, theta=0.0
% INFO    : Bus 40189	: V=0.994597, theta=10.762388 -> V=1.0, theta=0.0
% INFO    : Bus 40190	: V=0.9927687, theta=-1.774363 -> V=1.0, theta=0.0
% INFO    : Bus 40191	: V=0.983577, theta=-3.58508 -> V=1.0, theta=0.0
% INFO    : Bus 40192	: V=0.9857194, theta=-3.635713 -> V=1.0, theta=0.0
% INFO    : Bus 40193	: V=0.9828963, theta=-3.575892 -> V=1.0, theta=0.0
% INFO    : Bus 40194	: V=0.9970747, theta=6.997461 -> V=1.0, theta=0.0
% INFO    : Bus 40195	: V=0.9943101, theta=6.626418 -> V=1.0, theta=0.0
% INFO    : Bus 40196	: V=0.9933196, theta=5.76013 -> V=1.0, theta=0.0
% INFO    : Bus 40197	: V=0.9917305, theta=5.560576 -> V=1.0, theta=0.0
% INFO    : Bus 40198	: V=0.9861101, theta=31.356241 -> V=1.0, theta=0.0
% INFO    : Bus 40199	: V=0.9980106, theta=31.580298 -> V=1.0, theta=0.0
% INFO    : Bus 40200	: V=0.9862209, theta=31.201524 -> V=1.0, theta=0.0
% INFO    : Bus 40201	: V=1.0052331, theta=32.322737 -> V=1.0, theta=0.0
% INFO    : Bus 40202	: V=0.9835667, theta=31.359621 -> V=1.0, theta=0.0
% INFO    : Bus 40203	: V=0.988914, theta=32.169563 -> V=1.0, theta=0.0
% INFO    : Bus 40204	: V=0.9906651, theta=32.52537 -> V=1.0, theta=0.0
% INFO    : Bus 40205	: V=0.9820018, theta=14.915543 -> V=1.0, theta=0.0
% INFO    : Bus 40206	: V=0.9831983, theta=13.803917 -> V=1.0, theta=0.0
% INFO    : Bus 40207	: V=1.0113896, theta=29.131471 -> V=1.0, theta=0.0
% INFO    : Bus 40208	: V=1.0072695, theta=31.065916 -> V=1.0, theta=0.0
% INFO    : Bus 40209	: V=1.0157586, theta=28.576843 -> V=1.0, theta=0.0
% INFO    : Bus 40210	: V=1.0166788, theta=28.834587 -> V=1.0, theta=0.0
% INFO    : Bus 40211	: V=1.0065381, theta=27.645608 -> V=1.0, theta=0.0
% INFO    : Bus 40212	: V=1.0086339, theta=26.86665 -> V=1.0, theta=0.0
% INFO    : Bus 40213	: V=1.0164306, theta=28.663418 -> V=1.0, theta=0.0
% INFO    : Bus 40214	: V=1.0118871, theta=28.738311 -> V=1.0, theta=0.0
% INFO    : Bus 40215	: V=1.0174588, theta=28.578216 -> V=1.0, theta=0.0
% INFO    : Bus 40216	: V=1.0074718, theta=30.680335 -> V=1.0, theta=0.0
% INFO    : Bus 40217	: V=0.9995942, theta=6.240734 -> V=1.0, theta=0.0
% INFO    : Bus 40218	: V=0.9947822, theta=3.823457 -> V=1.0, theta=0.0
% INFO    : Bus 40219	: V=0.9997816, theta=33.238159 -> V=1.0, theta=0.0
% INFO    : Bus 40220	: V=0.9978204, theta=33.142995 -> V=1.0, theta=0.0
% INFO    : Bus 40221	: V=1.0093722, theta=33.40586 -> V=1.0, theta=0.0
% INFO    : Bus 40222	: V=1.0058634, theta=33.231087 -> V=1.0, theta=0.0
% INFO    : Bus 40223	: V=0.9952314, theta=32.883597 -> V=1.0, theta=0.0
% INFO    : Bus 40224	: V=1.0149823, theta=33.231832 -> V=1.0, theta=0.0
% INFO    : Bus 40225	: V=0.9902456, theta=17.435193 -> V=1.0, theta=0.0
% INFO    : Bus 40226	: V=0.9863596, theta=16.602664 -> V=1.0, theta=0.0
% INFO    : Bus 40227	: V=0.9854573, theta=15.809019 -> V=1.0, theta=0.0
% INFO    : Bus 40228	: V=0.9804399, theta=15.608191 -> V=1.0, theta=0.0
% INFO    : Bus 40229	: V=0.9865068, theta=16.030881 -> V=1.0, theta=0.0
% INFO    : Bus 40230	: V=0.997495, theta=14.724752 -> V=1.0, theta=0.0
% INFO    : Bus 40231	: V=0.9992552, theta=14.707942 -> V=1.0, theta=0.0
% INFO    : Bus 40232	: V=0.998663, theta=14.714289 -> V=1.0, theta=0.0
% INFO    : Bus 40233	: V=0.9982417, theta=14.699275 -> V=1.0, theta=0.0
% INFO    : Bus 40234	: V=1.0013894, theta=14.712202 -> V=1.0, theta=0.0
% INFO    : Bus 40235	: V=1.0019326, theta=14.730062 -> V=1.0, theta=0.0
% INFO    : Bus 40236	: V=0.9966414, theta=14.758941 -> V=1.0, theta=0.0
% INFO    : Bus 40237	: V=1.0006383, theta=14.96533 -> V=1.0, theta=0.0
% INFO    : Bus 40238	: V=1.0000996, theta=14.946443 -> V=1.0, theta=0.0
% INFO    : Bus 40239	: V=0.9995283, theta=15.031281 -> V=1.0, theta=0.0
% INFO    : Bus 40240	: V=0.9967266, theta=14.73599 -> V=1.0, theta=0.0
% INFO    : Bus 40241	: V=0.9977131, theta=14.740449 -> V=1.0, theta=0.0
% INFO    : Bus 40242	: V=0.994865, theta=14.624095 -> V=1.0, theta=0.0
% INFO    : Bus 40243	: V=0.9975421, theta=14.501398 -> V=1.0, theta=0.0
% INFO    : Bus 40244	: V=0.9962178, theta=14.108909 -> V=1.0, theta=0.0
% INFO    : Bus 40245	: V=0.9932419, theta=14.627387 -> V=1.0, theta=0.0
% INFO    : Bus 40246	: V=0.9942558, theta=14.577371 -> V=1.0, theta=0.0
% INFO    : Bus 40247	: V=0.9993805, theta=14.738376 -> V=1.0, theta=0.0
% INFO    : Bus 40248	: V=0.9967017, theta=14.567156 -> V=1.0, theta=0.0
% INFO    : Bus 40249	: V=0.9986948, theta=14.616417 -> V=1.0, theta=0.0
% INFO    : Bus 40250	: V=1.0074577, theta=14.025297 -> V=1.0, theta=0.0
% INFO    : Bus 40251	: V=0.9949435, theta=14.667597 -> V=1.0, theta=0.0
% INFO    : Bus 40252	: V=0.990803, theta=14.632395 -> V=1.0, theta=0.0
% INFO    : Bus 40253	: V=1.0006403, theta=14.790444 -> V=1.0, theta=0.0
% INFO    : Bus 40254	: V=0.9903292, theta=14.669536 -> V=1.0, theta=0.0
% INFO    : Bus 40255	: V=0.9957321, theta=14.744902 -> V=1.0, theta=0.0
% INFO    : Bus 40256	: V=0.9891061, theta=14.63341 -> V=1.0, theta=0.0
% INFO    : Bus 40257	: V=0.9964057, theta=14.714614 -> V=1.0, theta=0.0
% INFO    : Bus 40258	: V=0.9966906, theta=14.70574 -> V=1.0, theta=0.0
% INFO    : Bus 40259	: V=0.9981643, theta=14.631296 -> V=1.0, theta=0.0
% INFO    : Bus 40260	: V=1.0038506, theta=16.00077 -> V=1.0, theta=0.0
% INFO    : Bus 40261	: V=0.9921516, theta=15.311471 -> V=1.0, theta=0.0
% INFO    : Bus 40262	: V=1.0038727, theta=15.840216 -> V=1.0, theta=0.0
% INFO    : Bus 40263	: V=0.9916347, theta=15.355796 -> V=1.0, theta=0.0
% INFO    : Bus 40264	: V=1.0074294, theta=17.480675 -> V=1.0, theta=0.0
% INFO    : Bus 40265	: V=1.0039684, theta=16.80174 -> V=1.0, theta=0.0
% INFO    : Bus 40266	: V=1.0019774, theta=16.122698 -> V=1.0, theta=0.0
% INFO    : Bus 40267	: V=1.0100062, theta=15.351109 -> V=1.0, theta=0.0
% INFO    : Bus 40268	: V=0.9981673, theta=14.729451 -> V=1.0, theta=0.0
% INFO    : Bus 40269	: V=0.9564681, theta=11.205297 -> V=1.0, theta=0.0
% INFO    : Bus 40270	: V=0.9915643, theta=12.545717 -> V=1.0, theta=0.0
% INFO    : Bus 40271	: V=0.9963191, theta=14.748727 -> V=1.0, theta=0.0
% INFO    : Bus 40272	: V=0.9958837, theta=14.695161 -> V=1.0, theta=0.0
% INFO    : Bus 40273	: V=1.0194928, theta=19.172503 -> V=1.0, theta=0.0
% INFO    : Bus 40274	: V=1.0199162, theta=19.526852 -> V=1.0, theta=0.0
% INFO    : Bus 40275	: V=1.0038948, theta=15.591529 -> V=1.0, theta=0.0
% INFO    : Bus 40276	: V=0.9918373, theta=14.403753 -> V=1.0, theta=0.0
% INFO    : Bus 40277	: V=1.0029073, theta=15.254468 -> V=1.0, theta=0.0
% INFO    : Bus 40278	: V=0.9985991, theta=13.88056 -> V=1.0, theta=0.0
% INFO    : Bus 40279	: V=0.9961003, theta=11.629879 -> V=1.0, theta=0.0
% INFO    : Bus 40280	: V=0.9975198, theta=11.267282 -> V=1.0, theta=0.0
% INFO    : Bus 40281	: V=0.9971353, theta=11.328838 -> V=1.0, theta=0.0
% INFO    : Bus 40282	: V=0.9785169, theta=13.068218 -> V=1.0, theta=0.0
% INFO    : Bus 40283	: V=0.9719426, theta=6.047427 -> V=1.0, theta=0.0
% INFO    : Bus 40284	: V=0.9714588, theta=6.289462 -> V=1.0, theta=0.0
% INFO    : Bus 40285	: V=0.9779314, theta=5.441519 -> V=1.0, theta=0.0
% INFO    : Bus 40286	: V=0.9755342, theta=5.713695 -> V=1.0, theta=0.0
% INFO    : Bus 40287	: V=1.0180228, theta=6.053113 -> V=1.0, theta=0.0
% INFO    : Bus 40288	: V=1.0191016, theta=7.174221 -> V=1.0, theta=0.0
% INFO    : Bus 40289	: V=1.0109909, theta=4.956843 -> V=1.0, theta=0.0
% INFO    : Bus 40290	: V=1.0098383, theta=4.570758 -> V=1.0, theta=0.0
% INFO    : Bus 40291	: V=0.9874082, theta=1.763482 -> V=1.0, theta=0.0
% INFO    : Bus 40292	: V=0.9915818, theta=3.987587 -> V=1.0, theta=0.0
% INFO    : Bus 40293	: V=0.992616, theta=3.081577 -> V=1.0, theta=0.0
% INFO    : Bus 40294	: V=0.9928161, theta=3.439839 -> V=1.0, theta=0.0
% INFO    : Bus 40295	: V=0.9843456, theta=2.910025 -> V=1.0, theta=0.0
% INFO    : Bus 40296	: V=0.9956081, theta=2.569782 -> V=1.0, theta=0.0
% INFO    : Bus 40297	: V=0.9908647, theta=1.620009 -> V=1.0, theta=0.0
% INFO    : Bus 40298	: V=1.0007628, theta=1.558351 -> V=1.0, theta=0.0
% INFO    : Bus 40299	: V=0.9771042, theta=7.339431 -> V=1.0, theta=0.0
% INFO    : Bus 40300	: V=0.9831028, theta=7.694033 -> V=1.0, theta=0.0
% INFO    : Bus 40301	: V=0.9699415, theta=7.57995 -> V=1.0, theta=0.0
% INFO    : Bus 40302	: V=0.9806305, theta=7.490235 -> V=1.0, theta=0.0
% INFO    : Bus 40303	: V=0.9803049, theta=7.346872 -> V=1.0, theta=0.0
% INFO    : Bus 40304	: V=0.9617523, theta=6.812883 -> V=1.0, theta=0.0
% INFO    : Bus 40305	: V=0.9613622, theta=6.908446 -> V=1.0, theta=0.0
% INFO    : Bus 40306	: V=0.9618662, theta=6.897853 -> V=1.0, theta=0.0
% INFO    : Bus 40307	: V=0.9613528, theta=6.906818 -> V=1.0, theta=0.0
% INFO    : Bus 40308	: V=0.9639666, theta=7.265715 -> V=1.0, theta=0.0
% INFO    : Bus 40309	: V=0.9648126, theta=7.340667 -> V=1.0, theta=0.0
% INFO    : Bus 40310	: V=0.963759, theta=7.342145 -> V=1.0, theta=0.0
% INFO    : Bus 40311	: V=0.9587973, theta=19.335861 -> V=1.0, theta=0.0
% INFO    : Bus 40312	: V=0.9587017, theta=19.336432 -> V=1.0, theta=0.0
% INFO    : Bus 40313	: V=0.9586282, theta=19.33482 -> V=1.0, theta=0.0
% INFO    : Bus 40314	: V=0.9585844, theta=19.309541 -> V=1.0, theta=0.0
% INFO    : Bus 40315	: V=0.9575802, theta=19.24259 -> V=1.0, theta=0.0
% INFO    : Bus 40316	: V=0.9576868, theta=19.252242 -> V=1.0, theta=0.0
% INFO    : Bus 40317	: V=0.9575332, theta=19.237072 -> V=1.0, theta=0.0
% INFO    : Bus 40318	: V=0.9572118, theta=19.207806 -> V=1.0, theta=0.0
% INFO    : Bus 40319	: V=0.9577449, theta=19.253797 -> V=1.0, theta=0.0
% INFO    : Bus 40320	: V=0.9582826, theta=19.30228 -> V=1.0, theta=0.0
% INFO    : Bus 40321	: V=0.9580594, theta=19.285377 -> V=1.0, theta=0.0
% INFO    : Bus 40322	: V=0.9585806, theta=19.330949 -> V=1.0, theta=0.0
% INFO    : Bus 40323	: V=0.9591909, theta=19.416165 -> V=1.0, theta=0.0
% INFO    : Bus 40324	: V=0.9586307, theta=19.336274 -> V=1.0, theta=0.0
% INFO    : Bus 40325	: V=0.9587157, theta=19.356685 -> V=1.0, theta=0.0
% INFO    : Bus 40326	: V=0.9584642, theta=19.327313 -> V=1.0, theta=0.0
% INFO    : Bus 40327	: V=0.9579847, theta=19.287899 -> V=1.0, theta=0.0
% INFO    : Bus 40328	: V=0.9584295, theta=19.316371 -> V=1.0, theta=0.0
% INFO    : Bus 40329	: V=0.9580902, theta=19.302655 -> V=1.0, theta=0.0
% INFO    : Bus 40330	: V=0.957413, theta=19.304098 -> V=1.0, theta=0.0
% INFO    : Bus 40331	: V=0.9581694, theta=19.308535 -> V=1.0, theta=0.0
% INFO    : Bus 40332	: V=0.9575123, theta=19.27855 -> V=1.0, theta=0.0
% INFO    : Bus 40333	: V=0.9578146, theta=19.286556 -> V=1.0, theta=0.0
% INFO    : Bus 40334	: V=0.9577369, theta=19.273167 -> V=1.0, theta=0.0
% INFO    : Bus 40335	: V=0.9576998, theta=19.265365 -> V=1.0, theta=0.0
% INFO    : Bus 40336	: V=0.9563377, theta=19.141246 -> V=1.0, theta=0.0
% INFO    : Bus 40337	: V=0.9563729, theta=19.144704 -> V=1.0, theta=0.0
% INFO    : Bus 40338	: V=0.9564433, theta=19.148937 -> V=1.0, theta=0.0
% INFO    : Bus 40339	: V=0.9564213, theta=19.148311 -> V=1.0, theta=0.0
% INFO    : Bus 40340	: V=0.9567396, theta=19.167198 -> V=1.0, theta=0.0
% INFO    : Bus 40341	: V=0.9576411, theta=19.263749 -> V=1.0, theta=0.0
% INFO    : Bus 40342	: V=0.956404, theta=19.145158 -> V=1.0, theta=0.0
% INFO    : Bus 40343	: V=0.9564962, theta=19.147801 -> V=1.0, theta=0.0
% INFO    : Bus 40344	: V=0.9563425, theta=19.138934 -> V=1.0, theta=0.0
% INFO    : Bus 40345	: V=0.9562598, theta=19.132527 -> V=1.0, theta=0.0
% INFO    : Bus 40346	: V=0.9562941, theta=19.133532 -> V=1.0, theta=0.0
% INFO    : Bus 40347	: V=0.9563171, theta=19.128525 -> V=1.0, theta=0.0
% INFO    : Bus 40348	: V=0.9563013, theta=19.129088 -> V=1.0, theta=0.0
% INFO    : Bus 40349	: V=0.9563379, theta=19.129115 -> V=1.0, theta=0.0
% INFO    : Bus 40350	: V=0.9563092, theta=19.129314 -> V=1.0, theta=0.0
% INFO    : Bus 40351	: V=0.9568608, theta=19.168394 -> V=1.0, theta=0.0
% INFO    : Bus 40352	: V=0.957023, theta=19.190584 -> V=1.0, theta=0.0
% INFO    : Bus 40353	: V=0.9565954, theta=19.154658 -> V=1.0, theta=0.0
% INFO    : Bus 40354	: V=0.9564929, theta=19.140796 -> V=1.0, theta=0.0
% INFO    : Bus 40355	: V=0.9564204, theta=19.133334 -> V=1.0, theta=0.0
% INFO    : Bus 40356	: V=0.9564473, theta=19.124354 -> V=1.0, theta=0.0
% INFO    : Bus 40357	: V=0.956546, theta=19.11699 -> V=1.0, theta=0.0
% INFO    : Bus 40358	: V=0.9565389, theta=19.120491 -> V=1.0, theta=0.0
% INFO    : Bus 40359	: V=0.9565955, theta=19.120038 -> V=1.0, theta=0.0
% INFO    : Bus 40360	: V=0.9564809, theta=19.123613 -> V=1.0, theta=0.0
% INFO    : Bus 40361	: V=0.9566084, theta=19.141192 -> V=1.0, theta=0.0
% INFO    : Bus 40362	: V=0.9566339, theta=19.141793 -> V=1.0, theta=0.0
% INFO    : Bus 40363	: V=0.9610785, theta=19.340687 -> V=1.0, theta=0.0
% INFO    : Bus 40364	: V=0.9572674, theta=19.229412 -> V=1.0, theta=0.0
% INFO    : Bus 40365	: V=0.9586449, theta=19.429897 -> V=1.0, theta=0.0
% INFO    : Bus 40366	: V=0.9585737, theta=19.424339 -> V=1.0, theta=0.0
% INFO    : Bus 40367	: V=0.9562804, theta=19.239758 -> V=1.0, theta=0.0
% INFO    : Bus 40368	: V=0.9567926, theta=19.209983 -> V=1.0, theta=0.0
% INFO    : Bus 40369	: V=0.9566495, theta=19.179345 -> V=1.0, theta=0.0
% INFO    : Bus 40370	: V=0.9565372, theta=19.172793 -> V=1.0, theta=0.0
% INFO    : Bus 40371	: V=0.9565442, theta=19.224857 -> V=1.0, theta=0.0
% INFO    : Bus 40372	: V=0.956453, theta=19.188102 -> V=1.0, theta=0.0
% INFO    : Bus 40373	: V=0.9564777, theta=19.158802 -> V=1.0, theta=0.0
% INFO    : Bus 40374	: V=0.9566022, theta=19.153058 -> V=1.0, theta=0.0
% INFO    : Bus 40375	: V=0.9564974, theta=19.167269 -> V=1.0, theta=0.0
% INFO    : Bus 40376	: V=0.9564946, theta=19.189029 -> V=1.0, theta=0.0
% INFO    : Bus 40377	: V=0.956403, theta=19.159348 -> V=1.0, theta=0.0
% INFO    : Bus 40378	: V=0.9563653, theta=19.139725 -> V=1.0, theta=0.0
% INFO    : Bus 40379	: V=0.9560024, theta=19.153217 -> V=1.0, theta=0.0
% INFO    : Bus 40380	: V=0.9560474, theta=19.159705 -> V=1.0, theta=0.0
% INFO    : Bus 40381	: V=0.9560308, theta=19.159326 -> V=1.0, theta=0.0
% INFO    : Bus 40382	: V=0.9560974, theta=19.167325 -> V=1.0, theta=0.0
% INFO    : Bus 40383	: V=0.9559728, theta=19.160932 -> V=1.0, theta=0.0
% INFO    : Bus 40384	: V=0.9560197, theta=19.15372 -> V=1.0, theta=0.0
% INFO    : Bus 40385	: V=0.9559803, theta=19.152983 -> V=1.0, theta=0.0
% INFO    : Bus 40386	: V=0.9558549, theta=19.166105 -> V=1.0, theta=0.0
% INFO    : Bus 40387	: V=0.9566907, theta=19.143499 -> V=1.0, theta=0.0
% INFO    : Bus 40388	: V=0.962195, theta=19.402573 -> V=1.0, theta=0.0
% INFO    : Bus 40389	: V=0.9564231, theta=19.138573 -> V=1.0, theta=0.0
% INFO    : Bus 40390	: V=0.9563234, theta=19.136897 -> V=1.0, theta=0.0
% INFO    : Bus 40391	: V=0.9564116, theta=19.129296 -> V=1.0, theta=0.0
% INFO    : Bus 40392	: V=0.9567823, theta=19.122535 -> V=1.0, theta=0.0
% INFO    : Bus 40393	: V=0.9616258, theta=19.353312 -> V=1.0, theta=0.0
% INFO    : Bus 40394	: V=0.9564057, theta=19.130166 -> V=1.0, theta=0.0
% INFO    : Bus 40395	: V=0.9563481, theta=19.132708 -> V=1.0, theta=0.0
% INFO    : Bus 40396	: V=0.9563215, theta=19.131942 -> V=1.0, theta=0.0
% INFO    : Bus 40397	: V=0.9562397, theta=19.137636 -> V=1.0, theta=0.0
% INFO    : Bus 40398	: V=0.956153, theta=19.132699 -> V=1.0, theta=0.0
% INFO    : Bus 40399	: V=0.9559377, theta=19.13293 -> V=1.0, theta=0.0
% INFO    : Bus 40400	: V=0.9559547, theta=19.131309 -> V=1.0, theta=0.0
% INFO    : Bus 40401	: V=0.9559366, theta=19.134203 -> V=1.0, theta=0.0
% INFO    : Bus 40402	: V=0.9560903, theta=19.132407 -> V=1.0, theta=0.0
% INFO    : Bus 40403	: V=0.9560909, theta=19.135155 -> V=1.0, theta=0.0
% INFO    : Bus 40404	: V=0.9561301, theta=19.1391 -> V=1.0, theta=0.0
% INFO    : Bus 40405	: V=0.9561133, theta=19.142775 -> V=1.0, theta=0.0
% INFO    : Bus 40406	: V=0.9561134, theta=19.146941 -> V=1.0, theta=0.0
% INFO    : Bus 40407	: V=0.9559927, theta=19.153661 -> V=1.0, theta=0.0
% INFO    : Bus 40408	: V=0.9560005, theta=19.146252 -> V=1.0, theta=0.0
% INFO    : Bus 40409	: V=0.9559285, theta=19.14299 -> V=1.0, theta=0.0
% INFO    : Bus 40410	: V=0.9559694, theta=19.13828 -> V=1.0, theta=0.0
% INFO    : Bus 40411	: V=0.9625689, theta=19.379047 -> V=1.0, theta=0.0
% INFO    : Bus 40412	: V=0.9558177, theta=19.134634 -> V=1.0, theta=0.0
% INFO    : Bus 40413	: V=0.962691, theta=19.364544 -> V=1.0, theta=0.0
% INFO    : Bus 40414	: V=0.955524, theta=19.13554 -> V=1.0, theta=0.0
% INFO    : Bus 40415	: V=0.9556206, theta=19.133868 -> V=1.0, theta=0.0
% INFO    : Bus 40416	: V=0.9629374, theta=19.360665 -> V=1.0, theta=0.0
% INFO    : Bus 40417	: V=0.9560229, theta=19.13818 -> V=1.0, theta=0.0
% INFO    : Bus 40418	: V=0.9632342, theta=19.357251 -> V=1.0, theta=0.0
% INFO    : Bus 40419	: V=0.9553025, theta=19.133599 -> V=1.0, theta=0.0
% INFO    : Bus 40420	: V=0.9550717, theta=19.131435 -> V=1.0, theta=0.0
% INFO    : Bus 40421	: V=0.9553922, theta=19.131877 -> V=1.0, theta=0.0
% INFO    : Bus 40422	: V=0.95562, theta=19.137075 -> V=1.0, theta=0.0
% INFO    : Bus 40423	: V=0.9557229, theta=19.138793 -> V=1.0, theta=0.0
% INFO    : Bus 40424	: V=0.9558647, theta=19.141029 -> V=1.0, theta=0.0
% INFO    : Bus 40425	: V=0.9557639, theta=19.144095 -> V=1.0, theta=0.0
% INFO    : Bus 40426	: V=0.963117, theta=19.427719 -> V=1.0, theta=0.0
% INFO    : Bus 40427	: V=0.9560523, theta=19.14755 -> V=1.0, theta=0.0
% INFO    : Bus 40428	: V=0.9558745, theta=19.144263 -> V=1.0, theta=0.0
% INFO    : Bus 40429	: V=0.9546986, theta=19.129957 -> V=1.0, theta=0.0
% INFO    : Bus 40430	: V=0.9548297, theta=19.126469 -> V=1.0, theta=0.0
% INFO    : Bus 40431	: V=0.9636849, theta=19.353149 -> V=1.0, theta=0.0
% INFO    : Bus 40432	: V=0.9642112, theta=19.349386 -> V=1.0, theta=0.0
% INFO    : Bus 40433	: V=0.955129, theta=19.096775 -> V=1.0, theta=0.0
% INFO    : Bus 40434	: V=0.9552959, theta=19.095883 -> V=1.0, theta=0.0
% INFO    : Bus 40435	: V=0.9549908, theta=19.097904 -> V=1.0, theta=0.0
% INFO    : Bus 40436	: V=0.9647885, theta=19.347948 -> V=1.0, theta=0.0
% INFO    : Bus 40437	: V=0.9561193, theta=19.089882 -> V=1.0, theta=0.0
% INFO    : Bus 40438	: V=0.9562142, theta=19.08654 -> V=1.0, theta=0.0
% INFO    : Bus 40439	: V=0.9558159, theta=19.087971 -> V=1.0, theta=0.0
% INFO    : Bus 40440	: V=0.9555471, theta=19.093536 -> V=1.0, theta=0.0
% INFO    : Bus 40441	: V=0.9569772, theta=19.0842 -> V=1.0, theta=0.0
% INFO    : Bus 40442	: V=0.9568989, theta=19.081125 -> V=1.0, theta=0.0
% INFO    : Bus 40443	: V=0.9654659, theta=19.347146 -> V=1.0, theta=0.0
% INFO    : Bus 40444	: V=0.9567798, theta=19.084761 -> V=1.0, theta=0.0
% INFO    : Bus 40445	: V=0.9567409, theta=19.07329 -> V=1.0, theta=0.0
% INFO    : Bus 40446	: V=0.9567969, theta=19.069887 -> V=1.0, theta=0.0
% INFO    : Bus 40447	: V=0.9563937, theta=19.064588 -> V=1.0, theta=0.0
% INFO    : Bus 40448	: V=0.9579009, theta=19.096675 -> V=1.0, theta=0.0
% INFO    : Bus 40449	: V=0.9660726, theta=19.352633 -> V=1.0, theta=0.0
% INFO    : Bus 40450	: V=0.9590177, theta=19.118276 -> V=1.0, theta=0.0
% INFO    : Bus 40451	: V=0.9589087, theta=19.117556 -> V=1.0, theta=0.0
% INFO    : Bus 40452	: V=0.9587994, theta=19.115507 -> V=1.0, theta=0.0
% INFO    : Bus 40453	: V=0.9586727, theta=19.118554 -> V=1.0, theta=0.0
% INFO    : Bus 40454	: V=0.955386, theta=20.395786 -> V=1.0, theta=0.0
% INFO    : Bus 40455	: V=0.9543913, theta=20.309556 -> V=1.0, theta=0.0
% INFO    : Bus 40456	: V=0.9542709, theta=20.312244 -> V=1.0, theta=0.0
% INFO    : Bus 40457	: V=0.9514714, theta=19.807277 -> V=1.0, theta=0.0
% INFO    : Bus 40458	: V=0.9514093, theta=19.847771 -> V=1.0, theta=0.0
% INFO    : Bus 40459	: V=0.9499197, theta=19.872549 -> V=1.0, theta=0.0
% INFO    : Bus 40460	: V=0.9491755, theta=19.871032 -> V=1.0, theta=0.0
% INFO    : Bus 40461	: V=0.9490519, theta=19.82587 -> V=1.0, theta=0.0
% INFO    : Bus 40462	: V=0.9500027, theta=19.666105 -> V=1.0, theta=0.0
% INFO    : Bus 40463	: V=0.9503061, theta=19.659108 -> V=1.0, theta=0.0
% INFO    : Bus 40464	: V=0.9520261, theta=19.798297 -> V=1.0, theta=0.0
% INFO    : Bus 40465	: V=0.9518425, theta=19.747953 -> V=1.0, theta=0.0
% INFO    : Bus 40466	: V=0.9504423, theta=19.636657 -> V=1.0, theta=0.0
% INFO    : Bus 40467	: V=0.9514363, theta=19.704012 -> V=1.0, theta=0.0
% INFO    : Bus 40468	: V=0.9525173, theta=19.694355 -> V=1.0, theta=0.0
% INFO    : Bus 40469	: V=0.9509723, theta=19.625925 -> V=1.0, theta=0.0
% INFO    : Bus 40470	: V=0.9529106, theta=19.975245 -> V=1.0, theta=0.0
% INFO    : Bus 40471	: V=0.9517982, theta=19.786672 -> V=1.0, theta=0.0
% INFO    : Bus 40472	: V=0.9569171, theta=19.532069 -> V=1.0, theta=0.0
% INFO    : Bus 40473	: V=0.9531107, theta=19.605285 -> V=1.0, theta=0.0
% INFO    : Bus 40474	: V=0.9579561, theta=19.323824 -> V=1.0, theta=0.0
% INFO    : Bus 40475	: V=0.9556957, theta=19.466013 -> V=1.0, theta=0.0
% INFO    : Bus 40476	: V=0.9573554, theta=19.331004 -> V=1.0, theta=0.0
% INFO    : Bus 40477	: V=0.9563472, theta=19.241705 -> V=1.0, theta=0.0
% INFO    : Bus 40478	: V=0.9556354, theta=19.313902 -> V=1.0, theta=0.0
% INFO    : Bus 40479	: V=0.9550041, theta=19.398055 -> V=1.0, theta=0.0
% INFO    : Bus 40480	: V=0.9599108, theta=19.577703 -> V=1.0, theta=0.0
% INFO    : Bus 40481	: V=0.9542506, theta=19.472343 -> V=1.0, theta=0.0
% INFO    : Bus 40482	: V=0.9593063, theta=19.523979 -> V=1.0, theta=0.0
% INFO    : Bus 40483	: V=0.9548086, theta=19.424942 -> V=1.0, theta=0.0
% INFO    : Bus 40484	: V=0.9549529, theta=19.389356 -> V=1.0, theta=0.0
% INFO    : Bus 40485	: V=0.9553693, theta=19.332017 -> V=1.0, theta=0.0
% INFO    : Bus 40486	: V=0.959131, theta=19.477378 -> V=1.0, theta=0.0
% INFO    : Bus 40487	: V=0.9588886, theta=19.447988 -> V=1.0, theta=0.0
% INFO    : Bus 40488	: V=0.9524788, theta=19.500572 -> V=1.0, theta=0.0
% INFO    : Bus 40489	: V=0.9513008, theta=19.549377 -> V=1.0, theta=0.0
% INFO    : Bus 40490	: V=0.9509775, theta=19.580423 -> V=1.0, theta=0.0
% INFO    : Bus 40491	: V=0.9510043, theta=19.61737 -> V=1.0, theta=0.0
% INFO    : Bus 40492	: V=0.9509166, theta=19.59864 -> V=1.0, theta=0.0
% INFO    : Bus 40493	: V=0.9551304, theta=19.997979 -> V=1.0, theta=0.0
% INFO    : Bus 40494	: V=0.9509597, theta=19.532264 -> V=1.0, theta=0.0
% INFO    : Bus 40495	: V=0.9511632, theta=19.522084 -> V=1.0, theta=0.0
% INFO    : Bus 40496	: V=0.954568, theta=19.345285 -> V=1.0, theta=0.0
% INFO    : Bus 40497	: V=0.9545953, theta=19.356046 -> V=1.0, theta=0.0
% INFO    : Bus 40498	: V=0.9551369, theta=19.341772 -> V=1.0, theta=0.0
% INFO    : Bus 40499	: V=0.9513893, theta=19.494655 -> V=1.0, theta=0.0
% INFO    : Bus 40500	: V=0.9511644, theta=19.510084 -> V=1.0, theta=0.0
% INFO    : Bus 40501	: V=0.9529956, theta=19.444554 -> V=1.0, theta=0.0
% INFO    : Bus 40502	: V=0.9593457, theta=19.507804 -> V=1.0, theta=0.0
% INFO    : Bus 40503	: V=0.9538943, theta=19.379094 -> V=1.0, theta=0.0
% INFO    : Bus 40504	: V=0.9543365, theta=19.359592 -> V=1.0, theta=0.0
% INFO    : Bus 40505	: V=0.9591791, theta=19.477908 -> V=1.0, theta=0.0
% INFO    : Bus 40506	: V=0.9554272, theta=19.34436 -> V=1.0, theta=0.0
% INFO    : Bus 40507	: V=0.9589658, theta=19.451804 -> V=1.0, theta=0.0
% INFO    : Bus 40508	: V=0.9566922, theta=19.241978 -> V=1.0, theta=0.0
% INFO    : Bus 40509	: V=0.9591283, theta=19.447295 -> V=1.0, theta=0.0
% INFO    : Bus 40510	: V=0.9593487, theta=19.444072 -> V=1.0, theta=0.0
% INFO    : Bus 40511	: V=0.9540668, theta=19.355327 -> V=1.0, theta=0.0
% INFO    : Bus 40512	: V=0.9539739, theta=19.357913 -> V=1.0, theta=0.0
% INFO    : Bus 40513	: V=0.9595023, theta=19.491856 -> V=1.0, theta=0.0
% INFO    : Bus 40514	: V=0.9568153, theta=19.35255 -> V=1.0, theta=0.0
% INFO    : Bus 40515	: V=0.9598019, theta=19.477323 -> V=1.0, theta=0.0
% INFO    : Bus 40516	: V=0.9505329, theta=19.660325 -> V=1.0, theta=0.0
% INFO    : Bus 40517	: V=0.9510363, theta=19.575446 -> V=1.0, theta=0.0
% INFO    : Bus 40518	: V=0.9505268, theta=19.649066 -> V=1.0, theta=0.0
% INFO    : Bus 40519	: V=0.9502089, theta=19.706259 -> V=1.0, theta=0.0
% INFO    : Bus 40520	: V=0.9502731, theta=19.747293 -> V=1.0, theta=0.0
% INFO    : Bus 40521	: V=0.9509109, theta=19.720491 -> V=1.0, theta=0.0
% INFO    : Bus 40522	: V=0.9510233, theta=19.716163 -> V=1.0, theta=0.0
% INFO    : Bus 40523	: V=0.9506744, theta=19.68326 -> V=1.0, theta=0.0
% INFO    : Bus 40524	: V=0.9514744, theta=19.657427 -> V=1.0, theta=0.0
% INFO    : Bus 40525	: V=0.9504699, theta=19.607224 -> V=1.0, theta=0.0
% INFO    : Bus 40526	: V=0.9508243, theta=19.538255 -> V=1.0, theta=0.0
% INFO    : Bus 40527	: V=0.9512695, theta=19.629003 -> V=1.0, theta=0.0
% INFO    : Bus 40528	: V=0.9569594, theta=19.348719 -> V=1.0, theta=0.0
% INFO    : Bus 40529	: V=0.9539775, theta=19.38071 -> V=1.0, theta=0.0
% INFO    : Bus 40530	: V=0.951726, theta=19.484186 -> V=1.0, theta=0.0
% INFO    : Bus 40531	: V=0.9512612, theta=19.485969 -> V=1.0, theta=0.0
% INFO    : Bus 40532	: V=0.9515615, theta=19.491652 -> V=1.0, theta=0.0
% INFO    : Bus 40533	: V=0.9520547, theta=19.464586 -> V=1.0, theta=0.0
% INFO    : Bus 40534	: V=0.9586866, theta=19.577232 -> V=1.0, theta=0.0
% INFO    : Bus 40535	: V=0.9520551, theta=19.470364 -> V=1.0, theta=0.0
% INFO    : Bus 40536	: V=0.9523614, theta=19.462166 -> V=1.0, theta=0.0
% INFO    : Bus 40537	: V=0.9537465, theta=19.390297 -> V=1.0, theta=0.0
% INFO    : Bus 40538	: V=0.9535411, theta=19.395279 -> V=1.0, theta=0.0
% INFO    : Bus 40539	: V=0.9538022, theta=19.395037 -> V=1.0, theta=0.0
% INFO    : Bus 40540	: V=0.9540695, theta=19.396644 -> V=1.0, theta=0.0
% INFO    : Bus 40541	: V=0.9532167, theta=19.434474 -> V=1.0, theta=0.0
% INFO    : Bus 40542	: V=0.953673, theta=19.347445 -> V=1.0, theta=0.0
% INFO    : Bus 40543	: V=0.9587514, theta=19.575507 -> V=1.0, theta=0.0
% INFO    : Bus 40544	: V=0.957081, theta=19.34592 -> V=1.0, theta=0.0
% INFO    : Bus 40545	: V=0.9723079, theta=19.976618 -> V=1.0, theta=0.0
% INFO    : Bus 40546	: V=0.9572328, theta=19.358421 -> V=1.0, theta=0.0
% INFO    : Bus 40547	: V=0.9569631, theta=19.364317 -> V=1.0, theta=0.0
% INFO    : Bus 40548	: V=0.9604264, theta=19.454158 -> V=1.0, theta=0.0
% INFO    : Bus 40549	: V=0.9594132, theta=19.408214 -> V=1.0, theta=0.0
% INFO    : Bus 40550	: V=0.9601214, theta=19.468792 -> V=1.0, theta=0.0
% INFO    : Bus 40551	: V=0.9599318, theta=19.453719 -> V=1.0, theta=0.0
% INFO    : Bus 40552	: V=0.9599597, theta=19.450129 -> V=1.0, theta=0.0
% INFO    : Bus 40553	: V=0.9597461, theta=19.442789 -> V=1.0, theta=0.0
% INFO    : Bus 40554	: V=0.9597799, theta=19.441648 -> V=1.0, theta=0.0
% INFO    : Bus 40555	: V=0.9561917, theta=19.244937 -> V=1.0, theta=0.0
% INFO    : Bus 40556	: V=0.9561127, theta=19.229049 -> V=1.0, theta=0.0
% INFO    : Bus 40557	: V=0.9559253, theta=19.204623 -> V=1.0, theta=0.0
% INFO    : Bus 40558	: V=0.9559, theta=19.249218 -> V=1.0, theta=0.0
% INFO    : Bus 40559	: V=0.9560414, theta=19.24988 -> V=1.0, theta=0.0
% INFO    : Bus 40560	: V=0.9562161, theta=19.251105 -> V=1.0, theta=0.0
% INFO    : Bus 40561	: V=0.9566166, theta=19.299868 -> V=1.0, theta=0.0
% INFO    : Bus 40562	: V=0.9598441, theta=19.440369 -> V=1.0, theta=0.0
% INFO    : Bus 40563	: V=0.9601326, theta=19.444584 -> V=1.0, theta=0.0
% INFO    : Bus 40564	: V=0.9600202, theta=19.445909 -> V=1.0, theta=0.0
% INFO    : Bus 40565	: V=0.9602942, theta=19.442518 -> V=1.0, theta=0.0
% INFO    : Bus 40566	: V=0.9601697, theta=19.444392 -> V=1.0, theta=0.0
% INFO    : Bus 40567	: V=0.9567005, theta=19.297332 -> V=1.0, theta=0.0
% INFO    : Bus 40568	: V=0.9565281, theta=19.288874 -> V=1.0, theta=0.0
% INFO    : Bus 40569	: V=0.9562726, theta=19.273113 -> V=1.0, theta=0.0
% INFO    : Bus 40570	: V=0.9561343, theta=19.260209 -> V=1.0, theta=0.0
% INFO    : Bus 40571	: V=0.9557461, theta=19.239682 -> V=1.0, theta=0.0
% INFO    : Bus 40572	: V=0.9557264, theta=19.244632 -> V=1.0, theta=0.0
% INFO    : Bus 40573	: V=0.9556988, theta=19.216788 -> V=1.0, theta=0.0
% INFO    : Bus 40574	: V=0.9561808, theta=19.221307 -> V=1.0, theta=0.0
% INFO    : Bus 40575	: V=0.9567159, theta=19.249637 -> V=1.0, theta=0.0
% INFO    : Bus 40576	: V=0.956779, theta=19.254584 -> V=1.0, theta=0.0
% INFO    : Bus 40577	: V=0.9568899, theta=19.261177 -> V=1.0, theta=0.0
% INFO    : Bus 40578	: V=0.9570978, theta=19.266515 -> V=1.0, theta=0.0
% INFO    : Bus 40579	: V=0.9604346, theta=19.440756 -> V=1.0, theta=0.0
% INFO    : Bus 40580	: V=0.956756, theta=19.265642 -> V=1.0, theta=0.0
% INFO    : Bus 40581	: V=0.9568099, theta=19.264045 -> V=1.0, theta=0.0
% INFO    : Bus 40582	: V=0.9571022, theta=19.306225 -> V=1.0, theta=0.0
% INFO    : Bus 40583	: V=0.9605009, theta=19.440514 -> V=1.0, theta=0.0
% INFO    : Bus 40584	: V=0.9566189, theta=19.365282 -> V=1.0, theta=0.0
% INFO    : Bus 40585	: V=0.9611422, theta=19.465946 -> V=1.0, theta=0.0
% INFO    : Bus 40586	: V=0.9608204, theta=19.441744 -> V=1.0, theta=0.0
% INFO    : Bus 40587	: V=0.95723, theta=19.280832 -> V=1.0, theta=0.0
% INFO    : Bus 40588	: V=0.9568652, theta=19.26331 -> V=1.0, theta=0.0
% INFO    : Bus 40589	: V=0.9569712, theta=19.345168 -> V=1.0, theta=0.0
% INFO    : Bus 40590	: V=0.9611669, theta=19.430805 -> V=1.0, theta=0.0
% INFO    : Bus 40591	: V=0.9617173, theta=19.420152 -> V=1.0, theta=0.0
% INFO    : Bus 40592	: V=0.9564486, theta=19.197021 -> V=1.0, theta=0.0
% INFO    : Bus 40593	: V=0.9564625, theta=19.204921 -> V=1.0, theta=0.0
% INFO    : Bus 40594	: V=0.9563401, theta=19.217891 -> V=1.0, theta=0.0
% INFO    : Bus 40595	: V=0.9565727, theta=19.242935 -> V=1.0, theta=0.0
% INFO    : Bus 40596	: V=0.9566349, theta=19.241406 -> V=1.0, theta=0.0
% INFO    : Bus 40597	: V=0.9565927, theta=19.2426 -> V=1.0, theta=0.0
% INFO    : Bus 40598	: V=0.9567219, theta=19.254674 -> V=1.0, theta=0.0
% INFO    : Bus 40599	: V=0.9566997, theta=19.228892 -> V=1.0, theta=0.0
% INFO    : Bus 40600	: V=0.9566453, theta=19.222755 -> V=1.0, theta=0.0
% INFO    : Bus 40601	: V=0.9595798, theta=19.348422 -> V=1.0, theta=0.0
% INFO    : Bus 40602	: V=0.9568286, theta=19.210112 -> V=1.0, theta=0.0
% INFO    : Bus 40603	: V=0.9570861, theta=19.200048 -> V=1.0, theta=0.0
% INFO    : Bus 40604	: V=0.9567841, theta=19.201076 -> V=1.0, theta=0.0
% INFO    : Bus 40605	: V=0.9565209, theta=19.179779 -> V=1.0, theta=0.0
% INFO    : Bus 40606	: V=0.9568508, theta=19.160232 -> V=1.0, theta=0.0
% INFO    : Bus 40607	: V=0.9567438, theta=19.170635 -> V=1.0, theta=0.0
% INFO    : Bus 40608	: V=0.9567432, theta=19.178486 -> V=1.0, theta=0.0
% INFO    : Bus 40609	: V=0.9568185, theta=19.18301 -> V=1.0, theta=0.0
% INFO    : Bus 40610	: V=0.9596735, theta=19.338176 -> V=1.0, theta=0.0
% INFO    : Bus 40611	: V=0.95975, theta=19.333942 -> V=1.0, theta=0.0
% INFO    : Bus 40612	: V=0.9598597, theta=19.330385 -> V=1.0, theta=0.0
% INFO    : Bus 40613	: V=0.9569999, theta=19.206377 -> V=1.0, theta=0.0
% INFO    : Bus 40614	: V=0.9572214, theta=19.176696 -> V=1.0, theta=0.0
% INFO    : Bus 40615	: V=0.9572468, theta=19.167624 -> V=1.0, theta=0.0
% INFO    : Bus 40616	: V=0.9571988, theta=19.155451 -> V=1.0, theta=0.0
% INFO    : Bus 40617	: V=0.9573054, theta=19.140627 -> V=1.0, theta=0.0
% INFO    : Bus 40618	: V=0.9572063, theta=19.142371 -> V=1.0, theta=0.0
% INFO    : Bus 40619	: V=0.9575533, theta=19.141612 -> V=1.0, theta=0.0
% INFO    : Bus 40620	: V=0.9578678, theta=19.13642 -> V=1.0, theta=0.0
% INFO    : Bus 40621	: V=0.9584742, theta=19.137012 -> V=1.0, theta=0.0
% INFO    : Bus 40622	: V=0.9546795, theta=19.404554 -> V=1.0, theta=0.0
% INFO    : Bus 40623	: V=0.9593263, theta=19.556361 -> V=1.0, theta=0.0
% INFO    : Bus 40624	: V=0.9590499, theta=19.580149 -> V=1.0, theta=0.0
% INFO    : Bus 40625	: V=0.9589754, theta=19.61313 -> V=1.0, theta=0.0
% INFO    : Bus 40626	: V=0.9595338, theta=19.565951 -> V=1.0, theta=0.0
% INFO    : Bus 40627	: V=0.9597547, theta=19.551275 -> V=1.0, theta=0.0
% INFO    : Bus 40628	: V=0.960549, theta=19.53198 -> V=1.0, theta=0.0
% INFO    : Bus 40629	: V=0.9618323, theta=19.514455 -> V=1.0, theta=0.0
% INFO    : Bus 40630	: V=0.9573559, theta=19.293785 -> V=1.0, theta=0.0
% INFO    : Bus 40631	: V=0.956745, theta=19.395973 -> V=1.0, theta=0.0
% INFO    : Bus 40632	: V=0.9597898, theta=19.569362 -> V=1.0, theta=0.0
% INFO    : Bus 40633	: V=0.9601528, theta=19.576073 -> V=1.0, theta=0.0
% INFO    : Bus 40634	: V=0.9572688, theta=19.378128 -> V=1.0, theta=0.0
% INFO    : Bus 40635	: V=0.9573703, theta=19.369578 -> V=1.0, theta=0.0
% INFO    : Bus 40636	: V=0.9628095, theta=19.501968 -> V=1.0, theta=0.0
% INFO    : Bus 40637	: V=0.964013, theta=19.493949 -> V=1.0, theta=0.0
% INFO    : Bus 40638	: V=0.9579104, theta=19.366243 -> V=1.0, theta=0.0
% INFO    : Bus 40639	: V=0.9605644, theta=19.583859 -> V=1.0, theta=0.0
% INFO    : Bus 40640	: V=0.9588649, theta=19.383638 -> V=1.0, theta=0.0
% INFO    : Bus 40641	: V=0.9586574, theta=19.361824 -> V=1.0, theta=0.0
% INFO    : Bus 40642	: V=0.9585722, theta=19.342284 -> V=1.0, theta=0.0
% INFO    : Bus 40643	: V=0.9585461, theta=19.3208 -> V=1.0, theta=0.0
% INFO    : Bus 40644	: V=0.9623278, theta=19.409598 -> V=1.0, theta=0.0
% INFO    : Bus 40645	: V=0.9580251, theta=19.284213 -> V=1.0, theta=0.0
% INFO    : Bus 40646	: V=0.9580557, theta=19.29182 -> V=1.0, theta=0.0
% INFO    : Bus 40647	: V=0.9581351, theta=19.300153 -> V=1.0, theta=0.0
% INFO    : Bus 40648	: V=0.9592958, theta=19.241166 -> V=1.0, theta=0.0
% INFO    : Bus 40649	: V=0.9592037, theta=19.242823 -> V=1.0, theta=0.0
% INFO    : Bus 40650	: V=0.9591977, theta=19.242165 -> V=1.0, theta=0.0
% INFO    : Bus 40651	: V=0.9630184, theta=19.404426 -> V=1.0, theta=0.0
% INFO    : Bus 40652	: V=0.9593714, theta=19.237172 -> V=1.0, theta=0.0
% INFO    : Bus 40653	: V=0.9640083, theta=19.402572 -> V=1.0, theta=0.0
% INFO    : Bus 40654	: V=0.9591764, theta=19.24177 -> V=1.0, theta=0.0
% INFO    : Bus 40655	: V=0.9590564, theta=19.224816 -> V=1.0, theta=0.0
% INFO    : Bus 40656	: V=0.9588856, theta=19.221679 -> V=1.0, theta=0.0
% INFO    : Bus 40657	: V=0.9589523, theta=19.226411 -> V=1.0, theta=0.0
% INFO    : Bus 40658	: V=0.9591453, theta=19.230855 -> V=1.0, theta=0.0
% INFO    : Bus 40659	: V=0.9622567, theta=19.330203 -> V=1.0, theta=0.0
% INFO    : Bus 40660	: V=0.960163, theta=19.123581 -> V=1.0, theta=0.0
% INFO    : Bus 40661	: V=0.957945, theta=19.127924 -> V=1.0, theta=0.0
% INFO    : Bus 40662	: V=0.9583152, theta=19.187959 -> V=1.0, theta=0.0
% INFO    : Bus 40663	: V=0.9582953, theta=19.188531 -> V=1.0, theta=0.0
% INFO    : Bus 40664	: V=0.9613757, theta=19.138938 -> V=1.0, theta=0.0
% INFO    : Bus 40665	: V=0.9583808, theta=19.181949 -> V=1.0, theta=0.0
% INFO    : Bus 40666	: V=0.95833, theta=19.183479 -> V=1.0, theta=0.0
% INFO    : Bus 40667	: V=0.9630651, theta=19.177757 -> V=1.0, theta=0.0
% INFO    : Bus 40668	: V=0.9638492, theta=19.175125 -> V=1.0, theta=0.0
% INFO    : Bus 40669	: V=0.9695208, theta=19.341668 -> V=1.0, theta=0.0
% INFO    : Bus 40670	: V=0.9650017, theta=19.400989 -> V=1.0, theta=0.0
% INFO    : Bus 40671	: V=0.9598683, theta=19.175069 -> V=1.0, theta=0.0
% INFO    : Bus 40672	: V=0.9596784, theta=19.164077 -> V=1.0, theta=0.0
% INFO    : Bus 40673	: V=0.9601704, theta=19.206837 -> V=1.0, theta=0.0
% INFO    : Bus 40674	: V=0.9606777, theta=19.203094 -> V=1.0, theta=0.0
% INFO    : Bus 40675	: V=0.9658815, theta=19.405432 -> V=1.0, theta=0.0
% INFO    : Bus 40676	: V=0.9606832, theta=19.199293 -> V=1.0, theta=0.0
% INFO    : Bus 40677	: V=0.9608435, theta=19.198692 -> V=1.0, theta=0.0
% INFO    : Bus 40678	: V=0.9600552, theta=19.201871 -> V=1.0, theta=0.0
% INFO    : Bus 40679	: V=0.9601655, theta=19.19464 -> V=1.0, theta=0.0
% INFO    : Bus 40680	: V=0.9601262, theta=19.191387 -> V=1.0, theta=0.0
% INFO    : Bus 40681	: V=0.960178, theta=19.187098 -> V=1.0, theta=0.0
% INFO    : Bus 40682	: V=0.9668145, theta=19.368542 -> V=1.0, theta=0.0
% INFO    : Bus 40683	: V=0.9603878, theta=19.204059 -> V=1.0, theta=0.0
% INFO    : Bus 40684	: V=0.9614808, theta=19.202038 -> V=1.0, theta=0.0
% INFO    : Bus 40685	: V=0.961376, theta=19.205467 -> V=1.0, theta=0.0
% INFO    : Bus 40686	: V=0.9677063, theta=19.435656 -> V=1.0, theta=0.0
% INFO    : Bus 40687	: V=0.9669032, theta=19.421148 -> V=1.0, theta=0.0
% INFO    : Bus 40688	: V=0.9677875, theta=19.423556 -> V=1.0, theta=0.0
% INFO    : Bus 40689	: V=0.9644535, theta=19.118171 -> V=1.0, theta=0.0
% INFO    : Bus 40690	: V=0.9702425, theta=19.332881 -> V=1.0, theta=0.0
% INFO    : Bus 40691	: V=0.964935, theta=19.114433 -> V=1.0, theta=0.0
% INFO    : Bus 40692	: V=0.96505, theta=19.114899 -> V=1.0, theta=0.0
% INFO    : Bus 40693	: V=0.9647982, theta=19.120894 -> V=1.0, theta=0.0
% INFO    : Bus 40694	: V=0.9639315, theta=19.121572 -> V=1.0, theta=0.0
% INFO    : Bus 40695	: V=0.9634461, theta=19.12337 -> V=1.0, theta=0.0
% INFO    : Bus 40696	: V=0.962616, theta=19.131605 -> V=1.0, theta=0.0
% INFO    : Bus 40697	: V=0.9671359, theta=19.364705 -> V=1.0, theta=0.0
% INFO    : Bus 40698	: V=0.9597783, theta=19.125056 -> V=1.0, theta=0.0
% INFO    : Bus 40699	: V=0.9608582, theta=19.12547 -> V=1.0, theta=0.0
% INFO    : Bus 40700	: V=0.9609807, theta=19.070744 -> V=1.0, theta=0.0
% INFO    : Bus 40701	: V=0.9621722, theta=19.092547 -> V=1.0, theta=0.0
% INFO    : Bus 40702	: V=0.9628161, theta=19.030507 -> V=1.0, theta=0.0
% INFO    : Bus 40703	: V=0.9620369, theta=19.018844 -> V=1.0, theta=0.0
% INFO    : Bus 40704	: V=0.9618619, theta=19.013055 -> V=1.0, theta=0.0
% INFO    : Bus 40705	: V=0.961579, theta=18.997411 -> V=1.0, theta=0.0
% INFO    : Bus 40706	: V=0.9608806, theta=19.01951 -> V=1.0, theta=0.0
% INFO    : Bus 40707	: V=0.9616864, theta=19.01632 -> V=1.0, theta=0.0
% INFO    : Bus 40708	: V=0.9603991, theta=19.01858 -> V=1.0, theta=0.0
% INFO    : Bus 40709	: V=0.96091, theta=18.986075 -> V=1.0, theta=0.0
% INFO    : Bus 40710	: V=0.9612116, theta=18.988158 -> V=1.0, theta=0.0
% INFO    : Bus 40711	: V=0.9613492, theta=18.989718 -> V=1.0, theta=0.0
% INFO    : Bus 40712	: V=0.9608745, theta=18.987522 -> V=1.0, theta=0.0
% INFO    : Bus 40713	: V=0.9605766, theta=18.968221 -> V=1.0, theta=0.0
% INFO    : Bus 40714	: V=0.9608598, theta=18.965498 -> V=1.0, theta=0.0
% INFO    : Bus 40715	: V=0.9615031, theta=18.970839 -> V=1.0, theta=0.0
% INFO    : Bus 40716	: V=0.9611693, theta=18.947397 -> V=1.0, theta=0.0
% INFO    : Bus 40717	: V=0.9606601, theta=18.933309 -> V=1.0, theta=0.0
% INFO    : Bus 40718	: V=0.9612067, theta=18.937625 -> V=1.0, theta=0.0
% INFO    : Bus 40719	: V=0.9611382, theta=18.941653 -> V=1.0, theta=0.0
% INFO    : Bus 40720	: V=0.9615586, theta=18.930716 -> V=1.0, theta=0.0
% INFO    : Bus 40721	: V=0.9613405, theta=18.934624 -> V=1.0, theta=0.0
% INFO    : Bus 40722	: V=0.9607408, theta=18.930697 -> V=1.0, theta=0.0
% INFO    : Bus 40723	: V=0.9600931, theta=18.983689 -> V=1.0, theta=0.0
% INFO    : Bus 40724	: V=0.9601372, theta=18.982184 -> V=1.0, theta=0.0
% INFO    : Bus 40725	: V=0.9602198, theta=18.979771 -> V=1.0, theta=0.0
% INFO    : Bus 40726	: V=0.9607637, theta=18.923171 -> V=1.0, theta=0.0
% INFO    : Bus 40727	: V=0.960811, theta=18.918317 -> V=1.0, theta=0.0
% INFO    : Bus 40728	: V=0.9609016, theta=18.910938 -> V=1.0, theta=0.0
% INFO    : Bus 40729	: V=0.9611371, theta=18.897683 -> V=1.0, theta=0.0
% INFO    : Bus 40730	: V=0.9609896, theta=18.88688 -> V=1.0, theta=0.0
% INFO    : Bus 40731	: V=0.9609599, theta=18.89285 -> V=1.0, theta=0.0
% INFO    : Bus 40732	: V=0.9609895, theta=18.895821 -> V=1.0, theta=0.0
% INFO    : Bus 40733	: V=0.9597738, theta=18.842583 -> V=1.0, theta=0.0
% INFO    : Bus 40734	: V=0.9614593, theta=18.879444 -> V=1.0, theta=0.0
% INFO    : Bus 40735	: V=0.9613669, theta=18.887149 -> V=1.0, theta=0.0
% INFO    : Bus 40736	: V=0.9609804, theta=18.915585 -> V=1.0, theta=0.0
% INFO    : Bus 40737	: V=0.9609057, theta=18.917817 -> V=1.0, theta=0.0
% INFO    : Bus 40738	: V=0.9614106, theta=18.885728 -> V=1.0, theta=0.0
% INFO    : Bus 40739	: V=0.961534, theta=18.87724 -> V=1.0, theta=0.0
% INFO    : Bus 40740	: V=0.9619937, theta=18.855793 -> V=1.0, theta=0.0
% INFO    : Bus 40741	: V=0.9728506, theta=19.021627 -> V=1.0, theta=0.0
% INFO    : Bus 40742	: V=0.9621783, theta=18.8529 -> V=1.0, theta=0.0
% INFO    : Bus 40743	: V=0.9618893, theta=18.86413 -> V=1.0, theta=0.0
% INFO    : Bus 40744	: V=0.9732469, theta=19.020686 -> V=1.0, theta=0.0
% INFO    : Bus 40745	: V=0.9609189, theta=18.843418 -> V=1.0, theta=0.0
% INFO    : Bus 40746	: V=0.9609625, theta=18.853133 -> V=1.0, theta=0.0
% INFO    : Bus 40747	: V=0.9596741, theta=18.844994 -> V=1.0, theta=0.0
% INFO    : Bus 40748	: V=0.9597392, theta=18.843154 -> V=1.0, theta=0.0
% INFO    : Bus 40749	: V=0.9597173, theta=18.843978 -> V=1.0, theta=0.0
% INFO    : Bus 40750	: V=0.9600568, theta=18.833971 -> V=1.0, theta=0.0
% INFO    : Bus 40751	: V=0.9599379, theta=18.837092 -> V=1.0, theta=0.0
% INFO    : Bus 40752	: V=0.9604046, theta=18.799816 -> V=1.0, theta=0.0
% INFO    : Bus 40753	: V=0.9749057, theta=19.032148 -> V=1.0, theta=0.0
% INFO    : Bus 40754	: V=0.9712271, theta=18.838235 -> V=1.0, theta=0.0
% INFO    : Bus 40755	: V=0.9742697, theta=19.021359 -> V=1.0, theta=0.0
% INFO    : Bus 40756	: V=0.974106, theta=18.990186 -> V=1.0, theta=0.0
% INFO    : Bus 40757	: V=0.966665, theta=18.773822 -> V=1.0, theta=0.0
% INFO    : Bus 40758	: V=0.9661039, theta=18.786996 -> V=1.0, theta=0.0
% INFO    : Bus 40759	: V=0.9756625, theta=19.046664 -> V=1.0, theta=0.0
% INFO    : Bus 40760	: V=0.971153, theta=18.840436 -> V=1.0, theta=0.0
% INFO    : Bus 40761	: V=0.9758864, theta=19.049372 -> V=1.0, theta=0.0
% INFO    : Bus 40762	: V=0.9660404, theta=18.789089 -> V=1.0, theta=0.0
% INFO    : Bus 40763	: V=0.9763582, theta=19.057187 -> V=1.0, theta=0.0
% INFO    : Bus 40764	: V=0.9688243, theta=18.790693 -> V=1.0, theta=0.0
% INFO    : Bus 40765	: V=0.9700387, theta=18.830328 -> V=1.0, theta=0.0
% INFO    : Bus 40766	: V=0.9690007, theta=18.823968 -> V=1.0, theta=0.0
% INFO    : Bus 40767	: V=0.974032, theta=18.920045 -> V=1.0, theta=0.0
% INFO    : Bus 40768	: V=0.9645777, theta=18.717244 -> V=1.0, theta=0.0
% INFO    : Bus 40769	: V=0.962838, theta=18.706332 -> V=1.0, theta=0.0
% INFO    : Bus 40770	: V=0.9635776, theta=18.704395 -> V=1.0, theta=0.0
% INFO    : Bus 40771	: V=0.9623273, theta=18.703971 -> V=1.0, theta=0.0
% INFO    : Bus 40772	: V=0.9608648, theta=18.663789 -> V=1.0, theta=0.0
% INFO    : Bus 40773	: V=0.9635035, theta=18.706656 -> V=1.0, theta=0.0
% INFO    : Bus 40774	: V=0.9653576, theta=18.679232 -> V=1.0, theta=0.0
% INFO    : Bus 40775	: V=0.9644439, theta=18.652411 -> V=1.0, theta=0.0
% INFO    : Bus 40776	: V=0.9672193, theta=18.741258 -> V=1.0, theta=0.0
% INFO    : Bus 40777	: V=0.969407, theta=18.800112 -> V=1.0, theta=0.0
% INFO    : Bus 40778	: V=0.9696103, theta=18.79417 -> V=1.0, theta=0.0
% INFO    : Bus 40779	: V=0.9791399, theta=19.114749 -> V=1.0, theta=0.0
% INFO    : Bus 40780	: V=0.9684231, theta=18.790821 -> V=1.0, theta=0.0
% INFO    : Bus 40781	: V=0.9683027, theta=18.785817 -> V=1.0, theta=0.0
% INFO    : Bus 40782	: V=0.9776999, theta=19.089947 -> V=1.0, theta=0.0
% INFO    : Bus 40783	: V=0.9796561, theta=19.124718 -> V=1.0, theta=0.0
% INFO    : Bus 40784	: V=0.9697139, theta=18.791223 -> V=1.0, theta=0.0
% INFO    : Bus 40785	: V=0.9697006, theta=18.791058 -> V=1.0, theta=0.0
% INFO    : Bus 40786	: V=0.9654398, theta=18.67608 -> V=1.0, theta=0.0
% INFO    : Bus 40787	: V=0.9694557, theta=18.78227 -> V=1.0, theta=0.0
% INFO    : Bus 40788	: V=0.9664072, theta=18.712166 -> V=1.0, theta=0.0
% INFO    : Bus 40789	: V=0.9659743, theta=18.694928 -> V=1.0, theta=0.0
% INFO    : Bus 40790	: V=0.9696118, theta=18.778152 -> V=1.0, theta=0.0
% INFO    : Bus 40791	: V=0.9805255, theta=19.141634 -> V=1.0, theta=0.0
% INFO    : Bus 40792	: V=0.96251, theta=18.652485 -> V=1.0, theta=0.0
% INFO    : Bus 40793	: V=0.9637393, theta=18.645748 -> V=1.0, theta=0.0
% INFO    : Bus 40794	: V=0.9641117, theta=18.630576 -> V=1.0, theta=0.0
% INFO    : Bus 40795	: V=0.9626692, theta=18.472074 -> V=1.0, theta=0.0
% INFO    : Bus 40796	: V=0.9625817, theta=18.474461 -> V=1.0, theta=0.0
% INFO    : Bus 40797	: V=0.9648611, theta=18.612119 -> V=1.0, theta=0.0
% INFO    : Bus 40798	: V=0.964912, theta=18.541917 -> V=1.0, theta=0.0
% INFO    : Bus 40799	: V=0.9649846, theta=18.58118 -> V=1.0, theta=0.0
% INFO    : Bus 40800	: V=0.9642149, theta=18.538212 -> V=1.0, theta=0.0
% INFO    : Bus 40801	: V=0.9640833, theta=18.505291 -> V=1.0, theta=0.0
% INFO    : Bus 40802	: V=0.9719987, theta=18.431605 -> V=1.0, theta=0.0
% INFO    : Bus 40803	: V=0.9647814, theta=18.493717 -> V=1.0, theta=0.0
% INFO    : Bus 40804	: V=0.9651344, theta=18.499826 -> V=1.0, theta=0.0
% INFO    : Bus 40805	: V=0.9664471, theta=18.672243 -> V=1.0, theta=0.0
% INFO    : Bus 40806	: V=0.966174, theta=18.623833 -> V=1.0, theta=0.0
% INFO    : Bus 40807	: V=0.9657547, theta=18.635157 -> V=1.0, theta=0.0
% INFO    : Bus 40808	: V=0.9812376, theta=19.163681 -> V=1.0, theta=0.0
% INFO    : Bus 40809	: V=0.9711947, theta=18.805203 -> V=1.0, theta=0.0
% INFO    : Bus 40810	: V=0.9782151, theta=19.111077 -> V=1.0, theta=0.0
% INFO    : Bus 40811	: V=0.9740525, theta=18.863009 -> V=1.0, theta=0.0
% INFO    : Bus 40812	: V=0.9737579, theta=18.852756 -> V=1.0, theta=0.0
% INFO    : Bus 40813	: V=0.9817429, theta=19.243484 -> V=1.0, theta=0.0
% INFO    : Bus 40814	: V=0.9739982, theta=18.880119 -> V=1.0, theta=0.0
% INFO    : Bus 40815	: V=0.9814712, theta=19.277773 -> V=1.0, theta=0.0
% INFO    : Bus 40816	: V=0.9813046, theta=19.305618 -> V=1.0, theta=0.0
% INFO    : Bus 40817	: V=0.9658431, theta=18.477083 -> V=1.0, theta=0.0
% INFO    : Bus 40818	: V=0.9721417, theta=18.427754 -> V=1.0, theta=0.0
% INFO    : Bus 40819	: V=0.9709102, theta=18.482729 -> V=1.0, theta=0.0
% INFO    : Bus 40820	: V=0.971166, theta=18.449127 -> V=1.0, theta=0.0
% INFO    : Bus 40821	: V=0.972315, theta=18.42455 -> V=1.0, theta=0.0
% INFO    : Bus 40822	: V=0.9669001, theta=18.416109 -> V=1.0, theta=0.0
% INFO    : Bus 40823	: V=0.9727031, theta=18.419936 -> V=1.0, theta=0.0
% INFO    : Bus 40824	: V=0.9740085, theta=18.805188 -> V=1.0, theta=0.0
% INFO    : Bus 40825	: V=0.9750327, theta=18.677201 -> V=1.0, theta=0.0
% INFO    : Bus 40826	: V=0.9744428, theta=18.816201 -> V=1.0, theta=0.0
% INFO    : Bus 40827	: V=0.9803738, theta=19.205274 -> V=1.0, theta=0.0
% INFO    : Bus 40828	: V=0.9750773, theta=19.043918 -> V=1.0, theta=0.0
% INFO    : Bus 40829	: V=0.9707436, theta=19.353312 -> V=1.0, theta=0.0
% INFO    : Bus 40830	: V=0.9714177, theta=19.344657 -> V=1.0, theta=0.0
% INFO    : Bus 40831	: V=0.9646731, theta=18.90706 -> V=1.0, theta=0.0
% INFO    : Bus 40832	: V=0.9639941, theta=18.903225 -> V=1.0, theta=0.0
% INFO    : Bus 40833	: V=0.9733711, theta=19.326073 -> V=1.0, theta=0.0
% INFO    : Bus 40834	: V=0.9844837, theta=19.615479 -> V=1.0, theta=0.0
% INFO    : Bus 40835	: V=0.9613124, theta=19.399365 -> V=1.0, theta=0.0
% INFO    : Bus 40836	: V=0.9608882, theta=19.386818 -> V=1.0, theta=0.0
% INFO    : Bus 40837	: V=0.9848555, theta=19.521844 -> V=1.0, theta=0.0
% INFO    : Bus 40838	: V=0.9686979, theta=19.072039 -> V=1.0, theta=0.0
% INFO    : Bus 40839	: V=0.9699186, theta=19.36856 -> V=1.0, theta=0.0
% INFO    : Bus 40840	: V=0.9631428, theta=18.905715 -> V=1.0, theta=0.0
% INFO    : Bus 40841	: V=0.9690554, theta=19.065403 -> V=1.0, theta=0.0
% INFO    : Bus 40842	: V=0.9630249, theta=18.905085 -> V=1.0, theta=0.0
% INFO    : Bus 40843	: V=0.9597567, theta=19.050856 -> V=1.0, theta=0.0
% INFO    : Bus 40844	: V=0.9604213, theta=19.063458 -> V=1.0, theta=0.0
% INFO    : Bus 40845	: V=0.9614412, theta=19.09407 -> V=1.0, theta=0.0
% INFO    : Bus 40846	: V=0.9610788, theta=19.026716 -> V=1.0, theta=0.0
% INFO    : Bus 40847	: V=0.960136, theta=19.029551 -> V=1.0, theta=0.0
% INFO    : Bus 40848	: V=0.9601982, theta=19.002017 -> V=1.0, theta=0.0
% INFO    : Bus 40849	: V=0.9596101, theta=18.993444 -> V=1.0, theta=0.0
% INFO    : Bus 40850	: V=0.9593645, theta=18.988301 -> V=1.0, theta=0.0
% INFO    : Bus 40851	: V=0.9604548, theta=18.974538 -> V=1.0, theta=0.0
% INFO    : Bus 40852	: V=0.9589294, theta=19.03645 -> V=1.0, theta=0.0
% INFO    : Bus 40853	: V=0.9589106, theta=19.023482 -> V=1.0, theta=0.0
% INFO    : Bus 40854	: V=0.9695832, theta=19.247625 -> V=1.0, theta=0.0
% INFO    : Bus 40855	: V=0.9634274, theta=19.039263 -> V=1.0, theta=0.0
% INFO    : Bus 40856	: V=0.9704045, theta=19.306067 -> V=1.0, theta=0.0
% INFO    : Bus 40857	: V=0.9701988, theta=19.293817 -> V=1.0, theta=0.0
% INFO    : Bus 40858	: V=0.9701185, theta=19.294533 -> V=1.0, theta=0.0
% INFO    : Bus 40859	: V=0.9589448, theta=18.982324 -> V=1.0, theta=0.0
% INFO    : Bus 40860	: V=0.960801, theta=18.943056 -> V=1.0, theta=0.0
% INFO    : Bus 40861	: V=0.961603, theta=18.963088 -> V=1.0, theta=0.0
% INFO    : Bus 40862	: V=0.962818, theta=18.941395 -> V=1.0, theta=0.0
% INFO    : Bus 40863	: V=0.9618205, theta=18.941248 -> V=1.0, theta=0.0
% INFO    : Bus 40864	: V=0.961262, theta=18.938881 -> V=1.0, theta=0.0
% INFO    : Bus 40865	: V=0.9609133, theta=18.939314 -> V=1.0, theta=0.0
% INFO    : Bus 40866	: V=0.9608434, theta=18.933464 -> V=1.0, theta=0.0
% INFO    : Bus 40867	: V=0.9608857, theta=18.926946 -> V=1.0, theta=0.0
% INFO    : Bus 40868	: V=0.9605923, theta=18.914165 -> V=1.0, theta=0.0
% INFO    : Bus 40869	: V=0.9607084, theta=18.910555 -> V=1.0, theta=0.0
% INFO    : Bus 40870	: V=0.9607893, theta=18.91771 -> V=1.0, theta=0.0
% INFO    : Bus 40871	: V=0.9610371, theta=18.92775 -> V=1.0, theta=0.0
% INFO    : Bus 40872	: V=0.9616067, theta=18.93198 -> V=1.0, theta=0.0
% INFO    : Bus 40873	: V=0.9620295, theta=18.933448 -> V=1.0, theta=0.0
% INFO    : Bus 40874	: V=0.969347, theta=19.05482 -> V=1.0, theta=0.0
% INFO    : Bus 40875	: V=0.9630386, theta=18.902049 -> V=1.0, theta=0.0
% INFO    : Bus 40876	: V=0.9701939, theta=19.037773 -> V=1.0, theta=0.0
% INFO    : Bus 40877	: V=0.9697039, theta=19.043303 -> V=1.0, theta=0.0
% INFO    : Bus 40878	: V=0.9606583, theta=18.912437 -> V=1.0, theta=0.0
% INFO    : Bus 40879	: V=0.9689622, theta=19.091747 -> V=1.0, theta=0.0
% INFO    : Bus 40880	: V=0.9652308, theta=18.861249 -> V=1.0, theta=0.0
% INFO    : Bus 40881	: V=0.9688955, theta=19.067431 -> V=1.0, theta=0.0
% INFO    : Bus 40882	: V=0.9608026, theta=18.914095 -> V=1.0, theta=0.0
% INFO    : Bus 40883	: V=0.9689097, theta=19.040971 -> V=1.0, theta=0.0
% INFO    : Bus 40884	: V=0.9692542, theta=19.040708 -> V=1.0, theta=0.0
% INFO    : Bus 40885	: V=0.9659345, theta=18.845678 -> V=1.0, theta=0.0
% INFO    : Bus 40886	: V=0.9853555, theta=19.421152 -> V=1.0, theta=0.0
% INFO    : Bus 40887	: V=0.9802351, theta=19.682759 -> V=1.0, theta=0.0
% INFO    : Bus 40888	: V=0.9804984, theta=19.635878 -> V=1.0, theta=0.0
% INFO    : Bus 40889	: V=0.9754271, theta=19.20991 -> V=1.0, theta=0.0
% INFO    : Bus 40890	: V=0.9721852, theta=19.04721 -> V=1.0, theta=0.0
% INFO    : Bus 40891	: V=0.9655545, theta=18.80373 -> V=1.0, theta=0.0
% INFO    : Bus 40892	: V=0.965693, theta=18.838419 -> V=1.0, theta=0.0
% INFO    : Bus 40893	: V=0.9706782, theta=19.035053 -> V=1.0, theta=0.0
% INFO    : Bus 40894	: V=0.9651777, theta=18.808694 -> V=1.0, theta=0.0
% INFO    : Bus 40895	: V=0.9644413, theta=18.795075 -> V=1.0, theta=0.0
% INFO    : Bus 40896	: V=0.9697655, theta=18.917262 -> V=1.0, theta=0.0
% INFO    : Bus 40897	: V=0.9861563, theta=19.17422 -> V=1.0, theta=0.0
% INFO    : Bus 40898	: V=0.9684321, theta=18.980962 -> V=1.0, theta=0.0
% INFO    : Bus 40899	: V=0.9686377, theta=18.995883 -> V=1.0, theta=0.0
% INFO    : Bus 40900	: V=0.9625403, theta=18.825868 -> V=1.0, theta=0.0
% INFO    : Bus 40901	: V=0.9687879, theta=18.96533 -> V=1.0, theta=0.0
% INFO    : Bus 40902	: V=0.9680692, theta=18.970565 -> V=1.0, theta=0.0
% INFO    : Bus 40903	: V=0.9611981, theta=18.814566 -> V=1.0, theta=0.0
% INFO    : Bus 40904	: V=0.9621336, theta=18.827716 -> V=1.0, theta=0.0
% INFO    : Bus 40905	: V=0.9629433, theta=18.776106 -> V=1.0, theta=0.0
% INFO    : Bus 40906	: V=0.9612415, theta=18.769047 -> V=1.0, theta=0.0
% INFO    : Bus 40907	: V=0.9685391, theta=18.937199 -> V=1.0, theta=0.0
% INFO    : Bus 40908	: V=0.9607253, theta=18.918043 -> V=1.0, theta=0.0
% INFO    : Bus 40909	: V=0.9606235, theta=18.907201 -> V=1.0, theta=0.0
% INFO    : Bus 40910	: V=0.9605646, theta=18.898506 -> V=1.0, theta=0.0
% INFO    : Bus 40911	: V=0.9605365, theta=18.887986 -> V=1.0, theta=0.0
% INFO    : Bus 40912	: V=0.967321, theta=18.969652 -> V=1.0, theta=0.0
% INFO    : Bus 40913	: V=0.9605379, theta=18.869743 -> V=1.0, theta=0.0
% INFO    : Bus 40914	: V=0.9601795, theta=18.842025 -> V=1.0, theta=0.0
% INFO    : Bus 40915	: V=0.960068, theta=18.842354 -> V=1.0, theta=0.0
% INFO    : Bus 40916	: V=0.9599685, theta=18.842006 -> V=1.0, theta=0.0
% INFO    : Bus 40917	: V=0.959916, theta=18.81995 -> V=1.0, theta=0.0
% INFO    : Bus 40918	: V=0.9602169, theta=18.814969 -> V=1.0, theta=0.0
% INFO    : Bus 40919	: V=0.9606017, theta=18.809657 -> V=1.0, theta=0.0
% INFO    : Bus 40920	: V=0.9611429, theta=18.816855 -> V=1.0, theta=0.0
% INFO    : Bus 40921	: V=0.9606472, theta=18.795969 -> V=1.0, theta=0.0
% INFO    : Bus 40922	: V=0.9605029, theta=18.800668 -> V=1.0, theta=0.0
% INFO    : Bus 40923	: V=0.9587609, theta=18.73236 -> V=1.0, theta=0.0
% INFO    : Bus 40924	: V=0.9588, theta=18.73131 -> V=1.0, theta=0.0
% INFO    : Bus 40925	: V=0.9589634, theta=18.726691 -> V=1.0, theta=0.0
% INFO    : Bus 40926	: V=0.9608066, theta=18.922024 -> V=1.0, theta=0.0
% INFO    : Bus 40927	: V=0.9597609, theta=18.834859 -> V=1.0, theta=0.0
% INFO    : Bus 40928	: V=0.9595409, theta=18.82968 -> V=1.0, theta=0.0
% INFO    : Bus 40929	: V=0.959488, theta=18.822586 -> V=1.0, theta=0.0
% INFO    : Bus 40930	: V=0.9590151, theta=18.802579 -> V=1.0, theta=0.0
% INFO    : Bus 40931	: V=0.9587375, theta=18.789362 -> V=1.0, theta=0.0
% INFO    : Bus 40932	: V=0.9584736, theta=18.816349 -> V=1.0, theta=0.0
% INFO    : Bus 40933	: V=0.9586631, theta=18.810263 -> V=1.0, theta=0.0
% INFO    : Bus 40934	: V=0.9585992, theta=18.777907 -> V=1.0, theta=0.0
% INFO    : Bus 40935	: V=0.9601053, theta=18.825732 -> V=1.0, theta=0.0
% INFO    : Bus 40936	: V=0.9604433, theta=18.79857 -> V=1.0, theta=0.0
% INFO    : Bus 40937	: V=0.960941, theta=18.766687 -> V=1.0, theta=0.0
% INFO    : Bus 40938	: V=0.9599599, theta=18.830221 -> V=1.0, theta=0.0
% INFO    : Bus 40939	: V=0.9585063, theta=18.766629 -> V=1.0, theta=0.0
% INFO    : Bus 40940	: V=0.9585322, theta=18.754633 -> V=1.0, theta=0.0
% INFO    : Bus 40941	: V=0.9582122, theta=18.76452 -> V=1.0, theta=0.0
% INFO    : Bus 40942	: V=0.9619045, theta=18.717066 -> V=1.0, theta=0.0
% INFO    : Bus 40943	: V=0.9637108, theta=18.727983 -> V=1.0, theta=0.0
% INFO    : Bus 40944	: V=0.9614581, theta=18.751104 -> V=1.0, theta=0.0
% INFO    : Bus 40945	: V=0.9706059, theta=18.861994 -> V=1.0, theta=0.0
% INFO    : Bus 40946	: V=0.9630793, theta=18.753975 -> V=1.0, theta=0.0
% INFO    : Bus 40947	: V=0.9708704, theta=18.766525 -> V=1.0, theta=0.0
% INFO    : Bus 40948	: V=0.9701312, theta=18.859836 -> V=1.0, theta=0.0
% INFO    : Bus 40949	: V=0.9614546, theta=18.713895 -> V=1.0, theta=0.0
% INFO    : Bus 40950	: V=0.961074, theta=18.758314 -> V=1.0, theta=0.0
% INFO    : Bus 40951	: V=0.9602954, theta=18.672056 -> V=1.0, theta=0.0
% INFO    : Bus 40952	: V=0.9588836, theta=18.706869 -> V=1.0, theta=0.0
% INFO    : Bus 40953	: V=0.9577026, theta=18.733083 -> V=1.0, theta=0.0
% INFO    : Bus 40954	: V=0.9579871, theta=18.724751 -> V=1.0, theta=0.0
% INFO    : Bus 40955	: V=0.95837, theta=18.723721 -> V=1.0, theta=0.0
% INFO    : Bus 40956	: V=0.9591084, theta=18.701986 -> V=1.0, theta=0.0
% INFO    : Bus 40957	: V=0.9587522, theta=18.698247 -> V=1.0, theta=0.0
% INFO    : Bus 40958	: V=0.9588193, theta=18.696035 -> V=1.0, theta=0.0
% INFO    : Bus 40959	: V=0.9590059, theta=18.704433 -> V=1.0, theta=0.0
% INFO    : Bus 40960	: V=0.9599098, theta=18.697309 -> V=1.0, theta=0.0
% INFO    : Bus 40961	: V=0.9599383, theta=18.671258 -> V=1.0, theta=0.0
% INFO    : Bus 40962	: V=0.9590092, theta=18.685463 -> V=1.0, theta=0.0
% INFO    : Bus 40963	: V=0.959405, theta=18.677702 -> V=1.0, theta=0.0
% INFO    : Bus 40964	: V=0.959755, theta=18.664776 -> V=1.0, theta=0.0
% INFO    : Bus 40965	: V=0.9602861, theta=18.617498 -> V=1.0, theta=0.0
% INFO    : Bus 40966	: V=0.9604493, theta=18.678655 -> V=1.0, theta=0.0
% INFO    : Bus 40967	: V=0.9603885, theta=18.639984 -> V=1.0, theta=0.0
% INFO    : Bus 40968	: V=0.9631268, theta=18.443192 -> V=1.0, theta=0.0
% INFO    : Bus 40969	: V=0.9628559, theta=18.450948 -> V=1.0, theta=0.0
% INFO    : Bus 40970	: V=0.9628569, theta=18.411096 -> V=1.0, theta=0.0
% INFO    : Bus 40971	: V=0.9622711, theta=18.390192 -> V=1.0, theta=0.0
% INFO    : Bus 40972	: V=0.9628127, theta=18.407006 -> V=1.0, theta=0.0
% INFO    : Bus 40973	: V=0.9629521, theta=18.402334 -> V=1.0, theta=0.0
% INFO    : Bus 40974	: V=0.960402, theta=18.614723 -> V=1.0, theta=0.0
% INFO    : Bus 40975	: V=0.9707874, theta=18.711745 -> V=1.0, theta=0.0
% INFO    : Bus 40976	: V=0.9605494, theta=18.610237 -> V=1.0, theta=0.0
% INFO    : Bus 40977	: V=0.9606001, theta=18.622732 -> V=1.0, theta=0.0
% INFO    : Bus 40978	: V=0.9706016, theta=18.659631 -> V=1.0, theta=0.0
% INFO    : Bus 40979	: V=0.9627602, theta=18.468557 -> V=1.0, theta=0.0
% INFO    : Bus 40980	: V=0.9705092, theta=18.624446 -> V=1.0, theta=0.0
% INFO    : Bus 40981	: V=0.9705653, theta=18.587189 -> V=1.0, theta=0.0
% INFO    : Bus 40982	: V=0.9617994, theta=18.310601 -> V=1.0, theta=0.0
% INFO    : Bus 40983	: V=0.9715584, theta=18.233398 -> V=1.0, theta=0.0
% INFO    : Bus 40984	: V=0.9720176, theta=18.217852 -> V=1.0, theta=0.0
% INFO    : Bus 40985	: V=0.9726837, theta=18.199216 -> V=1.0, theta=0.0
% INFO    : Bus 40986	: V=0.9706461, theta=18.55146 -> V=1.0, theta=0.0
% INFO    : Bus 40987	: V=0.9634062, theta=18.341916 -> V=1.0, theta=0.0
% INFO    : Bus 40988	: V=0.9616044, theta=18.359169 -> V=1.0, theta=0.0
% INFO    : Bus 40989	: V=0.9612828, theta=18.3683 -> V=1.0, theta=0.0
% INFO    : Bus 40990	: V=0.9643023, theta=18.276111 -> V=1.0, theta=0.0
% INFO    : Bus 40991	: V=0.9707612, theta=18.516859 -> V=1.0, theta=0.0
% INFO    : Bus 40992	: V=0.9487599, theta=19.896514 -> V=1.0, theta=0.0
% INFO    : Bus 40993	: V=0.9502226, theta=19.777706 -> V=1.0, theta=0.0
% INFO    : Bus 40994	: V=0.9490416, theta=19.80134 -> V=1.0, theta=0.0
% INFO    : Bus 40995	: V=0.957957, theta=21.108603 -> V=1.0, theta=0.0
% INFO    : Bus 40996	: V=0.9611605, theta=21.66453 -> V=1.0, theta=0.0
% INFO    : Bus 40997	: V=0.9802617, theta=21.631147 -> V=1.0, theta=0.0
% INFO    : Bus 40998	: V=0.9601313, theta=21.50682 -> V=1.0, theta=0.0
% INFO    : Bus 40999	: V=0.9825114, theta=21.564735 -> V=1.0, theta=0.0
% INFO    : Bus 41000	: V=0.9634819, theta=21.067135 -> V=1.0, theta=0.0
% INFO    : Bus 41001	: V=0.9635049, theta=20.920889 -> V=1.0, theta=0.0
% INFO    : Bus 41002	: V=0.9609268, theta=20.665356 -> V=1.0, theta=0.0
% INFO    : Bus 41003	: V=0.9582936, theta=20.187791 -> V=1.0, theta=0.0
% INFO    : Bus 41004	: V=0.949171, theta=19.798713 -> V=1.0, theta=0.0
% INFO    : Bus 41005	: V=0.9493995, theta=19.791984 -> V=1.0, theta=0.0
% INFO    : Bus 41006	: V=0.9654258, theta=21.13241 -> V=1.0, theta=0.0
% INFO    : Bus 41007	: V=0.9655235, theta=21.135144 -> V=1.0, theta=0.0
% INFO    : Bus 41008	: V=0.964069, theta=20.729942 -> V=1.0, theta=0.0
% INFO    : Bus 41009	: V=0.9654563, theta=20.064325 -> V=1.0, theta=0.0
% INFO    : Bus 41010	: V=0.963638, theta=20.197472 -> V=1.0, theta=0.0
% INFO    : Bus 41011	: V=0.9586874, theta=19.695774 -> V=1.0, theta=0.0
% INFO    : Bus 41012	: V=0.9616835, theta=20.120325 -> V=1.0, theta=0.0
% INFO    : Bus 41013	: V=0.9626394, theta=20.389993 -> V=1.0, theta=0.0
% INFO    : Bus 41014	: V=0.9611712, theta=20.076529 -> V=1.0, theta=0.0
% INFO    : Bus 41015	: V=0.9590782, theta=19.845787 -> V=1.0, theta=0.0
% INFO    : Bus 41016	: V=0.9589626, theta=19.702314 -> V=1.0, theta=0.0
% INFO    : Bus 41017	: V=0.9622551, theta=19.727672 -> V=1.0, theta=0.0
% INFO    : Bus 41018	: V=0.9612306, theta=19.668736 -> V=1.0, theta=0.0
% INFO    : Bus 41019	: V=0.9609456, theta=20.110772 -> V=1.0, theta=0.0
% INFO    : Bus 41020	: V=0.9655323, theta=21.457556 -> V=1.0, theta=0.0
% INFO    : Bus 41021	: V=0.9663974, theta=21.965735 -> V=1.0, theta=0.0
% INFO    : Bus 41022	: V=0.9559508, theta=21.139203 -> V=1.0, theta=0.0
% INFO    : Bus 41023	: V=0.9639625, theta=21.744277 -> V=1.0, theta=0.0
% INFO    : Bus 41024	: V=0.9620083, theta=21.644075 -> V=1.0, theta=0.0
% INFO    : Bus 41025	: V=0.9559835, theta=20.962805 -> V=1.0, theta=0.0
% INFO    : Bus 41026	: V=0.9618004, theta=21.230479 -> V=1.0, theta=0.0
% INFO    : Bus 41027	: V=0.9618982, theta=21.461308 -> V=1.0, theta=0.0
% INFO    : Bus 41028	: V=0.9618214, theta=21.361306 -> V=1.0, theta=0.0
% INFO    : Bus 41029	: V=0.9629095, theta=20.965318 -> V=1.0, theta=0.0
% INFO    : Bus 41030	: V=0.9601874, theta=20.831152 -> V=1.0, theta=0.0
% INFO    : Bus 41031	: V=0.9604818, theta=20.350666 -> V=1.0, theta=0.0
% INFO    : Bus 41032	: V=0.9578179, theta=20.691188 -> V=1.0, theta=0.0
% INFO    : Bus 41033	: V=0.9568439, theta=20.868456 -> V=1.0, theta=0.0
% INFO    : Bus 41034	: V=0.9540341, theta=20.81742 -> V=1.0, theta=0.0
% INFO    : Bus 41035	: V=0.9580432, theta=20.440889 -> V=1.0, theta=0.0
% INFO    : Bus 41036	: V=0.9594952, theta=20.327817 -> V=1.0, theta=0.0
% INFO    : Bus 41037	: V=0.9607216, theta=20.918581 -> V=1.0, theta=0.0
% INFO    : Bus 41038	: V=0.9632009, theta=22.037096 -> V=1.0, theta=0.0
% INFO    : Bus 41039	: V=0.9650229, theta=22.165181 -> V=1.0, theta=0.0
% INFO    : Bus 41040	: V=0.9675994, theta=22.255595 -> V=1.0, theta=0.0
% INFO    : Bus 41041	: V=0.9577068, theta=22.072341 -> V=1.0, theta=0.0
% INFO    : Bus 41042	: V=0.9817621, theta=22.671811 -> V=1.0, theta=0.0
% INFO    : Bus 41043	: V=0.9813899, theta=22.478141 -> V=1.0, theta=0.0
% INFO    : Bus 41044	: V=0.9598348, theta=21.736993 -> V=1.0, theta=0.0
% INFO    : Bus 41045	: V=0.9566226, theta=21.618141 -> V=1.0, theta=0.0
% INFO    : Bus 41046	: V=0.9552032, theta=21.708128 -> V=1.0, theta=0.0
% INFO    : Bus 41047	: V=0.9536738, theta=21.793719 -> V=1.0, theta=0.0
% INFO    : Bus 41048	: V=0.9580037, theta=21.654125 -> V=1.0, theta=0.0
% INFO    : Bus 41049	: V=0.9578624, theta=21.658144 -> V=1.0, theta=0.0
% INFO    : Bus 41050	: V=0.9550874, theta=21.59344 -> V=1.0, theta=0.0
% INFO    : Bus 41051	: V=0.9645384, theta=21.503744 -> V=1.0, theta=0.0
% INFO    : Bus 41052	: V=0.9519153, theta=21.567286 -> V=1.0, theta=0.0
% INFO    : Bus 41053	: V=0.9518629, theta=21.344819 -> V=1.0, theta=0.0
% INFO    : Bus 41054	: V=0.9525921, theta=21.804187 -> V=1.0, theta=0.0
% INFO    : Bus 41055	: V=0.9520272, theta=22.243396 -> V=1.0, theta=0.0
% INFO    : Bus 41056	: V=0.9514622, theta=22.177126 -> V=1.0, theta=0.0
% INFO    : Bus 41057	: V=0.9519922, theta=22.162591 -> V=1.0, theta=0.0
% INFO    : Bus 41058	: V=0.9610248, theta=22.487209 -> V=1.0, theta=0.0
% INFO    : Bus 41059	: V=0.9514922, theta=22.242557 -> V=1.0, theta=0.0
% INFO    : Bus 41060	: V=0.9593357, theta=22.316295 -> V=1.0, theta=0.0
% INFO    : Bus 41061	: V=0.9598362, theta=21.741848 -> V=1.0, theta=0.0
% INFO    : Bus 41062	: V=0.956052, theta=21.922357 -> V=1.0, theta=0.0
% INFO    : Bus 41063	: V=0.9518363, theta=22.206076 -> V=1.0, theta=0.0
% INFO    : Bus 41064	: V=0.951263, theta=22.266992 -> V=1.0, theta=0.0
% INFO    : Bus 41065	: V=0.9520404, theta=21.898082 -> V=1.0, theta=0.0
% INFO    : Bus 41066	: V=0.9517995, theta=21.96301 -> V=1.0, theta=0.0
% INFO    : Bus 41067	: V=0.9515612, theta=21.992223 -> V=1.0, theta=0.0
% INFO    : Bus 41068	: V=0.9499898, theta=21.332032 -> V=1.0, theta=0.0
% INFO    : Bus 41069	: V=0.9518963, theta=22.011701 -> V=1.0, theta=0.0
% INFO    : Bus 41070	: V=0.9578041, theta=22.955217 -> V=1.0, theta=0.0
% INFO    : Bus 41071	: V=0.957357, theta=22.768846 -> V=1.0, theta=0.0
% INFO    : Bus 41072	: V=0.9570342, theta=22.752583 -> V=1.0, theta=0.0
% INFO    : Bus 41073	: V=0.9513656, theta=22.327858 -> V=1.0, theta=0.0
% INFO    : Bus 41074	: V=0.9514162, theta=22.332529 -> V=1.0, theta=0.0
% INFO    : Bus 41075	: V=0.9574543, theta=23.824363 -> V=1.0, theta=0.0
% INFO    : Bus 41076	: V=0.9578553, theta=22.87242 -> V=1.0, theta=0.0
% INFO    : Bus 41077	: V=0.9508397, theta=22.329158 -> V=1.0, theta=0.0
% INFO    : Bus 41078	: V=0.9506547, theta=22.334229 -> V=1.0, theta=0.0
% INFO    : Bus 41079	: V=0.9578431, theta=22.789147 -> V=1.0, theta=0.0
% INFO    : Bus 41080	: V=0.9583048, theta=22.657525 -> V=1.0, theta=0.0
% INFO    : Bus 41081	: V=0.9510509, theta=22.194056 -> V=1.0, theta=0.0
% INFO    : Bus 41082	: V=0.9623978, theta=22.200522 -> V=1.0, theta=0.0
% INFO    : Bus 41083	: V=0.9527249, theta=22.10646 -> V=1.0, theta=0.0
% INFO    : Bus 41084	: V=0.9532283, theta=22.126361 -> V=1.0, theta=0.0
% INFO    : Bus 41085	: V=0.9547483, theta=22.57789 -> V=1.0, theta=0.0
% INFO    : Bus 41086	: V=0.9552739, theta=22.729939 -> V=1.0, theta=0.0
% INFO    : Bus 41087	: V=0.9550827, theta=22.534294 -> V=1.0, theta=0.0
% INFO    : Bus 41088	: V=0.9591625, theta=22.485517 -> V=1.0, theta=0.0
% INFO    : Bus 41089	: V=0.9546798, theta=22.302386 -> V=1.0, theta=0.0
% INFO    : Bus 41090	: V=0.954009, theta=22.231757 -> V=1.0, theta=0.0
% INFO    : Bus 41091	: V=0.9594309, theta=23.673758 -> V=1.0, theta=0.0
% INFO    : Bus 41092	: V=0.9584289, theta=23.220989 -> V=1.0, theta=0.0
% INFO    : Bus 41093	: V=0.9616499, theta=22.399698 -> V=1.0, theta=0.0
% INFO    : Bus 41094	: V=0.9588293, theta=22.08601 -> V=1.0, theta=0.0
% INFO    : Bus 41095	: V=0.9615437, theta=22.28856 -> V=1.0, theta=0.0
% INFO    : Bus 41096	: V=0.9619994, theta=22.258385 -> V=1.0, theta=0.0
% INFO    : Bus 41097	: V=0.9621963, theta=22.683026 -> V=1.0, theta=0.0
% INFO    : Bus 41098	: V=0.9610788, theta=23.075269 -> V=1.0, theta=0.0
% INFO    : Bus 41099	: V=0.953666, theta=23.321702 -> V=1.0, theta=0.0
% INFO    : Bus 41100	: V=0.9529677, theta=23.269026 -> V=1.0, theta=0.0
% INFO    : Bus 41101	: V=0.952816, theta=23.256653 -> V=1.0, theta=0.0
% INFO    : Bus 41102	: V=0.9631417, theta=22.825346 -> V=1.0, theta=0.0
% INFO    : Bus 41103	: V=0.9626733, theta=22.351136 -> V=1.0, theta=0.0
% INFO    : Bus 41104	: V=0.963626, theta=22.324023 -> V=1.0, theta=0.0
% INFO    : Bus 41105	: V=0.9775096, theta=22.685358 -> V=1.0, theta=0.0
% INFO    : Bus 41106	: V=0.963038, theta=22.283593 -> V=1.0, theta=0.0
% INFO    : Bus 41107	: V=0.9625577, theta=22.24906 -> V=1.0, theta=0.0
% INFO    : Bus 41108	: V=0.9623305, theta=22.181482 -> V=1.0, theta=0.0
% INFO    : Bus 41109	: V=0.9600587, theta=21.983815 -> V=1.0, theta=0.0
% INFO    : Bus 41110	: V=0.9793214, theta=21.713054 -> V=1.0, theta=0.0
% INFO    : Bus 41111	: V=0.9615635, theta=21.573901 -> V=1.0, theta=0.0
% INFO    : Bus 41112	: V=0.9621095, theta=21.528331 -> V=1.0, theta=0.0
% INFO    : Bus 41113	: V=0.9577144, theta=21.912739 -> V=1.0, theta=0.0
% INFO    : Bus 41114	: V=0.9611096, theta=21.742671 -> V=1.0, theta=0.0
% INFO    : Bus 41115	: V=0.9611748, theta=21.784962 -> V=1.0, theta=0.0
% INFO    : Bus 41116	: V=0.9612819, theta=21.831926 -> V=1.0, theta=0.0
% INFO    : Bus 41117	: V=0.9591687, theta=22.233188 -> V=1.0, theta=0.0
% INFO    : Bus 41118	: V=0.9584499, theta=22.028111 -> V=1.0, theta=0.0
% INFO    : Bus 41119	: V=0.9584834, theta=22.024983 -> V=1.0, theta=0.0
% INFO    : Bus 41120	: V=0.9609913, theta=22.094232 -> V=1.0, theta=0.0
% INFO    : Bus 41121	: V=0.961011, theta=22.065495 -> V=1.0, theta=0.0
% INFO    : Bus 41122	: V=0.9611603, theta=22.206174 -> V=1.0, theta=0.0
% INFO    : Bus 41123	: V=0.9610645, theta=22.163561 -> V=1.0, theta=0.0
% INFO    : Bus 41124	: V=0.9582929, theta=21.99488 -> V=1.0, theta=0.0
% INFO    : Bus 41125	: V=0.9579963, theta=22.002567 -> V=1.0, theta=0.0
% INFO    : Bus 41126	: V=0.9609283, theta=22.100663 -> V=1.0, theta=0.0
% INFO    : Bus 41127	: V=0.9609788, theta=22.111854 -> V=1.0, theta=0.0
% INFO    : Bus 41128	: V=0.9621036, theta=21.783113 -> V=1.0, theta=0.0
% INFO    : Bus 41129	: V=0.9620331, theta=22.060775 -> V=1.0, theta=0.0
% INFO    : Bus 41130	: V=0.959219, theta=22.035585 -> V=1.0, theta=0.0
% INFO    : Bus 41131	: V=0.9614784, theta=22.171381 -> V=1.0, theta=0.0
% INFO    : Bus 41132	: V=0.9612251, theta=22.112974 -> V=1.0, theta=0.0
% INFO    : Bus 41133	: V=0.9611103, theta=22.006168 -> V=1.0, theta=0.0
% INFO    : Bus 41134	: V=0.9610893, theta=22.045148 -> V=1.0, theta=0.0
% INFO    : Bus 41135	: V=0.9614371, theta=21.877693 -> V=1.0, theta=0.0
% INFO    : Bus 41136	: V=0.9529552, theta=21.205759 -> V=1.0, theta=0.0
% INFO    : Bus 41137	: V=0.9556733, theta=21.155615 -> V=1.0, theta=0.0
% INFO    : Bus 41138	: V=0.9532159, theta=21.248617 -> V=1.0, theta=0.0
% INFO    : Bus 41139	: V=0.9648143, theta=21.188974 -> V=1.0, theta=0.0
% INFO    : Bus 41140	: V=0.9606571, theta=21.951705 -> V=1.0, theta=0.0
% INFO    : Bus 41141	: V=0.9529265, theta=22.058389 -> V=1.0, theta=0.0
% INFO    : Bus 41142	: V=0.9544129, theta=21.155712 -> V=1.0, theta=0.0
% INFO    : Bus 41143	: V=0.954293, theta=21.169708 -> V=1.0, theta=0.0
% INFO    : Bus 41144	: V=0.9537261, theta=21.172453 -> V=1.0, theta=0.0
% INFO    : Bus 41145	: V=0.953327, theta=21.183045 -> V=1.0, theta=0.0
% INFO    : Bus 41146	: V=0.9819963, theta=21.453657 -> V=1.0, theta=0.0
% INFO    : Bus 41147	: V=0.9652797, theta=21.102894 -> V=1.0, theta=0.0
% INFO    : Bus 41148	: V=0.9575072, theta=20.59306 -> V=1.0, theta=0.0
% INFO    : Bus 41149	: V=0.9583301, theta=20.39582 -> V=1.0, theta=0.0
% INFO    : Bus 41150	: V=0.9575538, theta=20.445287 -> V=1.0, theta=0.0
% INFO    : Bus 41151	: V=0.957727, theta=20.428851 -> V=1.0, theta=0.0
% INFO    : Bus 41152	: V=0.9564815, theta=20.481114 -> V=1.0, theta=0.0
% INFO    : Bus 41153	: V=0.9566066, theta=20.403409 -> V=1.0, theta=0.0
% INFO    : Bus 41154	: V=0.9557262, theta=20.521011 -> V=1.0, theta=0.0
% INFO    : Bus 41155	: V=0.9554838, theta=20.452359 -> V=1.0, theta=0.0
% INFO    : Bus 41156	: V=0.9546311, theta=20.393699 -> V=1.0, theta=0.0
% INFO    : Bus 41157	: V=0.955124, theta=20.476477 -> V=1.0, theta=0.0
% INFO    : Bus 41158	: V=0.9485791, theta=19.902165 -> V=1.0, theta=0.0
% INFO    : Bus 41159	: V=0.9559507, theta=20.610362 -> V=1.0, theta=0.0
% INFO    : Bus 41160	: V=0.9556455, theta=20.554767 -> V=1.0, theta=0.0
% INFO    : Bus 41161	: V=0.9558227, theta=20.718112 -> V=1.0, theta=0.0
% INFO    : Bus 41162	: V=0.9623075, theta=20.687869 -> V=1.0, theta=0.0
% INFO    : Bus 41163	: V=0.9541147, theta=20.762025 -> V=1.0, theta=0.0
% INFO    : Bus 41164	: V=0.9549933, theta=20.70511 -> V=1.0, theta=0.0
% INFO    : Bus 41165	: V=0.9547239, theta=20.704398 -> V=1.0, theta=0.0
% INFO    : Bus 41166	: V=0.9625061, theta=20.612781 -> V=1.0, theta=0.0
% INFO    : Bus 41167	: V=0.9635346, theta=21.212434 -> V=1.0, theta=0.0
% INFO    : Bus 41168	: V=0.9552214, theta=21.178753 -> V=1.0, theta=0.0
% INFO    : Bus 41169	: V=0.954723, theta=20.936162 -> V=1.0, theta=0.0
% INFO    : Bus 41170	: V=0.9559854, theta=20.86915 -> V=1.0, theta=0.0
% INFO    : Bus 41171	: V=0.9629723, theta=21.123179 -> V=1.0, theta=0.0
% INFO    : Bus 41172	: V=0.9633399, theta=21.133611 -> V=1.0, theta=0.0
% INFO    : Bus 41173	: V=0.9562905, theta=20.729614 -> V=1.0, theta=0.0
% INFO    : Bus 41174	: V=0.962929, theta=20.920542 -> V=1.0, theta=0.0
% INFO    : Bus 41175	: V=0.9627902, theta=20.823908 -> V=1.0, theta=0.0
% INFO    : Bus 41176	: V=0.9617743, theta=20.786 -> V=1.0, theta=0.0
% INFO    : Bus 41177	: V=0.9595158, theta=19.770449 -> V=1.0, theta=0.0
% INFO    : Bus 41178	: V=0.9594317, theta=19.856191 -> V=1.0, theta=0.0
% INFO    : Bus 41179	: V=0.9598819, theta=19.922983 -> V=1.0, theta=0.0
% INFO    : Bus 41180	: V=0.959585, theta=19.96727 -> V=1.0, theta=0.0
% INFO    : Bus 41181	: V=0.95986, theta=19.973402 -> V=1.0, theta=0.0
% INFO    : Bus 41182	: V=0.9597613, theta=19.821052 -> V=1.0, theta=0.0
% INFO    : Bus 41183	: V=0.9600102, theta=19.868858 -> V=1.0, theta=0.0
% INFO    : Bus 41184	: V=0.964057, theta=20.233654 -> V=1.0, theta=0.0
% INFO    : Bus 41185	: V=0.9637435, theta=20.093411 -> V=1.0, theta=0.0
% INFO    : Bus 41186	: V=0.961579, theta=19.938194 -> V=1.0, theta=0.0
% INFO    : Bus 41187	: V=0.9800566, theta=21.176461 -> V=1.0, theta=0.0
% INFO    : Bus 41188	: V=0.9593873, theta=19.847032 -> V=1.0, theta=0.0
% INFO    : Bus 41189	: V=0.9635056, theta=20.14149 -> V=1.0, theta=0.0
% INFO    : Bus 41190	: V=0.9583761, theta=19.729471 -> V=1.0, theta=0.0
% INFO    : Bus 41191	: V=0.9581233, theta=19.722559 -> V=1.0, theta=0.0
% INFO    : Bus 41192	: V=0.9629024, theta=19.868254 -> V=1.0, theta=0.0
% INFO    : Bus 41193	: V=0.9806789, theta=21.181672 -> V=1.0, theta=0.0
% INFO    : Bus 41194	: V=0.9576058, theta=20.265128 -> V=1.0, theta=0.0
% INFO    : Bus 41195	: V=0.9802795, theta=21.164891 -> V=1.0, theta=0.0
% INFO    : Bus 41196	: V=0.9600519, theta=19.929615 -> V=1.0, theta=0.0
% INFO    : Bus 41197	: V=0.9634963, theta=20.450733 -> V=1.0, theta=0.0
% INFO    : Bus 41198	: V=0.959457, theta=20.123917 -> V=1.0, theta=0.0
% INFO    : Bus 41199	: V=0.9603762, theta=20.192564 -> V=1.0, theta=0.0
% INFO    : Bus 41200	: V=0.9593019, theta=19.512631 -> V=1.0, theta=0.0
% INFO    : Bus 41201	: V=0.9596988, theta=19.573023 -> V=1.0, theta=0.0
% INFO    : Bus 41202	: V=0.9591525, theta=19.726354 -> V=1.0, theta=0.0
% INFO    : Bus 41203	: V=0.9592845, theta=19.729272 -> V=1.0, theta=0.0
% INFO    : Bus 41204	: V=0.9593231, theta=19.638976 -> V=1.0, theta=0.0
% INFO    : Bus 41205	: V=0.959368, theta=19.573219 -> V=1.0, theta=0.0
% INFO    : Bus 41206	: V=0.9591546, theta=19.502008 -> V=1.0, theta=0.0
% INFO    : Bus 41207	: V=0.9591135, theta=19.492926 -> V=1.0, theta=0.0
% INFO    : Bus 41208	: V=0.9591818, theta=19.515399 -> V=1.0, theta=0.0
% INFO    : Bus 41209	: V=0.9592315, theta=19.535336 -> V=1.0, theta=0.0
% INFO    : Bus 41210	: V=0.9593528, theta=19.51359 -> V=1.0, theta=0.0
% INFO    : Bus 41211	: V=0.9589462, theta=19.38203 -> V=1.0, theta=0.0
% INFO    : Bus 41212	: V=0.9589907, theta=19.450007 -> V=1.0, theta=0.0
% INFO    : Bus 41213	: V=0.9590109, theta=19.410181 -> V=1.0, theta=0.0
% INFO    : Bus 41214	: V=0.9590131, theta=19.383598 -> V=1.0, theta=0.0
% INFO    : Bus 41215	: V=0.9629635, theta=19.932613 -> V=1.0, theta=0.0
% INFO    : Bus 41216	: V=0.9634153, theta=19.980672 -> V=1.0, theta=0.0
% INFO    : Bus 41217	: V=0.959854, theta=19.505369 -> V=1.0, theta=0.0
% INFO    : Bus 41218	: V=0.94894, theta=19.867456 -> V=1.0, theta=0.0
% INFO    : Bus 41219	: V=0.9498154, theta=19.765189 -> V=1.0, theta=0.0
% INFO    : Bus 41220	: V=0.9560195, theta=20.050749 -> V=1.0, theta=0.0
% INFO    : Bus 41221	: V=0.9554665, theta=20.01732 -> V=1.0, theta=0.0
% INFO    : Bus 41222	: V=0.9516306, theta=19.672879 -> V=1.0, theta=0.0
% INFO    : Bus 41223	: V=0.9529632, theta=19.694167 -> V=1.0, theta=0.0
% INFO    : Bus 41224	: V=0.9519667, theta=19.693997 -> V=1.0, theta=0.0
% INFO    : Bus 41225	: V=0.9593563, theta=19.646754 -> V=1.0, theta=0.0
% INFO    : Bus 41226	: V=0.9596689, theta=19.672136 -> V=1.0, theta=0.0
% INFO    : Bus 41227	: V=0.9623831, theta=19.971166 -> V=1.0, theta=0.0
% INFO    : Bus 41228	: V=0.9628168, theta=19.976037 -> V=1.0, theta=0.0
% INFO    : Bus 41229	: V=0.9610752, theta=20.254172 -> V=1.0, theta=0.0
% INFO    : Bus 41230	: V=0.9738647, theta=20.388111 -> V=1.0, theta=0.0
% INFO    : Bus 41231	: V=0.9599316, theta=20.234106 -> V=1.0, theta=0.0
% INFO    : Bus 41232	: V=0.9603313, theta=20.24103 -> V=1.0, theta=0.0
% INFO    : Bus 41233	: V=0.9596079, theta=20.228521 -> V=1.0, theta=0.0
% INFO    : Bus 41234	: V=0.9588308, theta=20.20372 -> V=1.0, theta=0.0
% INFO    : Bus 41235	: V=0.9844659, theta=21.334234 -> V=1.0, theta=0.0
% INFO    : Bus 41236	: V=0.9635222, theta=20.419249 -> V=1.0, theta=0.0
% INFO    : Bus 41237	: V=0.9622689, theta=20.277829 -> V=1.0, theta=0.0
% INFO    : Bus 41238	: V=0.9605771, theta=19.71074 -> V=1.0, theta=0.0
% INFO    : Bus 41239	: V=0.9615203, theta=19.757091 -> V=1.0, theta=0.0
% INFO    : Bus 41240	: V=0.9566719, theta=19.453734 -> V=1.0, theta=0.0
% INFO    : Bus 41241	: V=0.9566654, theta=19.48166 -> V=1.0, theta=0.0
% INFO    : Bus 41242	: V=0.9573614, theta=19.476121 -> V=1.0, theta=0.0
% INFO    : Bus 41243	: V=0.9570531, theta=19.497371 -> V=1.0, theta=0.0
% INFO    : Bus 41244	: V=0.9568523, theta=19.468205 -> V=1.0, theta=0.0
% INFO    : Bus 41245	: V=0.9574253, theta=19.449345 -> V=1.0, theta=0.0
% INFO    : Bus 41246	: V=0.9610165, theta=19.596992 -> V=1.0, theta=0.0
% INFO    : Bus 41247	: V=0.9618561, theta=19.647732 -> V=1.0, theta=0.0
% INFO    : Bus 41248	: V=0.9573464, theta=19.494059 -> V=1.0, theta=0.0
% INFO    : Bus 41249	: V=0.9620582, theta=19.667892 -> V=1.0, theta=0.0
% INFO    : Bus 41250	: V=0.9623673, theta=19.69385 -> V=1.0, theta=0.0
% INFO    : Bus 41251	: V=0.9615647, theta=19.614934 -> V=1.0, theta=0.0
% INFO    : Bus 41252	: V=0.9590547, theta=19.421021 -> V=1.0, theta=0.0
% INFO    : Bus 41253	: V=0.9590075, theta=19.4351 -> V=1.0, theta=0.0
% INFO    : Bus 41254	: V=0.9670916, theta=19.477312 -> V=1.0, theta=0.0
% INFO    : Bus 41255	: V=0.959772, theta=19.308151 -> V=1.0, theta=0.0
% INFO    : Bus 41256	: V=0.9675769, theta=19.487615 -> V=1.0, theta=0.0
% INFO    : Bus 41257	: V=0.9598036, theta=19.373722 -> V=1.0, theta=0.0
% INFO    : Bus 41258	: V=0.9684088, theta=19.49068 -> V=1.0, theta=0.0
% INFO    : Bus 41259	: V=0.9676678, theta=19.472561 -> V=1.0, theta=0.0
% INFO    : Bus 41260	: V=0.9609443, theta=19.274135 -> V=1.0, theta=0.0
% INFO    : Bus 41261	: V=0.9611443, theta=19.267798 -> V=1.0, theta=0.0
% INFO    : Bus 41262	: V=0.9683619, theta=19.471181 -> V=1.0, theta=0.0
% INFO    : Bus 41263	: V=0.9619842, theta=19.26068 -> V=1.0, theta=0.0
% INFO    : Bus 41264	: V=0.9617167, theta=19.265649 -> V=1.0, theta=0.0
% INFO    : Bus 41265	: V=0.9692947, theta=19.470227 -> V=1.0, theta=0.0
% INFO    : Bus 41266	: V=0.9834202, theta=19.901922 -> V=1.0, theta=0.0
% INFO    : Bus 41267	: V=0.9628312, theta=19.2616 -> V=1.0, theta=0.0
% INFO    : Bus 41268	: V=0.9714057, theta=19.489706 -> V=1.0, theta=0.0
% INFO    : Bus 41269	: V=0.9718512, theta=19.503145 -> V=1.0, theta=0.0
% INFO    : Bus 41270	: V=0.9592558, theta=19.389296 -> V=1.0, theta=0.0
% INFO    : Bus 41271	: V=0.9594937, theta=19.420149 -> V=1.0, theta=0.0
% INFO    : Bus 41272	: V=0.9639556, theta=19.604695 -> V=1.0, theta=0.0
% INFO    : Bus 41273	: V=0.963346, theta=19.600764 -> V=1.0, theta=0.0
% INFO    : Bus 41274	: V=0.9599612, theta=19.379689 -> V=1.0, theta=0.0
% INFO    : Bus 41275	: V=0.9602884, theta=19.379596 -> V=1.0, theta=0.0
% INFO    : Bus 41276	: V=0.9609289, theta=19.360329 -> V=1.0, theta=0.0
% INFO    : Bus 41277	: V=0.9604764, theta=19.371594 -> V=1.0, theta=0.0
% INFO    : Bus 41278	: V=0.9610741, theta=19.360813 -> V=1.0, theta=0.0
% INFO    : Bus 41279	: V=0.9722825, theta=19.50887 -> V=1.0, theta=0.0
% INFO    : Bus 41280	: V=0.9596253, theta=19.512632 -> V=1.0, theta=0.0
% INFO    : Bus 41281	: V=0.96097, theta=19.517817 -> V=1.0, theta=0.0
% INFO    : Bus 41282	: V=0.9664922, theta=19.646622 -> V=1.0, theta=0.0
% INFO    : Bus 41283	: V=0.9627829, theta=19.848717 -> V=1.0, theta=0.0
% INFO    : Bus 41284	: V=0.9573592, theta=19.501416 -> V=1.0, theta=0.0
% INFO    : Bus 41285	: V=0.9576982, theta=19.503483 -> V=1.0, theta=0.0
% INFO    : Bus 41286	: V=0.9637158, theta=19.797467 -> V=1.0, theta=0.0
% INFO    : Bus 41287	: V=0.9560519, theta=19.765677 -> V=1.0, theta=0.0
% INFO    : Bus 41288	: V=0.9635036, theta=20.009126 -> V=1.0, theta=0.0
% INFO    : Bus 41289	: V=0.9635074, theta=20.010185 -> V=1.0, theta=0.0
% INFO    : Bus 41290	: V=0.9635115, theta=20.007091 -> V=1.0, theta=0.0
% INFO    : Bus 41291	: V=0.9635749, theta=20.014967 -> V=1.0, theta=0.0
% INFO    : Bus 41292	: V=0.9588712, theta=20.038392 -> V=1.0, theta=0.0
% INFO    : Bus 41293	: V=0.9631013, theta=20.246087 -> V=1.0, theta=0.0
% INFO    : Bus 41294	: V=0.9653063, theta=20.206516 -> V=1.0, theta=0.0
% INFO    : Bus 41295	: V=0.9643871, theta=20.201578 -> V=1.0, theta=0.0
% INFO    : Bus 41296	: V=0.9640142, theta=20.025933 -> V=1.0, theta=0.0
% INFO    : Bus 41297	: V=0.9646511, theta=20.045447 -> V=1.0, theta=0.0
% INFO    : Bus 41298	: V=0.9644937, theta=20.014174 -> V=1.0, theta=0.0
% INFO    : Bus 41299	: V=0.9639095, theta=20.008038 -> V=1.0, theta=0.0
% INFO    : Bus 41300	: V=0.9578291, theta=19.846989 -> V=1.0, theta=0.0
% INFO    : Bus 41301	: V=0.9572315, theta=19.787251 -> V=1.0, theta=0.0
% INFO    : Bus 41302	: V=0.9573763, theta=19.763835 -> V=1.0, theta=0.0
% INFO    : Bus 41303	: V=0.9633169, theta=19.854431 -> V=1.0, theta=0.0
% INFO    : Bus 41304	: V=0.9578539, theta=19.729077 -> V=1.0, theta=0.0
% INFO    : Bus 41305	: V=0.9645722, theta=19.91024 -> V=1.0, theta=0.0
% INFO    : Bus 41306	: V=0.982541, theta=19.92144 -> V=1.0, theta=0.0
% INFO    : Bus 41307	: V=0.9661515, theta=20.031963 -> V=1.0, theta=0.0
% INFO    : Bus 41308	: V=0.9653794, theta=20.038142 -> V=1.0, theta=0.0
% INFO    : Bus 41309	: V=0.9653631, theta=20.175537 -> V=1.0, theta=0.0
% INFO    : Bus 41310	: V=0.9661053, theta=20.103258 -> V=1.0, theta=0.0
% INFO    : Bus 41311	: V=0.9663633, theta=20.069901 -> V=1.0, theta=0.0
% INFO    : Bus 41312	: V=0.9669946, theta=20.074351 -> V=1.0, theta=0.0
% INFO    : Bus 41313	: V=0.9666731, theta=19.983717 -> V=1.0, theta=0.0
% INFO    : Bus 41314	: V=0.9628642, theta=19.845421 -> V=1.0, theta=0.0
% INFO    : Bus 41315	: V=0.9669748, theta=20.002047 -> V=1.0, theta=0.0
% INFO    : Bus 41316	: V=0.9627973, theta=19.763139 -> V=1.0, theta=0.0
% INFO    : Bus 41317	: V=0.9667837, theta=20.13322 -> V=1.0, theta=0.0
% INFO    : Bus 41318	: V=0.9622682, theta=19.514732 -> V=1.0, theta=0.0
% INFO    : Bus 41319	: V=0.9685019, theta=19.685935 -> V=1.0, theta=0.0
% INFO    : Bus 41320	: V=0.9673002, theta=20.019823 -> V=1.0, theta=0.0
% INFO    : Bus 41321	: V=0.9676035, theta=20.038843 -> V=1.0, theta=0.0
% INFO    : Bus 41322	: V=0.9690751, theta=19.89271 -> V=1.0, theta=0.0
% INFO    : Bus 41323	: V=0.9682669, theta=20.073096 -> V=1.0, theta=0.0
% INFO    : Bus 41324	: V=0.9689015, theta=20.106886 -> V=1.0, theta=0.0
% INFO    : Bus 41325	: V=0.969769, theta=20.147202 -> V=1.0, theta=0.0
% INFO    : Bus 41326	: V=0.9707104, theta=20.076065 -> V=1.0, theta=0.0
% INFO    : Bus 41327	: V=0.9706244, theta=20.180665 -> V=1.0, theta=0.0
% INFO    : Bus 41328	: V=0.9711342, theta=20.200628 -> V=1.0, theta=0.0
% INFO    : Bus 41329	: V=0.9744245, theta=20.161013 -> V=1.0, theta=0.0
% INFO    : Bus 41330	: V=0.9714301, theta=19.833502 -> V=1.0, theta=0.0
% INFO    : Bus 41331	: V=0.9714837, theta=19.991248 -> V=1.0, theta=0.0
% INFO    : Bus 41332	: V=0.9779263, theta=19.927839 -> V=1.0, theta=0.0
% INFO    : Bus 41333	: V=0.985468, theta=20.001083 -> V=1.0, theta=0.0
% INFO    : Bus 41334	: V=0.9624931, theta=19.408435 -> V=1.0, theta=0.0
% INFO    : Bus 41335	: V=0.9803535, theta=19.744641 -> V=1.0, theta=0.0
% INFO    : Bus 41336	: V=0.990322, theta=19.550968 -> V=1.0, theta=0.0
% INFO    : Bus 41337	: V=0.9820929, theta=19.588016 -> V=1.0, theta=0.0
% INFO    : Bus 41338	: V=0.9722832, theta=19.812381 -> V=1.0, theta=0.0
% INFO    : Bus 41339	: V=0.9722302, theta=18.945055 -> V=1.0, theta=0.0
% INFO    : Bus 41340	: V=0.9714551, theta=18.747065 -> V=1.0, theta=0.0
% INFO    : Bus 41341	: V=0.9708317, theta=18.764735 -> V=1.0, theta=0.0
% INFO    : Bus 41342	: V=0.9835047, theta=19.792373 -> V=1.0, theta=0.0
% INFO    : Bus 41343	: V=0.9839629, theta=19.756512 -> V=1.0, theta=0.0
% INFO    : Bus 41344	: V=0.9867976, theta=19.182379 -> V=1.0, theta=0.0
% INFO    : Bus 41345	: V=0.973107, theta=18.897222 -> V=1.0, theta=0.0
% INFO    : Bus 41346	: V=0.982307, theta=19.603024 -> V=1.0, theta=0.0
% INFO    : Bus 41347	: V=0.9818768, theta=19.598552 -> V=1.0, theta=0.0
% INFO    : Bus 41348	: V=0.96995, theta=18.784204 -> V=1.0, theta=0.0
% INFO    : Bus 41349	: V=0.9733252, theta=18.797863 -> V=1.0, theta=0.0
% INFO    : Bus 41350	: V=0.9719584, theta=18.377797 -> V=1.0, theta=0.0
% INFO    : Bus 41351	: V=0.9733018, theta=18.321472 -> V=1.0, theta=0.0
% INFO    : Bus 41352	: V=0.9659348, theta=18.274196 -> V=1.0, theta=0.0
% INFO    : Bus 41353	: V=0.9660607, theta=18.30631 -> V=1.0, theta=0.0
% INFO    : Bus 41354	: V=0.9732824, theta=18.413152 -> V=1.0, theta=0.0
% INFO    : Bus 41355	: V=0.9634288, theta=18.4743 -> V=1.0, theta=0.0
% INFO    : Bus 41356	: V=0.9655789, theta=18.51486 -> V=1.0, theta=0.0
% INFO    : Bus 41357	: V=0.9710459, theta=18.26367 -> V=1.0, theta=0.0
% INFO    : Bus 41358	: V=0.9633391, theta=18.443683 -> V=1.0, theta=0.0
% INFO    : Bus 41359	: V=0.971047, theta=18.724904 -> V=1.0, theta=0.0
% INFO    : Bus 41360	: V=0.9683752, theta=18.635446 -> V=1.0, theta=0.0
% INFO    : Bus 41361	: V=0.9713062, theta=18.671721 -> V=1.0, theta=0.0
% INFO    : Bus 41362	: V=0.9692336, theta=18.691428 -> V=1.0, theta=0.0
% INFO    : Bus 41363	: V=0.970151, theta=18.741863 -> V=1.0, theta=0.0
% INFO    : Bus 41364	: V=0.9698479, theta=18.480413 -> V=1.0, theta=0.0
% INFO    : Bus 41365	: V=0.9702471, theta=18.562817 -> V=1.0, theta=0.0
% INFO    : Bus 41366	: V=0.9740545, theta=18.574706 -> V=1.0, theta=0.0
% INFO    : Bus 41367	: V=0.9741158, theta=18.512731 -> V=1.0, theta=0.0
% INFO    : Bus 41368	: V=0.9742518, theta=18.447353 -> V=1.0, theta=0.0
% INFO    : Bus 41369	: V=0.9674962, theta=18.526953 -> V=1.0, theta=0.0
% INFO    : Bus 41370	: V=0.9723427, theta=18.578076 -> V=1.0, theta=0.0
% INFO    : Bus 41371	: V=0.9731966, theta=18.513012 -> V=1.0, theta=0.0
% INFO    : Bus 41372	: V=0.9672195, theta=18.426406 -> V=1.0, theta=0.0
% INFO    : Bus 41373	: V=0.9702893, theta=18.577744 -> V=1.0, theta=0.0
% INFO    : Bus 41374	: V=0.9750491, theta=18.527748 -> V=1.0, theta=0.0
% INFO    : Bus 41375	: V=0.9755094, theta=18.516455 -> V=1.0, theta=0.0
% INFO    : Bus 41376	: V=0.9762083, theta=18.496722 -> V=1.0, theta=0.0
% INFO    : Bus 41377	: V=0.9761217, theta=18.546658 -> V=1.0, theta=0.0
% INFO    : Bus 41378	: V=0.9831023, theta=17.071288 -> V=1.0, theta=0.0
% INFO    : Bus 41379	: V=0.9832889, theta=17.522627 -> V=1.0, theta=0.0
% INFO    : Bus 41380	: V=0.9735644, theta=18.166512 -> V=1.0, theta=0.0
% INFO    : Bus 41381	: V=0.9666823, theta=18.306155 -> V=1.0, theta=0.0
% INFO    : Bus 41382	: V=0.9742745, theta=18.214138 -> V=1.0, theta=0.0
% INFO    : Bus 41383	: V=0.9666752, theta=18.214812 -> V=1.0, theta=0.0
% INFO    : Bus 41384	: V=0.9742028, theta=18.113065 -> V=1.0, theta=0.0
% INFO    : Bus 41385	: V=0.9709091, theta=18.106351 -> V=1.0, theta=0.0
% INFO    : Bus 41386	: V=0.9844965, theta=17.544289 -> V=1.0, theta=0.0
% INFO    : Bus 41387	: V=0.9838784, theta=17.385776 -> V=1.0, theta=0.0
% INFO    : Bus 41388	: V=0.9734371, theta=18.619796 -> V=1.0, theta=0.0
% INFO    : Bus 41389	: V=0.9705491, theta=18.599108 -> V=1.0, theta=0.0
% INFO    : Bus 41390	: V=0.9711757, theta=18.6637 -> V=1.0, theta=0.0
% INFO    : Bus 41391	: V=0.9714947, theta=18.653746 -> V=1.0, theta=0.0
% INFO    : Bus 41392	: V=0.987487, theta=19.735857 -> V=1.0, theta=0.0
% INFO    : Bus 41393	: V=0.9789811, theta=18.738981 -> V=1.0, theta=0.0
% INFO    : Bus 41394	: V=0.9766919, theta=18.568013 -> V=1.0, theta=0.0
% INFO    : Bus 41395	: V=0.9772346, theta=18.601982 -> V=1.0, theta=0.0
% INFO    : Bus 41396	: V=0.9791659, theta=18.491034 -> V=1.0, theta=0.0
% INFO    : Bus 41397	: V=0.985381, theta=17.765988 -> V=1.0, theta=0.0
% INFO    : Bus 41398	: V=0.9850455, theta=17.679294 -> V=1.0, theta=0.0
% INFO    : Bus 41399	: V=0.9907817, theta=20.407869 -> V=1.0, theta=0.0
% INFO    : Bus 41400	: V=0.9973334, theta=20.323073 -> V=1.0, theta=0.0
% INFO    : Bus 41401	: V=0.9926186, theta=20.553285 -> V=1.0, theta=0.0
% INFO    : Bus 41402	: V=0.9878516, theta=19.981798 -> V=1.0, theta=0.0
% INFO    : Bus 41403	: V=0.9854713, theta=18.556412 -> V=1.0, theta=0.0
% INFO    : Bus 41404	: V=0.9848248, theta=18.516568 -> V=1.0, theta=0.0
% INFO    : Bus 41405	: V=0.9839847, theta=18.469215 -> V=1.0, theta=0.0
% INFO    : Bus 41406	: V=0.9872528, theta=18.297663 -> V=1.0, theta=0.0
% INFO    : Bus 41407	: V=0.9919607, theta=19.722706 -> V=1.0, theta=0.0
% INFO    : Bus 41408	: V=0.9884728, theta=18.561404 -> V=1.0, theta=0.0
% INFO    : Bus 41409	: V=0.9860242, theta=18.601996 -> V=1.0, theta=0.0
% INFO    : Bus 41410	: V=0.9886913, theta=18.601028 -> V=1.0, theta=0.0
% INFO    : Bus 41411	: V=0.979818, theta=18.233409 -> V=1.0, theta=0.0
% INFO    : Bus 41412	: V=0.9906444, theta=18.93676 -> V=1.0, theta=0.0
% INFO    : Bus 41413	: V=0.98743, theta=18.329987 -> V=1.0, theta=0.0
% INFO    : Bus 41414	: V=0.9849841, theta=18.48963 -> V=1.0, theta=0.0
% INFO    : Bus 41415	: V=0.9840667, theta=18.345234 -> V=1.0, theta=0.0
% INFO    : Bus 41416	: V=0.9829133, theta=18.29818 -> V=1.0, theta=0.0
% INFO    : Bus 41417	: V=0.9754721, theta=18.19657 -> V=1.0, theta=0.0
% INFO    : Bus 41418	: V=0.9765896, theta=18.174511 -> V=1.0, theta=0.0
% INFO    : Bus 41419	: V=0.9763859, theta=18.182271 -> V=1.0, theta=0.0
% INFO    : Bus 41420	: V=0.980218, theta=18.256391 -> V=1.0, theta=0.0
% INFO    : Bus 41421	: V=0.9821955, theta=18.385964 -> V=1.0, theta=0.0
% INFO    : Bus 41422	: V=0.981195, theta=18.27056 -> V=1.0, theta=0.0
% INFO    : Bus 41423	: V=0.9778589, theta=18.209936 -> V=1.0, theta=0.0
% INFO    : Bus 41424	: V=0.9788197, theta=18.237409 -> V=1.0, theta=0.0
% INFO    : Bus 41425	: V=0.9729417, theta=18.098809 -> V=1.0, theta=0.0
% INFO    : Bus 41426	: V=0.9770479, theta=18.226325 -> V=1.0, theta=0.0
% INFO    : Bus 41427	: V=0.9710134, theta=18.099249 -> V=1.0, theta=0.0
% INFO    : Bus 41428	: V=0.9784256, theta=18.25859 -> V=1.0, theta=0.0
% INFO    : Bus 41429	: V=0.9801136, theta=18.293003 -> V=1.0, theta=0.0
% INFO    : Bus 41430	: V=0.9796501, theta=18.270313 -> V=1.0, theta=0.0
% INFO    : Bus 41431	: V=0.9762315, theta=18.159467 -> V=1.0, theta=0.0
% INFO    : Bus 41432	: V=0.9789475, theta=18.227809 -> V=1.0, theta=0.0
% INFO    : Bus 41433	: V=0.9833032, theta=18.258839 -> V=1.0, theta=0.0
% INFO    : Bus 41434	: V=0.9769004, theta=18.154886 -> V=1.0, theta=0.0
% INFO    : Bus 41435	: V=0.9805656, theta=18.265502 -> V=1.0, theta=0.0
% INFO    : Bus 41436	: V=0.9814677, theta=18.300648 -> V=1.0, theta=0.0
% INFO    : Bus 41437	: V=0.9819772, theta=18.264267 -> V=1.0, theta=0.0
% INFO    : Bus 41438	: V=0.9811463, theta=18.246275 -> V=1.0, theta=0.0
% INFO    : Bus 41439	: V=0.9794721, theta=18.27783 -> V=1.0, theta=0.0
% INFO    : Bus 41440	: V=0.9726815, theta=18.765664 -> V=1.0, theta=0.0
% INFO    : Bus 41441	: V=0.9704018, theta=18.582395 -> V=1.0, theta=0.0
% INFO    : Bus 41442	: V=0.9768043, theta=18.710103 -> V=1.0, theta=0.0
% INFO    : Bus 41443	: V=0.9770495, theta=18.734104 -> V=1.0, theta=0.0
% INFO    : Bus 41444	: V=0.9719593, theta=18.710267 -> V=1.0, theta=0.0
% INFO    : Bus 41445	: V=0.9786658, theta=18.922014 -> V=1.0, theta=0.0
% INFO    : Bus 41446	: V=0.9781619, theta=18.812504 -> V=1.0, theta=0.0
% INFO    : Bus 41447	: V=0.9720065, theta=18.472867 -> V=1.0, theta=0.0
% INFO    : Bus 41448	: V=0.978564, theta=18.782256 -> V=1.0, theta=0.0
% INFO    : Bus 41449	: V=0.9766782, theta=18.534054 -> V=1.0, theta=0.0
% INFO    : Bus 41450	: V=0.9768875, theta=18.615754 -> V=1.0, theta=0.0
% INFO    : Bus 41451	: V=0.9765651, theta=18.648647 -> V=1.0, theta=0.0
% INFO    : Bus 41452	: V=0.9760532, theta=18.668583 -> V=1.0, theta=0.0
% INFO    : Bus 41453	: V=0.976215, theta=18.658243 -> V=1.0, theta=0.0
% INFO    : Bus 41454	: V=0.9764575, theta=18.567868 -> V=1.0, theta=0.0
% INFO    : Bus 41455	: V=0.9742773, theta=18.517887 -> V=1.0, theta=0.0
% INFO    : Bus 41456	: V=0.9741082, theta=18.462896 -> V=1.0, theta=0.0
% INFO    : Bus 41457	: V=0.9743891, theta=18.330512 -> V=1.0, theta=0.0
% INFO    : Bus 41458	: V=0.975601, theta=18.345623 -> V=1.0, theta=0.0
% INFO    : Bus 41459	: V=0.9752149, theta=18.323473 -> V=1.0, theta=0.0
% INFO    : Bus 41460	: V=0.974839, theta=18.427682 -> V=1.0, theta=0.0
% INFO    : Bus 41461	: V=0.9753305, theta=18.406199 -> V=1.0, theta=0.0
% INFO    : Bus 41462	: V=0.9769938, theta=18.503147 -> V=1.0, theta=0.0
% INFO    : Bus 41463	: V=0.9741554, theta=18.346469 -> V=1.0, theta=0.0
% INFO    : Bus 41464	: V=0.9766495, theta=18.356135 -> V=1.0, theta=0.0
% INFO    : Bus 41465	: V=0.9785338, theta=18.419727 -> V=1.0, theta=0.0
% INFO    : Bus 41466	: V=0.9784381, theta=18.354677 -> V=1.0, theta=0.0
% INFO    : Bus 41467	: V=0.9795855, theta=18.350291 -> V=1.0, theta=0.0
% INFO    : Bus 41468	: V=0.970063, theta=18.370729 -> V=1.0, theta=0.0
% INFO    : Bus 41469	: V=0.9774482, theta=18.566055 -> V=1.0, theta=0.0
% INFO    : Bus 41470	: V=0.9783142, theta=18.5267 -> V=1.0, theta=0.0
% INFO    : Bus 41471	: V=0.9789058, theta=18.500927 -> V=1.0, theta=0.0
% INFO    : Bus 41472	: V=0.9724504, theta=18.409956 -> V=1.0, theta=0.0
% INFO    : Bus 41473	: V=0.9789746, theta=18.758599 -> V=1.0, theta=0.0
% INFO    : Bus 41474	: V=0.9796578, theta=18.734404 -> V=1.0, theta=0.0
% INFO    : Bus 41475	: V=0.9719211, theta=18.546209 -> V=1.0, theta=0.0
% INFO    : Bus 41476	: V=0.9811831, theta=18.704497 -> V=1.0, theta=0.0
% INFO    : Bus 41477	: V=0.9821957, theta=18.704549 -> V=1.0, theta=0.0
% INFO    : Bus 41478	: V=0.9803477, theta=18.462119 -> V=1.0, theta=0.0
% INFO    : Bus 41479	: V=0.9810966, theta=18.343033 -> V=1.0, theta=0.0
% INFO    : Bus 41480	: V=0.9806756, theta=18.386509 -> V=1.0, theta=0.0
% INFO    : Bus 41481	: V=0.9881944, theta=18.619185 -> V=1.0, theta=0.0
% INFO    : Bus 41482	: V=0.9895939, theta=18.643936 -> V=1.0, theta=0.0
% INFO    : Bus 41483	: V=0.9809034, theta=18.546022 -> V=1.0, theta=0.0
% INFO    : Bus 41484	: V=0.9821797, theta=18.533897 -> V=1.0, theta=0.0
% INFO    : Bus 41485	: V=0.9812523, theta=18.371147 -> V=1.0, theta=0.0
% INFO    : Bus 41486	: V=0.9803018, theta=18.359742 -> V=1.0, theta=0.0
% INFO    : Bus 41487	: V=0.9844275, theta=18.554475 -> V=1.0, theta=0.0
% INFO    : Bus 41488	: V=0.9860073, theta=18.712635 -> V=1.0, theta=0.0
% INFO    : Bus 41489	: V=0.9827373, theta=18.399303 -> V=1.0, theta=0.0
% INFO    : Bus 41490	: V=0.9859315, theta=18.577752 -> V=1.0, theta=0.0
% INFO    : Bus 41491	: V=0.9875063, theta=18.60612 -> V=1.0, theta=0.0
% INFO    : Bus 41492	: V=0.987992, theta=18.620767 -> V=1.0, theta=0.0
% INFO    : Bus 41493	: V=0.9901368, theta=18.688197 -> V=1.0, theta=0.0
% INFO    : Bus 41494	: V=0.9879012, theta=18.576072 -> V=1.0, theta=0.0
% INFO    : Bus 41495	: V=0.9839322, theta=18.358861 -> V=1.0, theta=0.0
% INFO    : Bus 41496	: V=0.9885146, theta=18.521411 -> V=1.0, theta=0.0
% INFO    : Bus 41497	: V=0.9864378, theta=18.392473 -> V=1.0, theta=0.0
% INFO    : Bus 41498	: V=0.9876889, theta=18.40082 -> V=1.0, theta=0.0
% INFO    : Bus 41499	: V=0.992012, theta=18.751235 -> V=1.0, theta=0.0
% INFO    : Bus 41500	: V=0.9937367, theta=18.804194 -> V=1.0, theta=0.0
% INFO    : Bus 41501	: V=0.9925095, theta=18.787558 -> V=1.0, theta=0.0
% INFO    : Bus 41502	: V=0.980958, theta=18.326306 -> V=1.0, theta=0.0
% INFO    : Bus 41503	: V=0.9821238, theta=18.224 -> V=1.0, theta=0.0
% INFO    : Bus 41504	: V=0.9857744, theta=18.225992 -> V=1.0, theta=0.0
% INFO    : Bus 41505	: V=0.9875497, theta=18.236801 -> V=1.0, theta=0.0
% INFO    : Bus 41506	: V=0.9880636, theta=18.039476 -> V=1.0, theta=0.0
% INFO    : Bus 41507	: V=0.9884477, theta=18.205293 -> V=1.0, theta=0.0
% INFO    : Bus 41508	: V=0.9844553, theta=18.361023 -> V=1.0, theta=0.0
% INFO    : Bus 41509	: V=0.990994, theta=18.265062 -> V=1.0, theta=0.0
% INFO    : Bus 41510	: V=0.991037, theta=18.307626 -> V=1.0, theta=0.0
% INFO    : Bus 41511	: V=0.9906257, theta=18.300367 -> V=1.0, theta=0.0
% INFO    : Bus 41512	: V=0.9864231, theta=18.375203 -> V=1.0, theta=0.0
% INFO    : Bus 41513	: V=0.9913041, theta=18.336799 -> V=1.0, theta=0.0
% INFO    : Bus 41514	: V=0.9901757, theta=18.43877 -> V=1.0, theta=0.0
% INFO    : Bus 41515	: V=0.9913281, theta=18.401522 -> V=1.0, theta=0.0
% INFO    : Bus 41516	: V=0.9918051, theta=18.371766 -> V=1.0, theta=0.0
% INFO    : Bus 41517	: V=0.9829949, theta=19.855242 -> V=1.0, theta=0.0
% INFO    : Bus 41518	: V=0.9578215, theta=19.272323 -> V=1.0, theta=0.0
% INFO    : Bus 41519	: V=0.9565893, theta=19.119971 -> V=1.0, theta=0.0
% INFO    : Bus 41520	: V=0.9565014, theta=19.150581 -> V=1.0, theta=0.0
% INFO    : Bus 41521	: V=0.9556664, theta=19.199968 -> V=1.0, theta=0.0
% INFO    : Bus 41522	: V=0.9563259, theta=19.21001 -> V=1.0, theta=0.0
% INFO    : Bus 41523	: V=0.959724, theta=19.445698 -> V=1.0, theta=0.0
% INFO    : Bus 41524	: V=0.9606383, theta=19.461784 -> V=1.0, theta=0.0
% INFO    : Bus 41525	: V=0.9552933, theta=19.41729 -> V=1.0, theta=0.0
% INFO    : Bus 41526	: V=0.966664, theta=19.484875 -> V=1.0, theta=0.0
% INFO    : Bus 41527	: V=0.9585355, theta=19.593737 -> V=1.0, theta=0.0
% INFO    : Bus 41528	: V=0.9585612, theta=19.603717 -> V=1.0, theta=0.0
% INFO    : Bus 41529	: V=0.953785, theta=19.366998 -> V=1.0, theta=0.0
% INFO    : Bus 41530	: V=0.9596715, theta=19.55885 -> V=1.0, theta=0.0
% INFO    : Bus 41531	: V=0.9561869, theta=19.141882 -> V=1.0, theta=0.0
% INFO    : Bus 41532	: V=0.9562249, theta=19.132172 -> V=1.0, theta=0.0
% INFO    : Bus 41533	: V=0.9612098, theta=19.344322 -> V=1.0, theta=0.0
% INFO    : Bus 41534	: V=0.9556139, theta=19.219243 -> V=1.0, theta=0.0
% INFO    : Bus 41535	: V=0.9560924, theta=19.142192 -> V=1.0, theta=0.0
% INFO    : Bus 41536	: V=0.9559272, theta=19.231577 -> V=1.0, theta=0.0
% INFO    : Bus 41537	: V=0.9804651, theta=20.3028 -> V=1.0, theta=0.0
% INFO    : Bus 41538	: V=0.9548681, theta=19.099902 -> V=1.0, theta=0.0
% INFO    : Bus 41539	: V=0.9597142, theta=19.153087 -> V=1.0, theta=0.0
% INFO    : Bus 41540	: V=0.9682442, theta=19.380084 -> V=1.0, theta=0.0
% INFO    : Bus 41541	: V=0.9684938, theta=19.367601 -> V=1.0, theta=0.0
% INFO    : Bus 41542	: V=0.9640854, theta=19.170139 -> V=1.0, theta=0.0
% INFO    : Bus 41543	: V=0.9698909, theta=18.786059 -> V=1.0, theta=0.0
% INFO    : Bus 41544	: V=0.9611068, theta=18.657988 -> V=1.0, theta=0.0
% INFO    : Bus 41545	: V=0.9670557, theta=18.759265 -> V=1.0, theta=0.0
% INFO    : Bus 41546	: V=0.9748781, theta=18.95614 -> V=1.0, theta=0.0
% INFO    : Bus 41547	: V=0.9740011, theta=19.003518 -> V=1.0, theta=0.0
% INFO    : Bus 41548	: V=0.9609235, theta=18.897329 -> V=1.0, theta=0.0
% INFO    : Bus 41549	: V=0.9612929, theta=18.905315 -> V=1.0, theta=0.0
% INFO    : Bus 41550	: V=0.9610579, theta=18.925931 -> V=1.0, theta=0.0
% INFO    : Bus 41551	: V=0.9609159, theta=18.930777 -> V=1.0, theta=0.0
% INFO    : Bus 41552	: V=0.9594099, theta=18.80977 -> V=1.0, theta=0.0
% INFO    : Bus 41553	: V=0.967578, theta=18.970082 -> V=1.0, theta=0.0
% INFO    : Bus 41554	: V=0.9607233, theta=18.888511 -> V=1.0, theta=0.0
% INFO    : Bus 41555	: V=0.9656567, theta=18.920145 -> V=1.0, theta=0.0
% INFO    : Bus 41556	: V=0.9686484, theta=19.193296 -> V=1.0, theta=0.0
% INFO    : Bus 41557	: V=0.9617903, theta=18.926678 -> V=1.0, theta=0.0
% INFO    : Bus 41558	: V=0.9613292, theta=18.952046 -> V=1.0, theta=0.0
% INFO    : Bus 41559	: V=0.9609541, theta=18.954484 -> V=1.0, theta=0.0
% INFO    : Bus 41560	: V=0.9609379, theta=18.963125 -> V=1.0, theta=0.0
% INFO    : Bus 41561	: V=0.9607243, theta=18.962102 -> V=1.0, theta=0.0
% INFO    : Bus 41562	: V=0.9606525, theta=18.933293 -> V=1.0, theta=0.0
% INFO    : Bus 41563	: V=0.9611976, theta=18.866363 -> V=1.0, theta=0.0
% INFO    : Bus 41564	: V=0.9609429, theta=18.91682 -> V=1.0, theta=0.0
% INFO    : Bus 41565	: V=0.9607777, theta=18.980975 -> V=1.0, theta=0.0
% INFO    : Bus 41566	: V=0.9608039, theta=18.984971 -> V=1.0, theta=0.0
% INFO    : Bus 41567	: V=0.9565707, theta=19.246591 -> V=1.0, theta=0.0
% INFO    : Bus 41568	: V=0.9603385, theta=19.32429 -> V=1.0, theta=0.0
% INFO    : Bus 41569	: V=0.957994, theta=19.282935 -> V=1.0, theta=0.0
% INFO    : Bus 41570	: V=0.9587695, theta=19.225259 -> V=1.0, theta=0.0
% INFO    : Bus 41571	: V=0.961306, theta=19.324325 -> V=1.0, theta=0.0
% INFO    : Bus 41572	: V=0.9607406, theta=19.322625 -> V=1.0, theta=0.0
% INFO    : Bus 41573	: V=0.9590441, theta=19.22736 -> V=1.0, theta=0.0
% INFO    : Bus 41574	: V=0.9617056, theta=19.325853 -> V=1.0, theta=0.0
% INFO    : Bus 41575	: V=0.9579916, theta=19.143754 -> V=1.0, theta=0.0
% INFO    : Bus 41576	: V=0.9581374, theta=19.190013 -> V=1.0, theta=0.0
% INFO    : Bus 41577	: V=0.9598481, theta=19.1479 -> V=1.0, theta=0.0
% INFO    : Bus 41578	: V=0.9698262, theta=19.321457 -> V=1.0, theta=0.0
% INFO    : Bus 41579	: V=0.9568586, theta=19.087623 -> V=1.0, theta=0.0
% INFO    : Bus 41580	: V=0.962646, theta=19.333165 -> V=1.0, theta=0.0
% INFO    : Bus 41581	: V=0.9597429, theta=19.224886 -> V=1.0, theta=0.0
% INFO    : Bus 41582	: V=0.9812726, theta=20.615148 -> V=1.0, theta=0.0
% INFO    : Bus 41583	: V=0.9619777, theta=19.14665 -> V=1.0, theta=0.0
% INFO    : Bus 41584	: V=0.9845515, theta=19.918944 -> V=1.0, theta=0.0
% INFO    : Bus 41585	: V=0.9610815, theta=19.01661 -> V=1.0, theta=0.0
% INFO    : Bus 41586	: V=0.9608386, theta=18.996123 -> V=1.0, theta=0.0
% INFO    : Bus 41587	: V=0.9610617, theta=18.986716 -> V=1.0, theta=0.0
% INFO    : Bus 41588	: V=0.9699619, theta=19.287264 -> V=1.0, theta=0.0
% INFO    : Bus 41589	: V=0.9625957, theta=19.022862 -> V=1.0, theta=0.0
% INFO    : Bus 41590	: V=0.9695619, theta=19.263885 -> V=1.0, theta=0.0
% INFO    : Bus 41591	: V=0.9619981, theta=19.008318 -> V=1.0, theta=0.0
% INFO    : Bus 41592	: V=0.9628571, theta=19.029286 -> V=1.0, theta=0.0
% INFO    : Bus 41593	: V=0.9643032, theta=19.066397 -> V=1.0, theta=0.0
% INFO    : Bus 41594	: V=0.9591355, theta=19.044566 -> V=1.0, theta=0.0
% INFO    : Bus 41595	: V=0.9698094, theta=19.267532 -> V=1.0, theta=0.0
% INFO    : Bus 41596	: V=0.9596621, theta=19.158174 -> V=1.0, theta=0.0
% INFO    : Bus 41597	: V=0.9661383, theta=19.371015 -> V=1.0, theta=0.0
% INFO    : Bus 41598	: V=0.9609745, theta=19.025855 -> V=1.0, theta=0.0
% INFO    : Bus 41599	: V=0.9695283, theta=19.319644 -> V=1.0, theta=0.0
% INFO    : Bus 41600	: V=0.9615245, theta=19.157832 -> V=1.0, theta=0.0
% INFO    : Bus 41601	: V=0.9589009, theta=19.12093 -> V=1.0, theta=0.0
% INFO    : Bus 41602	: V=0.9604714, theta=19.200742 -> V=1.0, theta=0.0
% INFO    : Bus 41603	: V=0.9634714, theta=19.33995 -> V=1.0, theta=0.0
% INFO    : Bus 41604	: V=0.9605281, theta=19.200602 -> V=1.0, theta=0.0
% INFO    : Bus 41605	: V=0.9645269, theta=19.35159 -> V=1.0, theta=0.0
% INFO    : Bus 41606	: V=0.9607054, theta=18.773078 -> V=1.0, theta=0.0
% INFO    : Bus 41607	: V=0.9834233, theta=19.97594 -> V=1.0, theta=0.0
% INFO    : Bus 41608	: V=0.9609572, theta=19.001878 -> V=1.0, theta=0.0
% INFO    : Bus 41609	: V=0.9818353, theta=20.201548 -> V=1.0, theta=0.0
% INFO    : Bus 41610	: V=0.9677778, theta=19.411117 -> V=1.0, theta=0.0
% INFO    : Bus 41611	: V=0.9812161, theta=20.172417 -> V=1.0, theta=0.0
% INFO    : Bus 41612	: V=0.9607675, theta=18.709095 -> V=1.0, theta=0.0
% INFO    : Bus 41613	: V=0.9600007, theta=18.839349 -> V=1.0, theta=0.0
% INFO    : Bus 41614	: V=0.9866726, theta=19.603358 -> V=1.0, theta=0.0
% INFO    : Bus 41615	: V=0.9691563, theta=19.123716 -> V=1.0, theta=0.0
% INFO    : Bus 41616	: V=0.9701289, theta=19.322283 -> V=1.0, theta=0.0
% INFO    : Bus 41617	: V=0.9654225, theta=19.400574 -> V=1.0, theta=0.0
% INFO    : Bus 41618	: V=0.959761, theta=19.170993 -> V=1.0, theta=0.0
% INFO    : Bus 41619	: V=0.9835948, theta=19.956319 -> V=1.0, theta=0.0
% INFO    : Bus 41620	: V=0.9588195, theta=19.16382 -> V=1.0, theta=0.0
% INFO    : Bus 41621	: V=0.966404, theta=19.413348 -> V=1.0, theta=0.0
% INFO    : Bus 41622	: V=0.9671784, theta=19.373142 -> V=1.0, theta=0.0
% INFO    : Bus 41623	: V=0.9607125, theta=18.926586 -> V=1.0, theta=0.0
% INFO    : Bus 41624	: V=0.9592575, theta=19.400175 -> V=1.0, theta=0.0
% INFO    : Bus 41625	: V=0.9686804, theta=19.194143 -> V=1.0, theta=0.0
% INFO    : Bus 41626	: V=0.9737074, theta=19.020598 -> V=1.0, theta=0.0
% INFO    : Bus 41627	: V=0.9608333, theta=20.527678 -> V=1.0, theta=0.0
% INFO    : Bus 41628	: V=0.9716099, theta=19.050816 -> V=1.0, theta=0.0
% INFO    : Bus 41629	: V=0.9718093, theta=2.867581 -> V=1.0, theta=0.0
% INFO    : Bus 41630	: V=0.9791192, theta=1.617211 -> V=1.0, theta=0.0
% INFO    : Bus 41631	: V=0.976761, theta=1.998134 -> V=1.0, theta=0.0
% INFO    : Bus 41632	: V=0.9768456, theta=1.97625 -> V=1.0, theta=0.0
% INFO    : Bus 41633	: V=0.9804049, theta=3.228185 -> V=1.0, theta=0.0
% INFO    : Bus 41634	: V=0.9761005, theta=1.465593 -> V=1.0, theta=0.0
% INFO    : Bus 41635	: V=0.9969564, theta=6.184419 -> V=1.0, theta=0.0
% INFO    : Bus 41636	: V=1.0004204, theta=6.651464 -> V=1.0, theta=0.0
% INFO    : Bus 41637	: V=1.0080988, theta=7.473292 -> V=1.0, theta=0.0
% INFO    : Bus 41638	: V=0.9932207, theta=29.106946 -> V=1.0, theta=0.0
% INFO    : Bus 41639	: V=0.9965845, theta=30.497078 -> V=1.0, theta=0.0
% INFO    : Bus 41640	: V=1.0021732, theta=28.06247 -> V=1.0, theta=0.0
% INFO    : Bus 41641	: V=0.9951152, theta=26.829389 -> V=1.0, theta=0.0
% INFO    : Bus 41642	: V=0.9931692, theta=27.220848 -> V=1.0, theta=0.0
% INFO    : Bus 41643	: V=0.9955873, theta=26.790519 -> V=1.0, theta=0.0
% INFO    : Bus 41644	: V=0.9923044, theta=27.143652 -> V=1.0, theta=0.0
% INFO    : Bus 41645	: V=0.9974901, theta=27.073767 -> V=1.0, theta=0.0
% INFO    : Bus 41646	: V=0.9948249, theta=27.335523 -> V=1.0, theta=0.0
% INFO    : Bus 41647	: V=0.999976, theta=27.351594 -> V=1.0, theta=0.0
% INFO    : Bus 41648	: V=0.9898974, theta=27.337242 -> V=1.0, theta=0.0
% INFO    : Bus 41649	: V=0.9954183, theta=27.243914 -> V=1.0, theta=0.0
% INFO    : Bus 41650	: V=0.9893154, theta=27.037655 -> V=1.0, theta=0.0
% INFO    : Bus 41651	: V=1.0018091, theta=26.71826 -> V=1.0, theta=0.0
% INFO    : Bus 41652	: V=0.9940763, theta=26.583742 -> V=1.0, theta=0.0
% INFO    : Bus 41653	: V=1.0006821, theta=25.133895 -> V=1.0, theta=0.0
% INFO    : Bus 41654	: V=1.0132493, theta=26.301753 -> V=1.0, theta=0.0
% INFO    : Bus 41655	: V=1.0020497, theta=24.863242 -> V=1.0, theta=0.0
% INFO    : Bus 41656	: V=1.0050245, theta=24.769374 -> V=1.0, theta=0.0
% INFO    : Bus 41657	: V=1.0054868, theta=24.635533 -> V=1.0, theta=0.0
% INFO    : Bus 41658	: V=0.9898086, theta=27.284754 -> V=1.0, theta=0.0
% INFO    : Bus 41659	: V=1.0124052, theta=18.910532 -> V=1.0, theta=0.0
% INFO    : Bus 41660	: V=1.0157001, theta=19.680051 -> V=1.0, theta=0.0
% INFO    : Bus 41661	: V=1.0068312, theta=19.63865 -> V=1.0, theta=0.0
% INFO    : Bus 41662	: V=1.0044959, theta=19.095366 -> V=1.0, theta=0.0
% INFO    : Bus 41663	: V=1.0103035, theta=19.415773 -> V=1.0, theta=0.0
% INFO    : Bus 41664	: V=0.9583539, theta=8.148326 -> V=1.0, theta=0.0
% INFO    : Bus 41665	: V=0.9712864, theta=8.11963 -> V=1.0, theta=0.0
% INFO    : Bus 41666	: V=0.9802201, theta=8.445784 -> V=1.0, theta=0.0
% INFO    : Bus 41667	: V=0.9776579, theta=9.479299 -> V=1.0, theta=0.0
% INFO    : Bus 41668	: V=1.0104586, theta=7.318739 -> V=1.0, theta=0.0
% INFO    : Bus 41669	: V=0.9743475, theta=21.164874 -> V=1.0, theta=0.0
% INFO    : Bus 41670	: V=0.9645494, theta=21.156069 -> V=1.0, theta=0.0
% INFO    : Bus 41671	: V=0.9648652, theta=21.114408 -> V=1.0, theta=0.0
% INFO    : Bus 41672	: V=0.9604467, theta=20.773649 -> V=1.0, theta=0.0
% INFO    : Bus 41673	: V=0.9654534, theta=21.081659 -> V=1.0, theta=0.0
% INFO    : Bus 41674	: V=0.9635283, theta=21.317287 -> V=1.0, theta=0.0
% INFO    : Bus 41675	: V=0.960777, theta=21.042766 -> V=1.0, theta=0.0
% INFO    : Bus 41676	: V=0.9618859, theta=20.928404 -> V=1.0, theta=0.0
% INFO    : Bus 41677	: V=0.9617749, theta=21.026488 -> V=1.0, theta=0.0
% INFO    : Bus 41678	: V=0.9647312, theta=20.450924 -> V=1.0, theta=0.0
% INFO    : Bus 41679	: V=0.9589389, theta=20.5504 -> V=1.0, theta=0.0
% INFO    : Bus 41680	: V=0.9592649, theta=20.558765 -> V=1.0, theta=0.0
% INFO    : Bus 41681	: V=0.9643391, theta=20.451558 -> V=1.0, theta=0.0
% INFO    : Bus 41682	: V=0.9641329, theta=20.43993 -> V=1.0, theta=0.0
% INFO    : Bus 41683	: V=0.959439, theta=20.534113 -> V=1.0, theta=0.0
% INFO    : Bus 41684	: V=0.9596668, theta=20.638586 -> V=1.0, theta=0.0
% INFO    : Bus 41685	: V=0.963271, theta=21.453778 -> V=1.0, theta=0.0
% INFO    : Bus 41686	: V=0.9664586, theta=21.112103 -> V=1.0, theta=0.0
% INFO    : Bus 41687	: V=0.9616008, theta=21.093087 -> V=1.0, theta=0.0
% INFO    : Bus 41688	: V=0.9661362, theta=21.122665 -> V=1.0, theta=0.0
% INFO    : Bus 41689	: V=0.967029, theta=21.100071 -> V=1.0, theta=0.0
% INFO    : Bus 41690	: V=0.9676886, theta=21.195646 -> V=1.0, theta=0.0
% INFO    : Bus 41691	: V=0.9644513, theta=21.179751 -> V=1.0, theta=0.0
% INFO    : Bus 41692	: V=0.9637738, theta=21.533796 -> V=1.0, theta=0.0
% INFO    : Bus 41693	: V=0.9598984, theta=21.593505 -> V=1.0, theta=0.0
% INFO    : Bus 41694	: V=0.9634701, theta=21.504234 -> V=1.0, theta=0.0
% INFO    : Bus 41695	: V=0.9619656, theta=21.957531 -> V=1.0, theta=0.0
% INFO    : Bus 41696	: V=0.9636446, theta=21.638177 -> V=1.0, theta=0.0
% INFO    : Bus 41697	: V=0.9627731, theta=21.695745 -> V=1.0, theta=0.0
% INFO    : Bus 41698	: V=0.9654843, theta=21.660296 -> V=1.0, theta=0.0
% INFO    : Bus 41699	: V=0.9608454, theta=21.294538 -> V=1.0, theta=0.0
% INFO    : Bus 41700	: V=0.9611305, theta=21.284935 -> V=1.0, theta=0.0
% INFO    : Bus 41701	: V=0.9643557, theta=21.582315 -> V=1.0, theta=0.0
% INFO    : Bus 41702	: V=0.96494, theta=21.624402 -> V=1.0, theta=0.0
% INFO    : Bus 41703	: V=0.9650326, theta=21.542461 -> V=1.0, theta=0.0
% INFO    : Bus 41704	: V=0.9632071, theta=21.69694 -> V=1.0, theta=0.0
% INFO    : Bus 41705	: V=0.9666062, theta=21.508285 -> V=1.0, theta=0.0
% INFO    : Bus 41706	: V=0.9685145, theta=21.605616 -> V=1.0, theta=0.0
% INFO    : Bus 41707	: V=0.9693352, theta=21.591331 -> V=1.0, theta=0.0
% INFO    : Bus 41708	: V=0.9671828, theta=21.452592 -> V=1.0, theta=0.0
% INFO    : Bus 41709	: V=0.9682192, theta=21.397042 -> V=1.0, theta=0.0
% INFO    : Bus 41710	: V=0.9677444, theta=21.569892 -> V=1.0, theta=0.0
% INFO    : Bus 41711	: V=0.9679119, theta=21.403565 -> V=1.0, theta=0.0
% INFO    : Bus 41712	: V=0.968731, theta=21.693411 -> V=1.0, theta=0.0
% INFO    : Bus 41713	: V=0.9659403, theta=22.175487 -> V=1.0, theta=0.0
% INFO    : Bus 41714	: V=0.9659632, theta=21.907885 -> V=1.0, theta=0.0
% INFO    : Bus 41715	: V=0.9697103, theta=22.018846 -> V=1.0, theta=0.0
% INFO    : Bus 41716	: V=0.9664982, theta=21.891305 -> V=1.0, theta=0.0
% INFO    : Bus 41717	: V=0.9600117, theta=22.001812 -> V=1.0, theta=0.0
% INFO    : Bus 41718	: V=0.9602668, theta=21.949165 -> V=1.0, theta=0.0
% INFO    : Bus 41719	: V=0.9620059, theta=21.953417 -> V=1.0, theta=0.0
% INFO    : Bus 41720	: V=0.9632301, theta=21.830564 -> V=1.0, theta=0.0
% INFO    : Bus 41721	: V=0.9616997, theta=21.909923 -> V=1.0, theta=0.0
% INFO    : Bus 41722	: V=0.9608684, theta=21.946676 -> V=1.0, theta=0.0
% INFO    : Bus 41723	: V=0.9667512, theta=21.677737 -> V=1.0, theta=0.0
% INFO    : Bus 41724	: V=0.9646618, theta=21.572762 -> V=1.0, theta=0.0
% INFO    : Bus 41725	: V=0.9654711, theta=21.574644 -> V=1.0, theta=0.0
% INFO    : Bus 41726	: V=0.9674719, theta=21.681895 -> V=1.0, theta=0.0
% INFO    : Bus 41727	: V=0.9702949, theta=21.781543 -> V=1.0, theta=0.0
% INFO    : Bus 41728	: V=0.9635071, theta=21.822088 -> V=1.0, theta=0.0
% INFO    : Bus 41729	: V=0.9729726, theta=21.778781 -> V=1.0, theta=0.0
% INFO    : Bus 41730	: V=0.9737237, theta=21.749123 -> V=1.0, theta=0.0
% INFO    : Bus 41731	: V=0.9718843, theta=21.647467 -> V=1.0, theta=0.0
% INFO    : Bus 41732	: V=0.9849333, theta=22.689179 -> V=1.0, theta=0.0
% INFO    : Bus 41733	: V=0.9708055, theta=21.857126 -> V=1.0, theta=0.0
% INFO    : Bus 41734	: V=0.9727518, theta=21.883417 -> V=1.0, theta=0.0
% INFO    : Bus 41735	: V=0.9769399, theta=21.808222 -> V=1.0, theta=0.0
% INFO    : Bus 41736	: V=0.9794219, theta=22.024034 -> V=1.0, theta=0.0
% INFO    : Bus 41737	: V=0.9780059, theta=21.943251 -> V=1.0, theta=0.0
% INFO    : Bus 41738	: V=0.9770785, theta=21.485975 -> V=1.0, theta=0.0
% INFO    : Bus 41739	: V=0.9795423, theta=21.856427 -> V=1.0, theta=0.0
% INFO    : Bus 41740	: V=0.96872, theta=21.31854 -> V=1.0, theta=0.0
% INFO    : Bus 41741	: V=0.9705177, theta=21.534539 -> V=1.0, theta=0.0
% INFO    : Bus 41742	: V=0.9657701, theta=21.107954 -> V=1.0, theta=0.0
% INFO    : Bus 41743	: V=0.9678907, theta=20.880857 -> V=1.0, theta=0.0
% INFO    : Bus 41744	: V=0.9663543, theta=21.115453 -> V=1.0, theta=0.0
% INFO    : Bus 41745	: V=0.9716279, theta=21.570534 -> V=1.0, theta=0.0
% INFO    : Bus 41746	: V=0.9700595, theta=21.348398 -> V=1.0, theta=0.0
% INFO    : Bus 41747	: V=0.9714127, theta=21.385626 -> V=1.0, theta=0.0
% INFO    : Bus 41748	: V=0.9657806, theta=20.999032 -> V=1.0, theta=0.0
% INFO    : Bus 41749	: V=0.9691702, theta=20.974867 -> V=1.0, theta=0.0
% INFO    : Bus 41750	: V=0.966023, theta=21.028221 -> V=1.0, theta=0.0
% INFO    : Bus 41751	: V=0.966431, theta=21.055757 -> V=1.0, theta=0.0
% INFO    : Bus 41752	: V=0.971908, theta=21.301434 -> V=1.0, theta=0.0
% INFO    : Bus 41753	: V=0.9718819, theta=21.455893 -> V=1.0, theta=0.0
% INFO    : Bus 41754	: V=0.9755769, theta=21.406788 -> V=1.0, theta=0.0
% INFO    : Bus 41755	: V=0.973841, theta=21.318684 -> V=1.0, theta=0.0
% INFO    : Bus 41756	: V=0.9725975, theta=21.549677 -> V=1.0, theta=0.0
% INFO    : Bus 41757	: V=0.9748397, theta=21.573006 -> V=1.0, theta=0.0
% INFO    : Bus 41758	: V=0.9736572, theta=21.559004 -> V=1.0, theta=0.0
% INFO    : Bus 41759	: V=0.9723112, theta=21.127456 -> V=1.0, theta=0.0
% INFO    : Bus 41760	: V=0.9725123, theta=21.242769 -> V=1.0, theta=0.0
% INFO    : Bus 41761	: V=0.9721986, theta=21.213891 -> V=1.0, theta=0.0
% INFO    : Bus 41762	: V=0.9679719, theta=21.055689 -> V=1.0, theta=0.0
% INFO    : Bus 41763	: V=0.972297, theta=21.019455 -> V=1.0, theta=0.0
% INFO    : Bus 41764	: V=0.9723399, theta=20.962368 -> V=1.0, theta=0.0
% INFO    : Bus 41765	: V=0.9722771, theta=21.146444 -> V=1.0, theta=0.0
% INFO    : Bus 41766	: V=0.9730402, theta=21.150653 -> V=1.0, theta=0.0
% INFO    : Bus 41767	: V=0.9604039, theta=20.163139 -> V=1.0, theta=0.0
% INFO    : Bus 41768	: V=0.9608927, theta=20.187647 -> V=1.0, theta=0.0
% INFO    : Bus 41769	: V=0.9656144, theta=20.469573 -> V=1.0, theta=0.0
% INFO    : Bus 41770	: V=0.9661803, theta=20.560164 -> V=1.0, theta=0.0
% INFO    : Bus 41771	: V=0.9666877, theta=20.632831 -> V=1.0, theta=0.0
% INFO    : Bus 41772	: V=0.9672732, theta=20.967199 -> V=1.0, theta=0.0
% INFO    : Bus 41773	: V=0.9645969, theta=20.809146 -> V=1.0, theta=0.0
% INFO    : Bus 41774	: V=0.9674423, theta=20.972173 -> V=1.0, theta=0.0
% INFO    : Bus 41775	: V=0.9674844, theta=20.779313 -> V=1.0, theta=0.0
% INFO    : Bus 41776	: V=0.9672735, theta=20.650104 -> V=1.0, theta=0.0
% INFO    : Bus 41777	: V=0.9646949, theta=20.798399 -> V=1.0, theta=0.0
% INFO    : Bus 41778	: V=0.9676124, theta=20.579312 -> V=1.0, theta=0.0
% INFO    : Bus 41779	: V=0.9670152, theta=20.495648 -> V=1.0, theta=0.0
% INFO    : Bus 41780	: V=0.966357, theta=20.411762 -> V=1.0, theta=0.0
% INFO    : Bus 41781	: V=0.9611568, theta=20.254385 -> V=1.0, theta=0.0
% INFO    : Bus 41782	: V=0.9659104, theta=20.32752 -> V=1.0, theta=0.0
% INFO    : Bus 41783	: V=0.9617988, theta=20.263625 -> V=1.0, theta=0.0
% INFO    : Bus 41784	: V=0.9655957, theta=20.547986 -> V=1.0, theta=0.0
% INFO    : Bus 41785	: V=0.9665754, theta=20.491741 -> V=1.0, theta=0.0
% INFO    : Bus 41786	: V=0.97138, theta=20.823834 -> V=1.0, theta=0.0
% INFO    : Bus 41787	: V=0.9719891, theta=20.896052 -> V=1.0, theta=0.0
% INFO    : Bus 41788	: V=0.9726216, theta=20.924343 -> V=1.0, theta=0.0
% INFO    : Bus 41789	: V=0.9701736, theta=20.572557 -> V=1.0, theta=0.0
% INFO    : Bus 41790	: V=0.9688737, theta=20.616486 -> V=1.0, theta=0.0
% INFO    : Bus 41791	: V=0.9743184, theta=20.893588 -> V=1.0, theta=0.0
% INFO    : Bus 41792	: V=0.9728562, theta=20.638023 -> V=1.0, theta=0.0
% INFO    : Bus 41793	: V=0.968825, theta=20.543495 -> V=1.0, theta=0.0
% INFO    : Bus 41794	: V=0.9667589, theta=20.314953 -> V=1.0, theta=0.0
% INFO    : Bus 41795	: V=0.9647394, theta=20.171146 -> V=1.0, theta=0.0
% INFO    : Bus 41796	: V=0.9670032, theta=20.356524 -> V=1.0, theta=0.0
% INFO    : Bus 41797	: V=0.9757502, theta=20.629381 -> V=1.0, theta=0.0
% INFO    : Bus 41798	: V=0.9670047, theta=20.20893 -> V=1.0, theta=0.0
% INFO    : Bus 41799	: V=0.9757491, theta=20.725906 -> V=1.0, theta=0.0
% INFO    : Bus 41800	: V=0.9762545, theta=20.872026 -> V=1.0, theta=0.0
% INFO    : Bus 41801	: V=0.9768773, theta=20.742019 -> V=1.0, theta=0.0
% INFO    : Bus 41802	: V=0.9788357, theta=20.895972 -> V=1.0, theta=0.0
% INFO    : Bus 41803	: V=0.9758448, theta=20.538932 -> V=1.0, theta=0.0
% INFO    : Bus 41804	: V=0.9738564, theta=20.38801 -> V=1.0, theta=0.0
% INFO    : Bus 41805	: V=0.9724209, theta=20.27444 -> V=1.0, theta=0.0
% INFO    : Bus 41806	: V=0.972048, theta=20.224127 -> V=1.0, theta=0.0
% INFO    : Bus 41807	: V=0.975994, theta=20.286238 -> V=1.0, theta=0.0
% INFO    : Bus 41808	: V=0.9771895, theta=20.380525 -> V=1.0, theta=0.0
% INFO    : Bus 41809	: V=0.9774966, theta=20.46649 -> V=1.0, theta=0.0
% INFO    : Bus 41810	: V=0.9785916, theta=20.601167 -> V=1.0, theta=0.0
% INFO    : Bus 41811	: V=0.9773452, theta=20.553335 -> V=1.0, theta=0.0
% INFO    : Bus 41812	: V=0.9798738, theta=20.416967 -> V=1.0, theta=0.0
% INFO    : Bus 41813	: V=0.9786549, theta=20.398663 -> V=1.0, theta=0.0
% INFO    : Bus 41814	: V=0.97577, theta=20.446824 -> V=1.0, theta=0.0
% INFO    : Bus 41815	: V=0.9780683, theta=20.594052 -> V=1.0, theta=0.0
% INFO    : Bus 41816	: V=0.9791485, theta=20.782273 -> V=1.0, theta=0.0
% INFO    : Bus 41817	: V=0.9781008, theta=20.76115 -> V=1.0, theta=0.0
% INFO    : Bus 41818	: V=0.9909416, theta=21.245619 -> V=1.0, theta=0.0
% INFO    : Bus 41819	: V=0.9801617, theta=20.805891 -> V=1.0, theta=0.0
% INFO    : Bus 41820	: V=0.9824358, theta=20.914625 -> V=1.0, theta=0.0
% INFO    : Bus 41821	: V=0.9813124, theta=20.859354 -> V=1.0, theta=0.0
% INFO    : Bus 41822	: V=0.9808891, theta=20.676014 -> V=1.0, theta=0.0
% INFO    : Bus 41823	: V=0.9849419, theta=20.593976 -> V=1.0, theta=0.0
% INFO    : Bus 41824	: V=0.9829527, theta=20.373528 -> V=1.0, theta=0.0
% INFO    : Bus 41825	: V=0.9827923, theta=20.516995 -> V=1.0, theta=0.0
% INFO    : Bus 41826	: V=0.9855513, theta=20.868271 -> V=1.0, theta=0.0
% INFO    : Bus 41827	: V=0.9848577, theta=20.987589 -> V=1.0, theta=0.0
% INFO    : Bus 41828	: V=0.9811301, theta=20.437724 -> V=1.0, theta=0.0
% INFO    : Bus 41829	: V=0.9817913, theta=20.412735 -> V=1.0, theta=0.0
% INFO    : Bus 41830	: V=0.9849301, theta=20.312964 -> V=1.0, theta=0.0
% INFO    : Bus 41831	: V=0.9804121, theta=20.022509 -> V=1.0, theta=0.0
% INFO    : Bus 41832	: V=0.9757744, theta=21.036461 -> V=1.0, theta=0.0
% INFO    : Bus 41833	: V=0.9762855, theta=21.104567 -> V=1.0, theta=0.0
% INFO    : Bus 41834	: V=0.9769189, theta=21.165974 -> V=1.0, theta=0.0
% INFO    : Bus 41835	: V=0.9779934, theta=21.253747 -> V=1.0, theta=0.0
% INFO    : Bus 41836	: V=0.9777299, theta=21.322914 -> V=1.0, theta=0.0
% INFO    : Bus 41837	: V=0.9804201, theta=21.238342 -> V=1.0, theta=0.0
% INFO    : Bus 41838	: V=0.9771498, theta=21.367461 -> V=1.0, theta=0.0
% INFO    : Bus 41839	: V=0.9786397, theta=21.403503 -> V=1.0, theta=0.0
% INFO    : Bus 41840	: V=0.9885158, theta=21.27939 -> V=1.0, theta=0.0
% INFO    : Bus 41841	: V=0.9852098, theta=21.248834 -> V=1.0, theta=0.0
% INFO    : Bus 41842	: V=0.9878627, theta=21.263979 -> V=1.0, theta=0.0
% INFO    : Bus 41843	: V=0.9793147, theta=21.313247 -> V=1.0, theta=0.0
% INFO    : Bus 41844	: V=0.9822657, theta=21.350925 -> V=1.0, theta=0.0
% INFO    : Bus 41845	: V=0.9829592, theta=21.392218 -> V=1.0, theta=0.0
% INFO    : Bus 41846	: V=0.9795146, theta=21.346096 -> V=1.0, theta=0.0
% INFO    : Bus 41847	: V=0.9791222, theta=21.37249 -> V=1.0, theta=0.0
% INFO    : Bus 41848	: V=0.9956152, theta=21.391963 -> V=1.0, theta=0.0
% INFO    : Bus 41849	: V=0.9951148, theta=21.423264 -> V=1.0, theta=0.0
% INFO    : Bus 41850	: V=0.9943588, theta=21.47874 -> V=1.0, theta=0.0
% INFO    : Bus 41851	: V=0.9862194, theta=21.044898 -> V=1.0, theta=0.0
% INFO    : Bus 41852	: V=0.9924206, theta=21.262556 -> V=1.0, theta=0.0
% INFO    : Bus 41853	: V=0.9959988, theta=21.389317 -> V=1.0, theta=0.0
% INFO    : Bus 41854	: V=0.982748, theta=21.229358 -> V=1.0, theta=0.0
% INFO    : Bus 41855	: V=0.983841, theta=21.236381 -> V=1.0, theta=0.0
% INFO    : Bus 41856	: V=0.9790959, theta=21.216715 -> V=1.0, theta=0.0
% INFO    : Bus 41857	: V=0.983951, theta=21.193222 -> V=1.0, theta=0.0
% INFO    : Bus 41858	: V=0.9782761, theta=21.557813 -> V=1.0, theta=0.0
% INFO    : Bus 41859	: V=0.9909854, theta=21.934732 -> V=1.0, theta=0.0
% INFO    : Bus 41860	: V=0.9827496, theta=22.059367 -> V=1.0, theta=0.0
% INFO    : Bus 41861	: V=0.9824399, theta=22.138696 -> V=1.0, theta=0.0
% INFO    : Bus 41862	: V=0.9824475, theta=21.955971 -> V=1.0, theta=0.0
% INFO    : Bus 41863	: V=0.9824289, theta=21.983193 -> V=1.0, theta=0.0
% INFO    : Bus 41864	: V=0.9824984, theta=21.903845 -> V=1.0, theta=0.0
% INFO    : Bus 41865	: V=0.9897973, theta=22.130097 -> V=1.0, theta=0.0
% INFO    : Bus 41866	: V=0.9815284, theta=21.683743 -> V=1.0, theta=0.0
% INFO    : Bus 41867	: V=0.9833319, theta=21.975742 -> V=1.0, theta=0.0
% INFO    : Bus 41868	: V=0.9839264, theta=21.947851 -> V=1.0, theta=0.0
% INFO    : Bus 41869	: V=0.9839604, theta=21.935176 -> V=1.0, theta=0.0
% INFO    : Bus 41870	: V=0.9862669, theta=21.895385 -> V=1.0, theta=0.0
% INFO    : Bus 41871	: V=0.983287, theta=21.813407 -> V=1.0, theta=0.0
% INFO    : Bus 41872	: V=0.9838532, theta=21.914415 -> V=1.0, theta=0.0
% INFO    : Bus 41873	: V=0.9848639, theta=21.916876 -> V=1.0, theta=0.0
% INFO    : Bus 41874	: V=0.9838879, theta=21.946105 -> V=1.0, theta=0.0
% INFO    : Bus 41875	: V=0.9829252, theta=21.861078 -> V=1.0, theta=0.0
% INFO    : Bus 41876	: V=0.9832297, theta=21.906778 -> V=1.0, theta=0.0
% INFO    : Bus 41877	: V=0.982607, theta=21.735042 -> V=1.0, theta=0.0
% INFO    : Bus 41878	: V=0.9837232, theta=21.879502 -> V=1.0, theta=0.0
% INFO    : Bus 41879	: V=0.9788689, theta=21.47248 -> V=1.0, theta=0.0
% INFO    : Bus 41880	: V=0.9842757, theta=21.823359 -> V=1.0, theta=0.0
% INFO    : Bus 41881	: V=0.9664341, theta=21.062521 -> V=1.0, theta=0.0
% INFO    : Bus 41882	: V=0.9805162, theta=21.041664 -> V=1.0, theta=0.0
% INFO    : Bus 41883	: V=0.9607233, theta=20.741914 -> V=1.0, theta=0.0
% INFO    : Bus 41884	: V=0.9805549, theta=20.954599 -> V=1.0, theta=0.0
% INFO    : Bus 41885	: V=0.9835367, theta=9.235764 -> V=1.0, theta=0.0
% INFO    : Bus 41886	: V=0.9581738, theta=7.987161 -> V=1.0, theta=0.0
% INFO    : Bus 41887	: V=0.9764674, theta=7.853914 -> V=1.0, theta=0.0
% INFO    : Bus 41888	: V=0.975718, theta=7.346373 -> V=1.0, theta=0.0
% INFO    : Bus 41889	: V=0.9738473, theta=7.023673 -> V=1.0, theta=0.0
% INFO    : Bus 41890	: V=0.9866844, theta=1.347204 -> V=1.0, theta=0.0
% INFO    : Bus 41891	: V=0.9850718, theta=0.28508 -> V=1.0, theta=0.0
% INFO    : Bus 41892	: V=0.9852174, theta=0.580007 -> V=1.0, theta=0.0
% INFO    : Bus 41893	: V=1.0073008, theta=7.475923 -> V=1.0, theta=0.0
% INFO    : Bus 41894	: V=1.0094034, theta=8.934295 -> V=1.0, theta=0.0
% INFO    : Bus 41895	: V=1.0129035, theta=7.62534 -> V=1.0, theta=0.0
% INFO    : Bus 41896	: V=1.0093133, theta=7.614235 -> V=1.0, theta=0.0
% INFO    : Bus 41897	: V=1.009752, theta=7.298985 -> V=1.0, theta=0.0
% INFO    : Bus 41898	: V=1.0058655, theta=7.563617 -> V=1.0, theta=0.0
% INFO    : Bus 41899	: V=0.9896864, theta=7.811141 -> V=1.0, theta=0.0
% INFO    : Bus 41900	: V=1.0063967, theta=7.62363 -> V=1.0, theta=0.0
% INFO    : Bus 41901	: V=1.0163809, theta=8.666044 -> V=1.0, theta=0.0
% INFO    : Bus 41902	: V=1.0133536, theta=8.183744 -> V=1.0, theta=0.0
% INFO    : Bus 41903	: V=0.9927419, theta=7.890435 -> V=1.0, theta=0.0
% INFO    : Bus 41904	: V=1.0094588, theta=7.630832 -> V=1.0, theta=0.0
% INFO    : Bus 41905	: V=1.0103188, theta=7.426341 -> V=1.0, theta=0.0
% INFO    : Bus 41906	: V=1.0128071, theta=6.949324 -> V=1.0, theta=0.0
% INFO    : Bus 41907	: V=1.0146625, theta=6.891706 -> V=1.0, theta=0.0
% INFO    : Bus 41908	: V=0.9801472, theta=17.698395 -> V=1.0, theta=0.0
% INFO    : Bus 41909	: V=0.9945377, theta=16.151515 -> V=1.0, theta=0.0
% INFO    : Bus 41910	: V=0.996222, theta=16.098001 -> V=1.0, theta=0.0
% INFO    : Bus 41911	: V=1.0044466, theta=17.51797 -> V=1.0, theta=0.0
% INFO    : Bus 41912	: V=1.0171771, theta=18.343152 -> V=1.0, theta=0.0
% INFO    : Bus 41913	: V=1.0110556, theta=0.172273 -> V=1.0, theta=0.0
% INFO    : Bus 41914	: V=1.0108058, theta=0.089469 -> V=1.0, theta=0.0
% INFO    : Bus 41915	: V=1.0112762, theta=0.1134 -> V=1.0, theta=0.0
% INFO    : Bus 41916	: V=1.0153402, theta=0.127254 -> V=1.0, theta=0.0
% INFO    : Bus 41917	: V=1.0030264, theta=-0.483038 -> V=1.0, theta=0.0
% INFO    : Bus 41918	: V=1.0184211, theta=-1.005058 -> V=1.0, theta=0.0
% INFO    : Bus 41919	: V=1.0034363, theta=-0.627826 -> V=1.0, theta=0.0
% INFO    : Bus 41920	: V=1.0016208, theta=-0.638586 -> V=1.0, theta=0.0
% INFO    : Bus 41921	: V=1.0042416, theta=-0.559664 -> V=1.0, theta=0.0
% INFO    : Bus 41922	: V=1.0080236, theta=-0.756669 -> V=1.0, theta=0.0
% INFO    : Bus 41923	: V=1.0026586, theta=-0.624822 -> V=1.0, theta=0.0
% INFO    : Bus 41924	: V=0.9995521, theta=-0.612535 -> V=1.0, theta=0.0
% INFO    : Bus 41925	: V=1.002425, theta=25.136104 -> V=1.0, theta=0.0
% INFO    : Bus 41926	: V=1.0030293, theta=25.081135 -> V=1.0, theta=0.0
% INFO    : Bus 41927	: V=1.0018163, theta=24.271673 -> V=1.0, theta=0.0
% INFO    : Bus 41928	: V=1.0002091, theta=21.366826 -> V=1.0, theta=0.0
% INFO    : Bus 41929	: V=1.001257, theta=22.062357 -> V=1.0, theta=0.0
% INFO    : Bus 41930	: V=0.9938967, theta=24.674707 -> V=1.0, theta=0.0
% INFO    : Bus 41931	: V=0.9952991, theta=24.623702 -> V=1.0, theta=0.0
% INFO    : Bus 41932	: V=1.0061764, theta=24.828583 -> V=1.0, theta=0.0
% INFO    : Bus 41933	: V=0.9944093, theta=24.638888 -> V=1.0, theta=0.0
% INFO    : Bus 41934	: V=1.0112158, theta=24.09222 -> V=1.0, theta=0.0
% INFO    : Bus 41935	: V=1.0081453, theta=22.698294 -> V=1.0, theta=0.0
% INFO    : Bus 41936	: V=1.0018919, theta=20.091994 -> V=1.0, theta=0.0
% INFO    : Bus 41937	: V=0.9895065, theta=-1.556712 -> V=1.0, theta=0.0
% INFO    : Bus 41938	: V=0.9902011, theta=-1.957023 -> V=1.0, theta=0.0
% INFO    : Bus 41939	: V=0.9926574, theta=8.249812 -> V=1.0, theta=0.0
% INFO    : Bus 41940	: V=0.9955525, theta=10.649853 -> V=1.0, theta=0.0
% INFO    : Bus 41941	: V=0.9976109, theta=8.135138 -> V=1.0, theta=0.0
% INFO    : Bus 41942	: V=0.9957036, theta=9.726701 -> V=1.0, theta=0.0
% INFO    : Bus 41943	: V=1.0030484, theta=7.029973 -> V=1.0, theta=0.0
% INFO    : Bus 41944	: V=1.0169603, theta=22.249153 -> V=1.0, theta=0.0
% INFO    : Bus 41945	: V=1.0155881, theta=22.314961 -> V=1.0, theta=0.0
% INFO    : Bus 41946	: V=1.0047908, theta=23.120414 -> V=1.0, theta=0.0
% INFO    : Bus 41947	: V=1.0158163, theta=22.821205 -> V=1.0, theta=0.0
% INFO    : Bus 41948	: V=1.0176276, theta=24.337675 -> V=1.0, theta=0.0
% INFO    : Bus 41949	: V=1.012894, theta=22.899891 -> V=1.0, theta=0.0
% INFO    : Bus 41950	: V=1.0145445, theta=22.556079 -> V=1.0, theta=0.0
% INFO    : Bus 41951	: V=1.0136669, theta=21.60969 -> V=1.0, theta=0.0
% INFO    : Bus 41952	: V=1.0185732, theta=21.411405 -> V=1.0, theta=0.0
% INFO    : Bus 41953	: V=1.0193369, theta=21.221467 -> V=1.0, theta=0.0
% INFO    : Bus 41954	: V=0.9820818, theta=-0.969305 -> V=1.0, theta=0.0
% INFO    : Bus 41955	: V=0.9818906, theta=-1.294647 -> V=1.0, theta=0.0
% INFO    : Bus 41956	: V=0.9807909, theta=-0.690601 -> V=1.0, theta=0.0
% INFO    : Bus 41957	: V=0.9878834, theta=18.201929 -> V=1.0, theta=0.0
% INFO    : Bus 41958	: V=0.9875387, theta=17.255382 -> V=1.0, theta=0.0
% INFO    : Bus 41959	: V=0.9893923, theta=18.393662 -> V=1.0, theta=0.0
% INFO    : Bus 41960	: V=1.0089996, theta=16.528122 -> V=1.0, theta=0.0
% INFO    : Bus 41961	: V=1.0189723, theta=15.307405 -> V=1.0, theta=0.0
% INFO    : Bus 41962	: V=1.0138318, theta=13.722106 -> V=1.0, theta=0.0
% INFO    : Bus 41963	: V=0.9849307, theta=16.88559 -> V=1.0, theta=0.0
% INFO    : Bus 41964	: V=0.9966998, theta=-2.538002 -> V=1.0, theta=0.0
% INFO    : Bus 41965	: V=0.9934675, theta=-2.322375 -> V=1.0, theta=0.0
% INFO    : Bus 41966	: V=0.9994454, theta=24.170526 -> V=1.0, theta=0.0
% INFO    : Bus 41967	: V=1.0059524, theta=23.466646 -> V=1.0, theta=0.0
% INFO    : Bus 41968	: V=1.0088774, theta=22.376338 -> V=1.0, theta=0.0
% INFO    : Bus 41969	: V=1.0056154, theta=30.939262 -> V=1.0, theta=0.0
% INFO    : Bus 41970	: V=0.9886494, theta=30.827493 -> V=1.0, theta=0.0
% INFO    : Bus 41971	: V=1.0026321, theta=30.054181 -> V=1.0, theta=0.0
% INFO    : Bus 41972	: V=1.0062082, theta=31.031994 -> V=1.0, theta=0.0
% INFO    : Bus 41973	: V=1.0083186, theta=30.480226 -> V=1.0, theta=0.0
% INFO    : Bus 41974	: V=1.0084608, theta=31.445078 -> V=1.0, theta=0.0
% INFO    : Bus 41975	: V=1.0019168, theta=30.005876 -> V=1.0, theta=0.0
% INFO    : Bus 41976	: V=0.9996305, theta=29.030589 -> V=1.0, theta=0.0
% INFO    : Bus 41977	: V=1.0011995, theta=29.20501 -> V=1.0, theta=0.0
% INFO    : Bus 41978	: V=0.9909862, theta=28.945559 -> V=1.0, theta=0.0
% INFO    : Bus 41979	: V=0.9841575, theta=28.597595 -> V=1.0, theta=0.0
% INFO    : Bus 41980	: V=0.9804757, theta=28.25007 -> V=1.0, theta=0.0
% INFO    : Bus 41981	: V=1.00279, theta=29.130426 -> V=1.0, theta=0.0
% INFO    : Bus 41982	: V=0.9776732, theta=16.876181 -> V=1.0, theta=0.0
% INFO    : Bus 41983	: V=0.9889339, theta=18.196443 -> V=1.0, theta=0.0
% INFO    : Bus 41984	: V=0.9887182, theta=17.866773 -> V=1.0, theta=0.0
% INFO    : Bus 41985	: V=0.9762723, theta=16.174124 -> V=1.0, theta=0.0
% INFO    : Bus 41986	: V=0.9779755, theta=15.811769 -> V=1.0, theta=0.0
% INFO    : Bus 41987	: V=0.9923474, theta=17.731946 -> V=1.0, theta=0.0
% INFO    : Bus 41988	: V=0.9913281, theta=16.953093 -> V=1.0, theta=0.0
% INFO    : Bus 41989	: V=0.9761696, theta=15.405077 -> V=1.0, theta=0.0
% INFO    : Bus 41990	: V=0.9847639, theta=15.253194 -> V=1.0, theta=0.0
% INFO    : Bus 41991	: V=1.0129069, theta=1.244784 -> V=1.0, theta=0.0
% INFO    : Bus 41992	: V=1.0108082, theta=0.748774 -> V=1.0, theta=0.0
% INFO    : Bus 41993	: V=1.0168632, theta=1.709233 -> V=1.0, theta=0.0
% INFO    : Bus 41994	: V=1.0126256, theta=0.943679 -> V=1.0, theta=0.0
% INFO    : Bus 41995	: V=1.0066739, theta=0.843811 -> V=1.0, theta=0.0
% INFO    : Bus 41996	: V=1.0113054, theta=0.62983 -> V=1.0, theta=0.0
% INFO    : Bus 41997	: V=1.0116821, theta=0.346698 -> V=1.0, theta=0.0
% INFO    : Bus 41998	: V=1.0117446, theta=0.043804 -> V=1.0, theta=0.0
% INFO    : Bus 41999	: V=1.0107512, theta=0.36745 -> V=1.0, theta=0.0
% INFO    : Bus 42000	: V=1.0099719, theta=0.197157 -> V=1.0, theta=0.0
% INFO    : Bus 42001	: V=1.0099706, theta=-0.160405 -> V=1.0, theta=0.0
% INFO    : Bus 42002	: V=1.0097079, theta=-0.044159 -> V=1.0, theta=0.0
% INFO    : Bus 42003	: V=1.006385, theta=0.38844 -> V=1.0, theta=0.0
% INFO    : Bus 42004	: V=1.0096409, theta=0.054781 -> V=1.0, theta=0.0
% INFO    : Bus 42005	: V=0.9963142, theta=5.399764 -> V=1.0, theta=0.0
% INFO    : Bus 42006	: V=0.9974866, theta=4.851537 -> V=1.0, theta=0.0
% INFO    : Bus 42007	: V=1.0005722, theta=4.830659 -> V=1.0, theta=0.0
% INFO    : Bus 42008	: V=1.0164659, theta=-0.105053 -> V=1.0, theta=0.0
% INFO    : Bus 42009	: V=1.0075624, theta=1.466203 -> V=1.0, theta=0.0
% INFO    : Bus 42010	: V=1.0110277, theta=-0.044271 -> V=1.0, theta=0.0
% INFO    : Bus 42011	: V=1.0032077, theta=-0.200126 -> V=1.0, theta=0.0
% INFO    : Bus 42012	: V=1.015768, theta=-0.112026 -> V=1.0, theta=0.0
% INFO    : Bus 42013	: V=0.9999097, theta=0.790133 -> V=1.0, theta=0.0
% INFO    : Bus 42014	: V=0.9993798, theta=1.131047 -> V=1.0, theta=0.0
% INFO    : Bus 42015	: V=1.0079058, theta=0.81749 -> V=1.0, theta=0.0
% INFO    : Bus 42016	: V=1.0018122, theta=0.454291 -> V=1.0, theta=0.0
% INFO    : Bus 42017	: V=1.0084708, theta=0.407498 -> V=1.0, theta=0.0
% INFO    : Bus 42018	: V=1.0176545, theta=-0.890218 -> V=1.0, theta=0.0
% INFO    : Bus 42019	: V=0.9985305, theta=5.333026 -> V=1.0, theta=0.0
% INFO    : Bus 42020	: V=0.999199, theta=3.885022 -> V=1.0, theta=0.0
% INFO    : Bus 42021	: V=1.0032337, theta=3.452465 -> V=1.0, theta=0.0
% INFO    : Bus 42022	: V=1.0087871, theta=3.881495 -> V=1.0, theta=0.0
% INFO    : Bus 42023	: V=0.9971699, theta=3.540454 -> V=1.0, theta=0.0
% INFO    : Bus 42024	: V=0.9948656, theta=3.743439 -> V=1.0, theta=0.0
% INFO    : Bus 42025	: V=1.003736, theta=34.121251 -> V=1.0, theta=0.0
% INFO    : Bus 42026	: V=0.999205, theta=34.527711 -> V=1.0, theta=0.0
% INFO    : Bus 42027	: V=1.0048946, theta=34.434105 -> V=1.0, theta=0.0
% INFO    : Bus 42028	: V=1.0042671, theta=34.182353 -> V=1.0, theta=0.0
% INFO    : Bus 42029	: V=1.0042417, theta=33.986397 -> V=1.0, theta=0.0
% INFO    : Bus 42030	: V=0.9909413, theta=33.314473 -> V=1.0, theta=0.0
% INFO    : Bus 42031	: V=1.0081004, theta=-2.442895 -> V=1.0, theta=0.0
% INFO    : Bus 42032	: V=1.0191376, theta=-1.697303 -> V=1.0, theta=0.0
% INFO    : Bus 42033	: V=1.0186944, theta=-2.487804 -> V=1.0, theta=0.0
% INFO    : Bus 42034	: V=1.0095568, theta=-2.405326 -> V=1.0, theta=0.0
% INFO    : Bus 42035	: V=0.9565086, theta=24.596764 -> V=1.0, theta=0.0
% INFO    : Bus 42036	: V=0.9596304, theta=24.788343 -> V=1.0, theta=0.0
% INFO    : Bus 42037	: V=0.9596981, theta=25.000046 -> V=1.0, theta=0.0
% INFO    : Bus 42038	: V=0.9570763, theta=24.576099 -> V=1.0, theta=0.0
% INFO    : Bus 42039	: V=0.9522832, theta=23.870004 -> V=1.0, theta=0.0
% INFO    : Bus 42040	: V=0.9526945, theta=23.857928 -> V=1.0, theta=0.0
% INFO    : Bus 42041	: V=0.953943, theta=24.148175 -> V=1.0, theta=0.0
% INFO    : Bus 42042	: V=0.9600043, theta=23.58102 -> V=1.0, theta=0.0
% INFO    : Bus 42043	: V=0.9600213, theta=23.559245 -> V=1.0, theta=0.0
% INFO    : Bus 42044	: V=0.960333, theta=23.467953 -> V=1.0, theta=0.0
% INFO    : Bus 42045	: V=0.9604294, theta=23.505645 -> V=1.0, theta=0.0
% INFO    : Bus 42046	: V=0.9729955, theta=25.810706 -> V=1.0, theta=0.0
% INFO    : Bus 42047	: V=0.9781563, theta=27.204984 -> V=1.0, theta=0.0
% INFO    : Bus 42048	: V=0.9897034, theta=26.834914 -> V=1.0, theta=0.0
% INFO    : Bus 42049	: V=0.9611098, theta=23.204303 -> V=1.0, theta=0.0
% INFO    : Bus 42050	: V=0.9621552, theta=23.016394 -> V=1.0, theta=0.0
% INFO    : Bus 42051	: V=0.954305, theta=23.241435 -> V=1.0, theta=0.0
% INFO    : Bus 42052	: V=0.9545564, theta=23.28302 -> V=1.0, theta=0.0
% INFO    : Bus 42053	: V=0.962204, theta=22.967314 -> V=1.0, theta=0.0
% INFO    : Bus 42054	: V=0.9619945, theta=23.009456 -> V=1.0, theta=0.0
% INFO    : Bus 42055	: V=0.962495, theta=22.922453 -> V=1.0, theta=0.0
% INFO    : Bus 42056	: V=0.9625224, theta=22.930885 -> V=1.0, theta=0.0
% INFO    : Bus 42057	: V=0.9626273, theta=22.941085 -> V=1.0, theta=0.0
% INFO    : Bus 42058	: V=0.9636735, theta=22.80177 -> V=1.0, theta=0.0
% INFO    : Bus 42059	: V=0.9576569, theta=23.488284 -> V=1.0, theta=0.0
% INFO    : Bus 42060	: V=0.9572429, theta=23.123797 -> V=1.0, theta=0.0
% INFO    : Bus 42061	: V=0.9644567, theta=22.984476 -> V=1.0, theta=0.0
% INFO    : Bus 42062	: V=0.9634122, theta=22.983225 -> V=1.0, theta=0.0
% INFO    : Bus 42063	: V=0.9559049, theta=23.385356 -> V=1.0, theta=0.0
% INFO    : Bus 42064	: V=0.9574526, theta=24.129728 -> V=1.0, theta=0.0
% INFO    : Bus 42065	: V=0.9630882, theta=22.119084 -> V=1.0, theta=0.0
% INFO    : Bus 42066	: V=0.9701187, theta=22.353056 -> V=1.0, theta=0.0
% INFO    : Bus 42067	: V=0.9647684, theta=22.122126 -> V=1.0, theta=0.0
% INFO    : Bus 42068	: V=0.9633871, theta=22.744215 -> V=1.0, theta=0.0
% INFO    : Bus 42069	: V=0.9668791, theta=23.006837 -> V=1.0, theta=0.0
% INFO    : Bus 42070	: V=0.9732791, theta=22.497004 -> V=1.0, theta=0.0
% INFO    : Bus 42071	: V=0.9706851, theta=23.060159 -> V=1.0, theta=0.0
% INFO    : Bus 42072	: V=0.9719495, theta=22.444048 -> V=1.0, theta=0.0
% INFO    : Bus 42073	: V=0.9620384, theta=23.084115 -> V=1.0, theta=0.0
% INFO    : Bus 42074	: V=0.9753244, theta=23.219216 -> V=1.0, theta=0.0
% INFO    : Bus 42075	: V=0.9904466, theta=24.97339 -> V=1.0, theta=0.0
% INFO    : Bus 42076	: V=0.9747047, theta=22.300227 -> V=1.0, theta=0.0
% INFO    : Bus 42077	: V=0.9747332, theta=22.553771 -> V=1.0, theta=0.0
% INFO    : Bus 42078	: V=0.9756068, theta=22.465583 -> V=1.0, theta=0.0
% INFO    : Bus 42079	: V=0.9771491, theta=22.49747 -> V=1.0, theta=0.0
% INFO    : Bus 42080	: V=0.9811749, theta=22.2573 -> V=1.0, theta=0.0
% INFO    : Bus 42081	: V=0.9807622, theta=22.461479 -> V=1.0, theta=0.0
% INFO    : Bus 42082	: V=0.9812859, theta=22.318521 -> V=1.0, theta=0.0
% INFO    : Bus 42083	: V=0.9809723, theta=22.738476 -> V=1.0, theta=0.0
% INFO    : Bus 42084	: V=0.9797554, theta=22.569154 -> V=1.0, theta=0.0
% INFO    : Bus 42085	: V=0.9827096, theta=22.178709 -> V=1.0, theta=0.0
% INFO    : Bus 42086	: V=0.9813607, theta=22.162368 -> V=1.0, theta=0.0
% INFO    : Bus 42087	: V=0.9826967, theta=22.462472 -> V=1.0, theta=0.0
% INFO    : Bus 42088	: V=0.982145, theta=22.494286 -> V=1.0, theta=0.0
% INFO    : Bus 42089	: V=0.9829608, theta=22.265563 -> V=1.0, theta=0.0
% INFO    : Bus 42090	: V=0.9751362, theta=22.434922 -> V=1.0, theta=0.0
% INFO    : Bus 42091	: V=0.9816696, theta=22.639715 -> V=1.0, theta=0.0
% INFO    : Bus 42092	: V=0.9793529, theta=22.440963 -> V=1.0, theta=0.0
% INFO    : Bus 42093	: V=0.9793787, theta=22.443878 -> V=1.0, theta=0.0
% INFO    : Bus 42094	: V=0.9826894, theta=22.567739 -> V=1.0, theta=0.0
% INFO    : Bus 42095	: V=0.9821046, theta=22.596679 -> V=1.0, theta=0.0
% INFO    : Bus 42096	: V=0.9833036, theta=22.54755 -> V=1.0, theta=0.0
% INFO    : Bus 42097	: V=0.9835782, theta=22.37196 -> V=1.0, theta=0.0
% INFO    : Bus 42098	: V=0.9831926, theta=22.315861 -> V=1.0, theta=0.0
% INFO    : Bus 42099	: V=0.983307, theta=22.323829 -> V=1.0, theta=0.0
% INFO    : Bus 42100	: V=0.9808466, theta=22.163411 -> V=1.0, theta=0.0
% INFO    : Bus 42101	: V=0.9832898, theta=22.339431 -> V=1.0, theta=0.0
% INFO    : Bus 42102	: V=0.9839102, theta=22.528899 -> V=1.0, theta=0.0
% INFO    : Bus 42103	: V=0.9846974, theta=22.605035 -> V=1.0, theta=0.0
% INFO    : Bus 42104	: V=1.0007186, theta=22.854677 -> V=1.0, theta=0.0
% INFO    : Bus 42105	: V=0.9836907, theta=22.398242 -> V=1.0, theta=0.0
% INFO    : Bus 42106	: V=0.9835323, theta=22.38103 -> V=1.0, theta=0.0
% INFO    : Bus 42107	: V=0.9833571, theta=22.35396 -> V=1.0, theta=0.0
% INFO    : Bus 42108	: V=0.9820459, theta=22.253177 -> V=1.0, theta=0.0
% INFO    : Bus 42109	: V=0.9901362, theta=22.174582 -> V=1.0, theta=0.0
% INFO    : Bus 42110	: V=0.9875002, theta=24.075278 -> V=1.0, theta=0.0
% INFO    : Bus 42111	: V=0.9754329, theta=22.323142 -> V=1.0, theta=0.0
% INFO    : Bus 42112	: V=0.9731149, theta=22.331979 -> V=1.0, theta=0.0
% INFO    : Bus 42113	: V=0.9618368, theta=23.049441 -> V=1.0, theta=0.0
% INFO    : Bus 42114	: V=0.9900503, theta=22.667301 -> V=1.0, theta=0.0
% INFO    : Bus 42115	: V=0.9774786, theta=22.841993 -> V=1.0, theta=0.0
% INFO    : Bus 42116	: V=0.9626454, theta=22.919633 -> V=1.0, theta=0.0
% INFO    : Bus 42117	: V=0.9932932, theta=18.65898 -> V=1.0, theta=0.0
% INFO    : Bus 42118	: V=0.9971389, theta=19.357075 -> V=1.0, theta=0.0
% INFO    : Bus 42119	: V=0.9922948, theta=18.656956 -> V=1.0, theta=0.0
% INFO    : Bus 42120	: V=1.0019046, theta=21.236679 -> V=1.0, theta=0.0
% INFO    : Bus 42121	: V=0.9907422, theta=18.782371 -> V=1.0, theta=0.0
% INFO    : Bus 42122	: V=0.9916743, theta=18.865188 -> V=1.0, theta=0.0
% INFO    : Bus 42123	: V=0.992435, theta=18.914104 -> V=1.0, theta=0.0
% INFO    : Bus 42124	: V=0.991122, theta=18.701881 -> V=1.0, theta=0.0
% INFO    : Bus 42125	: V=0.9796026, theta=18.305212 -> V=1.0, theta=0.0
% INFO    : Bus 42126	: V=0.987555, theta=18.413245 -> V=1.0, theta=0.0
% INFO    : Bus 42127	: V=0.9886577, theta=18.448888 -> V=1.0, theta=0.0
% INFO    : Bus 42128	: V=0.9764814, theta=18.534019 -> V=1.0, theta=0.0
% INFO    : Bus 42129	: V=0.9811791, theta=17.554434 -> V=1.0, theta=0.0
% INFO    : Bus 42130	: V=0.9834077, theta=17.924293 -> V=1.0, theta=0.0
% INFO    : Bus 42131	: V=0.9852983, theta=18.133976 -> V=1.0, theta=0.0
% INFO    : Bus 42132	: V=0.9870248, theta=18.332924 -> V=1.0, theta=0.0
% INFO    : Bus 42133	: V=0.9874089, theta=18.401138 -> V=1.0, theta=0.0
% INFO    : Bus 42134	: V=0.987647, theta=18.453649 -> V=1.0, theta=0.0
% INFO    : Bus 42135	: V=0.987243, theta=18.433481 -> V=1.0, theta=0.0
% INFO    : Bus 42136	: V=0.9871865, theta=18.440834 -> V=1.0, theta=0.0
% INFO    : Bus 42137	: V=0.983098, theta=18.31633 -> V=1.0, theta=0.0
% INFO    : Bus 42138	: V=0.9825853, theta=18.296619 -> V=1.0, theta=0.0
% INFO    : Bus 42139	: V=0.9816277, theta=18.316159 -> V=1.0, theta=0.0
% INFO    : Bus 42140	: V=0.9873758, theta=18.460043 -> V=1.0, theta=0.0
% INFO    : Bus 42141	: V=0.9876654, theta=18.478731 -> V=1.0, theta=0.0
% INFO    : Bus 42142	: V=0.9873148, theta=18.436938 -> V=1.0, theta=0.0
% INFO    : Bus 42143	: V=0.9842892, theta=18.302996 -> V=1.0, theta=0.0
% INFO    : Bus 42144	: V=0.9877659, theta=18.420919 -> V=1.0, theta=0.0
% INFO    : Bus 42145	: V=0.9905799, theta=18.646582 -> V=1.0, theta=0.0
% INFO    : Bus 42146	: V=1.0026711, theta=22.174852 -> V=1.0, theta=0.0
% INFO    : Bus 42147	: V=0.9934583, theta=22.473643 -> V=1.0, theta=0.0
% INFO    : Bus 42148	: V=0.9833298, theta=22.258238 -> V=1.0, theta=0.0
% INFO    : Bus 42149	: V=0.9833544, theta=22.256882 -> V=1.0, theta=0.0
% INFO    : Bus 42150	: V=0.9828481, theta=22.331226 -> V=1.0, theta=0.0
% INFO    : Bus 42151	: V=0.9836799, theta=22.245423 -> V=1.0, theta=0.0
% INFO    : Bus 42152	: V=1.0028293, theta=23.602004 -> V=1.0, theta=0.0
% INFO    : Bus 42153	: V=1.0046213, theta=24.034237 -> V=1.0, theta=0.0
% INFO    : Bus 42154	: V=0.9974955, theta=23.415571 -> V=1.0, theta=0.0
% INFO    : Bus 42155	: V=1.0119196, theta=22.358909 -> V=1.0, theta=0.0
% INFO    : Bus 42156	: V=0.995596, theta=27.893113 -> V=1.0, theta=0.0
% INFO    : Bus 42157	: V=0.9969717, theta=27.41569 -> V=1.0, theta=0.0
% INFO    : Bus 42158	: V=0.9952774, theta=26.967859 -> V=1.0, theta=0.0
% INFO    : Bus 42159	: V=0.9997111, theta=27.198782 -> V=1.0, theta=0.0
% INFO    : Bus 42160	: V=0.9968325, theta=26.832497 -> V=1.0, theta=0.0
% INFO    : Bus 42161	: V=0.9998689, theta=27.051164 -> V=1.0, theta=0.0
% INFO    : Bus 42162	: V=0.9965291, theta=26.884183 -> V=1.0, theta=0.0
% INFO    : Bus 42163	: V=0.9997495, theta=27.00656 -> V=1.0, theta=0.0
% INFO    : Bus 42164	: V=1.0141549, theta=27.753982 -> V=1.0, theta=0.0
% INFO    : Bus 42165	: V=0.9968028, theta=26.775214 -> V=1.0, theta=0.0
% INFO    : Bus 42166	: V=0.9999482, theta=26.909734 -> V=1.0, theta=0.0
% INFO    : Bus 42167	: V=0.9936702, theta=26.516127 -> V=1.0, theta=0.0
% INFO    : Bus 42168	: V=0.9989959, theta=26.493778 -> V=1.0, theta=0.0
% INFO    : Bus 42169	: V=0.9991813, theta=25.78634 -> V=1.0, theta=0.0
% INFO    : Bus 42170	: V=0.999103, theta=25.274864 -> V=1.0, theta=0.0
% INFO    : Bus 42171	: V=0.9889536, theta=25.771202 -> V=1.0, theta=0.0
% INFO    : Bus 42172	: V=0.9967405, theta=26.427849 -> V=1.0, theta=0.0
% INFO    : Bus 42173	: V=0.9972324, theta=26.407673 -> V=1.0, theta=0.0
% INFO    : Bus 42174	: V=0.9959415, theta=26.232973 -> V=1.0, theta=0.0
% INFO    : Bus 42175	: V=0.9946622, theta=26.062775 -> V=1.0, theta=0.0
% INFO    : Bus 42176	: V=0.9936234, theta=25.950173 -> V=1.0, theta=0.0
% INFO    : Bus 42177	: V=0.9940632, theta=26.171556 -> V=1.0, theta=0.0
% INFO    : Bus 42178	: V=0.993194, theta=25.843653 -> V=1.0, theta=0.0
% INFO    : Bus 42179	: V=0.9932199, theta=25.88285 -> V=1.0, theta=0.0
% INFO    : Bus 42180	: V=0.9928109, theta=25.817216 -> V=1.0, theta=0.0
% INFO    : Bus 42181	: V=0.9860107, theta=27.457803 -> V=1.0, theta=0.0
% INFO    : Bus 42182	: V=0.9883847, theta=27.177254 -> V=1.0, theta=0.0
% INFO    : Bus 42183	: V=0.981907, theta=27.182436 -> V=1.0, theta=0.0
% INFO    : Bus 42184	: V=0.9861694, theta=26.840267 -> V=1.0, theta=0.0
% INFO    : Bus 42185	: V=0.9871178, theta=26.982825 -> V=1.0, theta=0.0
% INFO    : Bus 42186	: V=0.985676, theta=25.837716 -> V=1.0, theta=0.0
% INFO    : Bus 42187	: V=0.9847167, theta=25.880666 -> V=1.0, theta=0.0
% INFO    : Bus 42188	: V=0.9803829, theta=26.382125 -> V=1.0, theta=0.0
% INFO    : Bus 42189	: V=0.9790634, theta=26.762554 -> V=1.0, theta=0.0
% INFO    : Bus 42190	: V=0.9808669, theta=26.228588 -> V=1.0, theta=0.0
% INFO    : Bus 42191	: V=0.9769327, theta=25.983177 -> V=1.0, theta=0.0
% INFO    : Bus 42192	: V=0.9833444, theta=25.81123 -> V=1.0, theta=0.0
% INFO    : Bus 42193	: V=0.9850634, theta=25.794068 -> V=1.0, theta=0.0
% INFO    : Bus 42194	: V=0.9824166, theta=25.766386 -> V=1.0, theta=0.0
% INFO    : Bus 42195	: V=0.9835312, theta=26.348366 -> V=1.0, theta=0.0
% INFO    : Bus 42196	: V=0.9822668, theta=25.772125 -> V=1.0, theta=0.0
% INFO    : Bus 42197	: V=0.9847183, theta=26.529083 -> V=1.0, theta=0.0
% INFO    : Bus 42198	: V=0.9821545, theta=25.770693 -> V=1.0, theta=0.0
% INFO    : Bus 42199	: V=0.9818531, theta=25.77448 -> V=1.0, theta=0.0
% INFO    : Bus 42200	: V=0.9799329, theta=25.598161 -> V=1.0, theta=0.0
% INFO    : Bus 42201	: V=0.9820903, theta=25.596298 -> V=1.0, theta=0.0
% INFO    : Bus 42202	: V=0.979301, theta=25.737477 -> V=1.0, theta=0.0
% INFO    : Bus 42203	: V=0.9810129, theta=25.689748 -> V=1.0, theta=0.0
% INFO    : Bus 42204	: V=0.9805264, theta=25.893119 -> V=1.0, theta=0.0
% INFO    : Bus 42205	: V=0.9808826, theta=25.818466 -> V=1.0, theta=0.0
% INFO    : Bus 42206	: V=0.9806547, theta=26.07535 -> V=1.0, theta=0.0
% INFO    : Bus 42207	: V=0.9824601, theta=26.175021 -> V=1.0, theta=0.0
% INFO    : Bus 42208	: V=0.9822304, theta=26.140382 -> V=1.0, theta=0.0
% INFO    : Bus 42209	: V=0.9785712, theta=25.821971 -> V=1.0, theta=0.0
% INFO    : Bus 42210	: V=0.981915, theta=26.037513 -> V=1.0, theta=0.0
% INFO    : Bus 42211	: V=0.9815285, theta=25.89553 -> V=1.0, theta=0.0
% INFO    : Bus 42212	: V=0.9865357, theta=24.800502 -> V=1.0, theta=0.0
% INFO    : Bus 42213	: V=0.9876669, theta=25.434928 -> V=1.0, theta=0.0
% INFO    : Bus 42214	: V=0.9877413, theta=25.37197 -> V=1.0, theta=0.0
% INFO    : Bus 42215	: V=0.9903113, theta=25.46737 -> V=1.0, theta=0.0
% INFO    : Bus 42216	: V=0.9864118, theta=25.088703 -> V=1.0, theta=0.0
% INFO    : Bus 42217	: V=0.9854248, theta=24.960533 -> V=1.0, theta=0.0
% INFO    : Bus 42218	: V=0.9870938, theta=24.875671 -> V=1.0, theta=0.0
% INFO    : Bus 42219	: V=0.9837283, theta=24.781817 -> V=1.0, theta=0.0
% INFO    : Bus 42220	: V=0.9874584, theta=25.556894 -> V=1.0, theta=0.0
% INFO    : Bus 42221	: V=0.9792604, theta=25.235168 -> V=1.0, theta=0.0
% INFO    : Bus 42222	: V=0.9845862, theta=24.99162 -> V=1.0, theta=0.0
% INFO    : Bus 42223	: V=0.9863761, theta=25.349987 -> V=1.0, theta=0.0
% INFO    : Bus 42224	: V=0.985211, theta=25.120342 -> V=1.0, theta=0.0
% INFO    : Bus 42225	: V=0.9858142, theta=25.240591 -> V=1.0, theta=0.0
% INFO    : Bus 42226	: V=0.9919351, theta=25.581593 -> V=1.0, theta=0.0
% INFO    : Bus 42227	: V=0.9898133, theta=25.177503 -> V=1.0, theta=0.0
% INFO    : Bus 42228	: V=0.9898562, theta=25.381304 -> V=1.0, theta=0.0
% INFO    : Bus 42229	: V=0.9878214, theta=24.971652 -> V=1.0, theta=0.0
% INFO    : Bus 42230	: V=0.9896078, theta=25.41806 -> V=1.0, theta=0.0
% INFO    : Bus 42231	: V=0.9876868, theta=25.142629 -> V=1.0, theta=0.0
% INFO    : Bus 42232	: V=0.9878906, theta=24.958811 -> V=1.0, theta=0.0
% INFO    : Bus 42233	: V=0.9892236, theta=25.09497 -> V=1.0, theta=0.0
% INFO    : Bus 42234	: V=0.9911909, theta=25.444941 -> V=1.0, theta=0.0
% INFO    : Bus 42235	: V=0.9877708, theta=24.857398 -> V=1.0, theta=0.0
% INFO    : Bus 42236	: V=0.9886952, theta=25.020207 -> V=1.0, theta=0.0
% INFO    : Bus 42237	: V=0.9881994, theta=24.918559 -> V=1.0, theta=0.0
% INFO    : Bus 42238	: V=0.986016, theta=24.625769 -> V=1.0, theta=0.0
% INFO    : Bus 42239	: V=0.9869098, theta=24.768247 -> V=1.0, theta=0.0
% INFO    : Bus 42240	: V=0.9874361, theta=25.012516 -> V=1.0, theta=0.0
% INFO    : Bus 42241	: V=0.9872717, theta=24.934385 -> V=1.0, theta=0.0
% INFO    : Bus 42242	: V=0.9871291, theta=24.856614 -> V=1.0, theta=0.0
% INFO    : Bus 42243	: V=0.9876464, theta=24.837921 -> V=1.0, theta=0.0
% INFO    : Bus 42244	: V=0.9858777, theta=24.609963 -> V=1.0, theta=0.0
% INFO    : Bus 42245	: V=0.9869631, theta=24.716352 -> V=1.0, theta=0.0
% INFO    : Bus 42246	: V=0.9865047, theta=24.650505 -> V=1.0, theta=0.0
% INFO    : Bus 42247	: V=0.9857231, theta=24.510575 -> V=1.0, theta=0.0
% INFO    : Bus 42248	: V=0.9828132, theta=24.005079 -> V=1.0, theta=0.0
% INFO    : Bus 42249	: V=0.9846804, theta=24.360439 -> V=1.0, theta=0.0
% INFO    : Bus 42250	: V=0.9887968, theta=24.417945 -> V=1.0, theta=0.0
% INFO    : Bus 42251	: V=0.9855576, theta=24.47275 -> V=1.0, theta=0.0
% INFO    : Bus 42252	: V=0.981434, theta=23.878518 -> V=1.0, theta=0.0
% INFO    : Bus 42253	: V=0.98309, theta=24.141418 -> V=1.0, theta=0.0
% INFO    : Bus 42254	: V=0.9808074, theta=23.834882 -> V=1.0, theta=0.0
% INFO    : Bus 42255	: V=0.9786485, theta=23.452081 -> V=1.0, theta=0.0
% INFO    : Bus 42256	: V=0.982378, theta=24.474483 -> V=1.0, theta=0.0
% INFO    : Bus 42257	: V=0.9794395, theta=24.321147 -> V=1.0, theta=0.0
% INFO    : Bus 42258	: V=0.9787085, theta=24.214344 -> V=1.0, theta=0.0
% INFO    : Bus 42259	: V=0.9814124, theta=24.268043 -> V=1.0, theta=0.0
% INFO    : Bus 42260	: V=0.9829926, theta=24.227638 -> V=1.0, theta=0.0
% INFO    : Bus 42261	: V=0.9801675, theta=24.001771 -> V=1.0, theta=0.0
% INFO    : Bus 42262	: V=0.9739605, theta=23.280843 -> V=1.0, theta=0.0
% INFO    : Bus 42263	: V=0.9787709, theta=24.229424 -> V=1.0, theta=0.0
% INFO    : Bus 42264	: V=0.9749961, theta=23.465581 -> V=1.0, theta=0.0
% INFO    : Bus 42265	: V=0.9765218, theta=24.106115 -> V=1.0, theta=0.0
% INFO    : Bus 42266	: V=0.9753991, theta=24.007289 -> V=1.0, theta=0.0
% INFO    : Bus 42267	: V=0.9758634, theta=25.262753 -> V=1.0, theta=0.0
% INFO    : Bus 42268	: V=0.9733209, theta=24.42231 -> V=1.0, theta=0.0
% INFO    : Bus 42269	: V=0.977671, theta=24.218918 -> V=1.0, theta=0.0
% INFO    : Bus 42270	: V=0.9695181, theta=24.145138 -> V=1.0, theta=0.0
% INFO    : Bus 42271	: V=0.969907, theta=23.721696 -> V=1.0, theta=0.0
% INFO    : Bus 42272	: V=0.9706963, theta=26.004928 -> V=1.0, theta=0.0
% INFO    : Bus 42273	: V=0.9628972, theta=24.994558 -> V=1.0, theta=0.0
% INFO    : Bus 42274	: V=0.971578, theta=26.014618 -> V=1.0, theta=0.0
% INFO    : Bus 42275	: V=0.9625431, theta=24.62615 -> V=1.0, theta=0.0
% INFO    : Bus 42276	: V=0.9614687, theta=24.727288 -> V=1.0, theta=0.0
% INFO    : Bus 42277	: V=0.9617822, theta=24.647368 -> V=1.0, theta=0.0
% INFO    : Bus 42278	: V=0.9595511, theta=24.408841 -> V=1.0, theta=0.0
% INFO    : Bus 42279	: V=0.9581617, theta=24.037423 -> V=1.0, theta=0.0
% INFO    : Bus 42280	: V=0.9583537, theta=24.109127 -> V=1.0, theta=0.0
% INFO    : Bus 42281	: V=0.9679988, theta=23.790923 -> V=1.0, theta=0.0
% INFO    : Bus 42282	: V=0.9596627, theta=23.251536 -> V=1.0, theta=0.0
% INFO    : Bus 42283	: V=0.9647468, theta=24.271689 -> V=1.0, theta=0.0
% INFO    : Bus 42284	: V=0.9769512, theta=23.861568 -> V=1.0, theta=0.0
% INFO    : Bus 42285	: V=0.9600339, theta=23.895046 -> V=1.0, theta=0.0
% INFO    : Bus 42286	: V=0.9596268, theta=23.734698 -> V=1.0, theta=0.0
% INFO    : Bus 42287	: V=0.9583756, theta=23.959385 -> V=1.0, theta=0.0
% INFO    : Bus 42288	: V=0.9596226, theta=23.837275 -> V=1.0, theta=0.0
% INFO    : Bus 42289	: V=0.970785, theta=22.672892 -> V=1.0, theta=0.0
% INFO    : Bus 42290	: V=0.9748974, theta=23.945346 -> V=1.0, theta=0.0
% INFO    : Bus 42291	: V=0.9706917, theta=23.26025 -> V=1.0, theta=0.0
% INFO    : Bus 42292	: V=0.9693062, theta=23.066703 -> V=1.0, theta=0.0
% INFO    : Bus 42293	: V=0.9717978, theta=23.053408 -> V=1.0, theta=0.0
% INFO    : Bus 42294	: V=0.9670569, theta=22.506706 -> V=1.0, theta=0.0
% INFO    : Bus 42295	: V=0.961768, theta=22.923239 -> V=1.0, theta=0.0
% INFO    : Bus 42296	: V=0.9633308, theta=22.702652 -> V=1.0, theta=0.0
% INFO    : Bus 42297	: V=0.96525, theta=22.675485 -> V=1.0, theta=0.0
% INFO    : Bus 42298	: V=0.9654033, theta=22.67944 -> V=1.0, theta=0.0
% INFO    : Bus 42299	: V=0.9644534, theta=22.451277 -> V=1.0, theta=0.0
% INFO    : Bus 42300	: V=0.9647308, theta=22.462323 -> V=1.0, theta=0.0
% INFO    : Bus 42301	: V=0.9673529, theta=22.51413 -> V=1.0, theta=0.0
% INFO    : Bus 42302	: V=0.9677453, theta=22.218732 -> V=1.0, theta=0.0
% INFO    : Bus 42303	: V=0.9745941, theta=22.908381 -> V=1.0, theta=0.0
% INFO    : Bus 42304	: V=0.9762056, theta=22.986395 -> V=1.0, theta=0.0
% INFO    : Bus 42305	: V=0.9727186, theta=22.3477 -> V=1.0, theta=0.0
% INFO    : Bus 42306	: V=0.9716022, theta=22.433134 -> V=1.0, theta=0.0
% INFO    : Bus 42307	: V=0.9693159, theta=22.129156 -> V=1.0, theta=0.0
% INFO    : Bus 42308	: V=0.9714851, theta=22.132922 -> V=1.0, theta=0.0
% INFO    : Bus 42309	: V=0.9689886, theta=21.98215 -> V=1.0, theta=0.0
% INFO    : Bus 42310	: V=0.9698534, theta=22.004292 -> V=1.0, theta=0.0
% INFO    : Bus 42311	: V=0.9792931, theta=23.624006 -> V=1.0, theta=0.0
% INFO    : Bus 42312	: V=0.9770841, theta=23.341349 -> V=1.0, theta=0.0
% INFO    : Bus 42313	: V=0.9778255, theta=23.435895 -> V=1.0, theta=0.0
% INFO    : Bus 42314	: V=0.9764246, theta=23.271265 -> V=1.0, theta=0.0
% INFO    : Bus 42315	: V=0.9743031, theta=22.510222 -> V=1.0, theta=0.0
% INFO    : Bus 42316	: V=0.970896, theta=22.084748 -> V=1.0, theta=0.0
% INFO    : Bus 42317	: V=0.9681169, theta=21.610982 -> V=1.0, theta=0.0
% INFO    : Bus 42318	: V=0.9692342, theta=21.842925 -> V=1.0, theta=0.0
% INFO    : Bus 42319	: V=0.969474, theta=21.899045 -> V=1.0, theta=0.0
% INFO    : Bus 42320	: V=0.9696706, theta=21.999348 -> V=1.0, theta=0.0
% INFO    : Bus 42321	: V=0.9921724, theta=26.157301 -> V=1.0, theta=0.0
% INFO    : Bus 42322	: V=0.9878684, theta=24.967088 -> V=1.0, theta=0.0
% INFO    : Bus 42323	: V=0.9771913, theta=23.546252 -> V=1.0, theta=0.0
% INFO    : Bus 42324	: V=1.0068504, theta=24.679729 -> V=1.0, theta=0.0
% INFO    : Bus 42325	: V=0.9995559, theta=25.049068 -> V=1.0, theta=0.0
% INFO    : Bus 42326	: V=1.0074833, theta=26.620592 -> V=1.0, theta=0.0
% INFO    : Bus 42327	: V=1.0062913, theta=27.371659 -> V=1.0, theta=0.0
% INFO    : Bus 42328	: V=1.0059603, theta=27.273601 -> V=1.0, theta=0.0
% INFO    : Bus 42329	: V=1.0080567, theta=27.087694 -> V=1.0, theta=0.0
% INFO    : Bus 42330	: V=1.0049722, theta=26.435031 -> V=1.0, theta=0.0
% INFO    : Bus 42331	: V=1.0124621, theta=24.872531 -> V=1.0, theta=0.0
% INFO    : Bus 42332	: V=1.0141803, theta=24.65918 -> V=1.0, theta=0.0
% INFO    : Bus 42333	: V=1.0048917, theta=24.123751 -> V=1.0, theta=0.0
% INFO    : Bus 42334	: V=1.0074733, theta=26.084751 -> V=1.0, theta=0.0
% INFO    : Bus 42335	: V=1.0082995, theta=26.033071 -> V=1.0, theta=0.0
% INFO    : Bus 42336	: V=1.005281, theta=25.547652 -> V=1.0, theta=0.0
% INFO    : Bus 42337	: V=1.0097321, theta=26.911494 -> V=1.0, theta=0.0
% INFO    : Bus 42338	: V=1.0095857, theta=26.923739 -> V=1.0, theta=0.0
% INFO    : Bus 42339	: V=1.010202, theta=26.95178 -> V=1.0, theta=0.0
% INFO    : Bus 42340	: V=1.0137796, theta=26.922458 -> V=1.0, theta=0.0
% INFO    : Bus 42341	: V=1.0105921, theta=26.940566 -> V=1.0, theta=0.0
% INFO    : Bus 42342	: V=1.0156992, theta=26.872477 -> V=1.0, theta=0.0
% INFO    : Bus 42343	: V=1.0114395, theta=25.953253 -> V=1.0, theta=0.0
% INFO    : Bus 42344	: V=1.0092193, theta=26.005558 -> V=1.0, theta=0.0
% INFO    : Bus 42345	: V=1.0189547, theta=24.650331 -> V=1.0, theta=0.0
% INFO    : Bus 42346	: V=1.0043101, theta=24.204797 -> V=1.0, theta=0.0
% INFO    : Bus 42347	: V=1.0104366, theta=24.183748 -> V=1.0, theta=0.0
% INFO    : Bus 42348	: V=1.0119746, theta=26.221995 -> V=1.0, theta=0.0
% INFO    : Bus 42349	: V=1.006252, theta=24.565282 -> V=1.0, theta=0.0
% INFO    : Bus 42350	: V=1.0037843, theta=24.216393 -> V=1.0, theta=0.0
% INFO    : Bus 42351	: V=1.0038905, theta=24.222213 -> V=1.0, theta=0.0
% INFO    : Bus 42352	: V=0.9762559, theta=0.905843 -> V=1.0, theta=0.0
% INFO    : Bus 42353	: V=0.978646, theta=0.579741 -> V=1.0, theta=0.0
% INFO    : Bus 42354	: V=0.9784022, theta=0.691509 -> V=1.0, theta=0.0
% INFO    : Bus 42355	: V=0.9768477, theta=0.687477 -> V=1.0, theta=0.0
% INFO    : Bus 42356	: V=0.9783991, theta=0.807205 -> V=1.0, theta=0.0
% INFO    : Bus 42357	: V=1.007757, theta=28.071252 -> V=1.0, theta=0.0
% INFO    : Bus 42358	: V=1.0194253, theta=32.316405 -> V=1.0, theta=0.0
% INFO    : Bus 42359	: V=1.0126959, theta=32.171693 -> V=1.0, theta=0.0
% INFO    : Bus 42360	: V=1.0119413, theta=32.287717 -> V=1.0, theta=0.0
% INFO    : Bus 42361	: V=1.0109944, theta=32.209375 -> V=1.0, theta=0.0
% INFO    : Bus 42362	: V=1.0119051, theta=32.179762 -> V=1.0, theta=0.0
% INFO    : Bus 42363	: V=1.0089259, theta=31.516179 -> V=1.0, theta=0.0
% INFO    : Bus 42364	: V=1.0115356, theta=29.522411 -> V=1.0, theta=0.0
% INFO    : Bus 42365	: V=1.0106348, theta=27.69574 -> V=1.0, theta=0.0
% INFO    : Bus 42366	: V=1.0196663, theta=20.919039 -> V=1.0, theta=0.0
% INFO    : Bus 42367	: V=1.0108756, theta=20.112619 -> V=1.0, theta=0.0
% INFO    : Bus 42368	: V=1.0126983, theta=23.15029 -> V=1.0, theta=0.0
% INFO    : Bus 42369	: V=1.0129618, theta=21.55842 -> V=1.0, theta=0.0
% INFO    : Bus 42370	: V=1.0151696, theta=19.652363 -> V=1.0, theta=0.0
% INFO    : Bus 42371	: V=1.0135528, theta=18.93359 -> V=1.0, theta=0.0
% INFO    : Bus 42372	: V=1.0140496, theta=19.004804 -> V=1.0, theta=0.0
% INFO    : Bus 42373	: V=1.0146571, theta=19.09108 -> V=1.0, theta=0.0
% INFO    : Bus 42374	: V=1.0062651, theta=19.142217 -> V=1.0, theta=0.0
% INFO    : Bus 42375	: V=1.0096182, theta=18.903764 -> V=1.0, theta=0.0
% INFO    : Bus 42376	: V=1.0026662, theta=20.121513 -> V=1.0, theta=0.0
% INFO    : Bus 42377	: V=0.9923478, theta=20.003367 -> V=1.0, theta=0.0
% INFO    : Bus 42378	: V=1.0000561, theta=19.856577 -> V=1.0, theta=0.0
% INFO    : Bus 42379	: V=1.0001911, theta=19.920504 -> V=1.0, theta=0.0
% INFO    : Bus 42380	: V=0.9943668, theta=19.731745 -> V=1.0, theta=0.0
% INFO    : Bus 42381	: V=1.0004258, theta=19.815661 -> V=1.0, theta=0.0
% INFO    : Bus 42382	: V=1.004676, theta=19.669093 -> V=1.0, theta=0.0
% INFO    : Bus 42383	: V=1.0084558, theta=17.962294 -> V=1.0, theta=0.0
% INFO    : Bus 42384	: V=0.991125, theta=22.513904 -> V=1.0, theta=0.0
% INFO    : Bus 42385	: V=0.9961218, theta=21.471511 -> V=1.0, theta=0.0
% INFO    : Bus 42386	: V=0.9851875, theta=19.898863 -> V=1.0, theta=0.0
% INFO    : Bus 42387	: V=0.9884773, theta=20.772926 -> V=1.0, theta=0.0
% INFO    : Bus 42388	: V=0.9886081, theta=20.864659 -> V=1.0, theta=0.0
% INFO    : Bus 42389	: V=0.9891664, theta=20.928443 -> V=1.0, theta=0.0
% INFO    : Bus 42390	: V=0.988736, theta=20.389708 -> V=1.0, theta=0.0
% INFO    : Bus 42391	: V=0.9876631, theta=20.010818 -> V=1.0, theta=0.0
% INFO    : Bus 42392	: V=0.9922517, theta=20.498413 -> V=1.0, theta=0.0
% INFO    : Bus 42393	: V=0.9876897, theta=17.923921 -> V=1.0, theta=0.0
% INFO    : Bus 42394	: V=0.979651, theta=29.367274 -> V=1.0, theta=0.0
% INFO    : Bus 42395	: V=0.9825369, theta=27.365406 -> V=1.0, theta=0.0
% INFO    : Bus 42396	: V=0.977167, theta=30.313853 -> V=1.0, theta=0.0
% INFO    : Bus 42397	: V=0.9874794, theta=31.69881 -> V=1.0, theta=0.0
% INFO    : Bus 42398	: V=0.9878707, theta=31.628517 -> V=1.0, theta=0.0
% INFO    : Bus 42399	: V=0.9718849, theta=28.828659 -> V=1.0, theta=0.0
% INFO    : Bus 42400	: V=0.964993, theta=28.121507 -> V=1.0, theta=0.0
% INFO    : Bus 42401	: V=0.9711601, theta=27.985255 -> V=1.0, theta=0.0
% INFO    : Bus 42402	: V=0.9763974, theta=27.699014 -> V=1.0, theta=0.0
% INFO    : Bus 42403	: V=0.9727297, theta=27.551481 -> V=1.0, theta=0.0
% INFO    : Bus 42404	: V=0.9703889, theta=27.142289 -> V=1.0, theta=0.0
% INFO    : Bus 42405	: V=0.9776539, theta=27.589416 -> V=1.0, theta=0.0
% INFO    : Bus 42406	: V=0.9782069, theta=27.141627 -> V=1.0, theta=0.0
% INFO    : Bus 42407	: V=0.9752505, theta=27.502382 -> V=1.0, theta=0.0
% INFO    : Bus 42408	: V=0.9825169, theta=26.827424 -> V=1.0, theta=0.0
% INFO    : Bus 42409	: V=0.9797213, theta=28.313056 -> V=1.0, theta=0.0
% INFO    : Bus 42410	: V=0.9738237, theta=27.068078 -> V=1.0, theta=0.0
% INFO    : Bus 42411	: V=0.9723089, theta=26.881662 -> V=1.0, theta=0.0
% INFO    : Bus 42412	: V=0.9710149, theta=26.68665 -> V=1.0, theta=0.0
% INFO    : Bus 42413	: V=0.9660131, theta=25.642384 -> V=1.0, theta=0.0
% INFO    : Bus 42414	: V=0.9707441, theta=26.601764 -> V=1.0, theta=0.0
% INFO    : Bus 42415	: V=0.9641985, theta=25.336709 -> V=1.0, theta=0.0
% INFO    : Bus 42416	: V=0.9954195, theta=30.943665 -> V=1.0, theta=0.0
% INFO    : Bus 42417	: V=0.9657581, theta=28.118044 -> V=1.0, theta=0.0
% INFO    : Bus 42418	: V=0.9634943, theta=28.116868 -> V=1.0, theta=0.0
% INFO    : Bus 42419	: V=0.9643131, theta=28.114607 -> V=1.0, theta=0.0
% INFO    : Bus 42420	: V=0.9802516, theta=30.095661 -> V=1.0, theta=0.0
% INFO    : Bus 42421	: V=0.9919852, theta=29.741055 -> V=1.0, theta=0.0
% INFO    : Bus 42422	: V=0.9762256, theta=27.536185 -> V=1.0, theta=0.0
% INFO    : Bus 42423	: V=0.9762901, theta=27.318917 -> V=1.0, theta=0.0
% INFO    : Bus 42424	: V=0.9937127, theta=30.671306 -> V=1.0, theta=0.0
% INFO    : Bus 42425	: V=0.9621005, theta=25.932797 -> V=1.0, theta=0.0
% INFO    : Bus 42426	: V=0.9779755, theta=27.797734 -> V=1.0, theta=0.0
% INFO    : Bus 42427	: V=0.9669508, theta=26.576371 -> V=1.0, theta=0.0
% INFO    : Bus 42428	: V=0.9743708, theta=26.891347 -> V=1.0, theta=0.0
% INFO    : Bus 42429	: V=0.9724619, theta=26.436698 -> V=1.0, theta=0.0
% INFO    : Bus 42430	: V=0.9620151, theta=25.786533 -> V=1.0, theta=0.0
% INFO    : Bus 42431	: V=0.9612483, theta=25.607979 -> V=1.0, theta=0.0
% INFO    : Bus 42432	: V=0.9628, theta=25.908444 -> V=1.0, theta=0.0
% INFO    : Bus 42433	: V=0.9622595, theta=25.924455 -> V=1.0, theta=0.0
% INFO    : Bus 42434	: V=0.9619303, theta=25.93466 -> V=1.0, theta=0.0
% INFO    : Bus 42435	: V=0.9639337, theta=26.096256 -> V=1.0, theta=0.0
% INFO    : Bus 42436	: V=0.9701716, theta=26.222356 -> V=1.0, theta=0.0
% INFO    : Bus 42437	: V=0.9689679, theta=26.092787 -> V=1.0, theta=0.0
% INFO    : Bus 42438	: V=0.9625364, theta=26.050352 -> V=1.0, theta=0.0
% INFO    : Bus 42439	: V=0.9627764, theta=24.906413 -> V=1.0, theta=0.0
% INFO    : Bus 42440	: V=0.9594674, theta=25.314053 -> V=1.0, theta=0.0
% INFO    : Bus 42441	: V=0.9688003, theta=25.687419 -> V=1.0, theta=0.0
% INFO    : Bus 42442	: V=0.9636025, theta=24.735391 -> V=1.0, theta=0.0
% INFO    : Bus 42443	: V=0.9577122, theta=24.986045 -> V=1.0, theta=0.0
% INFO    : Bus 42444	: V=0.9969829, theta=31.148697 -> V=1.0, theta=0.0
% INFO    : Bus 42445	: V=0.9659408, theta=25.169521 -> V=1.0, theta=0.0
% INFO    : Bus 42446	: V=0.99333, theta=20.11094 -> V=1.0, theta=0.0
% INFO    : Bus 42447	: V=0.9932505, theta=20.095493 -> V=1.0, theta=0.0
% INFO    : Bus 42448	: V=0.9918322, theta=20.236625 -> V=1.0, theta=0.0
% INFO    : Bus 42449	: V=0.9944552, theta=20.109022 -> V=1.0, theta=0.0
% INFO    : Bus 42450	: V=0.9948536, theta=20.147079 -> V=1.0, theta=0.0
% INFO    : Bus 42451	: V=1.0015752, theta=20.551959 -> V=1.0, theta=0.0
% INFO    : Bus 42452	: V=0.9956811, theta=20.043612 -> V=1.0, theta=0.0
% INFO    : Bus 42453	: V=0.9973237, theta=19.955486 -> V=1.0, theta=0.0
% INFO    : Bus 42454	: V=0.9975279, theta=19.941177 -> V=1.0, theta=0.0
% INFO    : Bus 42455	: V=1.0061083, theta=19.949894 -> V=1.0, theta=0.0
% INFO    : Bus 42456	: V=0.9976283, theta=19.908072 -> V=1.0, theta=0.0
% INFO    : Bus 42457	: V=0.9977479, theta=19.795051 -> V=1.0, theta=0.0
% INFO    : Bus 42458	: V=1.0074968, theta=20.324926 -> V=1.0, theta=0.0
% INFO    : Bus 42459	: V=0.9996052, theta=19.806315 -> V=1.0, theta=0.0
% INFO    : Bus 42460	: V=1.0044413, theta=20.090948 -> V=1.0, theta=0.0
% INFO    : Bus 42461	: V=0.9976796, theta=19.915494 -> V=1.0, theta=0.0
% INFO    : Bus 42462	: V=0.9972058, theta=19.973578 -> V=1.0, theta=0.0
% INFO    : Bus 42463	: V=1.0024941, theta=20.253903 -> V=1.0, theta=0.0
% INFO    : Bus 42464	: V=0.9967065, theta=20.009357 -> V=1.0, theta=0.0
% INFO    : Bus 42465	: V=1.0015866, theta=20.356947 -> V=1.0, theta=0.0
% INFO    : Bus 42466	: V=1.0021084, theta=20.380087 -> V=1.0, theta=0.0
% INFO    : Bus 42467	: V=1.0000207, theta=20.229103 -> V=1.0, theta=0.0
% INFO    : Bus 42468	: V=1.002394, theta=20.338267 -> V=1.0, theta=0.0
% INFO    : Bus 42469	: V=1.0025145, theta=20.31599 -> V=1.0, theta=0.0
% INFO    : Bus 42470	: V=1.0028871, theta=20.264682 -> V=1.0, theta=0.0
% INFO    : Bus 42471	: V=1.003544, theta=20.205967 -> V=1.0, theta=0.0
% INFO    : Bus 42472	: V=1.0032061, theta=20.313689 -> V=1.0, theta=0.0
% INFO    : Bus 42473	: V=1.0042997, theta=20.305152 -> V=1.0, theta=0.0
% INFO    : Bus 42474	: V=1.0085325, theta=19.779095 -> V=1.0, theta=0.0
% INFO    : Bus 42475	: V=0.9851842, theta=19.103874 -> V=1.0, theta=0.0
% INFO    : Bus 42476	: V=1.0018499, theta=20.970836 -> V=1.0, theta=0.0
% INFO    : Bus 42477	: V=1.0028739, theta=21.687168 -> V=1.0, theta=0.0
% INFO    : Bus 42478	: V=1.0106713, theta=20.393172 -> V=1.0, theta=0.0
% INFO    : Bus 42479	: V=1.011155, theta=19.272436 -> V=1.0, theta=0.0
% INFO    : Bus 42480	: V=1.0106488, theta=19.081108 -> V=1.0, theta=0.0
% INFO    : Bus 42481	: V=0.9987682, theta=19.406876 -> V=1.0, theta=0.0
% INFO    : Bus 42482	: V=1.0143938, theta=19.153113 -> V=1.0, theta=0.0
% INFO    : Bus 42483	: V=1.0171549, theta=19.342676 -> V=1.0, theta=0.0
% INFO    : Bus 42484	: V=1.0077059, theta=20.330956 -> V=1.0, theta=0.0
% INFO    : Bus 42485	: V=1.0025843, theta=20.322266 -> V=1.0, theta=0.0
% INFO    : Bus 42486	: V=1.0009211, theta=20.325249 -> V=1.0, theta=0.0
% INFO    : Bus 42487	: V=1.0144425, theta=18.101532 -> V=1.0, theta=0.0
% INFO    : Bus 42488	: V=1.0143246, theta=18.059282 -> V=1.0, theta=0.0
% INFO    : Bus 42489	: V=1.0128442, theta=18.154452 -> V=1.0, theta=0.0
% INFO    : Bus 42490	: V=1.012756, theta=18.14707 -> V=1.0, theta=0.0
% INFO    : Bus 42491	: V=1.0145802, theta=18.281363 -> V=1.0, theta=0.0
% INFO    : Bus 42492	: V=1.0153909, theta=18.213146 -> V=1.0, theta=0.0
% INFO    : Bus 42493	: V=1.0130832, theta=18.104072 -> V=1.0, theta=0.0
% INFO    : Bus 42494	: V=1.0143795, theta=18.147316 -> V=1.0, theta=0.0
% INFO    : Bus 42495	: V=1.0143199, theta=18.075528 -> V=1.0, theta=0.0
% INFO    : Bus 42496	: V=1.0137339, theta=17.955942 -> V=1.0, theta=0.0
% INFO    : Bus 42497	: V=1.0135069, theta=17.906121 -> V=1.0, theta=0.0
% INFO    : Bus 42498	: V=1.0190973, theta=18.783139 -> V=1.0, theta=0.0
% INFO    : Bus 42499	: V=1.0150314, theta=18.287681 -> V=1.0, theta=0.0
% INFO    : Bus 42500	: V=1.0150521, theta=18.351967 -> V=1.0, theta=0.0
% INFO    : Bus 42501	: V=1.0147505, theta=18.334346 -> V=1.0, theta=0.0
% INFO    : Bus 42502	: V=1.0143345, theta=18.305095 -> V=1.0, theta=0.0
% INFO    : Bus 42503	: V=1.0143172, theta=18.282725 -> V=1.0, theta=0.0
% INFO    : Bus 42504	: V=1.0141257, theta=18.284265 -> V=1.0, theta=0.0
% INFO    : Bus 42505	: V=1.0195871, theta=18.64955 -> V=1.0, theta=0.0
% INFO    : Bus 42506	: V=1.0077488, theta=18.324488 -> V=1.0, theta=0.0
% INFO    : Bus 42507	: V=1.0081729, theta=18.109776 -> V=1.0, theta=0.0
% INFO    : Bus 42508	: V=1.0098973, theta=17.960032 -> V=1.0, theta=0.0
% INFO    : Bus 42509	: V=1.0083776, theta=17.980291 -> V=1.0, theta=0.0
% INFO    : Bus 42510	: V=0.9881144, theta=14.972288 -> V=1.0, theta=0.0
% INFO    : Bus 42511	: V=1.0132272, theta=17.828006 -> V=1.0, theta=0.0
% INFO    : Bus 42512	: V=1.0119793, theta=17.039853 -> V=1.0, theta=0.0
% INFO    : Bus 42513	: V=1.012716, theta=17.366464 -> V=1.0, theta=0.0
% INFO    : Bus 42514	: V=1.009123, theta=18.037995 -> V=1.0, theta=0.0
% INFO    : Bus 42515	: V=1.0126555, theta=18.393738 -> V=1.0, theta=0.0
% INFO    : Bus 42516	: V=1.0130093, theta=18.339578 -> V=1.0, theta=0.0
% INFO    : Bus 42517	: V=1.0137825, theta=18.268909 -> V=1.0, theta=0.0
% INFO    : Bus 42518	: V=1.0133417, theta=18.313237 -> V=1.0, theta=0.0
% INFO    : Bus 42519	: V=1.0106423, theta=18.784338 -> V=1.0, theta=0.0
% INFO    : Bus 42520	: V=1.0192202, theta=18.692938 -> V=1.0, theta=0.0
% INFO    : Bus 42521	: V=0.9941791, theta=13.425429 -> V=1.0, theta=0.0
% INFO    : Bus 42522	: V=0.9931626, theta=12.798602 -> V=1.0, theta=0.0
% INFO    : Bus 42523	: V=0.9894669, theta=10.55149 -> V=1.0, theta=0.0
% INFO    : Bus 42524	: V=0.9912467, theta=11.003866 -> V=1.0, theta=0.0
% INFO    : Bus 42525	: V=0.9899602, theta=9.919499 -> V=1.0, theta=0.0
% INFO    : Bus 42526	: V=0.9797955, theta=10.475208 -> V=1.0, theta=0.0
% INFO    : Bus 42527	: V=0.9979417, theta=5.056383 -> V=1.0, theta=0.0
% INFO    : Bus 42528	: V=0.998201, theta=4.178091 -> V=1.0, theta=0.0
% INFO    : Bus 42529	: V=0.9905154, theta=4.474198 -> V=1.0, theta=0.0
% INFO    : Bus 42530	: V=0.9888527, theta=4.821287 -> V=1.0, theta=0.0
% INFO    : Bus 42531	: V=0.9909853, theta=6.510362 -> V=1.0, theta=0.0
% INFO    : Bus 42532	: V=0.991566, theta=5.694068 -> V=1.0, theta=0.0
% INFO    : Bus 42533	: V=0.9925614, theta=4.842525 -> V=1.0, theta=0.0
% INFO    : Bus 42534	: V=1.0047413, theta=0.554123 -> V=1.0, theta=0.0
% INFO    : Bus 42535	: V=1.0051474, theta=0.516115 -> V=1.0, theta=0.0
% INFO    : Bus 42536	: V=1.0046796, theta=0.43854 -> V=1.0, theta=0.0
% INFO    : Bus 42537	: V=1.0061773, theta=0.405556 -> V=1.0, theta=0.0
% INFO    : Bus 42538	: V=1.0071392, theta=0.344107 -> V=1.0, theta=0.0
% INFO    : Bus 42539	: V=1.0042798, theta=0.641038 -> V=1.0, theta=0.0
% INFO    : Bus 42540	: V=1.005544, theta=0.668664 -> V=1.0, theta=0.0
% INFO    : Bus 42541	: V=1.0030606, theta=0.526879 -> V=1.0, theta=0.0
% INFO    : Bus 42542	: V=1.0038737, theta=0.723404 -> V=1.0, theta=0.0
% INFO    : Bus 42543	: V=1.0058663, theta=0.782791 -> V=1.0, theta=0.0
% INFO    : Bus 42544	: V=1.0061972, theta=0.869968 -> V=1.0, theta=0.0
% INFO    : Bus 42545	: V=1.0086486, theta=2.393427 -> V=1.0, theta=0.0
% INFO    : Bus 42546	: V=1.0104248, theta=2.472341 -> V=1.0, theta=0.0
% INFO    : Bus 42547	: V=1.0077334, theta=2.082872 -> V=1.0, theta=0.0
% INFO    : Bus 42548	: V=1.0080512, theta=2.172403 -> V=1.0, theta=0.0
% INFO    : Bus 42549	: V=1.0001074, theta=2.500154 -> V=1.0, theta=0.0
% INFO    : Bus 42550	: V=1.0195407, theta=2.039648 -> V=1.0, theta=0.0
% INFO    : Bus 42551	: V=1.0000926, theta=2.405356 -> V=1.0, theta=0.0
% INFO    : Bus 42552	: V=1.0025887, theta=2.493826 -> V=1.0, theta=0.0
% INFO    : Bus 42553	: V=1.0020478, theta=2.452219 -> V=1.0, theta=0.0
% INFO    : Bus 42554	: V=1.0051983, theta=2.311899 -> V=1.0, theta=0.0
% INFO    : Bus 42555	: V=1.0009362, theta=2.357821 -> V=1.0, theta=0.0
% INFO    : Bus 42556	: V=1.0061384, theta=1.477801 -> V=1.0, theta=0.0
% INFO    : Bus 42557	: V=1.0021675, theta=1.021538 -> V=1.0, theta=0.0
% INFO    : Bus 42558	: V=0.999083, theta=2.694808 -> V=1.0, theta=0.0
% INFO    : Bus 42559	: V=1.0047305, theta=2.768422 -> V=1.0, theta=0.0
% INFO    : Bus 42560	: V=1.0046697, theta=2.768722 -> V=1.0, theta=0.0
% INFO    : Bus 42561	: V=1.0151939, theta=1.955704 -> V=1.0, theta=0.0
% INFO    : Bus 42562	: V=0.9996704, theta=2.5455 -> V=1.0, theta=0.0
% INFO    : Bus 42563	: V=1.0047904, theta=2.80516 -> V=1.0, theta=0.0
% INFO    : Bus 42564	: V=1.004901, theta=2.840811 -> V=1.0, theta=0.0
% INFO    : Bus 42565	: V=1.0035972, theta=3.244403 -> V=1.0, theta=0.0
% INFO    : Bus 42566	: V=1.0036498, theta=3.065552 -> V=1.0, theta=0.0
% INFO    : Bus 42567	: V=0.9980424, theta=2.618924 -> V=1.0, theta=0.0
% INFO    : Bus 42568	: V=0.9990288, theta=2.986149 -> V=1.0, theta=0.0
% INFO    : Bus 42569	: V=1.000941, theta=3.007123 -> V=1.0, theta=0.0
% INFO    : Bus 42570	: V=0.9964226, theta=2.042249 -> V=1.0, theta=0.0
% INFO    : Bus 42571	: V=0.9934385, theta=1.641332 -> V=1.0, theta=0.0
% INFO    : Bus 42572	: V=0.9920537, theta=1.433706 -> V=1.0, theta=0.0
% INFO    : Bus 42573	: V=0.9919952, theta=1.434078 -> V=1.0, theta=0.0
% INFO    : Bus 42574	: V=0.9983244, theta=1.626151 -> V=1.0, theta=0.0
% INFO    : Bus 42575	: V=0.9964661, theta=1.460324 -> V=1.0, theta=0.0
% INFO    : Bus 42576	: V=0.9909664, theta=1.367507 -> V=1.0, theta=0.0
% INFO    : Bus 42577	: V=0.9893283, theta=0.564772 -> V=1.0, theta=0.0
% INFO    : Bus 42578	: V=0.9897052, theta=0.512379 -> V=1.0, theta=0.0
% INFO    : Bus 42579	: V=0.99186, theta=0.627629 -> V=1.0, theta=0.0
% INFO    : Bus 42580	: V=0.9896555, theta=0.338323 -> V=1.0, theta=0.0
% INFO    : Bus 42581	: V=0.9948443, theta=1.195113 -> V=1.0, theta=0.0
% INFO    : Bus 42582	: V=0.9927615, theta=1.443864 -> V=1.0, theta=0.0
% INFO    : Bus 42583	: V=0.9856732, theta=1.57484 -> V=1.0, theta=0.0
% INFO    : Bus 42584	: V=0.9954044, theta=1.317296 -> V=1.0, theta=0.0
% INFO    : Bus 42585	: V=1.0049119, theta=0.86665 -> V=1.0, theta=0.0
% INFO    : Bus 42586	: V=0.9898599, theta=3.136598 -> V=1.0, theta=0.0
% INFO    : Bus 42587	: V=0.981976, theta=2.806109 -> V=1.0, theta=0.0
% INFO    : Bus 42588	: V=0.9800923, theta=2.783366 -> V=1.0, theta=0.0
% INFO    : Bus 42589	: V=0.9836372, theta=2.02171 -> V=1.0, theta=0.0
% INFO    : Bus 42590	: V=0.980952, theta=3.040519 -> V=1.0, theta=0.0
% INFO    : Bus 42591	: V=0.9957463, theta=3.670101 -> V=1.0, theta=0.0
% INFO    : Bus 42592	: V=0.9914147, theta=4.620095 -> V=1.0, theta=0.0
% INFO    : Bus 42593	: V=1.005564, theta=0.478552 -> V=1.0, theta=0.0
% INFO    : Bus 42594	: V=1.0033234, theta=0.870852 -> V=1.0, theta=0.0
% INFO    : Bus 42595	: V=1.0159535, theta=4.957241 -> V=1.0, theta=0.0
% INFO    : Bus 42596	: V=1.0054768, theta=4.897029 -> V=1.0, theta=0.0
% INFO    : Bus 42597	: V=0.9928865, theta=2.910645 -> V=1.0, theta=0.0
% INFO    : Bus 42598	: V=1.0068984, theta=3.252584 -> V=1.0, theta=0.0
% INFO    : Bus 42599	: V=0.9998338, theta=3.858322 -> V=1.0, theta=0.0
% INFO    : Bus 42600	: V=1.0087507, theta=4.037018 -> V=1.0, theta=0.0
% INFO    : Bus 42601	: V=1.0110168, theta=3.164072 -> V=1.0, theta=0.0
% INFO    : Bus 42602	: V=1.0121911, theta=1.20087 -> V=1.0, theta=0.0
% INFO    : Bus 42603	: V=1.0009209, theta=2.29716 -> V=1.0, theta=0.0
% INFO    : Bus 42604	: V=0.9994916, theta=2.321515 -> V=1.0, theta=0.0
% INFO    : Bus 42605	: V=1.0002572, theta=2.313893 -> V=1.0, theta=0.0
% INFO    : Bus 42606	: V=0.9999254, theta=2.327202 -> V=1.0, theta=0.0
% INFO    : Bus 42607	: V=1.0036333, theta=25.053568 -> V=1.0, theta=0.0
% INFO    : Bus 42608	: V=1.0047097, theta=26.007623 -> V=1.0, theta=0.0
% INFO    : Bus 42609	: V=1.0067532, theta=26.555755 -> V=1.0, theta=0.0
% INFO    : Bus 42610	: V=0.998092, theta=24.861601 -> V=1.0, theta=0.0
% INFO    : Bus 42611	: V=1.0031856, theta=24.666532 -> V=1.0, theta=0.0
% INFO    : Bus 42612	: V=1.0110607, theta=22.609891 -> V=1.0, theta=0.0
% INFO    : Bus 42613	: V=1.0116168, theta=22.620431 -> V=1.0, theta=0.0
% INFO    : Bus 42614	: V=1.0129564, theta=21.341209 -> V=1.0, theta=0.0
% INFO    : Bus 42615	: V=1.0092618, theta=20.278272 -> V=1.0, theta=0.0
% INFO    : Bus 42616	: V=1.0080178, theta=21.286994 -> V=1.0, theta=0.0
% INFO    : Bus 42617	: V=1.0062799, theta=20.911959 -> V=1.0, theta=0.0
% INFO    : Bus 42618	: V=1.0112871, theta=-3.237832 -> V=1.0, theta=0.0
% INFO    : Bus 42619	: V=0.9968136, theta=-3.057952 -> V=1.0, theta=0.0
% INFO    : Bus 42620	: V=0.9941038, theta=-3.038952 -> V=1.0, theta=0.0
% INFO    : Bus 42621	: V=0.9979649, theta=-3.070391 -> V=1.0, theta=0.0
% INFO    : Bus 42622	: V=1.0045952, theta=20.007757 -> V=1.0, theta=0.0
% INFO    : Bus 42623	: V=0.9989358, theta=18.690661 -> V=1.0, theta=0.0
% INFO    : Bus 42624	: V=1.0012664, theta=18.95786 -> V=1.0, theta=0.0
% INFO    : Bus 42625	: V=0.9944376, theta=29.371612 -> V=1.0, theta=0.0
% INFO    : Bus 42626	: V=0.9997856, theta=28.997184 -> V=1.0, theta=0.0
% INFO    : Bus 42627	: V=0.9932516, theta=28.793877 -> V=1.0, theta=0.0
% INFO    : Bus 42628	: V=0.9952421, theta=28.675325 -> V=1.0, theta=0.0
% INFO    : Bus 42629	: V=0.9787028, theta=-0.024331 -> V=1.0, theta=0.0
% INFO    : Bus 42630	: V=0.9804442, theta=-0.105768 -> V=1.0, theta=0.0
% INFO    : Bus 42631	: V=0.9826019, theta=0.386351 -> V=1.0, theta=0.0
% INFO    : Bus 42632	: V=0.9939776, theta=0.787943 -> V=1.0, theta=0.0
% INFO    : Bus 42633	: V=0.997243, theta=0.900941 -> V=1.0, theta=0.0
% INFO    : Bus 42634	: V=0.999576, theta=0.980159 -> V=1.0, theta=0.0
% INFO    : Bus 42635	: V=0.9768054, theta=10.631282 -> V=1.0, theta=0.0
% INFO    : Bus 42636	: V=0.9843128, theta=8.132088 -> V=1.0, theta=0.0
% INFO    : Bus 42637	: V=0.9905339, theta=11.987921 -> V=1.0, theta=0.0
% INFO    : Bus 42638	: V=0.9829033, theta=7.476989 -> V=1.0, theta=0.0
% INFO    : Bus 42639	: V=0.9846372, theta=7.498496 -> V=1.0, theta=0.0
% INFO    : Bus 42640	: V=0.9909508, theta=8.089114 -> V=1.0, theta=0.0
% INFO    : Bus 42641	: V=0.9978421, theta=8.24155 -> V=1.0, theta=0.0
% INFO    : Bus 42642	: V=0.9960039, theta=8.156566 -> V=1.0, theta=0.0
% INFO    : Bus 42643	: V=0.9874241, theta=13.668423 -> V=1.0, theta=0.0
% INFO    : Bus 42644	: V=0.9824854, theta=13.088239 -> V=1.0, theta=0.0
% INFO    : Bus 42645	: V=0.9855629, theta=13.010799 -> V=1.0, theta=0.0
% INFO    : Bus 42646	: V=0.9830848, theta=12.685862 -> V=1.0, theta=0.0
% INFO    : Bus 42647	: V=0.9834319, theta=12.69252 -> V=1.0, theta=0.0
% INFO    : Bus 42648	: V=0.9859656, theta=13.135025 -> V=1.0, theta=0.0
% INFO    : Bus 42649	: V=0.9859354, theta=13.035606 -> V=1.0, theta=0.0
% INFO    : Bus 42650	: V=0.986438, theta=12.746687 -> V=1.0, theta=0.0
% INFO    : Bus 42651	: V=0.9884898, theta=11.825533 -> V=1.0, theta=0.0
% INFO    : Bus 42652	: V=0.9766042, theta=13.159318 -> V=1.0, theta=0.0
% INFO    : Bus 42653	: V=0.9690134, theta=8.74805 -> V=1.0, theta=0.0
% INFO    : Bus 42654	: V=0.9730322, theta=12.131094 -> V=1.0, theta=0.0
% INFO    : Bus 42655	: V=0.9754009, theta=9.228358 -> V=1.0, theta=0.0
% INFO    : Bus 42656	: V=0.9804187, theta=8.352289 -> V=1.0, theta=0.0
% INFO    : Bus 42657	: V=1.0080637, theta=33.000583 -> V=1.0, theta=0.0
% INFO    : Bus 42658	: V=0.9964906, theta=32.810591 -> V=1.0, theta=0.0
% INFO    : Bus 42659	: V=1.0157819, theta=33.145413 -> V=1.0, theta=0.0
% INFO    : Bus 42660	: V=1.0085525, theta=32.01917 -> V=1.0, theta=0.0
% INFO    : Bus 42661	: V=1.0058437, theta=29.127675 -> V=1.0, theta=0.0
% INFO    : Bus 42662	: V=0.9922189, theta=29.021611 -> V=1.0, theta=0.0
% INFO    : Bus 42663	: V=1.0095913, theta=32.993184 -> V=1.0, theta=0.0
% INFO    : Bus 42664	: V=1.0192273, theta=33.528134 -> V=1.0, theta=0.0
% INFO    : Bus 42665	: V=1.0117647, theta=32.53814 -> V=1.0, theta=0.0
% INFO    : Bus 42666	: V=1.0091643, theta=29.91881 -> V=1.0, theta=0.0
% INFO    : Bus 42667	: V=1.0138522, theta=33.209868 -> V=1.0, theta=0.0
% INFO    : Bus 42668	: V=1.0090411, theta=25.125835 -> V=1.0, theta=0.0
% INFO    : Bus 42669	: V=1.0089411, theta=25.151213 -> V=1.0, theta=0.0
% INFO    : Bus 42670	: V=1.0088063, theta=25.134871 -> V=1.0, theta=0.0
% INFO    : Bus 42671	: V=1.0177458, theta=25.573559 -> V=1.0, theta=0.0
% INFO    : Bus 42672	: V=1.0080488, theta=25.107033 -> V=1.0, theta=0.0
% INFO    : Bus 42673	: V=1.0076337, theta=25.060738 -> V=1.0, theta=0.0
% INFO    : Bus 42674	: V=1.0064983, theta=25.053089 -> V=1.0, theta=0.0
% INFO    : Bus 42675	: V=1.0025477, theta=24.870834 -> V=1.0, theta=0.0
% INFO    : Bus 42676	: V=1.0054818, theta=25.011964 -> V=1.0, theta=0.0
% INFO    : Bus 42677	: V=1.0063804, theta=25.039926 -> V=1.0, theta=0.0
% INFO    : Bus 42678	: V=1.0069237, theta=25.086602 -> V=1.0, theta=0.0
% INFO    : Bus 42679	: V=1.0077239, theta=25.09922 -> V=1.0, theta=0.0
% INFO    : Bus 42680	: V=1.006511, theta=25.079796 -> V=1.0, theta=0.0
% INFO    : Bus 42681	: V=1.0063404, theta=25.076433 -> V=1.0, theta=0.0
% INFO    : Bus 42682	: V=1.0039107, theta=25.026658 -> V=1.0, theta=0.0
% INFO    : Bus 42683	: V=1.0049509, theta=25.072041 -> V=1.0, theta=0.0
% INFO    : Bus 42684	: V=1.0011524, theta=24.878197 -> V=1.0, theta=0.0
% INFO    : Bus 42685	: V=1.001888, theta=24.895285 -> V=1.0, theta=0.0
% INFO    : Bus 42686	: V=1.0003576, theta=24.840535 -> V=1.0, theta=0.0
% INFO    : Bus 42687	: V=1.0055634, theta=25.077932 -> V=1.0, theta=0.0
% INFO    : Bus 42688	: V=1.0049503, theta=25.076175 -> V=1.0, theta=0.0
% INFO    : Bus 42689	: V=1.0044913, theta=25.075298 -> V=1.0, theta=0.0
% INFO    : Bus 42690	: V=1.0041041, theta=25.072862 -> V=1.0, theta=0.0
% INFO    : Bus 42691	: V=1.0040004, theta=25.076933 -> V=1.0, theta=0.0
% INFO    : Bus 42692	: V=0.9989121, theta=24.958101 -> V=1.0, theta=0.0
% INFO    : Bus 42693	: V=0.9978243, theta=24.936719 -> V=1.0, theta=0.0
% INFO    : Bus 42694	: V=1.0036922, theta=25.090353 -> V=1.0, theta=0.0
% INFO    : Bus 42695	: V=0.9985468, theta=24.958739 -> V=1.0, theta=0.0
% INFO    : Bus 42696	: V=1.0031091, theta=25.130418 -> V=1.0, theta=0.0
% INFO    : Bus 42697	: V=1.0021432, theta=25.183757 -> V=1.0, theta=0.0
% INFO    : Bus 42698	: V=1.0019398, theta=25.166841 -> V=1.0, theta=0.0
% INFO    : Bus 42699	: V=1.0022556, theta=25.374493 -> V=1.0, theta=0.0
% INFO    : Bus 42700	: V=0.9965492, theta=25.610963 -> V=1.0, theta=0.0
% INFO    : Bus 42701	: V=0.9983093, theta=27.170786 -> V=1.0, theta=0.0
% INFO    : Bus 42702	: V=0.999568, theta=26.561029 -> V=1.0, theta=0.0
% INFO    : Bus 42703	: V=1.0034544, theta=25.20401 -> V=1.0, theta=0.0
% INFO    : Bus 42704	: V=0.9972154, theta=25.004716 -> V=1.0, theta=0.0
% INFO    : Bus 42705	: V=1.000239, theta=24.920621 -> V=1.0, theta=0.0
% INFO    : Bus 42706	: V=0.9985129, theta=24.970634 -> V=1.0, theta=0.0
% INFO    : Bus 42707	: V=1.0006443, theta=24.906819 -> V=1.0, theta=0.0
% INFO    : Bus 42708	: V=1.0045709, theta=25.019087 -> V=1.0, theta=0.0
% INFO    : Bus 42709	: V=1.0015882, theta=25.102014 -> V=1.0, theta=0.0
% INFO    : Bus 42710	: V=1.0190432, theta=25.772146 -> V=1.0, theta=0.0
% INFO    : Bus 42711	: V=1.0092456, theta=25.397932 -> V=1.0, theta=0.0
% INFO    : Bus 42712	: V=1.0092958, theta=25.190844 -> V=1.0, theta=0.0
% INFO    : Bus 42713	: V=1.0093295, theta=24.217927 -> V=1.0, theta=0.0
% INFO    : Bus 42714	: V=0.9996828, theta=25.118523 -> V=1.0, theta=0.0
% INFO    : Bus 42715	: V=1.0076477, theta=25.08977 -> V=1.0, theta=0.0
% INFO    : Bus 42716	: V=1.0187322, theta=2.390598 -> V=1.0, theta=0.0
% INFO    : Bus 42717	: V=1.019487, theta=2.444289 -> V=1.0, theta=0.0
% INFO    : Bus 42718	: V=1.0142299, theta=1.586911 -> V=1.0, theta=0.0
% INFO    : Bus 42719	: V=1.0171201, theta=1.488418 -> V=1.0, theta=0.0
% INFO    : Bus 42720	: V=1.0126606, theta=0.510811 -> V=1.0, theta=0.0
% INFO    : Bus 42721	: V=1.0138303, theta=0.620208 -> V=1.0, theta=0.0
% INFO    : Bus 42722	: V=1.0158801, theta=18.491268 -> V=1.0, theta=0.0
% INFO    : Bus 42723	: V=1.0125859, theta=18.286385 -> V=1.0, theta=0.0
% INFO    : Bus 42724	: V=0.9928666, theta=17.956792 -> V=1.0, theta=0.0
% INFO    : Bus 42725	: V=1.0116387, theta=18.302582 -> V=1.0, theta=0.0
% INFO    : Bus 42726	: V=0.9904391, theta=11.030183 -> V=1.0, theta=0.0
% INFO    : Bus 42727	: V=0.9933104, theta=9.221841 -> V=1.0, theta=0.0
% INFO    : Bus 42728	: V=0.9939994, theta=8.677428 -> V=1.0, theta=0.0
% INFO    : Bus 42729	: V=0.9912064, theta=9.797854 -> V=1.0, theta=0.0
% INFO    : Bus 42730	: V=0.9944311, theta=8.842447 -> V=1.0, theta=0.0
% INFO    : Bus 42731	: V=1.002276, theta=-2.199603 -> V=1.0, theta=0.0
% INFO    : Bus 42732	: V=0.9921306, theta=-2.994586 -> V=1.0, theta=0.0
% INFO    : Bus 42733	: V=1.0098712, theta=-2.318468 -> V=1.0, theta=0.0
% INFO    : Bus 42734	: V=1.0071456, theta=-1.694062 -> V=1.0, theta=0.0
% INFO    : Bus 42735	: V=1.0171431, theta=28.650476 -> V=1.0, theta=0.0
% INFO    : Bus 42736	: V=1.005434, theta=26.268394 -> V=1.0, theta=0.0
% INFO    : Bus 42737	: V=1.0128357, theta=1.118571 -> V=1.0, theta=0.0
% INFO    : Bus 42738	: V=1.015997, theta=1.5278 -> V=1.0, theta=0.0
% INFO    : Bus 42739	: V=1.0155608, theta=1.302893 -> V=1.0, theta=0.0
% INFO    : Bus 42740	: V=1.0081747, theta=1.294836 -> V=1.0, theta=0.0
% INFO    : Bus 42741	: V=1.0075144, theta=0.741778 -> V=1.0, theta=0.0
% INFO    : Bus 42742	: V=1.0115198, theta=-0.005052 -> V=1.0, theta=0.0
% INFO    : Bus 42743	: V=1.0110118, theta=0.508446 -> V=1.0, theta=0.0
% INFO    : Bus 42744	: V=1.0085295, theta=-0.029218 -> V=1.0, theta=0.0
% INFO    : Bus 42745	: V=1.0135109, theta=-1.254392 -> V=1.0, theta=0.0
% INFO    : Bus 42746	: V=0.9847491, theta=3.227217 -> V=1.0, theta=0.0
% INFO    : Bus 42747	: V=0.9920362, theta=3.072964 -> V=1.0, theta=0.0
% INFO    : Bus 42748	: V=0.9837149, theta=3.057717 -> V=1.0, theta=0.0
% INFO    : Bus 42749	: V=0.9839481, theta=3.060883 -> V=1.0, theta=0.0
% INFO    : Bus 42750	: V=0.9897503, theta=2.47631 -> V=1.0, theta=0.0
% INFO    : Bus 42751	: V=1.0119413, theta=32.235892 -> V=1.0, theta=0.0
% INFO    : Bus 42752	: V=1.0058556, theta=30.901524 -> V=1.0, theta=0.0
% INFO    : Bus 42753	: V=1.0063684, theta=30.885268 -> V=1.0, theta=0.0
% INFO    : Bus 42754	: V=0.9988336, theta=31.049339 -> V=1.0, theta=0.0
% INFO    : Bus 42755	: V=1.0082027, theta=30.867675 -> V=1.0, theta=0.0
% INFO    : Bus 42756	: V=1.0073859, theta=30.821465 -> V=1.0, theta=0.0
% INFO    : Bus 42757	: V=0.9988022, theta=30.560955 -> V=1.0, theta=0.0
% INFO    : Bus 42758	: V=0.9964293, theta=30.575225 -> V=1.0, theta=0.0
% INFO    : Bus 42759	: V=0.9946329, theta=30.592692 -> V=1.0, theta=0.0
% INFO    : Bus 42760	: V=0.9915004, theta=30.638384 -> V=1.0, theta=0.0
% INFO    : Bus 42761	: V=0.9929079, theta=30.590961 -> V=1.0, theta=0.0
% INFO    : Bus 42762	: V=0.9967846, theta=30.539901 -> V=1.0, theta=0.0
% INFO    : Bus 42763	: V=1.0065326, theta=30.799692 -> V=1.0, theta=0.0
% INFO    : Bus 42764	: V=0.9967071, theta=30.500167 -> V=1.0, theta=0.0
% INFO    : Bus 42765	: V=0.9965974, theta=30.492452 -> V=1.0, theta=0.0
% INFO    : Bus 42766	: V=0.9968958, theta=30.4863 -> V=1.0, theta=0.0
% INFO    : Bus 42767	: V=1.0028591, theta=30.518317 -> V=1.0, theta=0.0
% INFO    : Bus 42768	: V=1.0032883, theta=30.510078 -> V=1.0, theta=0.0
% INFO    : Bus 42769	: V=1.0040592, theta=30.5639 -> V=1.0, theta=0.0
% INFO    : Bus 42770	: V=0.9978043, theta=30.42287 -> V=1.0, theta=0.0
% INFO    : Bus 42771	: V=1.0050234, theta=30.62841 -> V=1.0, theta=0.0
% INFO    : Bus 42772	: V=1.0046817, theta=30.660047 -> V=1.0, theta=0.0
% INFO    : Bus 42773	: V=1.0034859, theta=30.587076 -> V=1.0, theta=0.0
% INFO    : Bus 42774	: V=1.0047585, theta=30.639866 -> V=1.0, theta=0.0
% INFO    : Bus 42775	: V=0.9981572, theta=30.414074 -> V=1.0, theta=0.0
% INFO    : Bus 42776	: V=0.9971893, theta=30.358937 -> V=1.0, theta=0.0
% INFO    : Bus 42777	: V=0.9960319, theta=30.334798 -> V=1.0, theta=0.0
% INFO    : Bus 42778	: V=0.9955815, theta=30.40609 -> V=1.0, theta=0.0
% INFO    : Bus 42779	: V=0.9979402, theta=30.412344 -> V=1.0, theta=0.0
% INFO    : Bus 42780	: V=0.9977346, theta=30.415009 -> V=1.0, theta=0.0
% INFO    : Bus 42781	: V=0.9975548, theta=30.419451 -> V=1.0, theta=0.0
% INFO    : Bus 42782	: V=0.9968902, theta=30.410721 -> V=1.0, theta=0.0
% INFO    : Bus 42783	: V=0.9901516, theta=30.681476 -> V=1.0, theta=0.0
% INFO    : Bus 42784	: V=0.9901104, theta=30.063721 -> V=1.0, theta=0.0
% INFO    : Bus 42785	: V=1.0032871, theta=30.20435 -> V=1.0, theta=0.0
% INFO    : Bus 42786	: V=1.0082552, theta=29.947352 -> V=1.0, theta=0.0
% INFO    : Bus 42787	: V=1.0021927, theta=30.325878 -> V=1.0, theta=0.0
% INFO    : Bus 42788	: V=1.0023694, theta=30.387374 -> V=1.0, theta=0.0
% INFO    : Bus 42789	: V=0.9962071, theta=30.381474 -> V=1.0, theta=0.0
% INFO    : Bus 42790	: V=1.0152067, theta=31.255451 -> V=1.0, theta=0.0
% INFO    : Bus 42791	: V=1.0012397, theta=-0.77868 -> V=1.0, theta=0.0
% INFO    : Bus 42792	: V=0.9944826, theta=-0.428857 -> V=1.0, theta=0.0
% INFO    : Bus 42793	: V=1.0016883, theta=-0.725168 -> V=1.0, theta=0.0
% INFO    : Bus 42794	: V=1.0010718, theta=-0.60494 -> V=1.0, theta=0.0
% INFO    : Bus 42795	: V=1.0002793, theta=-0.501102 -> V=1.0, theta=0.0
% INFO    : Bus 42796	: V=0.9989439, theta=-0.290335 -> V=1.0, theta=0.0
% INFO    : Bus 42797	: V=0.9984416, theta=-0.084116 -> V=1.0, theta=0.0
% INFO    : Bus 42798	: V=0.9902133, theta=-0.084241 -> V=1.0, theta=0.0
% INFO    : Bus 42799	: V=0.9886761, theta=0.370799 -> V=1.0, theta=0.0
% INFO    : Bus 42800	: V=0.9790847, theta=0.21822 -> V=1.0, theta=0.0
% INFO    : Bus 42801	: V=0.9895546, theta=0.473915 -> V=1.0, theta=0.0
% INFO    : Bus 42802	: V=0.9889058, theta=0.407034 -> V=1.0, theta=0.0
% INFO    : Bus 42803	: V=0.9861902, theta=-0.043523 -> V=1.0, theta=0.0
% INFO    : Bus 42804	: V=0.9910538, theta=0.560148 -> V=1.0, theta=0.0
% INFO    : Bus 42805	: V=0.981092, theta=0.35913 -> V=1.0, theta=0.0
% INFO    : Bus 42806	: V=0.9795786, theta=0.207366 -> V=1.0, theta=0.0
% INFO    : Bus 42807	: V=0.9953381, theta=-0.4947 -> V=1.0, theta=0.0
% INFO    : Bus 42808	: V=0.9937222, theta=-0.343361 -> V=1.0, theta=0.0
% INFO    : Bus 42809	: V=1.0156506, theta=-0.291587 -> V=1.0, theta=0.0
% INFO    : Bus 42810	: V=0.9946201, theta=-0.475582 -> V=1.0, theta=0.0
% INFO    : Bus 42811	: V=0.9986827, theta=0.204041 -> V=1.0, theta=0.0
% INFO    : Bus 42812	: V=0.9932695, theta=-0.624492 -> V=1.0, theta=0.0
% INFO    : Bus 42813	: V=0.9995951, theta=-0.493784 -> V=1.0, theta=0.0
% INFO    : Bus 42814	: V=1.0022129, theta=-0.566877 -> V=1.0, theta=0.0
% INFO    : Bus 42815	: V=0.9927506, theta=-0.596193 -> V=1.0, theta=0.0
% INFO    : Bus 42816	: V=0.9901618, theta=-0.410839 -> V=1.0, theta=0.0
% INFO    : Bus 42817	: V=0.9936652, theta=-0.531901 -> V=1.0, theta=0.0
% INFO    : Bus 42818	: V=0.9880159, theta=-0.494614 -> V=1.0, theta=0.0
% INFO    : Bus 42819	: V=0.9865286, theta=-0.269691 -> V=1.0, theta=0.0
% INFO    : Bus 42820	: V=0.9816993, theta=0.227199 -> V=1.0, theta=0.0
% INFO    : Bus 42821	: V=0.9887024, theta=-0.198876 -> V=1.0, theta=0.0
% INFO    : Bus 42822	: V=0.9802954, theta=0.197581 -> V=1.0, theta=0.0
% INFO    : Bus 42823	: V=0.9915245, theta=0.567293 -> V=1.0, theta=0.0
% INFO    : Bus 42824	: V=0.9821833, theta=0.090349 -> V=1.0, theta=0.0
% INFO    : Bus 42825	: V=0.981684, theta=0.298915 -> V=1.0, theta=0.0
% INFO    : Bus 42826	: V=0.9838266, theta=0.370912 -> V=1.0, theta=0.0
% INFO    : Bus 42827	: V=0.9828475, theta=0.390343 -> V=1.0, theta=0.0
% INFO    : Bus 42828	: V=0.9846142, theta=0.434923 -> V=1.0, theta=0.0
% INFO    : Bus 42829	: V=0.9874825, theta=0.083534 -> V=1.0, theta=0.0
% INFO    : Bus 42830	: V=0.9865829, theta=0.510155 -> V=1.0, theta=0.0
% INFO    : Bus 42831	: V=0.9911768, theta=-0.09269 -> V=1.0, theta=0.0
% INFO    : Bus 42832	: V=0.9890879, theta=-0.01834 -> V=1.0, theta=0.0
% INFO    : Bus 42833	: V=0.9843304, theta=0.455757 -> V=1.0, theta=0.0
% INFO    : Bus 42834	: V=0.9854717, theta=0.434917 -> V=1.0, theta=0.0
% INFO    : Bus 42835	: V=1.0140308, theta=1.416854 -> V=1.0, theta=0.0
% INFO    : Bus 42836	: V=0.9865471, theta=0.745187 -> V=1.0, theta=0.0
% INFO    : Bus 42837	: V=0.9994355, theta=1.181939 -> V=1.0, theta=0.0
% INFO    : Bus 42838	: V=0.9850227, theta=0.33604 -> V=1.0, theta=0.0
% INFO    : Bus 42839	: V=0.9944637, theta=0.517228 -> V=1.0, theta=0.0
% INFO    : Bus 42840	: V=1.0079369, theta=0.593897 -> V=1.0, theta=0.0
% INFO    : Bus 42841	: V=1.0090493, theta=1.862057 -> V=1.0, theta=0.0
% INFO    : Bus 42842	: V=0.9965365, theta=1.309916 -> V=1.0, theta=0.0
% INFO    : Bus 42843	: V=0.9996797, theta=1.342227 -> V=1.0, theta=0.0
% INFO    : Bus 42844	: V=0.9862546, theta=0.456116 -> V=1.0, theta=0.0
% INFO    : Bus 42845	: V=0.9861029, theta=0.450121 -> V=1.0, theta=0.0
% INFO    : Bus 42846	: V=0.9850375, theta=0.505093 -> V=1.0, theta=0.0
% INFO    : Bus 42847	: V=1.0064365, theta=1.139422 -> V=1.0, theta=0.0
% INFO    : Bus 42848	: V=0.9856958, theta=0.484782 -> V=1.0, theta=0.0
% INFO    : Bus 42849	: V=1.0102696, theta=-1.524959 -> V=1.0, theta=0.0
% INFO    : Bus 42850	: V=1.0016009, theta=-0.80457 -> V=1.0, theta=0.0
% INFO    : Bus 42851	: V=0.9905323, theta=-1.786212 -> V=1.0, theta=0.0
% INFO    : Bus 42852	: V=0.9903502, theta=-1.765455 -> V=1.0, theta=0.0
% INFO    : Bus 42853	: V=0.9853799, theta=-1.730031 -> V=1.0, theta=0.0
% INFO    : Bus 42854	: V=0.9874617, theta=-1.778308 -> V=1.0, theta=0.0
% INFO    : Bus 42855	: V=0.9784176, theta=-1.796853 -> V=1.0, theta=0.0
% INFO    : Bus 42856	: V=0.9793664, theta=-1.823619 -> V=1.0, theta=0.0
% INFO    : Bus 42857	: V=0.9794456, theta=-1.831841 -> V=1.0, theta=0.0
% INFO    : Bus 42858	: V=0.9820337, theta=-1.816064 -> V=1.0, theta=0.0
% INFO    : Bus 42859	: V=0.995072, theta=-1.997907 -> V=1.0, theta=0.0
% INFO    : Bus 42860	: V=1.0092593, theta=19.06999 -> V=1.0, theta=0.0
% INFO    : Bus 42861	: V=1.0018161, theta=18.603621 -> V=1.0, theta=0.0
% INFO    : Bus 42862	: V=1.0084487, theta=18.825917 -> V=1.0, theta=0.0
% INFO    : Bus 42863	: V=1.0109285, theta=19.103113 -> V=1.0, theta=0.0
% INFO    : Bus 42864	: V=1.010441, theta=19.089726 -> V=1.0, theta=0.0
% INFO    : Bus 42865	: V=1.0092602, theta=18.937674 -> V=1.0, theta=0.0
% INFO    : Bus 42866	: V=1.0129436, theta=18.953146 -> V=1.0, theta=0.0
% INFO    : Bus 42867	: V=1.0089924, theta=18.947368 -> V=1.0, theta=0.0
% INFO    : Bus 42868	: V=1.0161529, theta=19.366575 -> V=1.0, theta=0.0
% INFO    : Bus 42869	: V=1.011846, theta=18.957792 -> V=1.0, theta=0.0
% INFO    : Bus 42870	: V=1.0130746, theta=19.174098 -> V=1.0, theta=0.0
% INFO    : Bus 42871	: V=1.0123671, theta=19.14936 -> V=1.0, theta=0.0
% INFO    : Bus 42872	: V=1.00129, theta=18.531805 -> V=1.0, theta=0.0
% INFO    : Bus 42873	: V=1.0009511, theta=18.470486 -> V=1.0, theta=0.0
% INFO    : Bus 42874	: V=1.0010717, theta=18.466543 -> V=1.0, theta=0.0
% INFO    : Bus 42875	: V=1.0032091, theta=18.541042 -> V=1.0, theta=0.0
% INFO    : Bus 42876	: V=1.0062772, theta=18.667935 -> V=1.0, theta=0.0
% INFO    : Bus 42877	: V=1.0093349, theta=18.84495 -> V=1.0, theta=0.0
% INFO    : Bus 42878	: V=1.0087274, theta=18.758933 -> V=1.0, theta=0.0
% INFO    : Bus 42879	: V=1.008094, theta=18.742773 -> V=1.0, theta=0.0
% INFO    : Bus 42880	: V=1.0192678, theta=19.703165 -> V=1.0, theta=0.0
% INFO    : Bus 42881	: V=1.0076935, theta=18.726956 -> V=1.0, theta=0.0
% INFO    : Bus 42882	: V=1.0105408, theta=18.876418 -> V=1.0, theta=0.0
% INFO    : Bus 42883	: V=1.0069791, theta=18.701644 -> V=1.0, theta=0.0
% INFO    : Bus 42884	: V=1.0063477, theta=18.625324 -> V=1.0, theta=0.0
% INFO    : Bus 42885	: V=1.0048271, theta=18.592212 -> V=1.0, theta=0.0
% INFO    : Bus 42886	: V=1.0068749, theta=18.710944 -> V=1.0, theta=0.0
% INFO    : Bus 42887	: V=1.0101494, theta=18.797636 -> V=1.0, theta=0.0
% INFO    : Bus 42888	: V=1.0194166, theta=19.715699 -> V=1.0, theta=0.0
% INFO    : Bus 42889	: V=1.0098708, theta=18.618749 -> V=1.0, theta=0.0
% INFO    : Bus 42890	: V=1.0097199, theta=18.699303 -> V=1.0, theta=0.0
% INFO    : Bus 42891	: V=1.00873, theta=18.606674 -> V=1.0, theta=0.0
% INFO    : Bus 42892	: V=1.003424, theta=18.553815 -> V=1.0, theta=0.0
% INFO    : Bus 42893	: V=1.0021003, theta=18.486536 -> V=1.0, theta=0.0
% INFO    : Bus 42894	: V=1.0006536, theta=18.410098 -> V=1.0, theta=0.0
% INFO    : Bus 42895	: V=1.0081636, theta=18.474168 -> V=1.0, theta=0.0
% INFO    : Bus 42896	: V=1.0076755, theta=18.302261 -> V=1.0, theta=0.0
% INFO    : Bus 42897	: V=1.0009133, theta=17.937439 -> V=1.0, theta=0.0
% INFO    : Bus 42898	: V=0.9942175, theta=17.614659 -> V=1.0, theta=0.0
% INFO    : Bus 42899	: V=1.0078834, theta=18.125492 -> V=1.0, theta=0.0
% INFO    : Bus 42900	: V=1.0068134, theta=16.176998 -> V=1.0, theta=0.0
% INFO    : Bus 42901	: V=0.9976393, theta=14.489365 -> V=1.0, theta=0.0
% INFO    : Bus 42902	: V=0.9809122, theta=15.091185 -> V=1.0, theta=0.0
% INFO    : Bus 42903	: V=1.0059284, theta=18.768487 -> V=1.0, theta=0.0
% INFO    : Bus 42904	: V=1.0059859, theta=18.686043 -> V=1.0, theta=0.0
% INFO    : Bus 42905	: V=0.9923513, theta=17.392491 -> V=1.0, theta=0.0
% INFO    : Bus 42906	: V=0.9965856, theta=17.987806 -> V=1.0, theta=0.0
% INFO    : Bus 42907	: V=0.9938655, theta=18.997608 -> V=1.0, theta=0.0
% INFO    : Bus 42908	: V=1.0114853, theta=18.988639 -> V=1.0, theta=0.0
% INFO    : Bus 42909	: V=1.0080995, theta=18.806821 -> V=1.0, theta=0.0
% INFO    : Bus 42910	: V=1.0199216, theta=19.588547 -> V=1.0, theta=0.0
% INFO    : Bus 42911	: V=1.009321, theta=18.784253 -> V=1.0, theta=0.0
% INFO    : Bus 42912	: V=1.0114055, theta=17.948002 -> V=1.0, theta=0.0
% INFO    : Bus 42913	: V=0.9888263, theta=17.174769 -> V=1.0, theta=0.0
% INFO    : Bus 42914	: V=0.9913235, theta=16.715724 -> V=1.0, theta=0.0
% INFO    : Bus 42915	: V=0.9892593, theta=16.436091 -> V=1.0, theta=0.0
% INFO    : Bus 42916	: V=0.9865062, theta=11.520732 -> V=1.0, theta=0.0
% INFO    : Bus 42917	: V=0.9944035, theta=11.566801 -> V=1.0, theta=0.0
% INFO    : Bus 42918	: V=1.0070066, theta=14.741631 -> V=1.0, theta=0.0
% INFO    : Bus 42919	: V=0.9904328, theta=11.047124 -> V=1.0, theta=0.0
% INFO    : Bus 42920	: V=1.0034947, theta=11.949447 -> V=1.0, theta=0.0
% INFO    : Bus 42921	: V=0.9913105, theta=9.781578 -> V=1.0, theta=0.0
% INFO    : Bus 42922	: V=1.008475, theta=8.729176 -> V=1.0, theta=0.0
% INFO    : Bus 42923	: V=1.0021388, theta=10.686989 -> V=1.0, theta=0.0
% INFO    : Bus 42924	: V=1.0077233, theta=29.061282 -> V=1.0, theta=0.0
% INFO    : Bus 42925	: V=1.0010914, theta=28.1127 -> V=1.0, theta=0.0
% INFO    : Bus 42926	: V=0.9880384, theta=33.285899 -> V=1.0, theta=0.0
% INFO    : Bus 42927	: V=0.9972965, theta=33.749629 -> V=1.0, theta=0.0
% INFO    : Bus 42928	: V=1.0073857, theta=34.153419 -> V=1.0, theta=0.0
% INFO    : Bus 42929	: V=0.9975106, theta=33.336795 -> V=1.0, theta=0.0
% INFO    : Bus 42930	: V=0.9955733, theta=33.369974 -> V=1.0, theta=0.0
% INFO    : Bus 42931	: V=0.998549, theta=33.408132 -> V=1.0, theta=0.0
% INFO    : Bus 42932	: V=0.9961753, theta=33.402774 -> V=1.0, theta=0.0
% INFO    : Bus 42933	: V=0.9959752, theta=33.419732 -> V=1.0, theta=0.0
% INFO    : Bus 42934	: V=0.995746, theta=33.396991 -> V=1.0, theta=0.0
% INFO    : Bus 42935	: V=0.9879461, theta=33.149714 -> V=1.0, theta=0.0
% INFO    : Bus 42936	: V=0.9864464, theta=33.124453 -> V=1.0, theta=0.0
% INFO    : Bus 42937	: V=0.9855905, theta=33.107107 -> V=1.0, theta=0.0
% INFO    : Bus 42938	: V=0.9853866, theta=33.115763 -> V=1.0, theta=0.0
% INFO    : Bus 42939	: V=1.0076894, theta=25.001991 -> V=1.0, theta=0.0
% INFO    : Bus 42940	: V=1.0077563, theta=24.834906 -> V=1.0, theta=0.0
% INFO    : Bus 42941	: V=1.0080583, theta=24.923032 -> V=1.0, theta=0.0
% INFO    : Bus 42942	: V=1.0089588, theta=25.05568 -> V=1.0, theta=0.0
% INFO    : Bus 42943	: V=1.015067, theta=25.194332 -> V=1.0, theta=0.0
% INFO    : Bus 42944	: V=1.0158996, theta=25.235026 -> V=1.0, theta=0.0
% INFO    : Bus 42945	: V=1.015748, theta=25.260968 -> V=1.0, theta=0.0
% INFO    : Bus 42946	: V=1.0159589, theta=25.227467 -> V=1.0, theta=0.0
% INFO    : Bus 42947	: V=1.0195903, theta=25.801212 -> V=1.0, theta=0.0
% INFO    : Bus 42948	: V=1.0082334, theta=24.838903 -> V=1.0, theta=0.0
% INFO    : Bus 42949	: V=1.0069709, theta=24.847766 -> V=1.0, theta=0.0
% INFO    : Bus 42950	: V=1.007359, theta=24.868806 -> V=1.0, theta=0.0
% INFO    : Bus 42951	: V=1.0039437, theta=24.959493 -> V=1.0, theta=0.0
% INFO    : Bus 42952	: V=1.0016901, theta=24.622342 -> V=1.0, theta=0.0
% INFO    : Bus 42953	: V=1.0015379, theta=24.572305 -> V=1.0, theta=0.0
% INFO    : Bus 42954	: V=1.0179605, theta=25.219607 -> V=1.0, theta=0.0
% INFO    : Bus 42955	: V=1.01338, theta=24.50444 -> V=1.0, theta=0.0
% INFO    : Bus 42956	: V=1.0172462, theta=24.845653 -> V=1.0, theta=0.0
% INFO    : Bus 42957	: V=1.0107371, theta=24.302111 -> V=1.0, theta=0.0
% INFO    : Bus 42958	: V=1.0094149, theta=23.883894 -> V=1.0, theta=0.0
% INFO    : Bus 42959	: V=1.0065053, theta=23.119178 -> V=1.0, theta=0.0
% INFO    : Bus 42960	: V=1.0037579, theta=24.222217 -> V=1.0, theta=0.0
% INFO    : Bus 42961	: V=1.0051875, theta=24.047294 -> V=1.0, theta=0.0
% INFO    : Bus 42962	: V=1.0160661, theta=24.025067 -> V=1.0, theta=0.0
% INFO    : Bus 42963	: V=1.0027574, theta=22.584889 -> V=1.0, theta=0.0
% INFO    : Bus 42964	: V=1.0091712, theta=21.069275 -> V=1.0, theta=0.0
% INFO    : Bus 42965	: V=0.9989003, theta=24.047784 -> V=1.0, theta=0.0
% INFO    : Bus 42966	: V=1.0010555, theta=24.2808 -> V=1.0, theta=0.0
% INFO    : Bus 42967	: V=0.9986072, theta=24.389106 -> V=1.0, theta=0.0
% INFO    : Bus 42968	: V=1.0057885, theta=24.72222 -> V=1.0, theta=0.0
% INFO    : Bus 42969	: V=1.0025308, theta=-0.615129 -> V=1.0, theta=0.0
% INFO    : Bus 42970	: V=1.0088178, theta=0.758972 -> V=1.0, theta=0.0
% INFO    : Bus 42971	: V=0.9985136, theta=-0.474952 -> V=1.0, theta=0.0
% INFO    : Bus 42972	: V=1.0072213, theta=-0.169334 -> V=1.0, theta=0.0
% INFO    : Bus 42973	: V=1.0068672, theta=-0.58011 -> V=1.0, theta=0.0
% INFO    : Bus 42974	: V=1.0162895, theta=13.5978 -> V=1.0, theta=0.0
% INFO    : Bus 42975	: V=1.0157852, theta=13.590494 -> V=1.0, theta=0.0
% INFO    : Bus 42976	: V=1.0079183, theta=13.473656 -> V=1.0, theta=0.0
% INFO    : Bus 42977	: V=1.0136446, theta=13.538421 -> V=1.0, theta=0.0
% INFO    : Bus 42978	: V=1.0072764, theta=13.546864 -> V=1.0, theta=0.0
% INFO    : Bus 42979	: V=1.0077622, theta=13.506554 -> V=1.0, theta=0.0
% INFO    : Bus 42980	: V=1.0091159, theta=13.613149 -> V=1.0, theta=0.0
% INFO    : Bus 42981	: V=1.0086988, theta=13.541153 -> V=1.0, theta=0.0
% INFO    : Bus 42982	: V=1.0184661, theta=13.706607 -> V=1.0, theta=0.0
% INFO    : Bus 42983	: V=1.0082356, theta=13.602435 -> V=1.0, theta=0.0
% INFO    : Bus 42984	: V=1.0105192, theta=13.702251 -> V=1.0, theta=0.0
% INFO    : Bus 42985	: V=0.9880581, theta=15.094794 -> V=1.0, theta=0.0
% INFO    : Bus 42986	: V=0.9922303, theta=14.890195 -> V=1.0, theta=0.0
% INFO    : Bus 42987	: V=1.0091872, theta=14.398165 -> V=1.0, theta=0.0
% INFO    : Bus 42988	: V=1.0063596, theta=13.639387 -> V=1.0, theta=0.0
% INFO    : Bus 42989	: V=1.0045165, theta=13.3838 -> V=1.0, theta=0.0
% INFO    : Bus 42990	: V=1.0086554, theta=12.569753 -> V=1.0, theta=0.0
% INFO    : Bus 42991	: V=1.013696, theta=13.332161 -> V=1.0, theta=0.0
% INFO    : Bus 42992	: V=1.0128396, theta=13.652553 -> V=1.0, theta=0.0
% INFO    : Bus 42993	: V=1.0124319, theta=14.165179 -> V=1.0, theta=0.0
% INFO    : Bus 42994	: V=0.997906, theta=10.929275 -> V=1.0, theta=0.0
% INFO    : Bus 42995	: V=1.0027612, theta=11.653305 -> V=1.0, theta=0.0
% INFO    : Bus 42996	: V=0.9973001, theta=11.035051 -> V=1.0, theta=0.0
% INFO    : Bus 42997	: V=1.014642, theta=13.556726 -> V=1.0, theta=0.0
% INFO    : Bus 42998	: V=0.9795743, theta=0.366251 -> V=1.0, theta=0.0
% INFO    : Bus 42999	: V=0.9781948, theta=0.134547 -> V=1.0, theta=0.0
% INFO    : Bus 43000	: V=0.9780331, theta=0.183116 -> V=1.0, theta=0.0
% INFO    : Bus 43001	: V=0.9806162, theta=0.297881 -> V=1.0, theta=0.0
% INFO    : Bus 43002	: V=0.9946418, theta=24.713169 -> V=1.0, theta=0.0
% INFO    : Bus 43003	: V=0.9901888, theta=23.549145 -> V=1.0, theta=0.0
% INFO    : Bus 43004	: V=0.9957004, theta=25.894199 -> V=1.0, theta=0.0
% INFO    : Bus 43005	: V=0.9933087, theta=24.990932 -> V=1.0, theta=0.0
% INFO    : Bus 43006	: V=0.9925874, theta=24.857902 -> V=1.0, theta=0.0
% INFO    : Bus 43007	: V=0.9996986, theta=2.32645 -> V=1.0, theta=0.0
% INFO    : Bus 43008	: V=1.0063169, theta=1.786333 -> V=1.0, theta=0.0
% INFO    : Bus 43009	: V=1.0001347, theta=2.440853 -> V=1.0, theta=0.0
% INFO    : Bus 43010	: V=1.0033774, theta=2.404141 -> V=1.0, theta=0.0
% INFO    : Bus 43011	: V=0.9835128, theta=0.461803 -> V=1.0, theta=0.0
% INFO    : Bus 43012	: V=1.0070451, theta=3.265095 -> V=1.0, theta=0.0
% INFO    : Bus 43013	: V=0.988102, theta=0.50939 -> V=1.0, theta=0.0
% INFO    : Bus 43014	: V=0.9958207, theta=0.31961 -> V=1.0, theta=0.0
% INFO    : Bus 43015	: V=0.9996094, theta=0.099774 -> V=1.0, theta=0.0
% INFO    : Bus 43016	: V=0.987143, theta=-0.980922 -> V=1.0, theta=0.0
% INFO    : Bus 43017	: V=0.9875987, theta=-1.041479 -> V=1.0, theta=0.0
% INFO    : Bus 43018	: V=0.9856535, theta=-0.569073 -> V=1.0, theta=0.0
% INFO    : Bus 43019	: V=0.9807008, theta=-1.046787 -> V=1.0, theta=0.0
% INFO    : Bus 43020	: V=0.9900349, theta=-1.319228 -> V=1.0, theta=0.0
% INFO    : Bus 43021	: V=1.0090552, theta=32.254882 -> V=1.0, theta=0.0
% INFO    : Bus 43022	: V=1.016025, theta=33.206938 -> V=1.0, theta=0.0
% INFO    : Bus 43023	: V=1.0185012, theta=33.254772 -> V=1.0, theta=0.0
% INFO    : Bus 43024	: V=1.0141238, theta=33.318872 -> V=1.0, theta=0.0
% INFO    : Bus 43025	: V=1.0169531, theta=33.533301 -> V=1.0, theta=0.0
% INFO    : Bus 43026	: V=1.0190551, theta=33.510436 -> V=1.0, theta=0.0
% INFO    : Bus 43027	: V=1.0122036, theta=32.187172 -> V=1.0, theta=0.0
% INFO    : Bus 43028	: V=1.0105218, theta=32.054368 -> V=1.0, theta=0.0
% INFO    : Bus 43029	: V=1.0035338, theta=32.140524 -> V=1.0, theta=0.0
% INFO    : Bus 43030	: V=1.0179774, theta=32.862001 -> V=1.0, theta=0.0
% INFO    : Bus 43031	: V=1.0112163, theta=32.299699 -> V=1.0, theta=0.0
% INFO    : Bus 43032	: V=1.0111212, theta=32.289929 -> V=1.0, theta=0.0
% INFO    : Bus 43033	: V=1.0110647, theta=32.279337 -> V=1.0, theta=0.0
% INFO    : Bus 43034	: V=1.0028666, theta=32.051304 -> V=1.0, theta=0.0
% INFO    : Bus 43035	: V=1.0040516, theta=32.0431 -> V=1.0, theta=0.0
% INFO    : Bus 43036	: V=1.0052553, theta=32.016789 -> V=1.0, theta=0.0
% INFO    : Bus 43037	: V=1.0108149, theta=32.211427 -> V=1.0, theta=0.0
% INFO    : Bus 43038	: V=1.0103931, theta=32.132098 -> V=1.0, theta=0.0
% INFO    : Bus 43039	: V=0.9864291, theta=21.18297 -> V=1.0, theta=0.0
% INFO    : Bus 43040	: V=0.9864379, theta=21.096184 -> V=1.0, theta=0.0
% INFO    : Bus 43041	: V=0.9863602, theta=21.102267 -> V=1.0, theta=0.0
% INFO    : Bus 43042	: V=0.9967539, theta=21.378874 -> V=1.0, theta=0.0
% INFO    : Bus 43043	: V=0.9940442, theta=21.133784 -> V=1.0, theta=0.0
% INFO    : Bus 43044	: V=0.9931888, theta=21.131357 -> V=1.0, theta=0.0
% INFO    : Bus 43045	: V=0.9998857, theta=21.365502 -> V=1.0, theta=0.0
% INFO    : Bus 43046	: V=0.9941983, theta=21.091133 -> V=1.0, theta=0.0
% INFO    : Bus 43047	: V=0.9944018, theta=21.109893 -> V=1.0, theta=0.0
% INFO    : Bus 43048	: V=0.9895035, theta=20.996654 -> V=1.0, theta=0.0
% INFO    : Bus 43049	: V=0.9924049, theta=21.128808 -> V=1.0, theta=0.0
% INFO    : Bus 43050	: V=0.9848554, theta=21.217897 -> V=1.0, theta=0.0
% INFO    : Bus 43051	: V=0.9896143, theta=21.350309 -> V=1.0, theta=0.0
% INFO    : Bus 43052	: V=0.9906929, theta=21.261427 -> V=1.0, theta=0.0
% INFO    : Bus 43053	: V=0.9945764, theta=21.147177 -> V=1.0, theta=0.0
% INFO    : Bus 43054	: V=1.0035779, theta=21.363245 -> V=1.0, theta=0.0
% INFO    : Bus 43055	: V=0.9974161, theta=21.018122 -> V=1.0, theta=0.0
% INFO    : Bus 43056	: V=0.9970573, theta=21.112602 -> V=1.0, theta=0.0
% INFO    : Bus 43057	: V=0.9900131, theta=21.448168 -> V=1.0, theta=0.0
% INFO    : Bus 43058	: V=0.9897737, theta=21.400936 -> V=1.0, theta=0.0
% INFO    : Bus 43059	: V=0.9864815, theta=21.343298 -> V=1.0, theta=0.0
% INFO    : Bus 43060	: V=0.9918765, theta=21.374191 -> V=1.0, theta=0.0
% INFO    : Bus 43061	: V=0.9896189, theta=21.535013 -> V=1.0, theta=0.0
% INFO    : Bus 43062	: V=0.9949124, theta=21.308968 -> V=1.0, theta=0.0
% INFO    : Bus 43063	: V=0.9854291, theta=21.553006 -> V=1.0, theta=0.0
% INFO    : Bus 43064	: V=1.0107543, theta=22.348908 -> V=1.0, theta=0.0
% INFO    : Bus 43065	: V=0.984315, theta=21.722488 -> V=1.0, theta=0.0
% INFO    : Bus 43066	: V=0.9883234, theta=21.872441 -> V=1.0, theta=0.0
% INFO    : Bus 43067	: V=0.9874547, theta=22.002232 -> V=1.0, theta=0.0
% INFO    : Bus 43068	: V=1.0120284, theta=22.363727 -> V=1.0, theta=0.0
% INFO    : Bus 43069	: V=0.999344, theta=21.206123 -> V=1.0, theta=0.0
% INFO    : Bus 43070	: V=1.0057564, theta=21.55729 -> V=1.0, theta=0.0
% INFO    : Bus 43071	: V=0.9991048, theta=21.244266 -> V=1.0, theta=0.0
% INFO    : Bus 43072	: V=1.0055262, theta=21.377556 -> V=1.0, theta=0.0
% INFO    : Bus 43073	: V=1.0065602, theta=21.500638 -> V=1.0, theta=0.0
% INFO    : Bus 43074	: V=1.0068432, theta=21.434856 -> V=1.0, theta=0.0
% INFO    : Bus 43075	: V=1.0073102, theta=21.561152 -> V=1.0, theta=0.0
% INFO    : Bus 43076	: V=1.0054362, theta=21.430082 -> V=1.0, theta=0.0
% INFO    : Bus 43077	: V=1.0075159, theta=21.625142 -> V=1.0, theta=0.0
% INFO    : Bus 43078	: V=1.0137479, theta=22.429894 -> V=1.0, theta=0.0
% INFO    : Bus 43079	: V=1.0045872, theta=21.537129 -> V=1.0, theta=0.0
% INFO    : Bus 43080	: V=1.0077725, theta=21.941462 -> V=1.0, theta=0.0
% INFO    : Bus 43081	: V=1.0062723, theta=21.281283 -> V=1.0, theta=0.0
% INFO    : Bus 43082	: V=0.9986071, theta=21.174233 -> V=1.0, theta=0.0
% INFO    : Bus 43083	: V=0.9976635, theta=21.046382 -> V=1.0, theta=0.0
% INFO    : Bus 43084	: V=0.9992853, theta=21.185125 -> V=1.0, theta=0.0
% INFO    : Bus 43085	: V=0.9993333, theta=20.398766 -> V=1.0, theta=0.0
% INFO    : Bus 43086	: V=1.0067724, theta=21.217017 -> V=1.0, theta=0.0
% INFO    : Bus 43087	: V=0.9997447, theta=20.425311 -> V=1.0, theta=0.0
% INFO    : Bus 43088	: V=1.0002329, theta=20.452509 -> V=1.0, theta=0.0
% INFO    : Bus 43089	: V=1.0015334, theta=21.07784 -> V=1.0, theta=0.0
% INFO    : Bus 43090	: V=1.0019219, theta=20.947015 -> V=1.0, theta=0.0
% INFO    : Bus 43091	: V=1.003168, theta=20.897637 -> V=1.0, theta=0.0
% INFO    : Bus 43092	: V=0.996132, theta=20.078191 -> V=1.0, theta=0.0
% INFO    : Bus 43093	: V=0.9943278, theta=19.873184 -> V=1.0, theta=0.0
% INFO    : Bus 43094	: V=0.9933278, theta=19.799848 -> V=1.0, theta=0.0
% INFO    : Bus 43095	: V=0.9897615, theta=19.779953 -> V=1.0, theta=0.0
% INFO    : Bus 43096	: V=0.9947547, theta=19.887582 -> V=1.0, theta=0.0
% INFO    : Bus 43097	: V=0.9989571, theta=20.387537 -> V=1.0, theta=0.0
% INFO    : Bus 43098	: V=0.9941016, theta=19.846815 -> V=1.0, theta=0.0
% INFO    : Bus 43099	: V=0.9917489, theta=19.543289 -> V=1.0, theta=0.0
% INFO    : Bus 43100	: V=0.9927645, theta=19.669864 -> V=1.0, theta=0.0
% INFO    : Bus 43101	: V=0.992868, theta=19.114406 -> V=1.0, theta=0.0
% INFO    : Bus 43102	: V=0.9958148, theta=19.406084 -> V=1.0, theta=0.0
% INFO    : Bus 43103	: V=0.9977306, theta=19.773706 -> V=1.0, theta=0.0
% INFO    : Bus 43104	: V=0.9966042, theta=19.643513 -> V=1.0, theta=0.0
% INFO    : Bus 43105	: V=0.9968004, theta=19.437958 -> V=1.0, theta=0.0
% INFO    : Bus 43106	: V=1.007948, theta=19.952766 -> V=1.0, theta=0.0
% INFO    : Bus 43107	: V=0.9942057, theta=18.893037 -> V=1.0, theta=0.0
% INFO    : Bus 43108	: V=0.9941846, theta=19.154566 -> V=1.0, theta=0.0
% INFO    : Bus 43109	: V=0.9929109, theta=18.974699 -> V=1.0, theta=0.0
% INFO    : Bus 43110	: V=0.9993667, theta=20.332298 -> V=1.0, theta=0.0
% INFO    : Bus 43111	: V=1.0017592, theta=20.518249 -> V=1.0, theta=0.0
% INFO    : Bus 43112	: V=1.0019869, theta=20.57064 -> V=1.0, theta=0.0
% INFO    : Bus 43113	: V=1.0031281, theta=20.938787 -> V=1.0, theta=0.0
% INFO    : Bus 43114	: V=1.0035626, theta=20.868717 -> V=1.0, theta=0.0
% INFO    : Bus 43115	: V=1.0038577, theta=20.87538 -> V=1.0, theta=0.0
% INFO    : Bus 43116	: V=1.0048072, theta=20.971357 -> V=1.0, theta=0.0
% INFO    : Bus 43117	: V=1.0044167, theta=20.933651 -> V=1.0, theta=0.0
% INFO    : Bus 43118	: V=1.0024156, theta=20.961996 -> V=1.0, theta=0.0
% INFO    : Bus 43119	: V=1.0036986, theta=20.818839 -> V=1.0, theta=0.0
% INFO    : Bus 43120	: V=1.0008638, theta=20.640406 -> V=1.0, theta=0.0
% INFO    : Bus 43121	: V=1.0027729, theta=20.675778 -> V=1.0, theta=0.0
% INFO    : Bus 43122	: V=1.0026109, theta=20.598923 -> V=1.0, theta=0.0
% INFO    : Bus 43123	: V=1.001566, theta=20.455431 -> V=1.0, theta=0.0
% INFO    : Bus 43124	: V=1.006656, theta=20.657822 -> V=1.0, theta=0.0
% INFO    : Bus 43125	: V=0.9994429, theta=20.179551 -> V=1.0, theta=0.0
% INFO    : Bus 43126	: V=1.002094, theta=20.517972 -> V=1.0, theta=0.0
% INFO    : Bus 43127	: V=0.9998398, theta=20.604322 -> V=1.0, theta=0.0
% INFO    : Bus 43128	: V=1.0083354, theta=20.827598 -> V=1.0, theta=0.0
% INFO    : Bus 43129	: V=1.0034387, theta=20.710605 -> V=1.0, theta=0.0
% INFO    : Bus 43130	: V=1.0036173, theta=20.772183 -> V=1.0, theta=0.0
% INFO    : Bus 43131	: V=1.003162, theta=20.72277 -> V=1.0, theta=0.0
% INFO    : Bus 43132	: V=1.004085, theta=20.797188 -> V=1.0, theta=0.0
% INFO    : Bus 43133	: V=1.0053772, theta=21.039377 -> V=1.0, theta=0.0
% INFO    : Bus 43134	: V=1.0113842, theta=21.097415 -> V=1.0, theta=0.0
% INFO    : Bus 43135	: V=1.0095517, theta=20.449501 -> V=1.0, theta=0.0
% INFO    : Bus 43136	: V=1.010783, theta=20.79566 -> V=1.0, theta=0.0
% INFO    : Bus 43137	: V=1.0042683, theta=21.235177 -> V=1.0, theta=0.0
% INFO    : Bus 43138	: V=1.0062603, theta=21.434884 -> V=1.0, theta=0.0
% INFO    : Bus 43139	: V=1.0069322, theta=21.488011 -> V=1.0, theta=0.0
% INFO    : Bus 43140	: V=1.0066966, theta=21.318113 -> V=1.0, theta=0.0
% INFO    : Bus 43141	: V=1.0075632, theta=21.295672 -> V=1.0, theta=0.0
% INFO    : Bus 43142	: V=1.017393, theta=22.658041 -> V=1.0, theta=0.0
% INFO    : Bus 43143	: V=1.0163751, theta=22.5848 -> V=1.0, theta=0.0
% INFO    : Bus 43144	: V=1.015557, theta=22.500747 -> V=1.0, theta=0.0
% INFO    : Bus 43145	: V=1.0151448, theta=22.509806 -> V=1.0, theta=0.0
% INFO    : Bus 43146	: V=1.0159448, theta=22.54011 -> V=1.0, theta=0.0
% INFO    : Bus 43147	: V=1.0164465, theta=21.837854 -> V=1.0, theta=0.0
% INFO    : Bus 43148	: V=1.0083097, theta=21.562926 -> V=1.0, theta=0.0
% INFO    : Bus 43149	: V=1.0159762, theta=22.057555 -> V=1.0, theta=0.0
% INFO    : Bus 43150	: V=1.0147869, theta=21.549019 -> V=1.0, theta=0.0
% INFO    : Bus 43151	: V=1.0048984, theta=19.827037 -> V=1.0, theta=0.0
% INFO    : Bus 43152	: V=1.0128119, theta=21.493787 -> V=1.0, theta=0.0
% INFO    : Bus 43153	: V=1.0173826, theta=21.627148 -> V=1.0, theta=0.0
% INFO    : Bus 43154	: V=0.9954254, theta=15.901903 -> V=1.0, theta=0.0
% INFO    : Bus 43155	: V=0.9903493, theta=18.292354 -> V=1.0, theta=0.0
% INFO    : Bus 43156	: V=0.999763, theta=16.799028 -> V=1.0, theta=0.0
% INFO    : Bus 43157	: V=0.9996124, theta=18.768277 -> V=1.0, theta=0.0
% INFO    : Bus 43158	: V=0.9964195, theta=18.829904 -> V=1.0, theta=0.0
% INFO    : Bus 43159	: V=0.9841581, theta=18.217984 -> V=1.0, theta=0.0
% INFO    : Bus 43160	: V=0.9867336, theta=18.222436 -> V=1.0, theta=0.0
% INFO    : Bus 43161	: V=0.9844591, theta=18.196159 -> V=1.0, theta=0.0
% INFO    : Bus 43162	: V=0.9880496, theta=18.764714 -> V=1.0, theta=0.0
% INFO    : Bus 43163	: V=0.9906102, theta=18.28752 -> V=1.0, theta=0.0
% INFO    : Bus 43164	: V=0.9906108, theta=18.820296 -> V=1.0, theta=0.0
% INFO    : Bus 43165	: V=0.9908979, theta=18.891233 -> V=1.0, theta=0.0
% INFO    : Bus 43166	: V=0.9890041, theta=18.636683 -> V=1.0, theta=0.0
% INFO    : Bus 43167	: V=0.9881932, theta=18.504019 -> V=1.0, theta=0.0
% INFO    : Bus 43168	: V=0.9988493, theta=18.322181 -> V=1.0, theta=0.0
% INFO    : Bus 43169	: V=0.9930528, theta=18.366784 -> V=1.0, theta=0.0
% INFO    : Bus 43170	: V=0.9910272, theta=18.406146 -> V=1.0, theta=0.0
% INFO    : Bus 43171	: V=0.9959386, theta=18.353978 -> V=1.0, theta=0.0
% INFO    : Bus 43172	: V=0.9950806, theta=18.845548 -> V=1.0, theta=0.0
% INFO    : Bus 43173	: V=0.9946755, theta=18.660708 -> V=1.0, theta=0.0
% INFO    : Bus 43174	: V=0.9982692, theta=18.94401 -> V=1.0, theta=0.0
% INFO    : Bus 43175	: V=0.9929241, theta=18.711138 -> V=1.0, theta=0.0
% INFO    : Bus 43176	: V=1.0031194, theta=19.086236 -> V=1.0, theta=0.0
% INFO    : Bus 43177	: V=0.9976066, theta=18.628395 -> V=1.0, theta=0.0
% INFO    : Bus 43178	: V=0.9974328, theta=18.922162 -> V=1.0, theta=0.0
% INFO    : Bus 43179	: V=1.0024625, theta=19.077054 -> V=1.0, theta=0.0
% INFO    : Bus 43180	: V=1.0000455, theta=18.969965 -> V=1.0, theta=0.0
% INFO    : Bus 43181	: V=0.9895328, theta=18.556624 -> V=1.0, theta=0.0
% INFO    : Bus 43182	: V=0.9955567, theta=18.614206 -> V=1.0, theta=0.0
% INFO    : Bus 43183	: V=1.0128849, theta=21.33191 -> V=1.0, theta=0.0
% INFO    : Bus 43184	: V=1.0118908, theta=21.242317 -> V=1.0, theta=0.0
% INFO    : Bus 43185	: V=1.0111863, theta=21.264102 -> V=1.0, theta=0.0
% INFO    : Bus 43186	: V=1.0061233, theta=20.109879 -> V=1.0, theta=0.0
% INFO    : Bus 43187	: V=0.9981191, theta=21.080822 -> V=1.0, theta=0.0
% INFO    : Bus 43188	: V=1.0073958, theta=21.177301 -> V=1.0, theta=0.0
% INFO    : Bus 43189	: V=1.0124584, theta=21.534129 -> V=1.0, theta=0.0
% INFO    : Bus 43190	: V=1.0030136, theta=20.860248 -> V=1.0, theta=0.0
% INFO    : Bus 43191	: V=1.0106119, theta=-0.390115 -> V=1.0, theta=0.0
% INFO    : Bus 43192	: V=1.0131004, theta=-0.510631 -> V=1.0, theta=0.0
% INFO    : Bus 43193	: V=1.0124412, theta=-0.26849 -> V=1.0, theta=0.0
% INFO    : Bus 43194	: V=1.0134841, theta=-0.695517 -> V=1.0, theta=0.0
% INFO    : Bus 43195	: V=1.0134819, theta=-0.58423 -> V=1.0, theta=0.0
% INFO    : Bus 43196	: V=1.0134198, theta=-0.637476 -> V=1.0, theta=0.0
% INFO    : Bus 43197	: V=1.0158307, theta=-0.311206 -> V=1.0, theta=0.0
% INFO    : Bus 43198	: V=1.0092522, theta=-0.805438 -> V=1.0, theta=0.0
% INFO    : Bus 43199	: V=1.0095759, theta=-1.340252 -> V=1.0, theta=0.0
% INFO    : Bus 43200	: V=1.0112277, theta=-0.8292 -> V=1.0, theta=0.0
% INFO    : Bus 43201	: V=1.0188241, theta=-1.097007 -> V=1.0, theta=0.0
% INFO    : Bus 43202	: V=1.0134158, theta=-0.950661 -> V=1.0, theta=0.0
% INFO    : Bus 43203	: V=1.0188684, theta=-1.053454 -> V=1.0, theta=0.0
% INFO    : Bus 43204	: V=1.0189757, theta=-1.074992 -> V=1.0, theta=0.0
% INFO    : Bus 43205	: V=1.0131731, theta=-0.869509 -> V=1.0, theta=0.0
% INFO    : Bus 43206	: V=0.9886419, theta=32.813687 -> V=1.0, theta=0.0
% INFO    : Bus 43207	: V=0.9887549, theta=32.732956 -> V=1.0, theta=0.0
% INFO    : Bus 43208	: V=0.9949689, theta=32.939191 -> V=1.0, theta=0.0
% INFO    : Bus 43209	: V=0.989384, theta=32.843321 -> V=1.0, theta=0.0
% INFO    : Bus 43210	: V=0.9951954, theta=32.902774 -> V=1.0, theta=0.0
% INFO    : Bus 43211	: V=0.9956473, theta=32.897195 -> V=1.0, theta=0.0
% INFO    : Bus 43212	: V=0.993642, theta=32.707627 -> V=1.0, theta=0.0
% INFO    : Bus 43213	: V=0.9926505, theta=32.700344 -> V=1.0, theta=0.0
% INFO    : Bus 43214	: V=0.9913675, theta=32.701825 -> V=1.0, theta=0.0
% INFO    : Bus 43215	: V=0.9977143, theta=32.60803 -> V=1.0, theta=0.0
% INFO    : Bus 43216	: V=0.9971485, theta=32.62674 -> V=1.0, theta=0.0
% INFO    : Bus 43217	: V=0.9901457, theta=32.670318 -> V=1.0, theta=0.0
% INFO    : Bus 43218	: V=0.9915631, theta=32.647492 -> V=1.0, theta=0.0
% INFO    : Bus 43219	: V=0.996643, theta=32.648098 -> V=1.0, theta=0.0
% INFO    : Bus 43220	: V=0.9879517, theta=32.673906 -> V=1.0, theta=0.0
% INFO    : Bus 43221	: V=0.9913134, theta=32.641524 -> V=1.0, theta=0.0
% INFO    : Bus 43222	: V=0.9891523, theta=32.647318 -> V=1.0, theta=0.0
% INFO    : Bus 43223	: V=0.9913224, theta=32.625469 -> V=1.0, theta=0.0
% INFO    : Bus 43224	: V=0.9903309, theta=32.635593 -> V=1.0, theta=0.0
% INFO    : Bus 43225	: V=0.9939112, theta=32.701448 -> V=1.0, theta=0.0
% INFO    : Bus 43226	: V=0.994796, theta=32.817951 -> V=1.0, theta=0.0
% INFO    : Bus 43227	: V=0.9953067, theta=32.809043 -> V=1.0, theta=0.0
% INFO    : Bus 43228	: V=0.997413, theta=32.854924 -> V=1.0, theta=0.0
% INFO    : Bus 43229	: V=0.9970926, theta=32.84972 -> V=1.0, theta=0.0
% INFO    : Bus 43230	: V=0.9971809, theta=32.807673 -> V=1.0, theta=0.0
% INFO    : Bus 43231	: V=0.9971335, theta=32.807244 -> V=1.0, theta=0.0
% INFO    : Bus 43232	: V=0.9978719, theta=32.810617 -> V=1.0, theta=0.0
% INFO    : Bus 43233	: V=0.9955492, theta=32.729579 -> V=1.0, theta=0.0
% INFO    : Bus 43234	: V=0.9957225, theta=32.703069 -> V=1.0, theta=0.0
% INFO    : Bus 43235	: V=0.9974081, theta=32.754212 -> V=1.0, theta=0.0
% INFO    : Bus 43236	: V=1.0129352, theta=33.436717 -> V=1.0, theta=0.0
% INFO    : Bus 43237	: V=0.9995568, theta=32.817254 -> V=1.0, theta=0.0
% INFO    : Bus 43238	: V=1.0134026, theta=33.486485 -> V=1.0, theta=0.0
% INFO    : Bus 43239	: V=0.9987388, theta=32.866759 -> V=1.0, theta=0.0
% INFO    : Bus 43240	: V=0.9975511, theta=32.863029 -> V=1.0, theta=0.0
% INFO    : Bus 43241	: V=0.9937496, theta=32.911478 -> V=1.0, theta=0.0
% INFO    : Bus 43242	: V=0.9943388, theta=32.923259 -> V=1.0, theta=0.0
% INFO    : Bus 43243	: V=0.9937493, theta=32.905774 -> V=1.0, theta=0.0
% INFO    : Bus 43244	: V=0.9970247, theta=32.873558 -> V=1.0, theta=0.0
% INFO    : Bus 43245	: V=0.9933008, theta=32.865513 -> V=1.0, theta=0.0
% INFO    : Bus 43246	: V=0.9944116, theta=32.812245 -> V=1.0, theta=0.0
% INFO    : Bus 43247	: V=0.9946183, theta=32.805405 -> V=1.0, theta=0.0
% INFO    : Bus 43248	: V=0.9969985, theta=32.871964 -> V=1.0, theta=0.0
% INFO    : Bus 43249	: V=0.9946048, theta=32.823056 -> V=1.0, theta=0.0
% INFO    : Bus 43250	: V=0.9970208, theta=32.89567 -> V=1.0, theta=0.0
% INFO    : Bus 43251	: V=0.9930172, theta=32.883952 -> V=1.0, theta=0.0
% INFO    : Bus 43252	: V=0.9927289, theta=32.877373 -> V=1.0, theta=0.0
% INFO    : Bus 43253	: V=0.9965329, theta=32.896414 -> V=1.0, theta=0.0
% INFO    : Bus 43254	: V=0.9963333, theta=32.89598 -> V=1.0, theta=0.0
% INFO    : Bus 43255	: V=0.9936423, theta=32.929037 -> V=1.0, theta=0.0
% INFO    : Bus 43256	: V=0.9920284, theta=32.895395 -> V=1.0, theta=0.0
% INFO    : Bus 43257	: V=0.9930854, theta=32.908699 -> V=1.0, theta=0.0
% INFO    : Bus 43258	: V=0.9935559, theta=32.955512 -> V=1.0, theta=0.0
% INFO    : Bus 43259	: V=0.9931282, theta=32.931789 -> V=1.0, theta=0.0
% INFO    : Bus 43260	: V=0.9931162, theta=32.712874 -> V=1.0, theta=0.0
% INFO    : Bus 43261	: V=1.0021454, theta=32.735103 -> V=1.0, theta=0.0
% INFO    : Bus 43262	: V=1.0009018, theta=32.502395 -> V=1.0, theta=0.0
% INFO    : Bus 43263	: V=0.9990647, theta=32.565139 -> V=1.0, theta=0.0
% INFO    : Bus 43264	: V=0.9984203, theta=32.584665 -> V=1.0, theta=0.0
% INFO    : Bus 43265	: V=0.9947479, theta=32.691959 -> V=1.0, theta=0.0
% INFO    : Bus 43266	: V=1.0151057, theta=33.620291 -> V=1.0, theta=0.0
% INFO    : Bus 43267	: V=1.0011208, theta=33.387532 -> V=1.0, theta=0.0
% INFO    : Bus 43268	: V=0.9985292, theta=33.25691 -> V=1.0, theta=0.0
% INFO    : Bus 43269	: V=0.9903482, theta=32.970494 -> V=1.0, theta=0.0
% INFO    : Bus 43270	: V=0.9938563, theta=32.853526 -> V=1.0, theta=0.0
% INFO    : Bus 43271	: V=0.9953128, theta=32.99737 -> V=1.0, theta=0.0
% INFO    : Bus 43272	: V=0.9881345, theta=32.71651 -> V=1.0, theta=0.0
% INFO    : Bus 43273	: V=1.0037078, theta=33.599977 -> V=1.0, theta=0.0
% INFO    : Bus 43274	: V=1.0042652, theta=33.744536 -> V=1.0, theta=0.0
% INFO    : Bus 43275	: V=1.0026586, theta=33.545892 -> V=1.0, theta=0.0
% INFO    : Bus 43276	: V=1.0153974, theta=34.476854 -> V=1.0, theta=0.0
% INFO    : Bus 43277	: V=1.0054905, theta=33.748025 -> V=1.0, theta=0.0
% INFO    : Bus 43278	: V=1.0001232, theta=33.656374 -> V=1.0, theta=0.0
% INFO    : Bus 43279	: V=1.0025678, theta=33.707408 -> V=1.0, theta=0.0
% INFO    : Bus 43280	: V=1.0139854, theta=33.630139 -> V=1.0, theta=0.0
% INFO    : Bus 43281	: V=0.9865777, theta=32.709099 -> V=1.0, theta=0.0
% INFO    : Bus 43282	: V=1.014315, theta=33.559671 -> V=1.0, theta=0.0
% INFO    : Bus 43283	: V=1.0037271, theta=24.372539 -> V=1.0, theta=0.0
% INFO    : Bus 43284	: V=1.0117991, theta=22.617555 -> V=1.0, theta=0.0
% INFO    : Bus 43285	: V=1.0119223, theta=22.916178 -> V=1.0, theta=0.0
% INFO    : Bus 43286	: V=1.0035499, theta=24.496024 -> V=1.0, theta=0.0
% INFO    : Bus 43287	: V=0.9954399, theta=24.847396 -> V=1.0, theta=0.0
% INFO    : Bus 43288	: V=0.9946461, theta=24.985338 -> V=1.0, theta=0.0
% INFO    : Bus 43289	: V=0.9994767, theta=23.241569 -> V=1.0, theta=0.0
% INFO    : Bus 43290	: V=1.00156, theta=21.93467 -> V=1.0, theta=0.0
% INFO    : Bus 43291	: V=0.9980323, theta=21.977625 -> V=1.0, theta=0.0
% INFO    : Bus 43292	: V=1.0056828, theta=11.848876 -> V=1.0, theta=0.0
% INFO    : Bus 43293	: V=1.0190076, theta=11.484922 -> V=1.0, theta=0.0
% INFO    : Bus 43294	: V=1.0186311, theta=11.394716 -> V=1.0, theta=0.0
% INFO    : Bus 43295	: V=1.0057804, theta=8.294969 -> V=1.0, theta=0.0
% INFO    : Bus 43296	: V=1.0071738, theta=7.906759 -> V=1.0, theta=0.0
% INFO    : Bus 43297	: V=1.0050315, theta=37.807927 -> V=1.0, theta=0.0
% INFO    : Bus 43298	: V=0.9868008, theta=36.764209 -> V=1.0, theta=0.0
% INFO    : Bus 43299	: V=0.970377, theta=35.947341 -> V=1.0, theta=0.0
% INFO    : Bus 43300	: V=0.99663, theta=36.412296 -> V=1.0, theta=0.0
% INFO    : Bus 43301	: V=0.9825223, theta=34.989957 -> V=1.0, theta=0.0
% INFO    : Bus 43302	: V=1.0091207, theta=18.183895 -> V=1.0, theta=0.0
% INFO    : Bus 43303	: V=1.0066675, theta=17.745172 -> V=1.0, theta=0.0
% INFO    : Bus 43304	: V=1.0116984, theta=18.252928 -> V=1.0, theta=0.0
% INFO    : Bus 43305	: V=1.014101, theta=18.355685 -> V=1.0, theta=0.0
% INFO    : Bus 43306	: V=1.0129298, theta=18.393598 -> V=1.0, theta=0.0
% INFO    : Bus 43307	: V=1.0016067, theta=13.139092 -> V=1.0, theta=0.0
% INFO    : Bus 43308	: V=1.0024489, theta=13.112787 -> V=1.0, theta=0.0
% INFO    : Bus 43309	: V=1.0118806, theta=12.811778 -> V=1.0, theta=0.0
% INFO    : Bus 43310	: V=1.0075761, theta=28.944171 -> V=1.0, theta=0.0
% INFO    : Bus 43311	: V=1.013841, theta=28.460723 -> V=1.0, theta=0.0
% INFO    : Bus 43312	: V=1.0156824, theta=28.872961 -> V=1.0, theta=0.0
% INFO    : Bus 43313	: V=1.0177086, theta=29.014737 -> V=1.0, theta=0.0
% INFO    : Bus 43314	: V=1.0136275, theta=28.037526 -> V=1.0, theta=0.0
% INFO    : Bus 43315	: V=1.0113387, theta=27.641007 -> V=1.0, theta=0.0
% INFO    : Bus 43316	: V=1.0119704, theta=27.613626 -> V=1.0, theta=0.0
% INFO    : Bus 43317	: V=1.0070042, theta=28.542529 -> V=1.0, theta=0.0
% INFO    : Bus 43318	: V=1.007762, theta=28.530647 -> V=1.0, theta=0.0
% INFO    : Bus 43319	: V=1.0144478, theta=28.742184 -> V=1.0, theta=0.0
% INFO    : Bus 43320	: V=1.0143743, theta=28.78 -> V=1.0, theta=0.0
% INFO    : Bus 43321	: V=1.0065023, theta=28.533892 -> V=1.0, theta=0.0
% INFO    : Bus 43322	: V=1.0067926, theta=28.54831 -> V=1.0, theta=0.0
% INFO    : Bus 43323	: V=1.0122625, theta=28.689518 -> V=1.0, theta=0.0
% INFO    : Bus 43324	: V=1.0130469, theta=28.656861 -> V=1.0, theta=0.0
% INFO    : Bus 43325	: V=1.008016, theta=28.56961 -> V=1.0, theta=0.0
% INFO    : Bus 43326	: V=1.0083621, theta=28.515196 -> V=1.0, theta=0.0
% INFO    : Bus 43327	: V=1.0089885, theta=28.504818 -> V=1.0, theta=0.0
% INFO    : Bus 43328	: V=1.0142237, theta=28.641325 -> V=1.0, theta=0.0
% INFO    : Bus 43329	: V=1.0101302, theta=28.475446 -> V=1.0, theta=0.0
% INFO    : Bus 43330	: V=1.0152391, theta=28.708864 -> V=1.0, theta=0.0
% INFO    : Bus 43331	: V=1.0171021, theta=28.676382 -> V=1.0, theta=0.0
% INFO    : Bus 43332	: V=1.0164255, theta=28.718587 -> V=1.0, theta=0.0
% INFO    : Bus 43333	: V=1.0080232, theta=28.59139 -> V=1.0, theta=0.0
% INFO    : Bus 43334	: V=1.0134408, theta=28.969901 -> V=1.0, theta=0.0
% INFO    : Bus 43335	: V=1.0055933, theta=28.549243 -> V=1.0, theta=0.0
% INFO    : Bus 43336	: V=1.0134202, theta=28.871067 -> V=1.0, theta=0.0
% INFO    : Bus 43337	: V=1.0054511, theta=28.553232 -> V=1.0, theta=0.0
% INFO    : Bus 43338	: V=1.0125244, theta=28.700306 -> V=1.0, theta=0.0
% INFO    : Bus 43339	: V=1.0125785, theta=28.686557 -> V=1.0, theta=0.0
% INFO    : Bus 43340	: V=1.0145433, theta=28.687705 -> V=1.0, theta=0.0
% INFO    : Bus 43341	: V=1.0136276, theta=28.655189 -> V=1.0, theta=0.0
% INFO    : Bus 43342	: V=1.0147505, theta=28.736405 -> V=1.0, theta=0.0
% INFO    : Bus 43343	: V=1.0145988, theta=28.71346 -> V=1.0, theta=0.0
% INFO    : Bus 43344	: V=1.0097731, theta=28.569697 -> V=1.0, theta=0.0
% INFO    : Bus 43345	: V=1.0067583, theta=28.477935 -> V=1.0, theta=0.0
% INFO    : Bus 43346	: V=1.0173238, theta=28.671136 -> V=1.0, theta=0.0
% INFO    : Bus 43347	: V=1.0081243, theta=29.175864 -> V=1.0, theta=0.0
% INFO    : Bus 43348	: V=1.0119135, theta=29.225463 -> V=1.0, theta=0.0
% INFO    : Bus 43349	: V=0.9975548, theta=28.368589 -> V=1.0, theta=0.0
% INFO    : Bus 43350	: V=1.0061565, theta=28.824982 -> V=1.0, theta=0.0
% INFO    : Bus 43351	: V=1.0125286, theta=28.666908 -> V=1.0, theta=0.0
% INFO    : Bus 43352	: V=1.0125948, theta=28.591321 -> V=1.0, theta=0.0
% INFO    : Bus 43353	: V=1.0161319, theta=28.624241 -> V=1.0, theta=0.0
% INFO    : Bus 43354	: V=1.016376, theta=28.47361 -> V=1.0, theta=0.0
% INFO    : Bus 43355	: V=0.9822979, theta=19.911205 -> V=1.0, theta=0.0
% INFO    : Bus 43356	: V=0.992806, theta=19.406621 -> V=1.0, theta=0.0
% INFO    : Bus 43357	: V=0.9817152, theta=18.967695 -> V=1.0, theta=0.0
% INFO    : Bus 43358	: V=0.9813049, theta=18.97902 -> V=1.0, theta=0.0
% INFO    : Bus 43359	: V=0.9762046, theta=17.886547 -> V=1.0, theta=0.0
% INFO    : Bus 43360	: V=0.9910324, theta=14.985989 -> V=1.0, theta=0.0
% INFO    : Bus 43361	: V=0.9918701, theta=18.864272 -> V=1.0, theta=0.0
% INFO    : Bus 43362	: V=1.000857, theta=30.06025 -> V=1.0, theta=0.0
% INFO    : Bus 43363	: V=0.9999341, theta=30.228336 -> V=1.0, theta=0.0
% INFO    : Bus 43364	: V=1.0109484, theta=29.947492 -> V=1.0, theta=0.0
% INFO    : Bus 43365	: V=1.0004833, theta=28.787973 -> V=1.0, theta=0.0
% INFO    : Bus 43366	: V=1.0048635, theta=29.078975 -> V=1.0, theta=0.0
% INFO    : Bus 43367	: V=0.9991403, theta=31.529899 -> V=1.0, theta=0.0
% INFO    : Bus 43368	: V=1.0111327, theta=29.593698 -> V=1.0, theta=0.0
% INFO    : Bus 43369	: V=0.9970113, theta=31.362402 -> V=1.0, theta=0.0
% INFO    : Bus 43370	: V=0.9970626, theta=29.480304 -> V=1.0, theta=0.0
% INFO    : Bus 43371	: V=1.0036315, theta=29.717561 -> V=1.0, theta=0.0
% INFO    : Bus 43372	: V=1.00677, theta=29.359011 -> V=1.0, theta=0.0
% INFO    : Bus 43373	: V=1.0076626, theta=29.380754 -> V=1.0, theta=0.0
% INFO    : Bus 43374	: V=1.0073773, theta=29.427903 -> V=1.0, theta=0.0
% INFO    : Bus 43375	: V=1.0099675, theta=29.277778 -> V=1.0, theta=0.0
% INFO    : Bus 43376	: V=1.0124477, theta=20.08613 -> V=1.0, theta=0.0
% INFO    : Bus 43377	: V=1.0190982, theta=19.83571 -> V=1.0, theta=0.0
% INFO    : Bus 43378	: V=1.0124719, theta=18.62908 -> V=1.0, theta=0.0
% INFO    : Bus 43379	: V=1.0136995, theta=17.785946 -> V=1.0, theta=0.0
% INFO    : Bus 43380	: V=1.0097326, theta=17.661886 -> V=1.0, theta=0.0
% INFO    : Bus 43381	: V=1.0187644, theta=17.782275 -> V=1.0, theta=0.0
% INFO    : Bus 43382	: V=0.9997709, theta=31.332478 -> V=1.0, theta=0.0
% INFO    : Bus 43383	: V=1.0044331, theta=32.231224 -> V=1.0, theta=0.0
% INFO    : Bus 43384	: V=1.0020163, theta=31.91064 -> V=1.0, theta=0.0
% INFO    : Bus 43385	: V=0.9919665, theta=27.542989 -> V=1.0, theta=0.0
% INFO    : Bus 43386	: V=1.0014706, theta=30.222773 -> V=1.0, theta=0.0
% INFO    : Bus 43387	: V=1.0085637, theta=21.637035 -> V=1.0, theta=0.0
% INFO    : Bus 43388	: V=1.0157633, theta=20.599118 -> V=1.0, theta=0.0
% INFO    : Bus 43389	: V=0.9989419, theta=18.957747 -> V=1.0, theta=0.0
% INFO    : Bus 43390	: V=1.0054894, theta=17.700847 -> V=1.0, theta=0.0
% INFO    : Bus 43391	: V=1.0097217, theta=16.314597 -> V=1.0, theta=0.0
% INFO    : Bus 43392	: V=1.0109996, theta=15.319718 -> V=1.0, theta=0.0
% INFO    : Bus 43393	: V=1.0096201, theta=15.902902 -> V=1.0, theta=0.0
% INFO    : Bus 43394	: V=1.0094458, theta=15.87107 -> V=1.0, theta=0.0
% INFO    : Bus 43395	: V=0.9987928, theta=13.653891 -> V=1.0, theta=0.0
% INFO    : Bus 43396	: V=1.0035038, theta=13.555148 -> V=1.0, theta=0.0
% INFO    : Bus 43397	: V=1.0196879, theta=10.065148 -> V=1.0, theta=0.0
% INFO    : Bus 43398	: V=1.0171653, theta=9.248625 -> V=1.0, theta=0.0
% INFO    : Bus 43399	: V=1.0125315, theta=9.260917 -> V=1.0, theta=0.0
% INFO    : Bus 43400	: V=1.0189152, theta=9.766883 -> V=1.0, theta=0.0
% INFO    : Bus 43401	: V=1.0185718, theta=9.790011 -> V=1.0, theta=0.0
% INFO    : Bus 43402	: V=0.9874113, theta=29.943485 -> V=1.0, theta=0.0
% INFO    : Bus 43403	: V=0.9920066, theta=29.135088 -> V=1.0, theta=0.0
% INFO    : Bus 43404	: V=0.9926056, theta=29.464031 -> V=1.0, theta=0.0
% INFO    : Bus 43405	: V=1.0079655, theta=30.763576 -> V=1.0, theta=0.0
% INFO    : Bus 43406	: V=1.0062414, theta=29.019294 -> V=1.0, theta=0.0
% INFO    : Bus 43407	: V=1.0102667, theta=37.082505 -> V=1.0, theta=0.0
% INFO    : Bus 43408	: V=1.0201128, theta=37.497767 -> V=1.0, theta=0.0
% INFO    : Bus 43409	: V=1.0036076, theta=35.693851 -> V=1.0, theta=0.0
% INFO    : Bus 43410	: V=1.0046716, theta=35.705151 -> V=1.0, theta=0.0
% INFO    : Bus 43411	: V=1.0021707, theta=34.986725 -> V=1.0, theta=0.0
% INFO    : Bus 43412	: V=1.0106246, theta=35.509843 -> V=1.0, theta=0.0
% INFO    : Bus 43413	: V=1.005232, theta=34.937863 -> V=1.0, theta=0.0
% INFO    : Bus 43414	: V=1.0172116, theta=35.36025 -> V=1.0, theta=0.0
% INFO    : Bus 43415	: V=1.0180907, theta=35.00697 -> V=1.0, theta=0.0
% INFO    : Bus 43416	: V=1.0034712, theta=35.599594 -> V=1.0, theta=0.0
% INFO    : Bus 43417	: V=1.0045092, theta=35.843162 -> V=1.0, theta=0.0
% INFO    : Bus 43418	: V=1.0159987, theta=18.460504 -> V=1.0, theta=0.0
% INFO    : Bus 43419	: V=1.0061471, theta=18.886802 -> V=1.0, theta=0.0
% INFO    : Bus 43420	: V=1.0118324, theta=16.616733 -> V=1.0, theta=0.0
% INFO    : Bus 43421	: V=1.0149347, theta=16.778893 -> V=1.0, theta=0.0
% INFO    : Bus 43422	: V=0.9967018, theta=32.294034 -> V=1.0, theta=0.0
% INFO    : Bus 43423	: V=1.0037162, theta=31.819651 -> V=1.0, theta=0.0
% INFO    : Bus 43424	: V=0.9965105, theta=31.696898 -> V=1.0, theta=0.0
% INFO    : Bus 43425	: V=0.9958552, theta=32.147015 -> V=1.0, theta=0.0
% INFO    : Bus 43426	: V=1.0052747, theta=13.148473 -> V=1.0, theta=0.0
% INFO    : Bus 43427	: V=1.0050404, theta=13.46886 -> V=1.0, theta=0.0
% INFO    : Bus 43428	: V=0.9935157, theta=13.023314 -> V=1.0, theta=0.0
% INFO    : Bus 43429	: V=1.0175497, theta=23.170826 -> V=1.0, theta=0.0
% INFO    : Bus 43430	: V=1.0185781, theta=25.364639 -> V=1.0, theta=0.0
% INFO    : Bus 43431	: V=1.0190836, theta=25.013924 -> V=1.0, theta=0.0
% INFO    : Bus 43432	: V=1.0176639, theta=23.344009 -> V=1.0, theta=0.0
% INFO    : Bus 43433	: V=0.9884214, theta=36.771118 -> V=1.0, theta=0.0
% INFO    : Bus 43434	: V=0.9871142, theta=34.454439 -> V=1.0, theta=0.0
% INFO    : Bus 43435	: V=0.9884631, theta=33.214569 -> V=1.0, theta=0.0
% INFO    : Bus 43436	: V=0.9941947, theta=33.909279 -> V=1.0, theta=0.0
% INFO    : Bus 43437	: V=0.9862361, theta=33.128708 -> V=1.0, theta=0.0
% INFO    : Bus 43438	: V=0.9935611, theta=31.915446 -> V=1.0, theta=0.0
% INFO    : Bus 43439	: V=1.0183546, theta=33.567439 -> V=1.0, theta=0.0
% INFO    : Bus 43440	: V=1.0194896, theta=33.722948 -> V=1.0, theta=0.0
% INFO    : Bus 43441	: V=1.0190499, theta=33.583397 -> V=1.0, theta=0.0
% INFO    : Bus 43442	: V=1.0195296, theta=33.825215 -> V=1.0, theta=0.0
% INFO    : Bus 43443	: V=1.0176274, theta=33.601627 -> V=1.0, theta=0.0
% INFO    : Bus 43444	: V=1.0177631, theta=33.57605 -> V=1.0, theta=0.0
% INFO    : Bus 43445	: V=1.0152409, theta=33.479434 -> V=1.0, theta=0.0
% INFO    : Bus 43446	: V=1.0197391, theta=33.963943 -> V=1.0, theta=0.0
% INFO    : Bus 43447	: V=1.0105558, theta=33.041694 -> V=1.0, theta=0.0
% INFO    : Bus 43448	: V=1.0072779, theta=32.332098 -> V=1.0, theta=0.0
% INFO    : Bus 43449	: V=1.0060777, theta=32.66845 -> V=1.0, theta=0.0
% INFO    : Bus 43450	: V=1.0068915, theta=33.472661 -> V=1.0, theta=0.0
% INFO    : Bus 43451	: V=1.0103372, theta=15.912105 -> V=1.0, theta=0.0
% INFO    : Bus 43452	: V=1.0049776, theta=12.177929 -> V=1.0, theta=0.0
% INFO    : Bus 43453	: V=1.002633, theta=10.748205 -> V=1.0, theta=0.0
% INFO    : Bus 43454	: V=1.0048514, theta=13.094767 -> V=1.0, theta=0.0
% INFO    : Bus 43455	: V=1.003912, theta=11.29958 -> V=1.0, theta=0.0
% INFO    : Bus 43456	: V=0.9946643, theta=14.667007 -> V=1.0, theta=0.0
% INFO    : Bus 43457	: V=0.9956004, theta=14.497654 -> V=1.0, theta=0.0
% INFO    : Bus 43458	: V=0.9954564, theta=14.756296 -> V=1.0, theta=0.0
% INFO    : Bus 43459	: V=0.9984728, theta=14.941819 -> V=1.0, theta=0.0
% INFO    : Bus 43460	: V=0.9979807, theta=14.27766 -> V=1.0, theta=0.0
% INFO    : Bus 43461	: V=0.9966625, theta=13.738314 -> V=1.0, theta=0.0
% INFO    : Bus 43462	: V=0.9932661, theta=14.35586 -> V=1.0, theta=0.0
% INFO    : Bus 43463	: V=0.9873184, theta=14.836246 -> V=1.0, theta=0.0
% INFO    : Bus 43464	: V=0.9933363, theta=14.925285 -> V=1.0, theta=0.0
% INFO    : Bus 43465	: V=0.992917, theta=14.835357 -> V=1.0, theta=0.0
% INFO    : Bus 43466	: V=0.9880132, theta=14.839749 -> V=1.0, theta=0.0
% INFO    : Bus 43467	: V=0.9947649, theta=14.936438 -> V=1.0, theta=0.0
% INFO    : Bus 43468	: V=0.9950293, theta=14.694122 -> V=1.0, theta=0.0
% INFO    : Bus 43469	: V=0.9926825, theta=14.775431 -> V=1.0, theta=0.0
% INFO    : Bus 43470	: V=0.9927434, theta=14.565044 -> V=1.0, theta=0.0
% INFO    : Bus 43471	: V=0.9932168, theta=14.409068 -> V=1.0, theta=0.0
% INFO    : Bus 43472	: V=0.9977132, theta=15.551792 -> V=1.0, theta=0.0
% INFO    : Bus 43473	: V=0.9872807, theta=13.999627 -> V=1.0, theta=0.0
% INFO    : Bus 43474	: V=0.988656, theta=12.915663 -> V=1.0, theta=0.0
% INFO    : Bus 43475	: V=0.9867465, theta=13.745199 -> V=1.0, theta=0.0
% INFO    : Bus 43476	: V=0.9777507, theta=31.870749 -> V=1.0, theta=0.0
% INFO    : Bus 43477	: V=0.994717, theta=31.095827 -> V=1.0, theta=0.0
% INFO    : Bus 43478	: V=0.9956524, theta=30.748423 -> V=1.0, theta=0.0
% INFO    : Bus 43479	: V=0.9792816, theta=29.668591 -> V=1.0, theta=0.0
% INFO    : Bus 43480	: V=1.0155461, theta=22.92888 -> V=1.0, theta=0.0
% INFO    : Bus 43481	: V=1.0153967, theta=22.8136 -> V=1.0, theta=0.0
% INFO    : Bus 43482	: V=1.0161563, theta=22.946487 -> V=1.0, theta=0.0
% INFO    : Bus 43483	: V=1.0165459, theta=22.956906 -> V=1.0, theta=0.0
% INFO    : Bus 43484	: V=1.0170784, theta=22.970861 -> V=1.0, theta=0.0
% INFO    : Bus 43485	: V=1.0182571, theta=23.000149 -> V=1.0, theta=0.0
% INFO    : Bus 43486	: V=1.0168305, theta=22.951158 -> V=1.0, theta=0.0
% INFO    : Bus 43487	: V=1.0119092, theta=23.050375 -> V=1.0, theta=0.0
% INFO    : Bus 43488	: V=1.0001843, theta=23.565511 -> V=1.0, theta=0.0
% INFO    : Bus 43489	: V=1.0053161, theta=21.131388 -> V=1.0, theta=0.0
% INFO    : Bus 43490	: V=1.0120723, theta=22.058831 -> V=1.0, theta=0.0
% INFO    : Bus 43491	: V=1.0191498, theta=26.629343 -> V=1.0, theta=0.0
% INFO    : Bus 43492	: V=1.0152729, theta=27.594937 -> V=1.0, theta=0.0
% INFO    : Bus 43493	: V=1.0125337, theta=26.853372 -> V=1.0, theta=0.0
% INFO    : Bus 43494	: V=1.0149588, theta=28.234965 -> V=1.0, theta=0.0
% INFO    : Bus 43495	: V=1.0144955, theta=27.408033 -> V=1.0, theta=0.0
% INFO    : Bus 43496	: V=1.0177468, theta=35.95404 -> V=1.0, theta=0.0
% INFO    : Bus 43497	: V=1.0052934, theta=34.66814 -> V=1.0, theta=0.0
% INFO    : Bus 43498	: V=1.0079136, theta=35.002425 -> V=1.0, theta=0.0
% INFO    : Bus 43499	: V=1.0085336, theta=34.992137 -> V=1.0, theta=0.0
% INFO    : Bus 43500	: V=1.0036902, theta=34.68166 -> V=1.0, theta=0.0
% INFO    : Bus 43501	: V=1.0088737, theta=34.951959 -> V=1.0, theta=0.0
% INFO    : Bus 43502	: V=1.0034269, theta=34.643713 -> V=1.0, theta=0.0
% INFO    : Bus 43503	: V=1.0022963, theta=34.617387 -> V=1.0, theta=0.0
% INFO    : Bus 43504	: V=1.0027864, theta=34.654664 -> V=1.0, theta=0.0
% INFO    : Bus 43505	: V=1.008514, theta=34.948265 -> V=1.0, theta=0.0
% INFO    : Bus 43506	: V=1.0087269, theta=34.967012 -> V=1.0, theta=0.0
% INFO    : Bus 43507	: V=1.0089069, theta=34.976809 -> V=1.0, theta=0.0
% INFO    : Bus 43508	: V=1.0085744, theta=34.956289 -> V=1.0, theta=0.0
% INFO    : Bus 43509	: V=1.0015019, theta=34.617962 -> V=1.0, theta=0.0
% INFO    : Bus 43510	: V=1.0005695, theta=34.584301 -> V=1.0, theta=0.0
% INFO    : Bus 43511	: V=1.0012745, theta=34.613643 -> V=1.0, theta=0.0
% INFO    : Bus 43512	: V=1.0018789, theta=34.629167 -> V=1.0, theta=0.0
% INFO    : Bus 43513	: V=1.0073388, theta=35.027635 -> V=1.0, theta=0.0
% INFO    : Bus 43514	: V=1.0012533, theta=34.614776 -> V=1.0, theta=0.0
% INFO    : Bus 43515	: V=1.0075278, theta=34.702769 -> V=1.0, theta=0.0
% INFO    : Bus 43516	: V=0.9919834, theta=34.04736 -> V=1.0, theta=0.0
% INFO    : Bus 43517	: V=1.0070938, theta=34.508651 -> V=1.0, theta=0.0
% INFO    : Bus 43518	: V=1.0061109, theta=34.08479 -> V=1.0, theta=0.0
% INFO    : Bus 43519	: V=0.9803407, theta=32.620683 -> V=1.0, theta=0.0
% INFO    : Bus 43520	: V=0.979151, theta=32.372053 -> V=1.0, theta=0.0
% INFO    : Bus 43521	: V=1.012322, theta=35.053338 -> V=1.0, theta=0.0
% INFO    : Bus 43522	: V=1.0013736, theta=27.629644 -> V=1.0, theta=0.0
% INFO    : Bus 43523	: V=1.0077112, theta=27.356358 -> V=1.0, theta=0.0
% INFO    : Bus 43524	: V=1.0086028, theta=27.947874 -> V=1.0, theta=0.0
% INFO    : Bus 43525	: V=1.008817, theta=27.797871 -> V=1.0, theta=0.0
% INFO    : Bus 43526	: V=0.9800826, theta=31.963897 -> V=1.0, theta=0.0
% INFO    : Bus 43527	: V=0.9800069, theta=30.810842 -> V=1.0, theta=0.0
% INFO    : Bus 43528	: V=0.9972994, theta=30.740861 -> V=1.0, theta=0.0
% INFO    : Bus 43529	: V=0.9976218, theta=30.524275 -> V=1.0, theta=0.0
% INFO    : Bus 43530	: V=0.9982258, theta=30.293258 -> V=1.0, theta=0.0
% INFO    : Bus 43531	: V=0.9795514, theta=32.669862 -> V=1.0, theta=0.0
% INFO    : Bus 43532	: V=0.9845409, theta=31.674305 -> V=1.0, theta=0.0
% INFO    : Bus 43533	: V=1.0041711, theta=32.565897 -> V=1.0, theta=0.0
% INFO    : Bus 43534	: V=1.0025893, theta=33.858657 -> V=1.0, theta=0.0
% INFO    : Bus 43535	: V=1.0034164, theta=32.682126 -> V=1.0, theta=0.0
% INFO    : Bus 43536	: V=1.003833, theta=32.444236 -> V=1.0, theta=0.0
% INFO    : Bus 43537	: V=1.0051431, theta=32.420998 -> V=1.0, theta=0.0
% INFO    : Bus 43538	: V=1.007893, theta=32.56826 -> V=1.0, theta=0.0
% INFO    : Bus 43539	: V=1.0181952, theta=34.93868 -> V=1.0, theta=0.0
% INFO    : Bus 43540	: V=0.9962323, theta=31.039057 -> V=1.0, theta=0.0
% INFO    : Bus 43541	: V=1.0087886, theta=2.384481 -> V=1.0, theta=0.0
% INFO    : Bus 43542	: V=0.9995944, theta=1.652689 -> V=1.0, theta=0.0
% INFO    : Bus 43543	: V=0.9978912, theta=1.684317 -> V=1.0, theta=0.0
% INFO    : Bus 43544	: V=0.9939225, theta=18.122437 -> V=1.0, theta=0.0
% INFO    : Bus 43545	: V=0.9903732, theta=16.850339 -> V=1.0, theta=0.0
% INFO    : Bus 43546	: V=0.9915579, theta=16.638351 -> V=1.0, theta=0.0
% INFO    : Bus 43547	: V=0.9952201, theta=16.471953 -> V=1.0, theta=0.0
% INFO    : Bus 43548	: V=0.9938829, theta=27.333667 -> V=1.0, theta=0.0
% INFO    : Bus 43549	: V=0.9906268, theta=26.222702 -> V=1.0, theta=0.0
% INFO    : Bus 43550	: V=0.99397, theta=26.144333 -> V=1.0, theta=0.0
% INFO    : Bus 43551	: V=0.9980231, theta=26.147989 -> V=1.0, theta=0.0
% INFO    : Bus 43552	: V=0.992507, theta=13.501571 -> V=1.0, theta=0.0
% INFO    : Bus 43553	: V=0.9937669, theta=12.973251 -> V=1.0, theta=0.0
% INFO    : Bus 43554	: V=1.004431, theta=12.605769 -> V=1.0, theta=0.0
% INFO    : Bus 43555	: V=1.0136354, theta=25.107737 -> V=1.0, theta=0.0
% INFO    : Bus 43556	: V=1.0156381, theta=24.370953 -> V=1.0, theta=0.0
% INFO    : Bus 43557	: V=1.0117873, theta=24.733873 -> V=1.0, theta=0.0
% INFO    : Bus 43558	: V=1.0093737, theta=24.729596 -> V=1.0, theta=0.0
% INFO    : Bus 43559	: V=0.9901504, theta=21.799398 -> V=1.0, theta=0.0
% INFO    : Bus 43560	: V=1.0144927, theta=34.22226 -> V=1.0, theta=0.0
% INFO    : Bus 43561	: V=1.0193524, theta=32.413477 -> V=1.0, theta=0.0
% INFO    : Bus 43562	: V=1.01755, theta=34.208843 -> V=1.0, theta=0.0
% INFO    : Bus 43563	: V=0.9940275, theta=31.407586 -> V=1.0, theta=0.0
% INFO    : Bus 43564	: V=1.0030101, theta=27.407075 -> V=1.0, theta=0.0
% INFO    : Bus 43565	: V=1.0159231, theta=30.837422 -> V=1.0, theta=0.0
% INFO    : Bus 43566	: V=1.0119548, theta=28.820777 -> V=1.0, theta=0.0
% INFO    : Bus 43567	: V=1.0145353, theta=26.135451 -> V=1.0, theta=0.0
% INFO    : Bus 43568	: V=1.0144013, theta=24.349328 -> V=1.0, theta=0.0
% INFO    : Bus 43569	: V=1.0120347, theta=24.888152 -> V=1.0, theta=0.0
% INFO    : Bus 43570	: V=1.0079046, theta=7.465445 -> V=1.0, theta=0.0
% INFO    : Bus 43571	: V=1.0096447, theta=7.159657 -> V=1.0, theta=0.0
% INFO    : Bus 43572	: V=1.011712, theta=6.902974 -> V=1.0, theta=0.0
% INFO    : Bus 43573	: V=1.0132447, theta=6.715074 -> V=1.0, theta=0.0
% INFO    : Bus 43574	: V=1.0084282, theta=6.258174 -> V=1.0, theta=0.0
% INFO    : Bus 43575	: V=1.0051009, theta=22.267301 -> V=1.0, theta=0.0
% INFO    : Bus 43576	: V=0.996883, theta=20.994556 -> V=1.0, theta=0.0
% INFO    : Bus 43577	: V=0.9986832, theta=20.940594 -> V=1.0, theta=0.0
% INFO    : Bus 43578	: V=1.0015098, theta=20.209266 -> V=1.0, theta=0.0
% INFO    : Bus 43579	: V=1.0027075, theta=20.546961 -> V=1.0, theta=0.0
% INFO    : Bus 43580	: V=0.9880399, theta=36.611041 -> V=1.0, theta=0.0
% INFO    : Bus 43581	: V=0.9856851, theta=36.679334 -> V=1.0, theta=0.0
% INFO    : Bus 43582	: V=1.0171741, theta=36.283761 -> V=1.0, theta=0.0
% INFO    : Bus 43583	: V=0.9855274, theta=24.437913 -> V=1.0, theta=0.0
% INFO    : Bus 43584	: V=0.9890478, theta=25.356283 -> V=1.0, theta=0.0
% INFO    : Bus 43585	: V=0.985564, theta=24.123099 -> V=1.0, theta=0.0
% INFO    : Bus 43586	: V=0.9953776, theta=23.803703 -> V=1.0, theta=0.0
% INFO    : Bus 43587	: V=1.0104036, theta=15.786744 -> V=1.0, theta=0.0
% INFO    : Bus 43588	: V=1.0078716, theta=15.264454 -> V=1.0, theta=0.0
% INFO    : Bus 43589	: V=1.0064808, theta=14.736042 -> V=1.0, theta=0.0
% INFO    : Bus 43590	: V=0.994261, theta=25.677724 -> V=1.0, theta=0.0
% INFO    : Bus 43591	: V=1.0038924, theta=25.563531 -> V=1.0, theta=0.0
% INFO    : Bus 43592	: V=0.9981235, theta=25.476337 -> V=1.0, theta=0.0
% INFO    : Bus 43593	: V=1.0003752, theta=26.395826 -> V=1.0, theta=0.0
% INFO    : Bus 43594	: V=0.9962658, theta=31.933456 -> V=1.0, theta=0.0
% INFO    : Bus 43595	: V=1.0055382, theta=34.099517 -> V=1.0, theta=0.0
% INFO    : Bus 43596	: V=1.0028927, theta=33.437584 -> V=1.0, theta=0.0
% INFO    : Bus 43597	: V=1.004855, theta=33.821932 -> V=1.0, theta=0.0
% INFO    : Bus 43598	: V=1.0057226, theta=33.036828 -> V=1.0, theta=0.0
% INFO    : Bus 43599	: V=1.0058588, theta=33.157389 -> V=1.0, theta=0.0
% INFO    : Bus 43600	: V=1.0034423, theta=24.731452 -> V=1.0, theta=0.0
% INFO    : Bus 43601	: V=0.9834596, theta=21.26485 -> V=1.0, theta=0.0
% INFO    : Bus 43602	: V=0.9861559, theta=19.43699 -> V=1.0, theta=0.0
% INFO    : Bus 43603	: V=0.9891441, theta=20.172164 -> V=1.0, theta=0.0
% INFO    : Bus 43604	: V=0.9876021, theta=19.782297 -> V=1.0, theta=0.0
% INFO    : Bus 43605	: V=0.9868039, theta=19.623712 -> V=1.0, theta=0.0
% INFO    : Bus 43606	: V=0.9908396, theta=16.865052 -> V=1.0, theta=0.0
% INFO    : Bus 43607	: V=0.9834572, theta=18.188164 -> V=1.0, theta=0.0
% INFO    : Bus 43608	: V=1.0022505, theta=21.072529 -> V=1.0, theta=0.0
% INFO    : Bus 43609	: V=0.9971146, theta=20.594245 -> V=1.0, theta=0.0
% INFO    : Bus 43610	: V=0.9992531, theta=20.020902 -> V=1.0, theta=0.0
% INFO    : Bus 43611	: V=0.9983567, theta=20.534154 -> V=1.0, theta=0.0
% INFO    : Bus 43612	: V=0.9980862, theta=20.490999 -> V=1.0, theta=0.0
% INFO    : Bus 43613	: V=1.0043601, theta=27.962132 -> V=1.0, theta=0.0
% INFO    : Bus 43614	: V=1.0130852, theta=28.191607 -> V=1.0, theta=0.0
% INFO    : Bus 43615	: V=1.0113579, theta=28.169026 -> V=1.0, theta=0.0
% INFO    : Bus 43616	: V=1.0121713, theta=28.178264 -> V=1.0, theta=0.0
% INFO    : Bus 43617	: V=1.0013062, theta=27.496 -> V=1.0, theta=0.0
% INFO    : Bus 43618	: V=1.0047386, theta=27.820255 -> V=1.0, theta=0.0
% INFO    : Bus 43619	: V=1.0055094, theta=27.803975 -> V=1.0, theta=0.0
% INFO    : Bus 43620	: V=1.0054691, theta=27.863173 -> V=1.0, theta=0.0
% INFO    : Bus 43621	: V=1.0052053, theta=27.919587 -> V=1.0, theta=0.0
% INFO    : Bus 43622	: V=1.0049161, theta=27.934912 -> V=1.0, theta=0.0
% INFO    : Bus 43623	: V=1.0052129, theta=27.929741 -> V=1.0, theta=0.0
% INFO    : Bus 43624	: V=1.0054976, theta=27.905595 -> V=1.0, theta=0.0
% INFO    : Bus 43625	: V=1.0053654, theta=27.884827 -> V=1.0, theta=0.0
% INFO    : Bus 43626	: V=1.0161248, theta=29.210741 -> V=1.0, theta=0.0
% INFO    : Bus 43627	: V=1.0033488, theta=27.95892 -> V=1.0, theta=0.0
% INFO    : Bus 43628	: V=1.0049599, theta=27.918284 -> V=1.0, theta=0.0
% INFO    : Bus 43629	: V=1.0125913, theta=28.17823 -> V=1.0, theta=0.0
% INFO    : Bus 43630	: V=1.0053351, theta=27.866242 -> V=1.0, theta=0.0
% INFO    : Bus 43631	: V=0.9905135, theta=27.83263 -> V=1.0, theta=0.0
% INFO    : Bus 43632	: V=1.0084868, theta=28.410618 -> V=1.0, theta=0.0
% INFO    : Bus 43633	: V=0.992403, theta=27.516183 -> V=1.0, theta=0.0
% INFO    : Bus 43634	: V=0.9952764, theta=27.797501 -> V=1.0, theta=0.0
% INFO    : Bus 43635	: V=1.0047352, theta=27.416451 -> V=1.0, theta=0.0
% INFO    : Bus 43636	: V=0.9990682, theta=28.152945 -> V=1.0, theta=0.0
% INFO    : Bus 43637	: V=0.9743129, theta=29.822496 -> V=1.0, theta=0.0
% INFO    : Bus 43638	: V=0.9840541, theta=28.874228 -> V=1.0, theta=0.0
% INFO    : Bus 43639	: V=0.9874276, theta=28.760274 -> V=1.0, theta=0.0
% INFO    : Bus 43640	: V=0.9868559, theta=30.777922 -> V=1.0, theta=0.0
% INFO    : Bus 43641	: V=0.9719703, theta=29.614655 -> V=1.0, theta=0.0
% INFO    : Bus 43642	: V=0.990341, theta=22.61341 -> V=1.0, theta=0.0
% INFO    : Bus 43643	: V=0.9947393, theta=22.171769 -> V=1.0, theta=0.0
% INFO    : Bus 43644	: V=0.9938632, theta=21.057513 -> V=1.0, theta=0.0
% INFO    : Bus 43645	: V=0.9938242, theta=20.165383 -> V=1.0, theta=0.0
% INFO    : Bus 43646	: V=1.0062397, theta=31.972249 -> V=1.0, theta=0.0
% INFO    : Bus 43647	: V=1.0070669, theta=31.647552 -> V=1.0, theta=0.0
% INFO    : Bus 43648	: V=1.0009127, theta=30.092964 -> V=1.0, theta=0.0
% INFO    : Bus 43649	: V=0.9935696, theta=29.530656 -> V=1.0, theta=0.0
% INFO    : Bus 43650	: V=1.0019898, theta=30.126605 -> V=1.0, theta=0.0
% INFO    : Bus 43651	: V=0.9953919, theta=27.505924 -> V=1.0, theta=0.0
% INFO    : Bus 43652	: V=0.9937085, theta=19.56356 -> V=1.0, theta=0.0
% INFO    : Bus 43653	: V=0.9926723, theta=19.403101 -> V=1.0, theta=0.0
% INFO    : Bus 43654	: V=0.998764, theta=19.564589 -> V=1.0, theta=0.0
% INFO    : Bus 43655	: V=1.0009919, theta=20.605223 -> V=1.0, theta=0.0
% INFO    : Bus 43656	: V=1.009674, theta=15.838405 -> V=1.0, theta=0.0
% INFO    : Bus 43657	: V=1.00919, theta=15.142662 -> V=1.0, theta=0.0
% INFO    : Bus 43658	: V=1.016979, theta=14.579964 -> V=1.0, theta=0.0
% INFO    : Bus 43659	: V=1.0185704, theta=14.33846 -> V=1.0, theta=0.0
% INFO    : Bus 43660	: V=1.0196475, theta=14.459138 -> V=1.0, theta=0.0
% INFO    : Bus 43661	: V=1.019512, theta=14.409673 -> V=1.0, theta=0.0
% INFO    : Bus 43662	: V=0.9947352, theta=19.62939 -> V=1.0, theta=0.0
% INFO    : Bus 43663	: V=1.0093071, theta=28.771763 -> V=1.0, theta=0.0
% INFO    : Bus 43664	: V=1.0076011, theta=28.668824 -> V=1.0, theta=0.0
% INFO    : Bus 43665	: V=1.003243, theta=28.712973 -> V=1.0, theta=0.0
% INFO    : Bus 43666	: V=1.0153372, theta=28.826018 -> V=1.0, theta=0.0
% INFO    : Bus 43667	: V=1.0062308, theta=28.744509 -> V=1.0, theta=0.0
% INFO    : Bus 43668	: V=1.0135619, theta=28.807848 -> V=1.0, theta=0.0
% INFO    : Bus 43669	: V=1.0048138, theta=28.670888 -> V=1.0, theta=0.0
% INFO    : Bus 43670	: V=1.003408, theta=28.689991 -> V=1.0, theta=0.0
% INFO    : Bus 43671	: V=1.0101631, theta=28.763504 -> V=1.0, theta=0.0
% INFO    : Bus 43672	: V=1.0112973, theta=28.761615 -> V=1.0, theta=0.0
% INFO    : Bus 43673	: V=1.0134081, theta=28.778959 -> V=1.0, theta=0.0
% INFO    : Bus 43674	: V=1.0132663, theta=28.780031 -> V=1.0, theta=0.0
% INFO    : Bus 43675	: V=1.0069292, theta=28.681991 -> V=1.0, theta=0.0
% INFO    : Bus 43676	: V=1.0154531, theta=28.79586 -> V=1.0, theta=0.0
% INFO    : Bus 43677	: V=1.0144291, theta=28.83103 -> V=1.0, theta=0.0
% INFO    : Bus 43678	: V=1.0083135, theta=28.372927 -> V=1.0, theta=0.0
% INFO    : Bus 43679	: V=1.0086398, theta=28.360493 -> V=1.0, theta=0.0
% INFO    : Bus 43680	: V=1.0155548, theta=28.668488 -> V=1.0, theta=0.0
% INFO    : Bus 43681	: V=1.0153395, theta=28.69866 -> V=1.0, theta=0.0
% INFO    : Bus 43682	: V=1.0178391, theta=28.766859 -> V=1.0, theta=0.0
% INFO    : Bus 43683	: V=1.0140227, theta=28.7271 -> V=1.0, theta=0.0
% INFO    : Bus 43684	: V=1.0131939, theta=28.756008 -> V=1.0, theta=0.0
% INFO    : Bus 43685	: V=1.0116071, theta=28.72185 -> V=1.0, theta=0.0
% INFO    : Bus 43686	: V=1.0193062, theta=28.637931 -> V=1.0, theta=0.0
% INFO    : Bus 43687	: V=1.014668, theta=28.723347 -> V=1.0, theta=0.0
% INFO    : Bus 43688	: V=1.0137977, theta=28.746605 -> V=1.0, theta=0.0
% INFO    : Bus 43689	: V=1.0149615, theta=28.706586 -> V=1.0, theta=0.0
% INFO    : Bus 43690	: V=1.0138003, theta=28.490993 -> V=1.0, theta=0.0
% INFO    : Bus 43691	: V=1.0159796, theta=28.4492 -> V=1.0, theta=0.0
% INFO    : Bus 43692	: V=1.0159935, theta=28.441114 -> V=1.0, theta=0.0
% INFO    : Bus 43693	: V=1.0116251, theta=28.416121 -> V=1.0, theta=0.0
% INFO    : Bus 43694	: V=1.016981, theta=28.671379 -> V=1.0, theta=0.0
% INFO    : Bus 43695	: V=1.0155497, theta=28.694299 -> V=1.0, theta=0.0
% INFO    : Bus 43696	: V=1.0196151, theta=28.62826 -> V=1.0, theta=0.0
% INFO    : Bus 43697	: V=1.0178866, theta=28.540416 -> V=1.0, theta=0.0
% INFO    : Bus 43698	: V=1.0150886, theta=28.380352 -> V=1.0, theta=0.0
% INFO    : Bus 43699	: V=1.0181129, theta=28.5232 -> V=1.0, theta=0.0
% INFO    : Bus 43700	: V=0.9978152, theta=29.081525 -> V=1.0, theta=0.0
% INFO    : Bus 43701	: V=1.0158128, theta=29.148877 -> V=1.0, theta=0.0
% INFO    : Bus 43702	: V=1.012927, theta=29.180091 -> V=1.0, theta=0.0
% INFO    : Bus 43703	: V=0.998855, theta=28.795702 -> V=1.0, theta=0.0
% INFO    : Bus 43704	: V=1.0018886, theta=28.72564 -> V=1.0, theta=0.0
% INFO    : Bus 43705	: V=1.0157673, theta=28.960103 -> V=1.0, theta=0.0
% INFO    : Bus 43706	: V=1.0103793, theta=28.428103 -> V=1.0, theta=0.0
% INFO    : Bus 43707	: V=0.9963278, theta=28.793907 -> V=1.0, theta=0.0
% INFO    : Bus 43708	: V=1.0156558, theta=28.270938 -> V=1.0, theta=0.0
% INFO    : Bus 43709	: V=1.010588, theta=26.350755 -> V=1.0, theta=0.0
% INFO    : Bus 43710	: V=1.0002032, theta=24.280182 -> V=1.0, theta=0.0
% INFO    : Bus 43711	: V=1.001944, theta=15.285068 -> V=1.0, theta=0.0
% INFO    : Bus 43712	: V=1.0053287, theta=14.216205 -> V=1.0, theta=0.0
% INFO    : Bus 43713	: V=1.0051553, theta=14.556288 -> V=1.0, theta=0.0
% INFO    : Bus 43714	: V=1.0052444, theta=14.726208 -> V=1.0, theta=0.0
% INFO    : Bus 43715	: V=0.993858, theta=19.591694 -> V=1.0, theta=0.0
% INFO    : Bus 43716	: V=0.9975966, theta=17.785181 -> V=1.0, theta=0.0
% INFO    : Bus 43717	: V=0.9972673, theta=16.059251 -> V=1.0, theta=0.0
% INFO    : Bus 43718	: V=0.996137, theta=13.934316 -> V=1.0, theta=0.0
% INFO    : Bus 43719	: V=0.9988814, theta=13.436514 -> V=1.0, theta=0.0
% INFO    : Bus 43720	: V=0.9882975, theta=13.604552 -> V=1.0, theta=0.0
% INFO    : Bus 43721	: V=1.0044756, theta=18.761231 -> V=1.0, theta=0.0
% INFO    : Bus 43722	: V=1.0056148, theta=18.907677 -> V=1.0, theta=0.0
% INFO    : Bus 43723	: V=1.0053547, theta=17.366243 -> V=1.0, theta=0.0
% INFO    : Bus 43724	: V=1.0047006, theta=17.590142 -> V=1.0, theta=0.0
% INFO    : Bus 43725	: V=1.0053355, theta=17.616883 -> V=1.0, theta=0.0
% INFO    : Bus 43726	: V=1.0044398, theta=17.582812 -> V=1.0, theta=0.0
% INFO    : Bus 43727	: V=1.0050218, theta=17.548554 -> V=1.0, theta=0.0
% INFO    : Bus 43728	: V=1.0036282, theta=17.828127 -> V=1.0, theta=0.0
% INFO    : Bus 43729	: V=1.0058895, theta=19.026252 -> V=1.0, theta=0.0
% INFO    : Bus 43730	: V=1.0066915, theta=19.021753 -> V=1.0, theta=0.0
% INFO    : Bus 43731	: V=0.9937799, theta=17.028913 -> V=1.0, theta=0.0
% INFO    : Bus 43732	: V=0.9952639, theta=17.149853 -> V=1.0, theta=0.0
% INFO    : Bus 43733	: V=0.9948032, theta=17.136149 -> V=1.0, theta=0.0
% INFO    : Bus 43734	: V=0.9927735, theta=16.991935 -> V=1.0, theta=0.0
% INFO    : Bus 43735	: V=0.9927867, theta=17.084109 -> V=1.0, theta=0.0
% INFO    : Bus 43736	: V=1.0130168, theta=26.610447 -> V=1.0, theta=0.0
% INFO    : Bus 43737	: V=1.0133764, theta=24.620832 -> V=1.0, theta=0.0
% INFO    : Bus 43738	: V=1.0080893, theta=24.989821 -> V=1.0, theta=0.0
% INFO    : Bus 43739	: V=1.0129058, theta=26.451755 -> V=1.0, theta=0.0
% INFO    : Bus 43740	: V=1.0173246, theta=26.980293 -> V=1.0, theta=0.0
% INFO    : Bus 43741	: V=1.0094145, theta=25.904093 -> V=1.0, theta=0.0
% INFO    : Bus 43742	: V=1.011181, theta=26.355666 -> V=1.0, theta=0.0
% INFO    : Bus 43743	: V=1.007256, theta=25.719052 -> V=1.0, theta=0.0
% INFO    : Bus 43744	: V=1.0169572, theta=26.875721 -> V=1.0, theta=0.0
% INFO    : Bus 43745	: V=1.0159023, theta=26.780599 -> V=1.0, theta=0.0
% INFO    : Bus 43746	: V=1.002482, theta=4.446655 -> V=1.0, theta=0.0
% INFO    : Bus 43747	: V=1.0045195, theta=3.468623 -> V=1.0, theta=0.0
% INFO    : Bus 43748	: V=1.0012516, theta=3.856536 -> V=1.0, theta=0.0
% INFO    : Bus 43749	: V=0.9993349, theta=3.436977 -> V=1.0, theta=0.0
% INFO    : Bus 43750	: V=0.9997358, theta=3.42142 -> V=1.0, theta=0.0
% INFO    : Bus 43751	: V=1.0198053, theta=39.54306 -> V=1.0, theta=0.0
% INFO    : Bus 43752	: V=1.0052786, theta=36.999479 -> V=1.0, theta=0.0
% INFO    : Bus 43753	: V=1.0084815, theta=36.527158 -> V=1.0, theta=0.0
% INFO    : Bus 43754	: V=1.0062629, theta=8.74399 -> V=1.0, theta=0.0
% INFO    : Bus 43755	: V=1.011301, theta=9.360576 -> V=1.0, theta=0.0
% INFO    : Bus 43756	: V=1.0093963, theta=8.742628 -> V=1.0, theta=0.0
% INFO    : Bus 43757	: V=1.0076981, theta=7.075395 -> V=1.0, theta=0.0
% INFO    : Bus 43758	: V=1.008588, theta=17.201165 -> V=1.0, theta=0.0
% INFO    : Bus 43759	: V=1.0012639, theta=17.087064 -> V=1.0, theta=0.0
% INFO    : Bus 43760	: V=1.0041456, theta=15.883322 -> V=1.0, theta=0.0
% INFO    : Bus 43761	: V=1.0044252, theta=5.955579 -> V=1.0, theta=0.0
% INFO    : Bus 43762	: V=1.0006533, theta=5.295873 -> V=1.0, theta=0.0
% INFO    : Bus 43763	: V=1.0023059, theta=5.433349 -> V=1.0, theta=0.0
% INFO    : Bus 43764	: V=1.0004479, theta=5.284415 -> V=1.0, theta=0.0
% INFO    : Bus 43765	: V=1.013382, theta=30.48783 -> V=1.0, theta=0.0
% INFO    : Bus 43766	: V=1.0064715, theta=29.317028 -> V=1.0, theta=0.0
% INFO    : Bus 43767	: V=1.001768, theta=28.470269 -> V=1.0, theta=0.0
% INFO    : Bus 43768	: V=1.0184607, theta=29.728357 -> V=1.0, theta=0.0
% INFO    : Bus 43769	: V=1.0054365, theta=29.322104 -> V=1.0, theta=0.0
% INFO    : Bus 43770	: V=1.0018837, theta=29.265287 -> V=1.0, theta=0.0
% INFO    : Bus 43771	: V=1.0010292, theta=29.240125 -> V=1.0, theta=0.0
% INFO    : Bus 43772	: V=1.003032, theta=29.233314 -> V=1.0, theta=0.0
% INFO    : Bus 43773	: V=1.0025283, theta=29.242607 -> V=1.0, theta=0.0
% INFO    : Bus 43774	: V=1.0149155, theta=30.394096 -> V=1.0, theta=0.0
% INFO    : Bus 43775	: V=1.0109434, theta=22.765737 -> V=1.0, theta=0.0
% INFO    : Bus 43776	: V=1.006464, theta=21.451521 -> V=1.0, theta=0.0
% INFO    : Bus 43777	: V=1.0049519, theta=20.72983 -> V=1.0, theta=0.0
% INFO    : Bus 43778	: V=1.0077924, theta=19.346349 -> V=1.0, theta=0.0
% INFO    : Bus 43779	: V=1.0094343, theta=22.791547 -> V=1.0, theta=0.0
% INFO    : Bus 43780	: V=1.0124026, theta=24.635851 -> V=1.0, theta=0.0
% INFO    : Bus 43781	: V=1.0036108, theta=4.302591 -> V=1.0, theta=0.0
% INFO    : Bus 43782	: V=1.009192, theta=2.810234 -> V=1.0, theta=0.0
% INFO    : Bus 43783	: V=1.0141008, theta=2.458388 -> V=1.0, theta=0.0
% INFO    : Bus 43784	: V=1.0045015, theta=4.855861 -> V=1.0, theta=0.0
% INFO    : Bus 43785	: V=1.0002087, theta=4.57512 -> V=1.0, theta=0.0
% INFO    : Bus 43786	: V=0.9980207, theta=4.646709 -> V=1.0, theta=0.0
% INFO    : Bus 43787	: V=1.003599, theta=24.759527 -> V=1.0, theta=0.0
% INFO    : Bus 43788	: V=1.0108017, theta=23.961492 -> V=1.0, theta=0.0
% INFO    : Bus 43789	: V=1.0031004, theta=25.471733 -> V=1.0, theta=0.0
% INFO    : Bus 43790	: V=1.0162761, theta=23.674556 -> V=1.0, theta=0.0
% INFO    : Bus 43791	: V=1.0122655, theta=14.935192 -> V=1.0, theta=0.0
% INFO    : Bus 43792	: V=1.0123911, theta=14.693939 -> V=1.0, theta=0.0
% INFO    : Bus 43793	: V=0.9992557, theta=13.117697 -> V=1.0, theta=0.0
% INFO    : Bus 43794	: V=0.9990953, theta=15.607991 -> V=1.0, theta=0.0
% INFO    : Bus 43795	: V=1.0138605, theta=14.099519 -> V=1.0, theta=0.0
% INFO    : Bus 43796	: V=1.0010639, theta=11.63049 -> V=1.0, theta=0.0
% INFO    : Bus 43797	: V=1.0038762, theta=22.804649 -> V=1.0, theta=0.0
% INFO    : Bus 43798	: V=1.0035876, theta=21.882335 -> V=1.0, theta=0.0
% INFO    : Bus 43799	: V=1.0177482, theta=21.281934 -> V=1.0, theta=0.0
% INFO    : Bus 43800	: V=1.000009, theta=15.834012 -> V=1.0, theta=0.0
% INFO    : Bus 43801	: V=1.0018119, theta=15.920301 -> V=1.0, theta=0.0
% INFO    : Bus 43802	: V=0.9950937, theta=15.589736 -> V=1.0, theta=0.0
% INFO    : Bus 43803	: V=0.9949211, theta=15.540926 -> V=1.0, theta=0.0
% INFO    : Bus 43804	: V=0.9956115, theta=15.571139 -> V=1.0, theta=0.0
% INFO    : Bus 43805	: V=1.0033128, theta=13.977178 -> V=1.0, theta=0.0
% INFO    : Bus 43806	: V=0.9936186, theta=15.279273 -> V=1.0, theta=0.0
% INFO    : Bus 43807	: V=0.9937235, theta=15.335085 -> V=1.0, theta=0.0
% INFO    : Bus 43808	: V=0.9974954, theta=15.349056 -> V=1.0, theta=0.0
% INFO    : Bus 43809	: V=0.9975202, theta=15.389955 -> V=1.0, theta=0.0
% INFO    : Bus 43810	: V=0.9965597, theta=15.16863 -> V=1.0, theta=0.0
% INFO    : Bus 43811	: V=0.9895429, theta=15.059947 -> V=1.0, theta=0.0
% INFO    : Bus 43812	: V=0.9905344, theta=15.063322 -> V=1.0, theta=0.0
% INFO    : Bus 43813	: V=0.9878627, theta=14.944926 -> V=1.0, theta=0.0
% INFO    : Bus 43814	: V=0.9878961, theta=15.011064 -> V=1.0, theta=0.0
% INFO    : Bus 43815	: V=0.9868632, theta=14.998504 -> V=1.0, theta=0.0
% INFO    : Bus 43816	: V=0.9873939, theta=15.118169 -> V=1.0, theta=0.0
% INFO    : Bus 43817	: V=0.9885063, theta=15.165238 -> V=1.0, theta=0.0
% INFO    : Bus 43818	: V=0.997116, theta=15.403749 -> V=1.0, theta=0.0
% INFO    : Bus 43819	: V=0.997641, theta=15.435512 -> V=1.0, theta=0.0
% INFO    : Bus 43820	: V=0.9915208, theta=15.338942 -> V=1.0, theta=0.0
% INFO    : Bus 43821	: V=0.9934796, theta=15.336853 -> V=1.0, theta=0.0
% INFO    : Bus 43822	: V=1.0033341, theta=15.942543 -> V=1.0, theta=0.0
% INFO    : Bus 43823	: V=1.003903, theta=15.979476 -> V=1.0, theta=0.0
% INFO    : Bus 43824	: V=1.0041557, theta=16.030508 -> V=1.0, theta=0.0
% INFO    : Bus 43825	: V=1.0039685, theta=15.959861 -> V=1.0, theta=0.0
% INFO    : Bus 43826	: V=0.9986847, theta=15.511312 -> V=1.0, theta=0.0
% INFO    : Bus 43827	: V=0.9994237, theta=15.561519 -> V=1.0, theta=0.0
% INFO    : Bus 43828	: V=0.9895186, theta=15.245634 -> V=1.0, theta=0.0
% INFO    : Bus 43829	: V=0.9899425, theta=15.271336 -> V=1.0, theta=0.0
% INFO    : Bus 43830	: V=0.989983, theta=15.23619 -> V=1.0, theta=0.0
% INFO    : Bus 43831	: V=0.9967288, theta=15.441378 -> V=1.0, theta=0.0
% INFO    : Bus 43832	: V=0.990309, theta=15.254591 -> V=1.0, theta=0.0
% INFO    : Bus 43833	: V=0.9896967, theta=15.278876 -> V=1.0, theta=0.0
% INFO    : Bus 43834	: V=1.0164119, theta=17.308744 -> V=1.0, theta=0.0
% INFO    : Bus 43835	: V=1.0175845, theta=17.400475 -> V=1.0, theta=0.0
% INFO    : Bus 43836	: V=0.9982058, theta=15.512378 -> V=1.0, theta=0.0
% INFO    : Bus 43837	: V=0.9892271, theta=15.298897 -> V=1.0, theta=0.0
% INFO    : Bus 43838	: V=0.9997284, theta=15.703062 -> V=1.0, theta=0.0
% INFO    : Bus 43839	: V=0.9925881, theta=15.419168 -> V=1.0, theta=0.0
% INFO    : Bus 43840	: V=1.0011055, theta=15.790435 -> V=1.0, theta=0.0
% INFO    : Bus 43841	: V=1.0023287, theta=15.855955 -> V=1.0, theta=0.0
% INFO    : Bus 43842	: V=0.9919064, theta=15.412523 -> V=1.0, theta=0.0
% INFO    : Bus 43843	: V=0.9918647, theta=15.367976 -> V=1.0, theta=0.0
% INFO    : Bus 43844	: V=0.9909006, theta=15.395402 -> V=1.0, theta=0.0
% INFO    : Bus 43845	: V=0.9912307, theta=15.383127 -> V=1.0, theta=0.0
% INFO    : Bus 43846	: V=0.9888213, theta=15.366088 -> V=1.0, theta=0.0
% INFO    : Bus 43847	: V=0.9902478, theta=15.407695 -> V=1.0, theta=0.0
% INFO    : Bus 43848	: V=1.0029921, theta=15.931606 -> V=1.0, theta=0.0
% INFO    : Bus 43849	: V=0.9928247, theta=15.327304 -> V=1.0, theta=0.0
% INFO    : Bus 43850	: V=0.9917725, theta=15.332603 -> V=1.0, theta=0.0
% INFO    : Bus 43851	: V=1.0016564, theta=15.697641 -> V=1.0, theta=0.0
% INFO    : Bus 43852	: V=1.0026256, theta=15.820202 -> V=1.0, theta=0.0
% INFO    : Bus 43853	: V=1.0066824, theta=16.099774 -> V=1.0, theta=0.0
% INFO    : Bus 43854	: V=0.9804211, theta=17.324423 -> V=1.0, theta=0.0
% INFO    : Bus 43855	: V=0.9798775, theta=15.8018 -> V=1.0, theta=0.0
% INFO    : Bus 43856	: V=0.9786826, theta=15.73356 -> V=1.0, theta=0.0
% INFO    : Bus 43857	: V=0.9927793, theta=15.167435 -> V=1.0, theta=0.0
% INFO    : Bus 43858	: V=0.9789178, theta=15.706256 -> V=1.0, theta=0.0
% INFO    : Bus 43859	: V=0.979946, theta=15.664873 -> V=1.0, theta=0.0
% INFO    : Bus 43860	: V=0.9810222, theta=15.750541 -> V=1.0, theta=0.0
% INFO    : Bus 43861	: V=0.9916325, theta=15.289445 -> V=1.0, theta=0.0
% INFO    : Bus 43862	: V=0.9920681, theta=15.243061 -> V=1.0, theta=0.0
% INFO    : Bus 43863	: V=0.9863762, theta=14.963742 -> V=1.0, theta=0.0
% INFO    : Bus 43864	: V=0.9852028, theta=14.974206 -> V=1.0, theta=0.0
% INFO    : Bus 43865	: V=0.9934623, theta=14.916033 -> V=1.0, theta=0.0
% INFO    : Bus 43866	: V=0.9941568, theta=14.920443 -> V=1.0, theta=0.0
% INFO    : Bus 43867	: V=0.9857083, theta=14.994705 -> V=1.0, theta=0.0
% INFO    : Bus 43868	: V=0.9868138, theta=14.946752 -> V=1.0, theta=0.0
% INFO    : Bus 43869	: V=1.0034151, theta=13.878361 -> V=1.0, theta=0.0
% INFO    : Bus 43870	: V=0.9978166, theta=15.639248 -> V=1.0, theta=0.0
% INFO    : Bus 43871	: V=0.9972986, theta=16.085643 -> V=1.0, theta=0.0
% INFO    : Bus 43872	: V=0.9896605, theta=15.903905 -> V=1.0, theta=0.0
% INFO    : Bus 43873	: V=0.990311, theta=16.008056 -> V=1.0, theta=0.0
% INFO    : Bus 43874	: V=0.997959, theta=15.96387 -> V=1.0, theta=0.0
% INFO    : Bus 43875	: V=1.0151933, theta=16.717506 -> V=1.0, theta=0.0
% INFO    : Bus 43876	: V=1.0083393, theta=16.279563 -> V=1.0, theta=0.0
% INFO    : Bus 43877	: V=1.0111644, theta=16.68742 -> V=1.0, theta=0.0
% INFO    : Bus 43878	: V=0.9882432, theta=15.011143 -> V=1.0, theta=0.0
% INFO    : Bus 43879	: V=0.9877141, theta=14.972703 -> V=1.0, theta=0.0
% INFO    : Bus 43880	: V=0.9878886, theta=14.967535 -> V=1.0, theta=0.0
% INFO    : Bus 43881	: V=0.9854686, theta=14.930818 -> V=1.0, theta=0.0
% INFO    : Bus 43882	: V=0.986101, theta=14.91321 -> V=1.0, theta=0.0
% INFO    : Bus 43883	: V=0.9860559, theta=14.844135 -> V=1.0, theta=0.0
% INFO    : Bus 43884	: V=0.9958673, theta=15.341663 -> V=1.0, theta=0.0
% INFO    : Bus 43885	: V=0.9953745, theta=15.276917 -> V=1.0, theta=0.0
% INFO    : Bus 43886	: V=0.9877612, theta=14.969491 -> V=1.0, theta=0.0
% INFO    : Bus 43887	: V=0.9949172, theta=15.206998 -> V=1.0, theta=0.0
% INFO    : Bus 43888	: V=0.9864386, theta=15.067296 -> V=1.0, theta=0.0
% INFO    : Bus 43889	: V=0.9931669, theta=14.902755 -> V=1.0, theta=0.0
% INFO    : Bus 43890	: V=0.9863496, theta=14.992499 -> V=1.0, theta=0.0
% INFO    : Bus 43891	: V=0.992929, theta=14.924741 -> V=1.0, theta=0.0
% INFO    : Bus 43892	: V=0.994153, theta=14.880475 -> V=1.0, theta=0.0
% INFO    : Bus 43893	: V=0.9953991, theta=14.926839 -> V=1.0, theta=0.0
% INFO    : Bus 43894	: V=0.9729986, theta=15.774005 -> V=1.0, theta=0.0
% INFO    : Bus 43895	: V=0.9896851, theta=15.34544 -> V=1.0, theta=0.0
% INFO    : Bus 43896	: V=0.9954319, theta=14.931898 -> V=1.0, theta=0.0
% INFO    : Bus 43897	: V=0.9966117, theta=15.007458 -> V=1.0, theta=0.0
% INFO    : Bus 43898	: V=0.9937421, theta=3.883773 -> V=1.0, theta=0.0
% INFO    : Bus 43899	: V=1.0104938, theta=6.152658 -> V=1.0, theta=0.0
% INFO    : Bus 43900	: V=1.0016819, theta=5.835133 -> V=1.0, theta=0.0
% INFO    : Bus 43901	: V=1.0151955, theta=8.261406 -> V=1.0, theta=0.0
% INFO    : Bus 43902	: V=1.0114153, theta=6.106711 -> V=1.0, theta=0.0
% INFO    : Bus 43903	: V=1.0045439, theta=5.751433 -> V=1.0, theta=0.0
% INFO    : Bus 43904	: V=1.016136, theta=7.85749 -> V=1.0, theta=0.0
% INFO    : Bus 43905	: V=1.0155891, theta=7.913265 -> V=1.0, theta=0.0
% INFO    : Bus 43906	: V=1.0063399, theta=4.921244 -> V=1.0, theta=0.0
% INFO    : Bus 43907	: V=1.0031583, theta=4.556595 -> V=1.0, theta=0.0
% INFO    : Bus 43908	: V=1.0007483, theta=4.31206 -> V=1.0, theta=0.0
% INFO    : Bus 43909	: V=0.9977118, theta=4.105527 -> V=1.0, theta=0.0
% INFO    : Bus 43910	: V=0.9980667, theta=4.092975 -> V=1.0, theta=0.0
% INFO    : Bus 43911	: V=1.0000239, theta=4.263032 -> V=1.0, theta=0.0
% INFO    : Bus 43912	: V=0.9996002, theta=4.223192 -> V=1.0, theta=0.0
% INFO    : Bus 43913	: V=1.0014042, theta=4.35288 -> V=1.0, theta=0.0
% INFO    : Bus 43914	: V=1.0009985, theta=4.300661 -> V=1.0, theta=0.0
% INFO    : Bus 43915	: V=1.0024803, theta=4.488874 -> V=1.0, theta=0.0
% INFO    : Bus 43916	: V=1.0014944, theta=4.295454 -> V=1.0, theta=0.0
% INFO    : Bus 43917	: V=1.0042354, theta=4.617986 -> V=1.0, theta=0.0
% INFO    : Bus 43918	: V=1.0083555, theta=4.661965 -> V=1.0, theta=0.0
% INFO    : Bus 43919	: V=1.0061068, theta=4.861298 -> V=1.0, theta=0.0
% INFO    : Bus 43920	: V=1.0064975, theta=4.847698 -> V=1.0, theta=0.0
% INFO    : Bus 43921	: V=1.0177606, theta=5.767132 -> V=1.0, theta=0.0
% INFO    : Bus 43922	: V=1.0079715, theta=4.26476 -> V=1.0, theta=0.0
% INFO    : Bus 43923	: V=1.0040395, theta=4.832213 -> V=1.0, theta=0.0
% INFO    : Bus 43924	: V=1.0077848, theta=4.94032 -> V=1.0, theta=0.0
% INFO    : Bus 43925	: V=1.0042073, theta=4.956414 -> V=1.0, theta=0.0
% INFO    : Bus 43926	: V=1.0034856, theta=4.65721 -> V=1.0, theta=0.0
% INFO    : Bus 43927	: V=1.0192367, theta=6.028628 -> V=1.0, theta=0.0
% INFO    : Bus 43928	: V=0.9939866, theta=23.95298 -> V=1.0, theta=0.0
% INFO    : Bus 43929	: V=1.012915, theta=22.818881 -> V=1.0, theta=0.0
% INFO    : Bus 43930	: V=1.0173462, theta=22.725098 -> V=1.0, theta=0.0
% INFO    : Bus 43931	: V=1.0150973, theta=22.648915 -> V=1.0, theta=0.0
% INFO    : Bus 43932	: V=0.9978468, theta=23.135701 -> V=1.0, theta=0.0
% INFO    : Bus 43933	: V=0.9817978, theta=4.870778 -> V=1.0, theta=0.0
% INFO    : Bus 43934	: V=0.985369, theta=4.764864 -> V=1.0, theta=0.0
% INFO    : Bus 43935	: V=1.0166106, theta=16.707343 -> V=1.0, theta=0.0
% INFO    : Bus 43936	: V=1.012518, theta=16.299001 -> V=1.0, theta=0.0
% INFO    : Bus 43937	: V=1.0123153, theta=18.375659 -> V=1.0, theta=0.0
% INFO    : Bus 43938	: V=1.0117712, theta=18.876462 -> V=1.0, theta=0.0
% INFO    : Bus 43939	: V=1.0162359, theta=32.906336 -> V=1.0, theta=0.0
% INFO    : Bus 43940	: V=1.0143316, theta=32.304537 -> V=1.0, theta=0.0
% INFO    : Bus 43941	: V=0.9927107, theta=30.796955 -> V=1.0, theta=0.0
% INFO    : Bus 43942	: V=0.9983526, theta=31.114779 -> V=1.0, theta=0.0
% INFO    : Bus 43943	: V=1.0062161, theta=31.231518 -> V=1.0, theta=0.0
% INFO    : Bus 43944	: V=0.9942351, theta=30.181424 -> V=1.0, theta=0.0
% INFO    : Bus 43945	: V=1.0079585, theta=30.484447 -> V=1.0, theta=0.0
% INFO    : Bus 43946	: V=1.0041248, theta=30.641194 -> V=1.0, theta=0.0
% INFO    : Bus 43947	: V=0.9986889, theta=30.437398 -> V=1.0, theta=0.0
% INFO    : Bus 43948	: V=1.003685, theta=30.585166 -> V=1.0, theta=0.0
% INFO    : Bus 43949	: V=1.0036953, theta=30.59428 -> V=1.0, theta=0.0
% INFO    : Bus 43950	: V=1.0037387, theta=30.582734 -> V=1.0, theta=0.0
% INFO    : Bus 43951	: V=1.003733, theta=30.571016 -> V=1.0, theta=0.0
% INFO    : Bus 43952	: V=0.9979274, theta=30.413856 -> V=1.0, theta=0.0
% INFO    : Bus 43953	: V=0.9979123, theta=30.44304 -> V=1.0, theta=0.0
% INFO    : Bus 43954	: V=0.9981808, theta=30.48175 -> V=1.0, theta=0.0
% INFO    : Bus 43955	: V=0.9987168, theta=30.546672 -> V=1.0, theta=0.0
% INFO    : Bus 43956	: V=0.9974619, theta=30.497707 -> V=1.0, theta=0.0
% INFO    : Bus 43957	: V=0.9972081, theta=30.513854 -> V=1.0, theta=0.0
% INFO    : Bus 43958	: V=0.9965655, theta=30.433092 -> V=1.0, theta=0.0
% INFO    : Bus 43959	: V=0.9964237, theta=30.40789 -> V=1.0, theta=0.0
% INFO    : Bus 43960	: V=0.9962448, theta=30.382119 -> V=1.0, theta=0.0
% INFO    : Bus 43961	: V=1.0039132, theta=30.561587 -> V=1.0, theta=0.0
% INFO    : Bus 43962	: V=1.0039247, theta=30.569098 -> V=1.0, theta=0.0
% INFO    : Bus 43963	: V=0.9982231, theta=30.295855 -> V=1.0, theta=0.0
% INFO    : Bus 43964	: V=0.995485, theta=30.204704 -> V=1.0, theta=0.0
% INFO    : Bus 43965	: V=0.9947923, theta=30.330154 -> V=1.0, theta=0.0
% INFO    : Bus 43966	: V=1.0046976, theta=30.544544 -> V=1.0, theta=0.0
% INFO    : Bus 43967	: V=1.0037474, theta=30.827658 -> V=1.0, theta=0.0
% INFO    : Bus 43968	: V=0.994934, theta=30.396883 -> V=1.0, theta=0.0
% INFO    : Bus 43969	: V=0.9954966, theta=30.465761 -> V=1.0, theta=0.0
% INFO    : Bus 43970	: V=0.9957306, theta=30.458347 -> V=1.0, theta=0.0
% INFO    : Bus 43971	: V=0.9959623, theta=30.499794 -> V=1.0, theta=0.0
% INFO    : Bus 43972	: V=0.9970757, theta=30.560959 -> V=1.0, theta=0.0
% INFO    : Bus 43973	: V=0.9979085, theta=30.682557 -> V=1.0, theta=0.0
% INFO    : Bus 43974	: V=0.998557, theta=30.662085 -> V=1.0, theta=0.0
% INFO    : Bus 43975	: V=0.9984449, theta=30.638853 -> V=1.0, theta=0.0
% INFO    : Bus 43976	: V=0.9994857, theta=30.536063 -> V=1.0, theta=0.0
% INFO    : Bus 43977	: V=1.0052813, theta=30.710693 -> V=1.0, theta=0.0
% INFO    : Bus 43978	: V=1.0054876, theta=30.738403 -> V=1.0, theta=0.0
% INFO    : Bus 43979	: V=1.0068502, theta=30.829337 -> V=1.0, theta=0.0
% INFO    : Bus 43980	: V=0.9987522, theta=30.700178 -> V=1.0, theta=0.0
% INFO    : Bus 43981	: V=0.99944, theta=30.772802 -> V=1.0, theta=0.0
% INFO    : Bus 43982	: V=1.0079813, theta=30.873405 -> V=1.0, theta=0.0
% INFO    : Bus 43983	: V=1.000044, theta=30.80717 -> V=1.0, theta=0.0
% INFO    : Bus 43984	: V=0.9996855, theta=30.802234 -> V=1.0, theta=0.0
% INFO    : Bus 43985	: V=1.0018188, theta=31.096285 -> V=1.0, theta=0.0
% INFO    : Bus 43986	: V=0.994074, theta=9.844801 -> V=1.0, theta=0.0
% INFO    : Bus 43987	: V=0.9918517, theta=9.024973 -> V=1.0, theta=0.0
% INFO    : Bus 43988	: V=0.9945719, theta=8.933244 -> V=1.0, theta=0.0
% INFO    : Bus 43989	: V=0.9929201, theta=9.45198 -> V=1.0, theta=0.0
% INFO    : Bus 43990	: V=1.0085551, theta=19.104378 -> V=1.0, theta=0.0
% INFO    : Bus 43991	: V=1.0025067, theta=17.834265 -> V=1.0, theta=0.0
% INFO    : Bus 43992	: V=0.994553, theta=15.657142 -> V=1.0, theta=0.0
% INFO    : Bus 43993	: V=0.9992908, theta=15.41028 -> V=1.0, theta=0.0
% INFO    : Bus 43994	: V=1.0064545, theta=16.954063 -> V=1.0, theta=0.0
% INFO    : Bus 43995	: V=1.0090046, theta=17.380333 -> V=1.0, theta=0.0
% INFO    : Bus 43996	: V=1.0086835, theta=17.736028 -> V=1.0, theta=0.0
% INFO    : Bus 43997	: V=1.0001474, theta=20.599576 -> V=1.0, theta=0.0
% INFO    : Bus 43998	: V=1.0084577, theta=20.645041 -> V=1.0, theta=0.0
% INFO    : Bus 43999	: V=1.0054293, theta=20.583143 -> V=1.0, theta=0.0
% INFO    : Bus 44000	: V=1.0040599, theta=20.5544 -> V=1.0, theta=0.0
% INFO    : Bus 44001	: V=1.002231, theta=20.454508 -> V=1.0, theta=0.0
% INFO    : Bus 44002	: V=0.9975061, theta=20.327214 -> V=1.0, theta=0.0
% INFO    : Bus 44003	: V=0.9989045, theta=20.345312 -> V=1.0, theta=0.0
% INFO    : Bus 44004	: V=0.999918, theta=20.176176 -> V=1.0, theta=0.0
% INFO    : Bus 44005	: V=1.0136305, theta=20.79958 -> V=1.0, theta=0.0
% INFO    : Bus 44006	: V=0.9999962, theta=19.962393 -> V=1.0, theta=0.0
% INFO    : Bus 44007	: V=0.9992718, theta=20.320447 -> V=1.0, theta=0.0
% INFO    : Bus 44008	: V=0.999176, theta=20.327306 -> V=1.0, theta=0.0
% INFO    : Bus 44009	: V=0.9978815, theta=20.370181 -> V=1.0, theta=0.0
% INFO    : Bus 44010	: V=0.9912842, theta=19.881867 -> V=1.0, theta=0.0
% INFO    : Bus 44011	: V=0.9849732, theta=19.304498 -> V=1.0, theta=0.0
% INFO    : Bus 44012	: V=0.9921153, theta=21.051707 -> V=1.0, theta=0.0
% INFO    : Bus 44013	: V=1.0050386, theta=21.703006 -> V=1.0, theta=0.0
% INFO    : Bus 44014	: V=1.0023963, theta=21.255148 -> V=1.0, theta=0.0
% INFO    : Bus 44015	: V=1.01994, theta=23.736695 -> V=1.0, theta=0.0
% INFO    : Bus 44016	: V=1.0063659, theta=21.806039 -> V=1.0, theta=0.0
% INFO    : Bus 44017	: V=1.0052328, theta=27.622724 -> V=1.0, theta=0.0
% INFO    : Bus 44018	: V=1.0056829, theta=27.463179 -> V=1.0, theta=0.0
% INFO    : Bus 44019	: V=1.0049533, theta=26.872763 -> V=1.0, theta=0.0
% INFO    : Bus 44020	: V=1.0037092, theta=26.966498 -> V=1.0, theta=0.0
% INFO    : Bus 44021	: V=1.0128548, theta=27.20412 -> V=1.0, theta=0.0
% INFO    : Bus 44022	: V=1.012534, theta=27.309606 -> V=1.0, theta=0.0
% INFO    : Bus 44023	: V=1.0060933, theta=7.775231 -> V=1.0, theta=0.0
% INFO    : Bus 44024	: V=1.0049754, theta=7.165543 -> V=1.0, theta=0.0
% INFO    : Bus 44025	: V=1.0041448, theta=6.489175 -> V=1.0, theta=0.0
% INFO    : Bus 44026	: V=0.9924192, theta=10.880326 -> V=1.0, theta=0.0
% INFO    : Bus 44027	: V=1.0133427, theta=11.170158 -> V=1.0, theta=0.0
% INFO    : Bus 44028	: V=0.9971263, theta=10.765594 -> V=1.0, theta=0.0
% INFO    : Bus 44029	: V=1.0158955, theta=11.456655 -> V=1.0, theta=0.0
% INFO    : Bus 44030	: V=1.0003289, theta=17.784725 -> V=1.0, theta=0.0
% INFO    : Bus 44031	: V=0.9942874, theta=17.37775 -> V=1.0, theta=0.0
% INFO    : Bus 44032	: V=1.0071753, theta=17.799324 -> V=1.0, theta=0.0
% INFO    : Bus 44033	: V=1.002001, theta=17.723554 -> V=1.0, theta=0.0
% INFO    : Bus 44034	: V=1.0043373, theta=17.7804 -> V=1.0, theta=0.0
% INFO    : Bus 44035	: V=1.0023898, theta=17.744875 -> V=1.0, theta=0.0
% INFO    : Bus 44036	: V=1.0020058, theta=18.630983 -> V=1.0, theta=0.0
% INFO    : Bus 44037	: V=1.0022366, theta=17.728928 -> V=1.0, theta=0.0
% INFO    : Bus 44038	: V=1.0009008, theta=17.673291 -> V=1.0, theta=0.0
% INFO    : Bus 44039	: V=1.001885, theta=17.72068 -> V=1.0, theta=0.0
% INFO    : Bus 44040	: V=1.002534, theta=17.738292 -> V=1.0, theta=0.0
% INFO    : Bus 44041	: V=1.001807, theta=17.660535 -> V=1.0, theta=0.0
% INFO    : Bus 44042	: V=1.001727, theta=18.920851 -> V=1.0, theta=0.0
% INFO    : Bus 44043	: V=0.9899955, theta=15.413789 -> V=1.0, theta=0.0
% INFO    : Bus 44044	: V=0.9855685, theta=15.37721 -> V=1.0, theta=0.0
% INFO    : Bus 44045	: V=0.9837124, theta=15.434633 -> V=1.0, theta=0.0
% INFO    : Bus 44046	: V=1.0060684, theta=16.215424 -> V=1.0, theta=0.0
% INFO    : Bus 44047	: V=1.0044123, theta=16.259649 -> V=1.0, theta=0.0
% INFO    : Bus 44048	: V=1.0142901, theta=16.268396 -> V=1.0, theta=0.0
% INFO    : Bus 44049	: V=1.0161859, theta=16.484535 -> V=1.0, theta=0.0
% INFO    : Bus 44050	: V=1.0141558, theta=16.272673 -> V=1.0, theta=0.0
% INFO    : Bus 44051	: V=1.0195125, theta=16.145695 -> V=1.0, theta=0.0
% INFO    : Bus 44052	: V=1.0175655, theta=16.183295 -> V=1.0, theta=0.0
% INFO    : Bus 44053	: V=1.0095997, theta=15.942901 -> V=1.0, theta=0.0
% INFO    : Bus 44054	: V=1.0130711, theta=16.25907 -> V=1.0, theta=0.0
% INFO    : Bus 44055	: V=0.9949442, theta=22.955976 -> V=1.0, theta=0.0
% INFO    : Bus 44056	: V=0.9939792, theta=22.86524 -> V=1.0, theta=0.0
% INFO    : Bus 44057	: V=1.0013537, theta=23.79164 -> V=1.0, theta=0.0
% INFO    : Bus 44058	: V=0.9967898, theta=23.20445 -> V=1.0, theta=0.0
% INFO    : Bus 44059	: V=0.9988657, theta=23.153969 -> V=1.0, theta=0.0
% INFO    : Bus 44060	: V=0.9999097, theta=16.707303 -> V=1.0, theta=0.0
% INFO    : Bus 44061	: V=0.9922129, theta=15.063554 -> V=1.0, theta=0.0
% INFO    : Bus 44062	: V=0.9874627, theta=14.902455 -> V=1.0, theta=0.0
% INFO    : Bus 44063	: V=0.9725859, theta=21.704045 -> V=1.0, theta=0.0
% INFO    : Bus 44064	: V=0.9770436, theta=21.471274 -> V=1.0, theta=0.0
% INFO    : Bus 44065	: V=0.9932118, theta=21.678712 -> V=1.0, theta=0.0
% INFO    : Bus 44066	: V=0.9780505, theta=21.20955 -> V=1.0, theta=0.0
% INFO    : Bus 44067	: V=0.9736992, theta=21.208284 -> V=1.0, theta=0.0
% INFO    : Bus 44068	: V=0.9775376, theta=21.162961 -> V=1.0, theta=0.0
% INFO    : Bus 44069	: V=0.9782089, theta=21.204601 -> V=1.0, theta=0.0
% INFO    : Bus 44070	: V=0.9777966, theta=20.775727 -> V=1.0, theta=0.0
% INFO    : Bus 44071	: V=0.9701005, theta=22.173292 -> V=1.0, theta=0.0
% INFO    : Bus 44072	: V=0.9976646, theta=21.778561 -> V=1.0, theta=0.0
% INFO    : Bus 44073	: V=0.9905996, theta=19.663755 -> V=1.0, theta=0.0
% INFO    : Bus 44074	: V=0.9833409, theta=20.05849 -> V=1.0, theta=0.0
% INFO    : Bus 44075	: V=1.0150971, theta=35.941944 -> V=1.0, theta=0.0
% INFO    : Bus 44076	: V=1.0196969, theta=34.396218 -> V=1.0, theta=0.0
% INFO    : Bus 44077	: V=1.0133459, theta=34.973318 -> V=1.0, theta=0.0
% INFO    : Bus 44078	: V=0.9821092, theta=36.149786 -> V=1.0, theta=0.0
% INFO    : Bus 44079	: V=0.9760454, theta=35.902029 -> V=1.0, theta=0.0
% INFO    : Bus 44080	: V=0.9731608, theta=35.60819 -> V=1.0, theta=0.0
% INFO    : Bus 44081	: V=0.9725934, theta=35.501949 -> V=1.0, theta=0.0
% INFO    : Bus 44082	: V=0.9749467, theta=34.735547 -> V=1.0, theta=0.0
% INFO    : Bus 44083	: V=1.0135867, theta=13.121748 -> V=1.0, theta=0.0
% INFO    : Bus 44084	: V=0.9982887, theta=10.119225 -> V=1.0, theta=0.0
% INFO    : Bus 44085	: V=0.9959614, theta=10.024508 -> V=1.0, theta=0.0
% INFO    : Bus 44086	: V=0.9953995, theta=10.041031 -> V=1.0, theta=0.0
% INFO    : Bus 44087	: V=0.9919453, theta=9.813859 -> V=1.0, theta=0.0
% INFO    : Bus 44088	: V=0.9919402, theta=9.572426 -> V=1.0, theta=0.0
% INFO    : Bus 44089	: V=0.9928725, theta=9.687934 -> V=1.0, theta=0.0
% INFO    : Bus 44090	: V=0.9927346, theta=9.785723 -> V=1.0, theta=0.0
% INFO    : Bus 44091	: V=0.992495, theta=9.79316 -> V=1.0, theta=0.0
% INFO    : Bus 44092	: V=0.9945879, theta=9.938534 -> V=1.0, theta=0.0
% INFO    : Bus 44093	: V=0.9941786, theta=9.900245 -> V=1.0, theta=0.0
% INFO    : Bus 44094	: V=0.9935415, theta=9.881496 -> V=1.0, theta=0.0
% INFO    : Bus 44095	: V=0.9932962, theta=9.862262 -> V=1.0, theta=0.0
% INFO    : Bus 44096	: V=0.9932797, theta=9.784159 -> V=1.0, theta=0.0
% INFO    : Bus 44097	: V=0.9930799, theta=9.829168 -> V=1.0, theta=0.0
% INFO    : Bus 44098	: V=1.0039817, theta=9.969871 -> V=1.0, theta=0.0
% INFO    : Bus 44099	: V=0.9991228, theta=10.069664 -> V=1.0, theta=0.0
% INFO    : Bus 44100	: V=0.9990621, theta=9.935785 -> V=1.0, theta=0.0
% INFO    : Bus 44101	: V=0.9996099, theta=10.055241 -> V=1.0, theta=0.0
% INFO    : Bus 44102	: V=1.0073949, theta=10.414516 -> V=1.0, theta=0.0
% INFO    : Bus 44103	: V=0.9934112, theta=8.613365 -> V=1.0, theta=0.0
% INFO    : Bus 44104	: V=1.016542, theta=12.904184 -> V=1.0, theta=0.0
% INFO    : Bus 44105	: V=0.9960812, theta=9.857337 -> V=1.0, theta=0.0
% INFO    : Bus 44106	: V=1.0178152, theta=12.416027 -> V=1.0, theta=0.0
% INFO    : Bus 44107	: V=1.0169618, theta=12.322843 -> V=1.0, theta=0.0
% INFO    : Bus 44108	: V=1.0182856, theta=38.224168 -> V=1.0, theta=0.0
% INFO    : Bus 44109	: V=1.0196981, theta=37.217784 -> V=1.0, theta=0.0
% INFO    : Bus 44110	: V=1.0178119, theta=38.064984 -> V=1.0, theta=0.0
% INFO    : Bus 44111	: V=1.0122806, theta=29.359311 -> V=1.0, theta=0.0
% INFO    : Bus 44112	: V=0.9807253, theta=24.821587 -> V=1.0, theta=0.0
% INFO    : Bus 44113	: V=1.0111726, theta=27.416676 -> V=1.0, theta=0.0
% INFO    : Bus 44114	: V=1.0048385, theta=28.021153 -> V=1.0, theta=0.0
% INFO    : Bus 44115	: V=0.9821773, theta=24.86335 -> V=1.0, theta=0.0
% INFO    : Bus 44116	: V=0.9855448, theta=39.557639 -> V=1.0, theta=0.0
% INFO    : Bus 44117	: V=1.0032579, theta=40.43932 -> V=1.0, theta=0.0
% INFO    : Bus 44118	: V=0.9818983, theta=39.031211 -> V=1.0, theta=0.0
% INFO    : Bus 44119	: V=0.9806509, theta=40.892087 -> V=1.0, theta=0.0
% INFO    : Bus 44120	: V=0.9804613, theta=40.041489 -> V=1.0, theta=0.0
% INFO    : Bus 44121	: V=0.9790911, theta=39.344118 -> V=1.0, theta=0.0
% INFO    : Bus 44122	: V=0.9940104, theta=41.682745 -> V=1.0, theta=0.0
% INFO    : Bus 44123	: V=0.975119, theta=41.45355 -> V=1.0, theta=0.0
% INFO    : Bus 44124	: V=0.9702457, theta=41.619455 -> V=1.0, theta=0.0
% INFO    : Bus 44125	: V=0.9701138, theta=41.390234 -> V=1.0, theta=0.0
% INFO    : Bus 44126	: V=0.9679776, theta=41.786013 -> V=1.0, theta=0.0
% INFO    : Bus 44127	: V=0.9789337, theta=41.389699 -> V=1.0, theta=0.0
% INFO    : Bus 44128	: V=0.9766253, theta=41.420241 -> V=1.0, theta=0.0
% INFO    : Bus 44129	: V=0.9970774, theta=41.717344 -> V=1.0, theta=0.0
% INFO    : Bus 44130	: V=0.9640619, theta=40.86047 -> V=1.0, theta=0.0
% INFO    : Bus 44131	: V=0.9637952, theta=42.286557 -> V=1.0, theta=0.0
% INFO    : Bus 44132	: V=0.9555175, theta=41.283332 -> V=1.0, theta=0.0
% INFO    : Bus 44133	: V=0.959522, theta=41.468898 -> V=1.0, theta=0.0
% INFO    : Bus 44134	: V=0.9701319, theta=40.970831 -> V=1.0, theta=0.0
% INFO    : Bus 44135	: V=0.9753895, theta=41.069571 -> V=1.0, theta=0.0
% INFO    : Bus 44136	: V=0.9695317, theta=40.918273 -> V=1.0, theta=0.0
% INFO    : Bus 44137	: V=0.9664497, theta=40.879256 -> V=1.0, theta=0.0
% INFO    : Bus 44138	: V=0.9667416, theta=40.910727 -> V=1.0, theta=0.0
% INFO    : Bus 44139	: V=0.9632245, theta=40.878309 -> V=1.0, theta=0.0
% INFO    : Bus 44140	: V=0.9940345, theta=41.434991 -> V=1.0, theta=0.0
% INFO    : Bus 44141	: V=0.9910105, theta=41.371415 -> V=1.0, theta=0.0
% INFO    : Bus 44142	: V=0.9790583, theta=41.13387 -> V=1.0, theta=0.0
% INFO    : Bus 44143	: V=0.9741296, theta=40.997145 -> V=1.0, theta=0.0
% INFO    : Bus 44144	: V=0.9849643, theta=41.291071 -> V=1.0, theta=0.0
% INFO    : Bus 44145	: V=0.9911602, theta=41.498421 -> V=1.0, theta=0.0
% INFO    : Bus 44146	: V=0.9543313, theta=41.368622 -> V=1.0, theta=0.0
% INFO    : Bus 44147	: V=0.9667146, theta=42.153217 -> V=1.0, theta=0.0
% INFO    : Bus 44148	: V=0.9640159, theta=42.019771 -> V=1.0, theta=0.0
% INFO    : Bus 44149	: V=0.9535794, theta=41.346112 -> V=1.0, theta=0.0
% INFO    : Bus 44150	: V=0.9638188, theta=41.654589 -> V=1.0, theta=0.0
% INFO    : Bus 44151	: V=0.9657797, theta=41.406467 -> V=1.0, theta=0.0
% INFO    : Bus 44152	: V=0.9590994, theta=41.56523 -> V=1.0, theta=0.0
% INFO    : Bus 44153	: V=0.9572692, theta=41.623455 -> V=1.0, theta=0.0
% INFO    : Bus 44154	: V=0.9654785, theta=40.564897 -> V=1.0, theta=0.0
% INFO    : Bus 44155	: V=0.9663838, theta=40.578422 -> V=1.0, theta=0.0
% INFO    : Bus 44156	: V=0.9671543, theta=40.608664 -> V=1.0, theta=0.0
% INFO    : Bus 44157	: V=0.9730715, theta=40.948252 -> V=1.0, theta=0.0
% INFO    : Bus 44158	: V=0.9645877, theta=40.559562 -> V=1.0, theta=0.0
% INFO    : Bus 44159	: V=0.9621893, theta=40.708692 -> V=1.0, theta=0.0
% INFO    : Bus 44160	: V=0.9700266, theta=40.939633 -> V=1.0, theta=0.0
% INFO    : Bus 44161	: V=0.9616456, theta=40.774084 -> V=1.0, theta=0.0
% INFO    : Bus 44162	: V=0.9609731, theta=40.773435 -> V=1.0, theta=0.0
% INFO    : Bus 44163	: V=0.9612758, theta=40.782959 -> V=1.0, theta=0.0
% INFO    : Bus 44164	: V=0.962035, theta=40.651889 -> V=1.0, theta=0.0
% INFO    : Bus 44165	: V=0.9714455, theta=40.934338 -> V=1.0, theta=0.0
% INFO    : Bus 44166	: V=0.9612205, theta=40.847628 -> V=1.0, theta=0.0
% INFO    : Bus 44167	: V=0.9691337, theta=40.969177 -> V=1.0, theta=0.0
% INFO    : Bus 44168	: V=0.9614627, theta=40.792509 -> V=1.0, theta=0.0
% INFO    : Bus 44169	: V=0.9634733, theta=40.861553 -> V=1.0, theta=0.0
% INFO    : Bus 44170	: V=0.9614042, theta=40.771773 -> V=1.0, theta=0.0
% INFO    : Bus 44171	: V=0.9695556, theta=40.994848 -> V=1.0, theta=0.0
% INFO    : Bus 44172	: V=0.9584806, theta=40.908895 -> V=1.0, theta=0.0
% INFO    : Bus 44173	: V=0.9630536, theta=40.87149 -> V=1.0, theta=0.0
% INFO    : Bus 44174	: V=0.952898, theta=41.060089 -> V=1.0, theta=0.0
% INFO    : Bus 44175	: V=0.9562595, theta=40.979048 -> V=1.0, theta=0.0
% INFO    : Bus 44176	: V=0.9609989, theta=40.834716 -> V=1.0, theta=0.0
% INFO    : Bus 44177	: V=0.9612256, theta=40.805671 -> V=1.0, theta=0.0
% INFO    : Bus 44178	: V=0.9612945, theta=40.810659 -> V=1.0, theta=0.0
% INFO    : Bus 44179	: V=0.9623909, theta=40.794997 -> V=1.0, theta=0.0
% INFO    : Bus 44180	: V=0.9632424, theta=40.8028 -> V=1.0, theta=0.0
% INFO    : Bus 44181	: V=0.9673835, theta=41.075346 -> V=1.0, theta=0.0
% INFO    : Bus 44182	: V=0.9539224, theta=41.27481 -> V=1.0, theta=0.0
% INFO    : Bus 44183	: V=0.9530525, theta=41.075849 -> V=1.0, theta=0.0
% INFO    : Bus 44184	: V=0.953573, theta=41.265729 -> V=1.0, theta=0.0
% INFO    : Bus 44185	: V=0.953861, theta=41.05471 -> V=1.0, theta=0.0
% INFO    : Bus 44186	: V=0.9547643, theta=41.055324 -> V=1.0, theta=0.0
% INFO    : Bus 44187	: V=0.9571126, theta=41.182581 -> V=1.0, theta=0.0
% INFO    : Bus 44188	: V=0.9574759, theta=41.234519 -> V=1.0, theta=0.0
% INFO    : Bus 44189	: V=0.9648568, theta=40.884343 -> V=1.0, theta=0.0
% INFO    : Bus 44190	: V=0.9647995, theta=40.824878 -> V=1.0, theta=0.0
% INFO    : Bus 44191	: V=1.0024631, theta=41.976867 -> V=1.0, theta=0.0
% INFO    : Bus 44192	: V=0.9712628, theta=41.08609 -> V=1.0, theta=0.0
% INFO    : Bus 44193	: V=0.966243, theta=40.901737 -> V=1.0, theta=0.0
% INFO    : Bus 44194	: V=0.9657705, theta=40.833437 -> V=1.0, theta=0.0
% INFO    : Bus 44195	: V=0.9665913, theta=40.871074 -> V=1.0, theta=0.0
% INFO    : Bus 44196	: V=0.9671667, theta=40.888974 -> V=1.0, theta=0.0
% INFO    : Bus 44197	: V=0.9680651, theta=40.909996 -> V=1.0, theta=0.0
% INFO    : Bus 44198	: V=0.9694501, theta=40.926352 -> V=1.0, theta=0.0
% INFO    : Bus 44199	: V=0.968248, theta=40.941003 -> V=1.0, theta=0.0
% INFO    : Bus 44200	: V=0.9685764, theta=40.938725 -> V=1.0, theta=0.0
% INFO    : Bus 44201	: V=0.9700843, theta=40.912467 -> V=1.0, theta=0.0
% INFO    : Bus 44202	: V=0.9713573, theta=40.956722 -> V=1.0, theta=0.0
% INFO    : Bus 44203	: V=0.9724321, theta=40.98918 -> V=1.0, theta=0.0
% INFO    : Bus 44204	: V=0.968531, theta=42.216442 -> V=1.0, theta=0.0
% INFO    : Bus 44205	: V=0.9536079, theta=29.449907 -> V=1.0, theta=0.0
% INFO    : Bus 44206	: V=0.9618081, theta=22.364791 -> V=1.0, theta=0.0
% INFO    : Bus 44207	: V=0.9639925, theta=20.32279 -> V=1.0, theta=0.0
% INFO    : Bus 44208	: V=0.9640027, theta=17.630431 -> V=1.0, theta=0.0
% INFO    : Bus 44209	: V=0.9665024, theta=19.173642 -> V=1.0, theta=0.0
% INFO    : Bus 44210	: V=0.9702772, theta=18.933724 -> V=1.0, theta=0.0
% INFO    : Bus 44211	: V=0.9751221, theta=18.751582 -> V=1.0, theta=0.0
% INFO    : Bus 44212	: V=0.9577879, theta=15.503527 -> V=1.0, theta=0.0
% INFO    : Bus 44213	: V=0.952464, theta=12.599315 -> V=1.0, theta=0.0
% INFO    : Bus 44214	: V=0.9540914, theta=17.64138 -> V=1.0, theta=0.0
% INFO    : Bus 44215	: V=0.9952848, theta=33.07704 -> V=1.0, theta=0.0
% INFO    : Bus 44216	: V=0.9831811, theta=34.263344 -> V=1.0, theta=0.0
% INFO    : Bus 44217	: V=0.9806762, theta=34.750259 -> V=1.0, theta=0.0
% INFO    : Bus 44218	: V=0.9826825, theta=34.857863 -> V=1.0, theta=0.0
% INFO    : Bus 44219	: V=0.9878207, theta=36.105988 -> V=1.0, theta=0.0
% INFO    : Bus 44220	: V=0.9885974, theta=33.988164 -> V=1.0, theta=0.0
% INFO    : Bus 44221	: V=0.9877535, theta=33.923045 -> V=1.0, theta=0.0
% INFO    : Bus 44222	: V=0.99384, theta=34.053869 -> V=1.0, theta=0.0
% INFO    : Bus 44223	: V=0.9887405, theta=36.132636 -> V=1.0, theta=0.0
% INFO    : Bus 44224	: V=0.9845019, theta=36.416554 -> V=1.0, theta=0.0
% INFO    : Bus 44225	: V=0.9749933, theta=39.934816 -> V=1.0, theta=0.0
% INFO    : Bus 44226	: V=0.9774481, theta=39.196003 -> V=1.0, theta=0.0
% INFO    : Bus 44227	: V=0.9773798, theta=38.541969 -> V=1.0, theta=0.0
% INFO    : Bus 44228	: V=0.9821411, theta=39.12382 -> V=1.0, theta=0.0
% INFO    : Bus 44229	: V=0.9856871, theta=39.585895 -> V=1.0, theta=0.0
% INFO    : Bus 44230	: V=0.9805982, theta=39.68986 -> V=1.0, theta=0.0
% INFO    : Bus 44231	: V=0.9866332, theta=39.578662 -> V=1.0, theta=0.0
% INFO    : Bus 44232	: V=0.9893944, theta=39.739494 -> V=1.0, theta=0.0
% INFO    : Bus 44233	: V=1.0151358, theta=42.689752 -> V=1.0, theta=0.0
% INFO    : Bus 44234	: V=0.9576692, theta=15.631323 -> V=1.0, theta=0.0
% INFO    : Bus 44235	: V=0.9565316, theta=14.394862 -> V=1.0, theta=0.0
% INFO    : Bus 44236	: V=0.9602996, theta=15.76776 -> V=1.0, theta=0.0
% INFO    : Bus 44237	: V=1.0079957, theta=37.472499 -> V=1.0, theta=0.0
% INFO    : Bus 44238	: V=1.0152886, theta=37.597816 -> V=1.0, theta=0.0
% INFO    : Bus 44239	: V=1.0156716, theta=37.374818 -> V=1.0, theta=0.0
% INFO    : Bus 44240	: V=1.0127613, theta=37.472031 -> V=1.0, theta=0.0
% INFO    : Bus 44241	: V=1.0129269, theta=37.486736 -> V=1.0, theta=0.0
% INFO    : Bus 44242	: V=1.0100648, theta=37.390372 -> V=1.0, theta=0.0
% INFO    : Bus 44243	: V=1.0128354, theta=37.456189 -> V=1.0, theta=0.0
% INFO    : Bus 44244	: V=1.0091687, theta=37.389639 -> V=1.0, theta=0.0
% INFO    : Bus 44245	: V=0.9947724, theta=34.890821 -> V=1.0, theta=0.0
% INFO    : Bus 44246	: V=0.9875578, theta=34.613222 -> V=1.0, theta=0.0
% INFO    : Bus 44247	: V=1.0127938, theta=37.422444 -> V=1.0, theta=0.0
% INFO    : Bus 44248	: V=1.0088939, theta=37.390957 -> V=1.0, theta=0.0
% INFO    : Bus 44249	: V=1.0180443, theta=37.050534 -> V=1.0, theta=0.0
% INFO    : Bus 44250	: V=1.0168191, theta=36.983041 -> V=1.0, theta=0.0
% INFO    : Bus 44251	: V=0.990912, theta=34.179991 -> V=1.0, theta=0.0
% INFO    : Bus 44252	: V=1.0129159, theta=37.386881 -> V=1.0, theta=0.0
% INFO    : Bus 44253	: V=1.0191939, theta=33.489233 -> V=1.0, theta=0.0
% INFO    : Bus 44254	: V=1.0134956, theta=33.523752 -> V=1.0, theta=0.0
% INFO    : Bus 44255	: V=1.0132227, theta=33.520357 -> V=1.0, theta=0.0
% INFO    : Bus 44256	: V=1.013547, theta=33.513795 -> V=1.0, theta=0.0
% INFO    : Bus 44257	: V=1.0092044, theta=33.751426 -> V=1.0, theta=0.0
% INFO    : Bus 44258	: V=1.0090417, theta=33.684743 -> V=1.0, theta=0.0
% INFO    : Bus 44259	: V=1.0086789, theta=31.150163 -> V=1.0, theta=0.0
% INFO    : Bus 44260	: V=1.0104516, theta=33.55845 -> V=1.0, theta=0.0
% INFO    : Bus 44261	: V=1.018693, theta=43.918202 -> V=1.0, theta=0.0
% INFO    : Bus 44262	: V=1.0185496, theta=43.880541 -> V=1.0, theta=0.0
% INFO    : Bus 44263	: V=1.0112884, theta=44.137901 -> V=1.0, theta=0.0
% INFO    : Bus 44264	: V=1.0117121, theta=44.002596 -> V=1.0, theta=0.0
% INFO    : Bus 44265	: V=1.0089319, theta=43.602528 -> V=1.0, theta=0.0
% INFO    : Bus 44266	: V=0.9916718, theta=43.165137 -> V=1.0, theta=0.0
% INFO    : Bus 44267	: V=1.0147298, theta=43.810375 -> V=1.0, theta=0.0
% INFO    : Bus 44268	: V=0.9895568, theta=39.200181 -> V=1.0, theta=0.0
% INFO    : Bus 44269	: V=0.9928599, theta=39.362577 -> V=1.0, theta=0.0
% INFO    : Bus 44270	: V=0.9854384, theta=39.293973 -> V=1.0, theta=0.0
% INFO    : Bus 44271	: V=0.983815, theta=39.300215 -> V=1.0, theta=0.0
% INFO    : Bus 44272	: V=0.9741066, theta=39.865198 -> V=1.0, theta=0.0
% INFO    : Bus 44273	: V=0.9770696, theta=39.784509 -> V=1.0, theta=0.0
% INFO    : Bus 44274	: V=0.9722661, theta=40.013159 -> V=1.0, theta=0.0
% INFO    : Bus 44275	: V=0.9727613, theta=40.012834 -> V=1.0, theta=0.0
% INFO    : Bus 44276	: V=0.9724489, theta=40.0211 -> V=1.0, theta=0.0
% INFO    : Bus 44277	: V=0.9728065, theta=40.052948 -> V=1.0, theta=0.0
% INFO    : Bus 44278	: V=0.9724733, theta=40.062591 -> V=1.0, theta=0.0
% INFO    : Bus 44279	: V=0.9860134, theta=40.344624 -> V=1.0, theta=0.0
% INFO    : Bus 44280	: V=0.9888365, theta=40.488988 -> V=1.0, theta=0.0
% INFO    : Bus 44281	: V=0.9768575, theta=39.800723 -> V=1.0, theta=0.0
% INFO    : Bus 44282	: V=0.9891437, theta=40.321903 -> V=1.0, theta=0.0
% INFO    : Bus 44283	: V=0.9901035, theta=40.218724 -> V=1.0, theta=0.0
% INFO    : Bus 44284	: V=0.9905353, theta=39.787952 -> V=1.0, theta=0.0
% INFO    : Bus 44285	: V=0.9958047, theta=39.002456 -> V=1.0, theta=0.0
% INFO    : Bus 44286	: V=0.9920879, theta=39.362508 -> V=1.0, theta=0.0
% INFO    : Bus 44287	: V=0.9979498, theta=37.991072 -> V=1.0, theta=0.0
% INFO    : Bus 44288	: V=0.9832891, theta=36.97733 -> V=1.0, theta=0.0
% INFO    : Bus 44289	: V=0.9982501, theta=41.13865 -> V=1.0, theta=0.0
% INFO    : Bus 44290	: V=0.9892222, theta=39.96758 -> V=1.0, theta=0.0
% INFO    : Bus 44291	: V=0.9845536, theta=38.997586 -> V=1.0, theta=0.0
% INFO    : Bus 44292	: V=0.9832235, theta=38.546456 -> V=1.0, theta=0.0
% INFO    : Bus 44293	: V=0.9779528, theta=38.662568 -> V=1.0, theta=0.0
% INFO    : Bus 44294	: V=0.994673, theta=37.576814 -> V=1.0, theta=0.0
% INFO    : Bus 44295	: V=0.9850085, theta=37.466421 -> V=1.0, theta=0.0
% INFO    : Bus 44296	: V=0.9815343, theta=35.640698 -> V=1.0, theta=0.0
% INFO    : Bus 44297	: V=0.9823893, theta=24.326275 -> V=1.0, theta=0.0
% INFO    : Bus 44298	: V=0.9819494, theta=25.805561 -> V=1.0, theta=0.0
% INFO    : Bus 44299	: V=0.9845024, theta=23.671507 -> V=1.0, theta=0.0
% INFO    : Bus 44300	: V=0.9945621, theta=24.132583 -> V=1.0, theta=0.0
% INFO    : Bus 44301	: V=0.9818235, theta=41.982079 -> V=1.0, theta=0.0
% INFO    : Bus 44302	: V=0.9544335, theta=42.523329 -> V=1.0, theta=0.0
% INFO    : Bus 44303	: V=0.9553321, theta=42.301214 -> V=1.0, theta=0.0
% INFO    : Bus 44304	: V=0.958056, theta=42.261767 -> V=1.0, theta=0.0
% INFO    : Bus 44305	: V=0.983874, theta=43.567243 -> V=1.0, theta=0.0
% INFO    : Bus 44306	: V=0.9634816, theta=42.495106 -> V=1.0, theta=0.0
% INFO    : Bus 44307	: V=0.9684132, theta=43.181031 -> V=1.0, theta=0.0
% INFO    : Bus 44308	: V=0.970495, theta=43.180007 -> V=1.0, theta=0.0
% INFO    : Bus 44309	: V=0.9669911, theta=43.233363 -> V=1.0, theta=0.0
% INFO    : Bus 44310	: V=0.9674354, theta=43.360234 -> V=1.0, theta=0.0
% INFO    : Bus 44311	: V=0.9495916, theta=3.114558 -> V=1.0, theta=0.0
% INFO    : Bus 44312	: V=0.9505953, theta=1.625172 -> V=1.0, theta=0.0
% INFO    : Bus 44313	: V=0.9504549, theta=1.881752 -> V=1.0, theta=0.0
% INFO    : Bus 44314	: V=0.9503054, theta=1.867836 -> V=1.0, theta=0.0
% INFO    : Bus 44315	: V=0.9521447, theta=2.016496 -> V=1.0, theta=0.0
% INFO    : Bus 44316	: V=0.9513017, theta=2.301921 -> V=1.0, theta=0.0
% INFO    : Bus 44317	: V=0.9490991, theta=2.325779 -> V=1.0, theta=0.0
% INFO    : Bus 44318	: V=0.9514719, theta=2.516377 -> V=1.0, theta=0.0
% INFO    : Bus 44319	: V=0.9555393, theta=4.276018 -> V=1.0, theta=0.0
% INFO    : Bus 44320	: V=0.9472283, theta=4.0464 -> V=1.0, theta=0.0
% INFO    : Bus 44321	: V=0.9508855, theta=5.032625 -> V=1.0, theta=0.0
% INFO    : Bus 44322	: V=0.949746, theta=8.338817 -> V=1.0, theta=0.0
% INFO    : Bus 44323	: V=0.9693542, theta=10.939812 -> V=1.0, theta=0.0
% INFO    : Bus 44324	: V=0.9902876, theta=27.862976 -> V=1.0, theta=0.0
% INFO    : Bus 44325	: V=0.9868991, theta=25.640216 -> V=1.0, theta=0.0
% INFO    : Bus 44326	: V=0.9793985, theta=25.920611 -> V=1.0, theta=0.0
% INFO    : Bus 44327	: V=1.015799, theta=50.010136 -> V=1.0, theta=0.0
% INFO    : Bus 44328	: V=1.0060571, theta=49.923168 -> V=1.0, theta=0.0
% INFO    : Bus 44329	: V=1.0087078, theta=30.516777 -> V=1.0, theta=0.0
% INFO    : Bus 44330	: V=1.0119803, theta=27.641288 -> V=1.0, theta=0.0
% INFO    : Bus 44331	: V=1.0152428, theta=27.874195 -> V=1.0, theta=0.0
% INFO    : Bus 44332	: V=1.015078, theta=30.949043 -> V=1.0, theta=0.0
% INFO    : Bus 44333	: V=0.9889651, theta=39.253688 -> V=1.0, theta=0.0
% INFO    : Bus 44334	: V=0.9864371, theta=38.863347 -> V=1.0, theta=0.0
% INFO    : Bus 44335	: V=0.9807878, theta=38.285381 -> V=1.0, theta=0.0
% INFO    : Bus 44336	: V=0.985489, theta=38.050557 -> V=1.0, theta=0.0
% INFO    : Bus 44337	: V=0.9853532, theta=38.436609 -> V=1.0, theta=0.0
% INFO    : Bus 44338	: V=0.9765331, theta=38.175801 -> V=1.0, theta=0.0
% INFO    : Bus 44339	: V=0.9767615, theta=37.719761 -> V=1.0, theta=0.0
% INFO    : Bus 44340	: V=0.991964, theta=37.940756 -> V=1.0, theta=0.0
% INFO    : Bus 44341	: V=0.9869721, theta=37.506953 -> V=1.0, theta=0.0
% INFO    : Bus 44342	: V=0.984918, theta=37.496301 -> V=1.0, theta=0.0
% INFO    : Bus 44343	: V=0.9929818, theta=38.099986 -> V=1.0, theta=0.0
% INFO    : Bus 44344	: V=0.9870432, theta=37.539668 -> V=1.0, theta=0.0
% INFO    : Bus 44345	: V=0.9862813, theta=37.50722 -> V=1.0, theta=0.0
% INFO    : Bus 44346	: V=0.9853977, theta=37.504289 -> V=1.0, theta=0.0
% INFO    : Bus 44347	: V=0.9764147, theta=37.972394 -> V=1.0, theta=0.0
% INFO    : Bus 44348	: V=0.9811088, theta=38.53616 -> V=1.0, theta=0.0
% INFO    : Bus 44349	: V=0.9884884, theta=41.839206 -> V=1.0, theta=0.0
% INFO    : Bus 44350	: V=0.9888951, theta=41.787339 -> V=1.0, theta=0.0
% INFO    : Bus 44351	: V=0.9892786, theta=41.797404 -> V=1.0, theta=0.0
% INFO    : Bus 44352	: V=0.9895248, theta=41.829789 -> V=1.0, theta=0.0
% INFO    : Bus 44353	: V=0.9899751, theta=41.874325 -> V=1.0, theta=0.0
% INFO    : Bus 44354	: V=0.9894948, theta=41.886326 -> V=1.0, theta=0.0
% INFO    : Bus 44355	: V=0.9899646, theta=41.91014 -> V=1.0, theta=0.0
% INFO    : Bus 44356	: V=0.9915407, theta=41.987008 -> V=1.0, theta=0.0
% INFO    : Bus 44357	: V=0.9911154, theta=41.923092 -> V=1.0, theta=0.0
% INFO    : Bus 44358	: V=0.9923494, theta=42.001318 -> V=1.0, theta=0.0
% INFO    : Bus 44359	: V=0.9932923, theta=42.017527 -> V=1.0, theta=0.0
% INFO    : Bus 44360	: V=1.0014777, theta=42.350241 -> V=1.0, theta=0.0
% INFO    : Bus 44361	: V=0.9967541, theta=42.146983 -> V=1.0, theta=0.0
% INFO    : Bus 44362	: V=0.9892673, theta=41.811387 -> V=1.0, theta=0.0
% INFO    : Bus 44363	: V=0.9922404, theta=41.918348 -> V=1.0, theta=0.0
% INFO    : Bus 44364	: V=0.9903466, theta=41.838203 -> V=1.0, theta=0.0
% INFO    : Bus 44365	: V=0.9966919, theta=41.992694 -> V=1.0, theta=0.0
% INFO    : Bus 44366	: V=0.9964676, theta=42.077925 -> V=1.0, theta=0.0
% INFO    : Bus 44367	: V=0.9851609, theta=41.595316 -> V=1.0, theta=0.0
% INFO    : Bus 44368	: V=0.9895204, theta=41.71594 -> V=1.0, theta=0.0
% INFO    : Bus 44369	: V=0.99084, theta=41.702898 -> V=1.0, theta=0.0
% INFO    : Bus 44370	: V=0.9873481, theta=41.676394 -> V=1.0, theta=0.0
% INFO    : Bus 44371	: V=0.9787723, theta=40.791349 -> V=1.0, theta=0.0
% INFO    : Bus 44372	: V=0.9803428, theta=40.882933 -> V=1.0, theta=0.0
% INFO    : Bus 44373	: V=0.9827916, theta=41.123206 -> V=1.0, theta=0.0
% INFO    : Bus 44374	: V=0.9833052, theta=41.14725 -> V=1.0, theta=0.0
% INFO    : Bus 44375	: V=0.9863401, theta=41.25639 -> V=1.0, theta=0.0
% INFO    : Bus 44376	: V=0.9836124, theta=41.337094 -> V=1.0, theta=0.0
% INFO    : Bus 44377	: V=0.9926498, theta=41.746672 -> V=1.0, theta=0.0
% INFO    : Bus 44378	: V=0.9850574, theta=41.359454 -> V=1.0, theta=0.0
% INFO    : Bus 44379	: V=0.9832647, theta=41.343688 -> V=1.0, theta=0.0
% INFO    : Bus 44380	: V=0.9826318, theta=41.377601 -> V=1.0, theta=0.0
% INFO    : Bus 44381	: V=0.9841438, theta=41.460689 -> V=1.0, theta=0.0
% INFO    : Bus 44382	: V=0.9851616, theta=41.551151 -> V=1.0, theta=0.0
% INFO    : Bus 44383	: V=0.9837765, theta=41.437075 -> V=1.0, theta=0.0
% INFO    : Bus 44384	: V=0.9866042, theta=41.608534 -> V=1.0, theta=0.0
% INFO    : Bus 44385	: V=0.9888214, theta=41.658653 -> V=1.0, theta=0.0
% INFO    : Bus 44386	: V=0.9879214, theta=41.662899 -> V=1.0, theta=0.0
% INFO    : Bus 44387	: V=0.9843718, theta=41.376011 -> V=1.0, theta=0.0
% INFO    : Bus 44388	: V=0.9867138, theta=41.344478 -> V=1.0, theta=0.0
% INFO    : Bus 44389	: V=0.9854381, theta=41.35226 -> V=1.0, theta=0.0
% INFO    : Bus 44390	: V=0.9845689, theta=41.170489 -> V=1.0, theta=0.0
% INFO    : Bus 44391	: V=0.9843329, theta=41.176284 -> V=1.0, theta=0.0
% INFO    : Bus 44392	: V=0.9915629, theta=41.252924 -> V=1.0, theta=0.0
% INFO    : Bus 44393	: V=0.9831999, theta=41.145697 -> V=1.0, theta=0.0
% INFO    : Bus 44394	: V=0.9839831, theta=41.174196 -> V=1.0, theta=0.0
% INFO    : Bus 44395	: V=0.9888977, theta=41.360711 -> V=1.0, theta=0.0
% INFO    : Bus 44396	: V=0.9884968, theta=41.35339 -> V=1.0, theta=0.0
% INFO    : Bus 44397	: V=0.9825774, theta=41.040284 -> V=1.0, theta=0.0
% INFO    : Bus 44398	: V=0.9922438, theta=41.259317 -> V=1.0, theta=0.0
% INFO    : Bus 44399	: V=0.9889892, theta=41.358442 -> V=1.0, theta=0.0
% INFO    : Bus 44400	: V=1.0005325, theta=41.714909 -> V=1.0, theta=0.0
% INFO    : Bus 44401	: V=0.9840999, theta=41.341268 -> V=1.0, theta=0.0
% INFO    : Bus 44402	: V=0.9845431, theta=41.342751 -> V=1.0, theta=0.0
% INFO    : Bus 44403	: V=0.9935173, theta=41.688455 -> V=1.0, theta=0.0
% INFO    : Bus 44404	: V=0.9830194, theta=41.235714 -> V=1.0, theta=0.0
% INFO    : Bus 44405	: V=0.9837837, theta=41.214784 -> V=1.0, theta=0.0
% INFO    : Bus 44406	: V=0.9848154, theta=41.223313 -> V=1.0, theta=0.0
% INFO    : Bus 44407	: V=0.9863564, theta=41.070676 -> V=1.0, theta=0.0
% INFO    : Bus 44408	: V=0.993318, theta=41.266432 -> V=1.0, theta=0.0
% INFO    : Bus 44409	: V=0.993489, theta=41.263029 -> V=1.0, theta=0.0
% INFO    : Bus 44410	: V=0.9866615, theta=41.168577 -> V=1.0, theta=0.0
% INFO    : Bus 44411	: V=0.9945016, theta=41.645748 -> V=1.0, theta=0.0
% INFO    : Bus 44412	: V=0.9869714, theta=41.298932 -> V=1.0, theta=0.0
% INFO    : Bus 44413	: V=0.9860487, theta=41.200711 -> V=1.0, theta=0.0
% INFO    : Bus 44414	: V=0.994245, theta=41.261255 -> V=1.0, theta=0.0
% INFO    : Bus 44415	: V=0.9965697, theta=41.546327 -> V=1.0, theta=0.0
% INFO    : Bus 44416	: V=0.9937836, theta=41.697796 -> V=1.0, theta=0.0
% INFO    : Bus 44417	: V=0.9858292, theta=41.279212 -> V=1.0, theta=0.0
% INFO    : Bus 44418	: V=0.9863477, theta=41.309031 -> V=1.0, theta=0.0
% INFO    : Bus 44419	: V=0.9942874, theta=41.714841 -> V=1.0, theta=0.0
% INFO    : Bus 44420	: V=0.9945257, theta=41.707085 -> V=1.0, theta=0.0
% INFO    : Bus 44421	: V=0.9858173, theta=41.259524 -> V=1.0, theta=0.0
% INFO    : Bus 44422	: V=0.9943281, theta=41.678106 -> V=1.0, theta=0.0
% INFO    : Bus 44423	: V=0.9905575, theta=41.348127 -> V=1.0, theta=0.0
% INFO    : Bus 44424	: V=0.9994265, theta=41.646339 -> V=1.0, theta=0.0
% INFO    : Bus 44425	: V=0.992471, theta=41.433555 -> V=1.0, theta=0.0
% INFO    : Bus 44426	: V=0.9874337, theta=41.303832 -> V=1.0, theta=0.0
% INFO    : Bus 44427	: V=0.9888918, theta=41.403563 -> V=1.0, theta=0.0
% INFO    : Bus 44428	: V=1.0028068, theta=42.085176 -> V=1.0, theta=0.0
% INFO    : Bus 44429	: V=1.0098382, theta=42.362466 -> V=1.0, theta=0.0
% INFO    : Bus 44430	: V=0.9953278, theta=41.762551 -> V=1.0, theta=0.0
% INFO    : Bus 44431	: V=0.993536, theta=41.735688 -> V=1.0, theta=0.0
% INFO    : Bus 44432	: V=0.9950505, theta=41.733549 -> V=1.0, theta=0.0
% INFO    : Bus 44433	: V=0.9961401, theta=41.791969 -> V=1.0, theta=0.0
% INFO    : Bus 44434	: V=0.9970025, theta=41.834491 -> V=1.0, theta=0.0
% INFO    : Bus 44435	: V=1.0135661, theta=43.253186 -> V=1.0, theta=0.0
% INFO    : Bus 44436	: V=1.0116072, theta=43.080319 -> V=1.0, theta=0.0
% INFO    : Bus 44437	: V=1.0116859, theta=43.080786 -> V=1.0, theta=0.0
% INFO    : Bus 44438	: V=1.0070066, theta=43.11041 -> V=1.0, theta=0.0
% INFO    : Bus 44439	: V=1.0138909, theta=43.199777 -> V=1.0, theta=0.0
% INFO    : Bus 44440	: V=1.0151209, theta=43.434486 -> V=1.0, theta=0.0
% INFO    : Bus 44441	: V=1.0104577, theta=42.383217 -> V=1.0, theta=0.0
% INFO    : Bus 44442	: V=1.0014505, theta=41.658403 -> V=1.0, theta=0.0
% INFO    : Bus 44443	: V=1.0052801, theta=41.687022 -> V=1.0, theta=0.0
% INFO    : Bus 44444	: V=1.0060997, theta=41.119245 -> V=1.0, theta=0.0
% INFO    : Bus 44445	: V=1.0139048, theta=40.820841 -> V=1.0, theta=0.0
% INFO    : Bus 44446	: V=1.0112028, theta=40.535427 -> V=1.0, theta=0.0
% INFO    : Bus 44447	: V=1.015243, theta=40.753379 -> V=1.0, theta=0.0
% INFO    : Bus 44448	: V=1.0100691, theta=40.949761 -> V=1.0, theta=0.0
% INFO    : Bus 44449	: V=0.9765083, theta=26.273444 -> V=1.0, theta=0.0
% INFO    : Bus 44450	: V=0.9853691, theta=21.601596 -> V=1.0, theta=0.0
% INFO    : Bus 44451	: V=0.9783575, theta=24.809335 -> V=1.0, theta=0.0
% INFO    : Bus 44452	: V=0.9797143, theta=24.931107 -> V=1.0, theta=0.0
% INFO    : Bus 44453	: V=0.9792481, theta=25.98048 -> V=1.0, theta=0.0
% INFO    : Bus 44454	: V=0.9779489, theta=25.876668 -> V=1.0, theta=0.0
% INFO    : Bus 44455	: V=0.9800525, theta=25.216537 -> V=1.0, theta=0.0
% INFO    : Bus 44456	: V=0.9850515, theta=24.932577 -> V=1.0, theta=0.0
% INFO    : Bus 44457	: V=0.9773101, theta=26.107245 -> V=1.0, theta=0.0
% INFO    : Bus 44458	: V=1.0109993, theta=36.819934 -> V=1.0, theta=0.0
% INFO    : Bus 44459	: V=1.0069764, theta=34.032281 -> V=1.0, theta=0.0
% INFO    : Bus 44460	: V=0.9944628, theta=33.369838 -> V=1.0, theta=0.0
% INFO    : Bus 44461	: V=1.0042469, theta=33.315453 -> V=1.0, theta=0.0
% INFO    : Bus 44462	: V=1.0113078, theta=36.487195 -> V=1.0, theta=0.0
% INFO    : Bus 44463	: V=1.0104021, theta=36.877761 -> V=1.0, theta=0.0
% INFO    : Bus 44464	: V=1.0143257, theta=41.319268 -> V=1.0, theta=0.0
% INFO    : Bus 44465	: V=1.0128224, theta=40.906302 -> V=1.0, theta=0.0
% INFO    : Bus 44466	: V=1.0093571, theta=40.075169 -> V=1.0, theta=0.0
% INFO    : Bus 44467	: V=1.0006891, theta=38.958043 -> V=1.0, theta=0.0
% INFO    : Bus 44468	: V=0.9983968, theta=37.990455 -> V=1.0, theta=0.0
% INFO    : Bus 44469	: V=1.0017141, theta=40.987973 -> V=1.0, theta=0.0
% INFO    : Bus 44470	: V=1.0130131, theta=38.959813 -> V=1.0, theta=0.0
% INFO    : Bus 44471	: V=0.9972531, theta=37.749372 -> V=1.0, theta=0.0
% INFO    : Bus 44472	: V=1.0055616, theta=36.779295 -> V=1.0, theta=0.0
% INFO    : Bus 44473	: V=1.006223, theta=37.517993 -> V=1.0, theta=0.0
% INFO    : Bus 44474	: V=1.0106487, theta=37.580397 -> V=1.0, theta=0.0
% INFO    : Bus 44475	: V=1.0167529, theta=37.542113 -> V=1.0, theta=0.0
% INFO    : Bus 44476	: V=1.0064859, theta=37.515738 -> V=1.0, theta=0.0
% INFO    : Bus 44477	: V=1.0111404, theta=37.638421 -> V=1.0, theta=0.0
% INFO    : Bus 44478	: V=1.0067287, theta=37.523594 -> V=1.0, theta=0.0
% INFO    : Bus 44479	: V=1.0155759, theta=38.527307 -> V=1.0, theta=0.0
% INFO    : Bus 44480	: V=1.0143571, theta=43.809731 -> V=1.0, theta=0.0
% INFO    : Bus 44481	: V=1.0138623, theta=43.796781 -> V=1.0, theta=0.0
% INFO    : Bus 44482	: V=1.0151343, theta=43.854055 -> V=1.0, theta=0.0
% INFO    : Bus 44483	: V=1.0117826, theta=43.729869 -> V=1.0, theta=0.0
% INFO    : Bus 44484	: V=1.003449, theta=43.808634 -> V=1.0, theta=0.0
% INFO    : Bus 44485	: V=1.0003878, theta=41.976087 -> V=1.0, theta=0.0
% INFO    : Bus 44486	: V=1.0199987, theta=42.758085 -> V=1.0, theta=0.0
% INFO    : Bus 44487	: V=1.0020469, theta=41.256999 -> V=1.0, theta=0.0
% INFO    : Bus 44488	: V=1.0187307, theta=41.89706 -> V=1.0, theta=0.0
% INFO    : Bus 44489	: V=1.0201878, theta=42.699713 -> V=1.0, theta=0.0
% INFO    : Bus 44490	: V=1.0013938, theta=21.156525 -> V=1.0, theta=0.0
% INFO    : Bus 44491	: V=0.989085, theta=18.932723 -> V=1.0, theta=0.0
% INFO    : Bus 44492	: V=0.9687792, theta=40.925616 -> V=1.0, theta=0.0
% INFO    : Bus 44493	: V=0.9643683, theta=40.76414 -> V=1.0, theta=0.0
% INFO    : Bus 44494	: V=0.9642886, theta=40.740126 -> V=1.0, theta=0.0
% INFO    : Bus 44495	: V=0.9688249, theta=40.89291 -> V=1.0, theta=0.0
% INFO    : Bus 44496	: V=0.9745539, theta=41.102587 -> V=1.0, theta=0.0
% INFO    : Bus 44497	: V=0.9697029, theta=40.920919 -> V=1.0, theta=0.0
% INFO    : Bus 44498	: V=0.9683042, theta=40.861015 -> V=1.0, theta=0.0
% INFO    : Bus 44499	: V=0.9668165, theta=40.830992 -> V=1.0, theta=0.0
% INFO    : Bus 44500	: V=0.9684305, theta=40.845714 -> V=1.0, theta=0.0
% INFO    : Bus 44501	: V=0.9653415, theta=40.798484 -> V=1.0, theta=0.0
% INFO    : Bus 44502	: V=0.9658435, theta=40.788545 -> V=1.0, theta=0.0
% INFO    : Bus 44503	: V=0.9728608, theta=40.919913 -> V=1.0, theta=0.0
% INFO    : Bus 44504	: V=0.9715868, theta=40.966507 -> V=1.0, theta=0.0
% INFO    : Bus 44505	: V=0.9720218, theta=40.940108 -> V=1.0, theta=0.0
% INFO    : Bus 44506	: V=0.9718353, theta=40.945322 -> V=1.0, theta=0.0
% INFO    : Bus 44507	: V=0.9688499, theta=40.814317 -> V=1.0, theta=0.0
% INFO    : Bus 44508	: V=0.9705875, theta=40.800066 -> V=1.0, theta=0.0
% INFO    : Bus 44509	: V=0.9716111, theta=40.875751 -> V=1.0, theta=0.0
% INFO    : Bus 44510	: V=0.9714271, theta=40.844257 -> V=1.0, theta=0.0
% INFO    : Bus 44511	: V=0.9716247, theta=40.838509 -> V=1.0, theta=0.0
% INFO    : Bus 44512	: V=0.9720195, theta=40.862951 -> V=1.0, theta=0.0
% INFO    : Bus 44513	: V=0.9810995, theta=41.285027 -> V=1.0, theta=0.0
% INFO    : Bus 44514	: V=0.9809744, theta=41.294374 -> V=1.0, theta=0.0
% INFO    : Bus 44515	: V=0.9815739, theta=41.276009 -> V=1.0, theta=0.0
% INFO    : Bus 44516	: V=0.9752317, theta=40.975719 -> V=1.0, theta=0.0
% INFO    : Bus 44517	: V=0.9712425, theta=40.746919 -> V=1.0, theta=0.0
% INFO    : Bus 44518	: V=0.9742507, theta=40.861492 -> V=1.0, theta=0.0
% INFO    : Bus 44519	: V=0.9828816, theta=41.259051 -> V=1.0, theta=0.0
% INFO    : Bus 44520	: V=0.9804989, theta=41.130809 -> V=1.0, theta=0.0
% INFO    : Bus 44521	: V=0.9848948, theta=41.278378 -> V=1.0, theta=0.0
% INFO    : Bus 44522	: V=0.9785249, theta=41.093581 -> V=1.0, theta=0.0
% INFO    : Bus 44523	: V=0.9780763, theta=41.103155 -> V=1.0, theta=0.0
% INFO    : Bus 44524	: V=0.9733469, theta=40.765825 -> V=1.0, theta=0.0
% INFO    : Bus 44525	: V=0.9858187, theta=41.244035 -> V=1.0, theta=0.0
% INFO    : Bus 44526	: V=0.977245, theta=41.123507 -> V=1.0, theta=0.0
% INFO    : Bus 44527	: V=0.9769782, theta=41.131414 -> V=1.0, theta=0.0
% INFO    : Bus 44528	: V=0.9747967, theta=41.096555 -> V=1.0, theta=0.0
% INFO    : Bus 44529	: V=0.9740284, theta=41.075277 -> V=1.0, theta=0.0
% INFO    : Bus 44530	: V=0.969405, theta=40.969414 -> V=1.0, theta=0.0
% INFO    : Bus 44531	: V=0.9628777, theta=40.665721 -> V=1.0, theta=0.0
% INFO    : Bus 44532	: V=0.9594895, theta=40.57561 -> V=1.0, theta=0.0
% INFO    : Bus 44533	: V=0.9618873, theta=40.620827 -> V=1.0, theta=0.0
% INFO    : Bus 44534	: V=0.9626066, theta=40.695194 -> V=1.0, theta=0.0
% INFO    : Bus 44535	: V=0.9622747, theta=40.696387 -> V=1.0, theta=0.0
% INFO    : Bus 44536	: V=0.9653814, theta=40.765926 -> V=1.0, theta=0.0
% INFO    : Bus 44537	: V=0.9687527, theta=40.933876 -> V=1.0, theta=0.0
% INFO    : Bus 44538	: V=0.9604538, theta=40.600472 -> V=1.0, theta=0.0
% INFO    : Bus 44539	: V=0.9583947, theta=40.49355 -> V=1.0, theta=0.0
% INFO    : Bus 44540	: V=0.9596656, theta=40.557251 -> V=1.0, theta=0.0
% INFO    : Bus 44541	: V=0.9583802, theta=40.473605 -> V=1.0, theta=0.0
% INFO    : Bus 44542	: V=0.9591655, theta=40.527695 -> V=1.0, theta=0.0
% INFO    : Bus 44543	: V=0.9579145, theta=40.4246 -> V=1.0, theta=0.0
% INFO    : Bus 44544	: V=0.9580624, theta=40.410843 -> V=1.0, theta=0.0
% INFO    : Bus 44545	: V=0.9590103, theta=40.531843 -> V=1.0, theta=0.0
% INFO    : Bus 44546	: V=0.9631218, theta=40.688425 -> V=1.0, theta=0.0
% INFO    : Bus 44547	: V=0.9618025, theta=40.63798 -> V=1.0, theta=0.0
% INFO    : Bus 44548	: V=0.9640579, theta=40.733063 -> V=1.0, theta=0.0
% INFO    : Bus 44549	: V=0.9571924, theta=40.446859 -> V=1.0, theta=0.0
% INFO    : Bus 44550	: V=0.9575096, theta=40.440769 -> V=1.0, theta=0.0
% INFO    : Bus 44551	: V=0.9579979, theta=40.410897 -> V=1.0, theta=0.0
% INFO    : Bus 44552	: V=0.9582831, theta=40.374322 -> V=1.0, theta=0.0
% INFO    : Bus 44553	: V=0.9579545, theta=40.335914 -> V=1.0, theta=0.0
% INFO    : Bus 44554	: V=0.9597601, theta=40.312798 -> V=1.0, theta=0.0
% INFO    : Bus 44555	: V=0.9588135, theta=40.370818 -> V=1.0, theta=0.0
% INFO    : Bus 44556	: V=0.9642541, theta=40.688314 -> V=1.0, theta=0.0
% INFO    : Bus 44557	: V=0.9652476, theta=40.596641 -> V=1.0, theta=0.0
% INFO    : Bus 44558	: V=0.9613154, theta=40.375108 -> V=1.0, theta=0.0
% INFO    : Bus 44559	: V=0.9651762, theta=40.52421 -> V=1.0, theta=0.0
% INFO    : Bus 44560	: V=0.9633065, theta=40.425554 -> V=1.0, theta=0.0
% INFO    : Bus 44561	: V=0.9638064, theta=40.419934 -> V=1.0, theta=0.0
% INFO    : Bus 44562	: V=0.9632093, theta=40.38105 -> V=1.0, theta=0.0
% INFO    : Bus 44563	: V=0.9735186, theta=40.643084 -> V=1.0, theta=0.0
% INFO    : Bus 44564	: V=0.9731225, theta=40.657719 -> V=1.0, theta=0.0
% INFO    : Bus 44565	: V=0.9650631, theta=40.424183 -> V=1.0, theta=0.0
% INFO    : Bus 44566	: V=0.9655463, theta=40.485188 -> V=1.0, theta=0.0
% INFO    : Bus 44567	: V=0.9665512, theta=40.554796 -> V=1.0, theta=0.0
% INFO    : Bus 44568	: V=0.9666881, theta=40.535614 -> V=1.0, theta=0.0
% INFO    : Bus 44569	: V=0.9763272, theta=40.605404 -> V=1.0, theta=0.0
% INFO    : Bus 44570	: V=0.9675484, theta=40.5491 -> V=1.0, theta=0.0
% INFO    : Bus 44571	: V=0.9770681, theta=40.597324 -> V=1.0, theta=0.0
% INFO    : Bus 44572	: V=0.9677242, theta=40.58831 -> V=1.0, theta=0.0
% INFO    : Bus 44573	: V=0.9742466, theta=40.617672 -> V=1.0, theta=0.0
% INFO    : Bus 44574	: V=0.9752766, theta=40.594217 -> V=1.0, theta=0.0
% INFO    : Bus 44575	: V=0.9761985, theta=40.58368 -> V=1.0, theta=0.0
% INFO    : Bus 44576	: V=0.9691841, theta=40.490326 -> V=1.0, theta=0.0
% INFO    : Bus 44577	: V=0.9711741, theta=40.495527 -> V=1.0, theta=0.0
% INFO    : Bus 44578	: V=0.9707464, theta=40.696719 -> V=1.0, theta=0.0
% INFO    : Bus 44579	: V=0.9731473, theta=40.529366 -> V=1.0, theta=0.0
% INFO    : Bus 44580	: V=0.972654, theta=40.732004 -> V=1.0, theta=0.0
% INFO    : Bus 44581	: V=0.9734872, theta=40.737004 -> V=1.0, theta=0.0
% INFO    : Bus 44582	: V=0.9758083, theta=40.660054 -> V=1.0, theta=0.0
% INFO    : Bus 44583	: V=0.9759326, theta=40.471703 -> V=1.0, theta=0.0
% INFO    : Bus 44584	: V=0.9852029, theta=41.008246 -> V=1.0, theta=0.0
% INFO    : Bus 44585	: V=0.976024, theta=40.775571 -> V=1.0, theta=0.0
% INFO    : Bus 44586	: V=0.9737492, theta=40.753899 -> V=1.0, theta=0.0
% INFO    : Bus 44587	: V=0.9745115, theta=40.753933 -> V=1.0, theta=0.0
% INFO    : Bus 44588	: V=0.9749656, theta=40.711753 -> V=1.0, theta=0.0
% INFO    : Bus 44589	: V=0.9743487, theta=40.772368 -> V=1.0, theta=0.0
% INFO    : Bus 44590	: V=0.9752811, theta=40.795975 -> V=1.0, theta=0.0
% INFO    : Bus 44591	: V=0.9764474, theta=40.82627 -> V=1.0, theta=0.0
% INFO    : Bus 44592	: V=0.9870113, theta=41.269973 -> V=1.0, theta=0.0
% INFO    : Bus 44593	: V=0.9880338, theta=41.290976 -> V=1.0, theta=0.0
% INFO    : Bus 44594	: V=0.9890623, theta=41.311947 -> V=1.0, theta=0.0
% INFO    : Bus 44595	: V=0.9865266, theta=41.294643 -> V=1.0, theta=0.0
% INFO    : Bus 44596	: V=0.9877253, theta=41.308472 -> V=1.0, theta=0.0
% INFO    : Bus 44597	: V=0.9886325, theta=41.320338 -> V=1.0, theta=0.0
% INFO    : Bus 44598	: V=0.9836711, theta=41.187495 -> V=1.0, theta=0.0
% INFO    : Bus 44599	: V=0.9858731, theta=41.202494 -> V=1.0, theta=0.0
% INFO    : Bus 44600	: V=0.9865355, theta=41.208807 -> V=1.0, theta=0.0
% INFO    : Bus 44601	: V=0.9965633, theta=41.651558 -> V=1.0, theta=0.0
% INFO    : Bus 44602	: V=0.9955337, theta=41.62141 -> V=1.0, theta=0.0
% INFO    : Bus 44603	: V=0.9891469, theta=41.265706 -> V=1.0, theta=0.0
% INFO    : Bus 44604	: V=0.9987316, theta=41.631051 -> V=1.0, theta=0.0
% INFO    : Bus 44605	: V=0.9966078, theta=41.532111 -> V=1.0, theta=0.0
% INFO    : Bus 44606	: V=0.9907276, theta=41.345839 -> V=1.0, theta=0.0
% INFO    : Bus 44607	: V=0.9954335, theta=41.513593 -> V=1.0, theta=0.0
% INFO    : Bus 44608	: V=0.9900854, theta=41.27741 -> V=1.0, theta=0.0
% INFO    : Bus 44609	: V=0.9785455, theta=40.879865 -> V=1.0, theta=0.0
% INFO    : Bus 44610	: V=0.9777027, theta=40.830191 -> V=1.0, theta=0.0
% INFO    : Bus 44611	: V=0.9848459, theta=40.987632 -> V=1.0, theta=0.0
% INFO    : Bus 44612	: V=0.9811076, theta=41.02226 -> V=1.0, theta=0.0
% INFO    : Bus 44613	: V=0.9892545, theta=41.156706 -> V=1.0, theta=0.0
% INFO    : Bus 44614	: V=0.9882235, theta=41.117174 -> V=1.0, theta=0.0
% INFO    : Bus 44615	: V=0.9912507, theta=41.221111 -> V=1.0, theta=0.0
% INFO    : Bus 44616	: V=0.9918567, theta=41.210849 -> V=1.0, theta=0.0
% INFO    : Bus 44617	: V=0.98337, theta=40.9336 -> V=1.0, theta=0.0
% INFO    : Bus 44618	: V=0.9872045, theta=40.9856 -> V=1.0, theta=0.0
% INFO    : Bus 44619	: V=0.9893412, theta=40.96755 -> V=1.0, theta=0.0
% INFO    : Bus 44620	: V=0.992533, theta=40.952678 -> V=1.0, theta=0.0
% INFO    : Bus 44621	: V=0.9738074, theta=40.277051 -> V=1.0, theta=0.0
% INFO    : Bus 44622	: V=0.9842067, theta=40.575501 -> V=1.0, theta=0.0
% INFO    : Bus 44623	: V=1.0008135, theta=41.06505 -> V=1.0, theta=0.0
% INFO    : Bus 44624	: V=0.9831364, theta=40.466221 -> V=1.0, theta=0.0
% INFO    : Bus 44625	: V=0.9838709, theta=40.471698 -> V=1.0, theta=0.0
% INFO    : Bus 44626	: V=0.9878118, theta=40.630069 -> V=1.0, theta=0.0
% INFO    : Bus 44627	: V=0.9828507, theta=40.633523 -> V=1.0, theta=0.0
% INFO    : Bus 44628	: V=0.9950314, theta=40.765354 -> V=1.0, theta=0.0
% INFO    : Bus 44629	: V=0.9787317, theta=40.450025 -> V=1.0, theta=0.0
% INFO    : Bus 44630	: V=0.9822952, theta=40.678627 -> V=1.0, theta=0.0
% INFO    : Bus 44631	: V=0.9833019, theta=40.487995 -> V=1.0, theta=0.0
% INFO    : Bus 44632	: V=0.9845964, theta=40.516022 -> V=1.0, theta=0.0
% INFO    : Bus 44633	: V=0.9697532, theta=40.362553 -> V=1.0, theta=0.0
% INFO    : Bus 44634	: V=0.9777151, theta=40.561177 -> V=1.0, theta=0.0
% INFO    : Bus 44635	: V=0.9785729, theta=40.571717 -> V=1.0, theta=0.0
% INFO    : Bus 44636	: V=0.9689004, theta=40.142611 -> V=1.0, theta=0.0
% INFO    : Bus 44637	: V=0.9679201, theta=40.204498 -> V=1.0, theta=0.0
% INFO    : Bus 44638	: V=0.970093, theta=40.275493 -> V=1.0, theta=0.0
% INFO    : Bus 44639	: V=0.9700796, theta=40.288367 -> V=1.0, theta=0.0
% INFO    : Bus 44640	: V=0.9717453, theta=40.145709 -> V=1.0, theta=0.0
% INFO    : Bus 44641	: V=0.9707536, theta=40.258603 -> V=1.0, theta=0.0
% INFO    : Bus 44642	: V=0.9649944, theta=40.235916 -> V=1.0, theta=0.0
% INFO    : Bus 44643	: V=0.9665665, theta=40.206515 -> V=1.0, theta=0.0
% INFO    : Bus 44644	: V=0.9633731, theta=40.348018 -> V=1.0, theta=0.0
% INFO    : Bus 44645	: V=0.9636921, theta=40.335259 -> V=1.0, theta=0.0
% INFO    : Bus 44646	: V=0.9646076, theta=40.315345 -> V=1.0, theta=0.0
% INFO    : Bus 44647	: V=0.9626296, theta=40.380224 -> V=1.0, theta=0.0
% INFO    : Bus 44648	: V=0.9735826, theta=40.669817 -> V=1.0, theta=0.0
% INFO    : Bus 44649	: V=0.9611699, theta=40.410519 -> V=1.0, theta=0.0
% INFO    : Bus 44650	: V=0.9603238, theta=40.431585 -> V=1.0, theta=0.0
% INFO    : Bus 44651	: V=0.9603664, theta=40.391081 -> V=1.0, theta=0.0
% INFO    : Bus 44652	: V=0.9601132, theta=40.38329 -> V=1.0, theta=0.0
% INFO    : Bus 44653	: V=0.9574581, theta=40.335779 -> V=1.0, theta=0.0
% INFO    : Bus 44654	: V=0.9985997, theta=41.413337 -> V=1.0, theta=0.0
% INFO    : Bus 44655	: V=0.9614785, theta=40.370938 -> V=1.0, theta=0.0
% INFO    : Bus 44656	: V=0.9612155, theta=40.371324 -> V=1.0, theta=0.0
% INFO    : Bus 44657	: V=0.9618197, theta=40.371005 -> V=1.0, theta=0.0
% INFO    : Bus 44658	: V=0.9617322, theta=40.357135 -> V=1.0, theta=0.0
% INFO    : Bus 44659	: V=0.962403, theta=40.355356 -> V=1.0, theta=0.0
% INFO    : Bus 44660	: V=0.9638684, theta=40.406343 -> V=1.0, theta=0.0
% INFO    : Bus 44661	: V=0.9627431, theta=40.433733 -> V=1.0, theta=0.0
% INFO    : Bus 44662	: V=0.9687241, theta=40.664108 -> V=1.0, theta=0.0
% INFO    : Bus 44663	: V=0.9638598, theta=40.558456 -> V=1.0, theta=0.0
% INFO    : Bus 44664	: V=0.9636224, theta=40.535932 -> V=1.0, theta=0.0
% INFO    : Bus 44665	: V=0.9748, theta=40.820939 -> V=1.0, theta=0.0
% INFO    : Bus 44666	: V=0.969552, theta=40.663685 -> V=1.0, theta=0.0
% INFO    : Bus 44667	: V=0.96973, theta=40.66802 -> V=1.0, theta=0.0
% INFO    : Bus 44668	: V=0.9690353, theta=40.679836 -> V=1.0, theta=0.0
% INFO    : Bus 44669	: V=0.9684755, theta=40.710826 -> V=1.0, theta=0.0
% INFO    : Bus 44670	: V=0.9757892, theta=40.779317 -> V=1.0, theta=0.0
% INFO    : Bus 44671	: V=0.9726825, theta=40.648675 -> V=1.0, theta=0.0
% INFO    : Bus 44672	: V=0.9712143, theta=40.656448 -> V=1.0, theta=0.0
% INFO    : Bus 44673	: V=0.9677987, theta=40.756065 -> V=1.0, theta=0.0
% INFO    : Bus 44674	: V=0.9595201, theta=40.554896 -> V=1.0, theta=0.0
% INFO    : Bus 44675	: V=0.9681297, theta=40.845991 -> V=1.0, theta=0.0
% INFO    : Bus 44676	: V=0.9684802, theta=40.885519 -> V=1.0, theta=0.0
% INFO    : Bus 44677	: V=0.960883, theta=40.58377 -> V=1.0, theta=0.0
% INFO    : Bus 44678	: V=0.9691337, theta=40.939385 -> V=1.0, theta=0.0
% INFO    : Bus 44679	: V=0.9701465, theta=41.003373 -> V=1.0, theta=0.0
% INFO    : Bus 44680	: V=0.9609295, theta=40.553092 -> V=1.0, theta=0.0
% INFO    : Bus 44681	: V=0.9604819, theta=40.56925 -> V=1.0, theta=0.0
% INFO    : Bus 44682	: V=0.9599046, theta=40.566347 -> V=1.0, theta=0.0
% INFO    : Bus 44683	: V=0.9695028, theta=40.933114 -> V=1.0, theta=0.0
% INFO    : Bus 44684	: V=0.9645666, theta=40.753361 -> V=1.0, theta=0.0
% INFO    : Bus 44685	: V=0.9628936, theta=40.68054 -> V=1.0, theta=0.0
% INFO    : Bus 44686	: V=0.9766711, theta=41.009063 -> V=1.0, theta=0.0
% INFO    : Bus 44687	: V=0.9624986, theta=40.599408 -> V=1.0, theta=0.0
% INFO    : Bus 44688	: V=0.9642582, theta=40.580758 -> V=1.0, theta=0.0
% INFO    : Bus 44689	: V=0.9618661, theta=40.59078 -> V=1.0, theta=0.0
% INFO    : Bus 44690	: V=0.9841297, theta=40.792761 -> V=1.0, theta=0.0
% INFO    : Bus 44691	: V=0.9655876, theta=40.495302 -> V=1.0, theta=0.0
% INFO    : Bus 44692	: V=0.9870093, theta=40.467438 -> V=1.0, theta=0.0
% INFO    : Bus 44693	: V=0.9810856, theta=40.025344 -> V=1.0, theta=0.0
% INFO    : Bus 44694	: V=0.9703269, theta=40.034799 -> V=1.0, theta=0.0
% INFO    : Bus 44695	: V=0.9793689, theta=40.67694 -> V=1.0, theta=0.0
% INFO    : Bus 44696	: V=0.9711789, theta=39.848985 -> V=1.0, theta=0.0
% INFO    : Bus 44697	: V=0.9702038, theta=39.872303 -> V=1.0, theta=0.0
% INFO    : Bus 44698	: V=0.9845622, theta=39.855262 -> V=1.0, theta=0.0
% INFO    : Bus 44699	: V=0.9642236, theta=40.276351 -> V=1.0, theta=0.0
% INFO    : Bus 44700	: V=0.9670515, theta=40.154304 -> V=1.0, theta=0.0
% INFO    : Bus 44701	: V=0.9726747, theta=39.980084 -> V=1.0, theta=0.0
% INFO    : Bus 44702	: V=0.9719337, theta=40.002383 -> V=1.0, theta=0.0
% INFO    : Bus 44703	: V=0.9721269, theta=40.056623 -> V=1.0, theta=0.0
% INFO    : Bus 44704	: V=0.9861324, theta=39.832099 -> V=1.0, theta=0.0
% INFO    : Bus 44705	: V=0.9869, theta=39.824636 -> V=1.0, theta=0.0
% INFO    : Bus 44706	: V=0.9877581, theta=39.858333 -> V=1.0, theta=0.0
% INFO    : Bus 44707	: V=0.9690826, theta=40.929265 -> V=1.0, theta=0.0
% INFO    : Bus 44708	: V=0.9697503, theta=40.936452 -> V=1.0, theta=0.0
% INFO    : Bus 44709	: V=0.9684344, theta=40.876361 -> V=1.0, theta=0.0
% INFO    : Bus 44710	: V=0.9643871, theta=40.753316 -> V=1.0, theta=0.0
% INFO    : Bus 44711	: V=0.9649538, theta=40.773301 -> V=1.0, theta=0.0
% INFO    : Bus 44712	: V=0.9657465, theta=40.812978 -> V=1.0, theta=0.0
% INFO    : Bus 44713	: V=0.9704801, theta=40.947016 -> V=1.0, theta=0.0
% INFO    : Bus 44714	: V=0.9646276, theta=40.778222 -> V=1.0, theta=0.0
% INFO    : Bus 44715	: V=0.9659761, theta=40.820532 -> V=1.0, theta=0.0
% INFO    : Bus 44716	: V=0.9691902, theta=40.886486 -> V=1.0, theta=0.0
% INFO    : Bus 44717	: V=0.970307, theta=40.951142 -> V=1.0, theta=0.0
% INFO    : Bus 44718	: V=0.9648325, theta=40.788164 -> V=1.0, theta=0.0
% INFO    : Bus 44719	: V=0.9653874, theta=40.799146 -> V=1.0, theta=0.0
% INFO    : Bus 44720	: V=0.9721568, theta=40.964802 -> V=1.0, theta=0.0
% INFO    : Bus 44721	: V=0.9700958, theta=40.918112 -> V=1.0, theta=0.0
% INFO    : Bus 44722	: V=0.9795602, theta=41.239978 -> V=1.0, theta=0.0
% INFO    : Bus 44723	: V=0.9654817, theta=40.794555 -> V=1.0, theta=0.0
% INFO    : Bus 44724	: V=0.9657535, theta=40.796882 -> V=1.0, theta=0.0
% INFO    : Bus 44725	: V=0.9694072, theta=40.866791 -> V=1.0, theta=0.0
% INFO    : Bus 44726	: V=0.9706829, theta=40.925051 -> V=1.0, theta=0.0
% INFO    : Bus 44727	: V=0.9658833, theta=40.794545 -> V=1.0, theta=0.0
% INFO    : Bus 44728	: V=0.9704661, theta=40.906046 -> V=1.0, theta=0.0
% INFO    : Bus 44729	: V=0.9791873, theta=41.253657 -> V=1.0, theta=0.0
% INFO    : Bus 44730	: V=0.9724115, theta=40.987103 -> V=1.0, theta=0.0
% INFO    : Bus 44731	: V=1.0023509, theta=42.107766 -> V=1.0, theta=0.0
% INFO    : Bus 44732	: V=0.9726594, theta=40.892547 -> V=1.0, theta=0.0
% INFO    : Bus 44733	: V=0.9783202, theta=41.253634 -> V=1.0, theta=0.0
% INFO    : Bus 44734	: V=0.9797631, theta=41.28707 -> V=1.0, theta=0.0
% INFO    : Bus 44735	: V=0.9794647, theta=41.281399 -> V=1.0, theta=0.0
% INFO    : Bus 44736	: V=0.972515, theta=40.850829 -> V=1.0, theta=0.0
% INFO    : Bus 44737	: V=0.9683431, theta=40.824059 -> V=1.0, theta=0.0
% INFO    : Bus 44738	: V=0.9784997, theta=41.256543 -> V=1.0, theta=0.0
% INFO    : Bus 44739	: V=0.9715943, theta=40.937049 -> V=1.0, theta=0.0
% INFO    : Bus 44740	: V=0.9676898, theta=40.800453 -> V=1.0, theta=0.0
% INFO    : Bus 44741	: V=0.969176, theta=40.825644 -> V=1.0, theta=0.0
% INFO    : Bus 44742	: V=0.9702305, theta=40.866273 -> V=1.0, theta=0.0
% INFO    : Bus 44743	: V=0.9728337, theta=40.960424 -> V=1.0, theta=0.0
% INFO    : Bus 44744	: V=0.9807255, theta=41.315311 -> V=1.0, theta=0.0
% INFO    : Bus 44745	: V=0.975296, theta=41.074304 -> V=1.0, theta=0.0
% INFO    : Bus 44746	: V=0.9666601, theta=40.616965 -> V=1.0, theta=0.0
% INFO    : Bus 44747	: V=0.9681629, theta=40.7623 -> V=1.0, theta=0.0
% INFO    : Bus 44748	: V=0.9687195, theta=40.793077 -> V=1.0, theta=0.0
% INFO    : Bus 44749	: V=0.9707204, theta=40.877569 -> V=1.0, theta=0.0
% INFO    : Bus 44750	: V=0.9703921, theta=40.804879 -> V=1.0, theta=0.0
% INFO    : Bus 44751	: V=0.9760291, theta=41.097063 -> V=1.0, theta=0.0
% INFO    : Bus 44752	: V=0.982087, theta=41.369445 -> V=1.0, theta=0.0
% INFO    : Bus 44753	: V=0.9780447, theta=41.1658 -> V=1.0, theta=0.0
% INFO    : Bus 44754	: V=0.9673765, theta=40.692362 -> V=1.0, theta=0.0
% INFO    : Bus 44755	: V=0.9756117, theta=41.024463 -> V=1.0, theta=0.0
% INFO    : Bus 44756	: V=0.9816997, theta=41.31892 -> V=1.0, theta=0.0
% INFO    : Bus 44757	: V=0.9821401, theta=41.360677 -> V=1.0, theta=0.0
% INFO    : Bus 44758	: V=0.9776617, theta=41.153819 -> V=1.0, theta=0.0
% INFO    : Bus 44759	: V=0.9781111, theta=41.16941 -> V=1.0, theta=0.0
% INFO    : Bus 44760	: V=0.9674411, theta=40.633674 -> V=1.0, theta=0.0
% INFO    : Bus 44761	: V=0.9726161, theta=40.851701 -> V=1.0, theta=0.0
% INFO    : Bus 44762	: V=0.9729339, theta=40.877592 -> V=1.0, theta=0.0
% INFO    : Bus 44763	: V=0.9741645, theta=40.918377 -> V=1.0, theta=0.0
% INFO    : Bus 44764	: V=0.9818428, theta=41.287878 -> V=1.0, theta=0.0
% INFO    : Bus 44765	: V=0.968102, theta=40.629943 -> V=1.0, theta=0.0
% INFO    : Bus 44766	: V=0.9737305, theta=40.867443 -> V=1.0, theta=0.0
% INFO    : Bus 44767	: V=0.9755384, theta=40.935745 -> V=1.0, theta=0.0
% INFO    : Bus 44768	: V=0.9822331, theta=41.276448 -> V=1.0, theta=0.0
% INFO    : Bus 44769	: V=0.9770219, theta=41.094102 -> V=1.0, theta=0.0
% INFO    : Bus 44770	: V=0.9775381, theta=41.169833 -> V=1.0, theta=0.0
% INFO    : Bus 44771	: V=0.9779652, theta=41.172137 -> V=1.0, theta=0.0
% INFO    : Bus 44772	: V=0.9749691, theta=40.889008 -> V=1.0, theta=0.0
% INFO    : Bus 44773	: V=0.9823684, theta=41.267734 -> V=1.0, theta=0.0
% INFO    : Bus 44774	: V=0.977501, theta=41.096247 -> V=1.0, theta=0.0
% INFO    : Bus 44775	: V=0.9714132, theta=40.74156 -> V=1.0, theta=0.0
% INFO    : Bus 44776	: V=0.9726173, theta=40.770276 -> V=1.0, theta=0.0
% INFO    : Bus 44777	: V=0.9731512, theta=40.816432 -> V=1.0, theta=0.0
% INFO    : Bus 44778	: V=0.9845873, theta=41.219093 -> V=1.0, theta=0.0
% INFO    : Bus 44779	: V=0.9834555, theta=41.273003 -> V=1.0, theta=0.0
% INFO    : Bus 44780	: V=0.9727194, theta=40.676278 -> V=1.0, theta=0.0
% INFO    : Bus 44781	: V=0.9661359, theta=40.445344 -> V=1.0, theta=0.0
% INFO    : Bus 44782	: V=1.0012412, theta=41.430099 -> V=1.0, theta=0.0
% INFO    : Bus 44783	: V=0.984306, theta=41.465443 -> V=1.0, theta=0.0
% INFO    : Bus 44784	: V=0.965112, theta=40.790039 -> V=1.0, theta=0.0
% INFO    : Bus 44785	: V=0.9725904, theta=40.929362 -> V=1.0, theta=0.0
% INFO    : Bus 44786	: V=0.9806369, theta=41.301494 -> V=1.0, theta=0.0
% INFO    : Bus 44787	: V=0.9715056, theta=40.889332 -> V=1.0, theta=0.0
% INFO    : Bus 44788	: V=0.9713885, theta=40.927971 -> V=1.0, theta=0.0
% INFO    : Bus 44789	: V=0.9736366, theta=40.981123 -> V=1.0, theta=0.0
% INFO    : Bus 44790	: V=0.9766981, theta=41.126516 -> V=1.0, theta=0.0
% INFO    : Bus 44791	: V=0.9973993, theta=41.510634 -> V=1.0, theta=0.0
% INFO    : Bus 44792	: V=1.0037179, theta=41.408639 -> V=1.0, theta=0.0
% INFO    : Bus 44793	: V=0.9934576, theta=41.04384 -> V=1.0, theta=0.0
% INFO    : Bus 44794	: V=1.0116565, theta=41.20479 -> V=1.0, theta=0.0
% INFO    : Bus 44795	: V=1.0199259, theta=41.160003 -> V=1.0, theta=0.0
% INFO    : Bus 44796	: V=0.9873262, theta=34.350894 -> V=1.0, theta=0.0
% INFO    : Bus 44797	: V=0.9784942, theta=32.930774 -> V=1.0, theta=0.0
% INFO    : Bus 44798	: V=0.9897841, theta=35.245497 -> V=1.0, theta=0.0
% INFO    : Bus 44799	: V=0.987248, theta=35.31858 -> V=1.0, theta=0.0
% INFO    : Bus 44800	: V=0.9551361, theta=29.534785 -> V=1.0, theta=0.0
% INFO    : Bus 44801	: V=0.9618936, theta=30.246631 -> V=1.0, theta=0.0
% INFO    : Bus 44802	: V=0.9840263, theta=34.502814 -> V=1.0, theta=0.0
% INFO    : Bus 44803	: V=0.9702207, theta=40.628356 -> V=1.0, theta=0.0
% INFO    : Bus 44804	: V=0.9845358, theta=41.899669 -> V=1.0, theta=0.0
% INFO    : Bus 44805	: V=0.9863827, theta=41.356893 -> V=1.0, theta=0.0
% INFO    : Bus 44806	: V=0.9841159, theta=41.815824 -> V=1.0, theta=0.0
% INFO    : Bus 44807	: V=0.9650119, theta=41.820649 -> V=1.0, theta=0.0
% INFO    : Bus 44808	: V=0.9725941, theta=41.500406 -> V=1.0, theta=0.0
% INFO    : Bus 44809	: V=0.9727708, theta=41.534108 -> V=1.0, theta=0.0
% INFO    : Bus 44810	: V=0.9765278, theta=40.714583 -> V=1.0, theta=0.0
% INFO    : Bus 44811	: V=0.9965939, theta=41.690983 -> V=1.0, theta=0.0
% INFO    : Bus 44812	: V=1.0141333, theta=41.650884 -> V=1.0, theta=0.0
% INFO    : Bus 44813	: V=1.0000799, theta=41.662865 -> V=1.0, theta=0.0
% INFO    : Bus 44814	: V=1.0147513, theta=43.430217 -> V=1.0, theta=0.0
% INFO    : Bus 44815	: V=1.0077513, theta=42.824595 -> V=1.0, theta=0.0
% INFO    : Bus 44816	: V=1.0132982, theta=41.851185 -> V=1.0, theta=0.0
% INFO    : Bus 44817	: V=1.0164619, theta=43.583804 -> V=1.0, theta=0.0
% INFO    : Bus 44818	: V=1.0210878, theta=44.994428 -> V=1.0, theta=0.0
% INFO    : Bus 44819	: V=1.0148544, theta=42.205865 -> V=1.0, theta=0.0
% INFO    : Bus 44820	: V=1.0142912, theta=42.870993 -> V=1.0, theta=0.0
% INFO    : Bus 44821	: V=0.9948994, theta=39.400049 -> V=1.0, theta=0.0
% INFO    : Bus 44822	: V=1.0189396, theta=30.921368 -> V=1.0, theta=0.0
% INFO    : Bus 44823	: V=1.0147919, theta=27.722899 -> V=1.0, theta=0.0
% INFO    : Bus 44824	: V=1.0168095, theta=29.63481 -> V=1.0, theta=0.0
% INFO    : Bus 44825	: V=1.018197, theta=31.688582 -> V=1.0, theta=0.0
% INFO    : Bus 44826	: V=0.9602487, theta=41.266053 -> V=1.0, theta=0.0
% INFO    : Bus 44827	: V=0.9704938, theta=40.681954 -> V=1.0, theta=0.0
% INFO    : Bus 44828	: V=0.9655322, theta=41.125688 -> V=1.0, theta=0.0
% INFO    : Bus 44829	: V=0.9691852, theta=41.510121 -> V=1.0, theta=0.0
% INFO    : Bus 44830	: V=0.9782195, theta=28.800089 -> V=1.0, theta=0.0
% INFO    : Bus 44831	: V=0.980365, theta=31.139982 -> V=1.0, theta=0.0
% INFO    : Bus 44832	: V=0.9711935, theta=27.123335 -> V=1.0, theta=0.0
% INFO    : Bus 44833	: V=0.9796142, theta=30.748572 -> V=1.0, theta=0.0
% INFO    : Bus 44834	: V=0.9789635, theta=30.35199 -> V=1.0, theta=0.0
% INFO    : Bus 44835	: V=0.9784185, theta=28.884972 -> V=1.0, theta=0.0
% INFO    : Bus 44836	: V=0.9799582, theta=28.811449 -> V=1.0, theta=0.0
% INFO    : Bus 44837	: V=0.9801584, theta=28.893814 -> V=1.0, theta=0.0
% INFO    : Bus 44838	: V=0.9788636, theta=28.884268 -> V=1.0, theta=0.0
% INFO    : Bus 44839	: V=0.9798597, theta=29.16423 -> V=1.0, theta=0.0
% INFO    : Bus 44840	: V=0.9828733, theta=31.2405 -> V=1.0, theta=0.0
% INFO    : Bus 44841	: V=0.9828536, theta=28.248598 -> V=1.0, theta=0.0
% INFO    : Bus 44842	: V=0.9653214, theta=12.597251 -> V=1.0, theta=0.0
% INFO    : Bus 44843	: V=0.9545538, theta=16.537727 -> V=1.0, theta=0.0
% INFO    : Bus 44844	: V=1.0150822, theta=41.152375 -> V=1.0, theta=0.0
% INFO    : Bus 44845	: V=1.0126568, theta=41.249508 -> V=1.0, theta=0.0
% INFO    : Bus 44846	: V=1.0123322, theta=41.426685 -> V=1.0, theta=0.0
% INFO    : Bus 44847	: V=1.0077017, theta=38.669013 -> V=1.0, theta=0.0
% INFO    : Bus 44848	: V=0.9840489, theta=19.107341 -> V=1.0, theta=0.0
% INFO    : Bus 44849	: V=0.9845081, theta=18.1382 -> V=1.0, theta=0.0
% INFO    : Bus 44850	: V=0.9926047, theta=22.718713 -> V=1.0, theta=0.0
% INFO    : Bus 44851	: V=1.0180829, theta=48.453589 -> V=1.0, theta=0.0
% INFO    : Bus 44852	: V=1.0187815, theta=47.999057 -> V=1.0, theta=0.0
% INFO    : Bus 44853	: V=1.0239891, theta=46.403445 -> V=1.0, theta=0.0
% INFO    : Bus 44854	: V=0.9789891, theta=23.321811 -> V=1.0, theta=0.0
% INFO    : Bus 44855	: V=0.9889582, theta=39.11786 -> V=1.0, theta=0.0
% INFO    : Bus 44856	: V=1.0036578, theta=38.090101 -> V=1.0, theta=0.0
% INFO    : Bus 44857	: V=1.0039596, theta=39.766332 -> V=1.0, theta=0.0
% INFO    : Bus 44858	: V=1.0067206, theta=39.740713 -> V=1.0, theta=0.0
% INFO    : Bus 44859	: V=1.0065451, theta=38.941373 -> V=1.0, theta=0.0
% INFO    : Bus 44860	: V=1.0006416, theta=37.288198 -> V=1.0, theta=0.0
% INFO    : Bus 44861	: V=1.0075739, theta=18.788514 -> V=1.0, theta=0.0
% INFO    : Bus 44862	: V=1.0147858, theta=23.63599 -> V=1.0, theta=0.0
% INFO    : Bus 44863	: V=0.9830557, theta=23.692568 -> V=1.0, theta=0.0
% INFO    : Bus 44864	: V=0.9892744, theta=25.313092 -> V=1.0, theta=0.0
% INFO    : Bus 44865	: V=0.9881594, theta=25.310109 -> V=1.0, theta=0.0
% INFO    : Bus 44866	: V=1.0010898, theta=25.556256 -> V=1.0, theta=0.0
% INFO    : Bus 44867	: V=0.9999181, theta=25.687062 -> V=1.0, theta=0.0
% INFO    : Bus 44868	: V=1.0086289, theta=24.964627 -> V=1.0, theta=0.0
% INFO    : Bus 44869	: V=0.999512, theta=25.810277 -> V=1.0, theta=0.0
% INFO    : Bus 44870	: V=1.0094202, theta=38.181323 -> V=1.0, theta=0.0
% INFO    : Bus 44871	: V=0.9970699, theta=35.552215 -> V=1.0, theta=0.0
% INFO    : Bus 44872	: V=1.0180218, theta=37.197613 -> V=1.0, theta=0.0
% INFO    : Bus 44873	: V=1.0184563, theta=37.18198 -> V=1.0, theta=0.0
% INFO    : Bus 44874	: V=1.0124087, theta=36.191107 -> V=1.0, theta=0.0
% INFO    : Bus 44875	: V=1.0098901, theta=38.251024 -> V=1.0, theta=0.0
% INFO    : Bus 44876	: V=1.0168022, theta=38.936574 -> V=1.0, theta=0.0
% INFO    : Bus 44877	: V=0.9585502, theta=15.034949 -> V=1.0, theta=0.0
% INFO    : Bus 44878	: V=0.9688471, theta=21.565086 -> V=1.0, theta=0.0
% INFO    : Bus 44879	: V=0.9739885, theta=24.533638 -> V=1.0, theta=0.0
% INFO    : Bus 44880	: V=0.9733204, theta=24.47166 -> V=1.0, theta=0.0
% INFO    : Bus 44881	: V=0.9655508, theta=8.073312 -> V=1.0, theta=0.0
% INFO    : Bus 44882	: V=0.9700844, theta=10.00471 -> V=1.0, theta=0.0
% INFO    : Bus 44883	: V=1.0115006, theta=32.331826 -> V=1.0, theta=0.0
% INFO    : Bus 44884	: V=0.997247, theta=31.492863 -> V=1.0, theta=0.0
% INFO    : Bus 44885	: V=1.0063896, theta=30.357979 -> V=1.0, theta=0.0
% INFO    : Bus 44886	: V=1.0045806, theta=29.487374 -> V=1.0, theta=0.0
% INFO    : Bus 44887	: V=1.0069776, theta=31.369398 -> V=1.0, theta=0.0
% INFO    : Bus 44888	: V=1.0091217, theta=32.064335 -> V=1.0, theta=0.0
% INFO    : Bus 44889	: V=0.9793894, theta=37.108674 -> V=1.0, theta=0.0
% INFO    : Bus 44890	: V=0.9739042, theta=35.814736 -> V=1.0, theta=0.0
% INFO    : Bus 44891	: V=0.9748556, theta=35.175811 -> V=1.0, theta=0.0
% INFO    : Bus 44892	: V=0.9855493, theta=34.326589 -> V=1.0, theta=0.0
% INFO    : Bus 44893	: V=0.9746391, theta=34.886555 -> V=1.0, theta=0.0
% INFO    : Bus 44894	: V=0.9834854, theta=33.015951 -> V=1.0, theta=0.0
% INFO    : Bus 44895	: V=0.9853739, theta=40.732851 -> V=1.0, theta=0.0
% INFO    : Bus 44896	: V=0.9758065, theta=40.251442 -> V=1.0, theta=0.0
% INFO    : Bus 44897	: V=0.9896893, theta=40.810696 -> V=1.0, theta=0.0
% INFO    : Bus 44898	: V=0.9776176, theta=40.6204 -> V=1.0, theta=0.0
% INFO    : Bus 44899	: V=0.9743741, theta=40.04776 -> V=1.0, theta=0.0
% INFO    : Bus 44900	: V=0.970481, theta=39.302601 -> V=1.0, theta=0.0
% INFO    : Bus 44901	: V=0.9718379, theta=40.159385 -> V=1.0, theta=0.0
% INFO    : Bus 44902	: V=0.9819486, theta=34.504864 -> V=1.0, theta=0.0
% INFO    : Bus 44903	: V=0.9844379, theta=34.584801 -> V=1.0, theta=0.0
% INFO    : Bus 44904	: V=1.0145515, theta=41.704049 -> V=1.0, theta=0.0
% INFO    : Bus 44905	: V=0.9775427, theta=38.352033 -> V=1.0, theta=0.0
% INFO    : Bus 44906	: V=0.9732895, theta=38.475934 -> V=1.0, theta=0.0
% INFO    : Bus 44907	: V=0.997922, theta=37.495899 -> V=1.0, theta=0.0
% INFO    : Bus 44908	: V=0.9974093, theta=37.438917 -> V=1.0, theta=0.0
% INFO    : Bus 44909	: V=0.9874574, theta=36.50394 -> V=1.0, theta=0.0
% INFO    : Bus 44910	: V=1.0188527, theta=39.582958 -> V=1.0, theta=0.0
% INFO    : Bus 44911	: V=1.0170883, theta=39.377442 -> V=1.0, theta=0.0
% INFO    : Bus 44912	: V=1.0174368, theta=39.418703 -> V=1.0, theta=0.0
% INFO    : Bus 44913	: V=1.0170497, theta=39.382157 -> V=1.0, theta=0.0
% INFO    : Bus 44914	: V=1.0169822, theta=39.442772 -> V=1.0, theta=0.0
% INFO    : Bus 44915	: V=1.0166155, theta=39.366739 -> V=1.0, theta=0.0
% INFO    : Bus 44916	: V=1.0155094, theta=39.214294 -> V=1.0, theta=0.0
% INFO    : Bus 44917	: V=1.019469, theta=39.731401 -> V=1.0, theta=0.0
% INFO    : Bus 44918	: V=1.0175297, theta=40.758422 -> V=1.0, theta=0.0
% INFO    : Bus 44919	: V=1.0205478, theta=39.740026 -> V=1.0, theta=0.0
% INFO    : Bus 44920	: V=1.0147642, theta=40.290227 -> V=1.0, theta=0.0
% INFO    : Bus 44921	: V=1.0086036, theta=25.060715 -> V=1.0, theta=0.0
% INFO    : Bus 44922	: V=1.0207727, theta=27.961018 -> V=1.0, theta=0.0
% INFO    : Bus 44923	: V=1.0146493, theta=25.348464 -> V=1.0, theta=0.0
% INFO    : Bus 44924	: V=1.0057854, theta=33.86911 -> V=1.0, theta=0.0
% INFO    : Bus 44925	: V=0.9980174, theta=36.582959 -> V=1.0, theta=0.0
% INFO    : Bus 44926	: V=1.0069086, theta=37.724497 -> V=1.0, theta=0.0
% INFO    : Bus 44927	: V=1.0041414, theta=37.106036 -> V=1.0, theta=0.0
% INFO    : Bus 44928	: V=1.0133267, theta=37.361665 -> V=1.0, theta=0.0
% INFO    : Bus 44929	: V=1.0158859, theta=37.442194 -> V=1.0, theta=0.0
% INFO    : Bus 44930	: V=1.0128306, theta=37.475977 -> V=1.0, theta=0.0
% INFO    : Bus 44931	: V=1.0170059, theta=25.124101 -> V=1.0, theta=0.0
% INFO    : Bus 44932	: V=1.0147865, theta=24.248385 -> V=1.0, theta=0.0
% INFO    : Bus 44933	: V=1.0132293, theta=24.176363 -> V=1.0, theta=0.0
% INFO    : Bus 44934	: V=1.0173298, theta=25.572366 -> V=1.0, theta=0.0
% INFO    : Bus 44935	: V=1.0159839, theta=25.250135 -> V=1.0, theta=0.0
% INFO    : Bus 44936	: V=1.0154683, theta=25.036149 -> V=1.0, theta=0.0
% INFO    : Bus 44937	: V=0.9592815, theta=12.118141 -> V=1.0, theta=0.0
% INFO    : Bus 44938	: V=0.9675238, theta=6.992675 -> V=1.0, theta=0.0
% INFO    : Bus 44939	: V=0.9585819, theta=10.779084 -> V=1.0, theta=0.0
% INFO    : Bus 44940	: V=1.0193606, theta=41.98902 -> V=1.0, theta=0.0
% INFO    : Bus 44941	: V=1.0183322, theta=41.958664 -> V=1.0, theta=0.0
% INFO    : Bus 44942	: V=1.0184437, theta=41.949087 -> V=1.0, theta=0.0
% INFO    : Bus 44943	: V=1.0128211, theta=41.799665 -> V=1.0, theta=0.0
% INFO    : Bus 44944	: V=1.0195912, theta=41.965677 -> V=1.0, theta=0.0
% INFO    : Bus 44945	: V=1.0191529, theta=42.026462 -> V=1.0, theta=0.0
% INFO    : Bus 44946	: V=1.0167699, theta=41.927133 -> V=1.0, theta=0.0
% INFO    : Bus 44947	: V=1.0116611, theta=41.737088 -> V=1.0, theta=0.0
% INFO    : Bus 44948	: V=1.0154965, theta=41.786678 -> V=1.0, theta=0.0
% INFO    : Bus 44949	: V=1.0176384, theta=41.870918 -> V=1.0, theta=0.0
% INFO    : Bus 44950	: V=1.011262, theta=41.78115 -> V=1.0, theta=0.0
% INFO    : Bus 44951	: V=1.0123049, theta=41.783966 -> V=1.0, theta=0.0
% INFO    : Bus 44952	: V=1.0172113, theta=41.774645 -> V=1.0, theta=0.0
% INFO    : Bus 44953	: V=1.0177038, theta=41.75451 -> V=1.0, theta=0.0
% INFO    : Bus 44954	: V=1.0114044, theta=41.755501 -> V=1.0, theta=0.0
% INFO    : Bus 44955	: V=1.0108604, theta=41.768365 -> V=1.0, theta=0.0
% INFO    : Bus 44956	: V=1.0197265, theta=42.472909 -> V=1.0, theta=0.0
% INFO    : Bus 44957	: V=1.0189387, theta=42.1539 -> V=1.0, theta=0.0
% INFO    : Bus 44958	: V=1.0185943, theta=42.069926 -> V=1.0, theta=0.0
% INFO    : Bus 44959	: V=1.0187818, theta=42.048357 -> V=1.0, theta=0.0
% INFO    : Bus 44960	: V=1.0151391, theta=41.845485 -> V=1.0, theta=0.0
% INFO    : Bus 44961	: V=1.014653, theta=41.834354 -> V=1.0, theta=0.0
% INFO    : Bus 44962	: V=1.0144283, theta=41.842249 -> V=1.0, theta=0.0
% INFO    : Bus 44963	: V=1.0169329, theta=42.098251 -> V=1.0, theta=0.0
% INFO    : Bus 44964	: V=1.0183152, theta=42.124868 -> V=1.0, theta=0.0
% INFO    : Bus 44965	: V=1.0183909, theta=42.100928 -> V=1.0, theta=0.0
% INFO    : Bus 44966	: V=1.0132581, theta=42.021288 -> V=1.0, theta=0.0
% INFO    : Bus 44967	: V=1.0092114, theta=41.192269 -> V=1.0, theta=0.0
% INFO    : Bus 44968	: V=1.0188422, theta=42.190231 -> V=1.0, theta=0.0
% INFO    : Bus 44969	: V=1.0106969, theta=41.370619 -> V=1.0, theta=0.0
% INFO    : Bus 44970	: V=1.0170525, theta=41.222797 -> V=1.0, theta=0.0
% INFO    : Bus 44971	: V=1.0175209, theta=41.516308 -> V=1.0, theta=0.0
% INFO    : Bus 44972	: V=1.016337, theta=42.063964 -> V=1.0, theta=0.0
% INFO    : Bus 44973	: V=0.9601285, theta=25.142581 -> V=1.0, theta=0.0
% INFO    : Bus 44974	: V=0.9865781, theta=18.328332 -> V=1.0, theta=0.0
% INFO    : Bus 44975	: V=0.9977662, theta=18.538197 -> V=1.0, theta=0.0
% INFO    : Bus 44976	: V=0.9780768, theta=18.915034 -> V=1.0, theta=0.0
% INFO    : Bus 44977	: V=0.9655766, theta=30.110457 -> V=1.0, theta=0.0
% INFO    : Bus 44978	: V=0.9644023, theta=27.749684 -> V=1.0, theta=0.0
% INFO    : Bus 44979	: V=1.0030946, theta=18.941407 -> V=1.0, theta=0.0
% INFO    : Bus 44980	: V=1.0090519, theta=19.307289 -> V=1.0, theta=0.0
% INFO    : Bus 44981	: V=1.0042346, theta=15.915738 -> V=1.0, theta=0.0
% INFO    : Bus 44982	: V=1.0168817, theta=20.204657 -> V=1.0, theta=0.0
% INFO    : Bus 44983	: V=1.0185836, theta=19.968601 -> V=1.0, theta=0.0
% INFO    : Bus 44984	: V=0.9850447, theta=19.299973 -> V=1.0, theta=0.0
% INFO    : Bus 44985	: V=0.9670574, theta=27.417282 -> V=1.0, theta=0.0
% INFO    : Bus 44986	: V=0.9596488, theta=28.017617 -> V=1.0, theta=0.0
% INFO    : Bus 44987	: V=0.9660625, theta=27.760384 -> V=1.0, theta=0.0
% INFO    : Bus 44988	: V=0.9899139, theta=19.632164 -> V=1.0, theta=0.0
% INFO    : Bus 44989	: V=1.0133407, theta=20.400425 -> V=1.0, theta=0.0
% INFO    : Bus 44990	: V=0.9770915, theta=24.674989 -> V=1.0, theta=0.0
% INFO    : Bus 44991	: V=0.9781702, theta=24.802141 -> V=1.0, theta=0.0
% INFO    : Bus 44992	: V=0.9717002, theta=23.500029 -> V=1.0, theta=0.0
% INFO    : Bus 44993	: V=0.9823217, theta=30.067558 -> V=1.0, theta=0.0
% INFO    : Bus 44994	: V=0.9784472, theta=24.786556 -> V=1.0, theta=0.0
% INFO    : Bus 44995	: V=0.9957174, theta=43.302197 -> V=1.0, theta=0.0
% INFO    : Bus 44996	: V=0.9836621, theta=41.809553 -> V=1.0, theta=0.0
% INFO    : Bus 44997	: V=0.9823859, theta=42.212846 -> V=1.0, theta=0.0
% INFO    : Bus 44998	: V=0.9967235, theta=43.6502 -> V=1.0, theta=0.0
% INFO    : Bus 44999	: V=0.9663243, theta=41.88473 -> V=1.0, theta=0.0
% INFO    : Bus 45000	: V=0.9792271, theta=42.593762 -> V=1.0, theta=0.0
% INFO    : Bus 45001	: V=0.9843454, theta=42.515285 -> V=1.0, theta=0.0
% INFO    : Bus 45002	: V=0.9856878, theta=42.196676 -> V=1.0, theta=0.0
% INFO    : Bus 45003	: V=1.016237, theta=24.357794 -> V=1.0, theta=0.0
% INFO    : Bus 45004	: V=1.0130051, theta=24.617779 -> V=1.0, theta=0.0
% INFO    : Bus 45005	: V=1.0117058, theta=24.2933 -> V=1.0, theta=0.0
% INFO    : Bus 45006	: V=1.0077314, theta=23.235385 -> V=1.0, theta=0.0
% INFO    : Bus 45007	: V=1.0200585, theta=27.513863 -> V=1.0, theta=0.0
% INFO    : Bus 45008	: V=0.9722731, theta=5.597939 -> V=1.0, theta=0.0
% INFO    : Bus 45009	: V=0.9740619, theta=5.571197 -> V=1.0, theta=0.0
% INFO    : Bus 45010	: V=0.9736032, theta=5.581215 -> V=1.0, theta=0.0
% INFO    : Bus 45011	: V=0.9720678, theta=7.368892 -> V=1.0, theta=0.0
% INFO    : Bus 45012	: V=0.9561563, theta=14.924991 -> V=1.0, theta=0.0
% INFO    : Bus 45013	: V=0.9540322, theta=17.439872 -> V=1.0, theta=0.0
% INFO    : Bus 45014	: V=0.957936, theta=15.306313 -> V=1.0, theta=0.0
% INFO    : Bus 45015	: V=0.9609278, theta=15.309712 -> V=1.0, theta=0.0
% INFO    : Bus 45016	: V=0.9632533, theta=15.365019 -> V=1.0, theta=0.0
% INFO    : Bus 45017	: V=0.9789146, theta=26.533098 -> V=1.0, theta=0.0
% INFO    : Bus 45018	: V=0.9712129, theta=27.496232 -> V=1.0, theta=0.0
% INFO    : Bus 45019	: V=0.9885504, theta=24.881559 -> V=1.0, theta=0.0
% INFO    : Bus 45020	: V=0.9944625, theta=24.482972 -> V=1.0, theta=0.0
% INFO    : Bus 45021	: V=0.9740268, theta=26.31011 -> V=1.0, theta=0.0
% INFO    : Bus 45022	: V=0.9944293, theta=41.896097 -> V=1.0, theta=0.0
% INFO    : Bus 45023	: V=0.9779441, theta=41.490918 -> V=1.0, theta=0.0
% INFO    : Bus 45024	: V=0.977511, theta=41.494403 -> V=1.0, theta=0.0
% INFO    : Bus 45025	: V=0.9769875, theta=41.508838 -> V=1.0, theta=0.0
% INFO    : Bus 45026	: V=0.9758749, theta=41.545787 -> V=1.0, theta=0.0
% INFO    : Bus 45027	: V=0.9844139, theta=41.765192 -> V=1.0, theta=0.0
% INFO    : Bus 45028	: V=0.9751723, theta=41.572319 -> V=1.0, theta=0.0
% INFO    : Bus 45029	: V=0.9746278, theta=41.620247 -> V=1.0, theta=0.0
% INFO    : Bus 45030	: V=0.976629, theta=41.745619 -> V=1.0, theta=0.0
% INFO    : Bus 45031	: V=0.9765935, theta=41.756108 -> V=1.0, theta=0.0
% INFO    : Bus 45032	: V=0.9751995, theta=41.69756 -> V=1.0, theta=0.0
% INFO    : Bus 45033	: V=0.977504, theta=41.518415 -> V=1.0, theta=0.0
% INFO    : Bus 45034	: V=0.9759746, theta=41.598977 -> V=1.0, theta=0.0
% INFO    : Bus 45035	: V=0.9751439, theta=41.607918 -> V=1.0, theta=0.0
% INFO    : Bus 45036	: V=0.9749234, theta=41.617374 -> V=1.0, theta=0.0
% INFO    : Bus 45037	: V=0.9783064, theta=41.501667 -> V=1.0, theta=0.0
% INFO    : Bus 45038	: V=0.9779256, theta=41.509415 -> V=1.0, theta=0.0
% INFO    : Bus 45039	: V=0.9784974, theta=41.546897 -> V=1.0, theta=0.0
% INFO    : Bus 45040	: V=0.9769229, theta=41.595682 -> V=1.0, theta=0.0
% INFO    : Bus 45041	: V=0.9751117, theta=41.623946 -> V=1.0, theta=0.0
% INFO    : Bus 45042	: V=0.9755876, theta=41.626933 -> V=1.0, theta=0.0
% INFO    : Bus 45043	: V=0.9756, theta=41.68984 -> V=1.0, theta=0.0
% INFO    : Bus 45044	: V=0.9764145, theta=41.703737 -> V=1.0, theta=0.0
% INFO    : Bus 45045	: V=0.9772222, theta=41.730423 -> V=1.0, theta=0.0
% INFO    : Bus 45046	: V=1.0022891, theta=42.161338 -> V=1.0, theta=0.0
% INFO    : Bus 45047	: V=0.9865853, theta=41.599313 -> V=1.0, theta=0.0
% INFO    : Bus 45048	: V=0.9785734, theta=41.4819 -> V=1.0, theta=0.0
% INFO    : Bus 45049	: V=0.9784638, theta=41.489251 -> V=1.0, theta=0.0
% INFO    : Bus 45050	: V=0.9785199, theta=41.497025 -> V=1.0, theta=0.0
% INFO    : Bus 45051	: V=0.9790705, theta=41.503031 -> V=1.0, theta=0.0
% INFO    : Bus 45052	: V=0.9795075, theta=41.492308 -> V=1.0, theta=0.0
% INFO    : Bus 45053	: V=0.9792026, theta=41.502662 -> V=1.0, theta=0.0
% INFO    : Bus 45054	: V=0.978851, theta=41.509954 -> V=1.0, theta=0.0
% INFO    : Bus 45055	: V=0.985458, theta=41.75307 -> V=1.0, theta=0.0
% INFO    : Bus 45056	: V=0.9769714, theta=41.6111 -> V=1.0, theta=0.0
% INFO    : Bus 45057	: V=0.9859754, theta=41.58459 -> V=1.0, theta=0.0
% INFO    : Bus 45058	: V=0.9861319, theta=41.611571 -> V=1.0, theta=0.0
% INFO    : Bus 45059	: V=0.9871172, theta=41.688007 -> V=1.0, theta=0.0
% INFO    : Bus 45060	: V=0.9799515, theta=41.493974 -> V=1.0, theta=0.0
% INFO    : Bus 45061	: V=0.9798198, theta=41.50755 -> V=1.0, theta=0.0
% INFO    : Bus 45062	: V=0.9802002, theta=41.515349 -> V=1.0, theta=0.0
% INFO    : Bus 45063	: V=0.9805308, theta=41.499939 -> V=1.0, theta=0.0
% INFO    : Bus 45064	: V=0.9800509, theta=41.519785 -> V=1.0, theta=0.0
% INFO    : Bus 45065	: V=0.9803031, theta=41.513761 -> V=1.0, theta=0.0
% INFO    : Bus 45066	: V=0.9867888, theta=41.765166 -> V=1.0, theta=0.0
% INFO    : Bus 45067	: V=0.9801882, theta=41.538624 -> V=1.0, theta=0.0
% INFO    : Bus 45068	: V=0.9783321, theta=41.61303 -> V=1.0, theta=0.0
% INFO    : Bus 45069	: V=0.9776364, theta=41.610024 -> V=1.0, theta=0.0
% INFO    : Bus 45070	: V=0.9786316, theta=41.664615 -> V=1.0, theta=0.0
% INFO    : Bus 45071	: V=0.9791067, theta=41.691047 -> V=1.0, theta=0.0
% INFO    : Bus 45072	: V=0.9798808, theta=41.711706 -> V=1.0, theta=0.0
% INFO    : Bus 45073	: V=0.9792993, theta=41.734342 -> V=1.0, theta=0.0
% INFO    : Bus 45074	: V=0.9845921, theta=41.527924 -> V=1.0, theta=0.0
% INFO    : Bus 45075	: V=0.9811849, theta=41.470464 -> V=1.0, theta=0.0
% INFO    : Bus 45076	: V=0.9850573, theta=41.561219 -> V=1.0, theta=0.0
% INFO    : Bus 45077	: V=0.9806856, theta=41.477387 -> V=1.0, theta=0.0
% INFO    : Bus 45078	: V=0.9867979, theta=41.680754 -> V=1.0, theta=0.0
% INFO    : Bus 45079	: V=0.9801094, theta=41.518153 -> V=1.0, theta=0.0
% INFO    : Bus 45080	: V=0.980921, theta=41.509569 -> V=1.0, theta=0.0
% INFO    : Bus 45081	: V=0.9809183, theta=41.542181 -> V=1.0, theta=0.0
% INFO    : Bus 45082	: V=0.9876109, theta=41.753137 -> V=1.0, theta=0.0
% INFO    : Bus 45083	: V=0.9832688, theta=41.630553 -> V=1.0, theta=0.0
% INFO    : Bus 45084	: V=0.987467, theta=41.808565 -> V=1.0, theta=0.0
% INFO    : Bus 45085	: V=0.9807737, theta=41.405869 -> V=1.0, theta=0.0
% INFO    : Bus 45086	: V=0.9858961, theta=41.605634 -> V=1.0, theta=0.0
% INFO    : Bus 45087	: V=0.9865252, theta=41.639159 -> V=1.0, theta=0.0
% INFO    : Bus 45088	: V=0.9823606, theta=41.524393 -> V=1.0, theta=0.0
% INFO    : Bus 45089	: V=0.9826769, theta=41.548564 -> V=1.0, theta=0.0
% INFO    : Bus 45090	: V=0.9825579, theta=41.549944 -> V=1.0, theta=0.0
% INFO    : Bus 45091	: V=0.9882002, theta=41.756872 -> V=1.0, theta=0.0
% INFO    : Bus 45092	: V=0.9887231, theta=41.782381 -> V=1.0, theta=0.0
% INFO    : Bus 45093	: V=0.9876889, theta=41.783188 -> V=1.0, theta=0.0
% INFO    : Bus 45094	: V=0.987981, theta=41.814465 -> V=1.0, theta=0.0
% INFO    : Bus 45095	: V=0.9808815, theta=41.713629 -> V=1.0, theta=0.0
% INFO    : Bus 45096	: V=0.9885556, theta=41.93624 -> V=1.0, theta=0.0
% INFO    : Bus 45097	: V=0.9873565, theta=41.651281 -> V=1.0, theta=0.0
% INFO    : Bus 45098	: V=0.9867498, theta=41.634136 -> V=1.0, theta=0.0
% INFO    : Bus 45099	: V=0.988879, theta=41.688976 -> V=1.0, theta=0.0
% INFO    : Bus 45100	: V=0.982903, theta=42.620988 -> V=1.0, theta=0.0
% INFO    : Bus 45101	: V=0.9811096, theta=42.452912 -> V=1.0, theta=0.0
% INFO    : Bus 45102	: V=0.9821522, theta=42.482198 -> V=1.0, theta=0.0
% INFO    : Bus 45103	: V=0.9917586, theta=43.221126 -> V=1.0, theta=0.0
% INFO    : Bus 45104	: V=0.9901483, theta=43.096924 -> V=1.0, theta=0.0
% INFO    : Bus 45105	: V=0.9819073, theta=42.461596 -> V=1.0, theta=0.0
% INFO    : Bus 45106	: V=0.9793044, theta=42.320592 -> V=1.0, theta=0.0
% INFO    : Bus 45107	: V=0.9777133, theta=42.090054 -> V=1.0, theta=0.0
% INFO    : Bus 45108	: V=0.9753563, theta=42.14371 -> V=1.0, theta=0.0
% INFO    : Bus 45109	: V=0.9638276, theta=41.739822 -> V=1.0, theta=0.0
% INFO    : Bus 45110	: V=0.9682733, theta=41.585649 -> V=1.0, theta=0.0
% INFO    : Bus 45111	: V=0.972135, theta=41.69552 -> V=1.0, theta=0.0
% INFO    : Bus 45112	: V=0.9669902, theta=41.461448 -> V=1.0, theta=0.0
% INFO    : Bus 45113	: V=0.9692987, theta=41.422134 -> V=1.0, theta=0.0
% INFO    : Bus 45114	: V=0.9601796, theta=41.195502 -> V=1.0, theta=0.0
% INFO    : Bus 45115	: V=0.9634298, theta=41.2778 -> V=1.0, theta=0.0
% INFO    : Bus 45116	: V=0.9667523, theta=41.353265 -> V=1.0, theta=0.0
% INFO    : Bus 45117	: V=0.9702211, theta=41.24658 -> V=1.0, theta=0.0
% INFO    : Bus 45118	: V=0.9707895, theta=41.238118 -> V=1.0, theta=0.0
% INFO    : Bus 45119	: V=0.9710766, theta=41.231053 -> V=1.0, theta=0.0
% INFO    : Bus 45120	: V=0.9582365, theta=41.137584 -> V=1.0, theta=0.0
% INFO    : Bus 45121	: V=0.9710947, theta=41.064865 -> V=1.0, theta=0.0
% INFO    : Bus 45122	: V=0.9643617, theta=40.896275 -> V=1.0, theta=0.0
% INFO    : Bus 45123	: V=0.9683894, theta=40.977461 -> V=1.0, theta=0.0
% INFO    : Bus 45124	: V=0.9756977, theta=41.108892 -> V=1.0, theta=0.0
% INFO    : Bus 45125	: V=0.9665956, theta=40.899065 -> V=1.0, theta=0.0
% INFO    : Bus 45126	: V=0.9914146, theta=41.722212 -> V=1.0, theta=0.0
% INFO    : Bus 45127	: V=0.9785498, theta=41.213706 -> V=1.0, theta=0.0
% INFO    : Bus 45128	: V=1.0000126, theta=42.007459 -> V=1.0, theta=0.0
% INFO    : Bus 45129	: V=1.0000885, theta=41.993761 -> V=1.0, theta=0.0
% INFO    : Bus 45130	: V=0.9935022, theta=41.839728 -> V=1.0, theta=0.0
% INFO    : Bus 45131	: V=1.0002936, theta=42.043057 -> V=1.0, theta=0.0
% INFO    : Bus 45132	: V=0.9784425, theta=41.495875 -> V=1.0, theta=0.0
% INFO    : Bus 45133	: V=0.972486, theta=41.52649 -> V=1.0, theta=0.0
% INFO    : Bus 45134	: V=0.9804099, theta=41.814783 -> V=1.0, theta=0.0
% INFO    : Bus 45135	: V=0.9822097, theta=41.781607 -> V=1.0, theta=0.0
% INFO    : Bus 45136	: V=0.9757187, theta=41.537642 -> V=1.0, theta=0.0
% INFO    : Bus 45137	: V=0.9794058, theta=41.49191 -> V=1.0, theta=0.0
% INFO    : Bus 45138	: V=0.9795764, theta=41.490306 -> V=1.0, theta=0.0
% INFO    : Bus 45139	: V=0.9829915, theta=41.511967 -> V=1.0, theta=0.0
% INFO    : Bus 45140	: V=0.982755, theta=41.514761 -> V=1.0, theta=0.0
% INFO    : Bus 45141	: V=0.973206, theta=41.619824 -> V=1.0, theta=0.0
% INFO    : Bus 45142	: V=0.9725701, theta=41.639314 -> V=1.0, theta=0.0
% INFO    : Bus 45143	: V=0.9751213, theta=41.567937 -> V=1.0, theta=0.0
% INFO    : Bus 45144	: V=0.9743677, theta=41.590882 -> V=1.0, theta=0.0
% INFO    : Bus 45145	: V=0.9742524, theta=41.869064 -> V=1.0, theta=0.0
% INFO    : Bus 45146	: V=0.9737221, theta=41.724137 -> V=1.0, theta=0.0
% INFO    : Bus 45147	: V=0.9780302, theta=42.177169 -> V=1.0, theta=0.0
% INFO    : Bus 45148	: V=0.9844057, theta=42.489936 -> V=1.0, theta=0.0
% INFO    : Bus 45149	: V=0.9866187, theta=41.986625 -> V=1.0, theta=0.0
% INFO    : Bus 45150	: V=0.9813116, theta=41.806826 -> V=1.0, theta=0.0
% INFO    : Bus 45151	: V=0.9796044, theta=41.706388 -> V=1.0, theta=0.0
% INFO    : Bus 45152	: V=0.9789115, theta=42.209031 -> V=1.0, theta=0.0
% INFO    : Bus 45153	: V=0.9866515, theta=42.745576 -> V=1.0, theta=0.0
% INFO    : Bus 45154	: V=0.9851876, theta=42.59159 -> V=1.0, theta=0.0
% INFO    : Bus 45155	: V=0.9792065, theta=41.538247 -> V=1.0, theta=0.0
% INFO    : Bus 45156	: V=0.9872311, theta=41.710829 -> V=1.0, theta=0.0
% INFO    : Bus 45157	: V=0.9841434, theta=41.505179 -> V=1.0, theta=0.0
% INFO    : Bus 45158	: V=0.9887964, theta=41.917612 -> V=1.0, theta=0.0
% INFO    : Bus 45159	: V=0.9704482, theta=22.846313 -> V=1.0, theta=0.0
% INFO    : Bus 45160	: V=0.9661192, theta=21.555752 -> V=1.0, theta=0.0
% INFO    : Bus 45161	: V=1.0059952, theta=31.8033 -> V=1.0, theta=0.0
% INFO    : Bus 45162	: V=0.9911965, theta=28.761889 -> V=1.0, theta=0.0
% INFO    : Bus 45163	: V=0.9862516, theta=28.920852 -> V=1.0, theta=0.0
% INFO    : Bus 45164	: V=0.9963354, theta=28.311139 -> V=1.0, theta=0.0
% INFO    : Bus 45165	: V=0.9893219, theta=27.293953 -> V=1.0, theta=0.0
% INFO    : Bus 45166	: V=1.0063806, theta=27.698762 -> V=1.0, theta=0.0
% INFO    : Bus 45167	: V=0.9927963, theta=32.948528 -> V=1.0, theta=0.0
% INFO    : Bus 45168	: V=0.9874617, theta=31.017942 -> V=1.0, theta=0.0
% INFO    : Bus 45169	: V=0.9844026, theta=27.218028 -> V=1.0, theta=0.0
% INFO    : Bus 45170	: V=0.9885694, theta=29.09347 -> V=1.0, theta=0.0
% INFO    : Bus 45171	: V=0.9867418, theta=29.598784 -> V=1.0, theta=0.0
% INFO    : Bus 45172	: V=1.0053991, theta=33.124671 -> V=1.0, theta=0.0
% INFO    : Bus 45173	: V=1.0022799, theta=40.917616 -> V=1.0, theta=0.0
% INFO    : Bus 45174	: V=1.0139871, theta=41.813097 -> V=1.0, theta=0.0
% INFO    : Bus 45175	: V=1.0100815, theta=40.452537 -> V=1.0, theta=0.0
% INFO    : Bus 45176	: V=1.0138363, theta=41.248872 -> V=1.0, theta=0.0
% INFO    : Bus 45177	: V=0.9955246, theta=41.3772 -> V=1.0, theta=0.0
% INFO    : Bus 45178	: V=0.9974487, theta=41.429788 -> V=1.0, theta=0.0
% INFO    : Bus 45179	: V=0.9978032, theta=41.419174 -> V=1.0, theta=0.0
% INFO    : Bus 45180	: V=0.9949028, theta=41.372869 -> V=1.0, theta=0.0
% INFO    : Bus 45181	: V=1.0090159, theta=41.739679 -> V=1.0, theta=0.0
% INFO    : Bus 45182	: V=1.0160818, theta=41.637029 -> V=1.0, theta=0.0
% INFO    : Bus 45183	: V=1.0030647, theta=41.257269 -> V=1.0, theta=0.0
% INFO    : Bus 45184	: V=1.0168302, theta=41.682255 -> V=1.0, theta=0.0
% INFO    : Bus 45185	: V=1.0014211, theta=41.263832 -> V=1.0, theta=0.0
% INFO    : Bus 45186	: V=0.9930475, theta=20.65159 -> V=1.0, theta=0.0
% INFO    : Bus 45187	: V=0.996165, theta=18.673777 -> V=1.0, theta=0.0
% INFO    : Bus 45188	: V=0.9942544, theta=17.544021 -> V=1.0, theta=0.0
% INFO    : Bus 45189	: V=0.9829718, theta=23.899571 -> V=1.0, theta=0.0
% INFO    : Bus 45190	: V=0.9818459, theta=24.120162 -> V=1.0, theta=0.0
% INFO    : Bus 45191	: V=0.9832989, theta=24.628372 -> V=1.0, theta=0.0
% INFO    : Bus 45192	: V=0.9817939, theta=23.573407 -> V=1.0, theta=0.0
% INFO    : Bus 45193	: V=0.9781558, theta=23.88366 -> V=1.0, theta=0.0
% INFO    : Bus 45194	: V=1.0031715, theta=45.16905 -> V=1.0, theta=0.0
% INFO    : Bus 45195	: V=1.0081278, theta=45.38085 -> V=1.0, theta=0.0
% INFO    : Bus 45196	: V=1.0044672, theta=45.292742 -> V=1.0, theta=0.0
% INFO    : Bus 45197	: V=1.0055491, theta=45.311027 -> V=1.0, theta=0.0
% INFO    : Bus 45198	: V=1.0030395, theta=45.169444 -> V=1.0, theta=0.0
% INFO    : Bus 45199	: V=1.0064004, theta=45.264858 -> V=1.0, theta=0.0
% INFO    : Bus 45200	: V=1.0060161, theta=45.231652 -> V=1.0, theta=0.0
% INFO    : Bus 45201	: V=0.9972299, theta=44.921391 -> V=1.0, theta=0.0
% INFO    : Bus 45202	: V=1.0055476, theta=45.222152 -> V=1.0, theta=0.0
% INFO    : Bus 45203	: V=1.0057571, theta=45.205526 -> V=1.0, theta=0.0
% INFO    : Bus 45204	: V=0.999812, theta=44.960721 -> V=1.0, theta=0.0
% INFO    : Bus 45205	: V=1.0016303, theta=45.014163 -> V=1.0, theta=0.0
% INFO    : Bus 45206	: V=1.0057304, theta=45.198002 -> V=1.0, theta=0.0
% INFO    : Bus 45207	: V=0.9985848, theta=44.928749 -> V=1.0, theta=0.0
% INFO    : Bus 45208	: V=1.0057887, theta=45.188896 -> V=1.0, theta=0.0
% INFO    : Bus 45209	: V=0.9976783, theta=44.89345 -> V=1.0, theta=0.0
% INFO    : Bus 45210	: V=1.0065922, theta=45.151223 -> V=1.0, theta=0.0
% INFO    : Bus 45211	: V=1.0073382, theta=45.130077 -> V=1.0, theta=0.0
% INFO    : Bus 45212	: V=0.9988522, theta=44.891445 -> V=1.0, theta=0.0
% INFO    : Bus 45213	: V=0.993345, theta=44.804723 -> V=1.0, theta=0.0
% INFO    : Bus 45214	: V=0.9963471, theta=44.804085 -> V=1.0, theta=0.0
% INFO    : Bus 45215	: V=0.9979996, theta=44.771864 -> V=1.0, theta=0.0
% INFO    : Bus 45216	: V=1.0019905, theta=44.593924 -> V=1.0, theta=0.0
% INFO    : Bus 45217	: V=1.0004653, theta=44.662172 -> V=1.0, theta=0.0
% INFO    : Bus 45218	: V=1.0006194, theta=44.657821 -> V=1.0, theta=0.0
% INFO    : Bus 45219	: V=1.0003874, theta=44.66251 -> V=1.0, theta=0.0
% INFO    : Bus 45220	: V=1.0051795, theta=44.552952 -> V=1.0, theta=0.0
% INFO    : Bus 45221	: V=1.0124877, theta=44.701066 -> V=1.0, theta=0.0
% INFO    : Bus 45222	: V=1.0151596, theta=44.470018 -> V=1.0, theta=0.0
% INFO    : Bus 45223	: V=1.0021221, theta=44.53228 -> V=1.0, theta=0.0
% INFO    : Bus 45224	: V=1.0053231, theta=44.401333 -> V=1.0, theta=0.0
% INFO    : Bus 45225	: V=0.9894506, theta=44.769518 -> V=1.0, theta=0.0
% INFO    : Bus 45226	: V=1.0079291, theta=45.486772 -> V=1.0, theta=0.0
% INFO    : Bus 45227	: V=1.0115435, theta=45.595305 -> V=1.0, theta=0.0
% INFO    : Bus 45228	: V=1.0100102, theta=45.680129 -> V=1.0, theta=0.0
% INFO    : Bus 45229	: V=0.9961082, theta=44.196283 -> V=1.0, theta=0.0
% INFO    : Bus 45230	: V=1.015096, theta=43.959112 -> V=1.0, theta=0.0
% INFO    : Bus 45231	: V=1.0084973, theta=43.259931 -> V=1.0, theta=0.0
% INFO    : Bus 45232	: V=1.0151438, theta=46.083612 -> V=1.0, theta=0.0
% INFO    : Bus 45233	: V=1.0156431, theta=43.858796 -> V=1.0, theta=0.0
% INFO    : Bus 45234	: V=1.0184595, theta=43.946519 -> V=1.0, theta=0.0
% INFO    : Bus 45235	: V=1.0161844, theta=43.924065 -> V=1.0, theta=0.0
% INFO    : Bus 45236	: V=1.0165635, theta=43.9695 -> V=1.0, theta=0.0
% INFO    : Bus 45237	: V=1.0158305, theta=43.886709 -> V=1.0, theta=0.0
% INFO    : Bus 45238	: V=1.0162187, theta=44.078769 -> V=1.0, theta=0.0
% INFO    : Bus 45239	: V=1.0153663, theta=44.449324 -> V=1.0, theta=0.0
% INFO    : Bus 45240	: V=1.0149054, theta=44.793476 -> V=1.0, theta=0.0
% INFO    : Bus 45241	: V=1.0193586, theta=45.065531 -> V=1.0, theta=0.0
% INFO    : Bus 45242	: V=1.0154841, theta=45.055964 -> V=1.0, theta=0.0
% INFO    : Bus 45243	: V=1.0157131, theta=45.142291 -> V=1.0, theta=0.0
% INFO    : Bus 45244	: V=1.0120661, theta=44.950948 -> V=1.0, theta=0.0
% INFO    : Bus 45245	: V=1.0096235, theta=44.997955 -> V=1.0, theta=0.0
% INFO    : Bus 45246	: V=1.0162359, theta=45.341737 -> V=1.0, theta=0.0
% INFO    : Bus 45247	: V=1.0173739, theta=45.678969 -> V=1.0, theta=0.0
% INFO    : Bus 45248	: V=1.0226869, theta=46.390514 -> V=1.0, theta=0.0
% INFO    : Bus 45249	: V=1.0150607, theta=46.19129 -> V=1.0, theta=0.0
% INFO    : Bus 45250	: V=1.0194243, theta=46.620809 -> V=1.0, theta=0.0
% INFO    : Bus 45251	: V=1.0177977, theta=47.041575 -> V=1.0, theta=0.0
% INFO    : Bus 45252	: V=1.0085405, theta=44.193291 -> V=1.0, theta=0.0
% INFO    : Bus 45253	: V=1.0096799, theta=45.471226 -> V=1.0, theta=0.0
% INFO    : Bus 45254	: V=1.0150276, theta=46.768535 -> V=1.0, theta=0.0
% INFO    : Bus 45255	: V=1.0072769, theta=46.816329 -> V=1.0, theta=0.0
% INFO    : Bus 45256	: V=1.0096127, theta=43.962033 -> V=1.0, theta=0.0
% INFO    : Bus 45257	: V=1.0084344, theta=45.101773 -> V=1.0, theta=0.0
% INFO    : Bus 45258	: V=1.0054955, theta=45.239182 -> V=1.0, theta=0.0
% INFO    : Bus 45259	: V=1.0106454, theta=45.032466 -> V=1.0, theta=0.0
% INFO    : Bus 45260	: V=0.9929332, theta=41.195221 -> V=1.0, theta=0.0
% INFO    : Bus 45261	: V=0.9939329, theta=41.069124 -> V=1.0, theta=0.0
% INFO    : Bus 45262	: V=0.9844788, theta=40.672444 -> V=1.0, theta=0.0
% INFO    : Bus 45263	: V=0.9797254, theta=40.775678 -> V=1.0, theta=0.0
% INFO    : Bus 45264	: V=0.984883, theta=40.724701 -> V=1.0, theta=0.0
% INFO    : Bus 45265	: V=0.9815051, theta=40.744184 -> V=1.0, theta=0.0
% INFO    : Bus 45266	: V=1.002847, theta=40.888767 -> V=1.0, theta=0.0
% INFO    : Bus 45267	: V=0.9940313, theta=40.62039 -> V=1.0, theta=0.0
% INFO    : Bus 45268	: V=0.9902973, theta=40.494047 -> V=1.0, theta=0.0
% INFO    : Bus 45269	: V=0.9918669, theta=40.39534 -> V=1.0, theta=0.0
% INFO    : Bus 45270	: V=0.9923182, theta=40.44214 -> V=1.0, theta=0.0
% INFO    : Bus 45271	: V=0.992013, theta=40.281549 -> V=1.0, theta=0.0
% INFO    : Bus 45272	: V=0.9941603, theta=40.30129 -> V=1.0, theta=0.0
% INFO    : Bus 45273	: V=0.9858243, theta=40.67885 -> V=1.0, theta=0.0
% INFO    : Bus 45274	: V=0.9925327, theta=41.031815 -> V=1.0, theta=0.0
% INFO    : Bus 45275	: V=0.9861786, theta=40.723207 -> V=1.0, theta=0.0
% INFO    : Bus 45276	: V=0.9922958, theta=41.028939 -> V=1.0, theta=0.0
% INFO    : Bus 45277	: V=0.9934173, theta=41.06505 -> V=1.0, theta=0.0
% INFO    : Bus 45278	: V=0.9962294, theta=41.025248 -> V=1.0, theta=0.0
% INFO    : Bus 45279	: V=0.9972604, theta=40.145796 -> V=1.0, theta=0.0
% INFO    : Bus 45280	: V=0.9957984, theta=38.774494 -> V=1.0, theta=0.0
% INFO    : Bus 45281	: V=0.9928505, theta=41.150182 -> V=1.0, theta=0.0
% INFO    : Bus 45282	: V=0.978909, theta=40.733793 -> V=1.0, theta=0.0
% INFO    : Bus 45283	: V=0.9967698, theta=40.952767 -> V=1.0, theta=0.0
% INFO    : Bus 45284	: V=1.0008879, theta=40.457357 -> V=1.0, theta=0.0
% INFO    : Bus 45285	: V=1.0035352, theta=41.392922 -> V=1.0, theta=0.0
% INFO    : Bus 45286	: V=0.995154, theta=40.996444 -> V=1.0, theta=0.0
% INFO    : Bus 45287	: V=1.0016256, theta=41.053503 -> V=1.0, theta=0.0
% INFO    : Bus 45288	: V=1.0057905, theta=41.913802 -> V=1.0, theta=0.0
% INFO    : Bus 45289	: V=1.007612, theta=41.854801 -> V=1.0, theta=0.0
% INFO    : Bus 45290	: V=1.0018879, theta=41.592806 -> V=1.0, theta=0.0
% INFO    : Bus 45291	: V=0.9942186, theta=39.851195 -> V=1.0, theta=0.0
% INFO    : Bus 45292	: V=0.9978181, theta=38.681889 -> V=1.0, theta=0.0
% INFO    : Bus 45293	: V=1.0065199, theta=34.140952 -> V=1.0, theta=0.0
% INFO    : Bus 45294	: V=0.9910588, theta=34.840117 -> V=1.0, theta=0.0
% INFO    : Bus 45295	: V=1.0002979, theta=38.382502 -> V=1.0, theta=0.0
% INFO    : Bus 45296	: V=0.9867913, theta=39.664246 -> V=1.0, theta=0.0
% INFO    : Bus 45297	: V=0.9865593, theta=39.728486 -> V=1.0, theta=0.0
% INFO    : Bus 45298	: V=0.9910215, theta=39.4567 -> V=1.0, theta=0.0
% INFO    : Bus 45299	: V=0.9919277, theta=39.577772 -> V=1.0, theta=0.0
% INFO    : Bus 45300	: V=0.9902872, theta=39.314347 -> V=1.0, theta=0.0
% INFO    : Bus 45301	: V=0.9845068, theta=39.564604 -> V=1.0, theta=0.0
% INFO    : Bus 45302	: V=0.9848519, theta=39.588255 -> V=1.0, theta=0.0
% INFO    : Bus 45303	: V=0.9958572, theta=39.833621 -> V=1.0, theta=0.0
% INFO    : Bus 45304	: V=0.9857161, theta=39.606549 -> V=1.0, theta=0.0
% INFO    : Bus 45305	: V=0.9875262, theta=39.655082 -> V=1.0, theta=0.0
% INFO    : Bus 45306	: V=0.9935644, theta=39.550915 -> V=1.0, theta=0.0
% INFO    : Bus 45307	: V=0.9772865, theta=39.517639 -> V=1.0, theta=0.0
% INFO    : Bus 45308	: V=0.979898, theta=39.477068 -> V=1.0, theta=0.0
% INFO    : Bus 45309	: V=0.9769358, theta=38.69406 -> V=1.0, theta=0.0
% INFO    : Bus 45310	: V=0.9872844, theta=36.743605 -> V=1.0, theta=0.0
% INFO    : Bus 45311	: V=0.9819481, theta=35.559382 -> V=1.0, theta=0.0
% INFO    : Bus 45312	: V=0.9843815, theta=36.272645 -> V=1.0, theta=0.0
% INFO    : Bus 45313	: V=0.9727118, theta=33.461776 -> V=1.0, theta=0.0
% INFO    : Bus 45314	: V=0.9634548, theta=31.995405 -> V=1.0, theta=0.0
% INFO    : Bus 45315	: V=0.9607667, theta=28.968196 -> V=1.0, theta=0.0
% INFO    : Bus 45316	: V=0.9815536, theta=31.873329 -> V=1.0, theta=0.0
% INFO    : Bus 45317	: V=0.9789197, theta=35.443567 -> V=1.0, theta=0.0
% INFO    : Bus 45318	: V=0.9859253, theta=38.417411 -> V=1.0, theta=0.0
% INFO    : Bus 45319	: V=0.9905131, theta=39.033932 -> V=1.0, theta=0.0
% INFO    : Bus 45320	: V=0.9816934, theta=35.651789 -> V=1.0, theta=0.0
% INFO    : Bus 45321	: V=0.9962395, theta=38.51892 -> V=1.0, theta=0.0
% INFO    : Bus 45322	: V=0.977156, theta=39.094763 -> V=1.0, theta=0.0
% INFO    : Bus 45323	: V=0.9573978, theta=29.688081 -> V=1.0, theta=0.0
% INFO    : Bus 45324	: V=0.9872172, theta=39.653197 -> V=1.0, theta=0.0
% INFO    : Bus 45325	: V=0.9956858, theta=39.94522 -> V=1.0, theta=0.0
% INFO    : Bus 45326	: V=1.0021245, theta=39.671936 -> V=1.0, theta=0.0
% INFO    : Bus 45327	: V=0.9979597, theta=39.702633 -> V=1.0, theta=0.0
% INFO    : Bus 45328	: V=1.0081233, theta=39.907904 -> V=1.0, theta=0.0
% INFO    : Bus 45329	: V=1.008216, theta=39.51654 -> V=1.0, theta=0.0
% INFO    : Bus 45330	: V=1.0078603, theta=39.805068 -> V=1.0, theta=0.0
% INFO    : Bus 45331	: V=1.0038276, theta=39.64752 -> V=1.0, theta=0.0
% INFO    : Bus 45332	: V=1.009979, theta=39.167873 -> V=1.0, theta=0.0
% INFO    : Bus 45333	: V=0.9843293, theta=18.015407 -> V=1.0, theta=0.0
% INFO    : Bus 45334	: V=0.9847477, theta=17.794812 -> V=1.0, theta=0.0
% INFO    : Bus 45335	: V=0.9878949, theta=19.728598 -> V=1.0, theta=0.0
% INFO    : Bus 45336	: V=0.9804936, theta=25.628982 -> V=1.0, theta=0.0
% INFO    : Bus 45337	: V=0.9965878, theta=23.523437 -> V=1.0, theta=0.0
% INFO    : Bus 45338	: V=1.0006304, theta=23.871558 -> V=1.0, theta=0.0
% INFO    : Bus 45339	: V=0.9876376, theta=19.86683 -> V=1.0, theta=0.0
% INFO    : Bus 45340	: V=0.9587543, theta=32.421152 -> V=1.0, theta=0.0
% INFO    : Bus 45341	: V=0.959713, theta=30.009182 -> V=1.0, theta=0.0
% INFO    : Bus 45342	: V=0.9621867, theta=29.440898 -> V=1.0, theta=0.0
% INFO    : Bus 45343	: V=0.9574459, theta=31.733724 -> V=1.0, theta=0.0
% INFO    : Bus 45344	: V=0.9625527, theta=30.870094 -> V=1.0, theta=0.0
% INFO    : Bus 45345	: V=0.9634212, theta=30.446196 -> V=1.0, theta=0.0
% INFO    : Bus 45346	: V=0.9743176, theta=29.312074 -> V=1.0, theta=0.0
% INFO    : Bus 45347	: V=0.9626655, theta=31.463452 -> V=1.0, theta=0.0
% INFO    : Bus 45348	: V=0.9659479, theta=12.783244 -> V=1.0, theta=0.0
% INFO    : Bus 45349	: V=0.9603128, theta=13.615558 -> V=1.0, theta=0.0
% INFO    : Bus 45350	: V=1.0161218, theta=43.638505 -> V=1.0, theta=0.0
% INFO    : Bus 45351	: V=1.0086196, theta=43.171213 -> V=1.0, theta=0.0
% INFO    : Bus 45352	: V=1.0097181, theta=43.654488 -> V=1.0, theta=0.0
% INFO    : Bus 45353	: V=1.005241, theta=42.740152 -> V=1.0, theta=0.0
% INFO    : Bus 45354	: V=1.0040737, theta=42.748074 -> V=1.0, theta=0.0
% INFO    : Bus 45355	: V=1.0147046, theta=42.539964 -> V=1.0, theta=0.0
% INFO    : Bus 45356	: V=0.9769496, theta=32.772814 -> V=1.0, theta=0.0
% INFO    : Bus 45357	: V=0.9561855, theta=30.872376 -> V=1.0, theta=0.0
% INFO    : Bus 45358	: V=0.9588705, theta=29.325436 -> V=1.0, theta=0.0
% INFO    : Bus 45359	: V=1.0069333, theta=38.99383 -> V=1.0, theta=0.0
% INFO    : Bus 45360	: V=0.9930754, theta=38.182539 -> V=1.0, theta=0.0
% INFO    : Bus 45361	: V=0.9941878, theta=38.665874 -> V=1.0, theta=0.0
% INFO    : Bus 45362	: V=0.9962567, theta=38.887888 -> V=1.0, theta=0.0
% INFO    : Bus 45363	: V=1.0051726, theta=38.980147 -> V=1.0, theta=0.0
% INFO    : Bus 45364	: V=0.9878525, theta=43.721721 -> V=1.0, theta=0.0
% INFO    : Bus 45365	: V=0.9761061, theta=42.813725 -> V=1.0, theta=0.0
% INFO    : Bus 45366	: V=0.9751746, theta=42.836664 -> V=1.0, theta=0.0
% INFO    : Bus 45367	: V=0.9767977, theta=42.787099 -> V=1.0, theta=0.0
% INFO    : Bus 45368	: V=0.9799339, theta=42.76488 -> V=1.0, theta=0.0
% INFO    : Bus 45369	: V=0.9840589, theta=42.773865 -> V=1.0, theta=0.0
% INFO    : Bus 45370	: V=0.980752, theta=43.650983 -> V=1.0, theta=0.0
% INFO    : Bus 45371	: V=0.991328, theta=43.965398 -> V=1.0, theta=0.0
% INFO    : Bus 45372	: V=0.9878018, theta=42.884038 -> V=1.0, theta=0.0
% INFO    : Bus 45373	: V=0.991422, theta=43.233532 -> V=1.0, theta=0.0
% INFO    : Bus 45374	: V=0.9969927, theta=43.625715 -> V=1.0, theta=0.0
% INFO    : Bus 45375	: V=1.00306, theta=44.160002 -> V=1.0, theta=0.0
% INFO    : Bus 45376	: V=1.0040458, theta=44.405464 -> V=1.0, theta=0.0
% INFO    : Bus 45377	: V=0.9957794, theta=43.678845 -> V=1.0, theta=0.0
% INFO    : Bus 45378	: V=0.9973066, theta=43.812856 -> V=1.0, theta=0.0
% INFO    : Bus 45379	: V=1.0110051, theta=44.862487 -> V=1.0, theta=0.0
% INFO    : Bus 45380	: V=1.0134143, theta=45.03243 -> V=1.0, theta=0.0
% INFO    : Bus 45381	: V=1.012383, theta=44.958126 -> V=1.0, theta=0.0
% INFO    : Bus 45382	: V=1.0037781, theta=44.372421 -> V=1.0, theta=0.0
% INFO    : Bus 45383	: V=1.0162414, theta=45.34125 -> V=1.0, theta=0.0
% INFO    : Bus 45384	: V=1.0058694, theta=44.551986 -> V=1.0, theta=0.0
% INFO    : Bus 45385	: V=1.0080878, theta=44.789038 -> V=1.0, theta=0.0
% INFO    : Bus 45386	: V=1.0085908, theta=44.795826 -> V=1.0, theta=0.0
% INFO    : Bus 45387	: V=1.0058459, theta=44.552505 -> V=1.0, theta=0.0
% INFO    : Bus 45388	: V=0.9905005, theta=43.277948 -> V=1.0, theta=0.0
% INFO    : Bus 45389	: V=0.9869425, theta=42.76565 -> V=1.0, theta=0.0
% INFO    : Bus 45390	: V=0.9919147, theta=43.425967 -> V=1.0, theta=0.0
% INFO    : Bus 45391	: V=0.9870932, theta=42.006623 -> V=1.0, theta=0.0
% INFO    : Bus 45392	: V=0.9873291, theta=42.056644 -> V=1.0, theta=0.0
% INFO    : Bus 45393	: V=0.9870084, theta=42.017085 -> V=1.0, theta=0.0
% INFO    : Bus 45394	: V=0.9786712, theta=41.71373 -> V=1.0, theta=0.0
% INFO    : Bus 45395	: V=0.9927699, theta=42.07418 -> V=1.0, theta=0.0
% INFO    : Bus 45396	: V=0.9876793, theta=41.994525 -> V=1.0, theta=0.0
% INFO    : Bus 45397	: V=0.9782139, theta=41.788802 -> V=1.0, theta=0.0
% INFO    : Bus 45398	: V=0.9789285, theta=41.796135 -> V=1.0, theta=0.0
% INFO    : Bus 45399	: V=0.9894116, theta=41.989648 -> V=1.0, theta=0.0
% INFO    : Bus 45400	: V=0.9808132, theta=41.793296 -> V=1.0, theta=0.0
% INFO    : Bus 45401	: V=0.9816776, theta=41.832265 -> V=1.0, theta=0.0
% INFO    : Bus 45402	: V=0.9802674, theta=41.811222 -> V=1.0, theta=0.0
% INFO    : Bus 45403	: V=0.9821571, theta=41.865919 -> V=1.0, theta=0.0
% INFO    : Bus 45404	: V=0.9783596, theta=41.85961 -> V=1.0, theta=0.0
% INFO    : Bus 45405	: V=0.9830968, theta=41.874822 -> V=1.0, theta=0.0
% INFO    : Bus 45406	: V=0.9925814, theta=43.761656 -> V=1.0, theta=0.0
% INFO    : Bus 45407	: V=0.9917213, theta=42.970584 -> V=1.0, theta=0.0
% INFO    : Bus 45408	: V=0.9992861, theta=42.316935 -> V=1.0, theta=0.0
% INFO    : Bus 45409	: V=0.9953164, theta=42.354651 -> V=1.0, theta=0.0
% INFO    : Bus 45410	: V=0.9996784, theta=42.353175 -> V=1.0, theta=0.0
% INFO    : Bus 45411	: V=1.0001826, theta=42.381491 -> V=1.0, theta=0.0
% INFO    : Bus 45412	: V=1.0037334, theta=42.519682 -> V=1.0, theta=0.0
% INFO    : Bus 45413	: V=1.0113492, theta=43.042547 -> V=1.0, theta=0.0
% INFO    : Bus 45414	: V=1.0105489, theta=33.485852 -> V=1.0, theta=0.0
% INFO    : Bus 45415	: V=1.0119649, theta=33.484354 -> V=1.0, theta=0.0
% INFO    : Bus 45416	: V=1.0109247, theta=32.44543 -> V=1.0, theta=0.0
% INFO    : Bus 45417	: V=0.9661375, theta=8.185612 -> V=1.0, theta=0.0
% INFO    : Bus 45418	: V=0.9682373, theta=8.336181 -> V=1.0, theta=0.0
% INFO    : Bus 45419	: V=0.9879472, theta=41.839249 -> V=1.0, theta=0.0
% INFO    : Bus 45420	: V=0.9795409, theta=41.503978 -> V=1.0, theta=0.0
% INFO    : Bus 45421	: V=0.9922361, theta=41.324482 -> V=1.0, theta=0.0
% INFO    : Bus 45422	: V=0.9783261, theta=41.296319 -> V=1.0, theta=0.0
% INFO    : Bus 45423	: V=0.9775775, theta=41.287433 -> V=1.0, theta=0.0
% INFO    : Bus 45424	: V=0.991283, theta=41.347945 -> V=1.0, theta=0.0
% INFO    : Bus 45425	: V=0.9902498, theta=41.400772 -> V=1.0, theta=0.0
% INFO    : Bus 45426	: V=0.9814678, theta=41.078736 -> V=1.0, theta=0.0
% INFO    : Bus 45427	: V=1.0033923, theta=41.255082 -> V=1.0, theta=0.0
% INFO    : Bus 45428	: V=1.0065556, theta=41.261834 -> V=1.0, theta=0.0
% INFO    : Bus 45429	: V=1.0051116, theta=41.672453 -> V=1.0, theta=0.0
% INFO    : Bus 45430	: V=0.9973554, theta=41.015696 -> V=1.0, theta=0.0
% INFO    : Bus 45431	: V=0.9997446, theta=41.052718 -> V=1.0, theta=0.0
% INFO    : Bus 45432	: V=0.9943277, theta=40.960422 -> V=1.0, theta=0.0
% INFO    : Bus 45433	: V=1.0020219, theta=40.092201 -> V=1.0, theta=0.0
% INFO    : Bus 45434	: V=1.0048396, theta=40.185317 -> V=1.0, theta=0.0
% INFO    : Bus 45435	: V=1.0046569, theta=39.683562 -> V=1.0, theta=0.0
% INFO    : Bus 45436	: V=1.002473, theta=40.492988 -> V=1.0, theta=0.0
% INFO    : Bus 45437	: V=1.0062214, theta=41.552934 -> V=1.0, theta=0.0
% INFO    : Bus 45438	: V=1.0038467, theta=40.434182 -> V=1.0, theta=0.0
% INFO    : Bus 45439	: V=0.9893651, theta=40.883913 -> V=1.0, theta=0.0
% INFO    : Bus 45440	: V=0.9864288, theta=40.851171 -> V=1.0, theta=0.0
% INFO    : Bus 45441	: V=0.9943914, theta=40.560983 -> V=1.0, theta=0.0
% INFO    : Bus 45442	: V=0.9904719, theta=40.062962 -> V=1.0, theta=0.0
% INFO    : Bus 45443	: V=0.9917831, theta=39.649873 -> V=1.0, theta=0.0
% INFO    : Bus 45444	: V=1.0041451, theta=39.26301 -> V=1.0, theta=0.0
% INFO    : Bus 45445	: V=1.0057098, theta=38.750403 -> V=1.0, theta=0.0
% INFO    : Bus 45446	: V=0.9804468, theta=23.980063 -> V=1.0, theta=0.0
% INFO    : Bus 45447	: V=0.9908486, theta=15.680107 -> V=1.0, theta=0.0
% INFO    : Bus 45448	: V=0.9788871, theta=21.570404 -> V=1.0, theta=0.0
% INFO    : Bus 45449	: V=0.9861795, theta=26.337173 -> V=1.0, theta=0.0
% INFO    : Bus 45450	: V=0.9944108, theta=46.9629 -> V=1.0, theta=0.0
% INFO    : Bus 45451	: V=0.9740734, theta=40.369418 -> V=1.0, theta=0.0
% INFO    : Bus 45452	: V=0.9768941, theta=44.454579 -> V=1.0, theta=0.0
% INFO    : Bus 45453	: V=0.9644299, theta=41.224252 -> V=1.0, theta=0.0
% INFO    : Bus 45454	: V=0.9651583, theta=39.222332 -> V=1.0, theta=0.0
% INFO    : Bus 45455	: V=0.9608871, theta=39.083372 -> V=1.0, theta=0.0
% INFO    : Bus 45456	: V=0.9593928, theta=38.752391 -> V=1.0, theta=0.0
% INFO    : Bus 45457	: V=1.0158149, theta=49.935086 -> V=1.0, theta=0.0
% INFO    : Bus 45458	: V=1.0176681, theta=49.87314 -> V=1.0, theta=0.0
% INFO    : Bus 45459	: V=1.0195457, theta=49.967956 -> V=1.0, theta=0.0
% INFO    : Bus 45460	: V=1.0070468, theta=49.472162 -> V=1.0, theta=0.0
% INFO    : Bus 45461	: V=0.9959336, theta=48.970612 -> V=1.0, theta=0.0
% INFO    : Bus 45462	: V=0.9765038, theta=48.274113 -> V=1.0, theta=0.0
% INFO    : Bus 45463	: V=1.015356, theta=48.914779 -> V=1.0, theta=0.0
% INFO    : Bus 45464	: V=0.9683335, theta=44.027045 -> V=1.0, theta=0.0
% INFO    : Bus 45465	: V=0.9835452, theta=43.983867 -> V=1.0, theta=0.0
% INFO    : Bus 45466	: V=0.9672444, theta=43.799238 -> V=1.0, theta=0.0
% INFO    : Bus 45467	: V=0.9675763, theta=43.9845 -> V=1.0, theta=0.0
% INFO    : Bus 45468	: V=0.9842754, theta=44.235273 -> V=1.0, theta=0.0
% INFO    : Bus 45469	: V=0.9689594, theta=43.962879 -> V=1.0, theta=0.0
% INFO    : Bus 45470	: V=0.9705033, theta=44.155265 -> V=1.0, theta=0.0
% INFO    : Bus 45471	: V=0.9769108, theta=44.275304 -> V=1.0, theta=0.0
% INFO    : Bus 45472	: V=0.9776929, theta=44.527411 -> V=1.0, theta=0.0
% INFO    : Bus 45473	: V=0.9792603, theta=44.675569 -> V=1.0, theta=0.0
% INFO    : Bus 45474	: V=1.0157406, theta=48.52609 -> V=1.0, theta=0.0
% INFO    : Bus 45475	: V=1.0124688, theta=47.379628 -> V=1.0, theta=0.0
% INFO    : Bus 45476	: V=1.0160945, theta=48.235173 -> V=1.0, theta=0.0
% INFO    : Bus 45477	: V=0.9987436, theta=47.905794 -> V=1.0, theta=0.0
% INFO    : Bus 45478	: V=0.9904752, theta=46.951928 -> V=1.0, theta=0.0
% INFO    : Bus 45479	: V=1.019613, theta=53.095404 -> V=1.0, theta=0.0
% INFO    : Bus 45480	: V=1.0025527, theta=53.009057 -> V=1.0, theta=0.0
% INFO    : Bus 45481	: V=1.0050899, theta=53.142096 -> V=1.0, theta=0.0
% INFO    : Bus 45482	: V=1.0007317, theta=52.934171 -> V=1.0, theta=0.0
% INFO    : Bus 45483	: V=1.0035493, theta=53.089188 -> V=1.0, theta=0.0
% INFO    : Bus 45484	: V=1.004644, theta=53.134669 -> V=1.0, theta=0.0
% INFO    : Bus 45485	: V=1.0052325, theta=53.163314 -> V=1.0, theta=0.0
% INFO    : Bus 45486	: V=1.0050363, theta=53.145462 -> V=1.0, theta=0.0
% INFO    : Bus 45487	: V=1.0058269, theta=53.161543 -> V=1.0, theta=0.0
% INFO    : Bus 45488	: V=1.0176638, theta=53.422764 -> V=1.0, theta=0.0
% INFO    : Bus 45489	: V=1.0197188, theta=53.265978 -> V=1.0, theta=0.0
% INFO    : Bus 45490	: V=1.0068436, theta=53.239486 -> V=1.0, theta=0.0
% INFO    : Bus 45491	: V=1.0158954, theta=53.505626 -> V=1.0, theta=0.0
% INFO    : Bus 45492	: V=1.0078871, theta=53.304734 -> V=1.0, theta=0.0
% INFO    : Bus 45493	: V=1.0173509, theta=53.42307 -> V=1.0, theta=0.0
% INFO    : Bus 45494	: V=1.0075571, theta=53.257095 -> V=1.0, theta=0.0
% INFO    : Bus 45495	: V=1.0164823, theta=53.521395 -> V=1.0, theta=0.0
% INFO    : Bus 45496	: V=1.0080619, theta=53.364162 -> V=1.0, theta=0.0
% INFO    : Bus 45497	: V=1.0055381, theta=53.424421 -> V=1.0, theta=0.0
% INFO    : Bus 45498	: V=1.0052032, theta=53.642453 -> V=1.0, theta=0.0
% INFO    : Bus 45499	: V=1.0137975, theta=53.838181 -> V=1.0, theta=0.0
% INFO    : Bus 45500	: V=1.005126, theta=53.443313 -> V=1.0, theta=0.0
% INFO    : Bus 45501	: V=1.0055362, theta=53.449282 -> V=1.0, theta=0.0
% INFO    : Bus 45502	: V=1.0158398, theta=53.74085 -> V=1.0, theta=0.0
% INFO    : Bus 45503	: V=1.0185054, theta=53.700888 -> V=1.0, theta=0.0
% INFO    : Bus 45504	: V=1.0136618, theta=53.351469 -> V=1.0, theta=0.0
% INFO    : Bus 45505	: V=1.0114186, theta=53.316139 -> V=1.0, theta=0.0
% INFO    : Bus 45506	: V=1.0188515, theta=53.81267 -> V=1.0, theta=0.0
% INFO    : Bus 45507	: V=1.0139187, theta=54.227813 -> V=1.0, theta=0.0
% INFO    : Bus 45508	: V=0.9944928, theta=52.884022 -> V=1.0, theta=0.0
% INFO    : Bus 45509	: V=0.9936865, theta=52.851369 -> V=1.0, theta=0.0
% INFO    : Bus 45510	: V=1.0170919, theta=52.602119 -> V=1.0, theta=0.0
% INFO    : Bus 45511	: V=0.9972996, theta=52.836687 -> V=1.0, theta=0.0
% INFO    : Bus 45512	: V=0.9965577, theta=52.868515 -> V=1.0, theta=0.0
% INFO    : Bus 45513	: V=1.0159275, theta=54.287975 -> V=1.0, theta=0.0
% INFO    : Bus 45514	: V=1.0031212, theta=53.470671 -> V=1.0, theta=0.0
% INFO    : Bus 45515	: V=1.0158717, theta=53.838743 -> V=1.0, theta=0.0
% INFO    : Bus 45516	: V=1.016077, theta=53.739235 -> V=1.0, theta=0.0
% INFO    : Bus 45517	: V=1.0179359, theta=53.447655 -> V=1.0, theta=0.0
% INFO    : Bus 45518	: V=1.0177571, theta=53.445231 -> V=1.0, theta=0.0
% INFO    : Bus 45519	: V=1.0146679, theta=53.361404 -> V=1.0, theta=0.0
% INFO    : Bus 45520	: V=1.0146508, theta=53.36209 -> V=1.0, theta=0.0
% INFO    : Bus 45521	: V=1.0174814, theta=53.70873 -> V=1.0, theta=0.0
% INFO    : Bus 45522	: V=1.0045834, theta=53.161464 -> V=1.0, theta=0.0
% INFO    : Bus 45523	: V=1.0076869, theta=53.168434 -> V=1.0, theta=0.0
% INFO    : Bus 45524	: V=1.0195783, theta=53.490941 -> V=1.0, theta=0.0
% INFO    : Bus 45525	: V=1.0179277, theta=53.437798 -> V=1.0, theta=0.0
% INFO    : Bus 45526	: V=1.0186452, theta=54.053605 -> V=1.0, theta=0.0
% INFO    : Bus 45527	: V=1.0108282, theta=53.619293 -> V=1.0, theta=0.0
% INFO    : Bus 45528	: V=1.0035979, theta=53.083582 -> V=1.0, theta=0.0
% INFO    : Bus 45529	: V=1.0160449, theta=53.246408 -> V=1.0, theta=0.0
% INFO    : Bus 45530	: V=1.0041756, theta=53.132856 -> V=1.0, theta=0.0
% INFO    : Bus 45531	: V=1.0052669, theta=53.140577 -> V=1.0, theta=0.0
% INFO    : Bus 45532	: V=1.0060767, theta=53.152782 -> V=1.0, theta=0.0
% INFO    : Bus 45533	: V=1.0154014, theta=43.855923 -> V=1.0, theta=0.0
% INFO    : Bus 45534	: V=1.0147585, theta=43.915223 -> V=1.0, theta=0.0
% INFO    : Bus 45535	: V=1.0143748, theta=43.798278 -> V=1.0, theta=0.0
% INFO    : Bus 45536	: V=1.0197809, theta=43.808729 -> V=1.0, theta=0.0
% INFO    : Bus 45537	: V=0.9923684, theta=42.227194 -> V=1.0, theta=0.0
% INFO    : Bus 45538	: V=0.9626204, theta=43.527305 -> V=1.0, theta=0.0
% INFO    : Bus 45539	: V=0.968912, theta=44.521354 -> V=1.0, theta=0.0
% INFO    : Bus 45540	: V=0.9662126, theta=43.213211 -> V=1.0, theta=0.0
% INFO    : Bus 45541	: V=0.9665116, theta=43.172167 -> V=1.0, theta=0.0
% INFO    : Bus 45542	: V=0.9722576, theta=42.976195 -> V=1.0, theta=0.0
% INFO    : Bus 45543	: V=0.9590582, theta=43.051057 -> V=1.0, theta=0.0
% INFO    : Bus 45544	: V=1.0156941, theta=54.106649 -> V=1.0, theta=0.0
% INFO    : Bus 45545	: V=1.0107548, theta=52.924454 -> V=1.0, theta=0.0
% INFO    : Bus 45546	: V=0.9994062, theta=51.264041 -> V=1.0, theta=0.0
% INFO    : Bus 45547	: V=1.0076717, theta=51.876903 -> V=1.0, theta=0.0
% INFO    : Bus 45548	: V=1.0152453, theta=53.479362 -> V=1.0, theta=0.0
% INFO    : Bus 45549	: V=1.0088802, theta=51.711453 -> V=1.0, theta=0.0
% INFO    : Bus 45550	: V=1.0060381, theta=52.387207 -> V=1.0, theta=0.0
% INFO    : Bus 45551	: V=1.0114475, theta=53.649844 -> V=1.0, theta=0.0
% INFO    : Bus 45552	: V=0.9936746, theta=53.617657 -> V=1.0, theta=0.0
% INFO    : Bus 45553	: V=1.0139357, theta=52.302131 -> V=1.0, theta=0.0
% INFO    : Bus 45554	: V=1.0054343, theta=51.744983 -> V=1.0, theta=0.0
% INFO    : Bus 45555	: V=1.0149539, theta=45.075511 -> V=1.0, theta=0.0
% INFO    : Bus 45556	: V=1.0138871, theta=45.116926 -> V=1.0, theta=0.0
% INFO    : Bus 45557	: V=1.0131086, theta=44.863565 -> V=1.0, theta=0.0
% INFO    : Bus 45558	: V=1.0196594, theta=45.228071 -> V=1.0, theta=0.0
% INFO    : Bus 45559	: V=1.0109558, theta=44.855027 -> V=1.0, theta=0.0
% INFO    : Bus 45560	: V=1.0099277, theta=44.750482 -> V=1.0, theta=0.0
% INFO    : Bus 45561	: V=1.0113709, theta=44.978369 -> V=1.0, theta=0.0
% INFO    : Bus 45562	: V=0.9932664, theta=45.831333 -> V=1.0, theta=0.0
% INFO    : Bus 45563	: V=1.012605, theta=45.07142 -> V=1.0, theta=0.0
% INFO    : Bus 45564	: V=1.0020605, theta=45.088929 -> V=1.0, theta=0.0
% INFO    : Bus 45565	: V=1.0004772, theta=44.9204 -> V=1.0, theta=0.0
% INFO    : Bus 45566	: V=0.9710101, theta=48.277984 -> V=1.0, theta=0.0
% INFO    : Bus 45567	: V=0.9738681, theta=47.815554 -> V=1.0, theta=0.0
% INFO    : Bus 45568	: V=0.985651, theta=47.051283 -> V=1.0, theta=0.0
% INFO    : Bus 45569	: V=0.9997845, theta=47.407047 -> V=1.0, theta=0.0
% INFO    : Bus 45570	: V=0.9664467, theta=47.887203 -> V=1.0, theta=0.0
% INFO    : Bus 45571	: V=0.9863357, theta=46.998247 -> V=1.0, theta=0.0
% INFO    : Bus 45572	: V=1.0017102, theta=46.910785 -> V=1.0, theta=0.0
% INFO    : Bus 45573	: V=0.9961224, theta=45.579945 -> V=1.0, theta=0.0
% INFO    : Bus 45574	: V=0.9872081, theta=37.883824 -> V=1.0, theta=0.0
% INFO    : Bus 45575	: V=0.9829549, theta=37.922172 -> V=1.0, theta=0.0
% INFO    : Bus 45576	: V=0.9611161, theta=38.222458 -> V=1.0, theta=0.0
% INFO    : Bus 45577	: V=0.9803403, theta=37.968507 -> V=1.0, theta=0.0
% INFO    : Bus 45578	: V=0.9801082, theta=37.973036 -> V=1.0, theta=0.0
% INFO    : Bus 45579	: V=0.9703194, theta=37.719742 -> V=1.0, theta=0.0
% INFO    : Bus 45580	: V=0.9760184, theta=37.138131 -> V=1.0, theta=0.0
% INFO    : Bus 45581	: V=0.9845692, theta=36.056767 -> V=1.0, theta=0.0
% INFO    : Bus 45582	: V=0.986961, theta=36.345091 -> V=1.0, theta=0.0
% INFO    : Bus 45583	: V=0.9804764, theta=36.147524 -> V=1.0, theta=0.0
% INFO    : Bus 45584	: V=0.9841122, theta=36.016469 -> V=1.0, theta=0.0
% INFO    : Bus 45585	: V=0.9884432, theta=36.011341 -> V=1.0, theta=0.0
% INFO    : Bus 45586	: V=0.9969932, theta=38.237206 -> V=1.0, theta=0.0
% INFO    : Bus 45587	: V=1.0053184, theta=38.234159 -> V=1.0, theta=0.0
% INFO    : Bus 45588	: V=0.9889314, theta=37.041715 -> V=1.0, theta=0.0
% INFO    : Bus 45589	: V=0.9873269, theta=36.148692 -> V=1.0, theta=0.0
% INFO    : Bus 45590	: V=0.9866278, theta=36.172634 -> V=1.0, theta=0.0
% INFO    : Bus 45591	: V=0.998126, theta=36.294088 -> V=1.0, theta=0.0
% INFO    : Bus 45592	: V=0.9903527, theta=35.834726 -> V=1.0, theta=0.0
% INFO    : Bus 45593	: V=0.9905751, theta=35.8267 -> V=1.0, theta=0.0
% INFO    : Bus 45594	: V=0.9896734, theta=35.823486 -> V=1.0, theta=0.0
% INFO    : Bus 45595	: V=0.9953762, theta=35.836403 -> V=1.0, theta=0.0
% INFO    : Bus 45596	: V=0.9879637, theta=35.846844 -> V=1.0, theta=0.0
% INFO    : Bus 45597	: V=0.9923122, theta=35.832222 -> V=1.0, theta=0.0
% INFO    : Bus 45598	: V=0.9924893, theta=35.83454 -> V=1.0, theta=0.0
% INFO    : Bus 45599	: V=0.9919086, theta=35.831817 -> V=1.0, theta=0.0
% INFO    : Bus 45600	: V=0.996121, theta=35.822963 -> V=1.0, theta=0.0
% INFO    : Bus 45601	: V=0.9915311, theta=35.74552 -> V=1.0, theta=0.0
% INFO    : Bus 45602	: V=0.9904546, theta=35.790571 -> V=1.0, theta=0.0
% INFO    : Bus 45603	: V=0.9894384, theta=35.800208 -> V=1.0, theta=0.0
% INFO    : Bus 45604	: V=0.9910471, theta=35.791285 -> V=1.0, theta=0.0
% INFO    : Bus 45605	: V=1.0018907, theta=35.727296 -> V=1.0, theta=0.0
% INFO    : Bus 45606	: V=0.9961244, theta=35.795872 -> V=1.0, theta=0.0
% INFO    : Bus 45607	: V=0.9986996, theta=35.849794 -> V=1.0, theta=0.0
% INFO    : Bus 45608	: V=0.9924984, theta=35.831092 -> V=1.0, theta=0.0
% INFO    : Bus 45609	: V=0.9992124, theta=35.904647 -> V=1.0, theta=0.0
% INFO    : Bus 45610	: V=0.9945263, theta=35.822539 -> V=1.0, theta=0.0
% INFO    : Bus 45611	: V=1.0003652, theta=35.922679 -> V=1.0, theta=0.0
% INFO    : Bus 45612	: V=0.9934042, theta=35.830658 -> V=1.0, theta=0.0
% INFO    : Bus 45613	: V=1.0022889, theta=35.948073 -> V=1.0, theta=0.0
% INFO    : Bus 45614	: V=1.0016479, theta=35.93978 -> V=1.0, theta=0.0
% INFO    : Bus 45615	: V=1.0021796, theta=35.967776 -> V=1.0, theta=0.0
% INFO    : Bus 45616	: V=1.0013401, theta=35.976018 -> V=1.0, theta=0.0
% INFO    : Bus 45617	: V=1.0008085, theta=35.980757 -> V=1.0, theta=0.0
% INFO    : Bus 45618	: V=0.9927997, theta=35.831741 -> V=1.0, theta=0.0
% INFO    : Bus 45619	: V=0.999459, theta=35.927354 -> V=1.0, theta=0.0
% INFO    : Bus 45620	: V=0.9949154, theta=35.91366 -> V=1.0, theta=0.0
% INFO    : Bus 45621	: V=0.994687, theta=35.903247 -> V=1.0, theta=0.0
% INFO    : Bus 45622	: V=1.0034025, theta=35.960441 -> V=1.0, theta=0.0
% INFO    : Bus 45623	: V=1.0043851, theta=35.970037 -> V=1.0, theta=0.0
% INFO    : Bus 45624	: V=0.9976795, theta=35.79574 -> V=1.0, theta=0.0
% INFO    : Bus 45625	: V=0.9971241, theta=35.803853 -> V=1.0, theta=0.0
% INFO    : Bus 45626	: V=1.00579, theta=35.98233 -> V=1.0, theta=0.0
% INFO    : Bus 45627	: V=1.0064273, theta=35.984861 -> V=1.0, theta=0.0
% INFO    : Bus 45628	: V=0.9987333, theta=35.804106 -> V=1.0, theta=0.0
% INFO    : Bus 45629	: V=0.9970754, theta=35.879803 -> V=1.0, theta=0.0
% INFO    : Bus 45630	: V=1.005939, theta=36.044202 -> V=1.0, theta=0.0
% INFO    : Bus 45631	: V=1.002915, theta=36.207354 -> V=1.0, theta=0.0
% INFO    : Bus 45632	: V=1.0038737, theta=36.143279 -> V=1.0, theta=0.0
% INFO    : Bus 45633	: V=0.9949326, theta=36.005893 -> V=1.0, theta=0.0
% INFO    : Bus 45634	: V=0.9937007, theta=36.031299 -> V=1.0, theta=0.0
% INFO    : Bus 45635	: V=0.9925039, theta=36.036049 -> V=1.0, theta=0.0
% INFO    : Bus 45636	: V=0.9939331, theta=36.037449 -> V=1.0, theta=0.0
% INFO    : Bus 45637	: V=0.994437, theta=36.034056 -> V=1.0, theta=0.0
% INFO    : Bus 45638	: V=1.011355, theta=36.587445 -> V=1.0, theta=0.0
% INFO    : Bus 45639	: V=0.9946728, theta=35.969381 -> V=1.0, theta=0.0
% INFO    : Bus 45640	: V=1.0007282, theta=36.350275 -> V=1.0, theta=0.0
% INFO    : Bus 45641	: V=0.9946663, theta=35.901345 -> V=1.0, theta=0.0
% INFO    : Bus 45642	: V=1.0027474, theta=36.228511 -> V=1.0, theta=0.0
% INFO    : Bus 45643	: V=0.9943206, theta=35.998246 -> V=1.0, theta=0.0
% INFO    : Bus 45644	: V=0.9952946, theta=35.989137 -> V=1.0, theta=0.0
% INFO    : Bus 45645	: V=0.9940137, theta=36.010969 -> V=1.0, theta=0.0
% INFO    : Bus 45646	: V=0.9951087, theta=35.920018 -> V=1.0, theta=0.0
% INFO    : Bus 45647	: V=1.002965, theta=36.297359 -> V=1.0, theta=0.0
% INFO    : Bus 45648	: V=0.993029, theta=35.841354 -> V=1.0, theta=0.0
% INFO    : Bus 45649	: V=0.992944, theta=35.828404 -> V=1.0, theta=0.0
% INFO    : Bus 45650	: V=0.9958437, theta=35.960279 -> V=1.0, theta=0.0
% INFO    : Bus 45651	: V=0.994767, theta=35.98801 -> V=1.0, theta=0.0
% INFO    : Bus 45652	: V=0.9949163, theta=35.968321 -> V=1.0, theta=0.0
% INFO    : Bus 45653	: V=1.0118401, theta=36.336793 -> V=1.0, theta=0.0
% INFO    : Bus 45654	: V=1.0037683, theta=36.213295 -> V=1.0, theta=0.0
% INFO    : Bus 45655	: V=0.9948998, theta=35.847469 -> V=1.0, theta=0.0
% INFO    : Bus 45656	: V=0.992765, theta=35.762348 -> V=1.0, theta=0.0
% INFO    : Bus 45657	: V=0.9985247, theta=35.851115 -> V=1.0, theta=0.0
% INFO    : Bus 45658	: V=0.9961328, theta=35.767596 -> V=1.0, theta=0.0
% INFO    : Bus 45659	: V=0.9949054, theta=35.845111 -> V=1.0, theta=0.0
% INFO    : Bus 45660	: V=0.9912138, theta=35.7602 -> V=1.0, theta=0.0
% INFO    : Bus 45661	: V=0.9815352, theta=35.886252 -> V=1.0, theta=0.0
% INFO    : Bus 45662	: V=0.9875327, theta=35.871536 -> V=1.0, theta=0.0
% INFO    : Bus 45663	: V=0.9870098, theta=35.90036 -> V=1.0, theta=0.0
% INFO    : Bus 45664	: V=0.9868457, theta=35.972191 -> V=1.0, theta=0.0
% INFO    : Bus 45665	: V=0.9935629, theta=36.307598 -> V=1.0, theta=0.0
% INFO    : Bus 45666	: V=0.9916409, theta=36.313431 -> V=1.0, theta=0.0
% INFO    : Bus 45667	: V=0.9824018, theta=36.065734 -> V=1.0, theta=0.0
% INFO    : Bus 45668	: V=1.003498, theta=36.370472 -> V=1.0, theta=0.0
% INFO    : Bus 45669	: V=1.0009228, theta=36.373245 -> V=1.0, theta=0.0
% INFO    : Bus 45670	: V=0.99035, theta=36.30758 -> V=1.0, theta=0.0
% INFO    : Bus 45671	: V=0.9902628, theta=36.275257 -> V=1.0, theta=0.0
% INFO    : Bus 45672	: V=0.9908027, theta=36.273088 -> V=1.0, theta=0.0
% INFO    : Bus 45673	: V=0.990501, theta=36.257514 -> V=1.0, theta=0.0
% INFO    : Bus 45674	: V=0.9926597, theta=36.251085 -> V=1.0, theta=0.0
% INFO    : Bus 45675	: V=0.991619, theta=36.249314 -> V=1.0, theta=0.0
% INFO    : Bus 45676	: V=0.992091, theta=36.177136 -> V=1.0, theta=0.0
% INFO    : Bus 45677	: V=1.0125956, theta=36.542267 -> V=1.0, theta=0.0
% INFO    : Bus 45678	: V=1.0131454, theta=37.419994 -> V=1.0, theta=0.0
% INFO    : Bus 45679	: V=1.0073521, theta=36.341179 -> V=1.0, theta=0.0
% INFO    : Bus 45680	: V=1.0124146, theta=36.157945 -> V=1.0, theta=0.0
% INFO    : Bus 45681	: V=0.9985887, theta=35.887267 -> V=1.0, theta=0.0
% INFO    : Bus 45682	: V=0.9983489, theta=35.838002 -> V=1.0, theta=0.0
% INFO    : Bus 45683	: V=1.0076031, theta=36.026783 -> V=1.0, theta=0.0
% INFO    : Bus 45684	: V=1.0009527, theta=35.676567 -> V=1.0, theta=0.0
% INFO    : Bus 45685	: V=0.9997021, theta=35.72913 -> V=1.0, theta=0.0
% INFO    : Bus 45686	: V=0.9990554, theta=35.771577 -> V=1.0, theta=0.0
% INFO    : Bus 45687	: V=0.997122, theta=35.300674 -> V=1.0, theta=0.0
% INFO    : Bus 45688	: V=0.9800385, theta=35.72201 -> V=1.0, theta=0.0
% INFO    : Bus 45689	: V=0.9786208, theta=35.764938 -> V=1.0, theta=0.0
% INFO    : Bus 45690	: V=0.976731, theta=35.982575 -> V=1.0, theta=0.0
% INFO    : Bus 45691	: V=0.9782402, theta=35.931143 -> V=1.0, theta=0.0
% INFO    : Bus 45692	: V=0.9799319, theta=35.875544 -> V=1.0, theta=0.0
% INFO    : Bus 45693	: V=0.9894199, theta=36.327344 -> V=1.0, theta=0.0
% INFO    : Bus 45694	: V=0.9833318, theta=36.177258 -> V=1.0, theta=0.0
% INFO    : Bus 45695	: V=0.9829126, theta=36.233924 -> V=1.0, theta=0.0
% INFO    : Bus 45696	: V=0.996685, theta=35.710906 -> V=1.0, theta=0.0
% INFO    : Bus 45697	: V=1.0013189, theta=36.053299 -> V=1.0, theta=0.0
% INFO    : Bus 45698	: V=1.0167642, theta=36.149891 -> V=1.0, theta=0.0
% INFO    : Bus 45699	: V=1.0106616, theta=36.764903 -> V=1.0, theta=0.0
% INFO    : Bus 45700	: V=1.0019229, theta=37.888989 -> V=1.0, theta=0.0
% INFO    : Bus 45701	: V=1.004768, theta=37.104844 -> V=1.0, theta=0.0
% INFO    : Bus 45702	: V=0.9771908, theta=37.556186 -> V=1.0, theta=0.0
% INFO    : Bus 45703	: V=0.988592, theta=36.298397 -> V=1.0, theta=0.0
% INFO    : Bus 45704	: V=1.0030372, theta=37.232075 -> V=1.0, theta=0.0
% INFO    : Bus 45705	: V=0.9925778, theta=36.424284 -> V=1.0, theta=0.0
% INFO    : Bus 45706	: V=0.9991609, theta=36.242002 -> V=1.0, theta=0.0
% INFO    : Bus 45707	: V=0.9916557, theta=36.319463 -> V=1.0, theta=0.0
% INFO    : Bus 45708	: V=0.997345, theta=35.984073 -> V=1.0, theta=0.0
% INFO    : Bus 45709	: V=1.0020924, theta=36.191289 -> V=1.0, theta=0.0
% INFO    : Bus 45710	: V=1.0018546, theta=36.11576 -> V=1.0, theta=0.0
% INFO    : Bus 45711	: V=1.0162815, theta=35.039837 -> V=1.0, theta=0.0
% INFO    : Bus 45712	: V=1.0079424, theta=34.5669 -> V=1.0, theta=0.0
% INFO    : Bus 45713	: V=1.0044237, theta=34.682006 -> V=1.0, theta=0.0
% INFO    : Bus 45714	: V=1.0019324, theta=35.403437 -> V=1.0, theta=0.0
% INFO    : Bus 45715	: V=1.0032172, theta=36.095504 -> V=1.0, theta=0.0
% INFO    : Bus 45716	: V=1.0069198, theta=35.347888 -> V=1.0, theta=0.0
% INFO    : Bus 45717	: V=1.0073574, theta=35.330815 -> V=1.0, theta=0.0
% INFO    : Bus 45718	: V=1.0098728, theta=55.263264 -> V=1.0, theta=0.0
% INFO    : Bus 45719	: V=1.0062015, theta=56.1388 -> V=1.0, theta=0.0
% INFO    : Bus 45720	: V=1.0077973, theta=56.089356 -> V=1.0, theta=0.0
% INFO    : Bus 45721	: V=1.0025665, theta=55.523079 -> V=1.0, theta=0.0
% INFO    : Bus 45722	: V=1.0019807, theta=55.544557 -> V=1.0, theta=0.0
% INFO    : Bus 45723	: V=1.0097384, theta=55.316772 -> V=1.0, theta=0.0
% INFO    : Bus 45724	: V=1.0145228, theta=56.180322 -> V=1.0, theta=0.0
% INFO    : Bus 45725	: V=1.0003734, theta=55.590604 -> V=1.0, theta=0.0
% INFO    : Bus 45726	: V=1.0062613, theta=55.710584 -> V=1.0, theta=0.0
% INFO    : Bus 45727	: V=0.9994385, theta=44.879904 -> V=1.0, theta=0.0
% INFO    : Bus 45728	: V=1.0009847, theta=44.945285 -> V=1.0, theta=0.0
% INFO    : Bus 45729	: V=0.9973334, theta=44.837328 -> V=1.0, theta=0.0
% INFO    : Bus 45730	: V=0.9976789, theta=44.827406 -> V=1.0, theta=0.0
% INFO    : Bus 45731	: V=1.0064865, theta=44.92224 -> V=1.0, theta=0.0
% INFO    : Bus 45732	: V=1.023677, theta=46.093614 -> V=1.0, theta=0.0
% INFO    : Bus 45733	: V=1.003115, theta=45.027453 -> V=1.0, theta=0.0
% INFO    : Bus 45734	: V=1.009722, theta=45.664254 -> V=1.0, theta=0.0
% INFO    : Bus 45735	: V=1.0093785, theta=45.123648 -> V=1.0, theta=0.0
% INFO    : Bus 45736	: V=1.009949, theta=46.376108 -> V=1.0, theta=0.0
% INFO    : Bus 45737	: V=0.9979504, theta=45.067096 -> V=1.0, theta=0.0
% INFO    : Bus 45738	: V=0.9851334, theta=44.952943 -> V=1.0, theta=0.0
% INFO    : Bus 45739	: V=0.9874539, theta=44.493088 -> V=1.0, theta=0.0
% INFO    : Bus 45740	: V=0.9842409, theta=44.070376 -> V=1.0, theta=0.0
% INFO    : Bus 45741	: V=1.0177988, theta=45.167328 -> V=1.0, theta=0.0
% INFO    : Bus 45742	: V=1.0100622, theta=44.473198 -> V=1.0, theta=0.0
% INFO    : Bus 45743	: V=1.0016249, theta=44.398229 -> V=1.0, theta=0.0
% INFO    : Bus 45744	: V=0.991113, theta=44.083903 -> V=1.0, theta=0.0
% INFO    : Bus 45745	: V=0.9895749, theta=44.169607 -> V=1.0, theta=0.0
% INFO    : Bus 45746	: V=0.9895651, theta=44.169339 -> V=1.0, theta=0.0
% INFO    : Bus 45747	: V=0.9982422, theta=44.757303 -> V=1.0, theta=0.0
% INFO    : Bus 45748	: V=1.0009993, theta=44.519584 -> V=1.0, theta=0.0
% INFO    : Bus 45749	: V=1.0079962, theta=44.6016 -> V=1.0, theta=0.0
% INFO    : Bus 45750	: V=1.0180769, theta=43.895471 -> V=1.0, theta=0.0
% INFO    : Bus 45751	: V=1.0015026, theta=44.418718 -> V=1.0, theta=0.0
% INFO    : Bus 45752	: V=1.0123007, theta=44.91607 -> V=1.0, theta=0.0
% INFO    : Bus 45753	: V=1.0104133, theta=44.94942 -> V=1.0, theta=0.0
% INFO    : Bus 45754	: V=1.0103848, theta=44.794843 -> V=1.0, theta=0.0
% INFO    : Bus 45755	: V=1.003415, theta=44.487109 -> V=1.0, theta=0.0
% INFO    : Bus 45756	: V=1.007331, theta=44.415423 -> V=1.0, theta=0.0
% INFO    : Bus 45757	: V=1.0035344, theta=44.470447 -> V=1.0, theta=0.0
% INFO    : Bus 45758	: V=1.0072319, theta=44.421726 -> V=1.0, theta=0.0
% INFO    : Bus 45759	: V=0.9999981, theta=44.506743 -> V=1.0, theta=0.0
% INFO    : Bus 45760	: V=1.0031804, theta=44.518417 -> V=1.0, theta=0.0
% INFO    : Bus 45761	: V=1.0013379, theta=44.503868 -> V=1.0, theta=0.0
% INFO    : Bus 45762	: V=1.0120483, theta=44.859722 -> V=1.0, theta=0.0
% INFO    : Bus 45763	: V=1.0118135, theta=44.874955 -> V=1.0, theta=0.0
% INFO    : Bus 45764	: V=1.0129977, theta=44.915948 -> V=1.0, theta=0.0
% INFO    : Bus 45765	: V=1.0133607, theta=44.100013 -> V=1.0, theta=0.0
% INFO    : Bus 45766	: V=1.0069822, theta=44.425422 -> V=1.0, theta=0.0
% INFO    : Bus 45767	: V=0.993835, theta=52.886987 -> V=1.0, theta=0.0
% INFO    : Bus 45768	: V=0.9923415, theta=52.935795 -> V=1.0, theta=0.0
% INFO    : Bus 45769	: V=1.0072771, theta=38.808512 -> V=1.0, theta=0.0
% INFO    : Bus 45770	: V=1.0169636, theta=38.9368 -> V=1.0, theta=0.0
% INFO    : Bus 45771	: V=1.0081415, theta=38.888271 -> V=1.0, theta=0.0
% INFO    : Bus 45772	: V=1.0079162, theta=38.896488 -> V=1.0, theta=0.0
% INFO    : Bus 45773	: V=1.0068419, theta=38.81407 -> V=1.0, theta=0.0
% INFO    : Bus 45774	: V=1.0191102, theta=39.209814 -> V=1.0, theta=0.0
% INFO    : Bus 45775	: V=1.0066316, theta=38.83477 -> V=1.0, theta=0.0
% INFO    : Bus 45776	: V=1.0067626, theta=38.833882 -> V=1.0, theta=0.0
% INFO    : Bus 45777	: V=1.0066377, theta=38.840584 -> V=1.0, theta=0.0
% INFO    : Bus 45778	: V=1.0068691, theta=38.839159 -> V=1.0, theta=0.0
% INFO    : Bus 45779	: V=1.0052315, theta=38.833266 -> V=1.0, theta=0.0
% INFO    : Bus 45780	: V=0.9937686, theta=39.144904 -> V=1.0, theta=0.0
% INFO    : Bus 45781	: V=0.9746547, theta=39.960024 -> V=1.0, theta=0.0
% INFO    : Bus 45782	: V=0.9712105, theta=40.3624 -> V=1.0, theta=0.0
% INFO    : Bus 45783	: V=0.9809328, theta=38.976542 -> V=1.0, theta=0.0
% INFO    : Bus 45784	: V=1.0091479, theta=39.007612 -> V=1.0, theta=0.0
% INFO    : Bus 45785	: V=1.0205122, theta=37.351034 -> V=1.0, theta=0.0
% INFO    : Bus 45786	: V=1.0164826, theta=38.956131 -> V=1.0, theta=0.0
% INFO    : Bus 45787	: V=1.0120526, theta=38.707279 -> V=1.0, theta=0.0
% INFO    : Bus 45788	: V=1.0155675, theta=35.769087 -> V=1.0, theta=0.0
% INFO    : Bus 45789	: V=0.9933505, theta=51.745029 -> V=1.0, theta=0.0
% INFO    : Bus 45790	: V=0.9927982, theta=52.3237 -> V=1.0, theta=0.0
% INFO    : Bus 45791	: V=1.0011968, theta=51.504307 -> V=1.0, theta=0.0
% INFO    : Bus 45792	: V=0.9882299, theta=51.636175 -> V=1.0, theta=0.0
% INFO    : Bus 45793	: V=0.9913649, theta=36.654598 -> V=1.0, theta=0.0
% INFO    : Bus 45794	: V=0.9864374, theta=36.617059 -> V=1.0, theta=0.0
% INFO    : Bus 45795	: V=0.9930828, theta=36.136163 -> V=1.0, theta=0.0
% INFO    : Bus 45796	: V=1.0030955, theta=36.036191 -> V=1.0, theta=0.0
% INFO    : Bus 45797	: V=1.0108945, theta=35.853025 -> V=1.0, theta=0.0
% INFO    : Bus 45798	: V=0.9972803, theta=35.065442 -> V=1.0, theta=0.0
% INFO    : Bus 45799	: V=0.9985243, theta=35.162726 -> V=1.0, theta=0.0
% INFO    : Bus 45800	: V=1.0035832, theta=35.223696 -> V=1.0, theta=0.0
% INFO    : Bus 45801	: V=1.0029884, theta=35.007793 -> V=1.0, theta=0.0
% INFO    : Bus 45802	: V=1.0028495, theta=35.011613 -> V=1.0, theta=0.0
% INFO    : Bus 45803	: V=1.0050039, theta=35.018223 -> V=1.0, theta=0.0
% INFO    : Bus 45804	: V=0.9993354, theta=34.678474 -> V=1.0, theta=0.0
% INFO    : Bus 45805	: V=1.0002703, theta=35.057869 -> V=1.0, theta=0.0
% INFO    : Bus 45806	: V=0.9986347, theta=34.827417 -> V=1.0, theta=0.0
% INFO    : Bus 45807	: V=1.0008361, theta=34.515482 -> V=1.0, theta=0.0
% INFO    : Bus 45808	: V=0.9927255, theta=34.184421 -> V=1.0, theta=0.0
% INFO    : Bus 45809	: V=0.9921459, theta=34.189842 -> V=1.0, theta=0.0
% INFO    : Bus 45810	: V=0.99281, theta=34.223505 -> V=1.0, theta=0.0
% INFO    : Bus 45811	: V=1.0015725, theta=34.223802 -> V=1.0, theta=0.0
% INFO    : Bus 45812	: V=1.0005234, theta=34.143062 -> V=1.0, theta=0.0
% INFO    : Bus 45813	: V=0.97493, theta=43.296458 -> V=1.0, theta=0.0
% INFO    : Bus 45814	: V=0.9662604, theta=42.767117 -> V=1.0, theta=0.0
% INFO    : Bus 45815	: V=0.9683529, theta=39.984901 -> V=1.0, theta=0.0
% INFO    : Bus 45816	: V=0.9711461, theta=39.904884 -> V=1.0, theta=0.0
% INFO    : Bus 45817	: V=0.9638507, theta=39.035329 -> V=1.0, theta=0.0
% INFO    : Bus 45818	: V=0.970349, theta=38.539817 -> V=1.0, theta=0.0
% INFO    : Bus 45819	: V=0.9866281, theta=35.513701 -> V=1.0, theta=0.0
% INFO    : Bus 45820	: V=0.9931478, theta=35.690165 -> V=1.0, theta=0.0
% INFO    : Bus 45821	: V=0.9989272, theta=35.034061 -> V=1.0, theta=0.0
% INFO    : Bus 45822	: V=0.989305, theta=35.134261 -> V=1.0, theta=0.0
% INFO    : Bus 45823	: V=0.9909314, theta=35.004888 -> V=1.0, theta=0.0
% INFO    : Bus 45824	: V=0.9927327, theta=35.00323 -> V=1.0, theta=0.0
% INFO    : Bus 45825	: V=0.9822753, theta=49.323263 -> V=1.0, theta=0.0
% INFO    : Bus 45826	: V=0.9807241, theta=49.376714 -> V=1.0, theta=0.0
% INFO    : Bus 45827	: V=0.9712768, theta=48.610989 -> V=1.0, theta=0.0
% INFO    : Bus 45828	: V=0.9948648, theta=45.935892 -> V=1.0, theta=0.0
% INFO    : Bus 45829	: V=0.9994265, theta=43.940622 -> V=1.0, theta=0.0
% INFO    : Bus 45830	: V=0.9978786, theta=43.918256 -> V=1.0, theta=0.0
% INFO    : Bus 45831	: V=0.9829461, theta=43.302287 -> V=1.0, theta=0.0
% INFO    : Bus 45832	: V=1.0008853, theta=43.796554 -> V=1.0, theta=0.0
% INFO    : Bus 45833	: V=1.0181232, theta=35.542807 -> V=1.0, theta=0.0
% INFO    : Bus 45834	: V=1.0077561, theta=35.319887 -> V=1.0, theta=0.0
% INFO    : Bus 45835	: V=1.0090326, theta=35.334015 -> V=1.0, theta=0.0
% INFO    : Bus 45836	: V=1.0105073, theta=36.018739 -> V=1.0, theta=0.0
% INFO    : Bus 45837	: V=1.0120028, theta=36.077255 -> V=1.0, theta=0.0
% INFO    : Bus 45838	: V=1.0068596, theta=35.855024 -> V=1.0, theta=0.0
% INFO    : Bus 45839	: V=1.0133324, theta=36.17675 -> V=1.0, theta=0.0
% INFO    : Bus 45840	: V=1.0135067, theta=35.70471 -> V=1.0, theta=0.0
% INFO    : Bus 45841	: V=1.0072558, theta=34.419001 -> V=1.0, theta=0.0
% INFO    : Bus 45842	: V=1.0065545, theta=34.782106 -> V=1.0, theta=0.0
% INFO    : Bus 45843	: V=1.0115732, theta=35.848716 -> V=1.0, theta=0.0
% INFO    : Bus 45844	: V=1.0116895, theta=35.785362 -> V=1.0, theta=0.0
% INFO    : Bus 45845	: V=1.0128741, theta=36.071922 -> V=1.0, theta=0.0
% INFO    : Bus 45846	: V=1.0115474, theta=35.492756 -> V=1.0, theta=0.0
% INFO    : Bus 45847	: V=1.0116118, theta=35.825054 -> V=1.0, theta=0.0
% INFO    : Bus 45848	: V=1.0113367, theta=35.690048 -> V=1.0, theta=0.0
% INFO    : Bus 45849	: V=1.0082556, theta=35.565279 -> V=1.0, theta=0.0
% INFO    : Bus 45850	: V=1.0107939, theta=34.623187 -> V=1.0, theta=0.0
% INFO    : Bus 45851	: V=1.0168916, theta=35.632376 -> V=1.0, theta=0.0
% INFO    : Bus 45852	: V=1.0167259, theta=35.026493 -> V=1.0, theta=0.0
% INFO    : Bus 45853	: V=0.9796512, theta=39.560841 -> V=1.0, theta=0.0
% INFO    : Bus 45854	: V=0.9694019, theta=40.045616 -> V=1.0, theta=0.0
% INFO    : Bus 45855	: V=0.9715855, theta=39.558588 -> V=1.0, theta=0.0
% INFO    : Bus 45856	: V=0.9700033, theta=39.367667 -> V=1.0, theta=0.0
% INFO    : Bus 45857	: V=0.9796645, theta=39.636788 -> V=1.0, theta=0.0
% INFO    : Bus 45858	: V=0.9807678, theta=39.344826 -> V=1.0, theta=0.0
% INFO    : Bus 45859	: V=0.971678, theta=38.8135 -> V=1.0, theta=0.0
% INFO    : Bus 45860	: V=1.0119629, theta=29.008454 -> V=1.0, theta=0.0
% INFO    : Bus 45861	: V=1.0080448, theta=28.066047 -> V=1.0, theta=0.0
% INFO    : Bus 45862	: V=1.0078776, theta=28.062142 -> V=1.0, theta=0.0
% INFO    : Bus 45863	: V=1.0079777, theta=27.884741 -> V=1.0, theta=0.0
% INFO    : Bus 45864	: V=1.0057128, theta=28.323632 -> V=1.0, theta=0.0
% INFO    : Bus 45865	: V=1.011889, theta=28.812865 -> V=1.0, theta=0.0
% INFO    : Bus 45866	: V=1.0118647, theta=28.709406 -> V=1.0, theta=0.0
% INFO    : Bus 45867	: V=1.0042198, theta=27.750158 -> V=1.0, theta=0.0
% INFO    : Bus 45868	: V=1.0038115, theta=27.733805 -> V=1.0, theta=0.0
% INFO    : Bus 45869	: V=1.0032761, theta=27.684024 -> V=1.0, theta=0.0
% INFO    : Bus 45870	: V=1.0041066, theta=27.656137 -> V=1.0, theta=0.0
% INFO    : Bus 45871	: V=1.0047732, theta=27.729234 -> V=1.0, theta=0.0
% INFO    : Bus 45872	: V=1.0119631, theta=28.665881 -> V=1.0, theta=0.0
% INFO    : Bus 45873	: V=1.0120449, theta=28.627907 -> V=1.0, theta=0.0
% INFO    : Bus 45874	: V=1.0033807, theta=27.709956 -> V=1.0, theta=0.0
% INFO    : Bus 45875	: V=1.0037245, theta=27.612347 -> V=1.0, theta=0.0
% INFO    : Bus 45876	: V=1.0033679, theta=27.573949 -> V=1.0, theta=0.0
% INFO    : Bus 45877	: V=1.0021728, theta=27.622942 -> V=1.0, theta=0.0
% INFO    : Bus 45878	: V=1.0021484, theta=27.622341 -> V=1.0, theta=0.0
% INFO    : Bus 45879	: V=0.9996583, theta=26.91971 -> V=1.0, theta=0.0
% INFO    : Bus 45880	: V=1.0021243, theta=27.43194 -> V=1.0, theta=0.0
% INFO    : Bus 45881	: V=1.0029562, theta=27.527502 -> V=1.0, theta=0.0
% INFO    : Bus 45882	: V=1.0028307, theta=27.494758 -> V=1.0, theta=0.0
% INFO    : Bus 45883	: V=1.0035179, theta=27.55664 -> V=1.0, theta=0.0
% INFO    : Bus 45884	: V=1.012228, theta=28.543142 -> V=1.0, theta=0.0
% INFO    : Bus 45885	: V=1.0034152, theta=27.69742 -> V=1.0, theta=0.0
% INFO    : Bus 45886	: V=1.0035928, theta=27.506281 -> V=1.0, theta=0.0
% INFO    : Bus 45887	: V=1.0007972, theta=27.493594 -> V=1.0, theta=0.0
% INFO    : Bus 45888	: V=0.9943465, theta=28.081668 -> V=1.0, theta=0.0
% INFO    : Bus 45889	: V=0.98912, theta=27.734163 -> V=1.0, theta=0.0
% INFO    : Bus 45890	: V=0.9881103, theta=27.537447 -> V=1.0, theta=0.0
% INFO    : Bus 45891	: V=0.9925246, theta=27.765905 -> V=1.0, theta=0.0
% INFO    : Bus 45892	: V=0.9903442, theta=27.457662 -> V=1.0, theta=0.0
% INFO    : Bus 45893	: V=0.9836138, theta=28.896808 -> V=1.0, theta=0.0
% INFO    : Bus 45894	: V=0.9845277, theta=28.289405 -> V=1.0, theta=0.0
% INFO    : Bus 45895	: V=0.999635, theta=55.037668 -> V=1.0, theta=0.0
% INFO    : Bus 45896	: V=0.9992809, theta=55.235226 -> V=1.0, theta=0.0
% INFO    : Bus 45897	: V=1.0142552, theta=55.000764 -> V=1.0, theta=0.0
% INFO    : Bus 45898	: V=1.0176911, theta=54.966889 -> V=1.0, theta=0.0
% INFO    : Bus 45899	: V=0.9971067, theta=41.696424 -> V=1.0, theta=0.0
% INFO    : Bus 45900	: V=1.0145619, theta=42.313526 -> V=1.0, theta=0.0
% INFO    : Bus 45901	: V=0.9950518, theta=41.544453 -> V=1.0, theta=0.0
% INFO    : Bus 45902	: V=0.992654, theta=41.490109 -> V=1.0, theta=0.0
% INFO    : Bus 45903	: V=0.9970659, theta=41.551083 -> V=1.0, theta=0.0
% INFO    : Bus 45904	: V=0.989487, theta=41.50124 -> V=1.0, theta=0.0
% INFO    : Bus 45905	: V=0.9905769, theta=41.496245 -> V=1.0, theta=0.0
% INFO    : Bus 45906	: V=0.9915269, theta=41.491513 -> V=1.0, theta=0.0
% INFO    : Bus 45907	: V=0.9981686, theta=41.574313 -> V=1.0, theta=0.0
% INFO    : Bus 45908	: V=0.989954, theta=41.473018 -> V=1.0, theta=0.0
% INFO    : Bus 45909	: V=0.989472, theta=41.458206 -> V=1.0, theta=0.0
% INFO    : Bus 45910	: V=0.9885326, theta=41.460931 -> V=1.0, theta=0.0
% INFO    : Bus 45911	: V=0.9890073, theta=41.433686 -> V=1.0, theta=0.0
% INFO    : Bus 45912	: V=0.9796092, theta=41.931659 -> V=1.0, theta=0.0
% INFO    : Bus 45913	: V=0.9949197, theta=41.529622 -> V=1.0, theta=0.0
% INFO    : Bus 45914	: V=0.9830378, theta=41.809509 -> V=1.0, theta=0.0
% INFO    : Bus 45915	: V=0.9829015, theta=41.81808 -> V=1.0, theta=0.0
% INFO    : Bus 45916	: V=0.9847037, theta=41.710447 -> V=1.0, theta=0.0
% INFO    : Bus 45917	: V=0.9924555, theta=41.56132 -> V=1.0, theta=0.0
% INFO    : Bus 45918	: V=0.9932583, theta=41.598834 -> V=1.0, theta=0.0
% INFO    : Bus 45919	: V=0.9927382, theta=41.675324 -> V=1.0, theta=0.0
% INFO    : Bus 45920	: V=0.9853448, theta=41.485959 -> V=1.0, theta=0.0
% INFO    : Bus 45921	: V=0.9844374, theta=41.519125 -> V=1.0, theta=0.0
% INFO    : Bus 45922	: V=0.987079, theta=41.523513 -> V=1.0, theta=0.0
% INFO    : Bus 45923	: V=0.9985521, theta=41.433815 -> V=1.0, theta=0.0
% INFO    : Bus 45924	: V=0.9935925, theta=34.311829 -> V=1.0, theta=0.0
% INFO    : Bus 45925	: V=0.9937298, theta=34.936115 -> V=1.0, theta=0.0
% INFO    : Bus 45926	: V=0.9977744, theta=34.88079 -> V=1.0, theta=0.0
% INFO    : Bus 45927	: V=0.9964281, theta=34.602702 -> V=1.0, theta=0.0
% INFO    : Bus 45928	: V=0.9963136, theta=34.215215 -> V=1.0, theta=0.0
% INFO    : Bus 45929	: V=0.980486, theta=51.114984 -> V=1.0, theta=0.0
% INFO    : Bus 45930	: V=0.9677857, theta=51.108611 -> V=1.0, theta=0.0
% INFO    : Bus 45931	: V=0.9572066, theta=51.502296 -> V=1.0, theta=0.0
% INFO    : Bus 45932	: V=0.9550767, theta=52.279727 -> V=1.0, theta=0.0
% INFO    : Bus 45933	: V=0.9621326, theta=51.136958 -> V=1.0, theta=0.0
% INFO    : Bus 45934	: V=0.960104, theta=51.201451 -> V=1.0, theta=0.0
% INFO    : Bus 45935	: V=0.9916039, theta=50.152548 -> V=1.0, theta=0.0
% INFO    : Bus 45936	: V=0.9839921, theta=50.06337 -> V=1.0, theta=0.0
% INFO    : Bus 45937	: V=0.9775072, theta=49.917583 -> V=1.0, theta=0.0
% INFO    : Bus 45938	: V=0.9794675, theta=49.451257 -> V=1.0, theta=0.0
% INFO    : Bus 45939	: V=0.9951281, theta=50.272469 -> V=1.0, theta=0.0
% INFO    : Bus 45940	: V=0.9872574, theta=49.936019 -> V=1.0, theta=0.0
% INFO    : Bus 45941	: V=0.9932623, theta=50.134932 -> V=1.0, theta=0.0
% INFO    : Bus 45942	: V=0.9841975, theta=49.74714 -> V=1.0, theta=0.0
% INFO    : Bus 45943	: V=0.9863604, theta=49.861817 -> V=1.0, theta=0.0
% INFO    : Bus 45944	: V=0.9929043, theta=50.05021 -> V=1.0, theta=0.0
% INFO    : Bus 45945	: V=1.0171726, theta=55.677267 -> V=1.0, theta=0.0
% INFO    : Bus 45946	: V=1.013922, theta=55.597792 -> V=1.0, theta=0.0
% INFO    : Bus 45947	: V=1.0167188, theta=55.582066 -> V=1.0, theta=0.0
% INFO    : Bus 45948	: V=1.0166158, theta=55.686608 -> V=1.0, theta=0.0
% INFO    : Bus 45949	: V=1.0164995, theta=55.691727 -> V=1.0, theta=0.0
% INFO    : Bus 45950	: V=1.0165165, theta=55.69313 -> V=1.0, theta=0.0
% INFO    : Bus 45951	: V=1.0166074, theta=55.703041 -> V=1.0, theta=0.0
% INFO    : Bus 45952	: V=1.0166039, theta=55.702738 -> V=1.0, theta=0.0
% INFO    : Bus 45953	: V=1.0103912, theta=55.705381 -> V=1.0, theta=0.0
% INFO    : Bus 45954	: V=1.017143, theta=55.634525 -> V=1.0, theta=0.0
% INFO    : Bus 45955	: V=1.0107911, theta=55.691643 -> V=1.0, theta=0.0
% INFO    : Bus 45956	: V=1.0170025, theta=55.6575 -> V=1.0, theta=0.0
% INFO    : Bus 45957	: V=1.0185461, theta=55.553837 -> V=1.0, theta=0.0
% INFO    : Bus 45958	: V=1.0176006, theta=55.094372 -> V=1.0, theta=0.0
% INFO    : Bus 45959	: V=1.0147152, theta=54.525851 -> V=1.0, theta=0.0
% INFO    : Bus 45960	: V=1.0126095, theta=54.570831 -> V=1.0, theta=0.0
% INFO    : Bus 45961	: V=1.0164141, theta=55.691026 -> V=1.0, theta=0.0
% INFO    : Bus 45962	: V=1.0113007, theta=38.108255 -> V=1.0, theta=0.0
% INFO    : Bus 45963	: V=0.9955048, theta=53.997898 -> V=1.0, theta=0.0
% INFO    : Bus 45964	: V=0.9940196, theta=50.245282 -> V=1.0, theta=0.0
% INFO    : Bus 45965	: V=0.9933089, theta=50.288335 -> V=1.0, theta=0.0
% INFO    : Bus 45966	: V=0.9915772, theta=50.123553 -> V=1.0, theta=0.0
% INFO    : Bus 45967	: V=0.9988372, theta=50.224024 -> V=1.0, theta=0.0
% INFO    : Bus 45968	: V=0.9946059, theta=50.238825 -> V=1.0, theta=0.0
% INFO    : Bus 45969	: V=1.0009581, theta=50.292613 -> V=1.0, theta=0.0
% INFO    : Bus 45970	: V=0.9983255, theta=50.23324 -> V=1.0, theta=0.0
% INFO    : Bus 45971	: V=0.9927353, theta=50.342984 -> V=1.0, theta=0.0
% INFO    : Bus 45972	: V=0.9950374, theta=50.292526 -> V=1.0, theta=0.0
% INFO    : Bus 45973	: V=0.9952084, theta=50.310781 -> V=1.0, theta=0.0
% INFO    : Bus 45974	: V=1.019385, theta=51.331963 -> V=1.0, theta=0.0
% INFO    : Bus 45975	: V=1.0010973, theta=50.592675 -> V=1.0, theta=0.0
% INFO    : Bus 45976	: V=1.0030813, theta=50.600112 -> V=1.0, theta=0.0
% INFO    : Bus 45977	: V=0.9967284, theta=50.356623 -> V=1.0, theta=0.0
% INFO    : Bus 45978	: V=1.0062607, theta=50.538401 -> V=1.0, theta=0.0
% INFO    : Bus 45979	: V=1.0062105, theta=50.335286 -> V=1.0, theta=0.0
% INFO    : Bus 45980	: V=1.0061861, theta=50.53227 -> V=1.0, theta=0.0
% INFO    : Bus 45981	: V=0.9996671, theta=50.098195 -> V=1.0, theta=0.0
% INFO    : Bus 45982	: V=0.9959949, theta=50.138395 -> V=1.0, theta=0.0
% INFO    : Bus 45983	: V=0.9754221, theta=50.576753 -> V=1.0, theta=0.0
% INFO    : Bus 45984	: V=0.9624687, theta=50.977658 -> V=1.0, theta=0.0
% INFO    : Bus 45985	: V=0.9932735, theta=49.388232 -> V=1.0, theta=0.0
% INFO    : Bus 45986	: V=0.9870351, theta=49.250147 -> V=1.0, theta=0.0
% INFO    : Bus 45987	: V=0.9756072, theta=48.448805 -> V=1.0, theta=0.0
% INFO    : Bus 45988	: V=0.9675086, theta=47.908218 -> V=1.0, theta=0.0
% INFO    : Bus 45989	: V=0.9723439, theta=48.706046 -> V=1.0, theta=0.0
% INFO    : Bus 45990	: V=0.986124, theta=49.310886 -> V=1.0, theta=0.0
% INFO    : Bus 45991	: V=1.0094302, theta=55.537056 -> V=1.0, theta=0.0
% INFO    : Bus 45992	: V=1.0011083, theta=52.19107 -> V=1.0, theta=0.0
% INFO    : Bus 45993	: V=1.0060857, theta=55.784025 -> V=1.0, theta=0.0
% INFO    : Bus 45994	: V=0.9811816, theta=54.709718 -> V=1.0, theta=0.0
% INFO    : Bus 45995	: V=0.9930585, theta=55.030327 -> V=1.0, theta=0.0
% INFO    : Bus 45996	: V=1.0124985, theta=56.444329 -> V=1.0, theta=0.0
% INFO    : Bus 45997	: V=1.0019434, theta=55.392017 -> V=1.0, theta=0.0
% INFO    : Bus 45998	: V=1.0132967, theta=56.169042 -> V=1.0, theta=0.0
% INFO    : Bus 45999	: V=1.0139142, theta=56.513455 -> V=1.0, theta=0.0
% INFO    : Bus 46000	: V=1.0161913, theta=56.675878 -> V=1.0, theta=0.0
% INFO    : Bus 46001	: V=1.0123975, theta=56.580287 -> V=1.0, theta=0.0
% INFO    : Bus 46002	: V=1.0188141, theta=56.916718 -> V=1.0, theta=0.0
% INFO    : Bus 46003	: V=0.9492301, theta=42.093789 -> V=1.0, theta=0.0
% INFO    : Bus 46004	: V=0.952655, theta=40.852461 -> V=1.0, theta=0.0
% INFO    : Bus 46005	: V=0.958165, theta=39.497208 -> V=1.0, theta=0.0
% INFO    : Bus 46006	: V=0.9646959, theta=38.740283 -> V=1.0, theta=0.0
% INFO    : Bus 46007	: V=0.9596159, theta=39.26931 -> V=1.0, theta=0.0
% INFO    : Bus 46008	: V=0.9560724, theta=51.488953 -> V=1.0, theta=0.0
% INFO    : Bus 46009	: V=0.9527467, theta=51.701472 -> V=1.0, theta=0.0
% INFO    : Bus 46010	: V=1.0128081, theta=31.562684 -> V=1.0, theta=0.0
% INFO    : Bus 46011	: V=1.0162483, theta=31.747927 -> V=1.0, theta=0.0
% INFO    : Bus 46012	: V=1.0166102, theta=31.904424 -> V=1.0, theta=0.0
% INFO    : Bus 46013	: V=1.0126473, theta=31.504482 -> V=1.0, theta=0.0
% INFO    : Bus 46014	: V=1.0101497, theta=31.356798 -> V=1.0, theta=0.0
% INFO    : Bus 46015	: V=1.0118991, theta=31.400772 -> V=1.0, theta=0.0
% INFO    : Bus 46016	: V=1.011595, theta=31.354243 -> V=1.0, theta=0.0
% INFO    : Bus 46017	: V=1.010281, theta=31.34671 -> V=1.0, theta=0.0
% INFO    : Bus 46018	: V=1.009706, theta=31.307384 -> V=1.0, theta=0.0
% INFO    : Bus 46019	: V=1.0113364, theta=31.387037 -> V=1.0, theta=0.0
% INFO    : Bus 46020	: V=1.0113342, theta=31.266351 -> V=1.0, theta=0.0
% INFO    : Bus 46021	: V=1.0116358, theta=31.144304 -> V=1.0, theta=0.0
% INFO    : Bus 46022	: V=1.0118288, theta=31.255197 -> V=1.0, theta=0.0
% INFO    : Bus 46023	: V=1.0097643, theta=31.008533 -> V=1.0, theta=0.0
% INFO    : Bus 46024	: V=1.011518, theta=31.183742 -> V=1.0, theta=0.0
% INFO    : Bus 46025	: V=1.0110011, theta=31.096822 -> V=1.0, theta=0.0
% INFO    : Bus 46026	: V=1.0096652, theta=30.963703 -> V=1.0, theta=0.0
% INFO    : Bus 46027	: V=1.0111254, theta=31.018581 -> V=1.0, theta=0.0
% INFO    : Bus 46028	: V=1.011285, theta=31.049526 -> V=1.0, theta=0.0
% INFO    : Bus 46029	: V=1.0103463, theta=31.034533 -> V=1.0, theta=0.0
% INFO    : Bus 46030	: V=1.0102746, theta=31.011533 -> V=1.0, theta=0.0
% INFO    : Bus 46031	: V=1.0103319, theta=31.013306 -> V=1.0, theta=0.0
% INFO    : Bus 46032	: V=1.0109956, theta=31.138095 -> V=1.0, theta=0.0
% INFO    : Bus 46033	: V=1.0111621, theta=31.011438 -> V=1.0, theta=0.0
% INFO    : Bus 46034	: V=1.0109822, theta=30.985869 -> V=1.0, theta=0.0
% INFO    : Bus 46035	: V=1.0094064, theta=30.940278 -> V=1.0, theta=0.0
% INFO    : Bus 46036	: V=1.0108272, theta=31.068718 -> V=1.0, theta=0.0
% INFO    : Bus 46037	: V=1.0096037, theta=30.64212 -> V=1.0, theta=0.0
% INFO    : Bus 46038	: V=1.0095675, theta=30.646929 -> V=1.0, theta=0.0
% INFO    : Bus 46039	: V=1.0106532, theta=31.043157 -> V=1.0, theta=0.0
% INFO    : Bus 46040	: V=1.0102275, theta=30.778605 -> V=1.0, theta=0.0
% INFO    : Bus 46041	: V=1.0103441, theta=30.794071 -> V=1.0, theta=0.0
% INFO    : Bus 46042	: V=1.0105041, theta=30.806224 -> V=1.0, theta=0.0
% INFO    : Bus 46043	: V=1.0108767, theta=30.936055 -> V=1.0, theta=0.0
% INFO    : Bus 46044	: V=1.0109201, theta=30.959817 -> V=1.0, theta=0.0
% INFO    : Bus 46045	: V=1.0102277, theta=30.913765 -> V=1.0, theta=0.0
% INFO    : Bus 46046	: V=1.0104509, theta=30.862718 -> V=1.0, theta=0.0
% INFO    : Bus 46047	: V=1.0110074, theta=30.959052 -> V=1.0, theta=0.0
% INFO    : Bus 46048	: V=1.0108971, theta=31.088382 -> V=1.0, theta=0.0
% INFO    : Bus 46049	: V=1.0103349, theta=30.862519 -> V=1.0, theta=0.0
% INFO    : Bus 46050	: V=1.0109297, theta=30.932286 -> V=1.0, theta=0.0
% INFO    : Bus 46051	: V=1.0108502, theta=30.898018 -> V=1.0, theta=0.0
% INFO    : Bus 46052	: V=1.0105285, theta=30.839779 -> V=1.0, theta=0.0
% INFO    : Bus 46053	: V=1.010819, theta=30.887231 -> V=1.0, theta=0.0
% INFO    : Bus 46054	: V=1.0104882, theta=30.838522 -> V=1.0, theta=0.0
% INFO    : Bus 46055	: V=1.0108187, theta=30.894205 -> V=1.0, theta=0.0
% INFO    : Bus 46056	: V=1.0104805, theta=31.015423 -> V=1.0, theta=0.0
% INFO    : Bus 46057	: V=1.0099869, theta=30.68647 -> V=1.0, theta=0.0
% INFO    : Bus 46058	: V=1.0095825, theta=30.656175 -> V=1.0, theta=0.0
% INFO    : Bus 46059	: V=1.0109239, theta=30.954812 -> V=1.0, theta=0.0
% INFO    : Bus 46060	: V=1.0091489, theta=30.615619 -> V=1.0, theta=0.0
% INFO    : Bus 46061	: V=1.009259, theta=30.626073 -> V=1.0, theta=0.0
% INFO    : Bus 46062	: V=1.0103846, theta=31.000831 -> V=1.0, theta=0.0
% INFO    : Bus 46063	: V=1.0098424, theta=30.670482 -> V=1.0, theta=0.0
% INFO    : Bus 46064	: V=1.0108021, theta=30.869909 -> V=1.0, theta=0.0
% INFO    : Bus 46065	: V=1.0101568, theta=30.73271 -> V=1.0, theta=0.0
% INFO    : Bus 46066	: V=1.0103047, theta=30.784499 -> V=1.0, theta=0.0
% INFO    : Bus 46067	: V=1.0107462, theta=30.997125 -> V=1.0, theta=0.0
% INFO    : Bus 46068	: V=1.0106852, theta=30.951673 -> V=1.0, theta=0.0
% INFO    : Bus 46069	: V=1.0101873, theta=30.829463 -> V=1.0, theta=0.0
% INFO    : Bus 46070	: V=1.0100736, theta=30.823404 -> V=1.0, theta=0.0
% INFO    : Bus 46071	: V=1.0099978, theta=30.81638 -> V=1.0, theta=0.0
% INFO    : Bus 46072	: V=1.0101876, theta=30.813827 -> V=1.0, theta=0.0
% INFO    : Bus 46073	: V=1.010211, theta=30.796996 -> V=1.0, theta=0.0
% INFO    : Bus 46074	: V=1.0099275, theta=30.702363 -> V=1.0, theta=0.0
% INFO    : Bus 46075	: V=1.0100347, theta=30.669475 -> V=1.0, theta=0.0
% INFO    : Bus 46076	: V=1.0108145, theta=30.84817 -> V=1.0, theta=0.0
% INFO    : Bus 46077	: V=1.0099778, theta=30.663751 -> V=1.0, theta=0.0
% INFO    : Bus 46078	: V=1.0099037, theta=30.671956 -> V=1.0, theta=0.0
% INFO    : Bus 46079	: V=1.009765, theta=30.652745 -> V=1.0, theta=0.0
% INFO    : Bus 46080	: V=1.0099675, theta=30.673143 -> V=1.0, theta=0.0
% INFO    : Bus 46081	: V=1.0089353, theta=30.595894 -> V=1.0, theta=0.0
% INFO    : Bus 46082	: V=1.0088759, theta=30.577453 -> V=1.0, theta=0.0
% INFO    : Bus 46083	: V=1.0089767, theta=30.595927 -> V=1.0, theta=0.0
% INFO    : Bus 46084	: V=1.0089157, theta=30.569769 -> V=1.0, theta=0.0
% INFO    : Bus 46085	: V=1.0088336, theta=30.564639 -> V=1.0, theta=0.0
% INFO    : Bus 46086	: V=1.0087038, theta=30.55408 -> V=1.0, theta=0.0
% INFO    : Bus 46087	: V=1.0086045, theta=30.547417 -> V=1.0, theta=0.0
% INFO    : Bus 46088	: V=1.0108167, theta=30.945216 -> V=1.0, theta=0.0
% INFO    : Bus 46089	: V=1.0090625, theta=30.571268 -> V=1.0, theta=0.0
% INFO    : Bus 46090	: V=1.0088706, theta=30.554792 -> V=1.0, theta=0.0
% INFO    : Bus 46091	: V=1.0085739, theta=30.540938 -> V=1.0, theta=0.0
% INFO    : Bus 46092	: V=1.0084285, theta=30.530124 -> V=1.0, theta=0.0
% INFO    : Bus 46093	: V=1.0084606, theta=30.536652 -> V=1.0, theta=0.0
% INFO    : Bus 46094	: V=1.0085195, theta=30.53864 -> V=1.0, theta=0.0
% INFO    : Bus 46095	: V=1.0085745, theta=30.545848 -> V=1.0, theta=0.0
% INFO    : Bus 46096	: V=1.0086092, theta=30.550817 -> V=1.0, theta=0.0
% INFO    : Bus 46097	: V=1.0089852, theta=30.579193 -> V=1.0, theta=0.0
% INFO    : Bus 46098	: V=1.0091295, theta=30.595423 -> V=1.0, theta=0.0
% INFO    : Bus 46099	: V=1.0092492, theta=30.607586 -> V=1.0, theta=0.0
% INFO    : Bus 46100	: V=1.0095554, theta=30.629115 -> V=1.0, theta=0.0
% INFO    : Bus 46101	: V=1.0097275, theta=30.642715 -> V=1.0, theta=0.0
% INFO    : Bus 46102	: V=1.0098581, theta=30.658464 -> V=1.0, theta=0.0
% INFO    : Bus 46103	: V=1.0098599, theta=30.647005 -> V=1.0, theta=0.0
% INFO    : Bus 46104	: V=1.0108689, theta=30.835426 -> V=1.0, theta=0.0
% INFO    : Bus 46105	: V=1.0099968, theta=30.673685 -> V=1.0, theta=0.0
% INFO    : Bus 46106	: V=1.0099667, theta=30.685391 -> V=1.0, theta=0.0
% INFO    : Bus 46107	: V=1.009932, theta=30.679534 -> V=1.0, theta=0.0
% INFO    : Bus 46108	: V=1.0099069, theta=30.678884 -> V=1.0, theta=0.0
% INFO    : Bus 46109	: V=1.011022, theta=30.818018 -> V=1.0, theta=0.0
% INFO    : Bus 46110	: V=1.0096806, theta=30.624641 -> V=1.0, theta=0.0
% INFO    : Bus 46111	: V=1.009661, theta=30.624164 -> V=1.0, theta=0.0
% INFO    : Bus 46112	: V=1.0095019, theta=30.6039 -> V=1.0, theta=0.0
% INFO    : Bus 46113	: V=1.0084143, theta=30.526908 -> V=1.0, theta=0.0
% INFO    : Bus 46114	: V=1.0082358, theta=30.513166 -> V=1.0, theta=0.0
% INFO    : Bus 46115	: V=1.0081896, theta=30.511881 -> V=1.0, theta=0.0
% INFO    : Bus 46116	: V=1.0081797, theta=30.491071 -> V=1.0, theta=0.0
% INFO    : Bus 46117	: V=1.0082431, theta=30.483166 -> V=1.0, theta=0.0
% INFO    : Bus 46118	: V=1.008259, theta=30.513712 -> V=1.0, theta=0.0
% INFO    : Bus 46119	: V=1.0082556, theta=30.483498 -> V=1.0, theta=0.0
% INFO    : Bus 46120	: V=1.0082391, theta=30.483129 -> V=1.0, theta=0.0
% INFO    : Bus 46121	: V=1.0093856, theta=30.601552 -> V=1.0, theta=0.0
% INFO    : Bus 46122	: V=1.0155478, theta=31.197755 -> V=1.0, theta=0.0
% INFO    : Bus 46123	: V=1.0098665, theta=30.674284 -> V=1.0, theta=0.0
% INFO    : Bus 46124	: V=1.0098272, theta=30.673252 -> V=1.0, theta=0.0
% INFO    : Bus 46125	: V=1.0098517, theta=30.718332 -> V=1.0, theta=0.0
% INFO    : Bus 46126	: V=1.0091846, theta=30.666201 -> V=1.0, theta=0.0
% INFO    : Bus 46127	: V=1.0088848, theta=30.707079 -> V=1.0, theta=0.0
% INFO    : Bus 46128	: V=1.0087366, theta=30.62366 -> V=1.0, theta=0.0
% INFO    : Bus 46129	: V=1.0088065, theta=30.615401 -> V=1.0, theta=0.0
% INFO    : Bus 46130	: V=1.0093304, theta=30.57964 -> V=1.0, theta=0.0
% INFO    : Bus 46131	: V=1.0105472, theta=30.707082 -> V=1.0, theta=0.0
% INFO    : Bus 46132	: V=1.0093366, theta=30.582071 -> V=1.0, theta=0.0
% INFO    : Bus 46133	: V=1.0093308, theta=30.583886 -> V=1.0, theta=0.0
% INFO    : Bus 46134	: V=1.0091224, theta=30.564118 -> V=1.0, theta=0.0
% INFO    : Bus 46135	: V=1.008333, theta=30.513649 -> V=1.0, theta=0.0
% INFO    : Bus 46136	: V=1.0082035, theta=30.482235 -> V=1.0, theta=0.0
% INFO    : Bus 46137	: V=1.0081051, theta=30.465603 -> V=1.0, theta=0.0
% INFO    : Bus 46138	: V=1.0097315, theta=30.539576 -> V=1.0, theta=0.0
% INFO    : Bus 46139	: V=1.0090172, theta=30.545955 -> V=1.0, theta=0.0
% INFO    : Bus 46140	: V=1.0090653, theta=30.554392 -> V=1.0, theta=0.0
% INFO    : Bus 46141	: V=1.0091602, theta=30.558683 -> V=1.0, theta=0.0
% INFO    : Bus 46142	: V=1.0095544, theta=30.470518 -> V=1.0, theta=0.0
% INFO    : Bus 46143	: V=1.0090734, theta=30.49925 -> V=1.0, theta=0.0
% INFO    : Bus 46144	: V=1.0090854, theta=30.499131 -> V=1.0, theta=0.0
% INFO    : Bus 46145	: V=1.0091411, theta=30.522522 -> V=1.0, theta=0.0
% INFO    : Bus 46146	: V=1.0089128, theta=30.466383 -> V=1.0, theta=0.0
% INFO    : Bus 46147	: V=1.0090397, theta=30.498025 -> V=1.0, theta=0.0
% INFO    : Bus 46148	: V=1.0089191, theta=30.468974 -> V=1.0, theta=0.0
% INFO    : Bus 46149	: V=1.0086962, theta=30.470166 -> V=1.0, theta=0.0
% INFO    : Bus 46150	: V=1.0093621, theta=30.4521 -> V=1.0, theta=0.0
% INFO    : Bus 46151	: V=1.0093387, theta=30.441655 -> V=1.0, theta=0.0
% INFO    : Bus 46152	: V=1.0085279, theta=30.429049 -> V=1.0, theta=0.0
% INFO    : Bus 46153	: V=1.0095269, theta=30.447855 -> V=1.0, theta=0.0
% INFO    : Bus 46154	: V=1.0086981, theta=30.446717 -> V=1.0, theta=0.0
% INFO    : Bus 46155	: V=1.0087394, theta=30.449289 -> V=1.0, theta=0.0
% INFO    : Bus 46156	: V=1.0087793, theta=30.452927 -> V=1.0, theta=0.0
% INFO    : Bus 46157	: V=1.0086225, theta=30.446629 -> V=1.0, theta=0.0
% INFO    : Bus 46158	: V=1.0086497, theta=30.44724 -> V=1.0, theta=0.0
% INFO    : Bus 46159	: V=1.0086538, theta=30.440233 -> V=1.0, theta=0.0
% INFO    : Bus 46160	: V=1.0095304, theta=30.432138 -> V=1.0, theta=0.0
% INFO    : Bus 46161	: V=1.0085798, theta=30.420859 -> V=1.0, theta=0.0
% INFO    : Bus 46162	: V=1.0093176, theta=30.413828 -> V=1.0, theta=0.0
% INFO    : Bus 46163	: V=1.0093408, theta=30.403891 -> V=1.0, theta=0.0
% INFO    : Bus 46164	: V=1.0094181, theta=30.376428 -> V=1.0, theta=0.0
% INFO    : Bus 46165	: V=1.0084537, theta=30.24731 -> V=1.0, theta=0.0
% INFO    : Bus 46166	: V=1.0094581, theta=30.362753 -> V=1.0, theta=0.0
% INFO    : Bus 46167	: V=1.0092939, theta=30.411585 -> V=1.0, theta=0.0
% INFO    : Bus 46168	: V=1.0097005, theta=30.382084 -> V=1.0, theta=0.0
% INFO    : Bus 46169	: V=1.0095761, theta=30.408004 -> V=1.0, theta=0.0
% INFO    : Bus 46170	: V=1.0095445, theta=30.417345 -> V=1.0, theta=0.0
% INFO    : Bus 46171	: V=1.0086302, theta=30.439778 -> V=1.0, theta=0.0
% INFO    : Bus 46172	: V=1.0077714, theta=30.33713 -> V=1.0, theta=0.0
% INFO    : Bus 46173	: V=1.0076332, theta=30.367837 -> V=1.0, theta=0.0
% INFO    : Bus 46174	: V=1.0079247, theta=30.317444 -> V=1.0, theta=0.0
% INFO    : Bus 46175	: V=1.0072601, theta=30.392434 -> V=1.0, theta=0.0
% INFO    : Bus 46176	: V=1.0074421, theta=30.41172 -> V=1.0, theta=0.0
% INFO    : Bus 46177	: V=1.0074277, theta=30.625493 -> V=1.0, theta=0.0
% INFO    : Bus 46178	: V=1.0071025, theta=30.597492 -> V=1.0, theta=0.0
% INFO    : Bus 46179	: V=1.0067925, theta=30.424372 -> V=1.0, theta=0.0
% INFO    : Bus 46180	: V=1.0064675, theta=30.443538 -> V=1.0, theta=0.0
% INFO    : Bus 46181	: V=1.0071336, theta=30.373386 -> V=1.0, theta=0.0
% INFO    : Bus 46182	: V=1.0073127, theta=30.339678 -> V=1.0, theta=0.0
% INFO    : Bus 46183	: V=1.0095969, theta=30.50775 -> V=1.0, theta=0.0
% INFO    : Bus 46184	: V=1.0080181, theta=30.293889 -> V=1.0, theta=0.0
% INFO    : Bus 46185	: V=1.0097167, theta=30.483215 -> V=1.0, theta=0.0
% INFO    : Bus 46186	: V=1.0084449, theta=30.272829 -> V=1.0, theta=0.0
% INFO    : Bus 46187	: V=1.0082758, theta=30.282263 -> V=1.0, theta=0.0
% INFO    : Bus 46188	: V=1.009636, theta=30.39479 -> V=1.0, theta=0.0
% INFO    : Bus 46189	: V=1.0086193, theta=30.255056 -> V=1.0, theta=0.0
% INFO    : Bus 46190	: V=1.0095447, theta=30.336836 -> V=1.0, theta=0.0
% INFO    : Bus 46191	: V=1.0084741, theta=30.247692 -> V=1.0, theta=0.0
% INFO    : Bus 46192	: V=1.0087569, theta=30.260732 -> V=1.0, theta=0.0
% INFO    : Bus 46193	: V=1.0086153, theta=30.253347 -> V=1.0, theta=0.0
% INFO    : Bus 46194	: V=1.0089751, theta=30.275709 -> V=1.0, theta=0.0
% INFO    : Bus 46195	: V=1.0099806, theta=30.440169 -> V=1.0, theta=0.0
% INFO    : Bus 46196	: V=1.0098056, theta=30.467265 -> V=1.0, theta=0.0
% INFO    : Bus 46197	: V=1.0088308, theta=30.317819 -> V=1.0, theta=0.0
% INFO    : Bus 46198	: V=1.0098174, theta=30.41898 -> V=1.0, theta=0.0
% INFO    : Bus 46199	: V=1.0167207, theta=30.80814 -> V=1.0, theta=0.0
% INFO    : Bus 46200	: V=1.0170429, theta=30.781767 -> V=1.0, theta=0.0
% INFO    : Bus 46201	: V=1.0082551, theta=30.281822 -> V=1.0, theta=0.0
% INFO    : Bus 46202	: V=1.0169917, theta=31.932138 -> V=1.0, theta=0.0
% INFO    : Bus 46203	: V=1.0109283, theta=31.217904 -> V=1.0, theta=0.0
% INFO    : Bus 46204	: V=1.0166753, theta=31.830877 -> V=1.0, theta=0.0
% INFO    : Bus 46205	: V=1.0105285, theta=31.327845 -> V=1.0, theta=0.0
% INFO    : Bus 46206	: V=1.0108262, theta=31.357002 -> V=1.0, theta=0.0
% INFO    : Bus 46207	: V=1.0106379, theta=31.286781 -> V=1.0, theta=0.0
% INFO    : Bus 46208	: V=1.0105409, theta=31.152597 -> V=1.0, theta=0.0
% INFO    : Bus 46209	: V=1.0102441, theta=31.118262 -> V=1.0, theta=0.0
% INFO    : Bus 46210	: V=1.0113174, theta=31.004761 -> V=1.0, theta=0.0
% INFO    : Bus 46211	: V=1.0115114, theta=31.032512 -> V=1.0, theta=0.0
% INFO    : Bus 46212	: V=1.011038, theta=30.716726 -> V=1.0, theta=0.0
% INFO    : Bus 46213	: V=1.0112386, theta=30.994273 -> V=1.0, theta=0.0
% INFO    : Bus 46214	: V=1.0109951, theta=30.962017 -> V=1.0, theta=0.0
% INFO    : Bus 46215	: V=1.0100021, theta=30.631489 -> V=1.0, theta=0.0
% INFO    : Bus 46216	: V=1.0095545, theta=30.603925 -> V=1.0, theta=0.0
% INFO    : Bus 46217	: V=1.0108869, theta=30.951729 -> V=1.0, theta=0.0
% INFO    : Bus 46218	: V=1.0111252, theta=31.434371 -> V=1.0, theta=0.0
% INFO    : Bus 46219	: V=1.0104361, theta=31.374581 -> V=1.0, theta=0.0
% INFO    : Bus 46220	: V=1.0098956, theta=31.327049 -> V=1.0, theta=0.0
% INFO    : Bus 46221	: V=1.0087322, theta=31.261877 -> V=1.0, theta=0.0
% INFO    : Bus 46222	: V=1.0101697, theta=30.830831 -> V=1.0, theta=0.0
% INFO    : Bus 46223	: V=1.0101078, theta=30.820577 -> V=1.0, theta=0.0
% INFO    : Bus 46224	: V=1.0101046, theta=30.812581 -> V=1.0, theta=0.0
% INFO    : Bus 46225	: V=1.0105033, theta=30.857315 -> V=1.0, theta=0.0
% INFO    : Bus 46226	: V=1.0097177, theta=30.742564 -> V=1.0, theta=0.0
% INFO    : Bus 46227	: V=1.0101055, theta=30.78416 -> V=1.0, theta=0.0
% INFO    : Bus 46228	: V=1.0092097, theta=30.666903 -> V=1.0, theta=0.0
% INFO    : Bus 46229	: V=1.0099487, theta=30.744623 -> V=1.0, theta=0.0
% INFO    : Bus 46230	: V=1.0096173, theta=30.648154 -> V=1.0, theta=0.0
% INFO    : Bus 46231	: V=1.0095449, theta=30.644412 -> V=1.0, theta=0.0
% INFO    : Bus 46232	: V=1.0094995, theta=30.644477 -> V=1.0, theta=0.0
% INFO    : Bus 46233	: V=1.0083766, theta=30.614239 -> V=1.0, theta=0.0
% INFO    : Bus 46234	: V=1.007892, theta=30.589432 -> V=1.0, theta=0.0
% INFO    : Bus 46235	: V=1.0081396, theta=30.600946 -> V=1.0, theta=0.0
% INFO    : Bus 46236	: V=1.0087404, theta=30.703891 -> V=1.0, theta=0.0
% INFO    : Bus 46237	: V=1.0083366, theta=31.236849 -> V=1.0, theta=0.0
% INFO    : Bus 46238	: V=1.008008, theta=31.217226 -> V=1.0, theta=0.0
% INFO    : Bus 46239	: V=1.0076182, theta=31.190747 -> V=1.0, theta=0.0
% INFO    : Bus 46240	: V=1.0089456, theta=30.820916 -> V=1.0, theta=0.0
% INFO    : Bus 46241	: V=1.0081528, theta=30.682676 -> V=1.0, theta=0.0
% INFO    : Bus 46242	: V=1.0082159, theta=30.684246 -> V=1.0, theta=0.0
% INFO    : Bus 46243	: V=1.0080003, theta=30.634813 -> V=1.0, theta=0.0
% INFO    : Bus 46244	: V=1.0074456, theta=30.473369 -> V=1.0, theta=0.0
% INFO    : Bus 46245	: V=1.0074946, theta=30.41303 -> V=1.0, theta=0.0
% INFO    : Bus 46246	: V=1.0072443, theta=30.460594 -> V=1.0, theta=0.0
% INFO    : Bus 46247	: V=1.006994, theta=30.442523 -> V=1.0, theta=0.0
% INFO    : Bus 46248	: V=1.0097857, theta=30.61534 -> V=1.0, theta=0.0
% INFO    : Bus 46249	: V=1.0072004, theta=30.805247 -> V=1.0, theta=0.0
% INFO    : Bus 46250	: V=1.007337, theta=30.97974 -> V=1.0, theta=0.0
% INFO    : Bus 46251	: V=1.006712, theta=30.548745 -> V=1.0, theta=0.0
% INFO    : Bus 46252	: V=1.0061671, theta=30.37582 -> V=1.0, theta=0.0
% INFO    : Bus 46253	: V=1.0060157, theta=30.372072 -> V=1.0, theta=0.0
% INFO    : Bus 46254	: V=1.0078988, theta=30.316791 -> V=1.0, theta=0.0
% INFO    : Bus 46255	: V=1.007618, theta=30.306148 -> V=1.0, theta=0.0
% INFO    : Bus 46256	: V=1.0081956, theta=30.280502 -> V=1.0, theta=0.0
% INFO    : Bus 46257	: V=1.0081168, theta=30.292369 -> V=1.0, theta=0.0
% INFO    : Bus 46258	: V=1.0070822, theta=30.612815 -> V=1.0, theta=0.0
% INFO    : Bus 46259	: V=1.0061589, theta=30.738494 -> V=1.0, theta=0.0
% INFO    : Bus 46260	: V=1.0074491, theta=30.54344 -> V=1.0, theta=0.0
% INFO    : Bus 46261	: V=1.0077656, theta=30.491064 -> V=1.0, theta=0.0
% INFO    : Bus 46262	: V=1.0071573, theta=30.252987 -> V=1.0, theta=0.0
% INFO    : Bus 46263	: V=1.0087443, theta=30.417521 -> V=1.0, theta=0.0
% INFO    : Bus 46264	: V=1.0017228, theta=30.240186 -> V=1.0, theta=0.0
% INFO    : Bus 46265	: V=1.0057166, theta=30.1767 -> V=1.0, theta=0.0
% INFO    : Bus 46266	: V=1.006343, theta=30.370437 -> V=1.0, theta=0.0
% INFO    : Bus 46267	: V=1.0176426, theta=30.734 -> V=1.0, theta=0.0
% INFO    : Bus 46268	: V=1.0120922, theta=29.992325 -> V=1.0, theta=0.0
% INFO    : Bus 46269	: V=1.0112214, theta=30.240141 -> V=1.0, theta=0.0
% INFO    : Bus 46270	: V=1.0095986, theta=29.743448 -> V=1.0, theta=0.0
% INFO    : Bus 46271	: V=1.0123857, theta=30.07615 -> V=1.0, theta=0.0
% INFO    : Bus 46272	: V=1.0094809, theta=29.875666 -> V=1.0, theta=0.0
% INFO    : Bus 46273	: V=1.010626, theta=30.073458 -> V=1.0, theta=0.0
% INFO    : Bus 46274	: V=1.0110358, theta=30.04181 -> V=1.0, theta=0.0
% INFO    : Bus 46275	: V=1.0114416, theta=30.021935 -> V=1.0, theta=0.0
% INFO    : Bus 46276	: V=1.009282, theta=29.823494 -> V=1.0, theta=0.0
% INFO    : Bus 46277	: V=1.0096506, theta=29.831433 -> V=1.0, theta=0.0
% INFO    : Bus 46278	: V=1.0094552, theta=29.827713 -> V=1.0, theta=0.0
% INFO    : Bus 46279	: V=1.0089672, theta=29.906314 -> V=1.0, theta=0.0
% INFO    : Bus 46280	: V=1.0090548, theta=29.908423 -> V=1.0, theta=0.0
% INFO    : Bus 46281	: V=1.0098869, theta=30.165075 -> V=1.0, theta=0.0
% INFO    : Bus 46282	: V=1.0092862, theta=29.898181 -> V=1.0, theta=0.0
% INFO    : Bus 46283	: V=1.0101755, theta=30.116209 -> V=1.0, theta=0.0
% INFO    : Bus 46284	: V=1.0080555, theta=30.213258 -> V=1.0, theta=0.0
% INFO    : Bus 46285	: V=1.0096, theta=30.25888 -> V=1.0, theta=0.0
% INFO    : Bus 46286	: V=1.0092022, theta=31.280733 -> V=1.0, theta=0.0
% INFO    : Bus 46287	: V=1.0093611, theta=30.589795 -> V=1.0, theta=0.0
% INFO    : Bus 46288	: V=1.0096204, theta=30.543429 -> V=1.0, theta=0.0
% INFO    : Bus 46289	: V=1.008432, theta=30.527268 -> V=1.0, theta=0.0
% INFO    : Bus 46290	: V=1.0086204, theta=30.551372 -> V=1.0, theta=0.0
% INFO    : Bus 46291	: V=1.0090533, theta=30.562709 -> V=1.0, theta=0.0
% INFO    : Bus 46292	: V=1.0096031, theta=30.54414 -> V=1.0, theta=0.0
% INFO    : Bus 46293	: V=1.008485, theta=30.528679 -> V=1.0, theta=0.0
% INFO    : Bus 46294	: V=1.0090706, theta=30.563126 -> V=1.0, theta=0.0
% INFO    : Bus 46295	: V=1.0089838, theta=30.546373 -> V=1.0, theta=0.0
% INFO    : Bus 46296	: V=1.0095408, theta=30.491183 -> V=1.0, theta=0.0
% INFO    : Bus 46297	: V=1.0097848, theta=30.538248 -> V=1.0, theta=0.0
% INFO    : Bus 46298	: V=1.0094346, theta=30.4689 -> V=1.0, theta=0.0
% INFO    : Bus 46299	: V=1.0093262, theta=30.425588 -> V=1.0, theta=0.0
% INFO    : Bus 46300	: V=1.0154946, theta=31.058717 -> V=1.0, theta=0.0
% INFO    : Bus 46301	: V=1.0081356, theta=30.497749 -> V=1.0, theta=0.0
% INFO    : Bus 46302	: V=1.00813, theta=30.505148 -> V=1.0, theta=0.0
% INFO    : Bus 46303	: V=1.005044, theta=29.978082 -> V=1.0, theta=0.0
% INFO    : Bus 46304	: V=1.0094372, theta=30.378905 -> V=1.0, theta=0.0
% INFO    : Bus 46305	: V=1.0094612, theta=30.465127 -> V=1.0, theta=0.0
% INFO    : Bus 46306	: V=0.9714202, theta=41.366129 -> V=1.0, theta=0.0
% INFO    : Bus 46307	: V=1.015606, theta=43.430013 -> V=1.0, theta=0.0
% INFO    : Bus 46308	: V=0.9847232, theta=41.943968 -> V=1.0, theta=0.0
% INFO    : Bus 46309	: V=0.9999139, theta=42.539177 -> V=1.0, theta=0.0
% INFO    : Bus 46310	: V=0.9740294, theta=41.173652 -> V=1.0, theta=0.0
% INFO    : Bus 46311	: V=0.9916301, theta=41.774795 -> V=1.0, theta=0.0
% INFO    : Bus 46312	: V=0.970124, theta=41.397161 -> V=1.0, theta=0.0
% INFO    : Bus 46313	: V=0.9702014, theta=41.289647 -> V=1.0, theta=0.0
% INFO    : Bus 46314	: V=0.9979933, theta=41.933566 -> V=1.0, theta=0.0
% INFO    : Bus 46315	: V=0.9582166, theta=53.214743 -> V=1.0, theta=0.0
% INFO    : Bus 46316	: V=0.9693905, theta=54.200712 -> V=1.0, theta=0.0
% INFO    : Bus 46317	: V=0.9796687, theta=54.276263 -> V=1.0, theta=0.0
% INFO    : Bus 46318	: V=0.9834584, theta=54.234187 -> V=1.0, theta=0.0
% INFO    : Bus 46319	: V=0.9929381, theta=54.912191 -> V=1.0, theta=0.0
% INFO    : Bus 46320	: V=1.0038324, theta=55.544995 -> V=1.0, theta=0.0
% INFO    : Bus 46321	: V=1.0008646, theta=55.262185 -> V=1.0, theta=0.0
% INFO    : Bus 46322	: V=0.9980575, theta=54.766613 -> V=1.0, theta=0.0
% INFO    : Bus 46323	: V=1.0029827, theta=54.582298 -> V=1.0, theta=0.0
% INFO    : Bus 46324	: V=0.9927151, theta=53.911393 -> V=1.0, theta=0.0
% INFO    : Bus 46325	: V=0.9917598, theta=51.193513 -> V=1.0, theta=0.0
% INFO    : Bus 46326	: V=0.9937284, theta=50.671598 -> V=1.0, theta=0.0
% INFO    : Bus 46327	: V=0.9974844, theta=50.556364 -> V=1.0, theta=0.0
% INFO    : Bus 46328	: V=1.0013517, theta=50.525281 -> V=1.0, theta=0.0
% INFO    : Bus 46329	: V=0.9966555, theta=50.328994 -> V=1.0, theta=0.0
% INFO    : Bus 46330	: V=0.9945892, theta=50.637926 -> V=1.0, theta=0.0
% INFO    : Bus 46331	: V=0.9687978, theta=49.547463 -> V=1.0, theta=0.0
% INFO    : Bus 46332	: V=0.9781127, theta=49.602062 -> V=1.0, theta=0.0
% INFO    : Bus 46333	: V=0.9799016, theta=49.570298 -> V=1.0, theta=0.0
% INFO    : Bus 46334	: V=0.9760154, theta=49.284015 -> V=1.0, theta=0.0
% INFO    : Bus 46335	: V=0.9870213, theta=49.894091 -> V=1.0, theta=0.0
% INFO    : Bus 46336	: V=0.9716449, theta=49.49734 -> V=1.0, theta=0.0
% INFO    : Bus 46337	: V=1.0171038, theta=51.267298 -> V=1.0, theta=0.0
% INFO    : Bus 46338	: V=0.997844, theta=50.523752 -> V=1.0, theta=0.0
% INFO    : Bus 46339	: V=1.0095912, theta=52.409215 -> V=1.0, theta=0.0
% INFO    : Bus 46340	: V=1.0023287, theta=51.720053 -> V=1.0, theta=0.0
% INFO    : Bus 46341	: V=1.003476, theta=51.771993 -> V=1.0, theta=0.0
% INFO    : Bus 46342	: V=1.0098869, theta=52.42479 -> V=1.0, theta=0.0
% INFO    : Bus 46343	: V=1.0103977, theta=52.45854 -> V=1.0, theta=0.0
% INFO    : Bus 46344	: V=1.0089782, theta=52.025932 -> V=1.0, theta=0.0
% INFO    : Bus 46345	: V=1.0093238, theta=51.988294 -> V=1.0, theta=0.0
% INFO    : Bus 46346	: V=0.9987362, theta=51.191831 -> V=1.0, theta=0.0
% INFO    : Bus 46347	: V=0.9925236, theta=50.912745 -> V=1.0, theta=0.0
% INFO    : Bus 46348	: V=1.0078602, theta=50.870722 -> V=1.0, theta=0.0
% INFO    : Bus 46349	: V=0.9996952, theta=51.620838 -> V=1.0, theta=0.0
% INFO    : Bus 46350	: V=1.0077168, theta=51.324942 -> V=1.0, theta=0.0
% INFO    : Bus 46351	: V=1.0013074, theta=51.676896 -> V=1.0, theta=0.0
% INFO    : Bus 46352	: V=1.009531, theta=51.869203 -> V=1.0, theta=0.0
% INFO    : Bus 46353	: V=1.0035652, theta=51.909607 -> V=1.0, theta=0.0
% INFO    : Bus 46354	: V=1.0105315, theta=52.102367 -> V=1.0, theta=0.0
% INFO    : Bus 46355	: V=1.0118012, theta=52.404544 -> V=1.0, theta=0.0
% INFO    : Bus 46356	: V=1.0112532, theta=52.506297 -> V=1.0, theta=0.0
% INFO    : Bus 46357	: V=1.0129185, theta=52.520136 -> V=1.0, theta=0.0
% INFO    : Bus 46358	: V=1.0141423, theta=53.023181 -> V=1.0, theta=0.0
% INFO    : Bus 46359	: V=1.014406, theta=53.038688 -> V=1.0, theta=0.0
% INFO    : Bus 46360	: V=1.018052, theta=52.928275 -> V=1.0, theta=0.0
% INFO    : Bus 46361	: V=1.0186326, theta=53.299985 -> V=1.0, theta=0.0
% INFO    : Bus 46362	: V=1.0151937, theta=53.323597 -> V=1.0, theta=0.0
% INFO    : Bus 46363	: V=1.0160601, theta=53.516018 -> V=1.0, theta=0.0
% INFO    : Bus 46364	: V=1.0165651, theta=53.623628 -> V=1.0, theta=0.0
% INFO    : Bus 46365	: V=1.0025521, theta=51.863588 -> V=1.0, theta=0.0
% INFO    : Bus 46366	: V=1.0042358, theta=52.03482 -> V=1.0, theta=0.0
% INFO    : Bus 46367	: V=0.9943385, theta=51.498807 -> V=1.0, theta=0.0
% INFO    : Bus 46368	: V=0.9919337, theta=51.030175 -> V=1.0, theta=0.0
% INFO    : Bus 46369	: V=0.9895928, theta=51.267148 -> V=1.0, theta=0.0
% INFO    : Bus 46370	: V=0.9872456, theta=51.358304 -> V=1.0, theta=0.0
% INFO    : Bus 46371	: V=1.0013411, theta=51.103387 -> V=1.0, theta=0.0
% INFO    : Bus 46372	: V=0.9861655, theta=51.536211 -> V=1.0, theta=0.0
% INFO    : Bus 46373	: V=1.0094223, theta=52.698568 -> V=1.0, theta=0.0
% INFO    : Bus 46374	: V=1.0018718, theta=52.033838 -> V=1.0, theta=0.0
% INFO    : Bus 46375	: V=0.9986542, theta=53.07463 -> V=1.0, theta=0.0
% INFO    : Bus 46376	: V=0.9834447, theta=51.6363 -> V=1.0, theta=0.0
% INFO    : Bus 46377	: V=1.0185335, theta=54.042945 -> V=1.0, theta=0.0
% INFO    : Bus 46378	: V=1.0020364, theta=52.993275 -> V=1.0, theta=0.0
% INFO    : Bus 46379	: V=1.0133285, theta=34.2713 -> V=1.0, theta=0.0
% INFO    : Bus 46380	: V=1.0189794, theta=34.077652 -> V=1.0, theta=0.0
% INFO    : Bus 46381	: V=1.0125153, theta=33.232152 -> V=1.0, theta=0.0
% INFO    : Bus 46382	: V=1.0199808, theta=32.924045 -> V=1.0, theta=0.0
% INFO    : Bus 46383	: V=1.0193572, theta=33.35196 -> V=1.0, theta=0.0
% INFO    : Bus 46384	: V=1.0126584, theta=32.70761 -> V=1.0, theta=0.0
% INFO    : Bus 46385	: V=1.0154063, theta=32.437766 -> V=1.0, theta=0.0
% INFO    : Bus 46386	: V=1.0189152, theta=32.606223 -> V=1.0, theta=0.0
% INFO    : Bus 46387	: V=1.0112643, theta=32.286732 -> V=1.0, theta=0.0
% INFO    : Bus 46388	: V=1.0109964, theta=32.235343 -> V=1.0, theta=0.0
% INFO    : Bus 46389	: V=1.015017, theta=32.251174 -> V=1.0, theta=0.0
% INFO    : Bus 46390	: V=1.0102015, theta=32.45925 -> V=1.0, theta=0.0
% INFO    : Bus 46391	: V=1.0123799, theta=31.770554 -> V=1.0, theta=0.0
% INFO    : Bus 46392	: V=1.0139407, theta=31.756006 -> V=1.0, theta=0.0
% INFO    : Bus 46393	: V=1.0144557, theta=32.092865 -> V=1.0, theta=0.0
% INFO    : Bus 46394	: V=1.0122271, theta=31.731062 -> V=1.0, theta=0.0
% INFO    : Bus 46395	: V=1.0109706, theta=31.577449 -> V=1.0, theta=0.0
% INFO    : Bus 46396	: V=1.0173279, theta=32.043119 -> V=1.0, theta=0.0
% INFO    : Bus 46397	: V=1.0115983, theta=44.121445 -> V=1.0, theta=0.0
% INFO    : Bus 46398	: V=1.006264, theta=43.754881 -> V=1.0, theta=0.0
% INFO    : Bus 46399	: V=0.9950711, theta=43.995837 -> V=1.0, theta=0.0
% INFO    : Bus 46400	: V=1.0090515, theta=44.177538 -> V=1.0, theta=0.0
% INFO    : Bus 46401	: V=1.0075522, theta=44.477966 -> V=1.0, theta=0.0
% INFO    : Bus 46402	: V=0.9984418, theta=43.931947 -> V=1.0, theta=0.0
% INFO    : Bus 46403	: V=1.0000683, theta=43.504472 -> V=1.0, theta=0.0
% INFO    : Bus 46404	: V=1.0095988, theta=43.776759 -> V=1.0, theta=0.0
% INFO    : Bus 46405	: V=1.0097246, theta=43.949136 -> V=1.0, theta=0.0
% INFO    : Bus 46406	: V=1.0012162, theta=43.920497 -> V=1.0, theta=0.0
% INFO    : Bus 46407	: V=0.9661984, theta=43.571201 -> V=1.0, theta=0.0
% INFO    : Bus 46408	: V=0.9607228, theta=43.23163 -> V=1.0, theta=0.0
% INFO    : Bus 46409	: V=0.9663079, theta=43.703353 -> V=1.0, theta=0.0
% INFO    : Bus 46410	: V=0.9707082, theta=43.922887 -> V=1.0, theta=0.0
% INFO    : Bus 46411	: V=0.968494, theta=43.67868 -> V=1.0, theta=0.0
% INFO    : Bus 46412	: V=0.9717545, theta=43.555797 -> V=1.0, theta=0.0
% INFO    : Bus 46413	: V=0.983306, theta=44.061712 -> V=1.0, theta=0.0
% INFO    : Bus 46414	: V=0.9790836, theta=44.110623 -> V=1.0, theta=0.0
% INFO    : Bus 46415	: V=0.9781635, theta=44.162524 -> V=1.0, theta=0.0
% INFO    : Bus 46416	: V=0.9755341, theta=44.086259 -> V=1.0, theta=0.0
% INFO    : Bus 46417	: V=0.9906975, theta=50.252697 -> V=1.0, theta=0.0
% INFO    : Bus 46418	: V=0.998303, theta=50.253942 -> V=1.0, theta=0.0
% INFO    : Bus 46419	: V=0.9861274, theta=50.033939 -> V=1.0, theta=0.0
% INFO    : Bus 46420	: V=0.9963906, theta=50.271774 -> V=1.0, theta=0.0
% INFO    : Bus 46421	: V=0.9851407, theta=50.026663 -> V=1.0, theta=0.0
% INFO    : Bus 46422	: V=0.9984101, theta=50.707133 -> V=1.0, theta=0.0
% INFO    : Bus 46423	: V=0.9956552, theta=50.385396 -> V=1.0, theta=0.0
% INFO    : Bus 46424	: V=0.9939018, theta=50.326476 -> V=1.0, theta=0.0
% INFO    : Bus 46425	: V=0.9859977, theta=49.918995 -> V=1.0, theta=0.0
% INFO    : Bus 46426	: V=0.9877144, theta=50.053792 -> V=1.0, theta=0.0
% INFO    : Bus 46427	: V=0.9888654, theta=50.07872 -> V=1.0, theta=0.0
% INFO    : Bus 46428	: V=0.9988757, theta=50.324077 -> V=1.0, theta=0.0
% INFO    : Bus 46429	: V=0.9887215, theta=50.107335 -> V=1.0, theta=0.0
% INFO    : Bus 46430	: V=0.9774872, theta=48.287084 -> V=1.0, theta=0.0
% INFO    : Bus 46431	: V=0.9756143, theta=48.428008 -> V=1.0, theta=0.0
% INFO    : Bus 46432	: V=0.9881994, theta=48.147491 -> V=1.0, theta=0.0
% INFO    : Bus 46433	: V=0.9707668, theta=48.124567 -> V=1.0, theta=0.0
% INFO    : Bus 46434	: V=0.9707373, theta=48.224488 -> V=1.0, theta=0.0
% INFO    : Bus 46435	: V=0.9615709, theta=48.070795 -> V=1.0, theta=0.0
% INFO    : Bus 46436	: V=0.9649782, theta=47.980589 -> V=1.0, theta=0.0
% INFO    : Bus 46437	: V=1.0078891, theta=28.707703 -> V=1.0, theta=0.0
% INFO    : Bus 46438	: V=1.0078624, theta=28.707671 -> V=1.0, theta=0.0
% INFO    : Bus 46439	: V=1.0084078, theta=28.84659 -> V=1.0, theta=0.0
% INFO    : Bus 46440	: V=1.0089543, theta=28.890189 -> V=1.0, theta=0.0
% INFO    : Bus 46441	: V=1.0078204, theta=28.705213 -> V=1.0, theta=0.0
% INFO    : Bus 46442	: V=1.007866, theta=28.706556 -> V=1.0, theta=0.0
% INFO    : Bus 46443	: V=1.0086916, theta=28.846046 -> V=1.0, theta=0.0
% INFO    : Bus 46444	: V=1.0086545, theta=28.597787 -> V=1.0, theta=0.0
% INFO    : Bus 46445	: V=1.0121763, theta=29.286972 -> V=1.0, theta=0.0
% INFO    : Bus 46446	: V=1.012062, theta=29.182056 -> V=1.0, theta=0.0
% INFO    : Bus 46447	: V=1.0073124, theta=28.824929 -> V=1.0, theta=0.0
% INFO    : Bus 46448	: V=1.0081061, theta=28.738856 -> V=1.0, theta=0.0
% INFO    : Bus 46449	: V=1.0080253, theta=28.71677 -> V=1.0, theta=0.0
% INFO    : Bus 46450	: V=1.0079505, theta=28.711841 -> V=1.0, theta=0.0
% INFO    : Bus 46451	: V=1.0105574, theta=29.071646 -> V=1.0, theta=0.0
% INFO    : Bus 46452	: V=1.011688, theta=29.325451 -> V=1.0, theta=0.0
% INFO    : Bus 46453	: V=1.0110897, theta=29.188833 -> V=1.0, theta=0.0
% INFO    : Bus 46454	: V=1.0094836, theta=28.940176 -> V=1.0, theta=0.0
% INFO    : Bus 46455	: V=1.0092849, theta=28.921551 -> V=1.0, theta=0.0
% INFO    : Bus 46456	: V=1.0098368, theta=28.978377 -> V=1.0, theta=0.0
% INFO    : Bus 46457	: V=1.0142126, theta=29.884524 -> V=1.0, theta=0.0
% INFO    : Bus 46458	: V=1.0128755, theta=29.576898 -> V=1.0, theta=0.0
% INFO    : Bus 46459	: V=1.0111733, theta=29.125837 -> V=1.0, theta=0.0
% INFO    : Bus 46460	: V=1.0108337, theta=29.102577 -> V=1.0, theta=0.0
% INFO    : Bus 46461	: V=1.0119757, theta=29.563313 -> V=1.0, theta=0.0
% INFO    : Bus 46462	: V=1.0108737, theta=29.090827 -> V=1.0, theta=0.0
% INFO    : Bus 46463	: V=1.0082271, theta=28.829281 -> V=1.0, theta=0.0
% INFO    : Bus 46464	: V=1.0153296, theta=29.480074 -> V=1.0, theta=0.0
% INFO    : Bus 46465	: V=1.0087155, theta=29.094057 -> V=1.0, theta=0.0
% INFO    : Bus 46466	: V=1.0097157, theta=28.987846 -> V=1.0, theta=0.0
% INFO    : Bus 46467	: V=1.0087505, theta=28.886395 -> V=1.0, theta=0.0
% INFO    : Bus 46468	: V=0.9993704, theta=28.713562 -> V=1.0, theta=0.0
% INFO    : Bus 46469	: V=0.9961981, theta=28.852203 -> V=1.0, theta=0.0
% INFO    : Bus 46470	: V=0.9973542, theta=29.780829 -> V=1.0, theta=0.0
% INFO    : Bus 46471	: V=0.9928111, theta=30.267504 -> V=1.0, theta=0.0
% INFO    : Bus 46472	: V=0.9905953, theta=29.83407 -> V=1.0, theta=0.0
% INFO    : Bus 46473	: V=0.9977116, theta=28.866127 -> V=1.0, theta=0.0
% INFO    : Bus 46474	: V=0.9874605, theta=29.993904 -> V=1.0, theta=0.0
% INFO    : Bus 46475	: V=0.9873783, theta=29.88288 -> V=1.0, theta=0.0
% INFO    : Bus 46476	: V=0.9888214, theta=29.591765 -> V=1.0, theta=0.0
% INFO    : Bus 46477	: V=0.9897469, theta=30.149309 -> V=1.0, theta=0.0
% INFO    : Bus 46478	: V=0.9871774, theta=30.132739 -> V=1.0, theta=0.0
% INFO    : Bus 46479	: V=0.9898748, theta=30.586618 -> V=1.0, theta=0.0
% INFO    : Bus 46480	: V=0.9938941, theta=29.093106 -> V=1.0, theta=0.0
% INFO    : Bus 46481	: V=0.9834819, theta=38.625493 -> V=1.0, theta=0.0
% INFO    : Bus 46482	: V=0.9846524, theta=38.120038 -> V=1.0, theta=0.0
% INFO    : Bus 46483	: V=0.985347, theta=37.968107 -> V=1.0, theta=0.0
% INFO    : Bus 46484	: V=0.986107, theta=37.854825 -> V=1.0, theta=0.0
% INFO    : Bus 46485	: V=0.9876179, theta=37.404388 -> V=1.0, theta=0.0
% INFO    : Bus 46486	: V=1.0034443, theta=34.72596 -> V=1.0, theta=0.0
% INFO    : Bus 46487	: V=1.0029304, theta=34.757177 -> V=1.0, theta=0.0
% INFO    : Bus 46488	: V=1.0035096, theta=34.723914 -> V=1.0, theta=0.0
% INFO    : Bus 46489	: V=1.0091363, theta=34.798122 -> V=1.0, theta=0.0
% INFO    : Bus 46490	: V=1.0068291, theta=35.035193 -> V=1.0, theta=0.0
% INFO    : Bus 46491	: V=1.0069198, theta=34.965271 -> V=1.0, theta=0.0
% INFO    : Bus 46492	: V=1.0067267, theta=35.018426 -> V=1.0, theta=0.0
% INFO    : Bus 46493	: V=1.0025884, theta=34.788016 -> V=1.0, theta=0.0
% INFO    : Bus 46494	: V=1.0023111, theta=34.798063 -> V=1.0, theta=0.0
% INFO    : Bus 46495	: V=1.0082808, theta=34.802638 -> V=1.0, theta=0.0
% INFO    : Bus 46496	: V=1.0101701, theta=34.801299 -> V=1.0, theta=0.0
% INFO    : Bus 46497	: V=1.0006653, theta=34.608167 -> V=1.0, theta=0.0
% INFO    : Bus 46498	: V=1.0068697, theta=35.202412 -> V=1.0, theta=0.0
% INFO    : Bus 46499	: V=1.001743, theta=34.406236 -> V=1.0, theta=0.0
% INFO    : Bus 46500	: V=1.0072137, theta=35.149487 -> V=1.0, theta=0.0
% INFO    : Bus 46501	: V=1.0068031, theta=35.061775 -> V=1.0, theta=0.0
% INFO    : Bus 46502	: V=1.0125023, theta=34.80931 -> V=1.0, theta=0.0
% INFO    : Bus 46503	: V=1.0088361, theta=33.947674 -> V=1.0, theta=0.0
% INFO    : Bus 46504	: V=1.0132846, theta=34.108673 -> V=1.0, theta=0.0
% INFO    : Bus 46505	: V=1.0119673, theta=34.121206 -> V=1.0, theta=0.0
% INFO    : Bus 46506	: V=1.0093553, theta=33.992928 -> V=1.0, theta=0.0
% INFO    : Bus 46507	: V=1.0120124, theta=34.116389 -> V=1.0, theta=0.0
% INFO    : Bus 46508	: V=1.0129022, theta=34.123404 -> V=1.0, theta=0.0
% INFO    : Bus 46509	: V=1.0102015, theta=34.211171 -> V=1.0, theta=0.0
% INFO    : Bus 46510	: V=1.006943, theta=34.203242 -> V=1.0, theta=0.0
% INFO    : Bus 46511	: V=1.0097576, theta=34.030103 -> V=1.0, theta=0.0
% INFO    : Bus 46512	: V=1.01886, theta=34.651417 -> V=1.0, theta=0.0
% INFO    : Bus 46513	: V=1.010073, theta=34.05534 -> V=1.0, theta=0.0
% INFO    : Bus 46514	: V=1.0094305, theta=34.069523 -> V=1.0, theta=0.0
% INFO    : Bus 46515	: V=1.0051232, theta=33.66785 -> V=1.0, theta=0.0
% INFO    : Bus 46516	: V=0.9986613, theta=34.019754 -> V=1.0, theta=0.0
% INFO    : Bus 46517	: V=0.9943405, theta=34.44168 -> V=1.0, theta=0.0
% INFO    : Bus 46518	: V=0.9927679, theta=34.95061 -> V=1.0, theta=0.0
% INFO    : Bus 46519	: V=1.0106571, theta=35.851288 -> V=1.0, theta=0.0
% INFO    : Bus 46520	: V=1.0088006, theta=35.608918 -> V=1.0, theta=0.0
% INFO    : Bus 46521	: V=1.0091657, theta=35.410833 -> V=1.0, theta=0.0
% INFO    : Bus 46522	: V=1.0053998, theta=34.928021 -> V=1.0, theta=0.0
% INFO    : Bus 46523	: V=1.0003719, theta=33.200387 -> V=1.0, theta=0.0
% INFO    : Bus 46524	: V=1.0110861, theta=45.028988 -> V=1.0, theta=0.0
% INFO    : Bus 46525	: V=0.9850277, theta=44.482465 -> V=1.0, theta=0.0
% INFO    : Bus 46526	: V=1.0061074, theta=45.076985 -> V=1.0, theta=0.0
% INFO    : Bus 46527	: V=1.0070482, theta=45.11478 -> V=1.0, theta=0.0
% INFO    : Bus 46528	: V=1.0050144, theta=45.511054 -> V=1.0, theta=0.0
% INFO    : Bus 46529	: V=0.9994151, theta=44.27994 -> V=1.0, theta=0.0
% INFO    : Bus 46530	: V=0.9997234, theta=44.266424 -> V=1.0, theta=0.0
% INFO    : Bus 46531	: V=0.9976202, theta=44.261748 -> V=1.0, theta=0.0
% INFO    : Bus 46532	: V=0.9985807, theta=44.312262 -> V=1.0, theta=0.0
% INFO    : Bus 46533	: V=0.9975451, theta=44.592294 -> V=1.0, theta=0.0
% INFO    : Bus 46534	: V=0.991294, theta=44.489442 -> V=1.0, theta=0.0
% INFO    : Bus 46535	: V=0.9886885, theta=44.4482 -> V=1.0, theta=0.0
% INFO    : Bus 46536	: V=0.9876134, theta=44.424277 -> V=1.0, theta=0.0
% INFO    : Bus 46537	: V=0.9886383, theta=44.203568 -> V=1.0, theta=0.0
% INFO    : Bus 46538	: V=1.0057259, theta=44.516689 -> V=1.0, theta=0.0
% INFO    : Bus 46539	: V=0.9991183, theta=44.238721 -> V=1.0, theta=0.0
% INFO    : Bus 46540	: V=0.9993618, theta=44.512305 -> V=1.0, theta=0.0
% INFO    : Bus 46541	: V=1.009342, theta=44.518847 -> V=1.0, theta=0.0
% INFO    : Bus 46542	: V=0.9978113, theta=44.268832 -> V=1.0, theta=0.0
% INFO    : Bus 46543	: V=0.9692136, theta=37.770917 -> V=1.0, theta=0.0
% INFO    : Bus 46544	: V=0.9697436, theta=38.095346 -> V=1.0, theta=0.0
% INFO    : Bus 46545	: V=0.9756561, theta=37.630003 -> V=1.0, theta=0.0
% INFO    : Bus 46546	: V=0.9703278, theta=37.516954 -> V=1.0, theta=0.0
% INFO    : Bus 46547	: V=0.9690652, theta=37.6034 -> V=1.0, theta=0.0
% INFO    : Bus 46548	: V=0.9802198, theta=36.681185 -> V=1.0, theta=0.0
% INFO    : Bus 46549	: V=0.9776696, theta=35.737721 -> V=1.0, theta=0.0
% INFO    : Bus 46550	: V=0.9848692, theta=35.795215 -> V=1.0, theta=0.0
% INFO    : Bus 46551	: V=0.9763621, theta=35.41035 -> V=1.0, theta=0.0
% INFO    : Bus 46552	: V=0.9728834, theta=38.203807 -> V=1.0, theta=0.0
% INFO    : Bus 46553	: V=0.9698121, theta=38.001581 -> V=1.0, theta=0.0
% INFO    : Bus 46554	: V=0.9773359, theta=37.797942 -> V=1.0, theta=0.0
% INFO    : Bus 46555	: V=0.9711869, theta=35.591746 -> V=1.0, theta=0.0
% INFO    : Bus 46556	: V=0.9784316, theta=45.224341 -> V=1.0, theta=0.0
% INFO    : Bus 46557	: V=0.9756502, theta=44.83192 -> V=1.0, theta=0.0
% INFO    : Bus 46558	: V=0.9838616, theta=46.085016 -> V=1.0, theta=0.0
% INFO    : Bus 46559	: V=0.9887632, theta=45.113235 -> V=1.0, theta=0.0
% INFO    : Bus 46560	: V=0.9686134, theta=48.178931 -> V=1.0, theta=0.0
% INFO    : Bus 46561	: V=0.9809426, theta=45.077539 -> V=1.0, theta=0.0
% INFO    : Bus 46562	: V=0.9667394, theta=52.108691 -> V=1.0, theta=0.0
% INFO    : Bus 46563	: V=0.9609436, theta=51.866835 -> V=1.0, theta=0.0
% INFO    : Bus 46564	: V=0.9555991, theta=51.602268 -> V=1.0, theta=0.0
% INFO    : Bus 46565	: V=0.9562759, theta=51.706333 -> V=1.0, theta=0.0
% INFO    : Bus 46566	: V=0.9574982, theta=51.748314 -> V=1.0, theta=0.0
% INFO    : Bus 46567	: V=0.9586124, theta=51.25035 -> V=1.0, theta=0.0
% INFO    : Bus 46568	: V=0.9611619, theta=51.030005 -> V=1.0, theta=0.0
% INFO    : Bus 46569	: V=0.9657488, theta=50.880221 -> V=1.0, theta=0.0
% INFO    : Bus 46570	: V=0.9559215, theta=51.253762 -> V=1.0, theta=0.0
% INFO    : Bus 46571	: V=0.9683752, theta=52.052685 -> V=1.0, theta=0.0
% INFO    : Bus 46572	: V=0.9665431, theta=52.113492 -> V=1.0, theta=0.0
% INFO    : Bus 46573	: V=1.009779, theta=36.424403 -> V=1.0, theta=0.0
% INFO    : Bus 46574	: V=1.00983, theta=36.414908 -> V=1.0, theta=0.0
% INFO    : Bus 46575	: V=1.0095509, theta=36.46732 -> V=1.0, theta=0.0
% INFO    : Bus 46576	: V=1.0093917, theta=36.518565 -> V=1.0, theta=0.0
% INFO    : Bus 46577	: V=1.0095099, theta=36.482796 -> V=1.0, theta=0.0
% INFO    : Bus 46578	: V=1.0099179, theta=36.403846 -> V=1.0, theta=0.0
% INFO    : Bus 46579	: V=1.0102057, theta=36.383522 -> V=1.0, theta=0.0
% INFO    : Bus 46580	: V=1.0104542, theta=36.439352 -> V=1.0, theta=0.0
% INFO    : Bus 46581	: V=1.008631, theta=36.268657 -> V=1.0, theta=0.0
% INFO    : Bus 46582	: V=1.0102158, theta=36.238231 -> V=1.0, theta=0.0
% INFO    : Bus 46583	: V=1.0125686, theta=37.415672 -> V=1.0, theta=0.0
% INFO    : Bus 46584	: V=1.0041863, theta=37.059901 -> V=1.0, theta=0.0
% INFO    : Bus 46585	: V=1.0093414, theta=36.899887 -> V=1.0, theta=0.0
% INFO    : Bus 46586	: V=1.0092207, theta=37.95614 -> V=1.0, theta=0.0
% INFO    : Bus 46587	: V=1.0131594, theta=36.911299 -> V=1.0, theta=0.0
% INFO    : Bus 46588	: V=1.0133967, theta=37.056743 -> V=1.0, theta=0.0
% INFO    : Bus 46589	: V=1.0123236, theta=36.669734 -> V=1.0, theta=0.0
% INFO    : Bus 46590	: V=1.0093397, theta=36.800231 -> V=1.0, theta=0.0
% INFO    : Bus 46591	: V=1.01903, theta=36.270763 -> V=1.0, theta=0.0
% INFO    : Bus 46592	: V=1.01948, theta=36.582478 -> V=1.0, theta=0.0
% INFO    : Bus 46593	: V=1.0129001, theta=36.288193 -> V=1.0, theta=0.0
% INFO    : Bus 46594	: V=1.0058392, theta=36.066484 -> V=1.0, theta=0.0
% INFO    : Bus 46595	: V=1.0138146, theta=36.574026 -> V=1.0, theta=0.0
% INFO    : Bus 46596	: V=1.0132833, theta=35.338733 -> V=1.0, theta=0.0
% INFO    : Bus 46597	: V=1.0186145, theta=35.038876 -> V=1.0, theta=0.0
% INFO    : Bus 46598	: V=1.0048481, theta=36.462133 -> V=1.0, theta=0.0
% INFO    : Bus 46599	: V=0.9753162, theta=49.096048 -> V=1.0, theta=0.0
% INFO    : Bus 46600	: V=0.9719645, theta=47.679808 -> V=1.0, theta=0.0
% INFO    : Bus 46601	: V=0.9829269, theta=46.65753 -> V=1.0, theta=0.0
% INFO    : Bus 46602	: V=0.9715561, theta=48.28688 -> V=1.0, theta=0.0
% INFO    : Bus 46603	: V=0.9891978, theta=49.58302 -> V=1.0, theta=0.0
% INFO    : Bus 46604	: V=0.9743352, theta=48.487074 -> V=1.0, theta=0.0
% INFO    : Bus 46605	: V=0.9937089, theta=43.489713 -> V=1.0, theta=0.0
% INFO    : Bus 46606	: V=0.9986716, theta=43.56883 -> V=1.0, theta=0.0
% INFO    : Bus 46607	: V=0.981344, theta=42.675846 -> V=1.0, theta=0.0
% INFO    : Bus 46608	: V=0.98776, theta=43.238928 -> V=1.0, theta=0.0
% INFO    : Bus 46609	: V=0.9813284, theta=42.801078 -> V=1.0, theta=0.0
% INFO    : Bus 46610	: V=0.9818479, theta=42.179806 -> V=1.0, theta=0.0
% INFO    : Bus 46611	: V=0.9789072, theta=41.457701 -> V=1.0, theta=0.0
% INFO    : Bus 46612	: V=0.9821257, theta=42.435172 -> V=1.0, theta=0.0
% INFO    : Bus 46613	: V=0.9828359, theta=39.090302 -> V=1.0, theta=0.0
% INFO    : Bus 46614	: V=0.9861203, theta=40.013632 -> V=1.0, theta=0.0
% INFO    : Bus 46615	: V=0.9970932, theta=41.104832 -> V=1.0, theta=0.0
% INFO    : Bus 46616	: V=1.000366, theta=40.89435 -> V=1.0, theta=0.0
% INFO    : Bus 46617	: V=1.0044779, theta=39.469074 -> V=1.0, theta=0.0
% INFO    : Bus 46618	: V=1.004766, theta=41.300044 -> V=1.0, theta=0.0
% INFO    : Bus 46619	: V=1.0124837, theta=41.662624 -> V=1.0, theta=0.0
% INFO    : Bus 46620	: V=0.967952, theta=49.072228 -> V=1.0, theta=0.0
% INFO    : Bus 46621	: V=0.9669204, theta=49.960398 -> V=1.0, theta=0.0
% INFO    : Bus 46622	: V=0.9711945, theta=49.834704 -> V=1.0, theta=0.0
% INFO    : Bus 46623	: V=0.9589651, theta=50.176394 -> V=1.0, theta=0.0
% INFO    : Bus 46624	: V=0.967545, theta=49.635062 -> V=1.0, theta=0.0
% INFO    : Bus 46625	: V=0.9925485, theta=32.336085 -> V=1.0, theta=0.0
% INFO    : Bus 46626	: V=0.9937682, theta=31.904891 -> V=1.0, theta=0.0
% INFO    : Bus 46627	: V=0.9891796, theta=32.413533 -> V=1.0, theta=0.0
% INFO    : Bus 46628	: V=1.0003421, theta=34.005218 -> V=1.0, theta=0.0
% INFO    : Bus 46629	: V=0.9992578, theta=33.576243 -> V=1.0, theta=0.0
% INFO    : Bus 46630	: V=1.0108373, theta=34.975094 -> V=1.0, theta=0.0
% INFO    : Bus 46631	: V=1.011856, theta=35.253046 -> V=1.0, theta=0.0
% INFO    : Bus 46632	: V=1.011152, theta=35.167009 -> V=1.0, theta=0.0
% INFO    : Bus 46633	: V=0.9964274, theta=32.75815 -> V=1.0, theta=0.0
% INFO    : Bus 46634	: V=0.9941148, theta=32.672357 -> V=1.0, theta=0.0
% INFO    : Bus 46635	: V=0.9930337, theta=32.458596 -> V=1.0, theta=0.0
% INFO    : Bus 46636	: V=0.9919056, theta=32.254233 -> V=1.0, theta=0.0
% INFO    : Bus 46637	: V=0.988627, theta=32.777548 -> V=1.0, theta=0.0
% INFO    : Bus 46638	: V=0.9877782, theta=32.527181 -> V=1.0, theta=0.0
% INFO    : Bus 46639	: V=0.9870603, theta=30.477736 -> V=1.0, theta=0.0
% INFO    : Bus 46640	: V=0.9870565, theta=30.938897 -> V=1.0, theta=0.0
% INFO    : Bus 46641	: V=0.9854994, theta=30.8057 -> V=1.0, theta=0.0
% INFO    : Bus 46642	: V=0.983126, theta=30.436636 -> V=1.0, theta=0.0
% INFO    : Bus 46643	: V=0.9907334, theta=31.941527 -> V=1.0, theta=0.0
% INFO    : Bus 46644	: V=0.9896774, theta=31.750991 -> V=1.0, theta=0.0
% INFO    : Bus 46645	: V=0.983677, theta=29.577595 -> V=1.0, theta=0.0
% INFO    : Bus 46646	: V=0.9879449, theta=31.332163 -> V=1.0, theta=0.0
% INFO    : Bus 46647	: V=0.9786493, theta=44.908726 -> V=1.0, theta=0.0
% INFO    : Bus 46648	: V=0.9751864, theta=44.716982 -> V=1.0, theta=0.0
% INFO    : Bus 46649	: V=0.9725082, theta=44.580312 -> V=1.0, theta=0.0
% INFO    : Bus 46650	: V=0.9889243, theta=44.326452 -> V=1.0, theta=0.0
% INFO    : Bus 46651	: V=0.9704232, theta=44.46525 -> V=1.0, theta=0.0
% INFO    : Bus 46652	: V=1.0117815, theta=33.773369 -> V=1.0, theta=0.0
% INFO    : Bus 46653	: V=1.0123237, theta=33.993239 -> V=1.0, theta=0.0
% INFO    : Bus 46654	: V=1.0116219, theta=33.585426 -> V=1.0, theta=0.0
% INFO    : Bus 46655	: V=1.0128423, theta=34.990982 -> V=1.0, theta=0.0
% INFO    : Bus 46656	: V=1.0112976, theta=34.210812 -> V=1.0, theta=0.0
% INFO    : Bus 46657	: V=1.0093604, theta=34.356348 -> V=1.0, theta=0.0
% INFO    : Bus 46658	: V=1.0114297, theta=34.375634 -> V=1.0, theta=0.0
% INFO    : Bus 46659	: V=1.0087807, theta=34.292056 -> V=1.0, theta=0.0
% INFO    : Bus 46660	: V=1.0066736, theta=34.11328 -> V=1.0, theta=0.0
% INFO    : Bus 46661	: V=1.0112696, theta=34.150133 -> V=1.0, theta=0.0
% INFO    : Bus 46662	: V=1.0076048, theta=34.174649 -> V=1.0, theta=0.0
% INFO    : Bus 46663	: V=1.0082311, theta=34.235188 -> V=1.0, theta=0.0
% INFO    : Bus 46664	: V=1.0075462, theta=35.043557 -> V=1.0, theta=0.0
% INFO    : Bus 46665	: V=1.013369, theta=34.12067 -> V=1.0, theta=0.0
% INFO    : Bus 46666	: V=1.0126412, theta=33.989698 -> V=1.0, theta=0.0
% INFO    : Bus 46667	: V=1.0097106, theta=33.779 -> V=1.0, theta=0.0
% INFO    : Bus 46668	: V=1.0121566, theta=33.746753 -> V=1.0, theta=0.0
% INFO    : Bus 46669	: V=1.0129625, theta=34.030168 -> V=1.0, theta=0.0
% INFO    : Bus 46670	: V=1.0116236, theta=33.590722 -> V=1.0, theta=0.0
% INFO    : Bus 46671	: V=1.0124565, theta=33.288586 -> V=1.0, theta=0.0
% INFO    : Bus 46672	: V=1.0119468, theta=33.955375 -> V=1.0, theta=0.0
% INFO    : Bus 46673	: V=1.0125215, theta=33.764693 -> V=1.0, theta=0.0
% INFO    : Bus 46674	: V=1.012741, theta=33.195662 -> V=1.0, theta=0.0
% INFO    : Bus 46675	: V=1.0122038, theta=32.841769 -> V=1.0, theta=0.0
% INFO    : Bus 46676	: V=1.014394, theta=32.888659 -> V=1.0, theta=0.0
% INFO    : Bus 46677	: V=1.0150881, theta=32.262003 -> V=1.0, theta=0.0
% INFO    : Bus 46678	: V=1.0144591, theta=32.633412 -> V=1.0, theta=0.0
% INFO    : Bus 46679	: V=1.0143679, theta=32.440947 -> V=1.0, theta=0.0
% INFO    : Bus 46680	: V=1.0170869, theta=32.363787 -> V=1.0, theta=0.0
% INFO    : Bus 46681	: V=1.0163219, theta=32.33122 -> V=1.0, theta=0.0
% INFO    : Bus 46682	: V=1.0150432, theta=32.198027 -> V=1.0, theta=0.0
% INFO    : Bus 46683	: V=1.0151348, theta=32.121927 -> V=1.0, theta=0.0
% INFO    : Bus 46684	: V=1.0149909, theta=32.166285 -> V=1.0, theta=0.0
% INFO    : Bus 46685	: V=1.0158465, theta=32.348009 -> V=1.0, theta=0.0
% INFO    : Bus 46686	: V=1.0131705, theta=31.796909 -> V=1.0, theta=0.0
% INFO    : Bus 46687	: V=1.0119141, theta=31.731626 -> V=1.0, theta=0.0
% INFO    : Bus 46688	: V=1.0095694, theta=31.383374 -> V=1.0, theta=0.0
% INFO    : Bus 46689	: V=1.0111146, theta=31.688478 -> V=1.0, theta=0.0
% INFO    : Bus 46690	: V=1.0143209, theta=32.256652 -> V=1.0, theta=0.0
% INFO    : Bus 46691	: V=1.0107138, theta=32.02153 -> V=1.0, theta=0.0
% INFO    : Bus 46692	: V=1.0093709, theta=31.882318 -> V=1.0, theta=0.0
% INFO    : Bus 46693	: V=1.0100804, theta=31.633758 -> V=1.0, theta=0.0
% INFO    : Bus 46694	: V=1.0124393, theta=31.161074 -> V=1.0, theta=0.0
% INFO    : Bus 46695	: V=1.0087466, theta=31.599535 -> V=1.0, theta=0.0
% INFO    : Bus 46696	: V=1.007804, theta=31.579511 -> V=1.0, theta=0.0
% INFO    : Bus 46697	: V=1.0058207, theta=31.464981 -> V=1.0, theta=0.0
% INFO    : Bus 46698	: V=1.0137135, theta=32.224187 -> V=1.0, theta=0.0
% INFO    : Bus 46699	: V=1.0074417, theta=31.676125 -> V=1.0, theta=0.0
% INFO    : Bus 46700	: V=1.0066866, theta=31.60355 -> V=1.0, theta=0.0
% INFO    : Bus 46701	: V=1.0062085, theta=31.411712 -> V=1.0, theta=0.0
% INFO    : Bus 46702	: V=1.0085455, theta=31.085871 -> V=1.0, theta=0.0
% INFO    : Bus 46703	: V=1.0072777, theta=31.566909 -> V=1.0, theta=0.0
% INFO    : Bus 46704	: V=1.0119814, theta=30.70744 -> V=1.0, theta=0.0
% INFO    : Bus 46705	: V=1.0075634, theta=31.173931 -> V=1.0, theta=0.0
% INFO    : Bus 46706	: V=1.0064009, theta=30.858572 -> V=1.0, theta=0.0
% INFO    : Bus 46707	: V=1.0062049, theta=31.002345 -> V=1.0, theta=0.0
% INFO    : Bus 46708	: V=1.006559, theta=31.472141 -> V=1.0, theta=0.0
% INFO    : Bus 46709	: V=1.0025473, theta=31.186895 -> V=1.0, theta=0.0
% INFO    : Bus 46710	: V=1.0009165, theta=30.733728 -> V=1.0, theta=0.0
% INFO    : Bus 46711	: V=1.0001177, theta=30.587925 -> V=1.0, theta=0.0
% INFO    : Bus 46712	: V=0.9983499, theta=30.824202 -> V=1.0, theta=0.0
% INFO    : Bus 46713	: V=1.004116, theta=30.854862 -> V=1.0, theta=0.0
% INFO    : Bus 46714	: V=0.9992569, theta=30.35926 -> V=1.0, theta=0.0
% INFO    : Bus 46715	: V=0.9991301, theta=31.649941 -> V=1.0, theta=0.0
% INFO    : Bus 46716	: V=0.9960741, theta=30.955596 -> V=1.0, theta=0.0
% INFO    : Bus 46717	: V=1.0046401, theta=32.437744 -> V=1.0, theta=0.0
% INFO    : Bus 46718	: V=1.0052381, theta=32.230316 -> V=1.0, theta=0.0
% INFO    : Bus 46719	: V=1.0061574, theta=32.061595 -> V=1.0, theta=0.0
% INFO    : Bus 46720	: V=1.0047196, theta=32.277565 -> V=1.0, theta=0.0
% INFO    : Bus 46721	: V=1.0049697, theta=32.288125 -> V=1.0, theta=0.0
% INFO    : Bus 46722	: V=1.0077629, theta=32.506653 -> V=1.0, theta=0.0
% INFO    : Bus 46723	: V=1.0076176, theta=32.420208 -> V=1.0, theta=0.0
% INFO    : Bus 46724	: V=1.0064159, theta=32.027776 -> V=1.0, theta=0.0
% INFO    : Bus 46725	: V=1.0078916, theta=32.413931 -> V=1.0, theta=0.0
% INFO    : Bus 46726	: V=1.0057701, theta=32.097264 -> V=1.0, theta=0.0
% INFO    : Bus 46727	: V=1.0056115, theta=32.121322 -> V=1.0, theta=0.0
% INFO    : Bus 46728	: V=1.0079426, theta=32.48684 -> V=1.0, theta=0.0
% INFO    : Bus 46729	: V=1.0081613, theta=31.725543 -> V=1.0, theta=0.0
% INFO    : Bus 46730	: V=1.0079836, theta=31.764999 -> V=1.0, theta=0.0
% INFO    : Bus 46731	: V=1.0085099, theta=32.593178 -> V=1.0, theta=0.0
% INFO    : Bus 46732	: V=1.0088786, theta=32.806748 -> V=1.0, theta=0.0
% INFO    : Bus 46733	: V=1.0058712, theta=32.540801 -> V=1.0, theta=0.0
% INFO    : Bus 46734	: V=1.0053689, theta=32.191457 -> V=1.0, theta=0.0
% INFO    : Bus 46735	: V=1.009774, theta=33.042716 -> V=1.0, theta=0.0
% INFO    : Bus 46736	: V=1.0098415, theta=33.103048 -> V=1.0, theta=0.0
% INFO    : Bus 46737	: V=1.0112186, theta=32.824314 -> V=1.0, theta=0.0
% INFO    : Bus 46738	: V=1.0090608, theta=32.855583 -> V=1.0, theta=0.0
% INFO    : Bus 46739	: V=1.0093816, theta=32.70466 -> V=1.0, theta=0.0
% INFO    : Bus 46740	: V=1.0088021, theta=32.502037 -> V=1.0, theta=0.0
% INFO    : Bus 46741	: V=1.0086123, theta=32.746634 -> V=1.0, theta=0.0
% INFO    : Bus 46742	: V=1.0130128, theta=32.735852 -> V=1.0, theta=0.0
% INFO    : Bus 46743	: V=1.0107703, theta=33.289807 -> V=1.0, theta=0.0
% INFO    : Bus 46744	: V=1.0100249, theta=32.906669 -> V=1.0, theta=0.0
% INFO    : Bus 46745	: V=1.0118732, theta=33.519576 -> V=1.0, theta=0.0
% INFO    : Bus 46746	: V=1.0063776, theta=33.358919 -> V=1.0, theta=0.0
% INFO    : Bus 46747	: V=1.0057824, theta=33.320663 -> V=1.0, theta=0.0
% INFO    : Bus 46748	: V=1.0032541, theta=32.925313 -> V=1.0, theta=0.0
% INFO    : Bus 46749	: V=1.0108611, theta=33.523768 -> V=1.0, theta=0.0
% INFO    : Bus 46750	: V=1.0103071, theta=33.267207 -> V=1.0, theta=0.0
% INFO    : Bus 46751	: V=1.0030665, theta=32.541207 -> V=1.0, theta=0.0
% INFO    : Bus 46752	: V=1.0081065, theta=33.162529 -> V=1.0, theta=0.0
% INFO    : Bus 46753	: V=1.0080098, theta=32.756838 -> V=1.0, theta=0.0
% INFO    : Bus 46754	: V=1.0022606, theta=32.31361 -> V=1.0, theta=0.0
% INFO    : Bus 46755	: V=1.0010345, theta=32.122785 -> V=1.0, theta=0.0
% INFO    : Bus 46756	: V=1.0088678, theta=33.767862 -> V=1.0, theta=0.0
% INFO    : Bus 46757	: V=1.0055881, theta=33.656183 -> V=1.0, theta=0.0
% INFO    : Bus 46758	: V=1.0054575, theta=33.337263 -> V=1.0, theta=0.0
% INFO    : Bus 46759	: V=1.011705, theta=33.898285 -> V=1.0, theta=0.0
% INFO    : Bus 46760	: V=1.0130969, theta=34.224857 -> V=1.0, theta=0.0
% INFO    : Bus 46761	: V=1.0094195, theta=33.955356 -> V=1.0, theta=0.0
% INFO    : Bus 46762	: V=1.0121023, theta=33.934428 -> V=1.0, theta=0.0
% INFO    : Bus 46763	: V=1.0136962, theta=34.408209 -> V=1.0, theta=0.0
% INFO    : Bus 46764	: V=1.0077127, theta=33.804243 -> V=1.0, theta=0.0
% INFO    : Bus 46765	: V=1.0086893, theta=33.768465 -> V=1.0, theta=0.0
% INFO    : Bus 46766	: V=0.9567737, theta=51.07691 -> V=1.0, theta=0.0
% INFO    : Bus 46767	: V=0.981994, theta=50.198217 -> V=1.0, theta=0.0
% INFO    : Bus 46768	: V=0.9851226, theta=50.181608 -> V=1.0, theta=0.0
% INFO    : Bus 46769	: V=0.9836427, theta=50.133935 -> V=1.0, theta=0.0
% INFO    : Bus 46770	: V=0.9945497, theta=50.534167 -> V=1.0, theta=0.0
% INFO    : Bus 46771	: V=0.9866924, theta=49.769695 -> V=1.0, theta=0.0
% INFO    : Bus 46772	: V=0.9934512, theta=50.552062 -> V=1.0, theta=0.0
% INFO    : Bus 46773	: V=0.9856336, theta=49.677242 -> V=1.0, theta=0.0
% INFO    : Bus 46774	: V=0.988527, theta=50.445852 -> V=1.0, theta=0.0
% INFO    : Bus 46775	: V=0.9931368, theta=50.466367 -> V=1.0, theta=0.0
% INFO    : Bus 46776	: V=0.9580229, theta=50.962575 -> V=1.0, theta=0.0
% INFO    : Bus 46777	: V=0.9860057, theta=50.530733 -> V=1.0, theta=0.0
% INFO    : Bus 46778	: V=0.9790998, theta=48.789525 -> V=1.0, theta=0.0
% INFO    : Bus 46779	: V=0.9813734, theta=49.234479 -> V=1.0, theta=0.0
% INFO    : Bus 46780	: V=0.9716848, theta=46.584059 -> V=1.0, theta=0.0
% INFO    : Bus 46781	: V=0.9489842, theta=44.15211 -> V=1.0, theta=0.0
% INFO    : Bus 46782	: V=0.9572518, theta=42.941686 -> V=1.0, theta=0.0
% INFO    : Bus 46783	: V=0.9586019, theta=42.899004 -> V=1.0, theta=0.0
% INFO    : Bus 46784	: V=0.9524042, theta=44.029242 -> V=1.0, theta=0.0
% INFO    : Bus 46785	: V=0.9777429, theta=45.140188 -> V=1.0, theta=0.0
% INFO    : Bus 46786	: V=0.9776902, theta=45.224077 -> V=1.0, theta=0.0
% INFO    : Bus 46787	: V=0.9784466, theta=45.278948 -> V=1.0, theta=0.0
% INFO    : Bus 46788	: V=0.9904984, theta=46.327333 -> V=1.0, theta=0.0
% INFO    : Bus 46789	: V=0.9780771, theta=45.279991 -> V=1.0, theta=0.0
% INFO    : Bus 46790	: V=0.9893565, theta=45.902403 -> V=1.0, theta=0.0
% INFO    : Bus 46791	: V=0.9796272, theta=45.346676 -> V=1.0, theta=0.0
% INFO    : Bus 46792	: V=0.9796156, theta=45.415323 -> V=1.0, theta=0.0
% INFO    : Bus 46793	: V=0.9785441, theta=45.24377 -> V=1.0, theta=0.0
% INFO    : Bus 46794	: V=0.9776166, theta=45.128118 -> V=1.0, theta=0.0
% INFO    : Bus 46795	: V=0.9886808, theta=45.601965 -> V=1.0, theta=0.0
% INFO    : Bus 46796	: V=0.9878918, theta=45.198588 -> V=1.0, theta=0.0
% INFO    : Bus 46797	: V=0.9882411, theta=44.896799 -> V=1.0, theta=0.0
% INFO    : Bus 46798	: V=0.9876473, theta=44.650015 -> V=1.0, theta=0.0
% INFO    : Bus 46799	: V=0.9932857, theta=47.193318 -> V=1.0, theta=0.0
% INFO    : Bus 46800	: V=0.9913494, theta=47.067236 -> V=1.0, theta=0.0
% INFO    : Bus 46801	: V=0.9723369, theta=44.817965 -> V=1.0, theta=0.0
% INFO    : Bus 46802	: V=0.9751378, theta=45.102949 -> V=1.0, theta=0.0
% INFO    : Bus 46803	: V=0.9764874, theta=45.283915 -> V=1.0, theta=0.0
% INFO    : Bus 46804	: V=1.0054166, theta=42.169727 -> V=1.0, theta=0.0
% INFO    : Bus 46805	: V=0.983715, theta=43.609657 -> V=1.0, theta=0.0
% INFO    : Bus 46806	: V=0.9692029, theta=44.207475 -> V=1.0, theta=0.0
% INFO    : Bus 46807	: V=0.974645, theta=46.064933 -> V=1.0, theta=0.0
% INFO    : Bus 46808	: V=0.978322, theta=48.06515 -> V=1.0, theta=0.0
% INFO    : Bus 46809	: V=0.992388, theta=49.873146 -> V=1.0, theta=0.0
% INFO    : Bus 46810	: V=1.007186, theta=50.162149 -> V=1.0, theta=0.0
% INFO    : Bus 46811	: V=0.9965458, theta=50.983699 -> V=1.0, theta=0.0
% INFO    : Bus 46812	: V=0.9939195, theta=50.671867 -> V=1.0, theta=0.0
% INFO    : Bus 46813	: V=0.9973097, theta=50.999023 -> V=1.0, theta=0.0
% INFO    : Bus 46814	: V=0.9926345, theta=50.431089 -> V=1.0, theta=0.0
% INFO    : Bus 46815	: V=0.9943883, theta=50.708467 -> V=1.0, theta=0.0
% INFO    : Bus 46816	: V=0.9921399, theta=50.310113 -> V=1.0, theta=0.0
% INFO    : Bus 46817	: V=1.00727, theta=50.06999 -> V=1.0, theta=0.0
% INFO    : Bus 46818	: V=0.9992981, theta=50.49301 -> V=1.0, theta=0.0
% INFO    : Bus 46819	: V=0.9934358, theta=49.977071 -> V=1.0, theta=0.0
% INFO    : Bus 46820	: V=0.9935934, theta=49.970472 -> V=1.0, theta=0.0
% INFO    : Bus 46821	: V=1.0061908, theta=49.44794 -> V=1.0, theta=0.0
% INFO    : Bus 46822	: V=0.9927351, theta=49.605161 -> V=1.0, theta=0.0
% INFO    : Bus 46823	: V=0.9930439, theta=49.990391 -> V=1.0, theta=0.0
% INFO    : Bus 46824	: V=1.0069657, theta=46.3634 -> V=1.0, theta=0.0
% INFO    : Bus 46825	: V=1.0067442, theta=46.180152 -> V=1.0, theta=0.0
% INFO    : Bus 46826	: V=0.985924, theta=47.590032 -> V=1.0, theta=0.0
% INFO    : Bus 46827	: V=0.981285, theta=47.063894 -> V=1.0, theta=0.0
% INFO    : Bus 46828	: V=0.9637193, theta=47.143277 -> V=1.0, theta=0.0
% INFO    : Bus 46829	: V=0.9802533, theta=46.929124 -> V=1.0, theta=0.0
% INFO    : Bus 46830	: V=0.9668659, theta=47.169997 -> V=1.0, theta=0.0
% INFO    : Bus 46831	: V=0.9643721, theta=47.122935 -> V=1.0, theta=0.0
% INFO    : Bus 46832	: V=0.9770301, theta=47.554667 -> V=1.0, theta=0.0
% INFO    : Bus 46833	: V=1.0037069, theta=48.279248 -> V=1.0, theta=0.0
% INFO    : Bus 46834	: V=1.0105948, theta=49.819199 -> V=1.0, theta=0.0
% INFO    : Bus 46835	: V=1.0097406, theta=50.578455 -> V=1.0, theta=0.0
% INFO    : Bus 46836	: V=1.0052116, theta=50.301067 -> V=1.0, theta=0.0
% INFO    : Bus 46837	: V=1.0141448, theta=50.436033 -> V=1.0, theta=0.0
% INFO    : Bus 46838	: V=1.0143927, theta=50.740563 -> V=1.0, theta=0.0
% INFO    : Bus 46839	: V=1.0128302, theta=50.743192 -> V=1.0, theta=0.0
% INFO    : Bus 46840	: V=1.0116584, theta=50.795869 -> V=1.0, theta=0.0
% INFO    : Bus 46841	: V=1.0063262, theta=48.740409 -> V=1.0, theta=0.0
% INFO    : Bus 46842	: V=1.0096562, theta=49.913911 -> V=1.0, theta=0.0
% INFO    : Bus 46843	: V=1.02, theta=-22.779505 -> V=1.0, theta=0.0
% INFO    : Bus 46844	: V=1.02, theta=-29.76157 -> V=1.0, theta=0.0
% INFO    : Bus 46845	: V=1.02, theta=-18.681706 -> V=1.0, theta=0.0
% INFO    : Bus 46846	: V=1.02, theta=-18.559455 -> V=1.0, theta=0.0
% INFO    : Bus 46847	: V=1.02, theta=-28.157014 -> V=1.0, theta=0.0
% INFO    : Bus 46848	: V=1.02, theta=-22.089852 -> V=1.0, theta=0.0
% INFO    : Bus 46849	: V=1.02, theta=-32.002077 -> V=1.0, theta=0.0
% INFO    : Bus 46850	: V=1.02, theta=-14.929062 -> V=1.0, theta=0.0
% INFO    : Bus 46851	: V=1.02, theta=-32.827252 -> V=1.0, theta=0.0
% INFO    : Bus 46852	: V=1.0186549, theta=-29.861335 -> V=1.0, theta=0.0
% INFO    : Bus 46853	: V=1.02, theta=-34.520506 -> V=1.0, theta=0.0
% INFO    : Bus 46854	: V=1.0083697, theta=-45.691899 -> V=1.0, theta=0.0
% INFO    : Bus 46855	: V=1.02, theta=-35.119587 -> V=1.0, theta=0.0
% INFO    : Bus 46856	: V=1.0194361, theta=-26.40076 -> V=1.0, theta=0.0
% INFO    : Bus 46857	: V=1.02, theta=-22.281117 -> V=1.0, theta=0.0
% INFO    : Bus 46858	: V=1.02, theta=-27.832081 -> V=1.0, theta=0.0
% INFO    : Bus 46859	: V=1.0143674, theta=-30.788865 -> V=1.0, theta=0.0
% INFO    : Bus 46860	: V=1.0170844, theta=-30.379695 -> V=1.0, theta=0.0
% INFO    : Bus 46861	: V=1.02, theta=-20.507657 -> V=1.0, theta=0.0
% INFO    : Bus 46862	: V=0.9907918, theta=-26.926138 -> V=1.0, theta=0.0
% INFO    : Bus 46863	: V=1.02, theta=-29.965949 -> V=1.0, theta=0.0
% INFO    : Bus 46864	: V=0.9902279, theta=-28.057188 -> V=1.0, theta=0.0
% INFO    : Bus 46865	: V=1.0052449, theta=-47.748243 -> V=1.0, theta=0.0
% INFO    : Bus 46866	: V=1.015785, theta=-22.747057 -> V=1.0, theta=0.0
% INFO    : Bus 46867	: V=1.0174015, theta=-25.574456 -> V=1.0, theta=0.0
% INFO    : Bus 46868	: V=1.02, theta=-32.350423 -> V=1.0, theta=0.0
% INFO    : Bus 46869	: V=1.0152928, theta=-36.512938 -> V=1.0, theta=0.0
% INFO    : Bus 46870	: V=1.02, theta=-21.857038 -> V=1.0, theta=0.0
% INFO    : Bus 46871	: V=1.0149967, theta=-34.809634 -> V=1.0, theta=0.0
% INFO    : Bus 46872	: V=0.9795959, theta=-35.545259 -> V=1.0, theta=0.0
% INFO    : Bus 46873	: V=0.9905522, theta=-30.039845 -> V=1.0, theta=0.0
% INFO    : Bus 46874	: V=1.02, theta=-33.694878 -> V=1.0, theta=0.0
% INFO    : Bus 46875	: V=1.0187837, theta=-46.792989 -> V=1.0, theta=0.0
% INFO    : Bus 46876	: V=1.002028, theta=-42.262203 -> V=1.0, theta=0.0
% INFO    : Bus 46877	: V=1.0041804, theta=-39.165815 -> V=1.0, theta=0.0
% INFO    : Bus 46878	: V=0.9903634, theta=-32.28284 -> V=1.0, theta=0.0
% INFO    : Bus 46879	: V=1.0011762, theta=-29.649772 -> V=1.0, theta=0.0
% INFO    : Bus 46880	: V=1.0214007, theta=-17.415238 -> V=1.0, theta=0.0
% INFO    : Bus 46881	: V=1.0193421, theta=-26.523965 -> V=1.0, theta=0.0
% INFO    : Bus 46882	: V=1.0187261, theta=-29.847868 -> V=1.0, theta=0.0
% INFO    : Bus 46883	: V=0.9870604, theta=-35.206444 -> V=1.0, theta=0.0
% INFO    : Bus 46884	: V=1.02, theta=-59.846223 -> V=1.0, theta=0.0
% INFO    : Bus 46885	: V=1.02, theta=-58.745065 -> V=1.0, theta=0.0
% INFO    : Bus 46886	: V=1.02, theta=-55.608149 -> V=1.0, theta=0.0
% INFO    : Bus 46887	: V=1.02, theta=-58.988125 -> V=1.0, theta=0.0
% INFO    : Bus 46888	: V=1.02, theta=-64.127327 -> V=1.0, theta=0.0
% INFO    : Bus 46889	: V=1.02, theta=-53.693394 -> V=1.0, theta=0.0
% INFO    : Bus 46890	: V=1.02, theta=-60.765627 -> V=1.0, theta=0.0
% INFO    : Bus 46891	: V=1.02, theta=-59.921795 -> V=1.0, theta=0.0
% INFO    : Bus 46892	: V=1.02, theta=-63.90063 -> V=1.0, theta=0.0
% INFO    : Bus 46893	: V=1.02, theta=-39.569249 -> V=1.0, theta=0.0
% INFO    : Bus 46894	: V=1.02, theta=-39.002153 -> V=1.0, theta=0.0
% INFO    : Bus 46895	: V=1.02, theta=-61.487789 -> V=1.0, theta=0.0
% INFO    : Bus 46896	: V=1.02, theta=-64.801928 -> V=1.0, theta=0.0
% INFO    : Bus 46897	: V=1.02, theta=-60.212371 -> V=1.0, theta=0.0
% INFO    : Bus 46898	: V=1.0196254, theta=-61.897684 -> V=1.0, theta=0.0
% INFO    : Bus 46899	: V=1.02, theta=-58.239855 -> V=1.0, theta=0.0
% INFO    : Bus 46900	: V=1.02, theta=-36.870025 -> V=1.0, theta=0.0
% INFO    : Bus 46901	: V=1.02, theta=-60.761588 -> V=1.0, theta=0.0
% INFO    : Bus 46902	: V=1.0190602, theta=-65.04254 -> V=1.0, theta=0.0
% INFO    : Bus 46903	: V=1.02, theta=-60.858044 -> V=1.0, theta=0.0
% INFO    : Bus 46904	: V=1.02, theta=-59.900376 -> V=1.0, theta=0.0
% INFO    : Bus 46905	: V=1.02, theta=-63.21974 -> V=1.0, theta=0.0
% INFO    : Bus 46906	: V=1.0161276, theta=-61.291181 -> V=1.0, theta=0.0
% INFO    : Bus 46907	: V=0.9885057, theta=-59.902797 -> V=1.0, theta=0.0
% INFO    : Bus 46908	: V=1.02, theta=-61.325649 -> V=1.0, theta=0.0
% INFO    : Bus 46909	: V=1.0175059, theta=-64.351455 -> V=1.0, theta=0.0
% INFO    : Bus 46910	: V=1.0194399, theta=-61.568734 -> V=1.0, theta=0.0
% INFO    : Bus 46911	: V=1.0195707, theta=-63.216148 -> V=1.0, theta=0.0
% INFO    : Bus 46912	: V=0.980007, theta=-67.912127 -> V=1.0, theta=0.0
% INFO    : Bus 46913	: V=0.9950042, theta=-57.911007 -> V=1.0, theta=0.0
% INFO    : Bus 46914	: V=1.0200048, theta=-61.483812 -> V=1.0, theta=0.0
% INFO    : Bus 46915	: V=1.0017136, theta=-53.42955 -> V=1.0, theta=0.0
% INFO    : Bus 46916	: V=1.02, theta=-61.857531 -> V=1.0, theta=0.0
% INFO    : Bus 46917	: V=1.0072794, theta=-61.18726 -> V=1.0, theta=0.0
% INFO    : Bus 46918	: V=1.02, theta=-38.585748 -> V=1.0, theta=0.0
% INFO    : Bus 46919	: V=0.9814337, theta=-71.822613 -> V=1.0, theta=0.0
% INFO    : Bus 46920	: V=1.0108063, theta=-57.200251 -> V=1.0, theta=0.0
% INFO    : Bus 46921	: V=0.9846376, theta=-67.087642 -> V=1.0, theta=0.0
% INFO    : Bus 46922	: V=1.02, theta=-64.970071 -> V=1.0, theta=0.0
% INFO    : Bus 46923	: V=1.0096289, theta=-62.740864 -> V=1.0, theta=0.0
% INFO    : Bus 46924	: V=0.9774838, theta=-68.240752 -> V=1.0, theta=0.0
% INFO    : Bus 46925	: V=0.9837177, theta=-67.717125 -> V=1.0, theta=0.0
% INFO    : Bus 46926	: V=0.9792528, theta=-67.900895 -> V=1.0, theta=0.0
% INFO    : Bus 46927	: V=0.9804838, theta=-67.78674 -> V=1.0, theta=0.0
% INFO    : Bus 46928	: V=0.9678646, theta=-55.539835 -> V=1.0, theta=0.0
% INFO    : Bus 46929	: V=0.9823278, theta=-68.32424 -> V=1.0, theta=0.0
% INFO    : Bus 46930	: V=1.008349, theta=-43.558151 -> V=1.0, theta=0.0
% INFO    : Bus 46931	: V=1.0147137, theta=-65.698294 -> V=1.0, theta=0.0
% INFO    : Bus 46932	: V=1.0053248, theta=-57.811685 -> V=1.0, theta=0.0
% INFO    : Bus 46933	: V=1.0041013, theta=-62.883566 -> V=1.0, theta=0.0
% INFO    : Bus 46934	: V=1.0095021, theta=-64.086479 -> V=1.0, theta=0.0
% INFO    : Bus 46935	: V=1.017657, theta=-59.381509 -> V=1.0, theta=0.0
% INFO    : Bus 46936	: V=0.9812436, theta=-67.914092 -> V=1.0, theta=0.0
% INFO    : Bus 46937	: V=1.02, theta=-68.687483 -> V=1.0, theta=0.0
% INFO    : Bus 46938	: V=0.993226, theta=-64.556044 -> V=1.0, theta=0.0
% INFO    : Bus 46939	: V=1.0088373, theta=-62.823597 -> V=1.0, theta=0.0
% INFO    : Bus 46940	: V=0.979076, theta=-72.739185 -> V=1.0, theta=0.0
% INFO    : Bus 46941	: V=1.02, theta=-69.011925 -> V=1.0, theta=0.0
% INFO    : Bus 46942	: V=0.9507476, theta=-76.836872 -> V=1.0, theta=0.0
% INFO    : Bus 46943	: V=1.0049051, theta=-63.742301 -> V=1.0, theta=0.0
% INFO    : Bus 46944	: V=0.9991381, theta=-44.212044 -> V=1.0, theta=0.0
% INFO    : Bus 46945	: V=1.02, theta=7.085147 -> V=1.0, theta=0.0
% INFO    : Bus 46946	: V=1.02, theta=-2.045917 -> V=1.0, theta=0.0
% INFO    : Bus 46947	: V=1.02, theta=-11.54564 -> V=1.0, theta=0.0
% INFO    : Bus 46948	: V=1.02, theta=-5.667106 -> V=1.0, theta=0.0
% INFO    : Bus 46949	: V=1.02, theta=-6.803578 -> V=1.0, theta=0.0
% INFO    : Bus 46950	: V=1.02, theta=-0.595814 -> V=1.0, theta=0.0
% INFO    : Bus 46951	: V=1.02, theta=1.451256 -> V=1.0, theta=0.0
% INFO    : Bus 46952	: V=1.02, theta=-6.281862 -> V=1.0, theta=0.0
% INFO    : Bus 46953	: V=1.0198916, theta=-9.676106 -> V=1.0, theta=0.0
% INFO    : Bus 46954	: V=1.0288024, theta=-12.055017 -> V=1.0, theta=0.0
% INFO    : Bus 46955	: V=0.9928967, theta=-18.917472 -> V=1.0, theta=0.0
% INFO    : Bus 46956	: V=1.02, theta=-8.459178 -> V=1.0, theta=0.0
% INFO    : Bus 46957	: V=1.02, theta=-22.077607 -> V=1.0, theta=0.0
% INFO    : Bus 46958	: V=1.02, theta=-2.832503 -> V=1.0, theta=0.0
% INFO    : Bus 46959	: V=0.986989, theta=-21.801559 -> V=1.0, theta=0.0
% INFO    : Bus 46960	: V=1.02, theta=-5.622537 -> V=1.0, theta=0.0
% INFO    : Bus 46961	: V=1.02, theta=8.917607 -> V=1.0, theta=0.0
% INFO    : Bus 46962	: V=1.02, theta=2.970924 -> V=1.0, theta=0.0
% INFO    : Bus 46963	: V=1.02, theta=1.435956 -> V=1.0, theta=0.0
% INFO    : Bus 46964	: V=1.02, theta=-1.592709 -> V=1.0, theta=0.0
% INFO    : Bus 46965	: V=1.02, theta=-1.989206 -> V=1.0, theta=0.0
% INFO    : Bus 46966	: V=1.02, theta=-9.657159 -> V=1.0, theta=0.0
% INFO    : Bus 46967	: V=1.02, theta=-7.454605 -> V=1.0, theta=0.0
% INFO    : Bus 46968	: V=1.02, theta=7.943986 -> V=1.0, theta=0.0
% INFO    : Bus 46969	: V=1.0004878, theta=-6.241177 -> V=1.0, theta=0.0
% INFO    : Bus 46970	: V=1.0127241, theta=-7.620328 -> V=1.0, theta=0.0
% INFO    : Bus 46971	: V=0.9950547, theta=-3.870063 -> V=1.0, theta=0.0
% INFO    : Bus 46972	: V=1.0121027, theta=-7.802013 -> V=1.0, theta=0.0
% INFO    : Bus 46973	: V=1.0020848, theta=-3.472114 -> V=1.0, theta=0.0
% INFO    : Bus 46974	: V=1.0113223, theta=2.320597 -> V=1.0, theta=0.0
% INFO    : Bus 46975	: V=1.0156139, theta=5.543612 -> V=1.0, theta=0.0
% INFO    : Bus 46976	: V=1.02, theta=-21.731794 -> V=1.0, theta=0.0
% INFO    : Bus 46977	: V=1.02, theta=6.003591 -> V=1.0, theta=0.0
% INFO    : Bus 46978	: V=1.0112455, theta=-21.443004 -> V=1.0, theta=0.0
% INFO    : Bus 46979	: V=1.02, theta=0.412335 -> V=1.0, theta=0.0
% INFO    : Bus 46980	: V=1.0045306, theta=0.824313 -> V=1.0, theta=0.0
% INFO    : Bus 46981	: V=0.9998953, theta=-14.437515 -> V=1.0, theta=0.0
% INFO    : Bus 46982	: V=1.0151351, theta=-1.003923 -> V=1.0, theta=0.0
% INFO    : Bus 46983	: V=1.0184159, theta=2.23814 -> V=1.0, theta=0.0
% INFO    : Bus 46984	: V=1.02, theta=-6.008206 -> V=1.0, theta=0.0
% INFO    : Bus 46985	: V=1.0227428, theta=-23.131672 -> V=1.0, theta=0.0
% INFO    : Bus 46986	: V=0.9817013, theta=-4.821968 -> V=1.0, theta=0.0
% INFO    : Bus 46987	: V=1.0036188, theta=0.415592 -> V=1.0, theta=0.0
% INFO    : Bus 46988	: V=0.9952154, theta=-22.514882 -> V=1.0, theta=0.0
% INFO    : Bus 46989	: V=1.018331, theta=-13.035211 -> V=1.0, theta=0.0
% INFO    : Bus 46990	: V=1.0154041, theta=1.545707 -> V=1.0, theta=0.0
% INFO    : Bus 46991	: V=1.0016871, theta=-1.989167 -> V=1.0, theta=0.0
% INFO    : Bus 46992	: V=0.9909308, theta=-7.000611 -> V=1.0, theta=0.0
% INFO    : Bus 46993	: V=1.0039782, theta=-8.155689 -> V=1.0, theta=0.0
% INFO    : Bus 46994	: V=1.0001289, theta=-8.477266 -> V=1.0, theta=0.0
% INFO    : Bus 46995	: V=0.9961186, theta=-6.732015 -> V=1.0, theta=0.0
% INFO    : Bus 46996	: V=1.02, theta=-13.22039 -> V=1.0, theta=0.0
% INFO    : Bus 46997	: V=1.0089037, theta=-8.004478 -> V=1.0, theta=0.0
% INFO    : Bus 46998	: V=1.02, theta=9.6303 -> V=1.0, theta=0.0
% INFO    : Bus 46999	: V=1.02, theta=10.320102 -> V=1.0, theta=0.0
% INFO    : Bus 47000	: V=1.02, theta=-6.205337 -> V=1.0, theta=0.0
% INFO    : Bus 47001	: V=0.9818664, theta=-5.076573 -> V=1.0, theta=0.0
% INFO    : Bus 47002	: V=1.0105103, theta=-7.150471 -> V=1.0, theta=0.0
% INFO    : Bus 47003	: V=1.0038737, theta=-7.019869 -> V=1.0, theta=0.0
% INFO    : Bus 47004	: V=0.985479, theta=-4.058644 -> V=1.0, theta=0.0
% INFO    : Bus 47005	: V=0.9866561, theta=-13.915527 -> V=1.0, theta=0.0
% INFO    : Bus 47006	: V=1.0103464, theta=1.208909 -> V=1.0, theta=0.0
% INFO    : Bus 47007	: V=1.0175982, theta=-22.716682 -> V=1.0, theta=0.0
% INFO    : Bus 47008	: V=1.0103587, theta=-20.048095 -> V=1.0, theta=0.0
% INFO    : Bus 47009	: V=1.0100905, theta=-12.506452 -> V=1.0, theta=0.0
% INFO    : Bus 47010	: V=0.9988898, theta=0.629287 -> V=1.0, theta=0.0
% INFO    : Bus 47011	: V=1.0282219, theta=-25.289532 -> V=1.0, theta=0.0
% INFO    : Bus 47012	: V=0.9882334, theta=-29.947646 -> V=1.0, theta=0.0
% INFO    : Bus 47013	: V=0.9971073, theta=-29.349517 -> V=1.0, theta=0.0
% INFO    : Bus 47014	: V=0.995985, theta=-29.271024 -> V=1.0, theta=0.0
% INFO    : Bus 47015	: V=0.9836196, theta=-30.275908 -> V=1.0, theta=0.0
% INFO    : Bus 47016	: V=1.000185, theta=-29.159951 -> V=1.0, theta=0.0
% INFO    : Bus 47017	: V=1.0176606, theta=-27.346413 -> V=1.0, theta=0.0
% INFO    : Bus 47018	: V=1.0086854, theta=-29.341588 -> V=1.0, theta=0.0
% INFO    : Bus 47019	: V=0.994659, theta=-37.870886 -> V=1.0, theta=0.0
% INFO    : Bus 47020	: V=0.997251, theta=-38.010358 -> V=1.0, theta=0.0
% INFO    : Bus 47021	: V=0.9975013, theta=-38.664143 -> V=1.0, theta=0.0
% INFO    : Bus 47022	: V=0.9967362, theta=-39.457158 -> V=1.0, theta=0.0
% INFO    : Bus 47023	: V=1.0023248, theta=-39.04519 -> V=1.0, theta=0.0
% INFO    : Bus 47024	: V=1.0030841, theta=-39.305936 -> V=1.0, theta=0.0
% INFO    : Bus 47025	: V=1.0176752, theta=-38.531563 -> V=1.0, theta=0.0
% INFO    : Bus 47026	: V=0.9936422, theta=-23.791472 -> V=1.0, theta=0.0
% INFO    : Bus 47027	: V=1.0087433, theta=-23.080291 -> V=1.0, theta=0.0
% INFO    : Bus 47028	: V=1.0065018, theta=-23.158967 -> V=1.0, theta=0.0
% INFO    : Bus 47029	: V=1.0066297, theta=-22.637254 -> V=1.0, theta=0.0
% INFO    : Bus 47030	: V=1.0059665, theta=-23.941215 -> V=1.0, theta=0.0
% INFO    : Bus 47031	: V=1.0083168, theta=-23.313075 -> V=1.0, theta=0.0
% INFO    : Bus 47032	: V=0.9953478, theta=-23.581915 -> V=1.0, theta=0.0
% INFO    : Bus 47033	: V=0.9924583, theta=-23.787526 -> V=1.0, theta=0.0
% INFO    : Bus 47034	: V=1.007907, theta=-22.538725 -> V=1.0, theta=0.0
% INFO    : Bus 47035	: V=0.9697636, theta=-30.123754 -> V=1.0, theta=0.0
% INFO    : Bus 47036	: V=0.9527773, theta=-31.772949 -> V=1.0, theta=0.0
% INFO    : Bus 47037	: V=0.9582519, theta=-31.493414 -> V=1.0, theta=0.0
% INFO    : Bus 47038	: V=0.9698947, theta=-30.577393 -> V=1.0, theta=0.0
% INFO    : Bus 47039	: V=0.9647541, theta=-31.155335 -> V=1.0, theta=0.0
% INFO    : Bus 47040	: V=0.970016, theta=-30.66746 -> V=1.0, theta=0.0
% INFO    : Bus 47041	: V=0.9673679, theta=-30.801614 -> V=1.0, theta=0.0
% INFO    : Bus 47042	: V=0.957844, theta=-31.566337 -> V=1.0, theta=0.0
% INFO    : Bus 47043	: V=0.9564857, theta=-31.667984 -> V=1.0, theta=0.0
% INFO    : Bus 47044	: V=0.9613954, theta=-31.434704 -> V=1.0, theta=0.0
% INFO    : Bus 47045	: V=0.9641204, theta=-31.335115 -> V=1.0, theta=0.0
% INFO    : Bus 47046	: V=0.9646241, theta=-31.154544 -> V=1.0, theta=0.0
% INFO    : Bus 47047	: V=0.9668578, theta=-31.153587 -> V=1.0, theta=0.0
% INFO    : Bus 47048	: V=0.9807361, theta=-30.20932 -> V=1.0, theta=0.0
% INFO    : Bus 47049	: V=0.9580274, theta=-31.431969 -> V=1.0, theta=0.0
% INFO    : Bus 47050	: V=0.9621089, theta=-31.373922 -> V=1.0, theta=0.0
% INFO    : Bus 47051	: V=0.9541915, theta=-31.834781 -> V=1.0, theta=0.0
% INFO    : Bus 47052	: V=0.9621479, theta=-31.25277 -> V=1.0, theta=0.0
% INFO    : Bus 47053	: V=0.9748605, theta=-29.902431 -> V=1.0, theta=0.0
% INFO    : Bus 47054	: V=0.9710302, theta=-29.855484 -> V=1.0, theta=0.0
% INFO    : Bus 47055	: V=0.9723143, theta=-29.877773 -> V=1.0, theta=0.0
% INFO    : Bus 47056	: V=0.9689057, theta=-29.531647 -> V=1.0, theta=0.0
% INFO    : Bus 47057	: V=0.9629649, theta=-30.815191 -> V=1.0, theta=0.0
% INFO    : Bus 47058	: V=0.9607473, theta=-30.997354 -> V=1.0, theta=0.0
% INFO    : Bus 47059	: V=0.9598451, theta=-30.874135 -> V=1.0, theta=0.0
% INFO    : Bus 47060	: V=0.9596223, theta=-30.874486 -> V=1.0, theta=0.0
% INFO    : Bus 47061	: V=0.9625677, theta=-30.84494 -> V=1.0, theta=0.0
% INFO    : Bus 47062	: V=0.9639182, theta=-30.700634 -> V=1.0, theta=0.0
% INFO    : Bus 47063	: V=0.9679523, theta=-30.690426 -> V=1.0, theta=0.0
% INFO    : Bus 47064	: V=0.9640372, theta=-30.806176 -> V=1.0, theta=0.0
% INFO    : Bus 47065	: V=0.970849, theta=-29.723323 -> V=1.0, theta=0.0
% INFO    : Bus 47066	: V=0.9972993, theta=-28.944395 -> V=1.0, theta=0.0
% INFO    : Bus 47067	: V=1.0192798, theta=-28.363509 -> V=1.0, theta=0.0
% INFO    : Bus 47068	: V=1.0040617, theta=-28.995865 -> V=1.0, theta=0.0
% INFO    : Bus 47069	: V=1.0062637, theta=-28.793787 -> V=1.0, theta=0.0
% INFO    : Bus 47070	: V=1.0029019, theta=-29.005923 -> V=1.0, theta=0.0
% INFO    : Bus 47071	: V=1.0000089, theta=-29.043021 -> V=1.0, theta=0.0
% INFO    : Bus 47072	: V=0.9799587, theta=-29.801354 -> V=1.0, theta=0.0
% INFO    : Bus 47073	: V=0.9890127, theta=-29.483529 -> V=1.0, theta=0.0
% INFO    : Bus 47074	: V=0.9661169, theta=-31.15778 -> V=1.0, theta=0.0
% INFO    : Bus 47075	: V=0.9835281, theta=-30.106334 -> V=1.0, theta=0.0
% INFO    : Bus 47076	: V=0.9640838, theta=-31.568132 -> V=1.0, theta=0.0
% INFO    : Bus 47077	: V=0.9872261, theta=-29.975785 -> V=1.0, theta=0.0
% INFO    : Bus 47078	: V=0.9829469, theta=-28.27763 -> V=1.0, theta=0.0
% INFO    : Bus 47079	: V=0.9874109, theta=-27.568299 -> V=1.0, theta=0.0
% INFO    : Bus 47080	: V=0.9641933, theta=-31.45907 -> V=1.0, theta=0.0
% INFO    : Bus 47081	: V=0.9813523, theta=-28.606775 -> V=1.0, theta=0.0
% INFO    : Bus 47082	: V=0.9687104, theta=-31.395741 -> V=1.0, theta=0.0
% INFO    : Bus 47083	: V=0.9829044, theta=-28.651327 -> V=1.0, theta=0.0
% INFO    : Bus 47084	: V=0.9823371, theta=-25.344318 -> V=1.0, theta=0.0
% INFO    : Bus 47085	: V=0.9897056, theta=-25.005334 -> V=1.0, theta=0.0
% INFO    : Bus 47086	: V=0.9791267, theta=-25.460887 -> V=1.0, theta=0.0
% INFO    : Bus 47087	: V=1.0089107, theta=-23.885694 -> V=1.0, theta=0.0
% INFO    : Bus 47088	: V=1.0016811, theta=-24.217237 -> V=1.0, theta=0.0
% INFO    : Bus 47089	: V=0.983755, theta=-25.501556 -> V=1.0, theta=0.0
% INFO    : Bus 47090	: V=0.982714, theta=-25.522698 -> V=1.0, theta=0.0
% INFO    : Bus 47091	: V=1.0015988, theta=-35.614796 -> V=1.0, theta=0.0
% INFO    : Bus 47092	: V=1.0101337, theta=-35.062491 -> V=1.0, theta=0.0
% INFO    : Bus 47093	: V=1.0094488, theta=-35.623261 -> V=1.0, theta=0.0
% INFO    : Bus 47094	: V=0.9969214, theta=-35.889035 -> V=1.0, theta=0.0
% INFO    : Bus 47095	: V=1.0097345, theta=-36.269743 -> V=1.0, theta=0.0
% INFO    : Bus 47096	: V=1.0102634, theta=-34.678108 -> V=1.0, theta=0.0
% INFO    : Bus 47097	: V=1.0218345, theta=-33.614018 -> V=1.0, theta=0.0
% INFO    : Bus 47098	: V=0.97577, theta=-27.195986 -> V=1.0, theta=0.0
% INFO    : Bus 47099	: V=0.9800031, theta=-27.152963 -> V=1.0, theta=0.0
% INFO    : Bus 47100	: V=0.9914429, theta=-25.205985 -> V=1.0, theta=0.0
% INFO    : Bus 47101	: V=0.9821008, theta=-26.310365 -> V=1.0, theta=0.0
% INFO    : Bus 47102	: V=0.9971224, theta=-24.8074 -> V=1.0, theta=0.0
% INFO    : Bus 47103	: V=0.9634787, theta=-40.359412 -> V=1.0, theta=0.0
% INFO    : Bus 47104	: V=0.9738525, theta=-36.663425 -> V=1.0, theta=0.0
% INFO    : Bus 47105	: V=0.9712919, theta=-39.695293 -> V=1.0, theta=0.0
% INFO    : Bus 47106	: V=0.967232, theta=-42.498968 -> V=1.0, theta=0.0
% INFO    : Bus 47107	: V=1.0057018, theta=-37.140722 -> V=1.0, theta=0.0
% INFO    : Bus 47108	: V=1.0133699, theta=-36.451411 -> V=1.0, theta=0.0
% INFO    : Bus 47109	: V=1.0000794, theta=-39.037919 -> V=1.0, theta=0.0
% INFO    : Bus 47110	: V=1.0096426, theta=-36.910244 -> V=1.0, theta=0.0
% INFO    : Bus 47111	: V=1.0055207, theta=-37.554991 -> V=1.0, theta=0.0
% INFO    : Bus 47112	: V=1.0254315, theta=-13.046997 -> V=1.0, theta=0.0
% INFO    : Bus 47113	: V=1.0202744, theta=-13.520242 -> V=1.0, theta=0.0
% INFO    : Bus 47114	: V=1.0234566, theta=-14.188776 -> V=1.0, theta=0.0
% INFO    : Bus 47115	: V=1.0231912, theta=-13.942533 -> V=1.0, theta=0.0
% INFO    : Bus 47116	: V=1.0312474, theta=-13.332857 -> V=1.0, theta=0.0
% INFO    : Bus 47117	: V=1.0317004, theta=-12.18816 -> V=1.0, theta=0.0
% INFO    : Bus 47118	: V=0.9851525, theta=-26.818055 -> V=1.0, theta=0.0
% INFO    : Bus 47119	: V=0.9872023, theta=-27.535888 -> V=1.0, theta=0.0
% INFO    : Bus 47120	: V=0.9895055, theta=-27.46051 -> V=1.0, theta=0.0
% INFO    : Bus 47121	: V=0.9851392, theta=-27.947442 -> V=1.0, theta=0.0
% INFO    : Bus 47122	: V=0.987006, theta=-28.629083 -> V=1.0, theta=0.0
% INFO    : Bus 47123	: V=0.9859961, theta=-28.825718 -> V=1.0, theta=0.0
% INFO    : Bus 47124	: V=0.966338, theta=-30.347249 -> V=1.0, theta=0.0
% INFO    : Bus 47125	: V=1.0210397, theta=-32.135105 -> V=1.0, theta=0.0
% INFO    : Bus 47126	: V=1.0139273, theta=-34.041023 -> V=1.0, theta=0.0
% INFO    : Bus 47127	: V=0.9832518, theta=-46.856589 -> V=1.0, theta=0.0
% INFO    : Bus 47128	: V=0.99375, theta=-45.716074 -> V=1.0, theta=0.0
% INFO    : Bus 47129	: V=0.9923318, theta=-48.162117 -> V=1.0, theta=0.0
% INFO    : Bus 47130	: V=0.9933332, theta=-46.693077 -> V=1.0, theta=0.0
% INFO    : Bus 47131	: V=0.9954282, theta=-46.894148 -> V=1.0, theta=0.0
% INFO    : Bus 47132	: V=0.9820751, theta=-29.717756 -> V=1.0, theta=0.0
% INFO    : Bus 47133	: V=0.9755249, theta=-29.812859 -> V=1.0, theta=0.0
% INFO    : Bus 47134	: V=0.9901499, theta=-29.652341 -> V=1.0, theta=0.0
% INFO    : Bus 47135	: V=0.9903147, theta=-29.863402 -> V=1.0, theta=0.0
% INFO    : Bus 47136	: V=0.9777889, theta=-30.761959 -> V=1.0, theta=0.0
% INFO    : Bus 47137	: V=1.0011442, theta=-29.569286 -> V=1.0, theta=0.0
% INFO    : Bus 47138	: V=1.0192759, theta=-17.447553 -> V=1.0, theta=0.0
% INFO    : Bus 47139	: V=1.0194811, theta=-17.461106 -> V=1.0, theta=0.0
% INFO    : Bus 47140	: V=1.017589, theta=-17.572816 -> V=1.0, theta=0.0
% INFO    : Bus 47141	: V=1.0018996, theta=-18.830528 -> V=1.0, theta=0.0
% INFO    : Bus 47142	: V=1.0124557, theta=-17.899646 -> V=1.0, theta=0.0
% INFO    : Bus 47143	: V=1.0250473, theta=-17.336909 -> V=1.0, theta=0.0
% INFO    : Bus 47144	: V=1.0031057, theta=-18.150095 -> V=1.0, theta=0.0
% INFO    : Bus 47145	: V=1.0124992, theta=-17.64877 -> V=1.0, theta=0.0
% INFO    : Bus 47146	: V=0.9976906, theta=-18.949813 -> V=1.0, theta=0.0
% INFO    : Bus 47147	: V=1.0017285, theta=-18.911792 -> V=1.0, theta=0.0
% INFO    : Bus 47148	: V=1.0127081, theta=-17.905768 -> V=1.0, theta=0.0
% INFO    : Bus 47149	: V=1.0216681, theta=-17.760207 -> V=1.0, theta=0.0
% INFO    : Bus 47150	: V=1.0254433, theta=-17.655782 -> V=1.0, theta=0.0
% INFO    : Bus 47151	: V=1.014444, theta=-17.633274 -> V=1.0, theta=0.0
% INFO    : Bus 47152	: V=1.0160621, theta=-16.998928 -> V=1.0, theta=0.0
% INFO    : Bus 47153	: V=1.0139997, theta=-17.264304 -> V=1.0, theta=0.0
% INFO    : Bus 47154	: V=1.0031289, theta=-18.335955 -> V=1.0, theta=0.0
% INFO    : Bus 47155	: V=1.0104144, theta=-29.901901 -> V=1.0, theta=0.0
% INFO    : Bus 47156	: V=1.0054614, theta=-31.274629 -> V=1.0, theta=0.0
% INFO    : Bus 47157	: V=0.9765068, theta=-34.782051 -> V=1.0, theta=0.0
% INFO    : Bus 47158	: V=0.9996361, theta=-32.894339 -> V=1.0, theta=0.0
% INFO    : Bus 47159	: V=0.9850685, theta=-33.721236 -> V=1.0, theta=0.0
% INFO    : Bus 47160	: V=0.9727184, theta=-35.460892 -> V=1.0, theta=0.0
% INFO    : Bus 47161	: V=0.9867195, theta=-32.793454 -> V=1.0, theta=0.0
% INFO    : Bus 47162	: V=0.999015, theta=-31.404756 -> V=1.0, theta=0.0
% INFO    : Bus 47163	: V=0.9846371, theta=-33.493206 -> V=1.0, theta=0.0
% INFO    : Bus 47164	: V=0.9847183, theta=-33.660722 -> V=1.0, theta=0.0
% INFO    : Bus 47165	: V=0.9956208, theta=-31.769652 -> V=1.0, theta=0.0
% INFO    : Bus 47166	: V=0.9781219, theta=-25.807269 -> V=1.0, theta=0.0
% INFO    : Bus 47167	: V=0.9793278, theta=-25.783073 -> V=1.0, theta=0.0
% INFO    : Bus 47168	: V=0.9910493, theta=-25.233673 -> V=1.0, theta=0.0
% INFO    : Bus 47169	: V=0.9910283, theta=-25.211392 -> V=1.0, theta=0.0
% INFO    : Bus 47170	: V=0.9868859, theta=-25.069903 -> V=1.0, theta=0.0
% INFO    : Bus 47171	: V=0.977526, theta=-25.862916 -> V=1.0, theta=0.0
% INFO    : Bus 47172	: V=0.9784475, theta=-25.837575 -> V=1.0, theta=0.0
% INFO    : Bus 47173	: V=0.9778907, theta=-25.810271 -> V=1.0, theta=0.0
% INFO    : Bus 47174	: V=1.0195946, theta=-21.838194 -> V=1.0, theta=0.0
% INFO    : Bus 47175	: V=1.0167758, theta=-20.650616 -> V=1.0, theta=0.0
% INFO    : Bus 47176	: V=0.9941204, theta=-23.787158 -> V=1.0, theta=0.0
% INFO    : Bus 47177	: V=0.9943405, theta=-24.802798 -> V=1.0, theta=0.0
% INFO    : Bus 47178	: V=0.9779788, theta=-25.839371 -> V=1.0, theta=0.0
% INFO    : Bus 47179	: V=0.9882083, theta=-24.535199 -> V=1.0, theta=0.0
% INFO    : Bus 47180	: V=0.9924196, theta=-24.157649 -> V=1.0, theta=0.0
% INFO    : Bus 47181	: V=0.9743266, theta=-25.864831 -> V=1.0, theta=0.0
% INFO    : Bus 47182	: V=0.9995798, theta=-22.693286 -> V=1.0, theta=0.0
% INFO    : Bus 47183	: V=0.9848408, theta=-24.852645 -> V=1.0, theta=0.0
% INFO    : Bus 47184	: V=1.0193839, theta=-20.522943 -> V=1.0, theta=0.0
% INFO    : Bus 47185	: V=0.9785586, theta=-25.836607 -> V=1.0, theta=0.0
% INFO    : Bus 47186	: V=1.0219249, theta=-20.384037 -> V=1.0, theta=0.0
% INFO    : Bus 47187	: V=1.0277839, theta=-19.729653 -> V=1.0, theta=0.0
% INFO    : Bus 47188	: V=1.0167597, theta=-20.22915 -> V=1.0, theta=0.0
% INFO    : Bus 47189	: V=1.0234939, theta=-19.956687 -> V=1.0, theta=0.0
% INFO    : Bus 47190	: V=1.0275535, theta=-20.006184 -> V=1.0, theta=0.0
% INFO    : Bus 47191	: V=1.0274732, theta=-20.102816 -> V=1.0, theta=0.0
% INFO    : Bus 47192	: V=1.0087871, theta=-34.133848 -> V=1.0, theta=0.0
% INFO    : Bus 47193	: V=1.0112609, theta=-34.682246 -> V=1.0, theta=0.0
% INFO    : Bus 47194	: V=1.0214027, theta=-32.926903 -> V=1.0, theta=0.0
% INFO    : Bus 47195	: V=0.9880372, theta=-34.366729 -> V=1.0, theta=0.0
% INFO    : Bus 47196	: V=0.9897523, theta=-33.923874 -> V=1.0, theta=0.0
% INFO    : Bus 47197	: V=0.9934153, theta=-33.18645 -> V=1.0, theta=0.0
% INFO    : Bus 47198	: V=0.9799118, theta=-36.347535 -> V=1.0, theta=0.0
% INFO    : Bus 47199	: V=0.9828033, theta=-35.908168 -> V=1.0, theta=0.0
% INFO    : Bus 47200	: V=0.9798756, theta=-36.864915 -> V=1.0, theta=0.0
% INFO    : Bus 47201	: V=0.9929366, theta=-35.712831 -> V=1.0, theta=0.0
% INFO    : Bus 47202	: V=0.9981108, theta=-35.786115 -> V=1.0, theta=0.0
% INFO    : Bus 47203	: V=0.9921511, theta=-36.264726 -> V=1.0, theta=0.0
% INFO    : Bus 47204	: V=0.9976681, theta=-36.139771 -> V=1.0, theta=0.0
% INFO    : Bus 47205	: V=0.9757759, theta=-30.265456 -> V=1.0, theta=0.0
% INFO    : Bus 47206	: V=0.9598543, theta=-32.20885 -> V=1.0, theta=0.0
% INFO    : Bus 47207	: V=0.9733982, theta=-31.032359 -> V=1.0, theta=0.0
% INFO    : Bus 47208	: V=0.9757203, theta=-30.650702 -> V=1.0, theta=0.0
% INFO    : Bus 47209	: V=0.9587292, theta=-31.792154 -> V=1.0, theta=0.0
% INFO    : Bus 47210	: V=0.9706222, theta=-31.958743 -> V=1.0, theta=0.0
% INFO    : Bus 47211	: V=0.9714286, theta=-31.874875 -> V=1.0, theta=0.0
% INFO    : Bus 47212	: V=0.9739118, theta=-32.118109 -> V=1.0, theta=0.0
% INFO    : Bus 47213	: V=0.971823, theta=-31.299729 -> V=1.0, theta=0.0
% INFO    : Bus 47214	: V=0.9632389, theta=-32.273602 -> V=1.0, theta=0.0
% INFO    : Bus 47215	: V=0.9636293, theta=-32.307606 -> V=1.0, theta=0.0
% INFO    : Bus 47216	: V=0.969882, theta=-31.786785 -> V=1.0, theta=0.0
% INFO    : Bus 47217	: V=0.9760256, theta=-31.266767 -> V=1.0, theta=0.0
% INFO    : Bus 47218	: V=0.9709089, theta=-31.479564 -> V=1.0, theta=0.0
% INFO    : Bus 47219	: V=0.9647371, theta=-32.208254 -> V=1.0, theta=0.0
% INFO    : Bus 47220	: V=0.9640649, theta=-32.210286 -> V=1.0, theta=0.0
% INFO    : Bus 47221	: V=0.9703404, theta=-31.610628 -> V=1.0, theta=0.0
% INFO    : Bus 47222	: V=0.9640059, theta=-32.220643 -> V=1.0, theta=0.0
% INFO    : Bus 47223	: V=0.9702677, theta=-31.6633 -> V=1.0, theta=0.0
% INFO    : Bus 47224	: V=0.9760188, theta=-31.430401 -> V=1.0, theta=0.0
% INFO    : Bus 47225	: V=0.976181, theta=-31.550645 -> V=1.0, theta=0.0
% INFO    : Bus 47226	: V=0.9686632, theta=-32.284188 -> V=1.0, theta=0.0
% INFO    : Bus 47227	: V=0.969712, theta=-31.728296 -> V=1.0, theta=0.0
% INFO    : Bus 47228	: V=0.9623047, theta=-32.301081 -> V=1.0, theta=0.0
% INFO    : Bus 47229	: V=0.9770062, theta=-31.91445 -> V=1.0, theta=0.0
% INFO    : Bus 47230	: V=1.0185554, theta=-27.121845 -> V=1.0, theta=0.0
% INFO    : Bus 47231	: V=1.0194692, theta=-26.338538 -> V=1.0, theta=0.0
% INFO    : Bus 47232	: V=1.0016151, theta=-29.981024 -> V=1.0, theta=0.0
% INFO    : Bus 47233	: V=1.0002338, theta=-19.487076 -> V=1.0, theta=0.0
% INFO    : Bus 47234	: V=1.0051331, theta=-22.03057 -> V=1.0, theta=0.0
% INFO    : Bus 47235	: V=1.0060649, theta=-35.402329 -> V=1.0, theta=0.0
% INFO    : Bus 47236	: V=1.0178695, theta=-32.032607 -> V=1.0, theta=0.0
% INFO    : Bus 47237	: V=1.0190705, theta=-32.214395 -> V=1.0, theta=0.0
% INFO    : Bus 47238	: V=1.0136861, theta=-33.562264 -> V=1.0, theta=0.0
% INFO    : Bus 47239	: V=1.0138902, theta=-33.548216 -> V=1.0, theta=0.0
% INFO    : Bus 47240	: V=1.0125745, theta=-33.973547 -> V=1.0, theta=0.0
% INFO    : Bus 47241	: V=1.0115715, theta=-34.359112 -> V=1.0, theta=0.0
% INFO    : Bus 47242	: V=1.0110939, theta=-34.797367 -> V=1.0, theta=0.0
% INFO    : Bus 47243	: V=1.0103165, theta=-36.572457 -> V=1.0, theta=0.0
% INFO    : Bus 47244	: V=1.0088417, theta=-35.432261 -> V=1.0, theta=0.0
% INFO    : Bus 47245	: V=1.0077096, theta=-34.496342 -> V=1.0, theta=0.0
% INFO    : Bus 47246	: V=1.008448, theta=-34.405517 -> V=1.0, theta=0.0
% INFO    : Bus 47247	: V=1.0092943, theta=-34.301335 -> V=1.0, theta=0.0
% INFO    : Bus 47248	: V=1.0137276, theta=-33.559088 -> V=1.0, theta=0.0
% INFO    : Bus 47249	: V=1.0121488, theta=-34.110981 -> V=1.0, theta=0.0
% INFO    : Bus 47250	: V=1.0187933, theta=-33.744335 -> V=1.0, theta=0.0
% INFO    : Bus 47251	: V=1.0067616, theta=-34.52345 -> V=1.0, theta=0.0
% INFO    : Bus 47252	: V=1.019376, theta=-33.766367 -> V=1.0, theta=0.0
% INFO    : Bus 47253	: V=1.0128943, theta=-33.633417 -> V=1.0, theta=0.0
% INFO    : Bus 47254	: V=1.0181928, theta=-31.964902 -> V=1.0, theta=0.0
% INFO    : Bus 47255	: V=1.0070879, theta=-32.419784 -> V=1.0, theta=0.0
% INFO    : Bus 47256	: V=1.0057563, theta=-32.649084 -> V=1.0, theta=0.0
% INFO    : Bus 47257	: V=1.0059956, theta=-33.131976 -> V=1.0, theta=0.0
% INFO    : Bus 47258	: V=1.010364, theta=-32.209959 -> V=1.0, theta=0.0
% INFO    : Bus 47259	: V=1.0301498, theta=-14.158455 -> V=1.0, theta=0.0
% INFO    : Bus 47260	: V=1.0096402, theta=-16.586738 -> V=1.0, theta=0.0
% INFO    : Bus 47261	: V=1.0236932, theta=-15.611258 -> V=1.0, theta=0.0
% INFO    : Bus 47262	: V=1.0242759, theta=-15.537833 -> V=1.0, theta=0.0
% INFO    : Bus 47263	: V=1.024557, theta=-15.388485 -> V=1.0, theta=0.0
% INFO    : Bus 47264	: V=1.0253706, theta=-16.122829 -> V=1.0, theta=0.0
% INFO    : Bus 47265	: V=1.0179446, theta=-16.61335 -> V=1.0, theta=0.0
% INFO    : Bus 47266	: V=1.0249506, theta=-15.81468 -> V=1.0, theta=0.0
% INFO    : Bus 47267	: V=1.0249951, theta=-15.829787 -> V=1.0, theta=0.0
% INFO    : Bus 47268	: V=0.9997151, theta=-43.113199 -> V=1.0, theta=0.0
% INFO    : Bus 47269	: V=1.001313, theta=-45.648792 -> V=1.0, theta=0.0
% INFO    : Bus 47270	: V=0.99951, theta=-44.091857 -> V=1.0, theta=0.0
% INFO    : Bus 47271	: V=1.0072426, theta=-45.430702 -> V=1.0, theta=0.0
% INFO    : Bus 47272	: V=1.0019595, theta=-44.653695 -> V=1.0, theta=0.0
% INFO    : Bus 47273	: V=1.0084272, theta=-33.856187 -> V=1.0, theta=0.0
% INFO    : Bus 47274	: V=1.0170389, theta=-32.608267 -> V=1.0, theta=0.0
% INFO    : Bus 47275	: V=1.0199843, theta=-32.462185 -> V=1.0, theta=0.0
% INFO    : Bus 47276	: V=1.0089786, theta=-33.118974 -> V=1.0, theta=0.0
% INFO    : Bus 47277	: V=1.0089037, theta=-34.584712 -> V=1.0, theta=0.0
% INFO    : Bus 47278	: V=1.0123576, theta=-35.036748 -> V=1.0, theta=0.0
% INFO    : Bus 47279	: V=1.0053559, theta=-36.771237 -> V=1.0, theta=0.0
% INFO    : Bus 47280	: V=0.9967069, theta=-43.247682 -> V=1.0, theta=0.0
% INFO    : Bus 47281	: V=1.0007552, theta=-44.929805 -> V=1.0, theta=0.0
% INFO    : Bus 47282	: V=1.001376, theta=-44.475999 -> V=1.0, theta=0.0
% INFO    : Bus 47283	: V=1.0152597, theta=-20.868129 -> V=1.0, theta=0.0
% INFO    : Bus 47284	: V=1.0019483, theta=-22.805221 -> V=1.0, theta=0.0
% INFO    : Bus 47285	: V=1.0173199, theta=-20.410434 -> V=1.0, theta=0.0
% INFO    : Bus 47286	: V=1.0215139, theta=-18.63654 -> V=1.0, theta=0.0
% INFO    : Bus 47287	: V=1.0021027, theta=-22.212245 -> V=1.0, theta=0.0
% INFO    : Bus 47288	: V=0.9981688, theta=-23.463505 -> V=1.0, theta=0.0
% INFO    : Bus 47289	: V=0.9906682, theta=-24.830674 -> V=1.0, theta=0.0
% INFO    : Bus 47290	: V=1.0043362, theta=-23.580983 -> V=1.0, theta=0.0
% INFO    : Bus 47291	: V=0.9924726, theta=-23.709475 -> V=1.0, theta=0.0
% INFO    : Bus 47292	: V=1.0052006, theta=-23.048804 -> V=1.0, theta=0.0
% INFO    : Bus 47293	: V=1.010507, theta=-22.922414 -> V=1.0, theta=0.0
% INFO    : Bus 47294	: V=0.9998006, theta=-24.350118 -> V=1.0, theta=0.0
% INFO    : Bus 47295	: V=1.0148225, theta=-19.393474 -> V=1.0, theta=0.0
% INFO    : Bus 47296	: V=1.0062627, theta=-20.882263 -> V=1.0, theta=0.0
% INFO    : Bus 47297	: V=1.013857, theta=-20.29093 -> V=1.0, theta=0.0
% INFO    : Bus 47298	: V=1.0128574, theta=-20.292796 -> V=1.0, theta=0.0
% INFO    : Bus 47299	: V=1.0193821, theta=-21.424177 -> V=1.0, theta=0.0
% INFO    : Bus 47300	: V=1.001956, theta=-30.805647 -> V=1.0, theta=0.0
% INFO    : Bus 47301	: V=1.0204514, theta=-30.910468 -> V=1.0, theta=0.0
% INFO    : Bus 47302	: V=1.0093176, theta=-31.894974 -> V=1.0, theta=0.0
% INFO    : Bus 47303	: V=1.0179055, theta=-30.209794 -> V=1.0, theta=0.0
% INFO    : Bus 47304	: V=1.0094015, theta=-31.090128 -> V=1.0, theta=0.0
% INFO    : Bus 47305	: V=1.0165019, theta=-30.475265 -> V=1.0, theta=0.0
% INFO    : Bus 47306	: V=1.0153369, theta=-30.588231 -> V=1.0, theta=0.0
% INFO    : Bus 47307	: V=1.0110836, theta=-31.140853 -> V=1.0, theta=0.0
% INFO    : Bus 47308	: V=1.0138401, theta=-30.747004 -> V=1.0, theta=0.0
% INFO    : Bus 47309	: V=1.0148144, theta=-30.646418 -> V=1.0, theta=0.0
% INFO    : Bus 47310	: V=1.014402, theta=-30.671219 -> V=1.0, theta=0.0
% INFO    : Bus 47311	: V=1.0096342, theta=-31.209185 -> V=1.0, theta=0.0
% INFO    : Bus 47312	: V=1.0094828, theta=-31.222933 -> V=1.0, theta=0.0
% INFO    : Bus 47313	: V=1.0128984, theta=-30.86039 -> V=1.0, theta=0.0
% INFO    : Bus 47314	: V=1.0122802, theta=-30.950195 -> V=1.0, theta=0.0
% INFO    : Bus 47315	: V=1.0095578, theta=-31.23133 -> V=1.0, theta=0.0
% INFO    : Bus 47316	: V=1.0098542, theta=-31.329982 -> V=1.0, theta=0.0
% INFO    : Bus 47317	: V=1.0114364, theta=-31.079865 -> V=1.0, theta=0.0
% INFO    : Bus 47318	: V=1.0115116, theta=-31.185126 -> V=1.0, theta=0.0
% INFO    : Bus 47319	: V=1.0205819, theta=-31.230108 -> V=1.0, theta=0.0
% INFO    : Bus 47320	: V=1.0206708, theta=-31.527487 -> V=1.0, theta=0.0
% INFO    : Bus 47321	: V=1.016629, theta=-29.470256 -> V=1.0, theta=0.0
% INFO    : Bus 47322	: V=1.0205218, theta=-29.788746 -> V=1.0, theta=0.0
% INFO    : Bus 47323	: V=1.0169779, theta=-30.251278 -> V=1.0, theta=0.0
% INFO    : Bus 47324	: V=1.0238152, theta=-24.701453 -> V=1.0, theta=0.0
% INFO    : Bus 47325	: V=1.0205825, theta=-25.56466 -> V=1.0, theta=0.0
% INFO    : Bus 47326	: V=1.0118189, theta=-25.930313 -> V=1.0, theta=0.0
% INFO    : Bus 47327	: V=1.0190831, theta=-25.730139 -> V=1.0, theta=0.0
% INFO    : Bus 47328	: V=1.0211636, theta=-24.724317 -> V=1.0, theta=0.0
% INFO    : Bus 47329	: V=1.022878, theta=-23.05904 -> V=1.0, theta=0.0
% INFO    : Bus 47330	: V=1.0139116, theta=-46.331104 -> V=1.0, theta=0.0
% INFO    : Bus 47331	: V=0.997368, theta=-50.47019 -> V=1.0, theta=0.0
% INFO    : Bus 47332	: V=1.0211378, theta=-17.048443 -> V=1.0, theta=0.0
% INFO    : Bus 47333	: V=1.0086214, theta=-19.772046 -> V=1.0, theta=0.0
% INFO    : Bus 47334	: V=0.998234, theta=-20.333519 -> V=1.0, theta=0.0
% INFO    : Bus 47335	: V=1.0176961, theta=-18.123772 -> V=1.0, theta=0.0
% INFO    : Bus 47336	: V=1.0190395, theta=-17.638524 -> V=1.0, theta=0.0
% INFO    : Bus 47337	: V=1.0200395, theta=-17.295706 -> V=1.0, theta=0.0
% INFO    : Bus 47338	: V=1.022957, theta=-22.006936 -> V=1.0, theta=0.0
% INFO    : Bus 47339	: V=1.0175765, theta=-23.010532 -> V=1.0, theta=0.0
% INFO    : Bus 47340	: V=1.0250344, theta=-22.017009 -> V=1.0, theta=0.0
% INFO    : Bus 47341	: V=1.0195598, theta=-22.788606 -> V=1.0, theta=0.0
% INFO    : Bus 47342	: V=0.99827, theta=-34.055902 -> V=1.0, theta=0.0
% INFO    : Bus 47343	: V=1.0029942, theta=-32.846327 -> V=1.0, theta=0.0
% INFO    : Bus 47344	: V=1.0010363, theta=-33.288423 -> V=1.0, theta=0.0
% INFO    : Bus 47345	: V=1.0031681, theta=-31.454179 -> V=1.0, theta=0.0
% INFO    : Bus 47346	: V=1.0129358, theta=-48.12125 -> V=1.0, theta=0.0
% INFO    : Bus 47347	: V=1.0134, theta=-47.315022 -> V=1.0, theta=0.0
% INFO    : Bus 47348	: V=0.9869316, theta=-48.616481 -> V=1.0, theta=0.0
% INFO    : Bus 47349	: V=0.9803826, theta=-48.805401 -> V=1.0, theta=0.0
% INFO    : Bus 47350	: V=1.0103862, theta=-27.224045 -> V=1.0, theta=0.0
% INFO    : Bus 47351	: V=1.0005261, theta=-29.786099 -> V=1.0, theta=0.0
% INFO    : Bus 47352	: V=1.0004566, theta=-29.559349 -> V=1.0, theta=0.0
% INFO    : Bus 47353	: V=0.9955235, theta=-30.638105 -> V=1.0, theta=0.0
% INFO    : Bus 47354	: V=0.9934095, theta=-31.231438 -> V=1.0, theta=0.0
% INFO    : Bus 47355	: V=0.9836056, theta=-32.031135 -> V=1.0, theta=0.0
% INFO    : Bus 47356	: V=0.9653594, theta=-32.195431 -> V=1.0, theta=0.0
% INFO    : Bus 47357	: V=0.972898, theta=-31.586919 -> V=1.0, theta=0.0
% INFO    : Bus 47358	: V=0.9708552, theta=-31.833598 -> V=1.0, theta=0.0
% INFO    : Bus 47359	: V=0.9850119, theta=-30.825556 -> V=1.0, theta=0.0
% INFO    : Bus 47360	: V=0.9849348, theta=-30.93256 -> V=1.0, theta=0.0
% INFO    : Bus 47361	: V=0.9711123, theta=-32.087491 -> V=1.0, theta=0.0
% INFO    : Bus 47362	: V=0.9850651, theta=-31.258523 -> V=1.0, theta=0.0
% INFO    : Bus 47363	: V=0.9704685, theta=-32.043518 -> V=1.0, theta=0.0
% INFO    : Bus 47364	: V=0.9743506, theta=-31.950968 -> V=1.0, theta=0.0
% INFO    : Bus 47365	: V=0.9889741, theta=-31.230116 -> V=1.0, theta=0.0
% INFO    : Bus 47366	: V=0.9868488, theta=-31.077608 -> V=1.0, theta=0.0
% INFO    : Bus 47367	: V=0.9860315, theta=-30.504362 -> V=1.0, theta=0.0
% INFO    : Bus 47368	: V=0.9833065, theta=-31.221339 -> V=1.0, theta=0.0
% INFO    : Bus 47369	: V=0.9890425, theta=-31.143721 -> V=1.0, theta=0.0
% INFO    : Bus 47370	: V=0.9966939, theta=-31.149703 -> V=1.0, theta=0.0
% INFO    : Bus 47371	: V=0.9931362, theta=-31.183706 -> V=1.0, theta=0.0
% INFO    : Bus 47372	: V=0.986128, theta=-28.682875 -> V=1.0, theta=0.0
% INFO    : Bus 47373	: V=0.9892729, theta=-28.646017 -> V=1.0, theta=0.0
% INFO    : Bus 47374	: V=1.0053511, theta=-28.827838 -> V=1.0, theta=0.0
% INFO    : Bus 47375	: V=0.9657761, theta=-29.987431 -> V=1.0, theta=0.0
% INFO    : Bus 47376	: V=1.0154225, theta=-22.391604 -> V=1.0, theta=0.0
% INFO    : Bus 47377	: V=0.9948286, theta=-22.819485 -> V=1.0, theta=0.0
% INFO    : Bus 47378	: V=1.0180246, theta=-21.939731 -> V=1.0, theta=0.0
% INFO    : Bus 47379	: V=1.0032835, theta=-22.761599 -> V=1.0, theta=0.0
% INFO    : Bus 47380	: V=0.987803, theta=-50.341053 -> V=1.0, theta=0.0
% INFO    : Bus 47381	: V=0.9855605, theta=-50.09962 -> V=1.0, theta=0.0
% INFO    : Bus 47382	: V=0.9821594, theta=-51.3679 -> V=1.0, theta=0.0
% INFO    : Bus 47383	: V=0.9832225, theta=-51.37073 -> V=1.0, theta=0.0
% INFO    : Bus 47384	: V=0.9835375, theta=-51.330627 -> V=1.0, theta=0.0
% INFO    : Bus 47385	: V=0.9869468, theta=-49.811125 -> V=1.0, theta=0.0
% INFO    : Bus 47386	: V=0.9872612, theta=-50.415479 -> V=1.0, theta=0.0
% INFO    : Bus 47387	: V=0.9880177, theta=-49.782755 -> V=1.0, theta=0.0
% INFO    : Bus 47388	: V=0.9848446, theta=-51.208357 -> V=1.0, theta=0.0
% INFO    : Bus 47389	: V=0.9936196, theta=-49.082057 -> V=1.0, theta=0.0
% INFO    : Bus 47390	: V=0.9833953, theta=-53.607541 -> V=1.0, theta=0.0
% INFO    : Bus 47391	: V=0.9861306, theta=-49.857512 -> V=1.0, theta=0.0
% INFO    : Bus 47392	: V=1.0161604, theta=-16.800524 -> V=1.0, theta=0.0
% INFO    : Bus 47393	: V=1.0207211, theta=-15.980022 -> V=1.0, theta=0.0
% INFO    : Bus 47394	: V=1.0160561, theta=-16.85016 -> V=1.0, theta=0.0
% INFO    : Bus 47395	: V=1.0127552, theta=-16.976296 -> V=1.0, theta=0.0
% INFO    : Bus 47396	: V=1.0204925, theta=-16.572877 -> V=1.0, theta=0.0
% INFO    : Bus 47397	: V=1.0200601, theta=-16.234956 -> V=1.0, theta=0.0
% INFO    : Bus 47398	: V=0.9978334, theta=-20.278682 -> V=1.0, theta=0.0
% INFO    : Bus 47399	: V=1.0207021, theta=-18.191732 -> V=1.0, theta=0.0
% INFO    : Bus 47400	: V=1.0055672, theta=-20.184948 -> V=1.0, theta=0.0
% INFO    : Bus 47401	: V=1.0112113, theta=-20.16586 -> V=1.0, theta=0.0
% INFO    : Bus 47402	: V=1.0080448, theta=-21.183854 -> V=1.0, theta=0.0
% INFO    : Bus 47403	: V=1.0182774, theta=-16.326993 -> V=1.0, theta=0.0
% INFO    : Bus 47404	: V=1.0140442, theta=-23.291902 -> V=1.0, theta=0.0
% INFO    : Bus 47405	: V=1.0018876, theta=-26.804076 -> V=1.0, theta=0.0
% INFO    : Bus 47406	: V=1.0078513, theta=-26.493492 -> V=1.0, theta=0.0
% INFO    : Bus 47407	: V=0.9967004, theta=-35.663194 -> V=1.0, theta=0.0
% INFO    : Bus 47408	: V=0.9968847, theta=-33.934711 -> V=1.0, theta=0.0
% INFO    : Bus 47409	: V=0.9944617, theta=-37.862905 -> V=1.0, theta=0.0
% INFO    : Bus 47410	: V=0.9979582, theta=-41.679826 -> V=1.0, theta=0.0
% INFO    : Bus 47411	: V=0.9965122, theta=-41.779156 -> V=1.0, theta=0.0
% INFO    : Bus 47412	: V=0.9960935, theta=-43.863655 -> V=1.0, theta=0.0
% INFO    : Bus 47413	: V=1.0318597, theta=-21.924037 -> V=1.0, theta=0.0
% INFO    : Bus 47414	: V=1.0290199, theta=-22.549004 -> V=1.0, theta=0.0
% INFO    : Bus 47415	: V=1.0149125, theta=-35.194865 -> V=1.0, theta=0.0
% INFO    : Bus 47416	: V=1.0062899, theta=-36.39884 -> V=1.0, theta=0.0
% INFO    : Bus 47417	: V=0.9976796, theta=-37.788767 -> V=1.0, theta=0.0
% INFO    : Bus 47418	: V=1.0067704, theta=-36.513621 -> V=1.0, theta=0.0
% INFO    : Bus 47419	: V=1.0105323, theta=-36.327199 -> V=1.0, theta=0.0
% INFO    : Bus 47420	: V=1.0075462, theta=-36.493824 -> V=1.0, theta=0.0
% INFO    : Bus 47421	: V=0.9896245, theta=-30.842133 -> V=1.0, theta=0.0
% INFO    : Bus 47422	: V=1.0064477, theta=-30.203076 -> V=1.0, theta=0.0
% INFO    : Bus 47423	: V=1.0160392, theta=-29.441298 -> V=1.0, theta=0.0
% INFO    : Bus 47424	: V=1.0225445, theta=-22.054221 -> V=1.0, theta=0.0
% INFO    : Bus 47425	: V=1.0063288, theta=-26.088954 -> V=1.0, theta=0.0
% INFO    : Bus 47426	: V=1.0223532, theta=-22.063877 -> V=1.0, theta=0.0
% INFO    : Bus 47427	: V=1.0185485, theta=-22.695403 -> V=1.0, theta=0.0
% INFO    : Bus 47428	: V=1.0216251, theta=-22.076921 -> V=1.0, theta=0.0
% INFO    : Bus 47429	: V=1.0224199, theta=-24.081451 -> V=1.0, theta=0.0
% INFO    : Bus 47430	: V=1.002629, theta=-40.554599 -> V=1.0, theta=0.0
% INFO    : Bus 47431	: V=0.9997316, theta=-40.162357 -> V=1.0, theta=0.0
% INFO    : Bus 47432	: V=1.0001753, theta=-42.698815 -> V=1.0, theta=0.0
% INFO    : Bus 47433	: V=1.0116865, theta=-20.885828 -> V=1.0, theta=0.0
% INFO    : Bus 47434	: V=1.0143016, theta=-18.743294 -> V=1.0, theta=0.0
% INFO    : Bus 47435	: V=1.0215053, theta=-18.157709 -> V=1.0, theta=0.0
% INFO    : Bus 47436	: V=1.0212032, theta=-18.097225 -> V=1.0, theta=0.0
% INFO    : Bus 47437	: V=1.0272086, theta=-18.440259 -> V=1.0, theta=0.0
% INFO    : Bus 47438	: V=1.0143466, theta=-19.517799 -> V=1.0, theta=0.0
% INFO    : Bus 47439	: V=1.012868, theta=-20.794086 -> V=1.0, theta=0.0
% INFO    : Bus 47440	: V=0.9842424, theta=-37.791733 -> V=1.0, theta=0.0
% INFO    : Bus 47441	: V=0.9886545, theta=-37.518349 -> V=1.0, theta=0.0
% INFO    : Bus 47442	: V=0.9870817, theta=-38.615641 -> V=1.0, theta=0.0
% INFO    : Bus 47443	: V=0.9877803, theta=-38.323287 -> V=1.0, theta=0.0
% INFO    : Bus 47444	: V=0.9875126, theta=-39.330741 -> V=1.0, theta=0.0
% INFO    : Bus 47445	: V=0.9870112, theta=-40.489752 -> V=1.0, theta=0.0
% INFO    : Bus 47446	: V=0.9820376, theta=-28.066524 -> V=1.0, theta=0.0
% INFO    : Bus 47447	: V=1.0105328, theta=-25.587998 -> V=1.0, theta=0.0
% INFO    : Bus 47448	: V=1.0031485, theta=-27.197148 -> V=1.0, theta=0.0
% INFO    : Bus 47449	: V=0.9849079, theta=-29.039696 -> V=1.0, theta=0.0
% INFO    : Bus 47450	: V=1.000777, theta=-28.882048 -> V=1.0, theta=0.0
% INFO    : Bus 47451	: V=1.0010791, theta=-28.321064 -> V=1.0, theta=0.0
% INFO    : Bus 47452	: V=1.0071249, theta=-26.931654 -> V=1.0, theta=0.0
% INFO    : Bus 47453	: V=1.0093045, theta=-26.356377 -> V=1.0, theta=0.0
% INFO    : Bus 47454	: V=1.0203125, theta=-22.842045 -> V=1.0, theta=0.0
% INFO    : Bus 47455	: V=1.0161617, theta=-25.385802 -> V=1.0, theta=0.0
% INFO    : Bus 47456	: V=1.0161906, theta=-25.625175 -> V=1.0, theta=0.0
% INFO    : Bus 47457	: V=0.9713648, theta=-27.262105 -> V=1.0, theta=0.0
% INFO    : Bus 47458	: V=0.9921385, theta=-28.796091 -> V=1.0, theta=0.0
% INFO    : Bus 47459	: V=0.9940151, theta=-28.027983 -> V=1.0, theta=0.0
% INFO    : Bus 47460	: V=1.0165625, theta=-30.358966 -> V=1.0, theta=0.0
% INFO    : Bus 47461	: V=0.9922848, theta=-32.459227 -> V=1.0, theta=0.0
% INFO    : Bus 47462	: V=0.9935967, theta=-32.358613 -> V=1.0, theta=0.0
% INFO    : Bus 47463	: V=0.9941895, theta=-32.312994 -> V=1.0, theta=0.0
% INFO    : Bus 47464	: V=0.9893243, theta=-32.496921 -> V=1.0, theta=0.0
% INFO    : Bus 47465	: V=0.9937245, theta=-32.122877 -> V=1.0, theta=0.0
% INFO    : Bus 47466	: V=0.993329, theta=-32.141952 -> V=1.0, theta=0.0
% INFO    : Bus 47467	: V=0.9926313, theta=-32.17774 -> V=1.0, theta=0.0
% INFO    : Bus 47468	: V=0.9949834, theta=-32.060661 -> V=1.0, theta=0.0
% INFO    : Bus 47469	: V=0.9969218, theta=-31.944939 -> V=1.0, theta=0.0
% INFO    : Bus 47470	: V=0.9930165, theta=-32.367225 -> V=1.0, theta=0.0
% INFO    : Bus 47471	: V=1.0180018, theta=-29.937252 -> V=1.0, theta=0.0
% INFO    : Bus 47472	: V=0.9881036, theta=-32.611356 -> V=1.0, theta=0.0
% INFO    : Bus 47473	: V=0.9871341, theta=-32.664928 -> V=1.0, theta=0.0
% INFO    : Bus 47474	: V=0.9868924, theta=-32.674602 -> V=1.0, theta=0.0
% INFO    : Bus 47475	: V=0.9869625, theta=-32.665272 -> V=1.0, theta=0.0
% INFO    : Bus 47476	: V=0.9877065, theta=-32.605094 -> V=1.0, theta=0.0
% INFO    : Bus 47477	: V=0.9870914, theta=-32.63203 -> V=1.0, theta=0.0
% INFO    : Bus 47478	: V=0.9882137, theta=-32.61002 -> V=1.0, theta=0.0
% INFO    : Bus 47479	: V=0.9875575, theta=-32.628942 -> V=1.0, theta=0.0
% INFO    : Bus 47480	: V=0.9873519, theta=-32.65133 -> V=1.0, theta=0.0
% INFO    : Bus 47481	: V=0.9934506, theta=-32.247705 -> V=1.0, theta=0.0
% INFO    : Bus 47482	: V=0.9901352, theta=-32.516109 -> V=1.0, theta=0.0
% INFO    : Bus 47483	: V=0.9893344, theta=-32.547904 -> V=1.0, theta=0.0
% INFO    : Bus 47484	: V=0.9988995, theta=-31.905554 -> V=1.0, theta=0.0
% INFO    : Bus 47485	: V=0.9824893, theta=-32.907907 -> V=1.0, theta=0.0
% INFO    : Bus 47486	: V=0.9934231, theta=-32.081732 -> V=1.0, theta=0.0
% INFO    : Bus 47487	: V=1.0055337, theta=-31.438715 -> V=1.0, theta=0.0
% INFO    : Bus 47488	: V=0.9913131, theta=-32.179689 -> V=1.0, theta=0.0
% INFO    : Bus 47489	: V=0.9837362, theta=-32.85138 -> V=1.0, theta=0.0
% INFO    : Bus 47490	: V=0.9814213, theta=-32.913842 -> V=1.0, theta=0.0
% INFO    : Bus 47491	: V=0.9844459, theta=-32.810939 -> V=1.0, theta=0.0
% INFO    : Bus 47492	: V=0.9922103, theta=-32.187991 -> V=1.0, theta=0.0
% INFO    : Bus 47493	: V=0.9839164, theta=-32.763304 -> V=1.0, theta=0.0
% INFO    : Bus 47494	: V=0.9839877, theta=-32.767628 -> V=1.0, theta=0.0
% INFO    : Bus 47495	: V=0.9841078, theta=-32.766853 -> V=1.0, theta=0.0
% INFO    : Bus 47496	: V=0.9843021, theta=-32.777073 -> V=1.0, theta=0.0
% INFO    : Bus 47497	: V=0.9834268, theta=-32.781838 -> V=1.0, theta=0.0
% INFO    : Bus 47498	: V=0.9890952, theta=-32.265213 -> V=1.0, theta=0.0
% INFO    : Bus 47499	: V=0.9839365, theta=-32.827996 -> V=1.0, theta=0.0
% INFO    : Bus 47500	: V=0.9833199, theta=-32.765585 -> V=1.0, theta=0.0
% INFO    : Bus 47501	: V=0.9700198, theta=-33.369097 -> V=1.0, theta=0.0
% INFO    : Bus 47502	: V=0.9765939, theta=-32.201167 -> V=1.0, theta=0.0
% INFO    : Bus 47503	: V=0.9664393, theta=-33.042983 -> V=1.0, theta=0.0
% INFO    : Bus 47504	: V=0.9859554, theta=-31.554413 -> V=1.0, theta=0.0
% INFO    : Bus 47505	: V=0.9873922, theta=-31.566356 -> V=1.0, theta=0.0
% INFO    : Bus 47506	: V=0.9897888, theta=-31.450959 -> V=1.0, theta=0.0
% INFO    : Bus 47507	: V=0.9770868, theta=-32.737496 -> V=1.0, theta=0.0
% INFO    : Bus 47508	: V=0.9802002, theta=-32.005658 -> V=1.0, theta=0.0
% INFO    : Bus 47509	: V=0.9876575, theta=-31.429993 -> V=1.0, theta=0.0
% INFO    : Bus 47510	: V=0.9870134, theta=-31.397394 -> V=1.0, theta=0.0
% INFO    : Bus 47511	: V=0.9862281, theta=-32.339105 -> V=1.0, theta=0.0
% INFO    : Bus 47512	: V=0.9789975, theta=-32.783613 -> V=1.0, theta=0.0
% INFO    : Bus 47513	: V=0.9791595, theta=-32.762597 -> V=1.0, theta=0.0
% INFO    : Bus 47514	: V=0.9790267, theta=-32.73947 -> V=1.0, theta=0.0
% INFO    : Bus 47515	: V=0.9778949, theta=-32.787462 -> V=1.0, theta=0.0
% INFO    : Bus 47516	: V=0.983862, theta=-32.378038 -> V=1.0, theta=0.0
% INFO    : Bus 47517	: V=0.9830646, theta=-32.727652 -> V=1.0, theta=0.0
% INFO    : Bus 47518	: V=0.9824832, theta=-32.369275 -> V=1.0, theta=0.0
% INFO    : Bus 47519	: V=1.0143988, theta=-30.47481 -> V=1.0, theta=0.0
% INFO    : Bus 47520	: V=1.0054427, theta=-31.222984 -> V=1.0, theta=0.0
% INFO    : Bus 47521	: V=0.9913345, theta=-32.54679 -> V=1.0, theta=0.0
% INFO    : Bus 47522	: V=1.0185481, theta=-29.917751 -> V=1.0, theta=0.0
% INFO    : Bus 47523	: V=1.0094094, theta=-31.033397 -> V=1.0, theta=0.0
% INFO    : Bus 47524	: V=1.0169726, theta=-30.111797 -> V=1.0, theta=0.0
% INFO    : Bus 47525	: V=1.0176133, theta=-30.177263 -> V=1.0, theta=0.0
% INFO    : Bus 47526	: V=1.0026479, theta=-31.741009 -> V=1.0, theta=0.0
% INFO    : Bus 47527	: V=1.0062798, theta=-31.647474 -> V=1.0, theta=0.0
% INFO    : Bus 47528	: V=1.0001198, theta=-31.878716 -> V=1.0, theta=0.0
% INFO    : Bus 47529	: V=1.0027282, theta=-31.67544 -> V=1.0, theta=0.0
% INFO    : Bus 47530	: V=1.0180877, theta=-29.936504 -> V=1.0, theta=0.0
% INFO    : Bus 47531	: V=1.0167627, theta=-30.042391 -> V=1.0, theta=0.0
% INFO    : Bus 47532	: V=0.9896961, theta=-31.282516 -> V=1.0, theta=0.0
% INFO    : Bus 47533	: V=0.9899543, theta=-31.594737 -> V=1.0, theta=0.0
% INFO    : Bus 47534	: V=0.9808552, theta=-32.755691 -> V=1.0, theta=0.0
% INFO    : Bus 47535	: V=0.9955967, theta=-31.993029 -> V=1.0, theta=0.0
% INFO    : Bus 47536	: V=0.9913319, theta=-31.967276 -> V=1.0, theta=0.0
% INFO    : Bus 47537	: V=0.9800927, theta=-32.71116 -> V=1.0, theta=0.0
% INFO    : Bus 47538	: V=0.9863465, theta=-32.636893 -> V=1.0, theta=0.0
% INFO    : Bus 47539	: V=0.9870261, theta=-32.630184 -> V=1.0, theta=0.0
% INFO    : Bus 47540	: V=0.9927508, theta=-32.020268 -> V=1.0, theta=0.0
% INFO    : Bus 47541	: V=0.9878367, theta=-32.558303 -> V=1.0, theta=0.0
% INFO    : Bus 47542	: V=0.9876449, theta=-32.597803 -> V=1.0, theta=0.0
% INFO    : Bus 47543	: V=1.0030512, theta=-31.754452 -> V=1.0, theta=0.0
% INFO    : Bus 47544	: V=0.9946957, theta=-32.060063 -> V=1.0, theta=0.0
% INFO    : Bus 47545	: V=0.9726954, theta=-33.236859 -> V=1.0, theta=0.0
% INFO    : Bus 47546	: V=0.9859169, theta=-32.359229 -> V=1.0, theta=0.0
% INFO    : Bus 47547	: V=0.9819903, theta=-32.293417 -> V=1.0, theta=0.0
% INFO    : Bus 47548	: V=0.9816111, theta=-32.340533 -> V=1.0, theta=0.0
% INFO    : Bus 47549	: V=0.9823097, theta=-32.907043 -> V=1.0, theta=0.0
% INFO    : Bus 47550	: V=0.9941155, theta=-32.083398 -> V=1.0, theta=0.0
% INFO    : Bus 47551	: V=0.9952079, theta=-32.012131 -> V=1.0, theta=0.0
% INFO    : Bus 47552	: V=0.9945615, theta=-32.054695 -> V=1.0, theta=0.0
% INFO    : Bus 47553	: V=0.9941348, theta=-32.099322 -> V=1.0, theta=0.0
% INFO    : Bus 47554	: V=0.9908363, theta=-32.265034 -> V=1.0, theta=0.0
% INFO    : Bus 47555	: V=1.031709, theta=-13.816929 -> V=1.0, theta=0.0
% INFO    : Bus 47556	: V=1.0095104, theta=-17.778859 -> V=1.0, theta=0.0
% INFO    : Bus 47557	: V=1.0217777, theta=-16.245449 -> V=1.0, theta=0.0
% INFO    : Bus 47558	: V=1.0308395, theta=-14.152094 -> V=1.0, theta=0.0
% INFO    : Bus 47559	: V=1.0223845, theta=-21.931732 -> V=1.0, theta=0.0
% INFO    : Bus 47560	: V=1.018041, theta=-21.220904 -> V=1.0, theta=0.0
% INFO    : Bus 47561	: V=1.0144147, theta=-21.168978 -> V=1.0, theta=0.0
% INFO    : Bus 47562	: V=1.0267301, theta=-21.09095 -> V=1.0, theta=0.0
% INFO    : Bus 47563	: V=1.0158714, theta=-21.343812 -> V=1.0, theta=0.0
% INFO    : Bus 47564	: V=1.0266134, theta=-20.891314 -> V=1.0, theta=0.0
% INFO    : Bus 47565	: V=0.9787767, theta=-33.388407 -> V=1.0, theta=0.0
% INFO    : Bus 47566	: V=0.9810206, theta=-33.346193 -> V=1.0, theta=0.0
% INFO    : Bus 47567	: V=1.0006212, theta=-32.193259 -> V=1.0, theta=0.0
% INFO    : Bus 47568	: V=0.984571, theta=-32.972822 -> V=1.0, theta=0.0
% INFO    : Bus 47569	: V=0.9822788, theta=-33.156194 -> V=1.0, theta=0.0
% INFO    : Bus 47570	: V=0.9811038, theta=-33.168268 -> V=1.0, theta=0.0
% INFO    : Bus 47571	: V=0.9957839, theta=-32.176162 -> V=1.0, theta=0.0
% INFO    : Bus 47572	: V=1.0190562, theta=-29.874549 -> V=1.0, theta=0.0
% INFO    : Bus 47573	: V=1.0008194, theta=-31.935032 -> V=1.0, theta=0.0
% INFO    : Bus 47574	: V=1.0049433, theta=-32.227853 -> V=1.0, theta=0.0
% INFO    : Bus 47575	: V=1.0006094, theta=-31.897225 -> V=1.0, theta=0.0
% INFO    : Bus 47576	: V=1.0064826, theta=-31.389848 -> V=1.0, theta=0.0
% INFO    : Bus 47577	: V=1.0185111, theta=-31.510357 -> V=1.0, theta=0.0
% INFO    : Bus 47578	: V=1.016058, theta=-30.904873 -> V=1.0, theta=0.0
% INFO    : Bus 47579	: V=0.9920665, theta=-31.786295 -> V=1.0, theta=0.0
% INFO    : Bus 47580	: V=1.0006827, theta=-32.238489 -> V=1.0, theta=0.0
% INFO    : Bus 47581	: V=0.9941169, theta=-32.109855 -> V=1.0, theta=0.0
% INFO    : Bus 47582	: V=0.9937894, theta=-32.141351 -> V=1.0, theta=0.0
% INFO    : Bus 47583	: V=0.9832889, theta=-32.401593 -> V=1.0, theta=0.0
% INFO    : Bus 47584	: V=0.9846214, theta=-32.232133 -> V=1.0, theta=0.0
% INFO    : Bus 47585	: V=1.0037849, theta=-32.232845 -> V=1.0, theta=0.0
% INFO    : Bus 47586	: V=0.9724961, theta=-35.547297 -> V=1.0, theta=0.0
% INFO    : Bus 47587	: V=0.9842418, theta=-34.424212 -> V=1.0, theta=0.0
% INFO    : Bus 47588	: V=0.9840385, theta=-35.70227 -> V=1.0, theta=0.0
% INFO    : Bus 47589	: V=1.0118084, theta=-24.070361 -> V=1.0, theta=0.0
% INFO    : Bus 47590	: V=1.0119524, theta=-22.949829 -> V=1.0, theta=0.0
% INFO    : Bus 47591	: V=1.0001075, theta=-25.242605 -> V=1.0, theta=0.0
% INFO    : Bus 47592	: V=0.9801247, theta=-34.494709 -> V=1.0, theta=0.0
% INFO    : Bus 47593	: V=0.9724084, theta=-35.645209 -> V=1.0, theta=0.0
% INFO    : Bus 47594	: V=0.9727652, theta=-36.16936 -> V=1.0, theta=0.0
% INFO    : Bus 47595	: V=0.977238, theta=-34.941018 -> V=1.0, theta=0.0
% INFO    : Bus 47596	: V=0.9776886, theta=-34.882204 -> V=1.0, theta=0.0
% INFO    : Bus 47597	: V=0.9783877, theta=-34.766548 -> V=1.0, theta=0.0
% INFO    : Bus 47598	: V=0.9776888, theta=-34.851662 -> V=1.0, theta=0.0
% INFO    : Bus 47599	: V=0.9751023, theta=-35.880242 -> V=1.0, theta=0.0
% INFO    : Bus 47600	: V=0.976759, theta=-35.008622 -> V=1.0, theta=0.0
% INFO    : Bus 47601	: V=0.9735915, theta=-36.297707 -> V=1.0, theta=0.0
% INFO    : Bus 47602	: V=0.9734435, theta=-36.436203 -> V=1.0, theta=0.0
% INFO    : Bus 47603	: V=0.9722175, theta=-36.470287 -> V=1.0, theta=0.0
% INFO    : Bus 47604	: V=0.9765015, theta=-35.02942 -> V=1.0, theta=0.0
% INFO    : Bus 47605	: V=0.9781261, theta=-37.387893 -> V=1.0, theta=0.0
% INFO    : Bus 47606	: V=0.9781952, theta=-37.431786 -> V=1.0, theta=0.0
% INFO    : Bus 47607	: V=0.9764319, theta=-35.749664 -> V=1.0, theta=0.0
% INFO    : Bus 47608	: V=0.9770491, theta=-34.973117 -> V=1.0, theta=0.0
% INFO    : Bus 47609	: V=0.9779122, theta=-37.410819 -> V=1.0, theta=0.0
% INFO    : Bus 47610	: V=0.9778123, theta=-37.41632 -> V=1.0, theta=0.0
% INFO    : Bus 47611	: V=0.9777366, theta=-35.713607 -> V=1.0, theta=0.0
% INFO    : Bus 47612	: V=0.9915851, theta=-31.760004 -> V=1.0, theta=0.0
% INFO    : Bus 47613	: V=0.9606763, theta=-36.7935 -> V=1.0, theta=0.0
% INFO    : Bus 47614	: V=0.9694116, theta=-36.426246 -> V=1.0, theta=0.0
% INFO    : Bus 47615	: V=0.9637242, theta=-36.581137 -> V=1.0, theta=0.0
% INFO    : Bus 47616	: V=0.9784954, theta=-37.373708 -> V=1.0, theta=0.0
% INFO    : Bus 47617	: V=0.9805693, theta=-37.509048 -> V=1.0, theta=0.0
% INFO    : Bus 47618	: V=0.9927225, theta=-42.887179 -> V=1.0, theta=0.0
% INFO    : Bus 47619	: V=0.9958939, theta=-44.490364 -> V=1.0, theta=0.0
% INFO    : Bus 47620	: V=0.9945313, theta=-44.033946 -> V=1.0, theta=0.0
% INFO    : Bus 47621	: V=0.987465, theta=-45.782433 -> V=1.0, theta=0.0
% INFO    : Bus 47622	: V=0.9946073, theta=-19.139701 -> V=1.0, theta=0.0
% INFO    : Bus 47623	: V=1.0028546, theta=-19.873934 -> V=1.0, theta=0.0
% INFO    : Bus 47624	: V=1.0039921, theta=-20.324444 -> V=1.0, theta=0.0
% INFO    : Bus 47625	: V=1.0069605, theta=-20.967915 -> V=1.0, theta=0.0
% INFO    : Bus 47626	: V=0.9971144, theta=-25.568232 -> V=1.0, theta=0.0
% INFO    : Bus 47627	: V=0.9950868, theta=-25.693752 -> V=1.0, theta=0.0
% INFO    : Bus 47628	: V=0.9917051, theta=-26.307627 -> V=1.0, theta=0.0
% INFO    : Bus 47629	: V=1.014014, theta=-37.479753 -> V=1.0, theta=0.0
% INFO    : Bus 47630	: V=1.0102513, theta=-36.646143 -> V=1.0, theta=0.0
% INFO    : Bus 47631	: V=0.9930226, theta=-38.971286 -> V=1.0, theta=0.0
% INFO    : Bus 47632	: V=0.9829485, theta=-44.537928 -> V=1.0, theta=0.0
% INFO    : Bus 47633	: V=0.9875632, theta=-41.667316 -> V=1.0, theta=0.0
% INFO    : Bus 47634	: V=0.9633787, theta=-42.288587 -> V=1.0, theta=0.0
% INFO    : Bus 47635	: V=0.9606511, theta=-42.341546 -> V=1.0, theta=0.0
% INFO    : Bus 47636	: V=0.958588, theta=-42.725873 -> V=1.0, theta=0.0
% INFO    : Bus 47637	: V=0.9610096, theta=-42.656395 -> V=1.0, theta=0.0
% INFO    : Bus 47638	: V=0.9888656, theta=-39.767148 -> V=1.0, theta=0.0
% INFO    : Bus 47639	: V=0.9945816, theta=-26.461788 -> V=1.0, theta=0.0
% INFO    : Bus 47640	: V=0.9868799, theta=-27.975124 -> V=1.0, theta=0.0
% INFO    : Bus 47641	: V=0.983115, theta=-28.26348 -> V=1.0, theta=0.0
% INFO    : Bus 47642	: V=0.9799834, theta=-28.886876 -> V=1.0, theta=0.0
% INFO    : Bus 47643	: V=0.9769465, theta=-29.618552 -> V=1.0, theta=0.0
% INFO    : Bus 47644	: V=0.9755476, theta=-31.276077 -> V=1.0, theta=0.0
% INFO    : Bus 47645	: V=0.9898571, theta=-30.202335 -> V=1.0, theta=0.0
% INFO    : Bus 47646	: V=0.9921238, theta=-30.210045 -> V=1.0, theta=0.0
% INFO    : Bus 47647	: V=0.9955317, theta=-29.924824 -> V=1.0, theta=0.0
% INFO    : Bus 47648	: V=0.9780392, theta=-31.13601 -> V=1.0, theta=0.0
% INFO    : Bus 47649	: V=0.9913848, theta=-30.238572 -> V=1.0, theta=0.0
% INFO    : Bus 47650	: V=0.9889231, theta=-29.989322 -> V=1.0, theta=0.0
% INFO    : Bus 47651	: V=0.9708442, theta=-31.550194 -> V=1.0, theta=0.0
% INFO    : Bus 47652	: V=0.9674248, theta=-31.803013 -> V=1.0, theta=0.0
% INFO    : Bus 47653	: V=0.9688562, theta=-31.487957 -> V=1.0, theta=0.0
% INFO    : Bus 47654	: V=0.9775247, theta=-31.089844 -> V=1.0, theta=0.0
% INFO    : Bus 47655	: V=0.9881725, theta=-30.143056 -> V=1.0, theta=0.0
% INFO    : Bus 47656	: V=1.0200509, theta=-27.765504 -> V=1.0, theta=0.0
% INFO    : Bus 47657	: V=0.9902141, theta=-30.044537 -> V=1.0, theta=0.0
% INFO    : Bus 47658	: V=1.0114675, theta=-29.16731 -> V=1.0, theta=0.0
% INFO    : Bus 47659	: V=1.010342, theta=-28.947489 -> V=1.0, theta=0.0
% INFO    : Bus 47660	: V=0.9803365, theta=-30.958581 -> V=1.0, theta=0.0
% INFO    : Bus 47661	: V=1.0119733, theta=-28.794392 -> V=1.0, theta=0.0
% INFO    : Bus 47662	: V=0.9919414, theta=-29.775513 -> V=1.0, theta=0.0
% INFO    : Bus 47663	: V=0.9797946, theta=-30.937369 -> V=1.0, theta=0.0
% INFO    : Bus 47664	: V=0.9831531, theta=-30.884435 -> V=1.0, theta=0.0
% INFO    : Bus 47665	: V=0.9879115, theta=-30.191894 -> V=1.0, theta=0.0
% INFO    : Bus 47666	: V=0.9820376, theta=-30.947868 -> V=1.0, theta=0.0
% INFO    : Bus 47667	: V=1.0101718, theta=-29.397581 -> V=1.0, theta=0.0
% INFO    : Bus 47668	: V=1.0108859, theta=-30.181377 -> V=1.0, theta=0.0
% INFO    : Bus 47669	: V=1.0102094, theta=-29.559145 -> V=1.0, theta=0.0
% INFO    : Bus 47670	: V=1.008489, theta=-30.653746 -> V=1.0, theta=0.0
% INFO    : Bus 47671	: V=1.0014041, theta=-29.620504 -> V=1.0, theta=0.0
% INFO    : Bus 47672	: V=0.9955429, theta=-30.066445 -> V=1.0, theta=0.0
% INFO    : Bus 47673	: V=1.013428, theta=-28.966802 -> V=1.0, theta=0.0
% INFO    : Bus 47674	: V=0.9766025, theta=-31.100438 -> V=1.0, theta=0.0
% INFO    : Bus 47675	: V=0.9850812, theta=-30.814348 -> V=1.0, theta=0.0
% INFO    : Bus 47676	: V=0.9937331, theta=-24.880321 -> V=1.0, theta=0.0
% INFO    : Bus 47677	: V=0.9889743, theta=-25.274512 -> V=1.0, theta=0.0
% INFO    : Bus 47678	: V=0.9851242, theta=-29.111805 -> V=1.0, theta=0.0
% INFO    : Bus 47679	: V=0.9819972, theta=-26.767879 -> V=1.0, theta=0.0
% INFO    : Bus 47680	: V=0.9841269, theta=-26.700432 -> V=1.0, theta=0.0
% INFO    : Bus 47681	: V=0.9870428, theta=-26.025172 -> V=1.0, theta=0.0
% INFO    : Bus 47682	: V=0.994007, theta=-25.388205 -> V=1.0, theta=0.0
% INFO    : Bus 47683	: V=0.9871087, theta=-26.679033 -> V=1.0, theta=0.0
% INFO    : Bus 47684	: V=1.0017499, theta=-25.153614 -> V=1.0, theta=0.0
% INFO    : Bus 47685	: V=0.9917497, theta=-27.41513 -> V=1.0, theta=0.0
% INFO    : Bus 47686	: V=0.9851793, theta=-29.664489 -> V=1.0, theta=0.0
% INFO    : Bus 47687	: V=0.9928964, theta=-27.106228 -> V=1.0, theta=0.0
% INFO    : Bus 47688	: V=0.9834296, theta=-30.375113 -> V=1.0, theta=0.0
% INFO    : Bus 47689	: V=1.0162434, theta=-22.869916 -> V=1.0, theta=0.0
% INFO    : Bus 47690	: V=1.0106227, theta=-23.389655 -> V=1.0, theta=0.0
% INFO    : Bus 47691	: V=1.0119097, theta=-27.533767 -> V=1.0, theta=0.0
% INFO    : Bus 47692	: V=1.0157523, theta=-25.380526 -> V=1.0, theta=0.0
% INFO    : Bus 47693	: V=0.9992601, theta=-29.386336 -> V=1.0, theta=0.0
% INFO    : Bus 47694	: V=1.0169167, theta=-26.538811 -> V=1.0, theta=0.0
% INFO    : Bus 47695	: V=1.0089532, theta=-28.343393 -> V=1.0, theta=0.0
% INFO    : Bus 47696	: V=1.0008896, theta=-31.028194 -> V=1.0, theta=0.0
% INFO    : Bus 47697	: V=0.9689152, theta=-68.904451 -> V=1.0, theta=0.0
% INFO    : Bus 47698	: V=1.011417, theta=-64.587012 -> V=1.0, theta=0.0
% INFO    : Bus 47699	: V=0.9895133, theta=-66.566262 -> V=1.0, theta=0.0
% INFO    : Bus 47700	: V=1.0150857, theta=-64.004915 -> V=1.0, theta=0.0
% INFO    : Bus 47701	: V=0.9923213, theta=-66.657289 -> V=1.0, theta=0.0
% INFO    : Bus 47702	: V=0.9611403, theta=-70.899434 -> V=1.0, theta=0.0
% INFO    : Bus 47703	: V=0.9685495, theta=-70.002707 -> V=1.0, theta=0.0
% INFO    : Bus 47704	: V=0.9900336, theta=-66.830523 -> V=1.0, theta=0.0
% INFO    : Bus 47705	: V=0.9943352, theta=-66.534353 -> V=1.0, theta=0.0
% INFO    : Bus 47706	: V=0.9882297, theta=-67.164635 -> V=1.0, theta=0.0
% INFO    : Bus 47707	: V=0.970719, theta=-67.886197 -> V=1.0, theta=0.0
% INFO    : Bus 47708	: V=0.9857166, theta=-67.489481 -> V=1.0, theta=0.0
% INFO    : Bus 47709	: V=0.9460229, theta=-67.900083 -> V=1.0, theta=0.0
% INFO    : Bus 47710	: V=0.9762155, theta=-62.656689 -> V=1.0, theta=0.0
% INFO    : Bus 47711	: V=0.9634823, theta=-64.041744 -> V=1.0, theta=0.0
% INFO    : Bus 47712	: V=0.9519559, theta=-67.72164 -> V=1.0, theta=0.0
% INFO    : Bus 47713	: V=0.950776, theta=-68.744406 -> V=1.0, theta=0.0
% INFO    : Bus 47714	: V=1.0053501, theta=-62.68332 -> V=1.0, theta=0.0
% INFO    : Bus 47715	: V=0.9851923, theta=-65.982781 -> V=1.0, theta=0.0
% INFO    : Bus 47716	: V=1.0056058, theta=-62.587155 -> V=1.0, theta=0.0
% INFO    : Bus 47717	: V=0.9868548, theta=-64.804328 -> V=1.0, theta=0.0
% INFO    : Bus 47718	: V=0.9864822, theta=-64.992072 -> V=1.0, theta=0.0
% INFO    : Bus 47719	: V=0.9770863, theta=-67.931349 -> V=1.0, theta=0.0
% INFO    : Bus 47720	: V=0.963644, theta=-67.97407 -> V=1.0, theta=0.0
% INFO    : Bus 47721	: V=1.0127992, theta=-62.657622 -> V=1.0, theta=0.0
% INFO    : Bus 47722	: V=0.9461335, theta=-71.017123 -> V=1.0, theta=0.0
% INFO    : Bus 47723	: V=0.9491818, theta=-70.831281 -> V=1.0, theta=0.0
% INFO    : Bus 47724	: V=0.9817562, theta=-66.716577 -> V=1.0, theta=0.0
% INFO    : Bus 47725	: V=0.9726599, theta=-68.321536 -> V=1.0, theta=0.0
% INFO    : Bus 47726	: V=0.9547717, theta=-69.983261 -> V=1.0, theta=0.0
% INFO    : Bus 47727	: V=0.9669449, theta=-69.036887 -> V=1.0, theta=0.0
% INFO    : Bus 47728	: V=0.9648997, theta=-69.252785 -> V=1.0, theta=0.0
% INFO    : Bus 47729	: V=0.959098, theta=-72.884655 -> V=1.0, theta=0.0
% INFO    : Bus 47730	: V=0.9878029, theta=-61.168875 -> V=1.0, theta=0.0
% INFO    : Bus 47731	: V=0.9692085, theta=-59.887749 -> V=1.0, theta=0.0
% INFO    : Bus 47732	: V=0.9674874, theta=-61.897547 -> V=1.0, theta=0.0
% INFO    : Bus 47733	: V=0.9728844, theta=-60.862363 -> V=1.0, theta=0.0
% INFO    : Bus 47734	: V=0.9761379, theta=-61.225791 -> V=1.0, theta=0.0
% INFO    : Bus 47735	: V=0.9884614, theta=-61.149469 -> V=1.0, theta=0.0
% INFO    : Bus 47736	: V=0.9649128, theta=-63.330895 -> V=1.0, theta=0.0
% INFO    : Bus 47737	: V=0.9571431, theta=-63.557255 -> V=1.0, theta=0.0
% INFO    : Bus 47738	: V=0.9540768, theta=-63.923403 -> V=1.0, theta=0.0
% INFO    : Bus 47739	: V=0.963375, theta=-66.952251 -> V=1.0, theta=0.0
% INFO    : Bus 47740	: V=1.0120634, theta=-62.12786 -> V=1.0, theta=0.0
% INFO    : Bus 47741	: V=0.990635, theta=-63.622418 -> V=1.0, theta=0.0
% INFO    : Bus 47742	: V=0.9945575, theta=-63.543496 -> V=1.0, theta=0.0
% INFO    : Bus 47743	: V=1.0006504, theta=-63.070152 -> V=1.0, theta=0.0
% INFO    : Bus 47744	: V=1.0051878, theta=-64.014267 -> V=1.0, theta=0.0
% INFO    : Bus 47745	: V=1.0024711, theta=-64.154067 -> V=1.0, theta=0.0
% INFO    : Bus 47746	: V=0.9798575, theta=-49.979235 -> V=1.0, theta=0.0
% INFO    : Bus 47747	: V=0.9679102, theta=-50.912186 -> V=1.0, theta=0.0
% INFO    : Bus 47748	: V=0.9768877, theta=-57.029939 -> V=1.0, theta=0.0
% INFO    : Bus 47749	: V=0.978608, theta=-57.058948 -> V=1.0, theta=0.0
% INFO    : Bus 47750	: V=0.9869633, theta=-52.128616 -> V=1.0, theta=0.0
% INFO    : Bus 47751	: V=0.9735989, theta=-61.3026 -> V=1.0, theta=0.0
% INFO    : Bus 47752	: V=0.9733531, theta=-60.883783 -> V=1.0, theta=0.0
% INFO    : Bus 47753	: V=0.9772659, theta=-59.297005 -> V=1.0, theta=0.0
% INFO    : Bus 47754	: V=0.9716224, theta=-61.273608 -> V=1.0, theta=0.0
% INFO    : Bus 47755	: V=0.9726784, theta=-61.200237 -> V=1.0, theta=0.0
% INFO    : Bus 47756	: V=0.9719992, theta=-61.238349 -> V=1.0, theta=0.0
% INFO    : Bus 47757	: V=0.972767, theta=-61.240252 -> V=1.0, theta=0.0
% INFO    : Bus 47758	: V=0.9751208, theta=-58.517667 -> V=1.0, theta=0.0
% INFO    : Bus 47759	: V=0.9656974, theta=-60.432284 -> V=1.0, theta=0.0
% INFO    : Bus 47760	: V=0.9663755, theta=-60.104384 -> V=1.0, theta=0.0
% INFO    : Bus 47761	: V=0.9853831, theta=-53.915156 -> V=1.0, theta=0.0
% INFO    : Bus 47762	: V=0.9764824, theta=-58.119949 -> V=1.0, theta=0.0
% INFO    : Bus 47763	: V=0.9769041, theta=-58.171799 -> V=1.0, theta=0.0
% INFO    : Bus 47764	: V=0.9569713, theta=-56.403119 -> V=1.0, theta=0.0
% INFO    : Bus 47765	: V=0.9720675, theta=-58.421249 -> V=1.0, theta=0.0
% INFO    : Bus 47766	: V=0.9703186, theta=-57.162808 -> V=1.0, theta=0.0
% INFO    : Bus 47767	: V=0.9616101, theta=-63.237207 -> V=1.0, theta=0.0
% INFO    : Bus 47768	: V=0.9712611, theta=-59.409293 -> V=1.0, theta=0.0
% INFO    : Bus 47769	: V=0.9761065, theta=-58.980711 -> V=1.0, theta=0.0
% INFO    : Bus 47770	: V=0.9705269, theta=-61.113999 -> V=1.0, theta=0.0
% INFO    : Bus 47771	: V=0.9457679, theta=-53.691499 -> V=1.0, theta=0.0
% INFO    : Bus 47772	: V=0.9757806, theta=-60.931341 -> V=1.0, theta=0.0
% INFO    : Bus 47773	: V=0.9859739, theta=-59.914107 -> V=1.0, theta=0.0
% INFO    : Bus 47774	: V=0.9943094, theta=-60.467324 -> V=1.0, theta=0.0
% INFO    : Bus 47775	: V=0.991381, theta=-60.529912 -> V=1.0, theta=0.0
% INFO    : Bus 47776	: V=0.983043, theta=-60.644053 -> V=1.0, theta=0.0
% INFO    : Bus 47777	: V=0.9750919, theta=-61.120785 -> V=1.0, theta=0.0
% INFO    : Bus 47778	: V=0.9796161, theta=-60.664461 -> V=1.0, theta=0.0
% INFO    : Bus 47779	: V=0.9735931, theta=-61.215316 -> V=1.0, theta=0.0
% INFO    : Bus 47780	: V=0.9727139, theta=-61.239434 -> V=1.0, theta=0.0
% INFO    : Bus 47781	: V=0.9779996, theta=-60.48338 -> V=1.0, theta=0.0
% INFO    : Bus 47782	: V=0.981975, theta=-60.682241 -> V=1.0, theta=0.0
% INFO    : Bus 47783	: V=0.986988, theta=-60.041817 -> V=1.0, theta=0.0
% INFO    : Bus 47784	: V=0.9875447, theta=-60.007941 -> V=1.0, theta=0.0
% INFO    : Bus 47785	: V=0.9891763, theta=-60.558005 -> V=1.0, theta=0.0
% INFO    : Bus 47786	: V=0.9901478, theta=-60.616581 -> V=1.0, theta=0.0
% INFO    : Bus 47787	: V=0.9880629, theta=-60.661628 -> V=1.0, theta=0.0
% INFO    : Bus 47788	: V=0.9783746, theta=-60.917072 -> V=1.0, theta=0.0
% INFO    : Bus 47789	: V=0.9831164, theta=-60.521028 -> V=1.0, theta=0.0
% INFO    : Bus 47790	: V=1.0088755, theta=-58.66859 -> V=1.0, theta=0.0
% INFO    : Bus 47791	: V=0.9784158, theta=-60.613436 -> V=1.0, theta=0.0
% INFO    : Bus 47792	: V=0.9788991, theta=-60.608636 -> V=1.0, theta=0.0
% INFO    : Bus 47793	: V=0.9732925, theta=-59.07327 -> V=1.0, theta=0.0
% INFO    : Bus 47794	: V=0.9733719, theta=-59.011556 -> V=1.0, theta=0.0
% INFO    : Bus 47795	: V=0.9735574, theta=-58.929136 -> V=1.0, theta=0.0
% INFO    : Bus 47796	: V=0.9760698, theta=-60.398635 -> V=1.0, theta=0.0
% INFO    : Bus 47797	: V=0.9765823, theta=-60.394654 -> V=1.0, theta=0.0
% INFO    : Bus 47798	: V=0.977398, theta=-60.511193 -> V=1.0, theta=0.0
% INFO    : Bus 47799	: V=0.9775403, theta=-60.54504 -> V=1.0, theta=0.0
% INFO    : Bus 47800	: V=0.9794712, theta=-60.861278 -> V=1.0, theta=0.0
% INFO    : Bus 47801	: V=0.9864767, theta=-60.076815 -> V=1.0, theta=0.0
% INFO    : Bus 47802	: V=0.9732003, theta=-62.543446 -> V=1.0, theta=0.0
% INFO    : Bus 47803	: V=0.9755048, theta=-59.6237 -> V=1.0, theta=0.0
% INFO    : Bus 47804	: V=0.9810081, theta=-59.654436 -> V=1.0, theta=0.0
% INFO    : Bus 47805	: V=0.9792995, theta=-59.279448 -> V=1.0, theta=0.0
% INFO    : Bus 47806	: V=0.9798128, theta=-59.560662 -> V=1.0, theta=0.0
% INFO    : Bus 47807	: V=0.9758337, theta=-60.391125 -> V=1.0, theta=0.0
% INFO    : Bus 47808	: V=0.9799207, theta=-59.480694 -> V=1.0, theta=0.0
% INFO    : Bus 47809	: V=0.9808393, theta=-58.791769 -> V=1.0, theta=0.0
% INFO    : Bus 47810	: V=0.9781392, theta=-59.856813 -> V=1.0, theta=0.0
% INFO    : Bus 47811	: V=0.9752817, theta=-59.824701 -> V=1.0, theta=0.0
% INFO    : Bus 47812	: V=0.9671384, theta=-61.377855 -> V=1.0, theta=0.0
% INFO    : Bus 47813	: V=0.9736675, theta=-61.203616 -> V=1.0, theta=0.0
% INFO    : Bus 47814	: V=0.9696679, theta=-61.161375 -> V=1.0, theta=0.0
% INFO    : Bus 47815	: V=0.9756719, theta=-59.901334 -> V=1.0, theta=0.0
% INFO    : Bus 47816	: V=0.9699608, theta=-61.853916 -> V=1.0, theta=0.0
% INFO    : Bus 47817	: V=0.9780801, theta=-60.518436 -> V=1.0, theta=0.0
% INFO    : Bus 47818	: V=0.9784238, theta=-60.553502 -> V=1.0, theta=0.0
% INFO    : Bus 47819	: V=0.9593288, theta=-62.925374 -> V=1.0, theta=0.0
% INFO    : Bus 47820	: V=0.9774226, theta=-60.688309 -> V=1.0, theta=0.0
% INFO    : Bus 47821	: V=0.9577967, theta=-63.734382 -> V=1.0, theta=0.0
% INFO    : Bus 47822	: V=0.9753228, theta=-61.031167 -> V=1.0, theta=0.0
% INFO    : Bus 47823	: V=0.9552311, theta=-63.203684 -> V=1.0, theta=0.0
% INFO    : Bus 47824	: V=0.9675407, theta=-60.432695 -> V=1.0, theta=0.0
% INFO    : Bus 47825	: V=0.9690988, theta=-62.067005 -> V=1.0, theta=0.0
% INFO    : Bus 47826	: V=0.9726002, theta=-61.763532 -> V=1.0, theta=0.0
% INFO    : Bus 47827	: V=0.9668743, theta=-62.115385 -> V=1.0, theta=0.0
% INFO    : Bus 47828	: V=0.9619089, theta=-63.777186 -> V=1.0, theta=0.0
% INFO    : Bus 47829	: V=0.9700489, theta=-58.604281 -> V=1.0, theta=0.0
% INFO    : Bus 47830	: V=0.9705384, theta=-58.348908 -> V=1.0, theta=0.0
% INFO    : Bus 47831	: V=0.9729478, theta=-57.565225 -> V=1.0, theta=0.0
% INFO    : Bus 47832	: V=0.9873108, theta=-60.596885 -> V=1.0, theta=0.0
% INFO    : Bus 47833	: V=0.9879876, theta=-59.92913 -> V=1.0, theta=0.0
% INFO    : Bus 47834	: V=0.9580177, theta=-63.002118 -> V=1.0, theta=0.0
% INFO    : Bus 47835	: V=0.9542247, theta=-63.256824 -> V=1.0, theta=0.0
% INFO    : Bus 47836	: V=0.9722164, theta=-62.56428 -> V=1.0, theta=0.0
% INFO    : Bus 47837	: V=1.0026904, theta=-66.1859 -> V=1.0, theta=0.0
% INFO    : Bus 47838	: V=1.0058757, theta=-66.016268 -> V=1.0, theta=0.0
% INFO    : Bus 47839	: V=0.9914933, theta=-67.393504 -> V=1.0, theta=0.0
% INFO    : Bus 47840	: V=1.0010191, theta=-66.281541 -> V=1.0, theta=0.0
% INFO    : Bus 47841	: V=0.9955533, theta=-66.751326 -> V=1.0, theta=0.0
% INFO    : Bus 47842	: V=0.9989253, theta=-66.400802 -> V=1.0, theta=0.0
% INFO    : Bus 47843	: V=1.0155914, theta=-65.215541 -> V=1.0, theta=0.0
% INFO    : Bus 47844	: V=1.0035008, theta=-66.164055 -> V=1.0, theta=0.0
% INFO    : Bus 47845	: V=0.9834754, theta=-67.914186 -> V=1.0, theta=0.0
% INFO    : Bus 47846	: V=1.0017477, theta=-66.486024 -> V=1.0, theta=0.0
% INFO    : Bus 47847	: V=0.9814689, theta=-68.132944 -> V=1.0, theta=0.0
% INFO    : Bus 47848	: V=0.9792458, theta=-68.244749 -> V=1.0, theta=0.0
% INFO    : Bus 47849	: V=0.9782752, theta=-68.280326 -> V=1.0, theta=0.0
% INFO    : Bus 47850	: V=0.9836745, theta=-67.937388 -> V=1.0, theta=0.0
% INFO    : Bus 47851	: V=0.999965, theta=-66.336441 -> V=1.0, theta=0.0
% INFO    : Bus 47852	: V=0.991722, theta=-66.921054 -> V=1.0, theta=0.0
% INFO    : Bus 47853	: V=0.9972663, theta=-66.482809 -> V=1.0, theta=0.0
% INFO    : Bus 47854	: V=0.9684328, theta=-68.432854 -> V=1.0, theta=0.0
% INFO    : Bus 47855	: V=0.9938739, theta=-67.503277 -> V=1.0, theta=0.0
% INFO    : Bus 47856	: V=1.0020648, theta=-66.454466 -> V=1.0, theta=0.0
% INFO    : Bus 47857	: V=1.0019902, theta=-66.290207 -> V=1.0, theta=0.0
% INFO    : Bus 47858	: V=0.9828817, theta=-67.959912 -> V=1.0, theta=0.0
% INFO    : Bus 47859	: V=0.9951594, theta=-66.688879 -> V=1.0, theta=0.0
% INFO    : Bus 47860	: V=0.9970796, theta=-66.552787 -> V=1.0, theta=0.0
% INFO    : Bus 47861	: V=0.9823655, theta=-67.5682 -> V=1.0, theta=0.0
% INFO    : Bus 47862	: V=1.0055624, theta=-65.861577 -> V=1.0, theta=0.0
% INFO    : Bus 47863	: V=1.0043338, theta=-65.926841 -> V=1.0, theta=0.0
% INFO    : Bus 47864	: V=1.017744, theta=-64.158997 -> V=1.0, theta=0.0
% INFO    : Bus 47865	: V=1.0150432, theta=-63.765958 -> V=1.0, theta=0.0
% INFO    : Bus 47866	: V=1.0088786, theta=-65.848927 -> V=1.0, theta=0.0
% INFO    : Bus 47867	: V=1.0196671, theta=-64.599937 -> V=1.0, theta=0.0
% INFO    : Bus 47868	: V=1.0184401, theta=-64.524543 -> V=1.0, theta=0.0
% INFO    : Bus 47869	: V=1.0051709, theta=-66.195125 -> V=1.0, theta=0.0
% INFO    : Bus 47870	: V=0.9811343, theta=-68.313581 -> V=1.0, theta=0.0
% INFO    : Bus 47871	: V=1.0072055, theta=-66.04203 -> V=1.0, theta=0.0
% INFO    : Bus 47872	: V=1.0099295, theta=-65.842031 -> V=1.0, theta=0.0
% INFO    : Bus 47873	: V=1.0125975, theta=-65.703716 -> V=1.0, theta=0.0
% INFO    : Bus 47874	: V=1.0125946, theta=-65.904606 -> V=1.0, theta=0.0
% INFO    : Bus 47875	: V=1.0115054, theta=-65.852907 -> V=1.0, theta=0.0
% INFO    : Bus 47876	: V=0.9649029, theta=-68.94972 -> V=1.0, theta=0.0
% INFO    : Bus 47877	: V=0.9567498, theta=-69.293602 -> V=1.0, theta=0.0
% INFO    : Bus 47878	: V=0.9586488, theta=-69.071203 -> V=1.0, theta=0.0
% INFO    : Bus 47879	: V=0.9895364, theta=-67.030849 -> V=1.0, theta=0.0
% INFO    : Bus 47880	: V=0.9827074, theta=-67.94625 -> V=1.0, theta=0.0
% INFO    : Bus 47881	: V=0.9738156, theta=-49.554046 -> V=1.0, theta=0.0
% INFO    : Bus 47882	: V=0.967465, theta=-49.599904 -> V=1.0, theta=0.0
% INFO    : Bus 47883	: V=0.9692135, theta=-50.839635 -> V=1.0, theta=0.0
% INFO    : Bus 47884	: V=0.9864596, theta=-68.035783 -> V=1.0, theta=0.0
% INFO    : Bus 47885	: V=0.9638877, theta=-71.540192 -> V=1.0, theta=0.0
% INFO    : Bus 47886	: V=0.9698848, theta=-54.116899 -> V=1.0, theta=0.0
% INFO    : Bus 47887	: V=0.975758, theta=-55.715224 -> V=1.0, theta=0.0
% INFO    : Bus 47888	: V=0.9831197, theta=-56.700907 -> V=1.0, theta=0.0
% INFO    : Bus 47889	: V=0.9748281, theta=-45.653885 -> V=1.0, theta=0.0
% INFO    : Bus 47890	: V=0.9736986, theta=-49.943373 -> V=1.0, theta=0.0
% INFO    : Bus 47891	: V=0.9756705, theta=-49.147566 -> V=1.0, theta=0.0
% INFO    : Bus 47892	: V=0.9733983, theta=-50.125078 -> V=1.0, theta=0.0
% INFO    : Bus 47893	: V=0.9740424, theta=-50.151264 -> V=1.0, theta=0.0
% INFO    : Bus 47894	: V=0.9603968, theta=-55.69913 -> V=1.0, theta=0.0
% INFO    : Bus 47895	: V=0.9589655, theta=-56.051703 -> V=1.0, theta=0.0
% INFO    : Bus 47896	: V=0.9565144, theta=-58.195172 -> V=1.0, theta=0.0
% INFO    : Bus 47897	: V=0.9566689, theta=-58.526884 -> V=1.0, theta=0.0
% INFO    : Bus 47898	: V=0.998031, theta=-57.999731 -> V=1.0, theta=0.0
% INFO    : Bus 47899	: V=0.985856, theta=-59.605693 -> V=1.0, theta=0.0
% INFO    : Bus 47900	: V=0.9828739, theta=-60.276815 -> V=1.0, theta=0.0
% INFO    : Bus 47901	: V=1.0187197, theta=-55.720331 -> V=1.0, theta=0.0
% INFO    : Bus 47902	: V=1.0002389, theta=-57.94461 -> V=1.0, theta=0.0
% INFO    : Bus 47903	: V=1.0015111, theta=-57.976671 -> V=1.0, theta=0.0
% INFO    : Bus 47904	: V=1.0052384, theta=-57.593563 -> V=1.0, theta=0.0
% INFO    : Bus 47905	: V=0.9936547, theta=-58.094687 -> V=1.0, theta=0.0
% INFO    : Bus 47906	: V=0.9908542, theta=-65.231208 -> V=1.0, theta=0.0
% INFO    : Bus 47907	: V=0.99996, theta=-64.444115 -> V=1.0, theta=0.0
% INFO    : Bus 47908	: V=1.0037709, theta=-64.220186 -> V=1.0, theta=0.0
% INFO    : Bus 47909	: V=1.0015917, theta=-64.351756 -> V=1.0, theta=0.0
% INFO    : Bus 47910	: V=0.9948128, theta=-64.709418 -> V=1.0, theta=0.0
% INFO    : Bus 47911	: V=0.9822914, theta=-65.754245 -> V=1.0, theta=0.0
% INFO    : Bus 47912	: V=0.9913913, theta=-64.860706 -> V=1.0, theta=0.0
% INFO    : Bus 47913	: V=0.9841999, theta=-65.660605 -> V=1.0, theta=0.0
% INFO    : Bus 47914	: V=0.9980028, theta=-64.546455 -> V=1.0, theta=0.0
% INFO    : Bus 47915	: V=0.974977, theta=-66.018757 -> V=1.0, theta=0.0
% INFO    : Bus 47916	: V=0.9760684, theta=-65.978599 -> V=1.0, theta=0.0
% INFO    : Bus 47917	: V=0.9847867, theta=-65.085328 -> V=1.0, theta=0.0
% INFO    : Bus 47918	: V=0.9879529, theta=-65.000769 -> V=1.0, theta=0.0
% INFO    : Bus 47919	: V=0.9863322, theta=-65.044683 -> V=1.0, theta=0.0
% INFO    : Bus 47920	: V=0.9589036, theta=-67.11628 -> V=1.0, theta=0.0
% INFO    : Bus 47921	: V=0.9722362, theta=-65.677068 -> V=1.0, theta=0.0
% INFO    : Bus 47922	: V=0.9498686, theta=-67.904481 -> V=1.0, theta=0.0
% INFO    : Bus 47923	: V=0.9491597, theta=-67.920443 -> V=1.0, theta=0.0
% INFO    : Bus 47924	: V=0.9836355, theta=-65.045094 -> V=1.0, theta=0.0
% INFO    : Bus 47925	: V=0.9757998, theta=-65.50672 -> V=1.0, theta=0.0
% INFO    : Bus 47926	: V=0.9592201, theta=-67.108992 -> V=1.0, theta=0.0
% INFO    : Bus 47927	: V=0.9775997, theta=-65.365648 -> V=1.0, theta=0.0
% INFO    : Bus 47928	: V=0.9767192, theta=-65.460006 -> V=1.0, theta=0.0
% INFO    : Bus 47929	: V=0.9770241, theta=-65.426599 -> V=1.0, theta=0.0
% INFO    : Bus 47930	: V=0.9761733, theta=-65.450489 -> V=1.0, theta=0.0
% INFO    : Bus 47931	: V=0.9607793, theta=-67.056403 -> V=1.0, theta=0.0
% INFO    : Bus 47932	: V=0.9795254, theta=-65.230889 -> V=1.0, theta=0.0
% INFO    : Bus 47933	: V=0.9781454, theta=-65.37169 -> V=1.0, theta=0.0
% INFO    : Bus 47934	: V=1.0103221, theta=-60.864706 -> V=1.0, theta=0.0
% INFO    : Bus 47935	: V=0.9864433, theta=-65.372565 -> V=1.0, theta=0.0
% INFO    : Bus 47936	: V=0.9848343, theta=-65.391222 -> V=1.0, theta=0.0
% INFO    : Bus 47937	: V=0.9857743, theta=-63.356335 -> V=1.0, theta=0.0
% INFO    : Bus 47938	: V=0.9867191, theta=-63.063825 -> V=1.0, theta=0.0
% INFO    : Bus 47939	: V=1.0039621, theta=-64.206589 -> V=1.0, theta=0.0
% INFO    : Bus 47940	: V=0.9868904, theta=-65.388911 -> V=1.0, theta=0.0
% INFO    : Bus 47941	: V=0.9714602, theta=-65.778823 -> V=1.0, theta=0.0
% INFO    : Bus 47942	: V=0.9730762, theta=-65.722108 -> V=1.0, theta=0.0
% INFO    : Bus 47943	: V=0.9926555, theta=-64.672251 -> V=1.0, theta=0.0
% INFO    : Bus 47944	: V=0.9865308, theta=-64.84634 -> V=1.0, theta=0.0
% INFO    : Bus 47945	: V=0.9845044, theta=-64.602773 -> V=1.0, theta=0.0
% INFO    : Bus 47946	: V=0.9750179, theta=-65.79745 -> V=1.0, theta=0.0
% INFO    : Bus 47947	: V=0.9843743, theta=-64.813065 -> V=1.0, theta=0.0
% INFO    : Bus 47948	: V=0.9841524, theta=-64.738391 -> V=1.0, theta=0.0
% INFO    : Bus 47949	: V=0.9832648, theta=-64.96903 -> V=1.0, theta=0.0
% INFO    : Bus 47950	: V=0.9836239, theta=-64.906892 -> V=1.0, theta=0.0
% INFO    : Bus 47951	: V=0.9835711, theta=-64.819696 -> V=1.0, theta=0.0
% INFO    : Bus 47952	: V=0.9742606, theta=-65.562903 -> V=1.0, theta=0.0
% INFO    : Bus 47953	: V=0.9626812, theta=-66.569641 -> V=1.0, theta=0.0
% INFO    : Bus 47954	: V=0.9635298, theta=-66.462201 -> V=1.0, theta=0.0
% INFO    : Bus 47955	: V=0.9835518, theta=-64.84644 -> V=1.0, theta=0.0
% INFO    : Bus 47956	: V=0.9830383, theta=-64.85686 -> V=1.0, theta=0.0
% INFO    : Bus 47957	: V=0.9851298, theta=-64.772856 -> V=1.0, theta=0.0
% INFO    : Bus 47958	: V=0.9828807, theta=-64.873429 -> V=1.0, theta=0.0
% INFO    : Bus 47959	: V=0.9830117, theta=-64.868288 -> V=1.0, theta=0.0
% INFO    : Bus 47960	: V=0.9828678, theta=-64.945873 -> V=1.0, theta=0.0
% INFO    : Bus 47961	: V=0.9830245, theta=-64.902608 -> V=1.0, theta=0.0
% INFO    : Bus 47962	: V=0.9677954, theta=-66.149894 -> V=1.0, theta=0.0
% INFO    : Bus 47963	: V=0.985028, theta=-64.723813 -> V=1.0, theta=0.0
% INFO    : Bus 47964	: V=1.0098323, theta=-62.109544 -> V=1.0, theta=0.0
% INFO    : Bus 47965	: V=0.9691577, theta=-66.308616 -> V=1.0, theta=0.0
% INFO    : Bus 47966	: V=0.9806198, theta=-65.151286 -> V=1.0, theta=0.0
% INFO    : Bus 47967	: V=0.9820405, theta=-65.056452 -> V=1.0, theta=0.0
% INFO    : Bus 47968	: V=1.0086064, theta=-62.592468 -> V=1.0, theta=0.0
% INFO    : Bus 47969	: V=0.9777955, theta=-65.854959 -> V=1.0, theta=0.0
% INFO    : Bus 47970	: V=0.9897885, theta=-64.377771 -> V=1.0, theta=0.0
% INFO    : Bus 47971	: V=0.9873699, theta=-63.21955 -> V=1.0, theta=0.0
% INFO    : Bus 47972	: V=0.9896908, theta=-62.910477 -> V=1.0, theta=0.0
% INFO    : Bus 47973	: V=0.9903789, theta=-62.660915 -> V=1.0, theta=0.0
% INFO    : Bus 47974	: V=0.9891652, theta=-62.858556 -> V=1.0, theta=0.0
% INFO    : Bus 47975	: V=0.9908667, theta=-62.990586 -> V=1.0, theta=0.0
% INFO    : Bus 47976	: V=0.9754883, theta=-64.18949 -> V=1.0, theta=0.0
% INFO    : Bus 47977	: V=0.9841201, theta=-63.342083 -> V=1.0, theta=0.0
% INFO    : Bus 47978	: V=0.986828, theta=-63.837749 -> V=1.0, theta=0.0
% INFO    : Bus 47979	: V=0.9858781, theta=-64.270989 -> V=1.0, theta=0.0
% INFO    : Bus 47980	: V=0.9857263, theta=-64.559799 -> V=1.0, theta=0.0
% INFO    : Bus 47981	: V=0.9848895, theta=-64.65932 -> V=1.0, theta=0.0
% INFO    : Bus 47982	: V=0.9646813, theta=-66.61054 -> V=1.0, theta=0.0
% INFO    : Bus 47983	: V=0.983675, theta=-64.832217 -> V=1.0, theta=0.0
% INFO    : Bus 47984	: V=0.9847248, theta=-64.774716 -> V=1.0, theta=0.0
% INFO    : Bus 47985	: V=0.9892562, theta=-64.434278 -> V=1.0, theta=0.0
% INFO    : Bus 47986	: V=0.9659447, theta=-66.487831 -> V=1.0, theta=0.0
% INFO    : Bus 47987	: V=1.0042071, theta=-60.882141 -> V=1.0, theta=0.0
% INFO    : Bus 47988	: V=1.0160851, theta=-60.133268 -> V=1.0, theta=0.0
% INFO    : Bus 47989	: V=0.9960974, theta=-61.931336 -> V=1.0, theta=0.0
% INFO    : Bus 47990	: V=1.0001939, theta=-61.43157 -> V=1.0, theta=0.0
% INFO    : Bus 47991	: V=0.9636371, theta=-66.874081 -> V=1.0, theta=0.0
% INFO    : Bus 47992	: V=0.9775018, theta=-65.361322 -> V=1.0, theta=0.0
% INFO    : Bus 47993	: V=0.966941, theta=-66.182655 -> V=1.0, theta=0.0
% INFO    : Bus 47994	: V=0.9727446, theta=-65.665382 -> V=1.0, theta=0.0
% INFO    : Bus 47995	: V=0.9760888, theta=-65.468156 -> V=1.0, theta=0.0
% INFO    : Bus 47996	: V=0.9746378, theta=-65.566129 -> V=1.0, theta=0.0
% INFO    : Bus 47997	: V=0.9844028, theta=-65.395381 -> V=1.0, theta=0.0
% INFO    : Bus 47998	: V=0.9632125, theta=-43.938331 -> V=1.0, theta=0.0
% INFO    : Bus 47999	: V=0.9604532, theta=-45.842169 -> V=1.0, theta=0.0
% INFO    : Bus 48000	: V=0.9620094, theta=-44.745375 -> V=1.0, theta=0.0
% INFO    : Bus 48001	: V=0.9907074, theta=-62.651839 -> V=1.0, theta=0.0
% INFO    : Bus 48002	: V=0.9934634, theta=-62.067609 -> V=1.0, theta=0.0
% INFO    : Bus 48003	: V=1.0108162, theta=-59.031506 -> V=1.0, theta=0.0
% INFO    : Bus 48004	: V=0.9962802, theta=-61.698487 -> V=1.0, theta=0.0
% INFO    : Bus 48005	: V=0.9898711, theta=-63.151459 -> V=1.0, theta=0.0
% INFO    : Bus 48006	: V=0.9873173, theta=-62.394796 -> V=1.0, theta=0.0
% INFO    : Bus 48007	: V=0.9717017, theta=-63.424673 -> V=1.0, theta=0.0
% INFO    : Bus 48008	: V=0.9872507, theta=-65.777286 -> V=1.0, theta=0.0
% INFO    : Bus 48009	: V=0.9826255, theta=-65.815061 -> V=1.0, theta=0.0
% INFO    : Bus 48010	: V=0.9859727, theta=-65.211867 -> V=1.0, theta=0.0
% INFO    : Bus 48011	: V=0.996203, theta=-64.070558 -> V=1.0, theta=0.0
% INFO    : Bus 48012	: V=1.0136336, theta=-61.204204 -> V=1.0, theta=0.0
% INFO    : Bus 48013	: V=0.9968752, theta=-65.115313 -> V=1.0, theta=0.0
% INFO    : Bus 48014	: V=0.9543107, theta=-49.811374 -> V=1.0, theta=0.0
% INFO    : Bus 48015	: V=0.9680725, theta=-48.80965 -> V=1.0, theta=0.0
% INFO    : Bus 48016	: V=0.9564007, theta=-50.016577 -> V=1.0, theta=0.0
% INFO    : Bus 48017	: V=0.9438769, theta=-50.721363 -> V=1.0, theta=0.0
% INFO    : Bus 48018	: V=0.9665488, theta=-50.580538 -> V=1.0, theta=0.0
% INFO    : Bus 48019	: V=0.9532218, theta=-52.124872 -> V=1.0, theta=0.0
% INFO    : Bus 48020	: V=0.989488, theta=-56.070332 -> V=1.0, theta=0.0
% INFO    : Bus 48021	: V=1.0033986, theta=-55.031724 -> V=1.0, theta=0.0
% INFO    : Bus 48022	: V=1.0120739, theta=-54.877536 -> V=1.0, theta=0.0
% INFO    : Bus 48023	: V=0.9838574, theta=-56.878572 -> V=1.0, theta=0.0
% INFO    : Bus 48024	: V=0.9839825, theta=-57.101985 -> V=1.0, theta=0.0
% INFO    : Bus 48025	: V=0.9602301, theta=-70.90444 -> V=1.0, theta=0.0
% INFO    : Bus 48026	: V=0.958761, theta=-71.015847 -> V=1.0, theta=0.0
% INFO    : Bus 48027	: V=0.9598368, theta=-71.776384 -> V=1.0, theta=0.0
% INFO    : Bus 48028	: V=0.9570461, theta=-73.101397 -> V=1.0, theta=0.0
% INFO    : Bus 48029	: V=0.9731925, theta=-70.121662 -> V=1.0, theta=0.0
% INFO    : Bus 48030	: V=0.9585652, theta=-72.118039 -> V=1.0, theta=0.0
% INFO    : Bus 48031	: V=0.9583788, theta=-71.817842 -> V=1.0, theta=0.0
% INFO    : Bus 48032	: V=0.9592274, theta=-71.966901 -> V=1.0, theta=0.0
% INFO    : Bus 48033	: V=0.9575747, theta=-72.164285 -> V=1.0, theta=0.0
% INFO    : Bus 48034	: V=0.958393, theta=-72.133538 -> V=1.0, theta=0.0
% INFO    : Bus 48035	: V=0.9594773, theta=-72.05324 -> V=1.0, theta=0.0
% INFO    : Bus 48036	: V=0.9777659, theta=-69.401648 -> V=1.0, theta=0.0
% INFO    : Bus 48037	: V=0.9589925, theta=-72.079197 -> V=1.0, theta=0.0
% INFO    : Bus 48038	: V=1.0041875, theta=-64.752511 -> V=1.0, theta=0.0
% INFO    : Bus 48039	: V=0.9925731, theta=-68.939442 -> V=1.0, theta=0.0
% INFO    : Bus 48040	: V=0.9552374, theta=-66.040657 -> V=1.0, theta=0.0
% INFO    : Bus 48041	: V=1.0128346, theta=-60.046653 -> V=1.0, theta=0.0
% INFO    : Bus 48042	: V=0.993045, theta=-64.244905 -> V=1.0, theta=0.0
% INFO    : Bus 48043	: V=1.0031646, theta=-63.702759 -> V=1.0, theta=0.0
% INFO    : Bus 48044	: V=1.0171122, theta=-61.600475 -> V=1.0, theta=0.0
% INFO    : Bus 48045	: V=1.0199042, theta=-60.880323 -> V=1.0, theta=0.0
% INFO    : Bus 48046	: V=0.9673407, theta=-48.664552 -> V=1.0, theta=0.0
% INFO    : Bus 48047	: V=0.9813144, theta=-51.133467 -> V=1.0, theta=0.0
% INFO    : Bus 48048	: V=0.989989, theta=-52.751419 -> V=1.0, theta=0.0
% INFO    : Bus 48049	: V=0.9941936, theta=-53.27133 -> V=1.0, theta=0.0
% INFO    : Bus 48050	: V=0.9995843, theta=-53.393452 -> V=1.0, theta=0.0
% INFO    : Bus 48051	: V=0.9694526, theta=-65.900688 -> V=1.0, theta=0.0
% INFO    : Bus 48052	: V=0.9707337, theta=-65.88366 -> V=1.0, theta=0.0
% INFO    : Bus 48053	: V=0.9834723, theta=-64.787381 -> V=1.0, theta=0.0
% INFO    : Bus 48054	: V=0.9711828, theta=-65.851176 -> V=1.0, theta=0.0
% INFO    : Bus 48055	: V=0.9712477, theta=-65.914807 -> V=1.0, theta=0.0
% INFO    : Bus 48056	: V=0.9594612, theta=-66.654463 -> V=1.0, theta=0.0
% INFO    : Bus 48057	: V=0.9621379, theta=-66.481788 -> V=1.0, theta=0.0
% INFO    : Bus 48058	: V=0.9775474, theta=-65.026695 -> V=1.0, theta=0.0
% INFO    : Bus 48059	: V=0.9588699, theta=-66.704535 -> V=1.0, theta=0.0
% INFO    : Bus 48060	: V=0.960031, theta=-66.731619 -> V=1.0, theta=0.0
% INFO    : Bus 48061	: V=0.9667446, theta=-66.168108 -> V=1.0, theta=0.0
% INFO    : Bus 48062	: V=0.9782821, theta=-64.900738 -> V=1.0, theta=0.0
% INFO    : Bus 48063	: V=0.966061, theta=-66.212279 -> V=1.0, theta=0.0
% INFO    : Bus 48064	: V=0.9615287, theta=-66.587486 -> V=1.0, theta=0.0
% INFO    : Bus 48065	: V=0.9587004, theta=-66.715005 -> V=1.0, theta=0.0
% INFO    : Bus 48066	: V=0.9651117, theta=-66.296066 -> V=1.0, theta=0.0
% INFO    : Bus 48067	: V=0.9598237, theta=-66.742442 -> V=1.0, theta=0.0
% INFO    : Bus 48068	: V=0.9597919, theta=-66.741515 -> V=1.0, theta=0.0
% INFO    : Bus 48069	: V=0.9661092, theta=-66.17626 -> V=1.0, theta=0.0
% INFO    : Bus 48070	: V=0.9667016, theta=-66.16562 -> V=1.0, theta=0.0
% INFO    : Bus 48071	: V=0.9597855, theta=-66.673318 -> V=1.0, theta=0.0
% INFO    : Bus 48072	: V=1.0115175, theta=-61.493457 -> V=1.0, theta=0.0
% INFO    : Bus 48073	: V=0.9652609, theta=-66.252958 -> V=1.0, theta=0.0
% INFO    : Bus 48074	: V=0.9647589, theta=-66.246887 -> V=1.0, theta=0.0
% INFO    : Bus 48075	: V=0.9655275, theta=-66.227328 -> V=1.0, theta=0.0
% INFO    : Bus 48076	: V=0.9657299, theta=-66.210883 -> V=1.0, theta=0.0
% INFO    : Bus 48077	: V=0.966385, theta=-66.170369 -> V=1.0, theta=0.0
% INFO    : Bus 48078	: V=0.9674578, theta=-66.086138 -> V=1.0, theta=0.0
% INFO    : Bus 48079	: V=0.9774656, theta=-64.996779 -> V=1.0, theta=0.0
% INFO    : Bus 48080	: V=0.9669504, theta=-66.181143 -> V=1.0, theta=0.0
% INFO    : Bus 48081	: V=0.977713, theta=-65.033004 -> V=1.0, theta=0.0
% INFO    : Bus 48082	: V=0.9783839, theta=-65.022406 -> V=1.0, theta=0.0
% INFO    : Bus 48083	: V=0.966955, theta=-66.187815 -> V=1.0, theta=0.0
% INFO    : Bus 48084	: V=0.965882, theta=-66.244988 -> V=1.0, theta=0.0
% INFO    : Bus 48085	: V=0.9731102, theta=-65.805964 -> V=1.0, theta=0.0
% INFO    : Bus 48086	: V=0.9815804, theta=-64.882588 -> V=1.0, theta=0.0
% INFO    : Bus 48087	: V=0.9727888, theta=-65.924796 -> V=1.0, theta=0.0
% INFO    : Bus 48088	: V=0.9707049, theta=-65.866342 -> V=1.0, theta=0.0
% INFO    : Bus 48089	: V=0.975112, theta=-65.772275 -> V=1.0, theta=0.0
% INFO    : Bus 48090	: V=0.9718859, theta=-65.842371 -> V=1.0, theta=0.0
% INFO    : Bus 48091	: V=0.9870898, theta=-64.588382 -> V=1.0, theta=0.0
% INFO    : Bus 48092	: V=0.9867108, theta=-64.62095 -> V=1.0, theta=0.0
% INFO    : Bus 48093	: V=0.973613, theta=-65.769899 -> V=1.0, theta=0.0
% INFO    : Bus 48094	: V=0.9867432, theta=-64.626445 -> V=1.0, theta=0.0
% INFO    : Bus 48095	: V=0.9761365, theta=-65.73116 -> V=1.0, theta=0.0
% INFO    : Bus 48096	: V=0.9876388, theta=-64.583839 -> V=1.0, theta=0.0
% INFO    : Bus 48097	: V=0.9737558, theta=-65.850118 -> V=1.0, theta=0.0
% INFO    : Bus 48098	: V=0.9744315, theta=-65.838006 -> V=1.0, theta=0.0
% INFO    : Bus 48099	: V=0.9738833, theta=-65.868891 -> V=1.0, theta=0.0
% INFO    : Bus 48100	: V=0.9714001, theta=-66.02036 -> V=1.0, theta=0.0
% INFO    : Bus 48101	: V=0.9691352, theta=-66.131373 -> V=1.0, theta=0.0
% INFO    : Bus 48102	: V=0.9668873, theta=-66.194717 -> V=1.0, theta=0.0
% INFO    : Bus 48103	: V=0.9708363, theta=-66.041878 -> V=1.0, theta=0.0
% INFO    : Bus 48104	: V=0.968022, theta=-66.181873 -> V=1.0, theta=0.0
% INFO    : Bus 48105	: V=0.9672178, theta=-66.192209 -> V=1.0, theta=0.0
% INFO    : Bus 48106	: V=0.9669084, theta=-66.195825 -> V=1.0, theta=0.0
% INFO    : Bus 48107	: V=0.9662431, theta=-66.179513 -> V=1.0, theta=0.0
% INFO    : Bus 48108	: V=0.975444, theta=-65.395531 -> V=1.0, theta=0.0
% INFO    : Bus 48109	: V=0.9756303, theta=-65.38727 -> V=1.0, theta=0.0
% INFO    : Bus 48110	: V=0.9761162, theta=-65.363721 -> V=1.0, theta=0.0
% INFO    : Bus 48111	: V=0.9697072, theta=-66.236701 -> V=1.0, theta=0.0
% INFO    : Bus 48112	: V=0.968388, theta=-66.278355 -> V=1.0, theta=0.0
% INFO    : Bus 48113	: V=0.9675698, theta=-66.288641 -> V=1.0, theta=0.0
% INFO    : Bus 48114	: V=0.981096, theta=-65.047572 -> V=1.0, theta=0.0
% INFO    : Bus 48115	: V=0.9697968, theta=-66.19613 -> V=1.0, theta=0.0
% INFO    : Bus 48116	: V=0.9691545, theta=-66.24599 -> V=1.0, theta=0.0
% INFO    : Bus 48117	: V=0.9832224, theta=-64.907095 -> V=1.0, theta=0.0
% INFO    : Bus 48118	: V=0.9712351, theta=-66.042353 -> V=1.0, theta=0.0
% INFO    : Bus 48119	: V=1.0115614, theta=-62.07773 -> V=1.0, theta=0.0
% INFO    : Bus 48120	: V=0.9861471, theta=-64.70546 -> V=1.0, theta=0.0
% INFO    : Bus 48121	: V=0.9857276, theta=-64.726179 -> V=1.0, theta=0.0
% INFO    : Bus 48122	: V=0.9873954, theta=-64.633189 -> V=1.0, theta=0.0
% INFO    : Bus 48123	: V=0.9768832, theta=-65.721286 -> V=1.0, theta=0.0
% INFO    : Bus 48124	: V=0.9891884, theta=-64.520314 -> V=1.0, theta=0.0
% INFO    : Bus 48125	: V=0.9888091, theta=-64.518137 -> V=1.0, theta=0.0
% INFO    : Bus 48126	: V=1.0181548, theta=-61.95117 -> V=1.0, theta=0.0
% INFO    : Bus 48127	: V=0.9917657, theta=-64.258168 -> V=1.0, theta=0.0
% INFO    : Bus 48128	: V=0.9919792, theta=-64.242273 -> V=1.0, theta=0.0
% INFO    : Bus 48129	: V=0.9969235, theta=-63.65137 -> V=1.0, theta=0.0
% INFO    : Bus 48130	: V=0.9914302, theta=-64.256065 -> V=1.0, theta=0.0
% INFO    : Bus 48131	: V=0.9972543, theta=-63.621501 -> V=1.0, theta=0.0
% INFO    : Bus 48132	: V=0.9887406, theta=-64.369625 -> V=1.0, theta=0.0
% INFO    : Bus 48133	: V=0.9891629, theta=-64.351189 -> V=1.0, theta=0.0
% INFO    : Bus 48134	: V=0.9914217, theta=-64.268639 -> V=1.0, theta=0.0
% INFO    : Bus 48135	: V=0.9913337, theta=-64.269243 -> V=1.0, theta=0.0
% INFO    : Bus 48136	: V=0.98923, theta=-64.351395 -> V=1.0, theta=0.0
% INFO    : Bus 48137	: V=0.9754782, theta=-65.632012 -> V=1.0, theta=0.0
% INFO    : Bus 48138	: V=0.9880249, theta=-64.405847 -> V=1.0, theta=0.0
% INFO    : Bus 48139	: V=0.98762, theta=-64.421955 -> V=1.0, theta=0.0
% INFO    : Bus 48140	: V=0.9881487, theta=-64.366213 -> V=1.0, theta=0.0
% INFO    : Bus 48141	: V=0.9806219, theta=-65.050899 -> V=1.0, theta=0.0
% INFO    : Bus 48142	: V=0.9894943, theta=-64.2779 -> V=1.0, theta=0.0
% INFO    : Bus 48143	: V=0.9759448, theta=-65.609089 -> V=1.0, theta=0.0
% INFO    : Bus 48144	: V=0.990568, theta=-64.204476 -> V=1.0, theta=0.0
% INFO    : Bus 48145	: V=0.9913665, theta=-64.147819 -> V=1.0, theta=0.0
% INFO    : Bus 48146	: V=0.9927234, theta=-64.048837 -> V=1.0, theta=0.0
% INFO    : Bus 48147	: V=0.982695, theta=-65.018598 -> V=1.0, theta=0.0
% INFO    : Bus 48148	: V=0.9989737, theta=-63.562563 -> V=1.0, theta=0.0
% INFO    : Bus 48149	: V=0.9829321, theta=-65.046886 -> V=1.0, theta=0.0
% INFO    : Bus 48150	: V=1.0105028, theta=-62.064583 -> V=1.0, theta=0.0
% INFO    : Bus 48151	: V=0.976086, theta=-65.383428 -> V=1.0, theta=0.0
% INFO    : Bus 48152	: V=0.9441718, theta=-69.084848 -> V=1.0, theta=0.0
% INFO    : Bus 48153	: V=0.9992598, theta=-63.52517 -> V=1.0, theta=0.0
% INFO    : Bus 48154	: V=0.9828636, theta=-65.048279 -> V=1.0, theta=0.0
% INFO    : Bus 48155	: V=0.9805812, theta=-65.116694 -> V=1.0, theta=0.0
% INFO    : Bus 48156	: V=0.9738432, theta=-65.819484 -> V=1.0, theta=0.0
% INFO    : Bus 48157	: V=0.9546901, theta=-69.988 -> V=1.0, theta=0.0
% INFO    : Bus 48158	: V=0.972569, theta=-68.960755 -> V=1.0, theta=0.0
% INFO    : Bus 48159	: V=0.9509866, theta=-70.170806 -> V=1.0, theta=0.0
% INFO    : Bus 48160	: V=0.9658732, theta=-66.24266 -> V=1.0, theta=0.0
% INFO    : Bus 48161	: V=1.0138099, theta=-62.097606 -> V=1.0, theta=0.0
% INFO    : Bus 48162	: V=0.9806152, theta=-64.663211 -> V=1.0, theta=0.0
% INFO    : Bus 48163	: V=0.9765912, theta=-67.530454 -> V=1.0, theta=0.0
% INFO    : Bus 48164	: V=0.999886, theta=-66.335465 -> V=1.0, theta=0.0
% INFO    : Bus 48165	: V=1.0157656, theta=-64.833308 -> V=1.0, theta=0.0
% INFO    : Bus 48166	: V=0.9988036, theta=-65.94627 -> V=1.0, theta=0.0
% INFO    : Bus 48167	: V=1.0054297, theta=-65.478723 -> V=1.0, theta=0.0
% INFO    : Bus 48168	: V=0.9870602, theta=-67.123319 -> V=1.0, theta=0.0
% INFO    : Bus 48169	: V=0.9821271, theta=-67.45984 -> V=1.0, theta=0.0
% INFO    : Bus 48170	: V=0.9711354, theta=-69.453605 -> V=1.0, theta=0.0
% INFO    : Bus 48171	: V=0.969602, theta=-69.582684 -> V=1.0, theta=0.0
% INFO    : Bus 48172	: V=0.970074, theta=-69.625587 -> V=1.0, theta=0.0
% INFO    : Bus 48173	: V=0.9839659, theta=-67.170527 -> V=1.0, theta=0.0
% INFO    : Bus 48174	: V=0.9669557, theta=-70.410075 -> V=1.0, theta=0.0
% INFO    : Bus 48175	: V=0.9688336, theta=-69.966177 -> V=1.0, theta=0.0
% INFO    : Bus 48176	: V=0.9779326, theta=-68.238928 -> V=1.0, theta=0.0
% INFO    : Bus 48177	: V=0.9731292, theta=-69.196173 -> V=1.0, theta=0.0
% INFO    : Bus 48178	: V=0.9720743, theta=-69.253092 -> V=1.0, theta=0.0
% INFO    : Bus 48179	: V=0.9860882, theta=-67.129295 -> V=1.0, theta=0.0
% INFO    : Bus 48180	: V=0.9756962, theta=-68.273176 -> V=1.0, theta=0.0
% INFO    : Bus 48181	: V=0.9748286, theta=-68.221855 -> V=1.0, theta=0.0
% INFO    : Bus 48182	: V=0.9750863, theta=-68.490839 -> V=1.0, theta=0.0
% INFO    : Bus 48183	: V=0.9741472, theta=-68.563681 -> V=1.0, theta=0.0
% INFO    : Bus 48184	: V=0.9653489, theta=-69.872347 -> V=1.0, theta=0.0
% INFO    : Bus 48185	: V=0.95466, theta=-72.110264 -> V=1.0, theta=0.0
% INFO    : Bus 48186	: V=0.9584537, theta=-72.344063 -> V=1.0, theta=0.0
% INFO    : Bus 48187	: V=0.9584777, theta=-72.167222 -> V=1.0, theta=0.0
% INFO    : Bus 48188	: V=0.9700674, theta=-70.020531 -> V=1.0, theta=0.0
% INFO    : Bus 48189	: V=0.9719219, theta=-69.846459 -> V=1.0, theta=0.0
% INFO    : Bus 48190	: V=0.9652454, theta=-70.424438 -> V=1.0, theta=0.0
% INFO    : Bus 48191	: V=0.965904, theta=-70.341066 -> V=1.0, theta=0.0
% INFO    : Bus 48192	: V=0.9682205, theta=-70.675714 -> V=1.0, theta=0.0
% INFO    : Bus 48193	: V=0.9636555, theta=-72.643604 -> V=1.0, theta=0.0
% INFO    : Bus 48194	: V=0.9711618, theta=-69.942191 -> V=1.0, theta=0.0
% INFO    : Bus 48195	: V=0.9661172, theta=-70.14198 -> V=1.0, theta=0.0
% INFO    : Bus 48196	: V=0.9669366, theta=-70.214125 -> V=1.0, theta=0.0
% INFO    : Bus 48197	: V=0.9628373, theta=-70.427172 -> V=1.0, theta=0.0
% INFO    : Bus 48198	: V=0.9647479, theta=-70.595207 -> V=1.0, theta=0.0
% INFO    : Bus 48199	: V=0.9681008, theta=-70.063199 -> V=1.0, theta=0.0
% INFO    : Bus 48200	: V=0.9558217, theta=-71.495842 -> V=1.0, theta=0.0
% INFO    : Bus 48201	: V=0.9713453, theta=-68.938393 -> V=1.0, theta=0.0
% INFO    : Bus 48202	: V=0.9577209, theta=-71.565973 -> V=1.0, theta=0.0
% INFO    : Bus 48203	: V=0.964509, theta=-70.57078 -> V=1.0, theta=0.0
% INFO    : Bus 48204	: V=0.9554514, theta=-71.882335 -> V=1.0, theta=0.0
% INFO    : Bus 48205	: V=0.9686111, theta=-69.498533 -> V=1.0, theta=0.0
% INFO    : Bus 48206	: V=0.9685073, theta=-69.59568 -> V=1.0, theta=0.0
% INFO    : Bus 48207	: V=0.9698007, theta=-69.082622 -> V=1.0, theta=0.0
% INFO    : Bus 48208	: V=0.9718835, theta=-67.947808 -> V=1.0, theta=0.0
% INFO    : Bus 48209	: V=0.9669964, theta=-69.341627 -> V=1.0, theta=0.0
% INFO    : Bus 48210	: V=0.9680401, theta=-69.198756 -> V=1.0, theta=0.0
% INFO    : Bus 48211	: V=0.9694219, theta=-69.662242 -> V=1.0, theta=0.0
% INFO    : Bus 48212	: V=0.9682472, theta=-69.690801 -> V=1.0, theta=0.0
% INFO    : Bus 48213	: V=1.0057927, theta=-62.487148 -> V=1.0, theta=0.0
% INFO    : Bus 48214	: V=0.9868938, theta=-70.767397 -> V=1.0, theta=0.0
% INFO    : Bus 48215	: V=0.9527496, theta=-71.554411 -> V=1.0, theta=0.0
% INFO    : Bus 48216	: V=0.9449294, theta=-73.476329 -> V=1.0, theta=0.0
% INFO    : Bus 48217	: V=0.9481841, theta=-72.545885 -> V=1.0, theta=0.0
% INFO    : Bus 48218	: V=0.9667087, theta=-52.195441 -> V=1.0, theta=0.0
% INFO    : Bus 48219	: V=0.9678816, theta=-54.635756 -> V=1.0, theta=0.0
% INFO    : Bus 48220	: V=0.9709355, theta=-56.322448 -> V=1.0, theta=0.0
% INFO    : Bus 48221	: V=0.9773192, theta=-45.935951 -> V=1.0, theta=0.0
% INFO    : Bus 48222	: V=0.9729182, theta=-49.589977 -> V=1.0, theta=0.0
% INFO    : Bus 48223	: V=0.9734397, theta=-48.891787 -> V=1.0, theta=0.0
% INFO    : Bus 48224	: V=0.9751599, theta=-48.373511 -> V=1.0, theta=0.0
% INFO    : Bus 48225	: V=0.9830029, theta=-47.541723 -> V=1.0, theta=0.0
% INFO    : Bus 48226	: V=0.9856271, theta=-47.023807 -> V=1.0, theta=0.0
% INFO    : Bus 48227	: V=0.9793303, theta=-46.977299 -> V=1.0, theta=0.0
% INFO    : Bus 48228	: V=0.9737852, theta=-48.403372 -> V=1.0, theta=0.0
% INFO    : Bus 48229	: V=0.9750563, theta=-48.242635 -> V=1.0, theta=0.0
% INFO    : Bus 48230	: V=0.9700571, theta=-50.206779 -> V=1.0, theta=0.0
% INFO    : Bus 48231	: V=0.9946003, theta=-63.036882 -> V=1.0, theta=0.0
% INFO    : Bus 48232	: V=0.9737568, theta=-64.78577 -> V=1.0, theta=0.0
% INFO    : Bus 48233	: V=1.0003873, theta=-62.516785 -> V=1.0, theta=0.0
% INFO    : Bus 48234	: V=0.9893495, theta=-63.473221 -> V=1.0, theta=0.0
% INFO    : Bus 48235	: V=0.9885316, theta=-63.732351 -> V=1.0, theta=0.0
% INFO    : Bus 48236	: V=0.9656409, theta=-65.952543 -> V=1.0, theta=0.0
% INFO    : Bus 48237	: V=0.9783528, theta=-64.985669 -> V=1.0, theta=0.0
% INFO    : Bus 48238	: V=1.0015369, theta=-62.449583 -> V=1.0, theta=0.0
% INFO    : Bus 48239	: V=1.0028852, theta=-62.345835 -> V=1.0, theta=0.0
% INFO    : Bus 48240	: V=1.003892, theta=-62.251278 -> V=1.0, theta=0.0
% INFO    : Bus 48241	: V=1.0048713, theta=-62.157775 -> V=1.0, theta=0.0
% INFO    : Bus 48242	: V=1.0044682, theta=-62.585283 -> V=1.0, theta=0.0
% INFO    : Bus 48243	: V=0.9653034, theta=-66.106912 -> V=1.0, theta=0.0
% INFO    : Bus 48244	: V=0.9793134, theta=-64.831479 -> V=1.0, theta=0.0
% INFO    : Bus 48245	: V=0.9624184, theta=-66.686816 -> V=1.0, theta=0.0
% INFO    : Bus 48246	: V=0.994494, theta=-63.024779 -> V=1.0, theta=0.0
% INFO    : Bus 48247	: V=1.0027715, theta=-62.49099 -> V=1.0, theta=0.0
% INFO    : Bus 48248	: V=0.9350318, theta=-52.395634 -> V=1.0, theta=0.0
% INFO    : Bus 48249	: V=0.9596427, theta=-48.260027 -> V=1.0, theta=0.0
% INFO    : Bus 48250	: V=0.9520719, theta=-50.519693 -> V=1.0, theta=0.0
% INFO    : Bus 48251	: V=0.9513949, theta=-50.549343 -> V=1.0, theta=0.0
% INFO    : Bus 48252	: V=0.9505741, theta=-50.591543 -> V=1.0, theta=0.0
% INFO    : Bus 48253	: V=0.9633825, theta=-42.708827 -> V=1.0, theta=0.0
% INFO    : Bus 48254	: V=0.99575, theta=-40.250264 -> V=1.0, theta=0.0
% INFO    : Bus 48255	: V=1.0025249, theta=-38.83033 -> V=1.0, theta=0.0
% INFO    : Bus 48256	: V=0.9881983, theta=-41.885 -> V=1.0, theta=0.0
% INFO    : Bus 48257	: V=1.0134483, theta=-39.413747 -> V=1.0, theta=0.0
% INFO    : Bus 48258	: V=1.0018382, theta=-40.851098 -> V=1.0, theta=0.0
% INFO    : Bus 48259	: V=0.9860516, theta=-43.030574 -> V=1.0, theta=0.0
% INFO    : Bus 48260	: V=0.9862643, theta=-41.986084 -> V=1.0, theta=0.0
% INFO    : Bus 48261	: V=0.989196, theta=-56.618577 -> V=1.0, theta=0.0
% INFO    : Bus 48262	: V=0.9915688, theta=-58.093334 -> V=1.0, theta=0.0
% INFO    : Bus 48263	: V=0.9999602, theta=-58.910043 -> V=1.0, theta=0.0
% INFO    : Bus 48264	: V=0.9877678, theta=-58.262045 -> V=1.0, theta=0.0
% INFO    : Bus 48265	: V=0.9876893, theta=-58.218215 -> V=1.0, theta=0.0
% INFO    : Bus 48266	: V=0.9882127, theta=-58.116265 -> V=1.0, theta=0.0
% INFO    : Bus 48267	: V=0.9875094, theta=-58.266406 -> V=1.0, theta=0.0
% INFO    : Bus 48268	: V=0.9883619, theta=-58.520292 -> V=1.0, theta=0.0
% INFO    : Bus 48269	: V=0.9958793, theta=-57.17964 -> V=1.0, theta=0.0
% INFO    : Bus 48270	: V=0.9827677, theta=-65.158954 -> V=1.0, theta=0.0
% INFO    : Bus 48271	: V=0.9824446, theta=-65.163463 -> V=1.0, theta=0.0
% INFO    : Bus 48272	: V=0.9834207, theta=-65.11125 -> V=1.0, theta=0.0
% INFO    : Bus 48273	: V=0.991729, theta=-64.241137 -> V=1.0, theta=0.0
% INFO    : Bus 48274	: V=0.990288, theta=-64.379867 -> V=1.0, theta=0.0
% INFO    : Bus 48275	: V=0.9907098, theta=-64.356625 -> V=1.0, theta=0.0
% INFO    : Bus 48276	: V=0.9846702, theta=-64.981495 -> V=1.0, theta=0.0
% INFO    : Bus 48277	: V=0.9850666, theta=-64.97735 -> V=1.0, theta=0.0
% INFO    : Bus 48278	: V=1.0013459, theta=-63.249854 -> V=1.0, theta=0.0
% INFO    : Bus 48279	: V=0.9918402, theta=-64.273824 -> V=1.0, theta=0.0
% INFO    : Bus 48280	: V=0.9917177, theta=-64.266957 -> V=1.0, theta=0.0
% INFO    : Bus 48281	: V=0.9919646, theta=-64.310416 -> V=1.0, theta=0.0
% INFO    : Bus 48282	: V=0.9926572, theta=-64.409248 -> V=1.0, theta=0.0
% INFO    : Bus 48283	: V=0.9922388, theta=-64.408219 -> V=1.0, theta=0.0
% INFO    : Bus 48284	: V=0.9929317, theta=-64.287077 -> V=1.0, theta=0.0
% INFO    : Bus 48285	: V=0.9915381, theta=-64.398184 -> V=1.0, theta=0.0
% INFO    : Bus 48286	: V=0.9926131, theta=-64.295612 -> V=1.0, theta=0.0
% INFO    : Bus 48287	: V=0.9923649, theta=-64.301652 -> V=1.0, theta=0.0
% INFO    : Bus 48288	: V=0.991704, theta=-64.314387 -> V=1.0, theta=0.0
% INFO    : Bus 48289	: V=0.9912062, theta=-64.32187 -> V=1.0, theta=0.0
% INFO    : Bus 48290	: V=0.988589, theta=-64.434326 -> V=1.0, theta=0.0
% INFO    : Bus 48291	: V=0.9893877, theta=-64.411427 -> V=1.0, theta=0.0
% INFO    : Bus 48292	: V=0.9885028, theta=-64.434487 -> V=1.0, theta=0.0
% INFO    : Bus 48293	: V=0.9889974, theta=-64.417751 -> V=1.0, theta=0.0
% INFO    : Bus 48294	: V=0.9882293, theta=-64.456752 -> V=1.0, theta=0.0
% INFO    : Bus 48295	: V=0.9885023, theta=-64.434537 -> V=1.0, theta=0.0
% INFO    : Bus 48296	: V=1.0063784, theta=-62.791378 -> V=1.0, theta=0.0
% INFO    : Bus 48297	: V=1.0061503, theta=-62.814405 -> V=1.0, theta=0.0
% INFO    : Bus 48298	: V=1.0071464, theta=-62.732909 -> V=1.0, theta=0.0
% INFO    : Bus 48299	: V=1.0080509, theta=-62.573649 -> V=1.0, theta=0.0
% INFO    : Bus 48300	: V=1.0054822, theta=-62.637842 -> V=1.0, theta=0.0
% INFO    : Bus 48301	: V=1.0069128, theta=-62.740242 -> V=1.0, theta=0.0
% INFO    : Bus 48302	: V=1.0051782, theta=-62.676056 -> V=1.0, theta=0.0
% INFO    : Bus 48303	: V=1.0057529, theta=-62.124905 -> V=1.0, theta=0.0
% INFO    : Bus 48304	: V=0.9552819, theta=-66.406663 -> V=1.0, theta=0.0
% INFO    : Bus 48305	: V=1.0060696, theta=-62.6787 -> V=1.0, theta=0.0
% INFO    : Bus 48306	: V=1.0053147, theta=-62.607732 -> V=1.0, theta=0.0
% INFO    : Bus 48307	: V=1.0112102, theta=-61.659362 -> V=1.0, theta=0.0
% INFO    : Bus 48308	: V=1.0120845, theta=-61.773105 -> V=1.0, theta=0.0
% INFO    : Bus 48309	: V=1.0152444, theta=-60.741328 -> V=1.0, theta=0.0
% INFO    : Bus 48310	: V=1.0066332, theta=-62.259088 -> V=1.0, theta=0.0
% INFO    : Bus 48311	: V=1.0092585, theta=-61.973581 -> V=1.0, theta=0.0
% INFO    : Bus 48312	: V=1.010123, theta=-61.830735 -> V=1.0, theta=0.0
% INFO    : Bus 48313	: V=1.0120923, theta=-61.523184 -> V=1.0, theta=0.0
% INFO    : Bus 48314	: V=1.0153489, theta=-61.193966 -> V=1.0, theta=0.0
% INFO    : Bus 48315	: V=1.0154797, theta=-60.792219 -> V=1.0, theta=0.0
% INFO    : Bus 48316	: V=1.0095232, theta=-62.155332 -> V=1.0, theta=0.0
% INFO    : Bus 48317	: V=1.0070106, theta=-62.255005 -> V=1.0, theta=0.0
% INFO    : Bus 48318	: V=1.0159282, theta=-60.841104 -> V=1.0, theta=0.0
% INFO    : Bus 48319	: V=0.9910716, theta=-64.320363 -> V=1.0, theta=0.0
% INFO    : Bus 48320	: V=0.988048, theta=-64.483794 -> V=1.0, theta=0.0
% INFO    : Bus 48321	: V=0.9880524, theta=-64.476028 -> V=1.0, theta=0.0
% INFO    : Bus 48322	: V=0.9882245, theta=-64.45015 -> V=1.0, theta=0.0
% INFO    : Bus 48323	: V=0.9883866, theta=-64.448252 -> V=1.0, theta=0.0
% INFO    : Bus 48324	: V=0.9949816, theta=-63.948419 -> V=1.0, theta=0.0
% INFO    : Bus 48325	: V=0.9953292, theta=-63.92467 -> V=1.0, theta=0.0
% INFO    : Bus 48326	: V=0.9956539, theta=-63.902314 -> V=1.0, theta=0.0
% INFO    : Bus 48327	: V=1.0051881, theta=-62.902229 -> V=1.0, theta=0.0
% INFO    : Bus 48328	: V=1.0056465, theta=-62.85931 -> V=1.0, theta=0.0
% INFO    : Bus 48329	: V=0.9978509, theta=-63.692695 -> V=1.0, theta=0.0
% INFO    : Bus 48330	: V=0.9982828, theta=-63.690795 -> V=1.0, theta=0.0
% INFO    : Bus 48331	: V=0.9910202, theta=-64.316736 -> V=1.0, theta=0.0
% INFO    : Bus 48332	: V=0.99093, theta=-64.319617 -> V=1.0, theta=0.0
% INFO    : Bus 48333	: V=0.9945039, theta=-63.983744 -> V=1.0, theta=0.0
% INFO    : Bus 48334	: V=0.9884742, theta=-64.481217 -> V=1.0, theta=0.0
% INFO    : Bus 48335	: V=0.9887454, theta=-64.466539 -> V=1.0, theta=0.0
% INFO    : Bus 48336	: V=0.9888297, theta=-64.461033 -> V=1.0, theta=0.0
% INFO    : Bus 48337	: V=1.0038533, theta=-63.030968 -> V=1.0, theta=0.0
% INFO    : Bus 48338	: V=0.9886724, theta=-64.484802 -> V=1.0, theta=0.0
% INFO    : Bus 48339	: V=1.0045998, theta=-62.958758 -> V=1.0, theta=0.0
% INFO    : Bus 48340	: V=1.0007059, theta=-63.543846 -> V=1.0, theta=0.0
% INFO    : Bus 48341	: V=0.9949407, theta=-63.948764 -> V=1.0, theta=0.0
% INFO    : Bus 48342	: V=0.9951972, theta=-63.929594 -> V=1.0, theta=0.0
% INFO    : Bus 48343	: V=0.9880422, theta=-64.488652 -> V=1.0, theta=0.0
% INFO    : Bus 48344	: V=0.9943243, theta=-63.99907 -> V=1.0, theta=0.0
% INFO    : Bus 48345	: V=0.994382, theta=-63.993926 -> V=1.0, theta=0.0
% INFO    : Bus 48346	: V=0.9945285, theta=-63.980411 -> V=1.0, theta=0.0
% INFO    : Bus 48347	: V=0.9944881, theta=-63.985325 -> V=1.0, theta=0.0
% INFO    : Bus 48348	: V=0.9910582, theta=-64.309747 -> V=1.0, theta=0.0
% INFO    : Bus 48349	: V=0.9866019, theta=-64.707872 -> V=1.0, theta=0.0
% INFO    : Bus 48350	: V=0.9942757, theta=-64.003357 -> V=1.0, theta=0.0
% INFO    : Bus 48351	: V=0.9890723, theta=-64.550593 -> V=1.0, theta=0.0
% INFO    : Bus 48352	: V=0.9942325, theta=-64.010136 -> V=1.0, theta=0.0
% INFO    : Bus 48353	: V=0.994208, theta=-64.01456 -> V=1.0, theta=0.0
% INFO    : Bus 48354	: V=0.9943944, theta=-63.992338 -> V=1.0, theta=0.0
% INFO    : Bus 48355	: V=0.9811613, theta=-65.118117 -> V=1.0, theta=0.0
% INFO    : Bus 48356	: V=0.9865054, theta=-64.707655 -> V=1.0, theta=0.0
% INFO    : Bus 48357	: V=0.9941685, theta=-64.021731 -> V=1.0, theta=0.0
% INFO    : Bus 48358	: V=0.9944428, theta=-63.989173 -> V=1.0, theta=0.0
% INFO    : Bus 48359	: V=0.9817335, theta=-65.104612 -> V=1.0, theta=0.0
% INFO    : Bus 48360	: V=0.989886, theta=-64.425221 -> V=1.0, theta=0.0
% INFO    : Bus 48361	: V=0.9777053, theta=-65.431602 -> V=1.0, theta=0.0
% INFO    : Bus 48362	: V=0.9892261, theta=-64.443456 -> V=1.0, theta=0.0
% INFO    : Bus 48363	: V=0.986372, theta=-64.764564 -> V=1.0, theta=0.0
% INFO    : Bus 48364	: V=0.9903147, theta=-64.390158 -> V=1.0, theta=0.0
% INFO    : Bus 48365	: V=0.9942475, theta=-64.022693 -> V=1.0, theta=0.0
% INFO    : Bus 48366	: V=0.9945524, theta=-63.98249 -> V=1.0, theta=0.0
% INFO    : Bus 48367	: V=0.9833906, theta=-65.077503 -> V=1.0, theta=0.0
% INFO    : Bus 48368	: V=0.9897911, theta=-64.439542 -> V=1.0, theta=0.0
% INFO    : Bus 48369	: V=0.9943386, theta=-64.023612 -> V=1.0, theta=0.0
% INFO    : Bus 48370	: V=0.9949417, theta=-63.958272 -> V=1.0, theta=0.0
% INFO    : Bus 48371	: V=0.9838419, theta=-65.069786 -> V=1.0, theta=0.0
% INFO    : Bus 48372	: V=1.0046448, theta=-63.012665 -> V=1.0, theta=0.0
% INFO    : Bus 48373	: V=0.984674, theta=-65.000203 -> V=1.0, theta=0.0
% INFO    : Bus 48374	: V=0.9901277, theta=-64.431511 -> V=1.0, theta=0.0
% INFO    : Bus 48375	: V=0.978183, theta=-65.564828 -> V=1.0, theta=0.0
% INFO    : Bus 48376	: V=0.9898982, theta=-64.43829 -> V=1.0, theta=0.0
% INFO    : Bus 48377	: V=0.987766, theta=-64.536011 -> V=1.0, theta=0.0
% INFO    : Bus 48378	: V=0.9912444, theta=-64.267198 -> V=1.0, theta=0.0
% INFO    : Bus 48379	: V=0.9911986, theta=-64.269253 -> V=1.0, theta=0.0
% INFO    : Bus 48380	: V=0.9910967, theta=-64.272689 -> V=1.0, theta=0.0
% INFO    : Bus 48381	: V=0.9910383, theta=-64.273991 -> V=1.0, theta=0.0
% INFO    : Bus 48382	: V=0.991199, theta=-64.264284 -> V=1.0, theta=0.0
% INFO    : Bus 48383	: V=0.9898668, theta=-64.471918 -> V=1.0, theta=0.0
% INFO    : Bus 48384	: V=0.9943015, theta=-64.02943 -> V=1.0, theta=0.0
% INFO    : Bus 48385	: V=0.9909866, theta=-64.274187 -> V=1.0, theta=0.0
% INFO    : Bus 48386	: V=0.9908158, theta=-64.278996 -> V=1.0, theta=0.0
% INFO    : Bus 48387	: V=0.9912118, theta=-64.25994 -> V=1.0, theta=0.0
% INFO    : Bus 48388	: V=0.9876476, theta=-64.640303 -> V=1.0, theta=0.0
% INFO    : Bus 48389	: V=0.994492, theta=-64.020622 -> V=1.0, theta=0.0
% INFO    : Bus 48390	: V=0.9914016, theta=-64.242246 -> V=1.0, theta=0.0
% INFO    : Bus 48391	: V=0.9827475, theta=-65.131244 -> V=1.0, theta=0.0
% INFO    : Bus 48392	: V=0.9919175, theta=-64.207722 -> V=1.0, theta=0.0
% INFO    : Bus 48393	: V=0.9872839, theta=-64.670895 -> V=1.0, theta=0.0
% INFO    : Bus 48394	: V=0.9921438, theta=-64.197374 -> V=1.0, theta=0.0
% INFO    : Bus 48395	: V=0.9922692, theta=-64.193726 -> V=1.0, theta=0.0
% INFO    : Bus 48396	: V=0.9947476, theta=-64.008438 -> V=1.0, theta=0.0
% INFO    : Bus 48397	: V=0.9940272, theta=-64.087912 -> V=1.0, theta=0.0
% INFO    : Bus 48398	: V=0.9843304, theta=-64.879177 -> V=1.0, theta=0.0
% INFO    : Bus 48399	: V=0.994728, theta=-64.041109 -> V=1.0, theta=0.0
% INFO    : Bus 48400	: V=0.9924627, theta=-64.181074 -> V=1.0, theta=0.0
% INFO    : Bus 48401	: V=1.0056547, theta=-62.990129 -> V=1.0, theta=0.0
% INFO    : Bus 48402	: V=0.9949219, theta=-64.000855 -> V=1.0, theta=0.0
% INFO    : Bus 48403	: V=0.9882427, theta=-64.615337 -> V=1.0, theta=0.0
% INFO    : Bus 48404	: V=0.9894052, theta=-64.542625 -> V=1.0, theta=0.0
% INFO    : Bus 48405	: V=0.9884056, theta=-64.613621 -> V=1.0, theta=0.0
% INFO    : Bus 48406	: V=0.9959019, theta=-63.964656 -> V=1.0, theta=0.0
% INFO    : Bus 48407	: V=0.9952221, theta=-63.987397 -> V=1.0, theta=0.0
% INFO    : Bus 48408	: V=0.9907117, theta=-64.454793 -> V=1.0, theta=0.0
% INFO    : Bus 48409	: V=0.9955626, theta=-63.970563 -> V=1.0, theta=0.0
% INFO    : Bus 48410	: V=1.0184207, theta=-61.910184 -> V=1.0, theta=0.0
% INFO    : Bus 48411	: V=0.9951882, theta=-63.988572 -> V=1.0, theta=0.0
% INFO    : Bus 48412	: V=0.9864943, theta=-64.866615 -> V=1.0, theta=0.0
% INFO    : Bus 48413	: V=0.9862383, theta=-64.871512 -> V=1.0, theta=0.0
% INFO    : Bus 48414	: V=0.9964624, theta=-64.04559 -> V=1.0, theta=0.0
% INFO    : Bus 48415	: V=0.9955464, theta=-64.149303 -> V=1.0, theta=0.0
% INFO    : Bus 48416	: V=0.9949657, theta=-64.157478 -> V=1.0, theta=0.0
% INFO    : Bus 48417	: V=0.985989, theta=-64.876328 -> V=1.0, theta=0.0
% INFO    : Bus 48418	: V=1.0066492, theta=-62.913091 -> V=1.0, theta=0.0
% INFO    : Bus 48419	: V=0.9869064, theta=-64.717919 -> V=1.0, theta=0.0
% INFO    : Bus 48420	: V=0.9871924, theta=-64.714677 -> V=1.0, theta=0.0
% INFO    : Bus 48421	: V=0.9904343, theta=-64.417631 -> V=1.0, theta=0.0
% INFO    : Bus 48422	: V=0.9903359, theta=-64.344243 -> V=1.0, theta=0.0
% INFO    : Bus 48423	: V=1.0071197, theta=-62.883181 -> V=1.0, theta=0.0
% INFO    : Bus 48424	: V=1.0004633, theta=-63.370336 -> V=1.0, theta=0.0
% INFO    : Bus 48425	: V=0.991205, theta=-64.291993 -> V=1.0, theta=0.0
% INFO    : Bus 48426	: V=0.9892383, theta=-64.41242 -> V=1.0, theta=0.0
% INFO    : Bus 48427	: V=0.9942451, theta=-64.087169 -> V=1.0, theta=0.0
% INFO    : Bus 48428	: V=0.9946776, theta=-63.967864 -> V=1.0, theta=0.0
% INFO    : Bus 48429	: V=0.9913349, theta=-64.264847 -> V=1.0, theta=0.0
% INFO    : Bus 48430	: V=0.9895055, theta=-64.486607 -> V=1.0, theta=0.0
% INFO    : Bus 48431	: V=0.9899799, theta=-64.31866 -> V=1.0, theta=0.0
% INFO    : Bus 48432	: V=0.9909582, theta=-64.271783 -> V=1.0, theta=0.0
% INFO    : Bus 48433	: V=0.9897804, theta=-64.470046 -> V=1.0, theta=0.0
% INFO    : Bus 48434	: V=0.9936421, theta=-64.111392 -> V=1.0, theta=0.0
% INFO    : Bus 48435	: V=0.994718, theta=-63.972279 -> V=1.0, theta=0.0
% INFO    : Bus 48436	: V=1.0033015, theta=-63.084515 -> V=1.0, theta=0.0
% INFO    : Bus 48437	: V=1.005046, theta=-62.60437 -> V=1.0, theta=0.0
% INFO    : Bus 48438	: V=0.9967398, theta=-42.878548 -> V=1.0, theta=0.0
% INFO    : Bus 48439	: V=0.997902, theta=-42.674303 -> V=1.0, theta=0.0
% INFO    : Bus 48440	: V=0.9949478, theta=-42.684428 -> V=1.0, theta=0.0
% INFO    : Bus 48441	: V=0.9909514, theta=-43.863526 -> V=1.0, theta=0.0
% INFO    : Bus 48442	: V=0.993536, theta=-42.88571 -> V=1.0, theta=0.0
% INFO    : Bus 48443	: V=0.9881827, theta=-44.030528 -> V=1.0, theta=0.0
% INFO    : Bus 48444	: V=0.9896372, theta=-44.178769 -> V=1.0, theta=0.0
% INFO    : Bus 48445	: V=0.9889895, theta=-44.188454 -> V=1.0, theta=0.0
% INFO    : Bus 48446	: V=0.9891571, theta=-44.364989 -> V=1.0, theta=0.0
% INFO    : Bus 48447	: V=0.9899729, theta=-44.44116 -> V=1.0, theta=0.0
% INFO    : Bus 48448	: V=0.9905582, theta=-44.399875 -> V=1.0, theta=0.0
% INFO    : Bus 48449	: V=0.9898801, theta=-43.981837 -> V=1.0, theta=0.0
% INFO    : Bus 48450	: V=1.0046011, theta=-41.9927 -> V=1.0, theta=0.0
% INFO    : Bus 48451	: V=1.0048697, theta=-43.571684 -> V=1.0, theta=0.0
% INFO    : Bus 48452	: V=0.9973306, theta=-43.742455 -> V=1.0, theta=0.0
% INFO    : Bus 48453	: V=1.0004873, theta=-42.480594 -> V=1.0, theta=0.0
% INFO    : Bus 48454	: V=1.0128516, theta=-43.378288 -> V=1.0, theta=0.0
% INFO    : Bus 48455	: V=1.0080217, theta=-43.564769 -> V=1.0, theta=0.0
% INFO    : Bus 48456	: V=0.9957621, theta=-44.058111 -> V=1.0, theta=0.0
% INFO    : Bus 48457	: V=0.9957743, theta=-44.138882 -> V=1.0, theta=0.0
% INFO    : Bus 48458	: V=0.9943751, theta=-44.179679 -> V=1.0, theta=0.0
% INFO    : Bus 48459	: V=0.995519, theta=-44.32459 -> V=1.0, theta=0.0
% INFO    : Bus 48460	: V=1.0027772, theta=-41.126871 -> V=1.0, theta=0.0
% INFO    : Bus 48461	: V=0.9912969, theta=-42.154693 -> V=1.0, theta=0.0
% INFO    : Bus 48462	: V=0.9855043, theta=-43.693004 -> V=1.0, theta=0.0
% INFO    : Bus 48463	: V=1.0066248, theta=-40.772466 -> V=1.0, theta=0.0
% INFO    : Bus 48464	: V=0.9993251, theta=-42.424067 -> V=1.0, theta=0.0
% INFO    : Bus 48465	: V=1.0192898, theta=-37.104672 -> V=1.0, theta=0.0
% INFO    : Bus 48466	: V=0.9883825, theta=-43.395291 -> V=1.0, theta=0.0
% INFO    : Bus 48467	: V=0.9719984, theta=-47.405933 -> V=1.0, theta=0.0
% INFO    : Bus 48468	: V=0.9634827, theta=-47.446881 -> V=1.0, theta=0.0
% INFO    : Bus 48469	: V=0.9598714, theta=-47.302898 -> V=1.0, theta=0.0
% INFO    : Bus 48470	: V=0.9896725, theta=-43.538214 -> V=1.0, theta=0.0
% INFO    : Bus 48471	: V=0.9853136, theta=-46.281392 -> V=1.0, theta=0.0
% INFO    : Bus 48472	: V=0.9894292, theta=-44.392943 -> V=1.0, theta=0.0
% INFO    : Bus 48473	: V=0.9958913, theta=-42.964622 -> V=1.0, theta=0.0
% INFO    : Bus 48474	: V=0.9890376, theta=-44.299393 -> V=1.0, theta=0.0
% INFO    : Bus 48475	: V=0.9888799, theta=-44.52346 -> V=1.0, theta=0.0
% INFO    : Bus 48476	: V=1.0078648, theta=-41.842551 -> V=1.0, theta=0.0
% INFO    : Bus 48477	: V=0.9924689, theta=-43.061143 -> V=1.0, theta=0.0
% INFO    : Bus 48478	: V=0.983318, theta=-65.948591 -> V=1.0, theta=0.0
% INFO    : Bus 48479	: V=0.9601087, theta=-67.969595 -> V=1.0, theta=0.0
% INFO    : Bus 48480	: V=0.9904291, theta=-62.219939 -> V=1.0, theta=0.0
% INFO    : Bus 48481	: V=0.984237, theta=-62.822345 -> V=1.0, theta=0.0
% INFO    : Bus 48482	: V=0.9772736, theta=-63.702435 -> V=1.0, theta=0.0
% INFO    : Bus 48483	: V=1.01298, theta=-59.83256 -> V=1.0, theta=0.0
% INFO    : Bus 48484	: V=1.0170873, theta=-59.232877 -> V=1.0, theta=0.0
% INFO    : Bus 48485	: V=0.9623601, theta=-65.622033 -> V=1.0, theta=0.0
% INFO    : Bus 48486	: V=0.9684607, theta=-58.711774 -> V=1.0, theta=0.0
% INFO    : Bus 48487	: V=0.9815126, theta=-57.899716 -> V=1.0, theta=0.0
% INFO    : Bus 48488	: V=0.9911359, theta=-57.09523 -> V=1.0, theta=0.0
% INFO    : Bus 48489	: V=1.0137841, theta=-53.392263 -> V=1.0, theta=0.0
% INFO    : Bus 48490	: V=1.0046202, theta=-56.054669 -> V=1.0, theta=0.0
% INFO    : Bus 48491	: V=0.9942693, theta=-57.015916 -> V=1.0, theta=0.0
% INFO    : Bus 48492	: V=0.9925255, theta=-57.983047 -> V=1.0, theta=0.0
% INFO    : Bus 48493	: V=1.0110299, theta=-54.058902 -> V=1.0, theta=0.0
% INFO    : Bus 48494	: V=0.9778662, theta=-58.233155 -> V=1.0, theta=0.0
% INFO    : Bus 48495	: V=0.9895923, theta=-57.827823 -> V=1.0, theta=0.0
% INFO    : Bus 48496	: V=1.0086998, theta=-57.226825 -> V=1.0, theta=0.0
% INFO    : Bus 48497	: V=0.9866066, theta=-58.318205 -> V=1.0, theta=0.0
% INFO    : Bus 48498	: V=0.9881903, theta=-58.175535 -> V=1.0, theta=0.0
% INFO    : Bus 48499	: V=0.9910959, theta=-56.937605 -> V=1.0, theta=0.0
% INFO    : Bus 48500	: V=0.9803215, theta=-58.433576 -> V=1.0, theta=0.0
% INFO    : Bus 48501	: V=0.9916547, theta=-56.844414 -> V=1.0, theta=0.0
% INFO    : Bus 48502	: V=0.9796676, theta=-58.511384 -> V=1.0, theta=0.0
% INFO    : Bus 48503	: V=0.9616842, theta=-60.97741 -> V=1.0, theta=0.0
% INFO    : Bus 48504	: V=0.97682, theta=-58.977779 -> V=1.0, theta=0.0
% INFO    : Bus 48505	: V=0.9751824, theta=-59.339068 -> V=1.0, theta=0.0
% INFO    : Bus 48506	: V=0.9761598, theta=-59.011756 -> V=1.0, theta=0.0
% INFO    : Bus 48507	: V=0.9872367, theta=-58.352382 -> V=1.0, theta=0.0
% INFO    : Bus 48508	: V=0.9677236, theta=-59.974252 -> V=1.0, theta=0.0
% INFO    : Bus 48509	: V=0.9790642, theta=-58.43321 -> V=1.0, theta=0.0
% INFO    : Bus 48510	: V=0.98039, theta=-58.059946 -> V=1.0, theta=0.0
% INFO    : Bus 48511	: V=0.9769187, theta=-60.524693 -> V=1.0, theta=0.0
% INFO    : Bus 48512	: V=0.9779689, theta=-58.244327 -> V=1.0, theta=0.0
% INFO    : Bus 48513	: V=0.979024, theta=-60.613344 -> V=1.0, theta=0.0
% INFO    : Bus 48514	: V=0.9574662, theta=-62.667426 -> V=1.0, theta=0.0
% INFO    : Bus 48515	: V=0.9803926, theta=-57.081719 -> V=1.0, theta=0.0
% INFO    : Bus 48516	: V=0.9931332, theta=-56.629999 -> V=1.0, theta=0.0
% INFO    : Bus 48517	: V=1.0092488, theta=-57.254636 -> V=1.0, theta=0.0
% INFO    : Bus 48518	: V=0.9955452, theta=-56.364364 -> V=1.0, theta=0.0
% INFO    : Bus 48519	: V=0.9963845, theta=-57.928435 -> V=1.0, theta=0.0
% INFO    : Bus 48520	: V=0.9939558, theta=-58.040869 -> V=1.0, theta=0.0
% INFO    : Bus 48521	: V=0.9649157, theta=-47.198176 -> V=1.0, theta=0.0
% INFO    : Bus 48522	: V=0.9555447, theta=-49.12254 -> V=1.0, theta=0.0
% INFO    : Bus 48523	: V=0.9326075, theta=-47.960466 -> V=1.0, theta=0.0
% INFO    : Bus 48524	: V=0.9737274, theta=-45.686878 -> V=1.0, theta=0.0
% INFO    : Bus 48525	: V=0.9382051, theta=-47.752091 -> V=1.0, theta=0.0
% INFO    : Bus 48526	: V=0.9645998, theta=-47.885625 -> V=1.0, theta=0.0
% INFO    : Bus 48527	: V=0.9914749, theta=-59.324628 -> V=1.0, theta=0.0
% INFO    : Bus 48528	: V=0.9812402, theta=-60.697751 -> V=1.0, theta=0.0
% INFO    : Bus 48529	: V=0.990272, theta=-59.552709 -> V=1.0, theta=0.0
% INFO    : Bus 48530	: V=0.9855793, theta=-59.793281 -> V=1.0, theta=0.0
% INFO    : Bus 48531	: V=0.9844126, theta=-59.913849 -> V=1.0, theta=0.0
% INFO    : Bus 48532	: V=0.9837648, theta=-60.635669 -> V=1.0, theta=0.0
% INFO    : Bus 48533	: V=0.9763616, theta=-61.876826 -> V=1.0, theta=0.0
% INFO    : Bus 48534	: V=0.9670821, theta=-66.090949 -> V=1.0, theta=0.0
% INFO    : Bus 48535	: V=0.9650479, theta=-66.135425 -> V=1.0, theta=0.0
% INFO    : Bus 48536	: V=0.9889837, theta=-64.865856 -> V=1.0, theta=0.0
% INFO    : Bus 48537	: V=0.9996289, theta=-63.655904 -> V=1.0, theta=0.0
% INFO    : Bus 48538	: V=0.9834011, theta=-65.162764 -> V=1.0, theta=0.0
% INFO    : Bus 48539	: V=0.9840887, theta=-65.149744 -> V=1.0, theta=0.0
% INFO    : Bus 48540	: V=0.9757497, theta=-65.613706 -> V=1.0, theta=0.0
% INFO    : Bus 48541	: V=1.0052833, theta=-62.843248 -> V=1.0, theta=0.0
% INFO    : Bus 48542	: V=0.9932913, theta=-64.275848 -> V=1.0, theta=0.0
% INFO    : Bus 48543	: V=1.0146836, theta=-61.80839 -> V=1.0, theta=0.0
% INFO    : Bus 48544	: V=0.9937789, theta=-64.256709 -> V=1.0, theta=0.0
% INFO    : Bus 48545	: V=0.9943625, theta=-64.229315 -> V=1.0, theta=0.0
% INFO    : Bus 48546	: V=0.9944326, theta=-64.350445 -> V=1.0, theta=0.0
% INFO    : Bus 48547	: V=0.9949356, theta=-64.200748 -> V=1.0, theta=0.0
% INFO    : Bus 48548	: V=0.9943042, theta=-64.358536 -> V=1.0, theta=0.0
% INFO    : Bus 48549	: V=0.9954517, theta=-64.175128 -> V=1.0, theta=0.0
% INFO    : Bus 48550	: V=1.006112, theta=-61.939171 -> V=1.0, theta=0.0
% INFO    : Bus 48551	: V=0.9639831, theta=-66.305158 -> V=1.0, theta=0.0
% INFO    : Bus 48552	: V=1.0177301, theta=-60.477387 -> V=1.0, theta=0.0
% INFO    : Bus 48553	: V=0.969536, theta=-66.008932 -> V=1.0, theta=0.0
% INFO    : Bus 48554	: V=0.9661155, theta=-66.241113 -> V=1.0, theta=0.0
% INFO    : Bus 48555	: V=0.989957, theta=-63.481469 -> V=1.0, theta=0.0
% INFO    : Bus 48556	: V=0.984175, theta=-63.821203 -> V=1.0, theta=0.0
% INFO    : Bus 48557	: V=1.0068266, theta=-63.048737 -> V=1.0, theta=0.0
% INFO    : Bus 48558	: V=0.9682559, theta=-68.615281 -> V=1.0, theta=0.0
% INFO    : Bus 48559	: V=1.0114603, theta=-62.343573 -> V=1.0, theta=0.0
% INFO    : Bus 48560	: V=1.0164692, theta=-61.048375 -> V=1.0, theta=0.0
% INFO    : Bus 48561	: V=0.9746553, theta=-64.340699 -> V=1.0, theta=0.0
% INFO    : Bus 48562	: V=0.9888981, theta=-64.313556 -> V=1.0, theta=0.0
% INFO    : Bus 48563	: V=0.9818249, theta=-64.557842 -> V=1.0, theta=0.0
% INFO    : Bus 48564	: V=0.9622389, theta=-65.781838 -> V=1.0, theta=0.0
% INFO    : Bus 48565	: V=0.9770957, theta=-67.01505 -> V=1.0, theta=0.0
% INFO    : Bus 48566	: V=0.9785403, theta=-66.436738 -> V=1.0, theta=0.0
% INFO    : Bus 48567	: V=0.9848198, theta=-66.457978 -> V=1.0, theta=0.0
% INFO    : Bus 48568	: V=1.0052294, theta=-64.846622 -> V=1.0, theta=0.0
% INFO    : Bus 48569	: V=1.0005379, theta=-65.231164 -> V=1.0, theta=0.0
% INFO    : Bus 48570	: V=1.00268, theta=-65.080211 -> V=1.0, theta=0.0
% INFO    : Bus 48571	: V=1.0052228, theta=-64.910037 -> V=1.0, theta=0.0
% INFO    : Bus 48572	: V=0.9615477, theta=-69.548709 -> V=1.0, theta=0.0
% INFO    : Bus 48573	: V=0.9749779, theta=-66.844773 -> V=1.0, theta=0.0
% INFO    : Bus 48574	: V=0.9627881, theta=-69.338844 -> V=1.0, theta=0.0
% INFO    : Bus 48575	: V=0.9604306, theta=-69.580764 -> V=1.0, theta=0.0
% INFO    : Bus 48576	: V=0.9619592, theta=-69.476667 -> V=1.0, theta=0.0
% INFO    : Bus 48577	: V=0.962842, theta=-69.429465 -> V=1.0, theta=0.0
% INFO    : Bus 48578	: V=0.972686, theta=-67.840782 -> V=1.0, theta=0.0
% INFO    : Bus 48579	: V=0.9750972, theta=-67.569189 -> V=1.0, theta=0.0
% INFO    : Bus 48580	: V=0.9855981, theta=-65.551714 -> V=1.0, theta=0.0
% INFO    : Bus 48581	: V=0.9738942, theta=-67.747436 -> V=1.0, theta=0.0
% INFO    : Bus 48582	: V=0.9734884, theta=-68.010082 -> V=1.0, theta=0.0
% INFO    : Bus 48583	: V=0.9749008, theta=-67.636269 -> V=1.0, theta=0.0
% INFO    : Bus 48584	: V=0.9715096, theta=-68.10308 -> V=1.0, theta=0.0
% INFO    : Bus 48585	: V=0.9638539, theta=-69.90696 -> V=1.0, theta=0.0
% INFO    : Bus 48586	: V=0.9736502, theta=-67.899098 -> V=1.0, theta=0.0
% INFO    : Bus 48587	: V=0.9631572, theta=-71.303303 -> V=1.0, theta=0.0
% INFO    : Bus 48588	: V=0.9610131, theta=-70.30938 -> V=1.0, theta=0.0
% INFO    : Bus 48589	: V=0.9580406, theta=-72.26795 -> V=1.0, theta=0.0
% INFO    : Bus 48590	: V=0.9534883, theta=-73.367916 -> V=1.0, theta=0.0
% INFO    : Bus 48591	: V=0.9676492, theta=-73.037158 -> V=1.0, theta=0.0
% INFO    : Bus 48592	: V=0.9666845, theta=-72.937384 -> V=1.0, theta=0.0
% INFO    : Bus 48593	: V=0.9706696, theta=-72.51092 -> V=1.0, theta=0.0
% INFO    : Bus 48594	: V=0.9932024, theta=-69.42405 -> V=1.0, theta=0.0
% INFO    : Bus 48595	: V=1.0038389, theta=-69.27952 -> V=1.0, theta=0.0
% INFO    : Bus 48596	: V=1.019085, theta=-68.753542 -> V=1.0, theta=0.0
% INFO    : Bus 48597	: V=1.0079466, theta=-68.862123 -> V=1.0, theta=0.0
% INFO    : Bus 48598	: V=1.0182096, theta=-68.723281 -> V=1.0, theta=0.0
% INFO    : Bus 48599	: V=1.0098844, theta=-69.283853 -> V=1.0, theta=0.0
% INFO    : Bus 48600	: V=1.0181503, theta=-68.814065 -> V=1.0, theta=0.0
% INFO    : Bus 48601	: V=0.9991881, theta=-70.29902 -> V=1.0, theta=0.0
% INFO    : Bus 48602	: V=0.9981569, theta=-70.308797 -> V=1.0, theta=0.0
% INFO    : Bus 48603	: V=0.9638469, theta=-64.923633 -> V=1.0, theta=0.0
% INFO    : Bus 48604	: V=0.9908959, theta=-63.509691 -> V=1.0, theta=0.0
% INFO    : Bus 48605	: V=0.9920486, theta=-63.378417 -> V=1.0, theta=0.0
% INFO    : Bus 48606	: V=0.9720375, theta=-65.060618 -> V=1.0, theta=0.0
% INFO    : Bus 48607	: V=0.9884772, theta=-63.608138 -> V=1.0, theta=0.0
% INFO    : Bus 48608	: V=0.9622161, theta=-65.163797 -> V=1.0, theta=0.0
% INFO    : Bus 48609	: V=0.9614738, theta=-65.340962 -> V=1.0, theta=0.0
% INFO    : Bus 48610	: V=1.0002965, theta=-62.17659 -> V=1.0, theta=0.0
% INFO    : Bus 48611	: V=1.0008294, theta=-62.149468 -> V=1.0, theta=0.0
% INFO    : Bus 48612	: V=0.996331, theta=-62.452526 -> V=1.0, theta=0.0
% INFO    : Bus 48613	: V=0.9885576, theta=-63.388761 -> V=1.0, theta=0.0
% INFO    : Bus 48614	: V=0.9678229, theta=-65.029815 -> V=1.0, theta=0.0
% INFO    : Bus 48615	: V=0.9880594, theta=-63.29076 -> V=1.0, theta=0.0
% INFO    : Bus 48616	: V=0.9829532, theta=-63.643223 -> V=1.0, theta=0.0
% INFO    : Bus 48617	: V=0.9853713, theta=-63.490185 -> V=1.0, theta=0.0
% INFO    : Bus 48618	: V=1.0052086, theta=-61.614012 -> V=1.0, theta=0.0
% INFO    : Bus 48619	: V=0.978693, theta=-63.888626 -> V=1.0, theta=0.0
% INFO    : Bus 48620	: V=0.9699672, theta=-64.465032 -> V=1.0, theta=0.0
% INFO    : Bus 48621	: V=0.9723319, theta=-64.323439 -> V=1.0, theta=0.0
% INFO    : Bus 48622	: V=0.9577372, theta=-66.209631 -> V=1.0, theta=0.0
% INFO    : Bus 48623	: V=0.9569762, theta=-65.571271 -> V=1.0, theta=0.0
% INFO    : Bus 48624	: V=0.95712, theta=-65.566477 -> V=1.0, theta=0.0
% INFO    : Bus 48625	: V=0.968502, theta=-64.870914 -> V=1.0, theta=0.0
% INFO    : Bus 48626	: V=0.9738126, theta=-64.378895 -> V=1.0, theta=0.0
% INFO    : Bus 48627	: V=0.9733443, theta=-64.243833 -> V=1.0, theta=0.0
% INFO    : Bus 48628	: V=0.9647816, theta=-65.194244 -> V=1.0, theta=0.0
% INFO    : Bus 48629	: V=0.9616955, theta=-65.366622 -> V=1.0, theta=0.0
% INFO    : Bus 48630	: V=0.9680881, theta=-64.566799 -> V=1.0, theta=0.0
% INFO    : Bus 48631	: V=0.9684613, theta=-64.547903 -> V=1.0, theta=0.0
% INFO    : Bus 48632	: V=0.9676416, theta=-64.842183 -> V=1.0, theta=0.0
% INFO    : Bus 48633	: V=0.9861997, theta=-63.104778 -> V=1.0, theta=0.0
% INFO    : Bus 48634	: V=0.9810025, theta=-63.61786 -> V=1.0, theta=0.0
% INFO    : Bus 48635	: V=1.0124623, theta=-59.667432 -> V=1.0, theta=0.0
% INFO    : Bus 48636	: V=0.9878769, theta=-62.984743 -> V=1.0, theta=0.0
% INFO    : Bus 48637	: V=1.0064391, theta=-61.348182 -> V=1.0, theta=0.0
% INFO    : Bus 48638	: V=0.9589762, theta=-65.466609 -> V=1.0, theta=0.0
% INFO    : Bus 48639	: V=0.9596385, theta=-65.430538 -> V=1.0, theta=0.0
% INFO    : Bus 48640	: V=0.973639, theta=-64.138689 -> V=1.0, theta=0.0
% INFO    : Bus 48641	: V=0.9774479, theta=-63.936157 -> V=1.0, theta=0.0
% INFO    : Bus 48642	: V=0.975223, theta=-64.047273 -> V=1.0, theta=0.0
% INFO    : Bus 48643	: V=0.9782055, theta=-63.750119 -> V=1.0, theta=0.0
% INFO    : Bus 48644	: V=0.9589658, theta=-65.407141 -> V=1.0, theta=0.0
% INFO    : Bus 48645	: V=1.0126449, theta=-59.85574 -> V=1.0, theta=0.0
% INFO    : Bus 48646	: V=0.9984972, theta=-63.020799 -> V=1.0, theta=0.0
% INFO    : Bus 48647	: V=0.9931565, theta=-63.43851 -> V=1.0, theta=0.0
% INFO    : Bus 48648	: V=0.9880987, theta=-63.748074 -> V=1.0, theta=0.0
% INFO    : Bus 48649	: V=1.0003639, theta=-62.766596 -> V=1.0, theta=0.0
% INFO    : Bus 48650	: V=0.9842192, theta=-64.017122 -> V=1.0, theta=0.0
% INFO    : Bus 48651	: V=0.9949994, theta=-62.797107 -> V=1.0, theta=0.0
% INFO    : Bus 48652	: V=0.9849203, theta=-63.963163 -> V=1.0, theta=0.0
% INFO    : Bus 48653	: V=0.9876487, theta=-63.645039 -> V=1.0, theta=0.0
% INFO    : Bus 48654	: V=0.9873438, theta=-63.651573 -> V=1.0, theta=0.0
% INFO    : Bus 48655	: V=0.9933799, theta=-63.016323 -> V=1.0, theta=0.0
% INFO    : Bus 48656	: V=0.9942242, theta=-63.037452 -> V=1.0, theta=0.0
% INFO    : Bus 48657	: V=0.9936093, theta=-63.081194 -> V=1.0, theta=0.0
% INFO    : Bus 48658	: V=0.9811708, theta=-63.99109 -> V=1.0, theta=0.0
% INFO    : Bus 48659	: V=0.9831744, theta=-63.934878 -> V=1.0, theta=0.0
% INFO    : Bus 48660	: V=0.9819889, theta=-63.985108 -> V=1.0, theta=0.0
% INFO    : Bus 48661	: V=0.9910732, theta=-63.336349 -> V=1.0, theta=0.0
% INFO    : Bus 48662	: V=0.9930544, theta=-63.092481 -> V=1.0, theta=0.0
% INFO    : Bus 48663	: V=0.9686033, theta=-64.896781 -> V=1.0, theta=0.0
% INFO    : Bus 48664	: V=0.9679667, theta=-65.494158 -> V=1.0, theta=0.0
% INFO    : Bus 48665	: V=1.0036484, theta=-62.095518 -> V=1.0, theta=0.0
% INFO    : Bus 48666	: V=0.9524658, theta=-52.493911 -> V=1.0, theta=0.0
% INFO    : Bus 48667	: V=0.9481366, theta=-54.048865 -> V=1.0, theta=0.0
% INFO    : Bus 48668	: V=0.948565, theta=-55.344677 -> V=1.0, theta=0.0
% INFO    : Bus 48669	: V=0.9483961, theta=-76.694106 -> V=1.0, theta=0.0
% INFO    : Bus 48670	: V=0.9574145, theta=-74.974839 -> V=1.0, theta=0.0
% INFO    : Bus 48671	: V=0.9453434, theta=-76.820456 -> V=1.0, theta=0.0
% INFO    : Bus 48672	: V=0.9441287, theta=-75.824664 -> V=1.0, theta=0.0
% INFO    : Bus 48673	: V=0.9135346, theta=-80.628029 -> V=1.0, theta=0.0
% INFO    : Bus 48674	: V=0.9440916, theta=-77.346643 -> V=1.0, theta=0.0
% INFO    : Bus 48675	: V=1.0199337, theta=-37.688426 -> V=1.0, theta=0.0
% INFO    : Bus 48676	: V=0.9829791, theta=-43.111031 -> V=1.0, theta=0.0
% INFO    : Bus 48677	: V=0.9823052, theta=-44.108787 -> V=1.0, theta=0.0
% INFO    : Bus 48678	: V=0.9923734, theta=-42.805391 -> V=1.0, theta=0.0
% INFO    : Bus 48679	: V=1.0020349, theta=-41.992326 -> V=1.0, theta=0.0
% INFO    : Bus 48680	: V=0.9881237, theta=-44.811969 -> V=1.0, theta=0.0
% INFO    : Bus 48681	: V=0.9700225, theta=-69.567466 -> V=1.0, theta=0.0
% INFO    : Bus 48682	: V=0.9496638, theta=-70.89342 -> V=1.0, theta=0.0
% INFO    : Bus 48683	: V=0.9715255, theta=-69.287518 -> V=1.0, theta=0.0
% INFO    : Bus 48684	: V=0.9663058, theta=-70.129448 -> V=1.0, theta=0.0
% INFO    : Bus 48685	: V=0.9604866, theta=-70.921006 -> V=1.0, theta=0.0
% INFO    : Bus 48686	: V=0.9582558, theta=-71.356858 -> V=1.0, theta=0.0
% INFO    : Bus 48687	: V=0.9577386, theta=-71.468085 -> V=1.0, theta=0.0
% INFO    : Bus 48688	: V=0.957148, theta=-73.284182 -> V=1.0, theta=0.0
% INFO    : Bus 48689	: V=0.9554048, theta=-73.41957 -> V=1.0, theta=0.0
% INFO    : Bus 48690	: V=0.9518144, theta=-74.460597 -> V=1.0, theta=0.0
% INFO    : Bus 48691	: V=0.9553027, theta=-74.072197 -> V=1.0, theta=0.0
% INFO    : Bus 48692	: V=0.9531845, theta=-74.343053 -> V=1.0, theta=0.0
% INFO    : Bus 48693	: V=0.9745482, theta=-59.836211 -> V=1.0, theta=0.0
% INFO    : Bus 48694	: V=0.9849526, theta=-61.825507 -> V=1.0, theta=0.0
% INFO    : Bus 48695	: V=0.9867715, theta=-63.133976 -> V=1.0, theta=0.0
% INFO    : Bus 48696	: V=0.9811172, theta=-62.715955 -> V=1.0, theta=0.0
% INFO    : Bus 48697	: V=0.9806274, theta=-62.907833 -> V=1.0, theta=0.0
% INFO    : Bus 48698	: V=0.9817607, theta=-63.022685 -> V=1.0, theta=0.0
% INFO    : Bus 48699	: V=0.981515, theta=-59.294887 -> V=1.0, theta=0.0
% INFO    : Bus 48700	: V=0.9807151, theta=-63.19057 -> V=1.0, theta=0.0
% INFO    : Bus 48701	: V=0.9734796, theta=-62.535395 -> V=1.0, theta=0.0
% INFO    : Bus 48702	: V=0.9803221, theta=-63.10744 -> V=1.0, theta=0.0
% INFO    : Bus 48703	: V=0.9592033, theta=-61.553726 -> V=1.0, theta=0.0
% INFO    : Bus 48704	: V=0.9838065, theta=-63.510727 -> V=1.0, theta=0.0
% INFO    : Bus 48705	: V=0.9887405, theta=-63.991547 -> V=1.0, theta=0.0
% INFO    : Bus 48706	: V=1.0141731, theta=-61.795208 -> V=1.0, theta=0.0
% INFO    : Bus 48707	: V=1.0152653, theta=-61.707589 -> V=1.0, theta=0.0
% INFO    : Bus 48708	: V=0.9982856, theta=-62.72596 -> V=1.0, theta=0.0
% INFO    : Bus 48709	: V=1.0124338, theta=-61.855342 -> V=1.0, theta=0.0
% INFO    : Bus 48710	: V=0.99299, theta=-63.339664 -> V=1.0, theta=0.0
% INFO    : Bus 48711	: V=0.9970787, theta=-63.245568 -> V=1.0, theta=0.0
% INFO    : Bus 48712	: V=0.9981042, theta=-63.254716 -> V=1.0, theta=0.0
% INFO    : Bus 48713	: V=1.0188374, theta=-62.745388 -> V=1.0, theta=0.0
% INFO    : Bus 48714	: V=1.0131589, theta=-61.839469 -> V=1.0, theta=0.0
% INFO    : Bus 48715	: V=0.9965305, theta=-63.30907 -> V=1.0, theta=0.0
% INFO    : Bus 48716	: V=0.9719507, theta=-50.928196 -> V=1.0, theta=0.0
% INFO    : Bus 48717	: V=0.9718006, theta=-51.365103 -> V=1.0, theta=0.0
% INFO    : Bus 48718	: V=0.9749124, theta=-50.890904 -> V=1.0, theta=0.0
% INFO    : Bus 48719	: V=0.9678454, theta=-53.016006 -> V=1.0, theta=0.0
% INFO    : Bus 48720	: V=0.9679709, theta=-56.524504 -> V=1.0, theta=0.0
% INFO    : Bus 48721	: V=0.9672172, theta=-54.641105 -> V=1.0, theta=0.0
% INFO    : Bus 48722	: V=0.9678279, theta=-55.666466 -> V=1.0, theta=0.0
% INFO    : Bus 48723	: V=0.9617914, theta=-56.309674 -> V=1.0, theta=0.0
% INFO    : Bus 48724	: V=0.9675717, theta=-55.391982 -> V=1.0, theta=0.0
% INFO    : Bus 48725	: V=0.9677605, theta=-55.349712 -> V=1.0, theta=0.0
% INFO    : Bus 48726	: V=0.9701634, theta=-54.899527 -> V=1.0, theta=0.0
% INFO    : Bus 48727	: V=0.9757411, theta=-65.402758 -> V=1.0, theta=0.0
% INFO    : Bus 48728	: V=0.9672528, theta=-65.891907 -> V=1.0, theta=0.0
% INFO    : Bus 48729	: V=0.940604, theta=-67.906781 -> V=1.0, theta=0.0
% INFO    : Bus 48730	: V=0.9890535, theta=-64.538467 -> V=1.0, theta=0.0
% INFO    : Bus 48731	: V=0.9967832, theta=-63.980297 -> V=1.0, theta=0.0
% INFO    : Bus 48732	: V=0.964905, theta=-42.942222 -> V=1.0, theta=0.0
% INFO    : Bus 48733	: V=0.9663309, theta=-43.832898 -> V=1.0, theta=0.0
% INFO    : Bus 48734	: V=0.973315, theta=-43.471707 -> V=1.0, theta=0.0
% INFO    : Bus 48735	: V=1.0177472, theta=-59.295983 -> V=1.0, theta=0.0
% INFO    : Bus 48736	: V=1.0009102, theta=-60.004437 -> V=1.0, theta=0.0
% INFO    : Bus 48737	: V=1.0196862, theta=-58.781426 -> V=1.0, theta=0.0
% INFO    : Bus 48738	: V=0.9618623, theta=-51.392453 -> V=1.0, theta=0.0
% INFO    : Bus 48739	: V=0.9908193, theta=-56.112012 -> V=1.0, theta=0.0
% INFO    : Bus 48740	: V=0.9844361, theta=-54.832766 -> V=1.0, theta=0.0
% INFO    : Bus 48741	: V=0.9845798, theta=-54.953682 -> V=1.0, theta=0.0
% INFO    : Bus 48742	: V=0.9879399, theta=4.547721 -> V=1.0, theta=0.0
% INFO    : Bus 48743	: V=0.9927861, theta=4.322376 -> V=1.0, theta=0.0
% INFO    : Bus 48744	: V=1.0018594, theta=5.705831 -> V=1.0, theta=0.0
% INFO    : Bus 48745	: V=0.9920676, theta=4.64805 -> V=1.0, theta=0.0
% INFO    : Bus 48746	: V=0.9927321, theta=4.550739 -> V=1.0, theta=0.0
% INFO    : Bus 48747	: V=0.9909414, theta=4.50554 -> V=1.0, theta=0.0
% INFO    : Bus 48748	: V=0.9904008, theta=4.471154 -> V=1.0, theta=0.0
% INFO    : Bus 48749	: V=0.9809175, theta=-3.839958 -> V=1.0, theta=0.0
% INFO    : Bus 48750	: V=1.0072781, theta=0.910333 -> V=1.0, theta=0.0
% INFO    : Bus 48751	: V=0.9907964, theta=-0.764056 -> V=1.0, theta=0.0
% INFO    : Bus 48752	: V=1.0012191, theta=-0.007192 -> V=1.0, theta=0.0
% INFO    : Bus 48753	: V=1.0139742, theta=-0.669305 -> V=1.0, theta=0.0
% INFO    : Bus 48754	: V=1.0074005, theta=-2.0936 -> V=1.0, theta=0.0
% INFO    : Bus 48755	: V=1.0153561, theta=6.832226 -> V=1.0, theta=0.0
% INFO    : Bus 48756	: V=1.0083617, theta=5.964028 -> V=1.0, theta=0.0
% INFO    : Bus 48757	: V=0.9975747, theta=2.233932 -> V=1.0, theta=0.0
% INFO    : Bus 48758	: V=1.0057342, theta=2.565324 -> V=1.0, theta=0.0
% INFO    : Bus 48759	: V=1.0062406, theta=3.046069 -> V=1.0, theta=0.0
% INFO    : Bus 48760	: V=1.0046509, theta=2.187909 -> V=1.0, theta=0.0
% INFO    : Bus 48761	: V=1.0078147, theta=2.132571 -> V=1.0, theta=0.0
% INFO    : Bus 48762	: V=0.9712653, theta=-26.655253 -> V=1.0, theta=0.0
% INFO    : Bus 48763	: V=0.9863573, theta=-25.109532 -> V=1.0, theta=0.0
% INFO    : Bus 48764	: V=0.9877263, theta=-24.529185 -> V=1.0, theta=0.0
% INFO    : Bus 48765	: V=0.9877344, theta=-26.499433 -> V=1.0, theta=0.0
% INFO    : Bus 48766	: V=0.9864936, theta=-26.05851 -> V=1.0, theta=0.0
% INFO    : Bus 48767	: V=0.9856762, theta=-26.40108 -> V=1.0, theta=0.0
% INFO    : Bus 48768	: V=0.9785696, theta=-26.590356 -> V=1.0, theta=0.0
% INFO    : Bus 48769	: V=0.9665891, theta=-20.637578 -> V=1.0, theta=0.0
% INFO    : Bus 48770	: V=0.9927356, theta=-16.934013 -> V=1.0, theta=0.0
% INFO    : Bus 48771	: V=0.9840768, theta=-19.573418 -> V=1.0, theta=0.0
% INFO    : Bus 48772	: V=1.0015364, theta=-8.586688 -> V=1.0, theta=0.0
% INFO    : Bus 48773	: V=0.9835749, theta=-9.984045 -> V=1.0, theta=0.0
% INFO    : Bus 48774	: V=0.997274, theta=-10.299832 -> V=1.0, theta=0.0
% INFO    : Bus 48775	: V=0.9927055, theta=-11.58841 -> V=1.0, theta=0.0
% INFO    : Bus 48776	: V=0.9768448, theta=-9.527762 -> V=1.0, theta=0.0
% INFO    : Bus 48777	: V=0.9863996, theta=-8.338019 -> V=1.0, theta=0.0
% INFO    : Bus 48778	: V=0.9878617, theta=-8.820819 -> V=1.0, theta=0.0
% INFO    : Bus 48779	: V=0.9790717, theta=-9.843375 -> V=1.0, theta=0.0
% INFO    : Bus 48780	: V=0.9846338, theta=-9.955224 -> V=1.0, theta=0.0
% INFO    : Bus 48781	: V=0.9828797, theta=-10.469912 -> V=1.0, theta=0.0
% INFO    : Bus 48782	: V=1.0145034, theta=-6.043891 -> V=1.0, theta=0.0
% INFO    : Bus 48783	: V=1.0161996, theta=-7.414276 -> V=1.0, theta=0.0
% INFO    : Bus 48784	: V=1.0052688, theta=-7.949471 -> V=1.0, theta=0.0
% INFO    : Bus 48785	: V=1.0079363, theta=0.693845 -> V=1.0, theta=0.0
% INFO    : Bus 48786	: V=1.0064076, theta=0.597432 -> V=1.0, theta=0.0
% INFO    : Bus 48787	: V=1.0079817, theta=0.601096 -> V=1.0, theta=0.0
% INFO    : Bus 48788	: V=1.004305, theta=0.585788 -> V=1.0, theta=0.0
% INFO    : Bus 48789	: V=1.0062678, theta=0.680692 -> V=1.0, theta=0.0
% INFO    : Bus 48790	: V=1.006017, theta=1.037025 -> V=1.0, theta=0.0
% INFO    : Bus 48791	: V=1.0027064, theta=0.489515 -> V=1.0, theta=0.0
% INFO    : Bus 48792	: V=1.0090773, theta=1.171535 -> V=1.0, theta=0.0
% INFO    : Bus 48793	: V=1.0019584, theta=0.441307 -> V=1.0, theta=0.0
% INFO    : Bus 48794	: V=1.0005888, theta=0.504992 -> V=1.0, theta=0.0
% INFO    : Bus 48795	: V=0.9999865, theta=0.250405 -> V=1.0, theta=0.0
% INFO    : Bus 48796	: V=1.0022405, theta=0.784674 -> V=1.0, theta=0.0
% INFO    : Bus 48797	: V=1.0000863, theta=0.583257 -> V=1.0, theta=0.0
% INFO    : Bus 48798	: V=0.9984844, theta=0.712662 -> V=1.0, theta=0.0
% INFO    : Bus 48799	: V=1.0063674, theta=3.083961 -> V=1.0, theta=0.0
% INFO    : Bus 48800	: V=1.0120503, theta=1.366964 -> V=1.0, theta=0.0
% INFO    : Bus 48801	: V=1.0128512, theta=1.396637 -> V=1.0, theta=0.0
% INFO    : Bus 48802	: V=1.0050891, theta=1.212731 -> V=1.0, theta=0.0
% INFO    : Bus 48803	: V=1.0113865, theta=1.356785 -> V=1.0, theta=0.0
% INFO    : Bus 48804	: V=0.9925883, theta=0.451021 -> V=1.0, theta=0.0
% INFO    : Bus 48805	: V=0.9915493, theta=-2.484526 -> V=1.0, theta=0.0
% INFO    : Bus 48806	: V=0.9982935, theta=-0.383381 -> V=1.0, theta=0.0
% INFO    : Bus 48807	: V=0.99869, theta=1.21493 -> V=1.0, theta=0.0
% INFO    : Bus 48808	: V=0.9907122, theta=-0.92247 -> V=1.0, theta=0.0
% INFO    : Bus 48809	: V=0.9952778, theta=0.940272 -> V=1.0, theta=0.0
% INFO    : Bus 48810	: V=0.9983685, theta=1.579097 -> V=1.0, theta=0.0
% INFO    : Bus 48811	: V=1.0084933, theta=3.3233 -> V=1.0, theta=0.0
% INFO    : Bus 48812	: V=1.0073829, theta=0.695948 -> V=1.0, theta=0.0
% INFO    : Bus 48813	: V=1.0057177, theta=0.534589 -> V=1.0, theta=0.0
% INFO    : Bus 48814	: V=0.9763995, theta=-5.842644 -> V=1.0, theta=0.0
% INFO    : Bus 48815	: V=0.9766998, theta=-6.192473 -> V=1.0, theta=0.0
% INFO    : Bus 48816	: V=0.9920978, theta=-6.322004 -> V=1.0, theta=0.0
% INFO    : Bus 48817	: V=0.9777669, theta=-6.706074 -> V=1.0, theta=0.0
% INFO    : Bus 48818	: V=0.9764091, theta=-6.761241 -> V=1.0, theta=0.0
% INFO    : Bus 48819	: V=0.9746277, theta=-6.691651 -> V=1.0, theta=0.0
% INFO    : Bus 48820	: V=0.9724201, theta=-6.71653 -> V=1.0, theta=0.0
% INFO    : Bus 48821	: V=0.9743139, theta=-6.461174 -> V=1.0, theta=0.0
% INFO    : Bus 48822	: V=0.9767256, theta=-6.767421 -> V=1.0, theta=0.0
% INFO    : Bus 48823	: V=0.9779847, theta=-6.770831 -> V=1.0, theta=0.0
% INFO    : Bus 48824	: V=0.9770552, theta=-6.759219 -> V=1.0, theta=0.0
% INFO    : Bus 48825	: V=0.9773145, theta=-6.746477 -> V=1.0, theta=0.0
% INFO    : Bus 48826	: V=0.9785763, theta=-6.796422 -> V=1.0, theta=0.0
% INFO    : Bus 48827	: V=0.9773039, theta=-6.798794 -> V=1.0, theta=0.0
% INFO    : Bus 48828	: V=0.9693568, theta=-6.848075 -> V=1.0, theta=0.0
% INFO    : Bus 48829	: V=0.980423, theta=-6.800829 -> V=1.0, theta=0.0
% INFO    : Bus 48830	: V=0.9851747, theta=-6.687882 -> V=1.0, theta=0.0
% INFO    : Bus 48831	: V=0.9778755, theta=-6.906286 -> V=1.0, theta=0.0
% INFO    : Bus 48832	: V=0.9894506, theta=-6.61861 -> V=1.0, theta=0.0
% INFO    : Bus 48833	: V=0.9993945, theta=-6.204495 -> V=1.0, theta=0.0
% INFO    : Bus 48834	: V=0.9994042, theta=-6.135236 -> V=1.0, theta=0.0
% INFO    : Bus 48835	: V=0.9659911, theta=-7.039688 -> V=1.0, theta=0.0
% INFO    : Bus 48836	: V=0.9745986, theta=-7.033467 -> V=1.0, theta=0.0
% INFO    : Bus 48837	: V=1.0015252, theta=-5.522271 -> V=1.0, theta=0.0
% INFO    : Bus 48838	: V=0.9946555, theta=-6.424134 -> V=1.0, theta=0.0
% INFO    : Bus 48839	: V=0.99635, theta=-13.992595 -> V=1.0, theta=0.0
% INFO    : Bus 48840	: V=1.0317725, theta=-12.607465 -> V=1.0, theta=0.0
% INFO    : Bus 48841	: V=1.0061183, theta=-13.539488 -> V=1.0, theta=0.0
% INFO    : Bus 48842	: V=1.0276062, theta=-12.09586 -> V=1.0, theta=0.0
% INFO    : Bus 48843	: V=1.0168468, theta=-12.953745 -> V=1.0, theta=0.0
% INFO    : Bus 48844	: V=1.0181582, theta=-13.25574 -> V=1.0, theta=0.0
% INFO    : Bus 48845	: V=1.0162155, theta=-12.155309 -> V=1.0, theta=0.0
% INFO    : Bus 48846	: V=1.0267034, theta=-12.055032 -> V=1.0, theta=0.0
% INFO    : Bus 48847	: V=1.0128855, theta=-13.415563 -> V=1.0, theta=0.0
% INFO    : Bus 48848	: V=1.0204675, theta=-13.257395 -> V=1.0, theta=0.0
% INFO    : Bus 48849	: V=0.9892413, theta=-3.717724 -> V=1.0, theta=0.0
% INFO    : Bus 48850	: V=0.983978, theta=-4.038731 -> V=1.0, theta=0.0
% INFO    : Bus 48851	: V=0.990117, theta=1.08316 -> V=1.0, theta=0.0
% INFO    : Bus 48852	: V=0.9992853, theta=1.108166 -> V=1.0, theta=0.0
% INFO    : Bus 48853	: V=1.0007387, theta=1.060058 -> V=1.0, theta=0.0
% INFO    : Bus 48854	: V=1.0007036, theta=1.009238 -> V=1.0, theta=0.0
% INFO    : Bus 48855	: V=1.0015872, theta=0.973175 -> V=1.0, theta=0.0
% INFO    : Bus 48856	: V=0.9944864, theta=-1.52339 -> V=1.0, theta=0.0
% INFO    : Bus 48857	: V=0.9966083, theta=-2.652817 -> V=1.0, theta=0.0
% INFO    : Bus 48858	: V=0.9959602, theta=-2.48162 -> V=1.0, theta=0.0
% INFO    : Bus 48859	: V=0.9961559, theta=-13.051725 -> V=1.0, theta=0.0
% INFO    : Bus 48860	: V=1.0020167, theta=-13.370687 -> V=1.0, theta=0.0
% INFO    : Bus 48861	: V=0.9906087, theta=-14.063458 -> V=1.0, theta=0.0
% INFO    : Bus 48862	: V=0.9909424, theta=-14.451599 -> V=1.0, theta=0.0
% INFO    : Bus 48863	: V=0.9947358, theta=-14.685971 -> V=1.0, theta=0.0
% INFO    : Bus 48864	: V=0.9902626, theta=-13.786611 -> V=1.0, theta=0.0
% INFO    : Bus 48865	: V=0.9811462, theta=-10.842019 -> V=1.0, theta=0.0
% INFO    : Bus 48866	: V=0.9940491, theta=-15.40728 -> V=1.0, theta=0.0
% INFO    : Bus 48867	: V=0.9830076, theta=-14.12302 -> V=1.0, theta=0.0
% INFO    : Bus 48868	: V=0.991381, theta=-13.35385 -> V=1.0, theta=0.0
% INFO    : Bus 48869	: V=0.9864042, theta=-12.519724 -> V=1.0, theta=0.0
% INFO    : Bus 48870	: V=1.0148367, theta=-5.529058 -> V=1.0, theta=0.0
% INFO    : Bus 48871	: V=1.0130314, theta=-5.95969 -> V=1.0, theta=0.0
% INFO    : Bus 48872	: V=1.0117936, theta=-8.740066 -> V=1.0, theta=0.0
% INFO    : Bus 48873	: V=1.0146454, theta=-5.725234 -> V=1.0, theta=0.0
% INFO    : Bus 48874	: V=1.0145213, theta=-5.774862 -> V=1.0, theta=0.0
% INFO    : Bus 48875	: V=1.0149817, theta=-5.615702 -> V=1.0, theta=0.0
% INFO    : Bus 48876	: V=1.0101205, theta=-7.260436 -> V=1.0, theta=0.0
% INFO    : Bus 48877	: V=1.0095194, theta=-7.56783 -> V=1.0, theta=0.0
% INFO    : Bus 48878	: V=1.0027403, theta=-8.066657 -> V=1.0, theta=0.0
% INFO    : Bus 48879	: V=1.003204, theta=-8.082497 -> V=1.0, theta=0.0
% INFO    : Bus 48880	: V=1.0095218, theta=-7.495085 -> V=1.0, theta=0.0
% INFO    : Bus 48881	: V=0.9959285, theta=-8.109997 -> V=1.0, theta=0.0
% INFO    : Bus 48882	: V=1.0131073, theta=-7.093241 -> V=1.0, theta=0.0
% INFO    : Bus 48883	: V=1.0182643, theta=-8.610378 -> V=1.0, theta=0.0
% INFO    : Bus 48884	: V=1.0020934, theta=-8.313569 -> V=1.0, theta=0.0
% INFO    : Bus 48885	: V=1.0047082, theta=-8.075356 -> V=1.0, theta=0.0
% INFO    : Bus 48886	: V=0.9818439, theta=-3.237922 -> V=1.0, theta=0.0
% INFO    : Bus 48887	: V=0.9896816, theta=-3.115237 -> V=1.0, theta=0.0
% INFO    : Bus 48888	: V=0.9786703, theta=-5.600652 -> V=1.0, theta=0.0
% INFO    : Bus 48889	: V=1.0107817, theta=-14.072251 -> V=1.0, theta=0.0
% INFO    : Bus 48890	: V=1.0005651, theta=-15.39443 -> V=1.0, theta=0.0
% INFO    : Bus 48891	: V=0.9797618, theta=-9.980689 -> V=1.0, theta=0.0
% INFO    : Bus 48892	: V=0.9785987, theta=-9.422539 -> V=1.0, theta=0.0
% INFO    : Bus 48893	: V=0.9795922, theta=-9.419916 -> V=1.0, theta=0.0
% INFO    : Bus 48894	: V=0.9788736, theta=-9.983318 -> V=1.0, theta=0.0
% INFO    : Bus 48895	: V=0.9856228, theta=-9.875222 -> V=1.0, theta=0.0
% INFO    : Bus 48896	: V=0.9868326, theta=-9.014264 -> V=1.0, theta=0.0
% INFO    : Bus 48897	: V=0.9936142, theta=-8.656301 -> V=1.0, theta=0.0
% INFO    : Bus 48898	: V=0.9944226, theta=-8.69405 -> V=1.0, theta=0.0
% INFO    : Bus 48899	: V=1.0022323, theta=-8.163285 -> V=1.0, theta=0.0
% INFO    : Bus 48900	: V=1.0027821, theta=-7.974788 -> V=1.0, theta=0.0
% INFO    : Bus 48901	: V=1.0121582, theta=-7.596999 -> V=1.0, theta=0.0
% INFO    : Bus 48902	: V=1.0096125, theta=-8.102317 -> V=1.0, theta=0.0
% INFO    : Bus 48903	: V=1.0152797, theta=-7.733358 -> V=1.0, theta=0.0
% INFO    : Bus 48904	: V=1.0129251, theta=-7.855202 -> V=1.0, theta=0.0
% INFO    : Bus 48905	: V=1.0145695, theta=-7.73369 -> V=1.0, theta=0.0
% INFO    : Bus 48906	: V=1.0166776, theta=-7.59504 -> V=1.0, theta=0.0
% INFO    : Bus 48907	: V=0.9966702, theta=-8.436485 -> V=1.0, theta=0.0
% INFO    : Bus 48908	: V=1.0099675, theta=-8.274604 -> V=1.0, theta=0.0
% INFO    : Bus 48909	: V=0.9910161, theta=-8.868966 -> V=1.0, theta=0.0
% INFO    : Bus 48910	: V=1.0116126, theta=-8.250153 -> V=1.0, theta=0.0
% INFO    : Bus 48911	: V=0.998625, theta=-13.622246 -> V=1.0, theta=0.0
% INFO    : Bus 48912	: V=0.9985221, theta=-11.614246 -> V=1.0, theta=0.0
% INFO    : Bus 48913	: V=0.9967983, theta=-15.609552 -> V=1.0, theta=0.0
% INFO    : Bus 48914	: V=0.9937916, theta=2.315001 -> V=1.0, theta=0.0
% INFO    : Bus 48915	: V=0.9969782, theta=1.140261 -> V=1.0, theta=0.0
% INFO    : Bus 48916	: V=1.0163467, theta=6.734476 -> V=1.0, theta=0.0
% INFO    : Bus 48917	: V=0.9846115, theta=-23.748514 -> V=1.0, theta=0.0
% INFO    : Bus 48918	: V=1.0073906, theta=-23.014887 -> V=1.0, theta=0.0
% INFO    : Bus 48919	: V=1.0062439, theta=-22.789887 -> V=1.0, theta=0.0
% INFO    : Bus 48920	: V=1.0071463, theta=-22.742439 -> V=1.0, theta=0.0
% INFO    : Bus 48921	: V=1.0037187, theta=-23.269319 -> V=1.0, theta=0.0
% INFO    : Bus 48922	: V=1.0085822, theta=-23.064723 -> V=1.0, theta=0.0
% INFO    : Bus 48923	: V=1.0052681, theta=-23.134098 -> V=1.0, theta=0.0
% INFO    : Bus 48924	: V=1.0117663, theta=-22.816562 -> V=1.0, theta=0.0
% INFO    : Bus 48925	: V=1.0180379, theta=-22.818377 -> V=1.0, theta=0.0
% INFO    : Bus 48926	: V=1.0175604, theta=-22.734929 -> V=1.0, theta=0.0
% INFO    : Bus 48927	: V=1.0175909, theta=-22.75037 -> V=1.0, theta=0.0
% INFO    : Bus 48928	: V=1.009844, theta=-22.792921 -> V=1.0, theta=0.0
% INFO    : Bus 48929	: V=0.9901715, theta=-23.552535 -> V=1.0, theta=0.0
% INFO    : Bus 48930	: V=1.0191643, theta=-22.957478 -> V=1.0, theta=0.0
% INFO    : Bus 48931	: V=0.9974977, theta=10.98081 -> V=1.0, theta=0.0
% INFO    : Bus 48932	: V=0.9949092, theta=10.601953 -> V=1.0, theta=0.0
% INFO    : Bus 48933	: V=1.0075384, theta=11.595334 -> V=1.0, theta=0.0
% INFO    : Bus 48934	: V=0.9907831, theta=-8.540837 -> V=1.0, theta=0.0
% INFO    : Bus 48935	: V=0.9829995, theta=-8.782193 -> V=1.0, theta=0.0
% INFO    : Bus 48936	: V=0.9809621, theta=-8.832681 -> V=1.0, theta=0.0
% INFO    : Bus 48937	: V=0.9853615, theta=-8.636287 -> V=1.0, theta=0.0
% INFO    : Bus 48938	: V=0.9953737, theta=-8.234646 -> V=1.0, theta=0.0
% INFO    : Bus 48939	: V=0.9985861, theta=-8.013671 -> V=1.0, theta=0.0
% INFO    : Bus 48940	: V=0.9859145, theta=-8.59597 -> V=1.0, theta=0.0
% INFO    : Bus 48941	: V=0.9976697, theta=-8.034665 -> V=1.0, theta=0.0
% INFO    : Bus 48942	: V=0.9807139, theta=-8.685947 -> V=1.0, theta=0.0
% INFO    : Bus 48943	: V=0.9943768, theta=-8.19764 -> V=1.0, theta=0.0
% INFO    : Bus 48944	: V=0.9828531, theta=-8.636183 -> V=1.0, theta=0.0
% INFO    : Bus 48945	: V=0.9789911, theta=-8.925985 -> V=1.0, theta=0.0
% INFO    : Bus 48946	: V=0.9832459, theta=-8.651863 -> V=1.0, theta=0.0
% INFO    : Bus 48947	: V=0.9921642, theta=-8.28338 -> V=1.0, theta=0.0
% INFO    : Bus 48948	: V=0.9902333, theta=-8.343228 -> V=1.0, theta=0.0
% INFO    : Bus 48949	: V=0.9774165, theta=-9.068247 -> V=1.0, theta=0.0
% INFO    : Bus 48950	: V=0.9771383, theta=-9.104375 -> V=1.0, theta=0.0
% INFO    : Bus 48951	: V=0.9783575, theta=-8.901825 -> V=1.0, theta=0.0
% INFO    : Bus 48952	: V=0.9759697, theta=-8.433586 -> V=1.0, theta=0.0
% INFO    : Bus 48953	: V=0.9787069, theta=-8.628169 -> V=1.0, theta=0.0
% INFO    : Bus 48954	: V=0.9732904, theta=-9.305386 -> V=1.0, theta=0.0
% INFO    : Bus 48955	: V=0.9746641, theta=-9.270237 -> V=1.0, theta=0.0
% INFO    : Bus 48956	: V=0.9738519, theta=-8.423452 -> V=1.0, theta=0.0
% INFO    : Bus 48957	: V=0.9783034, theta=-8.069415 -> V=1.0, theta=0.0
% INFO    : Bus 48958	: V=0.9769844, theta=-8.224783 -> V=1.0, theta=0.0
% INFO    : Bus 48959	: V=0.9787428, theta=-8.70081 -> V=1.0, theta=0.0
% INFO    : Bus 48960	: V=0.9771435, theta=-8.722158 -> V=1.0, theta=0.0
% INFO    : Bus 48961	: V=0.973832, theta=-8.493865 -> V=1.0, theta=0.0
% INFO    : Bus 48962	: V=0.98201, theta=-8.504386 -> V=1.0, theta=0.0
% INFO    : Bus 48963	: V=0.9793693, theta=-8.580415 -> V=1.0, theta=0.0
% INFO    : Bus 48964	: V=0.9804954, theta=-8.525094 -> V=1.0, theta=0.0
% INFO    : Bus 48965	: V=1.0037052, theta=-6.956588 -> V=1.0, theta=0.0
% INFO    : Bus 48966	: V=0.9765695, theta=-7.992394 -> V=1.0, theta=0.0
% INFO    : Bus 48967	: V=0.9824558, theta=-7.873883 -> V=1.0, theta=0.0
% INFO    : Bus 48968	: V=0.9754056, theta=-8.486173 -> V=1.0, theta=0.0
% INFO    : Bus 48969	: V=0.9739369, theta=-7.822294 -> V=1.0, theta=0.0
% INFO    : Bus 48970	: V=0.9731298, theta=-8.89463 -> V=1.0, theta=0.0
% INFO    : Bus 48971	: V=0.9723731, theta=-8.080325 -> V=1.0, theta=0.0
% INFO    : Bus 48972	: V=0.9792817, theta=-7.399471 -> V=1.0, theta=0.0
% INFO    : Bus 48973	: V=0.9890123, theta=-6.302898 -> V=1.0, theta=0.0
% INFO    : Bus 48974	: V=1.0251422, theta=-3.915292 -> V=1.0, theta=0.0
% INFO    : Bus 48975	: V=1.0027871, theta=-7.697273 -> V=1.0, theta=0.0
% INFO    : Bus 48976	: V=0.980952, theta=-8.657457 -> V=1.0, theta=0.0
% INFO    : Bus 48977	: V=0.9824052, theta=-8.666039 -> V=1.0, theta=0.0
% INFO    : Bus 48978	: V=0.9964308, theta=-2.368894 -> V=1.0, theta=0.0
% INFO    : Bus 48979	: V=0.9749121, theta=-4.647764 -> V=1.0, theta=0.0
% INFO    : Bus 48980	: V=0.9728018, theta=-5.384512 -> V=1.0, theta=0.0
% INFO    : Bus 48981	: V=0.9658962, theta=-6.269032 -> V=1.0, theta=0.0
% INFO    : Bus 48982	: V=0.998311, theta=-3.477605 -> V=1.0, theta=0.0
% INFO    : Bus 48983	: V=0.9940487, theta=-3.357084 -> V=1.0, theta=0.0
% INFO    : Bus 48984	: V=0.9961207, theta=-3.089144 -> V=1.0, theta=0.0
% INFO    : Bus 48985	: V=0.9966181, theta=-3.937363 -> V=1.0, theta=0.0
% INFO    : Bus 48986	: V=0.9937176, theta=-4.385446 -> V=1.0, theta=0.0
% INFO    : Bus 48987	: V=0.9954835, theta=-3.481329 -> V=1.0, theta=0.0
% INFO    : Bus 48988	: V=0.9961115, theta=-4.461261 -> V=1.0, theta=0.0
% INFO    : Bus 48989	: V=0.994376, theta=-4.018035 -> V=1.0, theta=0.0
% INFO    : Bus 48990	: V=0.9987127, theta=-0.478491 -> V=1.0, theta=0.0
% INFO    : Bus 48991	: V=0.9882896, theta=-5.037665 -> V=1.0, theta=0.0
% INFO    : Bus 48992	: V=0.985849, theta=-6.712122 -> V=1.0, theta=0.0
% INFO    : Bus 48993	: V=0.9899906, theta=-4.921857 -> V=1.0, theta=0.0
% INFO    : Bus 48994	: V=0.9819681, theta=-6.140928 -> V=1.0, theta=0.0
% INFO    : Bus 48995	: V=0.9909437, theta=-4.809114 -> V=1.0, theta=0.0
% INFO    : Bus 48996	: V=0.9963453, theta=-2.932001 -> V=1.0, theta=0.0
% INFO    : Bus 48997	: V=0.9873974, theta=-3.524995 -> V=1.0, theta=0.0
% INFO    : Bus 48998	: V=0.9891145, theta=-2.091936 -> V=1.0, theta=0.0
% INFO    : Bus 48999	: V=0.9779924, theta=-3.423739 -> V=1.0, theta=0.0
% INFO    : Bus 49000	: V=0.9803343, theta=-3.23183 -> V=1.0, theta=0.0
% INFO    : Bus 49001	: V=0.9668721, theta=-5.223468 -> V=1.0, theta=0.0
% INFO    : Bus 49002	: V=0.9768434, theta=-6.606809 -> V=1.0, theta=0.0
% INFO    : Bus 49003	: V=0.9831736, theta=-7.136083 -> V=1.0, theta=0.0
% INFO    : Bus 49004	: V=0.9836443, theta=-8.135449 -> V=1.0, theta=0.0
% INFO    : Bus 49005	: V=0.9749887, theta=-10.90117 -> V=1.0, theta=0.0
% INFO    : Bus 49006	: V=0.9766795, theta=-7.262993 -> V=1.0, theta=0.0
% INFO    : Bus 49007	: V=0.9799477, theta=-7.816504 -> V=1.0, theta=0.0
% INFO    : Bus 49008	: V=0.9885018, theta=-19.861721 -> V=1.0, theta=0.0
% INFO    : Bus 49009	: V=0.9930434, theta=-18.789685 -> V=1.0, theta=0.0
% INFO    : Bus 49010	: V=0.9934146, theta=-16.598504 -> V=1.0, theta=0.0
% INFO    : Bus 49011	: V=0.9919238, theta=-17.671491 -> V=1.0, theta=0.0
% INFO    : Bus 49012	: V=0.9965323, theta=-19.283233 -> V=1.0, theta=0.0
% INFO    : Bus 49013	: V=0.9883927, theta=-0.582745 -> V=1.0, theta=0.0
% INFO    : Bus 49014	: V=0.9804236, theta=-1.167766 -> V=1.0, theta=0.0
% INFO    : Bus 49015	: V=1.0139968, theta=0.676856 -> V=1.0, theta=0.0
% INFO    : Bus 49016	: V=0.9985646, theta=-0.924024 -> V=1.0, theta=0.0
% INFO    : Bus 49017	: V=0.9837655, theta=-14.127616 -> V=1.0, theta=0.0
% INFO    : Bus 49018	: V=0.9742373, theta=-13.909392 -> V=1.0, theta=0.0
% INFO    : Bus 49019	: V=0.9805047, theta=-13.601038 -> V=1.0, theta=0.0
% INFO    : Bus 49020	: V=0.9810404, theta=-13.704988 -> V=1.0, theta=0.0
% INFO    : Bus 49021	: V=0.9927503, theta=-20.796306 -> V=1.0, theta=0.0
% INFO    : Bus 49022	: V=0.9717778, theta=-22.506743 -> V=1.0, theta=0.0
% INFO    : Bus 49023	: V=0.9835498, theta=-21.755538 -> V=1.0, theta=0.0
% INFO    : Bus 49024	: V=1.0184271, theta=-12.231076 -> V=1.0, theta=0.0
% INFO    : Bus 49025	: V=1.018436, theta=-12.2219 -> V=1.0, theta=0.0
% INFO    : Bus 49026	: V=1.0198342, theta=-12.127962 -> V=1.0, theta=0.0
% INFO    : Bus 49027	: V=1.0207231, theta=-12.754609 -> V=1.0, theta=0.0
% INFO    : Bus 49028	: V=1.0190874, theta=-11.93399 -> V=1.0, theta=0.0
% INFO    : Bus 49029	: V=1.0179601, theta=-13.022951 -> V=1.0, theta=0.0
% INFO    : Bus 49030	: V=1.0179301, theta=-13.139777 -> V=1.0, theta=0.0
% INFO    : Bus 49031	: V=1.0189004, theta=-13.638313 -> V=1.0, theta=0.0
% INFO    : Bus 49032	: V=1.0224939, theta=-14.639839 -> V=1.0, theta=0.0
% INFO    : Bus 49033	: V=1.0240118, theta=-15.371977 -> V=1.0, theta=0.0
% INFO    : Bus 49034	: V=1.0067383, theta=-1.51689 -> V=1.0, theta=0.0
% INFO    : Bus 49035	: V=1.003822, theta=-1.363493 -> V=1.0, theta=0.0
% INFO    : Bus 49036	: V=0.9884215, theta=-3.444878 -> V=1.0, theta=0.0
% INFO    : Bus 49037	: V=1.0093037, theta=0.418803 -> V=1.0, theta=0.0
% INFO    : Bus 49038	: V=0.9802416, theta=-2.968998 -> V=1.0, theta=0.0
% INFO    : Bus 49039	: V=0.9895714, theta=-3.010764 -> V=1.0, theta=0.0
% INFO    : Bus 49040	: V=0.9781996, theta=-6.094752 -> V=1.0, theta=0.0
% INFO    : Bus 49041	: V=0.9849159, theta=-4.21587 -> V=1.0, theta=0.0
% INFO    : Bus 49042	: V=0.9843401, theta=-4.32938 -> V=1.0, theta=0.0
% INFO    : Bus 49043	: V=0.9905844, theta=-3.158314 -> V=1.0, theta=0.0
% INFO    : Bus 49044	: V=0.9906436, theta=-3.323982 -> V=1.0, theta=0.0
% INFO    : Bus 49045	: V=0.9759205, theta=-5.137657 -> V=1.0, theta=0.0
% INFO    : Bus 49046	: V=0.9862001, theta=-4.861997 -> V=1.0, theta=0.0
% INFO    : Bus 49047	: V=0.9850968, theta=-4.436199 -> V=1.0, theta=0.0
% INFO    : Bus 49048	: V=0.9883592, theta=-5.339777 -> V=1.0, theta=0.0
% INFO    : Bus 49049	: V=0.9739806, theta=-6.802287 -> V=1.0, theta=0.0
% INFO    : Bus 49050	: V=0.9812959, theta=-7.077357 -> V=1.0, theta=0.0
% INFO    : Bus 49051	: V=0.9865619, theta=-3.059268 -> V=1.0, theta=0.0
% INFO    : Bus 49052	: V=0.9826908, theta=-3.641325 -> V=1.0, theta=0.0
% INFO    : Bus 49053	: V=0.9785107, theta=-4.660954 -> V=1.0, theta=0.0
% INFO    : Bus 49054	: V=0.9827578, theta=-4.251981 -> V=1.0, theta=0.0
% INFO    : Bus 49055	: V=0.9799624, theta=-5.098374 -> V=1.0, theta=0.0
% INFO    : Bus 49056	: V=1.0001923, theta=1.036679 -> V=1.0, theta=0.0
% INFO    : Bus 49057	: V=1.014639, theta=1.876804 -> V=1.0, theta=0.0
% INFO    : Bus 49058	: V=0.9959782, theta=-23.067751 -> V=1.0, theta=0.0
% INFO    : Bus 49059	: V=0.9960874, theta=-23.078639 -> V=1.0, theta=0.0
% INFO    : Bus 49060	: V=0.9964745, theta=-23.081871 -> V=1.0, theta=0.0
% INFO    : Bus 49061	: V=0.9902622, theta=-23.549928 -> V=1.0, theta=0.0
% INFO    : Bus 49062	: V=0.9920199, theta=-23.479455 -> V=1.0, theta=0.0
% INFO    : Bus 49063	: V=0.9908494, theta=-23.513301 -> V=1.0, theta=0.0
% INFO    : Bus 49064	: V=0.9870564, theta=-23.616468 -> V=1.0, theta=0.0
% INFO    : Bus 49065	: V=0.9964418, theta=-23.026775 -> V=1.0, theta=0.0
% INFO    : Bus 49066	: V=0.9862965, theta=-23.614417 -> V=1.0, theta=0.0
% INFO    : Bus 49067	: V=0.9882301, theta=-23.556189 -> V=1.0, theta=0.0
% INFO    : Bus 49068	: V=0.9903886, theta=-23.473258 -> V=1.0, theta=0.0
% INFO    : Bus 49069	: V=0.9902723, theta=-23.486856 -> V=1.0, theta=0.0
% INFO    : Bus 49070	: V=0.997196, theta=-23.076457 -> V=1.0, theta=0.0
% INFO    : Bus 49071	: V=0.9979285, theta=-23.059219 -> V=1.0, theta=0.0
% INFO    : Bus 49072	: V=0.9984131, theta=-23.04656 -> V=1.0, theta=0.0
% INFO    : Bus 49073	: V=0.9904608, theta=-23.525228 -> V=1.0, theta=0.0
% INFO    : Bus 49074	: V=0.9896418, theta=-23.543372 -> V=1.0, theta=0.0
% INFO    : Bus 49075	: V=1.0039846, theta=-22.746399 -> V=1.0, theta=0.0
% INFO    : Bus 49076	: V=0.9861919, theta=-23.597571 -> V=1.0, theta=0.0
% INFO    : Bus 49077	: V=0.9831539, theta=-23.599181 -> V=1.0, theta=0.0
% INFO    : Bus 49078	: V=0.9996454, theta=-22.909017 -> V=1.0, theta=0.0
% INFO    : Bus 49079	: V=1.0001366, theta=-22.916944 -> V=1.0, theta=0.0
% INFO    : Bus 49080	: V=1.0051213, theta=-22.276972 -> V=1.0, theta=0.0
% INFO    : Bus 49081	: V=1.0053045, theta=-22.374179 -> V=1.0, theta=0.0
% INFO    : Bus 49082	: V=1.0057211, theta=-22.457816 -> V=1.0, theta=0.0
% INFO    : Bus 49083	: V=1.0062934, theta=-22.529964 -> V=1.0, theta=0.0
% INFO    : Bus 49084	: V=0.9911437, theta=-23.480298 -> V=1.0, theta=0.0
% INFO    : Bus 49085	: V=0.9940527, theta=-23.39836 -> V=1.0, theta=0.0
% INFO    : Bus 49086	: V=0.990302, theta=-23.529709 -> V=1.0, theta=0.0
% INFO    : Bus 49087	: V=0.9926659, theta=-23.405181 -> V=1.0, theta=0.0
% INFO    : Bus 49088	: V=1.0021131, theta=-22.783779 -> V=1.0, theta=0.0
% INFO    : Bus 49089	: V=1.0007627, theta=-22.796598 -> V=1.0, theta=0.0
% INFO    : Bus 49090	: V=0.9988129, theta=-22.89437 -> V=1.0, theta=0.0
% INFO    : Bus 49091	: V=1.0069855, theta=-21.915265 -> V=1.0, theta=0.0
% INFO    : Bus 49092	: V=1.0056234, theta=-22.660152 -> V=1.0, theta=0.0
% INFO    : Bus 49093	: V=1.0041432, theta=-22.797927 -> V=1.0, theta=0.0
% INFO    : Bus 49094	: V=1.0137915, theta=-22.266711 -> V=1.0, theta=0.0
% INFO    : Bus 49095	: V=1.0061094, theta=-22.765383 -> V=1.0, theta=0.0
% INFO    : Bus 49096	: V=1.0071038, theta=-22.745429 -> V=1.0, theta=0.0
% INFO    : Bus 49097	: V=1.0090267, theta=-22.683649 -> V=1.0, theta=0.0
% INFO    : Bus 49098	: V=1.0071103, theta=-22.77325 -> V=1.0, theta=0.0
% INFO    : Bus 49099	: V=1.0064385, theta=-22.796134 -> V=1.0, theta=0.0
% INFO    : Bus 49100	: V=1.0098214, theta=-22.502983 -> V=1.0, theta=0.0
% INFO    : Bus 49101	: V=1.0114503, theta=-22.500471 -> V=1.0, theta=0.0
% INFO    : Bus 49102	: V=0.9901722, theta=-23.553368 -> V=1.0, theta=0.0
% INFO    : Bus 49103	: V=0.9853874, theta=-21.546194 -> V=1.0, theta=0.0
% INFO    : Bus 49104	: V=1.0058426, theta=-21.805542 -> V=1.0, theta=0.0
% INFO    : Bus 49105	: V=1.0102867, theta=-21.496173 -> V=1.0, theta=0.0
% INFO    : Bus 49106	: V=1.0058478, theta=-20.913167 -> V=1.0, theta=0.0
% INFO    : Bus 49107	: V=0.9777261, theta=-23.406322 -> V=1.0, theta=0.0
% INFO    : Bus 49108	: V=1.0160172, theta=-22.368428 -> V=1.0, theta=0.0
% INFO    : Bus 49109	: V=1.010776, theta=-22.73095 -> V=1.0, theta=0.0
% INFO    : Bus 49110	: V=1.0121976, theta=-22.620867 -> V=1.0, theta=0.0
% INFO    : Bus 49111	: V=0.9948961, theta=-23.471982 -> V=1.0, theta=0.0
% INFO    : Bus 49112	: V=0.9875226, theta=-20.624305 -> V=1.0, theta=0.0
% INFO    : Bus 49113	: V=0.9869586, theta=-20.759123 -> V=1.0, theta=0.0
% INFO    : Bus 49114	: V=0.9855468, theta=-21.121851 -> V=1.0, theta=0.0
% INFO    : Bus 49115	: V=1.0025888, theta=-21.163394 -> V=1.0, theta=0.0
% INFO    : Bus 49116	: V=0.9977666, theta=-22.950551 -> V=1.0, theta=0.0
% INFO    : Bus 49117	: V=0.9841979, theta=-23.584379 -> V=1.0, theta=0.0
% INFO    : Bus 49118	: V=1.001292, theta=-22.888948 -> V=1.0, theta=0.0
% INFO    : Bus 49119	: V=1.0072663, theta=-22.643413 -> V=1.0, theta=0.0
% INFO    : Bus 49120	: V=0.9886968, theta=0.196148 -> V=1.0, theta=0.0
% INFO    : Bus 49121	: V=0.9914026, theta=-0.682839 -> V=1.0, theta=0.0
% INFO    : Bus 49122	: V=0.9914988, theta=-0.693791 -> V=1.0, theta=0.0
% INFO    : Bus 49123	: V=1.0011382, theta=-0.143966 -> V=1.0, theta=0.0
% INFO    : Bus 49124	: V=1.0012679, theta=2.212474 -> V=1.0, theta=0.0
% INFO    : Bus 49125	: V=0.9841964, theta=2.248319 -> V=1.0, theta=0.0
% INFO    : Bus 49126	: V=0.9864799, theta=1.475822 -> V=1.0, theta=0.0
% INFO    : Bus 49127	: V=0.9832955, theta=-8.578196 -> V=1.0, theta=0.0
% INFO    : Bus 49128	: V=0.9999759, theta=-6.253924 -> V=1.0, theta=0.0
% INFO    : Bus 49129	: V=0.9953796, theta=-6.77221 -> V=1.0, theta=0.0
% INFO    : Bus 49130	: V=1.0118208, theta=-4.84631 -> V=1.0, theta=0.0
% INFO    : Bus 49131	: V=1.0040569, theta=-5.89816 -> V=1.0, theta=0.0
% INFO    : Bus 49132	: V=1.0141154, theta=-3.244992 -> V=1.0, theta=0.0
% INFO    : Bus 49133	: V=0.9818639, theta=-11.450312 -> V=1.0, theta=0.0
% INFO    : Bus 49134	: V=0.9822466, theta=-12.258805 -> V=1.0, theta=0.0
% INFO    : Bus 49135	: V=0.9829465, theta=-13.251065 -> V=1.0, theta=0.0
% INFO    : Bus 49136	: V=0.9863422, theta=-1.377187 -> V=1.0, theta=0.0
% INFO    : Bus 49137	: V=0.983243, theta=-1.412689 -> V=1.0, theta=0.0
% INFO    : Bus 49138	: V=0.9850413, theta=-1.138735 -> V=1.0, theta=0.0
% INFO    : Bus 49139	: V=1.0008183, theta=2.765396 -> V=1.0, theta=0.0
% INFO    : Bus 49140	: V=0.9923684, theta=-0.777438 -> V=1.0, theta=0.0
% INFO    : Bus 49141	: V=0.9852931, theta=2.096917 -> V=1.0, theta=0.0
% INFO    : Bus 49142	: V=1.0049085, theta=-18.970897 -> V=1.0, theta=0.0
% INFO    : Bus 49143	: V=1.0037368, theta=-19.648888 -> V=1.0, theta=0.0
% INFO    : Bus 49144	: V=0.9949644, theta=-20.396674 -> V=1.0, theta=0.0
% INFO    : Bus 49145	: V=1.0036371, theta=-20.615826 -> V=1.0, theta=0.0
% INFO    : Bus 49146	: V=1.0076147, theta=-19.866229 -> V=1.0, theta=0.0
% INFO    : Bus 49147	: V=1.0113464, theta=-20.100811 -> V=1.0, theta=0.0
% INFO    : Bus 49148	: V=1.0178621, theta=-20.109187 -> V=1.0, theta=0.0
% INFO    : Bus 49149	: V=1.0080246, theta=-19.763511 -> V=1.0, theta=0.0
% INFO    : Bus 49150	: V=1.0000317, theta=-8.765835 -> V=1.0, theta=0.0
% INFO    : Bus 49151	: V=1.005931, theta=-8.972788 -> V=1.0, theta=0.0
% INFO    : Bus 49152	: V=1.0025384, theta=-8.810541 -> V=1.0, theta=0.0
% INFO    : Bus 49153	: V=1.0221475, theta=-9.406926 -> V=1.0, theta=0.0
% INFO    : Bus 49154	: V=0.9995508, theta=-8.132329 -> V=1.0, theta=0.0
% INFO    : Bus 49155	: V=0.9938184, theta=-8.520835 -> V=1.0, theta=0.0
% INFO    : Bus 49156	: V=0.9963067, theta=-8.303101 -> V=1.0, theta=0.0
% INFO    : Bus 49157	: V=0.9967741, theta=-8.275446 -> V=1.0, theta=0.0
% INFO    : Bus 49158	: V=0.9949113, theta=-8.455043 -> V=1.0, theta=0.0
% INFO    : Bus 49159	: V=1.0195138, theta=-6.302249 -> V=1.0, theta=0.0
% INFO    : Bus 49160	: V=0.99638, theta=-8.301441 -> V=1.0, theta=0.0
% INFO    : Bus 49161	: V=0.9968852, theta=-8.257828 -> V=1.0, theta=0.0
% INFO    : Bus 49162	: V=0.9928867, theta=-8.548537 -> V=1.0, theta=0.0
% INFO    : Bus 49163	: V=0.9887103, theta=-8.832949 -> V=1.0, theta=0.0
% INFO    : Bus 49164	: V=0.9895959, theta=-8.810042 -> V=1.0, theta=0.0
% INFO    : Bus 49165	: V=0.9920108, theta=-8.565176 -> V=1.0, theta=0.0
% INFO    : Bus 49166	: V=0.9955843, theta=-8.31541 -> V=1.0, theta=0.0
% INFO    : Bus 49167	: V=0.9946406, theta=-8.356059 -> V=1.0, theta=0.0
% INFO    : Bus 49168	: V=0.9909369, theta=-8.65499 -> V=1.0, theta=0.0
% INFO    : Bus 49169	: V=0.9892329, theta=-8.739021 -> V=1.0, theta=0.0
% INFO    : Bus 49170	: V=0.9890326, theta=-8.780357 -> V=1.0, theta=0.0
% INFO    : Bus 49171	: V=1.0046508, theta=-7.53582 -> V=1.0, theta=0.0
% INFO    : Bus 49172	: V=0.9857274, theta=-8.995674 -> V=1.0, theta=0.0
% INFO    : Bus 49173	: V=0.9832694, theta=-9.249529 -> V=1.0, theta=0.0
% INFO    : Bus 49174	: V=0.9905071, theta=-8.704443 -> V=1.0, theta=0.0
% INFO    : Bus 49175	: V=0.9895679, theta=-8.762663 -> V=1.0, theta=0.0
% INFO    : Bus 49176	: V=0.9881471, theta=-8.782791 -> V=1.0, theta=0.0
% INFO    : Bus 49177	: V=0.9871445, theta=-8.849667 -> V=1.0, theta=0.0
% INFO    : Bus 49178	: V=0.9883489, theta=-8.777063 -> V=1.0, theta=0.0
% INFO    : Bus 49179	: V=0.9872257, theta=-8.844744 -> V=1.0, theta=0.0
% INFO    : Bus 49180	: V=0.9864447, theta=-8.869322 -> V=1.0, theta=0.0
% INFO    : Bus 49181	: V=0.9934871, theta=-8.401928 -> V=1.0, theta=0.0
% INFO    : Bus 49182	: V=0.9862574, theta=-8.890037 -> V=1.0, theta=0.0
% INFO    : Bus 49183	: V=0.9864757, theta=-8.892309 -> V=1.0, theta=0.0
% INFO    : Bus 49184	: V=0.9860967, theta=-8.986757 -> V=1.0, theta=0.0
% INFO    : Bus 49185	: V=0.9873419, theta=-8.90783 -> V=1.0, theta=0.0
% INFO    : Bus 49186	: V=0.9812703, theta=-9.356903 -> V=1.0, theta=0.0
% INFO    : Bus 49187	: V=0.9824722, theta=-9.296555 -> V=1.0, theta=0.0
% INFO    : Bus 49188	: V=0.9791936, theta=-9.499841 -> V=1.0, theta=0.0
% INFO    : Bus 49189	: V=0.9798547, theta=-9.489956 -> V=1.0, theta=0.0
% INFO    : Bus 49190	: V=0.9785139, theta=-9.501438 -> V=1.0, theta=0.0
% INFO    : Bus 49191	: V=0.9862942, theta=-8.990024 -> V=1.0, theta=0.0
% INFO    : Bus 49192	: V=0.9854295, theta=-9.046221 -> V=1.0, theta=0.0
% INFO    : Bus 49193	: V=0.9800434, theta=-9.420232 -> V=1.0, theta=0.0
% INFO    : Bus 49194	: V=0.984899, theta=-9.068097 -> V=1.0, theta=0.0
% INFO    : Bus 49195	: V=0.979937, theta=-9.42086 -> V=1.0, theta=0.0
% INFO    : Bus 49196	: V=0.9782263, theta=-9.417551 -> V=1.0, theta=0.0
% INFO    : Bus 49197	: V=0.9768506, theta=-9.524716 -> V=1.0, theta=0.0
% INFO    : Bus 49198	: V=0.9831965, theta=-9.183491 -> V=1.0, theta=0.0
% INFO    : Bus 49199	: V=0.9777862, theta=-9.531108 -> V=1.0, theta=0.0
% INFO    : Bus 49200	: V=0.9780178, theta=-9.518641 -> V=1.0, theta=0.0
% INFO    : Bus 49201	: V=0.9785402, theta=-9.494341 -> V=1.0, theta=0.0
% INFO    : Bus 49202	: V=0.9782802, theta=-9.499513 -> V=1.0, theta=0.0
% INFO    : Bus 49203	: V=0.9733215, theta=-9.708173 -> V=1.0, theta=0.0
% INFO    : Bus 49204	: V=0.9818809, theta=-9.323417 -> V=1.0, theta=0.0
% INFO    : Bus 49205	: V=0.9817479, theta=-9.283958 -> V=1.0, theta=0.0
% INFO    : Bus 49206	: V=0.9755927, theta=-9.612255 -> V=1.0, theta=0.0
% INFO    : Bus 49207	: V=0.9745719, theta=-9.681685 -> V=1.0, theta=0.0
% INFO    : Bus 49208	: V=0.9806522, theta=-9.372066 -> V=1.0, theta=0.0
% INFO    : Bus 49209	: V=0.9806643, theta=-9.435106 -> V=1.0, theta=0.0
% INFO    : Bus 49210	: V=0.9720904, theta=-9.809669 -> V=1.0, theta=0.0
% INFO    : Bus 49211	: V=0.9710533, theta=-9.850421 -> V=1.0, theta=0.0
% INFO    : Bus 49212	: V=0.9713262, theta=-9.867575 -> V=1.0, theta=0.0
% INFO    : Bus 49213	: V=0.979892, theta=-9.397967 -> V=1.0, theta=0.0
% INFO    : Bus 49214	: V=0.9799679, theta=-9.366507 -> V=1.0, theta=0.0
% INFO    : Bus 49215	: V=0.9715597, theta=-9.850047 -> V=1.0, theta=0.0
% INFO    : Bus 49216	: V=0.9705807, theta=-9.984378 -> V=1.0, theta=0.0
% INFO    : Bus 49217	: V=0.9697727, theta=-9.985755 -> V=1.0, theta=0.0
% INFO    : Bus 49218	: V=0.9680162, theta=-10.040176 -> V=1.0, theta=0.0
% INFO    : Bus 49219	: V=0.9686216, theta=-10.045943 -> V=1.0, theta=0.0
% INFO    : Bus 49220	: V=0.9724886, theta=-9.818694 -> V=1.0, theta=0.0
% INFO    : Bus 49221	: V=0.9655923, theta=-10.133095 -> V=1.0, theta=0.0
% INFO    : Bus 49222	: V=0.9736647, theta=-9.783457 -> V=1.0, theta=0.0
% INFO    : Bus 49223	: V=0.9862378, theta=-8.885704 -> V=1.0, theta=0.0
% INFO    : Bus 49224	: V=0.9868107, theta=-8.862863 -> V=1.0, theta=0.0
% INFO    : Bus 49225	: V=0.9907476, theta=-8.539026 -> V=1.0, theta=0.0
% INFO    : Bus 49226	: V=0.980801, theta=-9.192083 -> V=1.0, theta=0.0
% INFO    : Bus 49227	: V=0.9859656, theta=-8.974064 -> V=1.0, theta=0.0
% INFO    : Bus 49228	: V=0.9944493, theta=-8.448206 -> V=1.0, theta=0.0
% INFO    : Bus 49229	: V=1.0038612, theta=-7.842141 -> V=1.0, theta=0.0
% INFO    : Bus 49230	: V=1.0032868, theta=-7.87639 -> V=1.0, theta=0.0
% INFO    : Bus 49231	: V=1.002739, theta=-7.903495 -> V=1.0, theta=0.0
% INFO    : Bus 49232	: V=1.0017154, theta=-8.029334 -> V=1.0, theta=0.0
% INFO    : Bus 49233	: V=0.9991996, theta=-8.197449 -> V=1.0, theta=0.0
% INFO    : Bus 49234	: V=0.9969047, theta=-8.202392 -> V=1.0, theta=0.0
% INFO    : Bus 49235	: V=0.9987491, theta=-8.485464 -> V=1.0, theta=0.0
% INFO    : Bus 49236	: V=0.9980287, theta=-8.431292 -> V=1.0, theta=0.0
% INFO    : Bus 49237	: V=1.0030821, theta=-7.889029 -> V=1.0, theta=0.0
% INFO    : Bus 49238	: V=1.0034204, theta=-7.753746 -> V=1.0, theta=0.0
% INFO    : Bus 49239	: V=1.0027969, theta=-7.763245 -> V=1.0, theta=0.0
% INFO    : Bus 49240	: V=0.988741, theta=-8.785526 -> V=1.0, theta=0.0
% INFO    : Bus 49241	: V=1.0033153, theta=-7.716946 -> V=1.0, theta=0.0
% INFO    : Bus 49242	: V=1.0039637, theta=-7.668598 -> V=1.0, theta=0.0
% INFO    : Bus 49243	: V=1.0028465, theta=-8.114612 -> V=1.0, theta=0.0
% INFO    : Bus 49244	: V=1.000323, theta=-8.093769 -> V=1.0, theta=0.0
% INFO    : Bus 49245	: V=0.9891607, theta=-8.607574 -> V=1.0, theta=0.0
% INFO    : Bus 49246	: V=0.9817691, theta=-9.193457 -> V=1.0, theta=0.0
% INFO    : Bus 49247	: V=0.9884161, theta=-8.63275 -> V=1.0, theta=0.0
% INFO    : Bus 49248	: V=0.9721771, theta=-9.537705 -> V=1.0, theta=0.0
% INFO    : Bus 49249	: V=0.9719182, theta=-9.611299 -> V=1.0, theta=0.0
% INFO    : Bus 49250	: V=0.9713791, theta=-9.531104 -> V=1.0, theta=0.0
% INFO    : Bus 49251	: V=0.970197, theta=-9.688471 -> V=1.0, theta=0.0
% INFO    : Bus 49252	: V=0.9700089, theta=-9.715788 -> V=1.0, theta=0.0
% INFO    : Bus 49253	: V=0.9697127, theta=-9.699755 -> V=1.0, theta=0.0
% INFO    : Bus 49254	: V=0.9700717, theta=-9.74718 -> V=1.0, theta=0.0
% INFO    : Bus 49255	: V=0.9677949, theta=-9.884229 -> V=1.0, theta=0.0
% INFO    : Bus 49256	: V=0.9691671, theta=-9.786002 -> V=1.0, theta=0.0
% INFO    : Bus 49257	: V=0.9704665, theta=-9.739304 -> V=1.0, theta=0.0
% INFO    : Bus 49258	: V=0.9713699, theta=-9.726776 -> V=1.0, theta=0.0
% INFO    : Bus 49259	: V=0.9716069, theta=-9.700944 -> V=1.0, theta=0.0
% INFO    : Bus 49260	: V=0.9885124, theta=-8.798163 -> V=1.0, theta=0.0
% INFO    : Bus 49261	: V=0.9719847, theta=-9.734671 -> V=1.0, theta=0.0
% INFO    : Bus 49262	: V=0.9729, theta=-9.722693 -> V=1.0, theta=0.0
% INFO    : Bus 49263	: V=0.9733877, theta=-9.678448 -> V=1.0, theta=0.0
% INFO    : Bus 49264	: V=0.9724814, theta=-9.88169 -> V=1.0, theta=0.0
% INFO    : Bus 49265	: V=0.9749469, theta=-9.993836 -> V=1.0, theta=0.0
% INFO    : Bus 49266	: V=0.9661256, theta=-10.099733 -> V=1.0, theta=0.0
% INFO    : Bus 49267	: V=0.9677052, theta=-10.054472 -> V=1.0, theta=0.0
% INFO    : Bus 49268	: V=0.9770508, theta=-9.526617 -> V=1.0, theta=0.0
% INFO    : Bus 49269	: V=0.9750471, theta=-9.607463 -> V=1.0, theta=0.0
% INFO    : Bus 49270	: V=1.0046532, theta=-8.060399 -> V=1.0, theta=0.0
% INFO    : Bus 49271	: V=0.9867414, theta=-8.73241 -> V=1.0, theta=0.0
% INFO    : Bus 49272	: V=0.9893292, theta=-8.580167 -> V=1.0, theta=0.0
% INFO    : Bus 49273	: V=0.9904214, theta=-8.509879 -> V=1.0, theta=0.0
% INFO    : Bus 49274	: V=0.9792115, theta=-9.32099 -> V=1.0, theta=0.0
% INFO    : Bus 49275	: V=0.9982568, theta=-8.036553 -> V=1.0, theta=0.0
% INFO    : Bus 49276	: V=0.9945769, theta=-8.265801 -> V=1.0, theta=0.0
% INFO    : Bus 49277	: V=0.9860693, theta=-8.724161 -> V=1.0, theta=0.0
% INFO    : Bus 49278	: V=1.0177443, theta=-6.030756 -> V=1.0, theta=0.0
% INFO    : Bus 49279	: V=1.0072275, theta=-7.893636 -> V=1.0, theta=0.0
% INFO    : Bus 49280	: V=0.9965445, theta=-8.170602 -> V=1.0, theta=0.0
% INFO    : Bus 49281	: V=1.003949, theta=-7.940723 -> V=1.0, theta=0.0
% INFO    : Bus 49282	: V=1.0034488, theta=-7.954892 -> V=1.0, theta=0.0
% INFO    : Bus 49283	: V=0.9859665, theta=-8.304695 -> V=1.0, theta=0.0
% INFO    : Bus 49284	: V=0.9875393, theta=-8.161258 -> V=1.0, theta=0.0
% INFO    : Bus 49285	: V=0.9844632, theta=-8.269919 -> V=1.0, theta=0.0
% INFO    : Bus 49286	: V=0.9851324, theta=-8.358847 -> V=1.0, theta=0.0
% INFO    : Bus 49287	: V=0.9870698, theta=-8.319749 -> V=1.0, theta=0.0
% INFO    : Bus 49288	: V=1.0055409, theta=-7.300138 -> V=1.0, theta=0.0
% INFO    : Bus 49289	: V=0.9873663, theta=-8.325396 -> V=1.0, theta=0.0
% INFO    : Bus 49290	: V=0.988969, theta=-8.25053 -> V=1.0, theta=0.0
% INFO    : Bus 49291	: V=0.9861517, theta=-8.36 -> V=1.0, theta=0.0
% INFO    : Bus 49292	: V=0.9867407, theta=-8.402902 -> V=1.0, theta=0.0
% INFO    : Bus 49293	: V=0.9867594, theta=-8.3491 -> V=1.0, theta=0.0
% INFO    : Bus 49294	: V=0.9888391, theta=-8.450115 -> V=1.0, theta=0.0
% INFO    : Bus 49295	: V=0.9891392, theta=-8.559295 -> V=1.0, theta=0.0
% INFO    : Bus 49296	: V=0.9823042, theta=-8.785299 -> V=1.0, theta=0.0
% INFO    : Bus 49297	: V=0.9758203, theta=-9.358465 -> V=1.0, theta=0.0
% INFO    : Bus 49298	: V=0.9880032, theta=-8.667594 -> V=1.0, theta=0.0
% INFO    : Bus 49299	: V=0.9985056, theta=-8.29527 -> V=1.0, theta=0.0
% INFO    : Bus 49300	: V=0.9935853, theta=-8.401501 -> V=1.0, theta=0.0
% INFO    : Bus 49301	: V=1.0017669, theta=-8.173839 -> V=1.0, theta=0.0
% INFO    : Bus 49302	: V=1.0049566, theta=-8.126117 -> V=1.0, theta=0.0
% INFO    : Bus 49303	: V=1.0065392, theta=-8.096203 -> V=1.0, theta=0.0
% INFO    : Bus 49304	: V=0.9920388, theta=-8.44255 -> V=1.0, theta=0.0
% INFO    : Bus 49305	: V=1.0115555, theta=-7.89303 -> V=1.0, theta=0.0
% INFO    : Bus 49306	: V=1.009656, theta=-7.094118 -> V=1.0, theta=0.0
% INFO    : Bus 49307	: V=0.9923603, theta=-8.110585 -> V=1.0, theta=0.0
% INFO    : Bus 49308	: V=1.0077148, theta=-7.219635 -> V=1.0, theta=0.0
% INFO    : Bus 49309	: V=0.9969471, theta=-7.722361 -> V=1.0, theta=0.0
% INFO    : Bus 49310	: V=0.9932717, theta=-8.073665 -> V=1.0, theta=0.0
% INFO    : Bus 49311	: V=0.9887056, theta=-8.219491 -> V=1.0, theta=0.0
% INFO    : Bus 49312	: V=1.014647, theta=-6.490373 -> V=1.0, theta=0.0
% INFO    : Bus 49313	: V=1.0068775, theta=-7.242952 -> V=1.0, theta=0.0
% INFO    : Bus 49314	: V=0.9962579, theta=-8.306285 -> V=1.0, theta=0.0
% INFO    : Bus 49315	: V=0.9879619, theta=-8.883515 -> V=1.0, theta=0.0
% INFO    : Bus 49316	: V=1.0074922, theta=-7.397726 -> V=1.0, theta=0.0
% INFO    : Bus 49317	: V=1.0154554, theta=-7.03132 -> V=1.0, theta=0.0
% INFO    : Bus 49318	: V=0.9926871, theta=-8.543155 -> V=1.0, theta=0.0
% INFO    : Bus 49319	: V=0.9965918, theta=-8.293007 -> V=1.0, theta=0.0
% INFO    : Bus 49320	: V=1.0058986, theta=-7.467748 -> V=1.0, theta=0.0
% INFO    : Bus 49321	: V=0.9969579, theta=-8.27586 -> V=1.0, theta=0.0
% INFO    : Bus 49322	: V=0.9925928, theta=-8.562163 -> V=1.0, theta=0.0
% INFO    : Bus 49323	: V=0.9951096, theta=-8.405634 -> V=1.0, theta=0.0
% INFO    : Bus 49324	: V=0.9920183, theta=-8.612944 -> V=1.0, theta=0.0
% INFO    : Bus 49325	: V=0.9941806, theta=-8.374473 -> V=1.0, theta=0.0
% INFO    : Bus 49326	: V=0.9941352, theta=-8.37585 -> V=1.0, theta=0.0
% INFO    : Bus 49327	: V=0.9902581, theta=-8.684468 -> V=1.0, theta=0.0
% INFO    : Bus 49328	: V=0.9898202, theta=-8.720592 -> V=1.0, theta=0.0
% INFO    : Bus 49329	: V=0.9850581, theta=-9.011478 -> V=1.0, theta=0.0
% INFO    : Bus 49330	: V=0.9875015, theta=-8.90688 -> V=1.0, theta=0.0
% INFO    : Bus 49331	: V=0.9885461, theta=-8.828748 -> V=1.0, theta=0.0
% INFO    : Bus 49332	: V=0.9899584, theta=-8.629338 -> V=1.0, theta=0.0
% INFO    : Bus 49333	: V=0.9932064, theta=-8.409381 -> V=1.0, theta=0.0
% INFO    : Bus 49334	: V=0.9723325, theta=-9.658236 -> V=1.0, theta=0.0
% INFO    : Bus 49335	: V=0.9643917, theta=-10.165771 -> V=1.0, theta=0.0
% INFO    : Bus 49336	: V=0.9662795, theta=-9.932634 -> V=1.0, theta=0.0
% INFO    : Bus 49337	: V=0.9761234, theta=-9.432843 -> V=1.0, theta=0.0
% INFO    : Bus 49338	: V=0.9780036, theta=-9.305222 -> V=1.0, theta=0.0
% INFO    : Bus 49339	: V=1.0120116, theta=-6.846653 -> V=1.0, theta=0.0
% INFO    : Bus 49340	: V=0.9843063, theta=-9.190572 -> V=1.0, theta=0.0
% INFO    : Bus 49341	: V=0.9842389, theta=-8.861946 -> V=1.0, theta=0.0
% INFO    : Bus 49342	: V=0.9868445, theta=-8.748826 -> V=1.0, theta=0.0
% INFO    : Bus 49343	: V=0.9870157, theta=-8.711224 -> V=1.0, theta=0.0
% INFO    : Bus 49344	: V=0.9755762, theta=-9.548818 -> V=1.0, theta=0.0
% INFO    : Bus 49345	: V=0.9810755, theta=-8.784854 -> V=1.0, theta=0.0
% INFO    : Bus 49346	: V=0.9873762, theta=-8.670374 -> V=1.0, theta=0.0
% INFO    : Bus 49347	: V=0.9872203, theta=-8.297948 -> V=1.0, theta=0.0
% INFO    : Bus 49348	: V=0.9750772, theta=-9.525332 -> V=1.0, theta=0.0
% INFO    : Bus 49349	: V=0.9886484, theta=-8.804273 -> V=1.0, theta=0.0
% INFO    : Bus 49350	: V=0.9753541, theta=-9.512383 -> V=1.0, theta=0.0
% INFO    : Bus 49351	: V=0.9880816, theta=-8.41557 -> V=1.0, theta=0.0
% INFO    : Bus 49352	: V=0.9773871, theta=-22.650315 -> V=1.0, theta=0.0
% INFO    : Bus 49353	: V=0.9627641, theta=-23.530657 -> V=1.0, theta=0.0
% INFO    : Bus 49354	: V=0.9769311, theta=-22.497418 -> V=1.0, theta=0.0
% INFO    : Bus 49355	: V=0.9649895, theta=-23.88915 -> V=1.0, theta=0.0
% INFO    : Bus 49356	: V=0.9657727, theta=-23.719932 -> V=1.0, theta=0.0
% INFO    : Bus 49357	: V=0.9664749, theta=-23.63637 -> V=1.0, theta=0.0
% INFO    : Bus 49358	: V=0.9677232, theta=-23.54226 -> V=1.0, theta=0.0
% INFO    : Bus 49359	: V=0.9696443, theta=-23.445072 -> V=1.0, theta=0.0
% INFO    : Bus 49360	: V=0.986357, theta=-21.920406 -> V=1.0, theta=0.0
% INFO    : Bus 49361	: V=0.9775454, theta=-22.701235 -> V=1.0, theta=0.0
% INFO    : Bus 49362	: V=0.9673493, theta=-23.522708 -> V=1.0, theta=0.0
% INFO    : Bus 49363	: V=0.9808592, theta=-22.132114 -> V=1.0, theta=0.0
% INFO    : Bus 49364	: V=0.9827266, theta=-21.487821 -> V=1.0, theta=0.0
% INFO    : Bus 49365	: V=0.9624212, theta=-23.513658 -> V=1.0, theta=0.0
% INFO    : Bus 49366	: V=0.9801453, theta=-22.078181 -> V=1.0, theta=0.0
% INFO    : Bus 49367	: V=0.9930365, theta=-22.496688 -> V=1.0, theta=0.0
% INFO    : Bus 49368	: V=1.0043491, theta=-22.453545 -> V=1.0, theta=0.0
% INFO    : Bus 49369	: V=0.991278, theta=-22.631602 -> V=1.0, theta=0.0
% INFO    : Bus 49370	: V=0.9890741, theta=-22.835616 -> V=1.0, theta=0.0
% INFO    : Bus 49371	: V=1.0081052, theta=-22.228185 -> V=1.0, theta=0.0
% INFO    : Bus 49372	: V=0.9674901, theta=-23.880623 -> V=1.0, theta=0.0
% INFO    : Bus 49373	: V=0.9892919, theta=-21.223844 -> V=1.0, theta=0.0
% INFO    : Bus 49374	: V=0.9904803, theta=-4.599803 -> V=1.0, theta=0.0
% INFO    : Bus 49375	: V=0.9932404, theta=-4.562967 -> V=1.0, theta=0.0
% INFO    : Bus 49376	: V=0.9973177, theta=-4.049584 -> V=1.0, theta=0.0
% INFO    : Bus 49377	: V=0.9971897, theta=-4.044983 -> V=1.0, theta=0.0
% INFO    : Bus 49378	: V=0.9744462, theta=-5.321033 -> V=1.0, theta=0.0
% INFO    : Bus 49379	: V=0.9986875, theta=-4.317414 -> V=1.0, theta=0.0
% INFO    : Bus 49380	: V=0.9967326, theta=-4.233097 -> V=1.0, theta=0.0
% INFO    : Bus 49381	: V=0.9763814, theta=-5.332508 -> V=1.0, theta=0.0
% INFO    : Bus 49382	: V=0.977571, theta=-5.30294 -> V=1.0, theta=0.0
% INFO    : Bus 49383	: V=0.9961159, theta=-4.10037 -> V=1.0, theta=0.0
% INFO    : Bus 49384	: V=0.9831858, theta=-4.92898 -> V=1.0, theta=0.0
% INFO    : Bus 49385	: V=0.9790697, theta=-5.166566 -> V=1.0, theta=0.0
% INFO    : Bus 49386	: V=0.9887014, theta=-4.594661 -> V=1.0, theta=0.0
% INFO    : Bus 49387	: V=0.9884324, theta=-4.548544 -> V=1.0, theta=0.0
% INFO    : Bus 49388	: V=0.9789345, theta=-5.19333 -> V=1.0, theta=0.0
% INFO    : Bus 49389	: V=0.9805464, theta=-5.061628 -> V=1.0, theta=0.0
% INFO    : Bus 49390	: V=0.9758444, theta=-5.787977 -> V=1.0, theta=0.0
% INFO    : Bus 49391	: V=0.9858361, theta=-4.546154 -> V=1.0, theta=0.0
% INFO    : Bus 49392	: V=0.9941103, theta=-4.190257 -> V=1.0, theta=0.0
% INFO    : Bus 49393	: V=0.984899, theta=-4.615834 -> V=1.0, theta=0.0
% INFO    : Bus 49394	: V=0.9861889, theta=-4.496634 -> V=1.0, theta=0.0
% INFO    : Bus 49395	: V=0.9842312, theta=-5.088399 -> V=1.0, theta=0.0
% INFO    : Bus 49396	: V=0.983733, theta=-4.678759 -> V=1.0, theta=0.0
% INFO    : Bus 49397	: V=1.0005846, theta=-4.74113 -> V=1.0, theta=0.0
% INFO    : Bus 49398	: V=0.9898961, theta=-4.777679 -> V=1.0, theta=0.0
% INFO    : Bus 49399	: V=0.994495, theta=-4.334137 -> V=1.0, theta=0.0
% INFO    : Bus 49400	: V=1.0174762, theta=-2.694738 -> V=1.0, theta=0.0
% INFO    : Bus 49401	: V=0.9995781, theta=-4.483554 -> V=1.0, theta=0.0
% INFO    : Bus 49402	: V=0.9996949, theta=-4.579647 -> V=1.0, theta=0.0
% INFO    : Bus 49403	: V=1.0152792, theta=-2.746825 -> V=1.0, theta=0.0
% INFO    : Bus 49404	: V=1.005143, theta=-4.848811 -> V=1.0, theta=0.0
% INFO    : Bus 49405	: V=1.0050423, theta=-4.710886 -> V=1.0, theta=0.0
% INFO    : Bus 49406	: V=1.0055959, theta=-4.569457 -> V=1.0, theta=0.0
% INFO    : Bus 49407	: V=0.9992993, theta=-4.963165 -> V=1.0, theta=0.0
% INFO    : Bus 49408	: V=1.0132142, theta=-4.721686 -> V=1.0, theta=0.0
% INFO    : Bus 49409	: V=1.0036411, theta=-5.219028 -> V=1.0, theta=0.0
% INFO    : Bus 49410	: V=1.0015291, theta=-5.015344 -> V=1.0, theta=0.0
% INFO    : Bus 49411	: V=1.0123398, theta=-4.857916 -> V=1.0, theta=0.0
% INFO    : Bus 49412	: V=1.0015589, theta=-5.965313 -> V=1.0, theta=0.0
% INFO    : Bus 49413	: V=0.99918, theta=-6.459002 -> V=1.0, theta=0.0
% INFO    : Bus 49414	: V=0.9863321, theta=-5.644303 -> V=1.0, theta=0.0
% INFO    : Bus 49415	: V=1.0074379, theta=-5.167045 -> V=1.0, theta=0.0
% INFO    : Bus 49416	: V=0.9883501, theta=-7.695445 -> V=1.0, theta=0.0
% INFO    : Bus 49417	: V=1.0004353, theta=-7.676617 -> V=1.0, theta=0.0
% INFO    : Bus 49418	: V=0.9978326, theta=-7.528435 -> V=1.0, theta=0.0
% INFO    : Bus 49419	: V=0.9908846, theta=-7.818626 -> V=1.0, theta=0.0
% INFO    : Bus 49420	: V=0.9819637, theta=-8.624907 -> V=1.0, theta=0.0
% INFO    : Bus 49421	: V=0.9842575, theta=-8.451956 -> V=1.0, theta=0.0
% INFO    : Bus 49422	: V=0.9756805, theta=-9.285537 -> V=1.0, theta=0.0
% INFO    : Bus 49423	: V=0.9966081, theta=-7.278698 -> V=1.0, theta=0.0
% INFO    : Bus 49424	: V=0.9814925, theta=-8.73968 -> V=1.0, theta=0.0
% INFO    : Bus 49425	: V=0.9838121, theta=4.825795 -> V=1.0, theta=0.0
% INFO    : Bus 49426	: V=0.9846463, theta=4.566263 -> V=1.0, theta=0.0
% INFO    : Bus 49427	: V=0.9805262, theta=-17.830762 -> V=1.0, theta=0.0
% INFO    : Bus 49428	: V=0.99391, theta=-16.542091 -> V=1.0, theta=0.0
% INFO    : Bus 49429	: V=0.9885261, theta=-16.422622 -> V=1.0, theta=0.0
% INFO    : Bus 49430	: V=0.9832065, theta=-16.681901 -> V=1.0, theta=0.0
% INFO    : Bus 49431	: V=0.9920529, theta=-15.565915 -> V=1.0, theta=0.0
% INFO    : Bus 49432	: V=0.9873091, theta=-16.9303 -> V=1.0, theta=0.0
% INFO    : Bus 49433	: V=0.9698018, theta=-8.502453 -> V=1.0, theta=0.0
% INFO    : Bus 49434	: V=0.9944313, theta=-6.491936 -> V=1.0, theta=0.0
% INFO    : Bus 49435	: V=0.9877972, theta=-5.950968 -> V=1.0, theta=0.0
% INFO    : Bus 49436	: V=0.9904185, theta=-6.94312 -> V=1.0, theta=0.0
% INFO    : Bus 49437	: V=0.9741857, theta=-8.379508 -> V=1.0, theta=0.0
% INFO    : Bus 49438	: V=0.9801734, theta=-8.17794 -> V=1.0, theta=0.0
% INFO    : Bus 49439	: V=0.979581, theta=-8.277631 -> V=1.0, theta=0.0
% INFO    : Bus 49440	: V=0.9648738, theta=-23.452595 -> V=1.0, theta=0.0
% INFO    : Bus 49441	: V=0.9921909, theta=-21.499892 -> V=1.0, theta=0.0
% INFO    : Bus 49442	: V=1.000915, theta=-23.386285 -> V=1.0, theta=0.0
% INFO    : Bus 49443	: V=0.9922659, theta=-24.106803 -> V=1.0, theta=0.0
% INFO    : Bus 49444	: V=0.9753527, theta=-23.652059 -> V=1.0, theta=0.0
% INFO    : Bus 49445	: V=0.9836228, theta=-24.436416 -> V=1.0, theta=0.0
% INFO    : Bus 49446	: V=0.9722431, theta=-24.28928 -> V=1.0, theta=0.0
% INFO    : Bus 49447	: V=0.991567, theta=8.291514 -> V=1.0, theta=0.0
% INFO    : Bus 49448	: V=0.9942392, theta=8.236136 -> V=1.0, theta=0.0
% INFO    : Bus 49449	: V=0.9866752, theta=7.293231 -> V=1.0, theta=0.0
% INFO    : Bus 49450	: V=0.9824693, theta=7.032701 -> V=1.0, theta=0.0
% INFO    : Bus 49451	: V=0.9824741, theta=1.355916 -> V=1.0, theta=0.0
% INFO    : Bus 49452	: V=0.9760378, theta=-0.575137 -> V=1.0, theta=0.0
% INFO    : Bus 49453	: V=0.9956322, theta=3.016676 -> V=1.0, theta=0.0
% INFO    : Bus 49454	: V=0.988108, theta=1.339333 -> V=1.0, theta=0.0
% INFO    : Bus 49455	: V=0.9835307, theta=0.111273 -> V=1.0, theta=0.0
% INFO    : Bus 49456	: V=0.9822203, theta=0.498796 -> V=1.0, theta=0.0
% INFO    : Bus 49457	: V=0.9787695, theta=-0.138212 -> V=1.0, theta=0.0
% INFO    : Bus 49458	: V=0.9918513, theta=2.312914 -> V=1.0, theta=0.0
% INFO    : Bus 49459	: V=0.9810826, theta=-0.174788 -> V=1.0, theta=0.0
% INFO    : Bus 49460	: V=0.9879559, theta=1.128979 -> V=1.0, theta=0.0
% INFO    : Bus 49461	: V=0.9901515, theta=1.656575 -> V=1.0, theta=0.0
% INFO    : Bus 49462	: V=0.9888363, theta=1.755256 -> V=1.0, theta=0.0
% INFO    : Bus 49463	: V=0.9871611, theta=-2.165102 -> V=1.0, theta=0.0
% INFO    : Bus 49464	: V=1.0027534, theta=-2.842968 -> V=1.0, theta=0.0
% INFO    : Bus 49465	: V=1.0045508, theta=-2.649122 -> V=1.0, theta=0.0
% INFO    : Bus 49466	: V=1.0054694, theta=-2.601299 -> V=1.0, theta=0.0
% INFO    : Bus 49467	: V=1.0015761, theta=-2.010518 -> V=1.0, theta=0.0
% INFO    : Bus 49468	: V=0.967404, theta=-28.568236 -> V=1.0, theta=0.0
% INFO    : Bus 49469	: V=0.9764172, theta=-25.912231 -> V=1.0, theta=0.0
% INFO    : Bus 49470	: V=0.9808962, theta=-27.454189 -> V=1.0, theta=0.0
% INFO    : Bus 49471	: V=0.9767656, theta=-26.654636 -> V=1.0, theta=0.0
% INFO    : Bus 49472	: V=0.9855527, theta=5.680325 -> V=1.0, theta=0.0
% INFO    : Bus 49473	: V=0.9869448, theta=6.667065 -> V=1.0, theta=0.0
% INFO    : Bus 49474	: V=1.0071654, theta=7.477161 -> V=1.0, theta=0.0
% INFO    : Bus 49475	: V=0.9942769, theta=6.513708 -> V=1.0, theta=0.0
% INFO    : Bus 49476	: V=1.0071842, theta=7.555032 -> V=1.0, theta=0.0
% INFO    : Bus 49477	: V=1.0229047, theta=-9.251027 -> V=1.0, theta=0.0
% INFO    : Bus 49478	: V=1.0218711, theta=-8.844198 -> V=1.0, theta=0.0
% INFO    : Bus 49479	: V=1.0054917, theta=-8.793782 -> V=1.0, theta=0.0
% INFO    : Bus 49480	: V=0.9769468, theta=-4.614624 -> V=1.0, theta=0.0
% INFO    : Bus 49481	: V=0.9824587, theta=-8.249008 -> V=1.0, theta=0.0
% INFO    : Bus 49482	: V=0.9743342, theta=-9.939182 -> V=1.0, theta=0.0
% INFO    : Bus 49483	: V=0.9839768, theta=6.368283 -> V=1.0, theta=0.0
% INFO    : Bus 49484	: V=0.9839685, theta=7.558895 -> V=1.0, theta=0.0
% INFO    : Bus 49485	: V=0.9813008, theta=6.250879 -> V=1.0, theta=0.0
% INFO    : Bus 49486	: V=0.9817342, theta=6.059472 -> V=1.0, theta=0.0
% INFO    : Bus 49487	: V=0.984968, theta=6.337714 -> V=1.0, theta=0.0
% INFO    : Bus 49488	: V=0.9831954, theta=6.029387 -> V=1.0, theta=0.0
% INFO    : Bus 49489	: V=0.990289, theta=7.458805 -> V=1.0, theta=0.0
% INFO    : Bus 49490	: V=0.9837931, theta=6.062306 -> V=1.0, theta=0.0
% INFO    : Bus 49491	: V=0.9821109, theta=5.055121 -> V=1.0, theta=0.0
% INFO    : Bus 49492	: V=0.9828823, theta=3.705984 -> V=1.0, theta=0.0
% INFO    : Bus 49493	: V=0.9887619, theta=-9.653978 -> V=1.0, theta=0.0
% INFO    : Bus 49494	: V=0.9868991, theta=-9.05931 -> V=1.0, theta=0.0
% INFO    : Bus 49495	: V=0.9983784, theta=-11.508995 -> V=1.0, theta=0.0
% INFO    : Bus 49496	: V=1.0077641, theta=-12.490352 -> V=1.0, theta=0.0
% INFO    : Bus 49497	: V=0.9989477, theta=-10.532325 -> V=1.0, theta=0.0
% INFO    : Bus 49498	: V=0.9763113, theta=-12.431264 -> V=1.0, theta=0.0
% INFO    : Bus 49499	: V=0.9815291, theta=-12.275491 -> V=1.0, theta=0.0
% INFO    : Bus 49500	: V=0.9837394, theta=-12.842805 -> V=1.0, theta=0.0
% INFO    : Bus 49501	: V=0.9900041, theta=-12.700441 -> V=1.0, theta=0.0
% INFO    : Bus 49502	: V=0.986055, theta=-5.097078 -> V=1.0, theta=0.0
% INFO    : Bus 49503	: V=0.9864649, theta=-6.053391 -> V=1.0, theta=0.0
% INFO    : Bus 49504	: V=0.9897962, theta=-7.54781 -> V=1.0, theta=0.0
% INFO    : Bus 49505	: V=0.9636411, theta=-7.758814 -> V=1.0, theta=0.0
% INFO    : Bus 49506	: V=0.9934663, theta=7.405656 -> V=1.0, theta=0.0
% INFO    : Bus 49507	: V=0.9863389, theta=6.670082 -> V=1.0, theta=0.0
% INFO    : Bus 49508	: V=0.9898186, theta=5.719931 -> V=1.0, theta=0.0
% INFO    : Bus 49509	: V=0.9905691, theta=3.734055 -> V=1.0, theta=0.0
% INFO    : Bus 49510	: V=0.9911102, theta=1.743002 -> V=1.0, theta=0.0
% INFO    : Bus 49511	: V=0.9926942, theta=0.291863 -> V=1.0, theta=0.0
% INFO    : Bus 49512	: V=0.982368, theta=0.467625 -> V=1.0, theta=0.0
% INFO    : Bus 49513	: V=0.9682531, theta=-8.748368 -> V=1.0, theta=0.0
% INFO    : Bus 49514	: V=0.9699145, theta=-9.780081 -> V=1.0, theta=0.0
% INFO    : Bus 49515	: V=0.9663494, theta=-9.354995 -> V=1.0, theta=0.0
% INFO    : Bus 49516	: V=0.9945746, theta=-11.612211 -> V=1.0, theta=0.0
% INFO    : Bus 49517	: V=0.9699176, theta=-10.464163 -> V=1.0, theta=0.0
% INFO    : Bus 49518	: V=1.020328, theta=-10.13399 -> V=1.0, theta=0.0
% INFO    : Bus 49519	: V=1.0055201, theta=-12.209738 -> V=1.0, theta=0.0
% INFO    : Bus 49520	: V=1.0211229, theta=-11.65663 -> V=1.0, theta=0.0
% INFO    : Bus 49521	: V=1.0217997, theta=-11.622473 -> V=1.0, theta=0.0
% INFO    : Bus 49522	: V=1.0198197, theta=-12.228995 -> V=1.0, theta=0.0
% INFO    : Bus 49523	: V=1.020572, theta=-12.204931 -> V=1.0, theta=0.0
% INFO    : Bus 49524	: V=0.9745988, theta=-25.568587 -> V=1.0, theta=0.0
% INFO    : Bus 49525	: V=0.974511, theta=-25.449921 -> V=1.0, theta=0.0
% INFO    : Bus 49526	: V=0.9748707, theta=-25.271407 -> V=1.0, theta=0.0
% INFO    : Bus 49527	: V=0.975504, theta=-26.173451 -> V=1.0, theta=0.0
% INFO    : Bus 49528	: V=0.96214, theta=-24.138068 -> V=1.0, theta=0.0
% INFO    : Bus 49529	: V=0.9805631, theta=-23.65101 -> V=1.0, theta=0.0
% INFO    : Bus 49530	: V=0.9828046, theta=-23.808 -> V=1.0, theta=0.0
% INFO    : Bus 49531	: V=0.9771495, theta=-24.443196 -> V=1.0, theta=0.0
% INFO    : Bus 49532	: V=0.9778403, theta=-25.047035 -> V=1.0, theta=0.0
% INFO    : Bus 49533	: V=0.9766304, theta=-25.803213 -> V=1.0, theta=0.0
% INFO    : Bus 49534	: V=0.9724153, theta=-26.78412 -> V=1.0, theta=0.0
% INFO    : Bus 49535	: V=0.9708055, theta=-27.350925 -> V=1.0, theta=0.0
% INFO    : Bus 49536	: V=0.9951635, theta=1.004502 -> V=1.0, theta=0.0
% INFO    : Bus 49537	: V=0.9999104, theta=0.679092 -> V=1.0, theta=0.0
% INFO    : Bus 49538	: V=1.0026264, theta=1.03942 -> V=1.0, theta=0.0
% INFO    : Bus 49539	: V=1.0160621, theta=2.09465 -> V=1.0, theta=0.0
% INFO    : Bus 49540	: V=1.0182461, theta=2.615444 -> V=1.0, theta=0.0
% INFO    : Bus 49541	: V=0.9968982, theta=-17.226946 -> V=1.0, theta=0.0
% INFO    : Bus 49542	: V=0.9984236, theta=-18.582237 -> V=1.0, theta=0.0
% INFO    : Bus 49543	: V=0.9831809, theta=-19.117213 -> V=1.0, theta=0.0
% INFO    : Bus 49544	: V=0.9933354, theta=-0.605091 -> V=1.0, theta=0.0
% INFO    : Bus 49545	: V=0.9903445, theta=-2.63112 -> V=1.0, theta=0.0
% INFO    : Bus 49546	: V=0.9936382, theta=-4.843504 -> V=1.0, theta=0.0
% INFO    : Bus 49547	: V=0.9839917, theta=-3.747596 -> V=1.0, theta=0.0
% INFO    : Bus 49548	: V=0.9966265, theta=-22.841542 -> V=1.0, theta=0.0
% INFO    : Bus 49549	: V=0.998232, theta=-20.904288 -> V=1.0, theta=0.0
% INFO    : Bus 49550	: V=1.0211924, theta=-13.125844 -> V=1.0, theta=0.0
% INFO    : Bus 49551	: V=1.0218177, theta=-14.239274 -> V=1.0, theta=0.0
% INFO    : Bus 49552	: V=0.9986383, theta=-14.399047 -> V=1.0, theta=0.0
% INFO    : Bus 49553	: V=1.0013446, theta=-14.345253 -> V=1.0, theta=0.0
% INFO    : Bus 49554	: V=1.0214657, theta=-14.377269 -> V=1.0, theta=0.0
% INFO    : Bus 49555	: V=1.0213552, theta=-14.936165 -> V=1.0, theta=0.0
% INFO    : Bus 49556	: V=0.9953913, theta=-5.279574 -> V=1.0, theta=0.0
% INFO    : Bus 49557	: V=1.0154803, theta=-4.919738 -> V=1.0, theta=0.0
% INFO    : Bus 49558	: V=1.0076909, theta=-4.939528 -> V=1.0, theta=0.0
% INFO    : Bus 49559	: V=1.0072684, theta=-5.00319 -> V=1.0, theta=0.0
% INFO    : Bus 49560	: V=1.0059945, theta=-5.380891 -> V=1.0, theta=0.0
% INFO    : Bus 49561	: V=0.9684363, theta=-8.345739 -> V=1.0, theta=0.0
% INFO    : Bus 49562	: V=0.9767409, theta=-9.0682 -> V=1.0, theta=0.0
% INFO    : Bus 49563	: V=0.9801511, theta=-8.841414 -> V=1.0, theta=0.0
% INFO    : Bus 49564	: V=0.9615717, theta=-10.615782 -> V=1.0, theta=0.0
% INFO    : Bus 49565	: V=0.9646314, theta=-10.370671 -> V=1.0, theta=0.0
% INFO    : Bus 49566	: V=0.9658966, theta=-10.145302 -> V=1.0, theta=0.0
% INFO    : Bus 49567	: V=0.9741786, theta=-9.268507 -> V=1.0, theta=0.0
% INFO    : Bus 49568	: V=0.9668713, theta=-10.089438 -> V=1.0, theta=0.0
% INFO    : Bus 49569	: V=0.9660045, theta=-10.125114 -> V=1.0, theta=0.0
% INFO    : Bus 49570	: V=0.9663881, theta=-10.076481 -> V=1.0, theta=0.0
% INFO    : Bus 49571	: V=0.9748779, theta=-9.228765 -> V=1.0, theta=0.0
% INFO    : Bus 49572	: V=0.973041, theta=-11.568234 -> V=1.0, theta=0.0
% INFO    : Bus 49573	: V=0.9726023, theta=-11.771822 -> V=1.0, theta=0.0
% INFO    : Bus 49574	: V=0.9731166, theta=-12.122036 -> V=1.0, theta=0.0
% INFO    : Bus 49575	: V=0.9737432, theta=-11.719838 -> V=1.0, theta=0.0
% INFO    : Bus 49576	: V=0.9696117, theta=-11.156039 -> V=1.0, theta=0.0
% INFO    : Bus 49577	: V=0.9809264, theta=-14.000186 -> V=1.0, theta=0.0
% INFO    : Bus 49578	: V=0.9754777, theta=-12.609263 -> V=1.0, theta=0.0
% INFO    : Bus 49579	: V=0.9739985, theta=-12.133912 -> V=1.0, theta=0.0
% INFO    : Bus 49580	: V=0.9736961, theta=-12.201772 -> V=1.0, theta=0.0
% INFO    : Bus 49581	: V=0.9759189, theta=-12.688269 -> V=1.0, theta=0.0
% INFO    : Bus 49582	: V=0.9875741, theta=4.137772 -> V=1.0, theta=0.0
% INFO    : Bus 49583	: V=0.9942144, theta=4.481485 -> V=1.0, theta=0.0
% INFO    : Bus 49584	: V=1.01232, theta=5.680847 -> V=1.0, theta=0.0
% INFO    : Bus 49585	: V=1.0088865, theta=5.081407 -> V=1.0, theta=0.0
% INFO    : Bus 49586	: V=1.000931, theta=5.434229 -> V=1.0, theta=0.0
% INFO    : Bus 49587	: V=0.9788347, theta=-8.826508 -> V=1.0, theta=0.0
% INFO    : Bus 49588	: V=0.9863115, theta=-8.716448 -> V=1.0, theta=0.0
% INFO    : Bus 49589	: V=0.9949171, theta=-8.246369 -> V=1.0, theta=0.0
% INFO    : Bus 49590	: V=0.9797657, theta=-8.664966 -> V=1.0, theta=0.0
% INFO    : Bus 49591	: V=0.9791175, theta=-8.551376 -> V=1.0, theta=0.0
% INFO    : Bus 49592	: V=0.9946116, theta=-6.867783 -> V=1.0, theta=0.0
% INFO    : Bus 49593	: V=0.9731092, theta=-9.317521 -> V=1.0, theta=0.0
% INFO    : Bus 49594	: V=0.9792534, theta=-8.264659 -> V=1.0, theta=0.0
% INFO    : Bus 49595	: V=0.9801507, theta=-8.284451 -> V=1.0, theta=0.0
% INFO    : Bus 49596	: V=0.9789971, theta=-8.387503 -> V=1.0, theta=0.0
% INFO    : Bus 49597	: V=0.9802114, theta=-8.243058 -> V=1.0, theta=0.0
% INFO    : Bus 49598	: V=0.9805299, theta=-8.242157 -> V=1.0, theta=0.0
% INFO    : Bus 49599	: V=0.9782858, theta=-8.459328 -> V=1.0, theta=0.0
% INFO    : Bus 49600	: V=0.9764851, theta=-8.451025 -> V=1.0, theta=0.0
% INFO    : Bus 49601	: V=0.9965102, theta=-6.602911 -> V=1.0, theta=0.0
% INFO    : Bus 49602	: V=0.9822242, theta=-8.100262 -> V=1.0, theta=0.0
% INFO    : Bus 49603	: V=0.992201, theta=-7.048875 -> V=1.0, theta=0.0
% INFO    : Bus 49604	: V=0.9992298, theta=-5.969026 -> V=1.0, theta=0.0
% INFO    : Bus 49605	: V=0.9943158, theta=-5.84228 -> V=1.0, theta=0.0
% INFO    : Bus 49606	: V=1.0047404, theta=-5.029338 -> V=1.0, theta=0.0
% INFO    : Bus 49607	: V=0.9822519, theta=-16.269406 -> V=1.0, theta=0.0
% INFO    : Bus 49608	: V=0.9955132, theta=-18.46124 -> V=1.0, theta=0.0
% INFO    : Bus 49609	: V=0.9727709, theta=-20.401401 -> V=1.0, theta=0.0
% INFO    : Bus 49610	: V=0.9743564, theta=-18.576175 -> V=1.0, theta=0.0
% INFO    : Bus 49611	: V=0.9852592, theta=-13.05135 -> V=1.0, theta=0.0
% INFO    : Bus 49612	: V=0.9798896, theta=-13.975648 -> V=1.0, theta=0.0
% INFO    : Bus 49613	: V=0.9792251, theta=-14.95699 -> V=1.0, theta=0.0
% INFO    : Bus 49614	: V=0.9849222, theta=-14.374822 -> V=1.0, theta=0.0
% INFO    : Bus 49615	: V=0.9845069, theta=-14.776955 -> V=1.0, theta=0.0
% INFO    : Bus 49616	: V=0.9844114, theta=-14.634615 -> V=1.0, theta=0.0
% INFO    : Bus 49617	: V=0.9866709, theta=-14.709207 -> V=1.0, theta=0.0
% INFO    : Bus 49618	: V=0.9763022, theta=-16.331286 -> V=1.0, theta=0.0
% INFO    : Bus 49619	: V=0.9776415, theta=-15.827501 -> V=1.0, theta=0.0
% INFO    : Bus 49620	: V=0.9904956, theta=7.678676 -> V=1.0, theta=0.0
% INFO    : Bus 49621	: V=1.018668, theta=10.286138 -> V=1.0, theta=0.0
% INFO    : Bus 49622	: V=0.9938751, theta=7.882148 -> V=1.0, theta=0.0
% INFO    : Bus 49623	: V=0.9892765, theta=5.844932 -> V=1.0, theta=0.0
% INFO    : Bus 49624	: V=1.0158238, theta=7.745506 -> V=1.0, theta=0.0
% INFO    : Bus 49625	: V=0.9995553, theta=5.175597 -> V=1.0, theta=0.0
% INFO    : Bus 49626	: V=1.0090359, theta=7.499552 -> V=1.0, theta=0.0
% INFO    : Bus 49627	: V=1.0145852, theta=5.667231 -> V=1.0, theta=0.0
% INFO    : Bus 49628	: V=1.0140518, theta=5.474242 -> V=1.0, theta=0.0
% INFO    : Bus 49629	: V=0.9982079, theta=4.536651 -> V=1.0, theta=0.0
% INFO    : Bus 49630	: V=0.9999498, theta=4.201779 -> V=1.0, theta=0.0
% INFO    : Bus 49631	: V=0.9766706, theta=-7.967333 -> V=1.0, theta=0.0
% INFO    : Bus 49632	: V=0.9948508, theta=-4.248589 -> V=1.0, theta=0.0
% INFO    : Bus 49633	: V=0.9719456, theta=-8.351221 -> V=1.0, theta=0.0
% INFO    : Bus 49634	: V=1.0086199, theta=-5.800233 -> V=1.0, theta=0.0
% INFO    : Bus 49635	: V=0.9953792, theta=-9.557263 -> V=1.0, theta=0.0
% INFO    : Bus 49636	: V=1.0094068, theta=-10.994792 -> V=1.0, theta=0.0
% INFO    : Bus 49637	: V=1.0342433, theta=-13.494999 -> V=1.0, theta=0.0
% INFO    : Bus 49638	: V=1.0214338, theta=-13.210341 -> V=1.0, theta=0.0
% INFO    : Bus 49639	: V=1.0323127, theta=-13.22587 -> V=1.0, theta=0.0
% INFO    : Bus 49640	: V=1.0248689, theta=-13.168028 -> V=1.0, theta=0.0
% INFO    : Bus 49641	: V=1.0006754, theta=-1.018555 -> V=1.0, theta=0.0
% INFO    : Bus 49642	: V=0.9769628, theta=-4.30097 -> V=1.0, theta=0.0
% INFO    : Bus 49643	: V=0.9778994, theta=-4.276159 -> V=1.0, theta=0.0
% INFO    : Bus 49644	: V=0.977989, theta=-4.216402 -> V=1.0, theta=0.0
% INFO    : Bus 49645	: V=0.9788697, theta=-4.199178 -> V=1.0, theta=0.0
% INFO    : Bus 49646	: V=0.9796969, theta=-4.158328 -> V=1.0, theta=0.0
% INFO    : Bus 49647	: V=0.9817027, theta=-3.582001 -> V=1.0, theta=0.0
% INFO    : Bus 49648	: V=0.977518, theta=-4.292226 -> V=1.0, theta=0.0
% INFO    : Bus 49649	: V=0.9810575, theta=-3.562855 -> V=1.0, theta=0.0
% INFO    : Bus 49650	: V=0.9778895, theta=-4.197146 -> V=1.0, theta=0.0
% INFO    : Bus 49651	: V=0.9805181, theta=-3.516815 -> V=1.0, theta=0.0
% INFO    : Bus 49652	: V=0.9778836, theta=-4.127846 -> V=1.0, theta=0.0
% INFO    : Bus 49653	: V=0.9775287, theta=-4.176739 -> V=1.0, theta=0.0
% INFO    : Bus 49654	: V=0.9781148, theta=-4.187049 -> V=1.0, theta=0.0
% INFO    : Bus 49655	: V=0.976391, theta=-4.307647 -> V=1.0, theta=0.0
% INFO    : Bus 49656	: V=0.980318, theta=-3.386114 -> V=1.0, theta=0.0
% INFO    : Bus 49657	: V=0.9767466, theta=-4.520088 -> V=1.0, theta=0.0
% INFO    : Bus 49658	: V=0.9785715, theta=-4.36554 -> V=1.0, theta=0.0
% INFO    : Bus 49659	: V=0.9779539, theta=-4.399076 -> V=1.0, theta=0.0
% INFO    : Bus 49660	: V=0.9817531, theta=-3.788227 -> V=1.0, theta=0.0
% INFO    : Bus 49661	: V=0.9799053, theta=-3.699774 -> V=1.0, theta=0.0
% INFO    : Bus 49662	: V=0.9819663, theta=-3.993758 -> V=1.0, theta=0.0
% INFO    : Bus 49663	: V=0.9800072, theta=-3.442862 -> V=1.0, theta=0.0
% INFO    : Bus 49664	: V=0.979706, theta=-3.845178 -> V=1.0, theta=0.0
% INFO    : Bus 49665	: V=0.9760158, theta=-4.563798 -> V=1.0, theta=0.0
% INFO    : Bus 49666	: V=0.975865, theta=-4.561019 -> V=1.0, theta=0.0
% INFO    : Bus 49667	: V=0.9767882, theta=-4.460325 -> V=1.0, theta=0.0
% INFO    : Bus 49668	: V=0.9812531, theta=-4.789234 -> V=1.0, theta=0.0
% INFO    : Bus 49669	: V=0.9771977, theta=-4.429868 -> V=1.0, theta=0.0
% INFO    : Bus 49670	: V=0.9772185, theta=-4.504193 -> V=1.0, theta=0.0
% INFO    : Bus 49671	: V=0.9908423, theta=-2.478719 -> V=1.0, theta=0.0
% INFO    : Bus 49672	: V=0.9802231, theta=-3.189654 -> V=1.0, theta=0.0
% INFO    : Bus 49673	: V=0.9785586, theta=-3.283797 -> V=1.0, theta=0.0
% INFO    : Bus 49674	: V=0.9794979, theta=-3.139659 -> V=1.0, theta=0.0
% INFO    : Bus 49675	: V=0.9801871, theta=-3.040869 -> V=1.0, theta=0.0
% INFO    : Bus 49676	: V=0.9762439, theta=-4.325994 -> V=1.0, theta=0.0
% INFO    : Bus 49677	: V=0.9803029, theta=-3.282136 -> V=1.0, theta=0.0
% INFO    : Bus 49678	: V=0.981476, theta=-4.00661 -> V=1.0, theta=0.0
% INFO    : Bus 49679	: V=0.9776481, theta=-4.135502 -> V=1.0, theta=0.0
% INFO    : Bus 49680	: V=0.977348, theta=-4.17771 -> V=1.0, theta=0.0
% INFO    : Bus 49681	: V=0.9779535, theta=-3.918233 -> V=1.0, theta=0.0
% INFO    : Bus 49682	: V=0.9780665, theta=-3.74119 -> V=1.0, theta=0.0
% INFO    : Bus 49683	: V=0.9816618, theta=-3.969917 -> V=1.0, theta=0.0
% INFO    : Bus 49684	: V=0.9778448, theta=-4.035109 -> V=1.0, theta=0.0
% INFO    : Bus 49685	: V=0.9777388, theta=-3.987191 -> V=1.0, theta=0.0
% INFO    : Bus 49686	: V=0.9780736, theta=-3.467953 -> V=1.0, theta=0.0
% INFO    : Bus 49687	: V=0.9829411, theta=-0.619148 -> V=1.0, theta=0.0
% INFO    : Bus 49688	: V=0.9822873, theta=-1.677989 -> V=1.0, theta=0.0
% INFO    : Bus 49689	: V=0.9823113, theta=-2.055589 -> V=1.0, theta=0.0
% INFO    : Bus 49690	: V=0.9835452, theta=-2.107585 -> V=1.0, theta=0.0
% INFO    : Bus 49691	: V=0.978666, theta=-3.565732 -> V=1.0, theta=0.0
% INFO    : Bus 49692	: V=0.9829978, theta=-2.173147 -> V=1.0, theta=0.0
% INFO    : Bus 49693	: V=0.982531, theta=-2.233852 -> V=1.0, theta=0.0
% INFO    : Bus 49694	: V=0.9790925, theta=-3.382188 -> V=1.0, theta=0.0
% INFO    : Bus 49695	: V=0.9793067, theta=-3.346111 -> V=1.0, theta=0.0
% INFO    : Bus 49696	: V=0.9788954, theta=-3.405497 -> V=1.0, theta=0.0
% INFO    : Bus 49697	: V=0.9794708, theta=-3.525033 -> V=1.0, theta=0.0
% INFO    : Bus 49698	: V=0.9813755, theta=-2.181491 -> V=1.0, theta=0.0
% INFO    : Bus 49699	: V=0.9923861, theta=-0.807765 -> V=1.0, theta=0.0
% INFO    : Bus 49700	: V=0.9788699, theta=-2.597204 -> V=1.0, theta=0.0
% INFO    : Bus 49701	: V=0.9788899, theta=-2.870134 -> V=1.0, theta=0.0
% INFO    : Bus 49702	: V=0.9800606, theta=-2.637795 -> V=1.0, theta=0.0
% INFO    : Bus 49703	: V=0.978343, theta=-2.810298 -> V=1.0, theta=0.0
% INFO    : Bus 49704	: V=0.9777176, theta=-2.866991 -> V=1.0, theta=0.0
% INFO    : Bus 49705	: V=0.9814317, theta=-1.599352 -> V=1.0, theta=0.0
% INFO    : Bus 49706	: V=0.9814833, theta=-1.724435 -> V=1.0, theta=0.0
% INFO    : Bus 49707	: V=0.9799624, theta=-2.360914 -> V=1.0, theta=0.0
% INFO    : Bus 49708	: V=0.9805685, theta=-1.960553 -> V=1.0, theta=0.0
% INFO    : Bus 49709	: V=0.9822645, theta=-0.486349 -> V=1.0, theta=0.0
% INFO    : Bus 49710	: V=0.9813675, theta=-2.407561 -> V=1.0, theta=0.0
% INFO    : Bus 49711	: V=0.9799664, theta=-2.54758 -> V=1.0, theta=0.0
% INFO    : Bus 49712	: V=0.9808024, theta=-2.049083 -> V=1.0, theta=0.0
% INFO    : Bus 49713	: V=0.9804165, theta=-2.264309 -> V=1.0, theta=0.0
% INFO    : Bus 49714	: V=1.001856, theta=-1.954284 -> V=1.0, theta=0.0
% INFO    : Bus 49715	: V=0.9776799, theta=-3.004507 -> V=1.0, theta=0.0
% INFO    : Bus 49716	: V=0.9851582, theta=-2.491682 -> V=1.0, theta=0.0
% INFO    : Bus 49717	: V=0.9775159, theta=-4.199983 -> V=1.0, theta=0.0
% INFO    : Bus 49718	: V=0.9808514, theta=-2.961482 -> V=1.0, theta=0.0
% INFO    : Bus 49719	: V=0.9930727, theta=-2.372184 -> V=1.0, theta=0.0
% INFO    : Bus 49720	: V=1.0081771, theta=-7.927096 -> V=1.0, theta=0.0
% INFO    : Bus 49721	: V=0.9962545, theta=-10.869994 -> V=1.0, theta=0.0
% INFO    : Bus 49722	: V=0.9925524, theta=-10.981078 -> V=1.0, theta=0.0
% INFO    : Bus 49723	: V=1.0164188, theta=-5.753024 -> V=1.0, theta=0.0
% INFO    : Bus 49724	: V=1.0158364, theta=-5.352424 -> V=1.0, theta=0.0
% INFO    : Bus 49725	: V=1.0078358, theta=-6.705228 -> V=1.0, theta=0.0
% INFO    : Bus 49726	: V=1.0095423, theta=-7.245099 -> V=1.0, theta=0.0
% INFO    : Bus 49727	: V=0.9955248, theta=-7.173743 -> V=1.0, theta=0.0
% INFO    : Bus 49728	: V=0.9963984, theta=-7.253998 -> V=1.0, theta=0.0
% INFO    : Bus 49729	: V=0.9958199, theta=-7.572207 -> V=1.0, theta=0.0
% INFO    : Bus 49730	: V=0.9961582, theta=-8.252412 -> V=1.0, theta=0.0
% INFO    : Bus 49731	: V=0.9991185, theta=-8.570279 -> V=1.0, theta=0.0
% INFO    : Bus 49732	: V=1.0197515, theta=-7.977149 -> V=1.0, theta=0.0
% INFO    : Bus 49733	: V=0.9900834, theta=-8.305679 -> V=1.0, theta=0.0
% INFO    : Bus 49734	: V=1.0182658, theta=-7.237314 -> V=1.0, theta=0.0
% INFO    : Bus 49735	: V=1.0185371, theta=-7.452351 -> V=1.0, theta=0.0
% INFO    : Bus 49736	: V=0.9959016, theta=-8.142183 -> V=1.0, theta=0.0
% INFO    : Bus 49737	: V=0.9962526, theta=-7.999887 -> V=1.0, theta=0.0
% INFO    : Bus 49738	: V=0.9837453, theta=-3.870825 -> V=1.0, theta=0.0
% INFO    : Bus 49739	: V=0.9857042, theta=-3.822796 -> V=1.0, theta=0.0
% INFO    : Bus 49740	: V=0.9841582, theta=-4.0952 -> V=1.0, theta=0.0
% INFO    : Bus 49741	: V=0.9845993, theta=-3.798067 -> V=1.0, theta=0.0
% INFO    : Bus 49742	: V=0.9825761, theta=-4.314699 -> V=1.0, theta=0.0
% INFO    : Bus 49743	: V=0.9855613, theta=-3.712404 -> V=1.0, theta=0.0
% INFO    : Bus 49744	: V=0.9866887, theta=-3.587276 -> V=1.0, theta=0.0
% INFO    : Bus 49745	: V=0.9885794, theta=-3.38173 -> V=1.0, theta=0.0
% INFO    : Bus 49746	: V=0.9852957, theta=-3.707694 -> V=1.0, theta=0.0
% INFO    : Bus 49747	: V=0.9857959, theta=-3.665832 -> V=1.0, theta=0.0
% INFO    : Bus 49748	: V=0.9862526, theta=-3.154917 -> V=1.0, theta=0.0
% INFO    : Bus 49749	: V=0.9942708, theta=-2.048581 -> V=1.0, theta=0.0
% INFO    : Bus 49750	: V=0.984034, theta=-3.618328 -> V=1.0, theta=0.0
% INFO    : Bus 49751	: V=0.9930531, theta=-2.160025 -> V=1.0, theta=0.0
% INFO    : Bus 49752	: V=0.9969747, theta=-1.750647 -> V=1.0, theta=0.0
% INFO    : Bus 49753	: V=0.9938769, theta=-1.883592 -> V=1.0, theta=0.0
% INFO    : Bus 49754	: V=0.9920581, theta=-2.045695 -> V=1.0, theta=0.0
% INFO    : Bus 49755	: V=0.993801, theta=-1.874073 -> V=1.0, theta=0.0
% INFO    : Bus 49756	: V=0.9901116, theta=-2.250085 -> V=1.0, theta=0.0
% INFO    : Bus 49757	: V=0.990895, theta=-2.167159 -> V=1.0, theta=0.0
% INFO    : Bus 49758	: V=0.9996137, theta=-1.351963 -> V=1.0, theta=0.0
% INFO    : Bus 49759	: V=0.9953097, theta=-1.727654 -> V=1.0, theta=0.0
% INFO    : Bus 49760	: V=0.9886331, theta=-2.41738 -> V=1.0, theta=0.0
% INFO    : Bus 49761	: V=0.9874196, theta=-2.570875 -> V=1.0, theta=0.0
% INFO    : Bus 49762	: V=0.9825186, theta=-3.88742 -> V=1.0, theta=0.0
% INFO    : Bus 49763	: V=0.9837561, theta=-3.235153 -> V=1.0, theta=0.0
% INFO    : Bus 49764	: V=0.9827923, theta=-3.268103 -> V=1.0, theta=0.0
% INFO    : Bus 49765	: V=0.9944066, theta=-1.941292 -> V=1.0, theta=0.0
% INFO    : Bus 49766	: V=0.9932875, theta=-2.047635 -> V=1.0, theta=0.0
% INFO    : Bus 49767	: V=0.9925712, theta=-2.105648 -> V=1.0, theta=0.0
% INFO    : Bus 49768	: V=0.9854524, theta=-3.141544 -> V=1.0, theta=0.0
% INFO    : Bus 49769	: V=0.9844085, theta=-3.146476 -> V=1.0, theta=0.0
% INFO    : Bus 49770	: V=0.9843132, theta=-3.431117 -> V=1.0, theta=0.0
% INFO    : Bus 49771	: V=0.9823619, theta=-3.674344 -> V=1.0, theta=0.0
% INFO    : Bus 49772	: V=0.9853185, theta=-3.441394 -> V=1.0, theta=0.0
% INFO    : Bus 49773	: V=0.9865341, theta=-2.702623 -> V=1.0, theta=0.0
% INFO    : Bus 49774	: V=0.981577, theta=-4.309778 -> V=1.0, theta=0.0
% INFO    : Bus 49775	: V=0.9811091, theta=-4.47476 -> V=1.0, theta=0.0
% INFO    : Bus 49776	: V=0.9806054, theta=-4.532422 -> V=1.0, theta=0.0
% INFO    : Bus 49777	: V=0.9799287, theta=-4.706885 -> V=1.0, theta=0.0
% INFO    : Bus 49778	: V=0.9789871, theta=-5.03479 -> V=1.0, theta=0.0
% INFO    : Bus 49779	: V=0.9797269, theta=-4.778914 -> V=1.0, theta=0.0
% INFO    : Bus 49780	: V=0.9780157, theta=-5.197233 -> V=1.0, theta=0.0
% INFO    : Bus 49781	: V=0.9784699, theta=-5.127492 -> V=1.0, theta=0.0
% INFO    : Bus 49782	: V=0.9814812, theta=-4.819638 -> V=1.0, theta=0.0
% INFO    : Bus 49783	: V=0.9793732, theta=-4.999137 -> V=1.0, theta=0.0
% INFO    : Bus 49784	: V=0.9798327, theta=-4.797912 -> V=1.0, theta=0.0
% INFO    : Bus 49785	: V=0.979573, theta=-4.742255 -> V=1.0, theta=0.0
% INFO    : Bus 49786	: V=0.9857344, theta=-2.825803 -> V=1.0, theta=0.0
% INFO    : Bus 49787	: V=0.9813889, theta=-4.552877 -> V=1.0, theta=0.0
% INFO    : Bus 49788	: V=0.9830984, theta=-3.927555 -> V=1.0, theta=0.0
% INFO    : Bus 49789	: V=0.9976424, theta=-1.612467 -> V=1.0, theta=0.0
% INFO    : Bus 49790	: V=0.9771535, theta=-5.133446 -> V=1.0, theta=0.0
% INFO    : Bus 49791	: V=0.9828978, theta=-4.122572 -> V=1.0, theta=0.0
% INFO    : Bus 49792	: V=0.98299, theta=-4.303326 -> V=1.0, theta=0.0
% INFO    : Bus 49793	: V=0.9799341, theta=-5.072068 -> V=1.0, theta=0.0
% INFO    : Bus 49794	: V=0.9830471, theta=-4.116414 -> V=1.0, theta=0.0
% INFO    : Bus 49795	: V=0.9827695, theta=-4.288793 -> V=1.0, theta=0.0
% INFO    : Bus 49796	: V=0.982113, theta=-4.636557 -> V=1.0, theta=0.0
% INFO    : Bus 49797	: V=0.9820044, theta=-4.77399 -> V=1.0, theta=0.0
% INFO    : Bus 49798	: V=0.9774255, theta=-5.393908 -> V=1.0, theta=0.0
% INFO    : Bus 49799	: V=0.9813986, theta=-5.003805 -> V=1.0, theta=0.0
% INFO    : Bus 49800	: V=0.9816607, theta=-4.94773 -> V=1.0, theta=0.0
% INFO    : Bus 49801	: V=0.9822229, theta=-4.843368 -> V=1.0, theta=0.0
% INFO    : Bus 49802	: V=0.9925256, theta=-3.814352 -> V=1.0, theta=0.0
% INFO    : Bus 49803	: V=0.9827067, theta=-4.431922 -> V=1.0, theta=0.0
% INFO    : Bus 49804	: V=0.9829882, theta=-4.586038 -> V=1.0, theta=0.0
% INFO    : Bus 49805	: V=0.9798884, theta=-5.128118 -> V=1.0, theta=0.0
% INFO    : Bus 49806	: V=0.9833638, theta=-4.620189 -> V=1.0, theta=0.0
% INFO    : Bus 49807	: V=0.9799942, theta=-5.09306 -> V=1.0, theta=0.0
% INFO    : Bus 49808	: V=0.9800375, theta=-5.087947 -> V=1.0, theta=0.0
% INFO    : Bus 49809	: V=0.9832039, theta=-4.43756 -> V=1.0, theta=0.0
% INFO    : Bus 49810	: V=0.9812434, theta=-4.921373 -> V=1.0, theta=0.0
% INFO    : Bus 49811	: V=0.9782231, theta=-5.147287 -> V=1.0, theta=0.0
% INFO    : Bus 49812	: V=0.979667, theta=-5.061503 -> V=1.0, theta=0.0
% INFO    : Bus 49813	: V=0.9802056, theta=-5.036103 -> V=1.0, theta=0.0
% INFO    : Bus 49814	: V=0.9777541, theta=-5.164068 -> V=1.0, theta=0.0
% INFO    : Bus 49815	: V=0.9777923, theta=-5.140104 -> V=1.0, theta=0.0
% INFO    : Bus 49816	: V=0.9810569, theta=-5.085571 -> V=1.0, theta=0.0
% INFO    : Bus 49817	: V=0.9787949, theta=-5.113732 -> V=1.0, theta=0.0
% INFO    : Bus 49818	: V=0.9778782, theta=-5.072929 -> V=1.0, theta=0.0
% INFO    : Bus 49819	: V=0.9833292, theta=-3.646311 -> V=1.0, theta=0.0
% INFO    : Bus 49820	: V=0.9776743, theta=-4.96999 -> V=1.0, theta=0.0
% INFO    : Bus 49821	: V=0.976374, theta=-5.508641 -> V=1.0, theta=0.0
% INFO    : Bus 49822	: V=0.9751204, theta=-5.615252 -> V=1.0, theta=0.0
% INFO    : Bus 49823	: V=0.9822352, theta=-4.438448 -> V=1.0, theta=0.0
% INFO    : Bus 49824	: V=0.9827954, theta=-4.393699 -> V=1.0, theta=0.0
% INFO    : Bus 49825	: V=0.9826563, theta=-4.746951 -> V=1.0, theta=0.0
% INFO    : Bus 49826	: V=0.976046, theta=-5.590494 -> V=1.0, theta=0.0
% INFO    : Bus 49827	: V=0.9815566, theta=-4.817801 -> V=1.0, theta=0.0
% INFO    : Bus 49828	: V=0.9826317, theta=-4.732466 -> V=1.0, theta=0.0
% INFO    : Bus 49829	: V=1.008849, theta=-2.997351 -> V=1.0, theta=0.0
% INFO    : Bus 49830	: V=0.9823782, theta=-4.760927 -> V=1.0, theta=0.0
% INFO    : Bus 49831	: V=0.9820357, theta=-4.792693 -> V=1.0, theta=0.0
% INFO    : Bus 49832	: V=0.977397, theta=-5.486906 -> V=1.0, theta=0.0
% INFO    : Bus 49833	: V=0.9778974, theta=-5.538072 -> V=1.0, theta=0.0
% INFO    : Bus 49834	: V=0.9778566, theta=-5.534872 -> V=1.0, theta=0.0
% INFO    : Bus 49835	: V=0.9817303, theta=-4.860358 -> V=1.0, theta=0.0
% INFO    : Bus 49836	: V=0.977891, theta=-5.547673 -> V=1.0, theta=0.0
% INFO    : Bus 49837	: V=0.9822417, theta=-4.820374 -> V=1.0, theta=0.0
% INFO    : Bus 49838	: V=0.9821937, theta=-4.81072 -> V=1.0, theta=0.0
% INFO    : Bus 49839	: V=0.9747934, theta=-5.840887 -> V=1.0, theta=0.0
% INFO    : Bus 49840	: V=0.977326, theta=-5.674525 -> V=1.0, theta=0.0
% INFO    : Bus 49841	: V=0.9826886, theta=-4.817947 -> V=1.0, theta=0.0
% INFO    : Bus 49842	: V=0.9780076, theta=-5.614584 -> V=1.0, theta=0.0
% INFO    : Bus 49843	: V=0.9813727, theta=-4.933939 -> V=1.0, theta=0.0
% INFO    : Bus 49844	: V=0.9807883, theta=-4.95735 -> V=1.0, theta=0.0
% INFO    : Bus 49845	: V=0.9803639, theta=-4.974834 -> V=1.0, theta=0.0
% INFO    : Bus 49846	: V=0.9747359, theta=-5.820046 -> V=1.0, theta=0.0
% INFO    : Bus 49847	: V=0.980321, theta=-4.925776 -> V=1.0, theta=0.0
% INFO    : Bus 49848	: V=0.974464, theta=-5.77715 -> V=1.0, theta=0.0
% INFO    : Bus 49849	: V=0.9777157, theta=-4.989034 -> V=1.0, theta=0.0
% INFO    : Bus 49850	: V=0.9788541, theta=-4.865911 -> V=1.0, theta=0.0
% INFO    : Bus 49851	: V=0.9800884, theta=-4.71712 -> V=1.0, theta=0.0
% INFO    : Bus 49852	: V=0.9829132, theta=-4.464367 -> V=1.0, theta=0.0
% INFO    : Bus 49853	: V=0.9775613, theta=-5.258988 -> V=1.0, theta=0.0
% INFO    : Bus 49854	: V=0.979768, theta=-5.050328 -> V=1.0, theta=0.0
% INFO    : Bus 49855	: V=0.9800085, theta=-5.112082 -> V=1.0, theta=0.0
% INFO    : Bus 49856	: V=0.9797469, theta=-5.009859 -> V=1.0, theta=0.0
% INFO    : Bus 49857	: V=0.9800967, theta=-4.946947 -> V=1.0, theta=0.0
% INFO    : Bus 49858	: V=0.9798751, theta=-4.924307 -> V=1.0, theta=0.0
% INFO    : Bus 49859	: V=0.9813664, theta=-4.735691 -> V=1.0, theta=0.0
% INFO    : Bus 49860	: V=0.9808379, theta=-4.792332 -> V=1.0, theta=0.0
% INFO    : Bus 49861	: V=0.9811259, theta=-4.825173 -> V=1.0, theta=0.0
% INFO    : Bus 49862	: V=0.9764015, theta=-5.671156 -> V=1.0, theta=0.0
% INFO    : Bus 49863	: V=0.9803655, theta=-4.930415 -> V=1.0, theta=0.0
% INFO    : Bus 49864	: V=0.9831094, theta=-4.451184 -> V=1.0, theta=0.0
% INFO    : Bus 49865	: V=0.9821331, theta=-4.601349 -> V=1.0, theta=0.0
% INFO    : Bus 49866	: V=0.9763262, theta=-5.645554 -> V=1.0, theta=0.0
% INFO    : Bus 49867	: V=0.9752119, theta=-5.719805 -> V=1.0, theta=0.0
% INFO    : Bus 49868	: V=0.9771579, theta=-5.059253 -> V=1.0, theta=0.0
% INFO    : Bus 49869	: V=0.9799202, theta=-5.003814 -> V=1.0, theta=0.0
% INFO    : Bus 49870	: V=0.9791079, theta=-5.127132 -> V=1.0, theta=0.0
% INFO    : Bus 49871	: V=0.9762231, theta=-5.793528 -> V=1.0, theta=0.0
% INFO    : Bus 49872	: V=0.9775624, theta=-5.422726 -> V=1.0, theta=0.0
% INFO    : Bus 49873	: V=0.9752212, theta=-5.732593 -> V=1.0, theta=0.0
% INFO    : Bus 49874	: V=0.9773366, theta=-5.441104 -> V=1.0, theta=0.0
% INFO    : Bus 49875	: V=0.9753001, theta=-5.821471 -> V=1.0, theta=0.0
% INFO    : Bus 49876	: V=0.9755849, theta=-5.824467 -> V=1.0, theta=0.0
% INFO    : Bus 49877	: V=0.9758855, theta=-5.757163 -> V=1.0, theta=0.0
% INFO    : Bus 49878	: V=0.9800204, theta=-4.97593 -> V=1.0, theta=0.0
% INFO    : Bus 49879	: V=0.9807911, theta=-4.954389 -> V=1.0, theta=0.0
% INFO    : Bus 49880	: V=0.9763019, theta=-5.742256 -> V=1.0, theta=0.0
% INFO    : Bus 49881	: V=0.9766647, theta=-5.722079 -> V=1.0, theta=0.0
% INFO    : Bus 49882	: V=0.9753289, theta=-5.829749 -> V=1.0, theta=0.0
% INFO    : Bus 49883	: V=0.9758601, theta=-5.781828 -> V=1.0, theta=0.0
% INFO    : Bus 49884	: V=0.981192, theta=-4.947578 -> V=1.0, theta=0.0
% INFO    : Bus 49885	: V=0.9768241, theta=-5.679717 -> V=1.0, theta=0.0
% INFO    : Bus 49886	: V=0.9824551, theta=-4.906749 -> V=1.0, theta=0.0
% INFO    : Bus 49887	: V=0.9836949, theta=-4.828539 -> V=1.0, theta=0.0
% INFO    : Bus 49888	: V=0.9776818, theta=-5.656426 -> V=1.0, theta=0.0
% INFO    : Bus 49889	: V=0.9772545, theta=-5.675165 -> V=1.0, theta=0.0
% INFO    : Bus 49890	: V=0.9846266, theta=-4.774134 -> V=1.0, theta=0.0
% INFO    : Bus 49891	: V=0.9795342, theta=-5.139644 -> V=1.0, theta=0.0
% INFO    : Bus 49892	: V=0.9974537, theta=-3.564238 -> V=1.0, theta=0.0
% INFO    : Bus 49893	: V=0.9778171, theta=-5.40462 -> V=1.0, theta=0.0
% INFO    : Bus 49894	: V=0.980988, theta=-5.06614 -> V=1.0, theta=0.0
% INFO    : Bus 49895	: V=0.9860235, theta=-4.672145 -> V=1.0, theta=0.0
% INFO    : Bus 49896	: V=1.0167413, theta=-1.454657 -> V=1.0, theta=0.0
% INFO    : Bus 49897	: V=0.9843208, theta=-4.87317 -> V=1.0, theta=0.0
% INFO    : Bus 49898	: V=0.9986901, theta=-3.976329 -> V=1.0, theta=0.0
% INFO    : Bus 49899	: V=0.9859401, theta=-4.783471 -> V=1.0, theta=0.0
% INFO    : Bus 49900	: V=0.9901811, theta=-4.530391 -> V=1.0, theta=0.0
% INFO    : Bus 49901	: V=0.9871927, theta=-4.554719 -> V=1.0, theta=0.0
% INFO    : Bus 49902	: V=0.9831232, theta=-4.89282 -> V=1.0, theta=0.0
% INFO    : Bus 49903	: V=0.9804182, theta=-5.125525 -> V=1.0, theta=0.0
% INFO    : Bus 49904	: V=0.9815309, theta=-5.02134 -> V=1.0, theta=0.0
% INFO    : Bus 49905	: V=0.9769035, theta=-5.638173 -> V=1.0, theta=0.0
% INFO    : Bus 49906	: V=0.9791959, theta=-5.222411 -> V=1.0, theta=0.0
% INFO    : Bus 49907	: V=0.9786904, theta=-5.264775 -> V=1.0, theta=0.0
% INFO    : Bus 49908	: V=0.9764081, theta=-5.709047 -> V=1.0, theta=0.0
% INFO    : Bus 49909	: V=0.978224, theta=-5.313559 -> V=1.0, theta=0.0
% INFO    : Bus 49910	: V=0.9780324, theta=-5.347386 -> V=1.0, theta=0.0
% INFO    : Bus 49911	: V=0.9781649, theta=-5.365463 -> V=1.0, theta=0.0
% INFO    : Bus 49912	: V=0.9769133, theta=-5.747084 -> V=1.0, theta=0.0
% INFO    : Bus 49913	: V=0.978658, theta=-5.613281 -> V=1.0, theta=0.0
% INFO    : Bus 49914	: V=0.9766402, theta=-5.831158 -> V=1.0, theta=0.0
% INFO    : Bus 49915	: V=0.9765361, theta=-5.506378 -> V=1.0, theta=0.0
% INFO    : Bus 49916	: V=0.9770664, theta=-5.449061 -> V=1.0, theta=0.0
% INFO    : Bus 49917	: V=0.9793521, theta=-5.1021 -> V=1.0, theta=0.0
% INFO    : Bus 49918	: V=0.9817068, theta=-5.037497 -> V=1.0, theta=0.0
% INFO    : Bus 49919	: V=0.9832136, theta=-4.694443 -> V=1.0, theta=0.0
% INFO    : Bus 49920	: V=0.9777651, theta=-5.58205 -> V=1.0, theta=0.0
% INFO    : Bus 49921	: V=0.9976522, theta=-3.859075 -> V=1.0, theta=0.0
% INFO    : Bus 49922	: V=0.9793257, theta=-5.354658 -> V=1.0, theta=0.0
% INFO    : Bus 49923	: V=0.9871089, theta=-3.768815 -> V=1.0, theta=0.0
% INFO    : Bus 49924	: V=0.9941654, theta=-3.543824 -> V=1.0, theta=0.0
% INFO    : Bus 49925	: V=0.9811219, theta=-4.617023 -> V=1.0, theta=0.0
% INFO    : Bus 49926	: V=0.9959992, theta=-2.940041 -> V=1.0, theta=0.0
% INFO    : Bus 49927	: V=0.9851119, theta=-4.11226 -> V=1.0, theta=0.0
% INFO    : Bus 49928	: V=0.9851972, theta=-4.062032 -> V=1.0, theta=0.0
% INFO    : Bus 49929	: V=0.9872218, theta=-3.882482 -> V=1.0, theta=0.0
% INFO    : Bus 49930	: V=0.99035, theta=-3.561711 -> V=1.0, theta=0.0
% INFO    : Bus 49931	: V=0.9836922, theta=-4.236741 -> V=1.0, theta=0.0
% INFO    : Bus 49932	: V=0.9960612, theta=-2.248158 -> V=1.0, theta=0.0
% INFO    : Bus 49933	: V=0.9836355, theta=-3.806693 -> V=1.0, theta=0.0
% INFO    : Bus 49934	: V=0.9755636, theta=-5.821009 -> V=1.0, theta=0.0
% INFO    : Bus 49935	: V=0.9805149, theta=-5.040735 -> V=1.0, theta=0.0
% INFO    : Bus 49936	: V=0.9857341, theta=-3.957108 -> V=1.0, theta=0.0
% INFO    : Bus 49937	: V=0.9869649, theta=-0.323886 -> V=1.0, theta=0.0
% INFO    : Bus 49938	: V=0.9766724, theta=-4.364405 -> V=1.0, theta=0.0
% INFO    : Bus 49939	: V=0.9829846, theta=-4.117995 -> V=1.0, theta=0.0
% INFO    : Bus 49940	: V=0.9842313, theta=-4.10907 -> V=1.0, theta=0.0
% INFO    : Bus 49941	: V=0.9848632, theta=-3.836802 -> V=1.0, theta=0.0
% INFO    : Bus 49942	: V=0.9841387, theta=-4.092096 -> V=1.0, theta=0.0
% INFO    : Bus 49943	: V=0.9852837, theta=-5.00767 -> V=1.0, theta=0.0
% INFO    : Bus 49944	: V=0.986254, theta=-2.520289 -> V=1.0, theta=0.0
% INFO    : Bus 49945	: V=1.0069314, theta=6.627501 -> V=1.0, theta=0.0
% INFO    : Bus 49946	: V=1.0013582, theta=5.910594 -> V=1.0, theta=0.0
% INFO    : Bus 49947	: V=1.0083684, theta=8.423328 -> V=1.0, theta=0.0
% INFO    : Bus 49948	: V=1.0081502, theta=8.544974 -> V=1.0, theta=0.0
% INFO    : Bus 49949	: V=1.0099688, theta=-8.059612 -> V=1.0, theta=0.0
% INFO    : Bus 49950	: V=1.0096183, theta=-9.124055 -> V=1.0, theta=0.0
% INFO    : Bus 49951	: V=1.0005745, theta=-9.785442 -> V=1.0, theta=0.0
% INFO    : Bus 49952	: V=1.0138697, theta=-9.226431 -> V=1.0, theta=0.0
% INFO    : Bus 49953	: V=1.0043976, theta=-10.227299 -> V=1.0, theta=0.0
% INFO    : Bus 49954	: V=1.0203949, theta=-10.086011 -> V=1.0, theta=0.0
% INFO    : Bus 49955	: V=1.0112141, theta=-8.721938 -> V=1.0, theta=0.0
% INFO    : Bus 49956	: V=1.0103161, theta=-8.328211 -> V=1.0, theta=0.0
% INFO    : Bus 49957	: V=1.0172143, theta=-9.521962 -> V=1.0, theta=0.0
% INFO    : Bus 49958	: V=1.0178509, theta=-9.632434 -> V=1.0, theta=0.0
% INFO    : Bus 49959	: V=0.9915141, theta=-15.258875 -> V=1.0, theta=0.0
% INFO    : Bus 49960	: V=0.9970749, theta=-15.999603 -> V=1.0, theta=0.0
% INFO    : Bus 49961	: V=0.9940121, theta=7.649147 -> V=1.0, theta=0.0
% INFO    : Bus 49962	: V=1.0034219, theta=8.265682 -> V=1.0, theta=0.0
% INFO    : Bus 49963	: V=0.9952818, theta=7.191866 -> V=1.0, theta=0.0
% INFO    : Bus 49964	: V=1.0118553, theta=-9.550151 -> V=1.0, theta=0.0
% INFO    : Bus 49965	: V=1.0231878, theta=-10.604418 -> V=1.0, theta=0.0
% INFO    : Bus 49966	: V=1.0024113, theta=-11.630446 -> V=1.0, theta=0.0
% INFO    : Bus 49967	: V=1.0100789, theta=-10.1822 -> V=1.0, theta=0.0
% INFO    : Bus 49968	: V=1.0189675, theta=-10.927045 -> V=1.0, theta=0.0
% INFO    : Bus 49969	: V=1.0224604, theta=-11.055156 -> V=1.0, theta=0.0
% INFO    : Bus 49970	: V=1.0219162, theta=-11.495145 -> V=1.0, theta=0.0
% INFO    : Bus 49971	: V=1.0201298, theta=-11.497404 -> V=1.0, theta=0.0
% INFO    : Bus 49972	: V=1.0052214, theta=-23.390745 -> V=1.0, theta=0.0
% INFO    : Bus 49973	: V=0.9855418, theta=-26.165866 -> V=1.0, theta=0.0
% INFO    : Bus 49974	: V=0.9851473, theta=-25.993343 -> V=1.0, theta=0.0
% INFO    : Bus 49975	: V=1.0115578, theta=-23.715372 -> V=1.0, theta=0.0
% INFO    : Bus 49976	: V=1.0150697, theta=-23.435761 -> V=1.0, theta=0.0
% INFO    : Bus 49977	: V=1.0084526, theta=-23.63706 -> V=1.0, theta=0.0
% INFO    : Bus 49978	: V=0.9973689, theta=4.105721 -> V=1.0, theta=0.0
% INFO    : Bus 49979	: V=0.9929239, theta=2.84276 -> V=1.0, theta=0.0
% INFO    : Bus 49980	: V=1.0010151, theta=4.117293 -> V=1.0, theta=0.0
% INFO    : Bus 49981	: V=1.0189223, theta=-23.390335 -> V=1.0, theta=0.0
% INFO    : Bus 49982	: V=1.0188549, theta=-23.362271 -> V=1.0, theta=0.0
% INFO    : Bus 49983	: V=1.0202709, theta=-23.144316 -> V=1.0, theta=0.0
% INFO    : Bus 49984	: V=1.0204355, theta=-23.098593 -> V=1.0, theta=0.0
% INFO    : Bus 49985	: V=1.0018766, theta=-24.16264 -> V=1.0, theta=0.0
% INFO    : Bus 49986	: V=0.9816359, theta=-24.489652 -> V=1.0, theta=0.0
% INFO    : Bus 49987	: V=0.9928482, theta=-24.343891 -> V=1.0, theta=0.0
% INFO    : Bus 49988	: V=0.9885317, theta=-23.68827 -> V=1.0, theta=0.0
% INFO    : Bus 49989	: V=0.9846018, theta=-25.127916 -> V=1.0, theta=0.0
% INFO    : Bus 49990	: V=1.0151291, theta=-23.527415 -> V=1.0, theta=0.0
% INFO    : Bus 49991	: V=0.9966593, theta=-16.441166 -> V=1.0, theta=0.0
% INFO    : Bus 49992	: V=0.9791144, theta=-18.147705 -> V=1.0, theta=0.0
% INFO    : Bus 49993	: V=0.9994882, theta=-17.452045 -> V=1.0, theta=0.0
% INFO    : Bus 49994	: V=1.0022098, theta=-18.281542 -> V=1.0, theta=0.0
% INFO    : Bus 49995	: V=0.984571, theta=-13.538375 -> V=1.0, theta=0.0
% INFO    : Bus 49996	: V=0.9876629, theta=-13.610707 -> V=1.0, theta=0.0
% INFO    : Bus 49997	: V=0.9888976, theta=-14.21306 -> V=1.0, theta=0.0
% INFO    : Bus 49998	: V=0.9883716, theta=-14.345461 -> V=1.0, theta=0.0
% INFO    : Bus 49999	: V=0.9863786, theta=-14.970202 -> V=1.0, theta=0.0
% INFO    : Bus 50000	: V=0.9876844, theta=-15.256393 -> V=1.0, theta=0.0
% INFO    : Bus 50001	: V=0.9798467, theta=-0.182845 -> V=1.0, theta=0.0
% INFO    : Bus 50002	: V=0.9848467, theta=-0.581494 -> V=1.0, theta=0.0
% INFO    : Bus 50003	: V=0.9829677, theta=-0.606901 -> V=1.0, theta=0.0
% INFO    : Bus 50004	: V=0.9806749, theta=-1.830862 -> V=1.0, theta=0.0
% INFO    : Bus 50005	: V=0.985819, theta=-0.59866 -> V=1.0, theta=0.0
% INFO    : Bus 50006	: V=1.013138, theta=-7.409795 -> V=1.0, theta=0.0
% INFO    : Bus 50007	: V=0.9904199, theta=-7.014967 -> V=1.0, theta=0.0
% INFO    : Bus 50008	: V=0.9767786, theta=-8.080752 -> V=1.0, theta=0.0
% INFO    : Bus 50009	: V=0.9750305, theta=-8.390221 -> V=1.0, theta=0.0
% INFO    : Bus 50010	: V=0.9925505, theta=-8.564575 -> V=1.0, theta=0.0
% INFO    : Bus 50011	: V=1.0244496, theta=-10.09498 -> V=1.0, theta=0.0
% INFO    : Bus 50012	: V=1.0239918, theta=-11.345778 -> V=1.0, theta=0.0
% INFO    : Bus 50013	: V=1.0295148, theta=-11.601886 -> V=1.0, theta=0.0
% INFO    : Bus 50014	: V=1.0253378, theta=-11.850042 -> V=1.0, theta=0.0
% INFO    : Bus 50015	: V=0.9815353, theta=-19.617983 -> V=1.0, theta=0.0
% INFO    : Bus 50016	: V=0.9778246, theta=-21.777852 -> V=1.0, theta=0.0
% INFO    : Bus 50017	: V=0.9804843, theta=-20.40585 -> V=1.0, theta=0.0
% INFO    : Bus 50018	: V=0.999579, theta=-21.369992 -> V=1.0, theta=0.0
% INFO    : Bus 50019	: V=0.9744791, theta=-22.856275 -> V=1.0, theta=0.0
% INFO    : Bus 50020	: V=0.9800585, theta=-20.811099 -> V=1.0, theta=0.0
% INFO    : Bus 50021	: V=0.9802917, theta=-21.2228 -> V=1.0, theta=0.0
% INFO    : Bus 50022	: V=0.9743954, theta=-22.405143 -> V=1.0, theta=0.0
% INFO    : Bus 50023	: V=0.9863507, theta=1.00282 -> V=1.0, theta=0.0
% INFO    : Bus 50024	: V=0.9992891, theta=-18.077794 -> V=1.0, theta=0.0
% INFO    : Bus 50025	: V=0.9957212, theta=-19.812488 -> V=1.0, theta=0.0
% INFO    : Bus 50026	: V=0.9909659, theta=-20.261706 -> V=1.0, theta=0.0
% INFO    : Bus 50027	: V=0.9898862, theta=-20.641315 -> V=1.0, theta=0.0
% INFO    : Bus 50028	: V=0.9763071, theta=-5.261975 -> V=1.0, theta=0.0
% INFO    : Bus 50029	: V=0.9758673, theta=-5.267932 -> V=1.0, theta=0.0
% INFO    : Bus 50030	: V=0.9838285, theta=-4.829717 -> V=1.0, theta=0.0
% INFO    : Bus 50031	: V=0.9843052, theta=-4.815884 -> V=1.0, theta=0.0
% INFO    : Bus 50032	: V=0.9847122, theta=-4.77917 -> V=1.0, theta=0.0
% INFO    : Bus 50033	: V=1.0089424, theta=-3.783198 -> V=1.0, theta=0.0
% INFO    : Bus 50034	: V=0.9829343, theta=-4.873317 -> V=1.0, theta=0.0
% INFO    : Bus 50035	: V=0.9824505, theta=-4.904876 -> V=1.0, theta=0.0
% INFO    : Bus 50036	: V=0.975441, theta=-5.266114 -> V=1.0, theta=0.0
% INFO    : Bus 50037	: V=0.9796073, theta=-5.116634 -> V=1.0, theta=0.0
% INFO    : Bus 50038	: V=0.9833973, theta=-4.851472 -> V=1.0, theta=0.0
% INFO    : Bus 50039	: V=0.9789114, theta=-5.445997 -> V=1.0, theta=0.0
% INFO    : Bus 50040	: V=0.9838423, theta=-4.751919 -> V=1.0, theta=0.0
% INFO    : Bus 50041	: V=0.9840029, theta=-4.745759 -> V=1.0, theta=0.0
% INFO    : Bus 50042	: V=0.9842515, theta=-4.73128 -> V=1.0, theta=0.0
% INFO    : Bus 50043	: V=0.9816552, theta=-4.932093 -> V=1.0, theta=0.0
% INFO    : Bus 50044	: V=0.978721, theta=-5.494617 -> V=1.0, theta=0.0
% INFO    : Bus 50045	: V=0.9835258, theta=-4.858364 -> V=1.0, theta=0.0
% INFO    : Bus 50046	: V=0.9782018, theta=-5.525091 -> V=1.0, theta=0.0
% INFO    : Bus 50047	: V=0.9821863, theta=-4.96626 -> V=1.0, theta=0.0
% INFO    : Bus 50048	: V=0.9819343, theta=-4.980241 -> V=1.0, theta=0.0
% INFO    : Bus 50049	: V=0.9816805, theta=-4.992497 -> V=1.0, theta=0.0
% INFO    : Bus 50050	: V=0.9771012, theta=-5.525368 -> V=1.0, theta=0.0
% INFO    : Bus 50051	: V=0.9771301, theta=-5.497214 -> V=1.0, theta=0.0
% INFO    : Bus 50052	: V=0.9773534, theta=-5.425589 -> V=1.0, theta=0.0
% INFO    : Bus 50053	: V=0.9774527, theta=-5.434057 -> V=1.0, theta=0.0
% INFO    : Bus 50054	: V=0.9779794, theta=-5.38874 -> V=1.0, theta=0.0
% INFO    : Bus 50055	: V=0.9804102, theta=-5.134434 -> V=1.0, theta=0.0
% INFO    : Bus 50056	: V=0.9775462, theta=-5.482742 -> V=1.0, theta=0.0
% INFO    : Bus 50057	: V=0.980057, theta=-5.179007 -> V=1.0, theta=0.0
% INFO    : Bus 50058	: V=0.9774491, theta=-5.30383 -> V=1.0, theta=0.0
% INFO    : Bus 50059	: V=0.9775894, theta=-5.268382 -> V=1.0, theta=0.0
% INFO    : Bus 50060	: V=0.9773988, theta=-5.325897 -> V=1.0, theta=0.0
% INFO    : Bus 50061	: V=0.9774415, theta=-5.344444 -> V=1.0, theta=0.0
% INFO    : Bus 50062	: V=0.9776502, theta=-5.35454 -> V=1.0, theta=0.0
% INFO    : Bus 50063	: V=0.9789806, theta=-5.135874 -> V=1.0, theta=0.0
% INFO    : Bus 50064	: V=0.9793316, theta=-4.995162 -> V=1.0, theta=0.0
% INFO    : Bus 50065	: V=0.9796304, theta=-4.987015 -> V=1.0, theta=0.0
% INFO    : Bus 50066	: V=0.9771955, theta=-5.646915 -> V=1.0, theta=0.0
% INFO    : Bus 50067	: V=0.9791, theta=-5.152415 -> V=1.0, theta=0.0
% INFO    : Bus 50068	: V=0.9789859, theta=-5.318688 -> V=1.0, theta=0.0
% INFO    : Bus 50069	: V=0.9769228, theta=-5.68458 -> V=1.0, theta=0.0
% INFO    : Bus 50070	: V=0.9788593, theta=-5.335606 -> V=1.0, theta=0.0
% INFO    : Bus 50071	: V=0.9787825, theta=-5.349832 -> V=1.0, theta=0.0
% INFO    : Bus 50072	: V=0.976701, theta=-5.694586 -> V=1.0, theta=0.0
% INFO    : Bus 50073	: V=0.9765632, theta=-5.711842 -> V=1.0, theta=0.0
% INFO    : Bus 50074	: V=0.9797852, theta=-5.216795 -> V=1.0, theta=0.0
% INFO    : Bus 50075	: V=0.9791028, theta=-5.315827 -> V=1.0, theta=0.0
% INFO    : Bus 50076	: V=0.9792277, theta=-5.309678 -> V=1.0, theta=0.0
% INFO    : Bus 50077	: V=0.9759, theta=-5.798092 -> V=1.0, theta=0.0
% INFO    : Bus 50078	: V=0.9827608, theta=-4.933757 -> V=1.0, theta=0.0
% INFO    : Bus 50079	: V=0.9773438, theta=-5.529477 -> V=1.0, theta=0.0
% INFO    : Bus 50080	: V=0.979618, theta=-5.242427 -> V=1.0, theta=0.0
% INFO    : Bus 50081	: V=0.9794108, theta=-5.276148 -> V=1.0, theta=0.0
% INFO    : Bus 50082	: V=0.9817111, theta=-5.150266 -> V=1.0, theta=0.0
% INFO    : Bus 50083	: V=0.9815105, theta=-5.088012 -> V=1.0, theta=0.0
% INFO    : Bus 50084	: V=0.9820159, theta=-4.924449 -> V=1.0, theta=0.0
% INFO    : Bus 50085	: V=0.9823018, theta=-5.016372 -> V=1.0, theta=0.0
% INFO    : Bus 50086	: V=0.9821959, theta=-4.990505 -> V=1.0, theta=0.0
% INFO    : Bus 50087	: V=0.9823077, theta=-4.982078 -> V=1.0, theta=0.0
% INFO    : Bus 50088	: V=0.9820837, theta=-5.013905 -> V=1.0, theta=0.0
% INFO    : Bus 50089	: V=0.9827645, theta=-4.954301 -> V=1.0, theta=0.0
% INFO    : Bus 50090	: V=0.9800456, theta=-5.116779 -> V=1.0, theta=0.0
% INFO    : Bus 50091	: V=0.9837535, theta=-4.854363 -> V=1.0, theta=0.0
% INFO    : Bus 50092	: V=0.9835318, theta=-4.872723 -> V=1.0, theta=0.0
% INFO    : Bus 50093	: V=0.9830379, theta=-4.927285 -> V=1.0, theta=0.0
% INFO    : Bus 50094	: V=0.9822816, theta=-4.993264 -> V=1.0, theta=0.0
% INFO    : Bus 50095	: V=0.981193, theta=-5.105434 -> V=1.0, theta=0.0
% INFO    : Bus 50096	: V=0.9789856, theta=-5.21847 -> V=1.0, theta=0.0
% INFO    : Bus 50097	: V=0.9793434, theta=-5.19811 -> V=1.0, theta=0.0
% INFO    : Bus 50098	: V=0.9794631, theta=-5.201172 -> V=1.0, theta=0.0
% INFO    : Bus 50099	: V=0.9789271, theta=-5.238316 -> V=1.0, theta=0.0
% INFO    : Bus 50100	: V=0.9805561, theta=-5.178684 -> V=1.0, theta=0.0
% INFO    : Bus 50101	: V=0.9801049, theta=-5.227667 -> V=1.0, theta=0.0
% INFO    : Bus 50102	: V=0.9780735, theta=-5.544625 -> V=1.0, theta=0.0
% INFO    : Bus 50103	: V=0.9796616, theta=-5.272652 -> V=1.0, theta=0.0
% INFO    : Bus 50104	: V=0.9800266, theta=-5.250254 -> V=1.0, theta=0.0
% INFO    : Bus 50105	: V=0.9793176, theta=-5.304602 -> V=1.0, theta=0.0
% INFO    : Bus 50106	: V=0.9774174, theta=-5.590665 -> V=1.0, theta=0.0
% INFO    : Bus 50107	: V=0.9773241, theta=-5.590391 -> V=1.0, theta=0.0
% INFO    : Bus 50108	: V=0.9771231, theta=-5.595866 -> V=1.0, theta=0.0
% INFO    : Bus 50109	: V=0.9766193, theta=-5.711479 -> V=1.0, theta=0.0
% INFO    : Bus 50110	: V=0.9765923, theta=-5.718129 -> V=1.0, theta=0.0
% INFO    : Bus 50111	: V=0.9797595, theta=-5.273951 -> V=1.0, theta=0.0
% INFO    : Bus 50112	: V=0.9795277, theta=-5.291265 -> V=1.0, theta=0.0
% INFO    : Bus 50113	: V=0.9809029, theta=-5.158992 -> V=1.0, theta=0.0
% INFO    : Bus 50114	: V=0.9806356, theta=-5.211755 -> V=1.0, theta=0.0
% INFO    : Bus 50115	: V=0.9797686, theta=-5.342336 -> V=1.0, theta=0.0
% INFO    : Bus 50116	: V=0.9827181, theta=-4.966404 -> V=1.0, theta=0.0
% INFO    : Bus 50117	: V=0.9804279, theta=-5.198256 -> V=1.0, theta=0.0
% INFO    : Bus 50118	: V=0.9808896, theta=-5.186541 -> V=1.0, theta=0.0
% INFO    : Bus 50119	: V=0.9929114, theta=-3.820249 -> V=1.0, theta=0.0
% INFO    : Bus 50120	: V=0.979414, theta=-5.325099 -> V=1.0, theta=0.0
% INFO    : Bus 50121	: V=0.9792598, theta=-5.334255 -> V=1.0, theta=0.0
% INFO    : Bus 50122	: V=0.9791321, theta=-5.326844 -> V=1.0, theta=0.0
% INFO    : Bus 50123	: V=0.9789254, theta=-5.321066 -> V=1.0, theta=0.0
% INFO    : Bus 50124	: V=0.9787907, theta=-5.259028 -> V=1.0, theta=0.0
% INFO    : Bus 50125	: V=0.9834386, theta=-4.772824 -> V=1.0, theta=0.0
% INFO    : Bus 50126	: V=0.9791542, theta=-5.286848 -> V=1.0, theta=0.0
% INFO    : Bus 50127	: V=0.9826212, theta=-4.36843 -> V=1.0, theta=0.0
% INFO    : Bus 50128	: V=0.9788041, theta=-5.35629 -> V=1.0, theta=0.0
% INFO    : Bus 50129	: V=0.9964817, theta=-3.402077 -> V=1.0, theta=0.0
% INFO    : Bus 50130	: V=0.9818252, theta=-5.052473 -> V=1.0, theta=0.0
% INFO    : Bus 50131	: V=0.9799682, theta=-5.283928 -> V=1.0, theta=0.0
% INFO    : Bus 50132	: V=0.9790699, theta=-5.344077 -> V=1.0, theta=0.0
% INFO    : Bus 50133	: V=0.9812364, theta=-5.071422 -> V=1.0, theta=0.0
% INFO    : Bus 50134	: V=1.02, theta=-21.098089 -> V=1.0, theta=0.0
% INFO    : Bus 50135	: V=1.02, theta=-14.406809 -> V=1.0, theta=0.0
% INFO    : Bus 50136	: V=1.02, theta=-6.767444 -> V=1.0, theta=0.0
% INFO    : Bus 50137	: V=1.02, theta=-52.410742 -> V=1.0, theta=0.0
% INFO    : Bus 50138	: V=1.0047129, theta=-25.337936 -> V=1.0, theta=0.0
% INFO    : Bus 50139	: V=1.013242, theta=-6.763898 -> V=1.0, theta=0.0
% INFO    : Bus 50140	: V=1.0063491, theta=-30.60205 -> V=1.0, theta=0.0
% INFO    : Bus 50141	: V=1.02, theta=-50.652837 -> V=1.0, theta=0.0
% INFO    : Bus 50142	: V=1.0154625, theta=-33.356639 -> V=1.0, theta=0.0
% INFO    : Bus 50143	: V=1.02, theta=-51.640907 -> V=1.0, theta=0.0
% INFO    : Bus 50144	: V=1.0156169, theta=-33.37918 -> V=1.0, theta=0.0
% INFO    : Bus 50145	: V=1.02, theta=-50.44609 -> V=1.0, theta=0.0
% INFO    : Bus 50146	: V=1.02, theta=-34.447934 -> V=1.0, theta=0.0
% INFO    : Bus 50147	: V=1.02, theta=-32.13569 -> V=1.0, theta=0.0
% INFO    : Bus 50148	: V=1.02, theta=-11.088219 -> V=1.0, theta=0.0
% INFO    : Bus 50149	: V=1.02, theta=-11.673953 -> V=1.0, theta=0.0
% INFO    : Bus 50150	: V=1.02, theta=-35.392963 -> V=1.0, theta=0.0
% INFO    : Bus 50151	: V=1.0084086, theta=-27.657001 -> V=1.0, theta=0.0
% INFO    : Bus 50152	: V=1.02, theta=-13.93279 -> V=1.0, theta=0.0
% INFO    : Bus 50153	: V=1.02, theta=-44.040353 -> V=1.0, theta=0.0
% INFO    : Bus 50154	: V=1.0088377, theta=-7.269134 -> V=1.0, theta=0.0
% INFO    : Bus 50155	: V=1.019146, theta=-27.991109 -> V=1.0, theta=0.0
% INFO    : Bus 50156	: V=1.02, theta=-43.811797 -> V=1.0, theta=0.0
% INFO    : Bus 50157	: V=1.02, theta=-33.507746 -> V=1.0, theta=0.0
% INFO    : Bus 50158	: V=1.0202725, theta=-52.211571 -> V=1.0, theta=0.0
% INFO    : Bus 50159	: V=0.9936905, theta=-25.264698 -> V=1.0, theta=0.0
% INFO    : Bus 50160	: V=1.02, theta=-18.96115 -> V=1.0, theta=0.0
% INFO    : Bus 50161	: V=0.9950284, theta=-8.453957 -> V=1.0, theta=0.0
% INFO    : Bus 50162	: V=1.02, theta=-56.243431 -> V=1.0, theta=0.0
% INFO    : Bus 50163	: V=0.9988835, theta=-45.632993 -> V=1.0, theta=0.0
% INFO    : Bus 50164	: V=0.9990248, theta=-45.616062 -> V=1.0, theta=0.0
% INFO    : Bus 50165	: V=1.02, theta=-12.277983 -> V=1.0, theta=0.0
% INFO    : Bus 50166	: V=1.02, theta=-49.518572 -> V=1.0, theta=0.0
% INFO    : Bus 50167	: V=1.0079818, theta=-38.690406 -> V=1.0, theta=0.0
% INFO    : Bus 50168	: V=1.0069916, theta=-38.754527 -> V=1.0, theta=0.0
% INFO    : Bus 50169	: V=0.9849964, theta=-33.89009 -> V=1.0, theta=0.0
% INFO    : Bus 50170	: V=1.0055969, theta=-11.024521 -> V=1.0, theta=0.0
% INFO    : Bus 50171	: V=0.9783978, theta=-34.219263 -> V=1.0, theta=0.0
% INFO    : Bus 50172	: V=1.0106235, theta=-35.398073 -> V=1.0, theta=0.0
% INFO    : Bus 50173	: V=0.9924827, theta=-21.156944 -> V=1.0, theta=0.0
% INFO    : Bus 50174	: V=0.9833163, theta=-25.962103 -> V=1.0, theta=0.0
% INFO    : Bus 50175	: V=0.9801568, theta=-35.868495 -> V=1.0, theta=0.0
% INFO    : Bus 50176	: V=1.02, theta=-24.110802 -> V=1.0, theta=0.0
% INFO    : Bus 50177	: V=1.02, theta=-19.051485 -> V=1.0, theta=0.0
% INFO    : Bus 50178	: V=0.9888852, theta=-40.30185 -> V=1.0, theta=0.0
% INFO    : Bus 50179	: V=0.9885759, theta=-39.805225 -> V=1.0, theta=0.0
% INFO    : Bus 50180	: V=1.02, theta=26.353564 -> V=1.0, theta=0.0
% INFO    : Bus 50181	: V=1.02, theta=22.346129 -> V=1.0, theta=0.0
% INFO    : Bus 50182	: V=1.02, theta=23.879921 -> V=1.0, theta=0.0
% INFO    : Bus 50183	: V=1.02, theta=26.24752 -> V=1.0, theta=0.0
% INFO    : Bus 50184	: V=1.02, theta=20.653614 -> V=1.0, theta=0.0
% INFO    : Bus 50185	: V=1.02, theta=20.678915 -> V=1.0, theta=0.0
% INFO    : Bus 50186	: V=1.02, theta=2.273013 -> V=1.0, theta=0.0
% INFO    : Bus 50187	: V=1.02, theta=-1.705375 -> V=1.0, theta=0.0
% INFO    : Bus 50188	: V=1.0131718, theta=2.160488 -> V=1.0, theta=0.0
% INFO    : Bus 50189	: V=1.02, theta=1.86 -> V=1.0, theta=0.0
% INFO    : Bus 50190	: V=1.02, theta=2.145975 -> V=1.0, theta=0.0
% INFO    : Bus 50191	: V=1.0055961, theta=9.977772 -> V=1.0, theta=0.0
% INFO    : Bus 50192	: V=1.02, theta=18.69819 -> V=1.0, theta=0.0
% INFO    : Bus 50193	: V=1.02, theta=16.921078 -> V=1.0, theta=0.0
% INFO    : Bus 50194	: V=1.0199462, theta=1.854121 -> V=1.0, theta=0.0
% INFO    : Bus 50195	: V=1.0158156, theta=4.53556 -> V=1.0, theta=0.0
% INFO    : Bus 50196	: V=1.02, theta=23.508217 -> V=1.0, theta=0.0
% INFO    : Bus 50197	: V=1.0183185, theta=2.143018 -> V=1.0, theta=0.0
% INFO    : Bus 50198	: V=1.02, theta=16.497793 -> V=1.0, theta=0.0
% INFO    : Bus 50199	: V=1.02, theta=1.807647 -> V=1.0, theta=0.0
% INFO    : Bus 50200	: V=1.0199861, theta=-1.701894 -> V=1.0, theta=0.0
% INFO    : Bus 50201	: V=1.0199838, theta=-1.706638 -> V=1.0, theta=0.0
% INFO    : Bus 50202	: V=1.0114931, theta=16.388141 -> V=1.0, theta=0.0
% INFO    : Bus 50203	: V=1.0189023, theta=20.24396 -> V=1.0, theta=0.0
% INFO    : Bus 50204	: V=1.02, theta=16.563077 -> V=1.0, theta=0.0
% INFO    : Bus 50205	: V=1.0061717, theta=4.40135 -> V=1.0, theta=0.0
% INFO    : Bus 50206	: V=1.0161887, theta=-4.281897 -> V=1.0, theta=0.0
% INFO    : Bus 50207	: V=1.02, theta=-39.061998 -> V=1.0, theta=0.0
% INFO    : Bus 50208	: V=1.02, theta=-1.478664 -> V=1.0, theta=0.0
% INFO    : Bus 50209	: V=1.02, theta=7.048125 -> V=1.0, theta=0.0
% INFO    : Bus 50210	: V=1.02, theta=1.015309 -> V=1.0, theta=0.0
% INFO    : Bus 50211	: V=1.02, theta=-30.260972 -> V=1.0, theta=0.0
% INFO    : Bus 50212	: V=1.0006371, theta=-1.58261 -> V=1.0, theta=0.0
% INFO    : Bus 50213	: V=1.0077173, theta=-18.055262 -> V=1.0, theta=0.0
% INFO    : Bus 50214	: V=1.0156659, theta=-33.915334 -> V=1.0, theta=0.0
% INFO    : Bus 50215	: V=1.02, theta=5.830863 -> V=1.0, theta=0.0
% INFO    : Bus 50216	: V=1.0181118, theta=-12.062152 -> V=1.0, theta=0.0
% INFO    : Bus 50217	: V=0.9942462, theta=-11.698255 -> V=1.0, theta=0.0
% INFO    : Bus 50218	: V=1.0031138, theta=4.309766 -> V=1.0, theta=0.0
% INFO    : Bus 50219	: V=1.02, theta=-29.356698 -> V=1.0, theta=0.0
% INFO    : Bus 50220	: V=1.0144558, theta=-11.911174 -> V=1.0, theta=0.0
% INFO    : Bus 50221	: V=1.0127946, theta=-12.397489 -> V=1.0, theta=0.0
% INFO    : Bus 50222	: V=1.0292956, theta=-25.124078 -> V=1.0, theta=0.0
% INFO    : Bus 50223	: V=1.02, theta=-15.02778 -> V=1.0, theta=0.0
% INFO    : Bus 50224	: V=1.0169085, theta=-30.655389 -> V=1.0, theta=0.0
% INFO    : Bus 50225	: V=1.0090757, theta=3.985593 -> V=1.0, theta=0.0
% INFO    : Bus 50226	: V=1.02, theta=-43.931313 -> V=1.0, theta=0.0
% INFO    : Bus 50227	: V=0.993701, theta=-11.37941 -> V=1.0, theta=0.0
% INFO    : Bus 50228	: V=1.0069897, theta=-40.983417 -> V=1.0, theta=0.0
% INFO    : Bus 50229	: V=1.0177372, theta=-0.933793 -> V=1.0, theta=0.0
% INFO    : Bus 50230	: V=1.02, theta=-43.099234 -> V=1.0, theta=0.0
% INFO    : Bus 50231	: V=1.0044525, theta=3.252443 -> V=1.0, theta=0.0
% INFO    : Bus 50232	: V=1.0155315, theta=-34.385475 -> V=1.0, theta=0.0
% INFO    : Bus 50233	: V=1.0185125, theta=-34.57148 -> V=1.0, theta=0.0
% INFO    : Bus 50234	: V=0.9939111, theta=2.098513 -> V=1.0, theta=0.0
% INFO    : Bus 50235	: V=1.0156193, theta=-41.342527 -> V=1.0, theta=0.0
% INFO    : Bus 50236	: V=1.0164437, theta=-42.232882 -> V=1.0, theta=0.0
% INFO    : Bus 50237	: V=1.010613, theta=-6.719036 -> V=1.0, theta=0.0
% INFO    : Bus 50238	: V=1.02, theta=-33.036 -> V=1.0, theta=0.0
% INFO    : Bus 50239	: V=1.02, theta=-41.297364 -> V=1.0, theta=0.0
% INFO    : Bus 50240	: V=1.02, theta=-31.385467 -> V=1.0, theta=0.0
% INFO    : Bus 50241	: V=1.02, theta=-33.669448 -> V=1.0, theta=0.0
% INFO    : Bus 50242	: V=1.02, theta=-48.337073 -> V=1.0, theta=0.0
% INFO    : Bus 50243	: V=1.02, theta=-47.966427 -> V=1.0, theta=0.0
% INFO    : Bus 50244	: V=1.02, theta=-45.629981 -> V=1.0, theta=0.0
% INFO    : Bus 50245	: V=1.02, theta=-36.701646 -> V=1.0, theta=0.0
% INFO    : Bus 50246	: V=1.0020185, theta=-52.758319 -> V=1.0, theta=0.0
% INFO    : Bus 50247	: V=1.02, theta=-31.363686 -> V=1.0, theta=0.0
% INFO    : Bus 50248	: V=1.02, theta=-35.162065 -> V=1.0, theta=0.0
% INFO    : Bus 50249	: V=1.02, theta=-38.115852 -> V=1.0, theta=0.0
% INFO    : Bus 50250	: V=1.02, theta=-55.507127 -> V=1.0, theta=0.0
% INFO    : Bus 50251	: V=1.0185171, theta=-59.611343 -> V=1.0, theta=0.0
% INFO    : Bus 50252	: V=1.02, theta=-51.639746 -> V=1.0, theta=0.0
% INFO    : Bus 50253	: V=1.0216558, theta=-51.3432 -> V=1.0, theta=0.0
% INFO    : Bus 50254	: V=1.02, theta=-55.237112 -> V=1.0, theta=0.0
% INFO    : Bus 50255	: V=0.9911623, theta=-55.1004 -> V=1.0, theta=0.0
% INFO    : Bus 50256	: V=1.0124999, theta=-62.634335 -> V=1.0, theta=0.0
% INFO    : Bus 50257	: V=1.02, theta=-52.58265 -> V=1.0, theta=0.0
% INFO    : Bus 50258	: V=1.0076746, theta=-37.706879 -> V=1.0, theta=0.0
% INFO    : Bus 50259	: V=1.0220629, theta=-50.878676 -> V=1.0, theta=0.0
% INFO    : Bus 50260	: V=1.02, theta=-54.687256 -> V=1.0, theta=0.0
% INFO    : Bus 50261	: V=1.02, theta=-36.709628 -> V=1.0, theta=0.0
% INFO    : Bus 50262	: V=1.0064386, theta=-63.324986 -> V=1.0, theta=0.0
% INFO    : Bus 50263	: V=1.0183492, theta=-59.627236 -> V=1.0, theta=0.0
% INFO    : Bus 50264	: V=1.02, theta=-56.485656 -> V=1.0, theta=0.0
% INFO    : Bus 50265	: V=1.0130939, theta=-50.301827 -> V=1.0, theta=0.0
% INFO    : Bus 50266	: V=1.0078853, theta=-39.433556 -> V=1.0, theta=0.0
% INFO    : Bus 50267	: V=0.9766892, theta=-53.156883 -> V=1.0, theta=0.0
% INFO    : Bus 50268	: V=1.0086494, theta=-48.674082 -> V=1.0, theta=0.0
% INFO    : Bus 50269	: V=0.9817786, theta=-49.220056 -> V=1.0, theta=0.0
% INFO    : Bus 50270	: V=1.02, theta=-52.723328 -> V=1.0, theta=0.0
% INFO    : Bus 50271	: V=0.9989621, theta=-44.159375 -> V=1.0, theta=0.0
% INFO    : Bus 50272	: V=1.02, theta=-53.164885 -> V=1.0, theta=0.0
% INFO    : Bus 50273	: V=1.0199007, theta=-56.513995 -> V=1.0, theta=0.0
% INFO    : Bus 50274	: V=0.9963084, theta=-34.754637 -> V=1.0, theta=0.0
% INFO    : Bus 50275	: V=1.02, theta=-31.179024 -> V=1.0, theta=0.0
% INFO    : Bus 50276	: V=1.0039431, theta=-51.659379 -> V=1.0, theta=0.0
% INFO    : Bus 50277	: V=0.9958508, theta=-57.601244 -> V=1.0, theta=0.0
% INFO    : Bus 50278	: V=1.0044443, theta=-37.177941 -> V=1.0, theta=0.0
% INFO    : Bus 50279	: V=1.0086501, theta=-39.274567 -> V=1.0, theta=0.0
% INFO    : Bus 50280	: V=0.9929475, theta=-39.549295 -> V=1.0, theta=0.0
% INFO    : Bus 50281	: V=1.02, theta=-31.289086 -> V=1.0, theta=0.0
% INFO    : Bus 50282	: V=1.0018493, theta=-39.086124 -> V=1.0, theta=0.0
% INFO    : Bus 50283	: V=1.007464, theta=-37.899423 -> V=1.0, theta=0.0
% INFO    : Bus 50284	: V=1.0168461, theta=-49.300575 -> V=1.0, theta=0.0
% INFO    : Bus 50285	: V=1.02, theta=-34.107998 -> V=1.0, theta=0.0
% INFO    : Bus 50286	: V=0.9836875, theta=-44.926022 -> V=1.0, theta=0.0
% INFO    : Bus 50287	: V=1.02, theta=-51.959124 -> V=1.0, theta=0.0
% INFO    : Bus 50288	: V=1.0044162, theta=-45.627285 -> V=1.0, theta=0.0
% INFO    : Bus 50289	: V=1.0030517, theta=-31.33061 -> V=1.0, theta=0.0
% INFO    : Bus 50290	: V=1.0093587, theta=-36.878802 -> V=1.0, theta=0.0
% INFO    : Bus 50291	: V=1.02, theta=10.914823 -> V=1.0, theta=0.0
% INFO    : Bus 50292	: V=1.02, theta=9.997769 -> V=1.0, theta=0.0
% INFO    : Bus 50293	: V=1.0114438, theta=10.361305 -> V=1.0, theta=0.0
% INFO    : Bus 50294	: V=1.02, theta=-3.795419 -> V=1.0, theta=0.0
% INFO    : Bus 50295	: V=1.02, theta=4.930419 -> V=1.0, theta=0.0
% INFO    : Bus 50296	: V=1.02, theta=5.155917 -> V=1.0, theta=0.0
% INFO    : Bus 50297	: V=1.02, theta=10.946852 -> V=1.0, theta=0.0
% INFO    : Bus 50298	: V=0.9980717, theta=4.959416 -> V=1.0, theta=0.0
% INFO    : Bus 50299	: V=1.02, theta=-4.023257 -> V=1.0, theta=0.0
% INFO    : Bus 50300	: V=1.02, theta=-3.952785 -> V=1.0, theta=0.0
% INFO    : Bus 50301	: V=1.02, theta=10.75037 -> V=1.0, theta=0.0
% INFO    : Bus 50302	: V=1.0068639, theta=-0.945994 -> V=1.0, theta=0.0
% INFO    : Bus 50303	: V=1.02, theta=-2.53954 -> V=1.0, theta=0.0
% INFO    : Bus 50304	: V=1.02, theta=-2.267237 -> V=1.0, theta=0.0
% INFO    : Bus 50305	: V=1.0165146, theta=-2.434101 -> V=1.0, theta=0.0
% INFO    : Bus 50306	: V=0.9897421, theta=-0.189734 -> V=1.0, theta=0.0
% INFO    : Bus 50307	: V=1.0151897, theta=-3.916226 -> V=1.0, theta=0.0
% INFO    : Bus 50308	: V=1.0154944, theta=-1.803996 -> V=1.0, theta=0.0
% INFO    : Bus 50309	: V=1.0061188, theta=4.116946 -> V=1.0, theta=0.0
% INFO    : Bus 50310	: V=1.02, theta=-59.759963 -> V=1.0, theta=0.0
% INFO    : Bus 50311	: V=1.02, theta=-62.13072 -> V=1.0, theta=0.0
% INFO    : Bus 50312	: V=1.02, theta=-67.655812 -> V=1.0, theta=0.0
% INFO    : Bus 50313	: V=1.02, theta=-63.660598 -> V=1.0, theta=0.0
% INFO    : Bus 50314	: V=1.02, theta=-56.427239 -> V=1.0, theta=0.0
% INFO    : Bus 50315	: V=1.02, theta=-73.983905 -> V=1.0, theta=0.0
% INFO    : Bus 50316	: V=1.02, theta=-54.772042 -> V=1.0, theta=0.0
% INFO    : Bus 50317	: V=1.02, theta=-59.617956 -> V=1.0, theta=0.0
% INFO    : Bus 50318	: V=1.02, theta=-63.439081 -> V=1.0, theta=0.0
% INFO    : Bus 50319	: V=1.02, theta=-60.07158 -> V=1.0, theta=0.0
% INFO    : Bus 50320	: V=1.02, theta=-67.191789 -> V=1.0, theta=0.0
% INFO    : Bus 50321	: V=1.02, theta=-66.765238 -> V=1.0, theta=0.0
% INFO    : Bus 50322	: V=1.02, theta=-65.464943 -> V=1.0, theta=0.0
% INFO    : Bus 50323	: V=1.02, theta=-55.112502 -> V=1.0, theta=0.0
% INFO    : Bus 50324	: V=1.0199019, theta=-63.450773 -> V=1.0, theta=0.0
% INFO    : Bus 50325	: V=1.02, theta=-54.351269 -> V=1.0, theta=0.0
% INFO    : Bus 50326	: V=1.02, theta=-66.912004 -> V=1.0, theta=0.0
% INFO    : Bus 50327	: V=1.02, theta=-54.110252 -> V=1.0, theta=0.0
% INFO    : Bus 50328	: V=1.02, theta=-68.402567 -> V=1.0, theta=0.0
% INFO    : Bus 50329	: V=1.0171736, theta=-69.884901 -> V=1.0, theta=0.0
% INFO    : Bus 50330	: V=1.0149415, theta=-75.134785 -> V=1.0, theta=0.0
% INFO    : Bus 50331	: V=1.0203162, theta=-66.890762 -> V=1.0, theta=0.0
% INFO    : Bus 50332	: V=1.02, theta=-66.956439 -> V=1.0, theta=0.0
% INFO    : Bus 50333	: V=1.0202472, theta=-66.895119 -> V=1.0, theta=0.0
% INFO    : Bus 50334	: V=1.02, theta=-65.604336 -> V=1.0, theta=0.0
% INFO    : Bus 50335	: V=1.0084246, theta=-72.461902 -> V=1.0, theta=0.0
% INFO    : Bus 50336	: V=1.0032131, theta=-71.04791 -> V=1.0, theta=0.0
% INFO    : Bus 50337	: V=1.02, theta=-55.452585 -> V=1.0, theta=0.0
% INFO    : Bus 50338	: V=0.9984259, theta=-73.682803 -> V=1.0, theta=0.0
% INFO    : Bus 50339	: V=1.02, theta=-58.088937 -> V=1.0, theta=0.0
% INFO    : Bus 50340	: V=1.02, theta=-57.197699 -> V=1.0, theta=0.0
% INFO    : Bus 50341	: V=1.02, theta=-72.680535 -> V=1.0, theta=0.0
% INFO    : Bus 50342	: V=1.02, theta=-61.194625 -> V=1.0, theta=0.0
% INFO    : Bus 50343	: V=1.02, theta=-43.785941 -> V=1.0, theta=0.0
% INFO    : Bus 50344	: V=1.02, theta=-56.625419 -> V=1.0, theta=0.0
% INFO    : Bus 50345	: V=1.02, theta=-56.914323 -> V=1.0, theta=0.0
% INFO    : Bus 50346	: V=1.0184437, theta=-63.180943 -> V=1.0, theta=0.0
% INFO    : Bus 50347	: V=1.02, theta=-63.800657 -> V=1.0, theta=0.0
% INFO    : Bus 50348	: V=1.02, theta=-66.1889 -> V=1.0, theta=0.0
% INFO    : Bus 50349	: V=1.02, theta=-40.933099 -> V=1.0, theta=0.0
% INFO    : Bus 50350	: V=1.02, theta=-67.424428 -> V=1.0, theta=0.0
% INFO    : Bus 50351	: V=1.0192933, theta=-67.212059 -> V=1.0, theta=0.0
% INFO    : Bus 50352	: V=1.0205641, theta=-44.291048 -> V=1.0, theta=0.0
% INFO    : Bus 50353	: V=0.9944415, theta=-76.305469 -> V=1.0, theta=0.0
% INFO    : Bus 50354	: V=1.02, theta=-44.877512 -> V=1.0, theta=0.0
% INFO    : Bus 50355	: V=1.02, theta=-74.000785 -> V=1.0, theta=0.0
% INFO    : Bus 50356	: V=1.02, theta=-44.574184 -> V=1.0, theta=0.0
% INFO    : Bus 50357	: V=1.02, theta=-67.553063 -> V=1.0, theta=0.0
% INFO    : Bus 50358	: V=1.02, theta=-56.551971 -> V=1.0, theta=0.0
% INFO    : Bus 50359	: V=1.0196991, theta=-57.735201 -> V=1.0, theta=0.0
% INFO    : Bus 50360	: V=1.02, theta=-57.874903 -> V=1.0, theta=0.0
% INFO    : Bus 50361	: V=1.0194355, theta=-67.245252 -> V=1.0, theta=0.0
% INFO    : Bus 50362	: V=1.02, theta=-50.298616 -> V=1.0, theta=0.0
% INFO    : Bus 50363	: V=1.0178646, theta=-48.488783 -> V=1.0, theta=0.0
% INFO    : Bus 50364	: V=1.02, theta=-48.427863 -> V=1.0, theta=0.0
% INFO    : Bus 50365	: V=1.02, theta=-60.564666 -> V=1.0, theta=0.0
% INFO    : Bus 50366	: V=1.02, theta=-57.690744 -> V=1.0, theta=0.0
% INFO    : Bus 50367	: V=1.02, theta=-65.957898 -> V=1.0, theta=0.0
% INFO    : Bus 50368	: V=1.02, theta=-68.68999 -> V=1.0, theta=0.0
% INFO    : Bus 50369	: V=1.02, theta=-44.662189 -> V=1.0, theta=0.0
% INFO    : Bus 50370	: V=1.02, theta=-60.457953 -> V=1.0, theta=0.0
% INFO    : Bus 50371	: V=1.02, theta=-66.486692 -> V=1.0, theta=0.0
% INFO    : Bus 50372	: V=1.02, theta=-74.826837 -> V=1.0, theta=0.0
% INFO    : Bus 50373	: V=1.02, theta=-57.733169 -> V=1.0, theta=0.0
% INFO    : Bus 50374	: V=1.02, theta=-56.925737 -> V=1.0, theta=0.0
% INFO    : Bus 50375	: V=1.02, theta=-66.722744 -> V=1.0, theta=0.0
% INFO    : Bus 50376	: V=1.02, theta=-67.096064 -> V=1.0, theta=0.0
% INFO    : Bus 50377	: V=1.0181419, theta=-74.928094 -> V=1.0, theta=0.0
% INFO    : Bus 50378	: V=1.02, theta=-69.889954 -> V=1.0, theta=0.0
% INFO    : Bus 50379	: V=1.02, theta=-58.181412 -> V=1.0, theta=0.0
% INFO    : Bus 50380	: V=1.02, theta=-54.155053 -> V=1.0, theta=0.0
% INFO    : Bus 50381	: V=1.017322, theta=-74.824963 -> V=1.0, theta=0.0
% INFO    : Bus 50382	: V=1.0064447, theta=-69.676218 -> V=1.0, theta=0.0
% INFO    : Bus 50383	: V=1.0245764, theta=-56.821912 -> V=1.0, theta=0.0
% INFO    : Bus 50384	: V=1.0116596, theta=-60.508494 -> V=1.0, theta=0.0
% INFO    : Bus 50385	: V=1.0201104, theta=-73.972379 -> V=1.0, theta=0.0
% INFO    : Bus 50386	: V=1.0090503, theta=-65.591297 -> V=1.0, theta=0.0
% INFO    : Bus 50387	: V=1.02, theta=-58.278563 -> V=1.0, theta=0.0
% INFO    : Bus 50388	: V=1.02, theta=-61.873822 -> V=1.0, theta=0.0
% INFO    : Bus 50389	: V=1.02, theta=-54.881463 -> V=1.0, theta=0.0
% INFO    : Bus 50390	: V=1.02, theta=-67.08474 -> V=1.0, theta=0.0
% INFO    : Bus 50391	: V=0.9982866, theta=-74.392914 -> V=1.0, theta=0.0
% INFO    : Bus 50392	: V=1.02, theta=-67.496608 -> V=1.0, theta=0.0
% INFO    : Bus 50393	: V=1.02, theta=-54.865322 -> V=1.0, theta=0.0
% INFO    : Bus 50394	: V=1.02, theta=-61.623635 -> V=1.0, theta=0.0
% INFO    : Bus 50395	: V=1.02, theta=-54.117693 -> V=1.0, theta=0.0
% INFO    : Bus 50396	: V=1.02, theta=-66.982834 -> V=1.0, theta=0.0
% INFO    : Bus 50397	: V=1.02, theta=-45.267878 -> V=1.0, theta=0.0
% INFO    : Bus 50398	: V=1.02, theta=-57.492973 -> V=1.0, theta=0.0
% INFO    : Bus 50399	: V=1.02, theta=-56.702563 -> V=1.0, theta=0.0
% INFO    : Bus 50400	: V=1.02, theta=-62.512888 -> V=1.0, theta=0.0
% INFO    : Bus 50401	: V=1.02, theta=-55.634349 -> V=1.0, theta=0.0
% INFO    : Bus 50402	: V=1.02, theta=-55.044931 -> V=1.0, theta=0.0
% INFO    : Bus 50403	: V=1.02, theta=-71.16946 -> V=1.0, theta=0.0
% INFO    : Bus 50404	: V=1.02, theta=-42.358753 -> V=1.0, theta=0.0
% INFO    : Bus 50405	: V=1.0175151, theta=-60.815179 -> V=1.0, theta=0.0
% INFO    : Bus 50406	: V=1.02, theta=-74.27914 -> V=1.0, theta=0.0
% INFO    : Bus 50407	: V=1.02, theta=-65.87955 -> V=1.0, theta=0.0
% INFO    : Bus 50408	: V=1.02, theta=-57.202605 -> V=1.0, theta=0.0
% INFO    : Bus 50409	: V=1.02, theta=-52.558331 -> V=1.0, theta=0.0
% INFO    : Bus 50410	: V=1.0192347, theta=-61.91219 -> V=1.0, theta=0.0
% INFO    : Bus 50411	: V=1.02, theta=-55.971803 -> V=1.0, theta=0.0
% INFO    : Bus 50412	: V=1.02, theta=-50.415703 -> V=1.0, theta=0.0
% INFO    : Bus 50413	: V=1.02, theta=-65.26674 -> V=1.0, theta=0.0
% INFO    : Bus 50414	: V=0.9926314, theta=-71.292882 -> V=1.0, theta=0.0
% INFO    : Bus 50415	: V=1.0205263, theta=-44.259322 -> V=1.0, theta=0.0
% INFO    : Bus 50416	: V=1.026221, theta=-57.050811 -> V=1.0, theta=0.0
% INFO    : Bus 50417	: V=1.026393, theta=-59.270635 -> V=1.0, theta=0.0
% INFO    : Bus 50418	: V=1.02, theta=-56.95591 -> V=1.0, theta=0.0
% INFO    : Bus 50419	: V=1.02, theta=-65.566659 -> V=1.0, theta=0.0
% INFO    : Bus 50420	: V=1.02, theta=-65.593645 -> V=1.0, theta=0.0
% INFO    : Bus 50421	: V=1.02, theta=-52.321741 -> V=1.0, theta=0.0
% INFO    : Bus 50422	: V=1.0199936, theta=-66.486846 -> V=1.0, theta=0.0
% INFO    : Bus 50423	: V=1.0040236, theta=-72.675309 -> V=1.0, theta=0.0
% INFO    : Bus 50424	: V=1.02, theta=-41.556827 -> V=1.0, theta=0.0
% INFO    : Bus 50425	: V=1.02, theta=-67.921937 -> V=1.0, theta=0.0
% INFO    : Bus 50426	: V=1.02, theta=-47.312669 -> V=1.0, theta=0.0
% INFO    : Bus 50427	: V=1.02, theta=-43.538159 -> V=1.0, theta=0.0
% INFO    : Bus 50428	: V=1.02, theta=-49.782067 -> V=1.0, theta=0.0
% INFO    : Bus 50429	: V=1.0066898, theta=-68.868079 -> V=1.0, theta=0.0
% INFO    : Bus 50430	: V=1.02, theta=-50.802631 -> V=1.0, theta=0.0
% INFO    : Bus 50431	: V=1.0199648, theta=-45.442623 -> V=1.0, theta=0.0
% INFO    : Bus 50432	: V=1.0048764, theta=-54.032479 -> V=1.0, theta=0.0
% INFO    : Bus 50433	: V=1.02, theta=-45.895426 -> V=1.0, theta=0.0
% INFO    : Bus 50434	: V=1.0197371, theta=-58.768704 -> V=1.0, theta=0.0
% INFO    : Bus 50435	: V=1.02, theta=-56.433684 -> V=1.0, theta=0.0
% INFO    : Bus 50436	: V=1.02, theta=-50.120506 -> V=1.0, theta=0.0
% INFO    : Bus 50437	: V=1.02, theta=-45.434052 -> V=1.0, theta=0.0
% INFO    : Bus 50438	: V=1.02, theta=-55.305269 -> V=1.0, theta=0.0
% INFO    : Bus 50439	: V=1.02, theta=-55.516508 -> V=1.0, theta=0.0
% INFO    : Bus 50440	: V=1.0183902, theta=-68.836548 -> V=1.0, theta=0.0
% INFO    : Bus 50441	: V=1.02, theta=-47.373914 -> V=1.0, theta=0.0
% INFO    : Bus 50442	: V=1.0198666, theta=-74.282267 -> V=1.0, theta=0.0
% INFO    : Bus 50443	: V=1.0196329, theta=-61.957612 -> V=1.0, theta=0.0
% INFO    : Bus 50444	: V=1.0129959, theta=-67.379173 -> V=1.0, theta=0.0
% INFO    : Bus 50445	: V=1.0125103, theta=-69.020517 -> V=1.0, theta=0.0
% INFO    : Bus 50446	: V=1.019659, theta=-45.227267 -> V=1.0, theta=0.0
% INFO    : Bus 50447	: V=1.02, theta=-43.803642 -> V=1.0, theta=0.0
% INFO    : Bus 50448	: V=1.0029227, theta=-69.603051 -> V=1.0, theta=0.0
% INFO    : Bus 50449	: V=1.02, theta=-68.556704 -> V=1.0, theta=0.0
% INFO    : Bus 50450	: V=1.02, theta=-43.179695 -> V=1.0, theta=0.0
% INFO    : Bus 50451	: V=1.02, theta=-49.997805 -> V=1.0, theta=0.0
% INFO    : Bus 50452	: V=1.02, theta=-41.875206 -> V=1.0, theta=0.0
% INFO    : Bus 50453	: V=1.02, theta=-56.086759 -> V=1.0, theta=0.0
% INFO    : Bus 50454	: V=1.02, theta=-63.485198 -> V=1.0, theta=0.0
% INFO    : Bus 50455	: V=1.0155413, theta=-74.789499 -> V=1.0, theta=0.0
% INFO    : Bus 50456	: V=1.02, theta=-55.287941 -> V=1.0, theta=0.0
% INFO    : Bus 50457	: V=1.0147526, theta=-69.847553 -> V=1.0, theta=0.0
% INFO    : Bus 50458	: V=1.02, theta=-70.771379 -> V=1.0, theta=0.0
% INFO    : Bus 50459	: V=0.9985455, theta=-73.629667 -> V=1.0, theta=0.0
% INFO    : Bus 50460	: V=1.0158111, theta=-75.304922 -> V=1.0, theta=0.0
% INFO    : Bus 50461	: V=1.02, theta=-74.884735 -> V=1.0, theta=0.0
% INFO    : Bus 50462	: V=1.02, theta=-50.904677 -> V=1.0, theta=0.0
% INFO    : Bus 50463	: V=0.9969388, theta=-69.36081 -> V=1.0, theta=0.0
% INFO    : Bus 50464	: V=1.02, theta=-58.23327 -> V=1.0, theta=0.0
% INFO    : Bus 50465	: V=1.0095191, theta=-68.877403 -> V=1.0, theta=0.0
% INFO    : Bus 50466	: V=0.9977118, theta=-74.04561 -> V=1.0, theta=0.0
% INFO    : Bus 50467	: V=1.02, theta=-41.471504 -> V=1.0, theta=0.0
% INFO    : Bus 50468	: V=1.015055, theta=-56.697319 -> V=1.0, theta=0.0
% INFO    : Bus 50469	: V=1.0184563, theta=-55.906396 -> V=1.0, theta=0.0
% INFO    : Bus 50470	: V=1.02, theta=-68.791957 -> V=1.0, theta=0.0
% INFO    : Bus 50471	: V=1.02, theta=-56.302665 -> V=1.0, theta=0.0
% INFO    : Bus 50472	: V=1.02, theta=-74.260103 -> V=1.0, theta=0.0
% INFO    : Bus 50473	: V=1.02, theta=-56.749826 -> V=1.0, theta=0.0
% INFO    : Bus 50474	: V=1.02, theta=-50.768836 -> V=1.0, theta=0.0
% INFO    : Bus 50475	: V=0.998542, theta=-76.565727 -> V=1.0, theta=0.0
% INFO    : Bus 50476	: V=1.02, theta=-57.279939 -> V=1.0, theta=0.0
% INFO    : Bus 50477	: V=1.02, theta=-54.845983 -> V=1.0, theta=0.0
% INFO    : Bus 50478	: V=1.02, theta=-44.661127 -> V=1.0, theta=0.0
% INFO    : Bus 50479	: V=1.0196801, theta=-75.111607 -> V=1.0, theta=0.0
% INFO    : Bus 50480	: V=1.0201605, theta=-47.761031 -> V=1.0, theta=0.0
% INFO    : Bus 50481	: V=1.02, theta=-59.932762 -> V=1.0, theta=0.0
% INFO    : Bus 50482	: V=1.015638, theta=-60.949652 -> V=1.0, theta=0.0
% INFO    : Bus 50483	: V=1.0145425, theta=-48.127546 -> V=1.0, theta=0.0
% INFO    : Bus 50484	: V=0.9700323, theta=-73.640682 -> V=1.0, theta=0.0
% INFO    : Bus 50485	: V=1.0200433, theta=-67.075724 -> V=1.0, theta=0.0
% INFO    : Bus 50486	: V=1.02, theta=-47.199536 -> V=1.0, theta=0.0
% INFO    : Bus 50487	: V=1.0170517, theta=-68.191543 -> V=1.0, theta=0.0
% INFO    : Bus 50488	: V=1.02, theta=-57.657379 -> V=1.0, theta=0.0
% INFO    : Bus 50489	: V=0.9806655, theta=-58.669537 -> V=1.0, theta=0.0
% INFO    : Bus 50490	: V=1.0135802, theta=-59.264535 -> V=1.0, theta=0.0
% INFO    : Bus 50491	: V=1.0141668, theta=-75.1016 -> V=1.0, theta=0.0
% INFO    : Bus 50492	: V=1.02, theta=-50.802227 -> V=1.0, theta=0.0
% INFO    : Bus 50493	: V=1.0125998, theta=-68.769223 -> V=1.0, theta=0.0
% INFO    : Bus 50494	: V=0.9945263, theta=-71.364812 -> V=1.0, theta=0.0
% INFO    : Bus 50495	: V=0.9997776, theta=-75.611341 -> V=1.0, theta=0.0
% INFO    : Bus 50496	: V=0.9885559, theta=-67.528994 -> V=1.0, theta=0.0
% INFO    : Bus 50497	: V=1.0035412, theta=-73.478195 -> V=1.0, theta=0.0
% INFO    : Bus 50498	: V=0.9930291, theta=-59.686021 -> V=1.0, theta=0.0
% INFO    : Bus 50499	: V=1.0197567, theta=-67.607499 -> V=1.0, theta=0.0
% INFO    : Bus 50500	: V=1.0026535, theta=-76.756852 -> V=1.0, theta=0.0
% INFO    : Bus 50501	: V=1.0194676, theta=-69.034303 -> V=1.0, theta=0.0
% INFO    : Bus 50502	: V=1.0245729, theta=-57.234039 -> V=1.0, theta=0.0
% INFO    : Bus 50503	: V=1.02, theta=-69.632917 -> V=1.0, theta=0.0
% INFO    : Bus 50504	: V=1.02, theta=-56.811273 -> V=1.0, theta=0.0
% INFO    : Bus 50505	: V=1.02, theta=-54.879086 -> V=1.0, theta=0.0
% INFO    : Bus 50506	: V=0.9600945, theta=-78.47817 -> V=1.0, theta=0.0
% INFO    : Bus 50507	: V=1.000878, theta=-60.284326 -> V=1.0, theta=0.0
% INFO    : Bus 50508	: V=1.0014449, theta=-72.881531 -> V=1.0, theta=0.0
% INFO    : Bus 50509	: V=1.0043143, theta=-59.861328 -> V=1.0, theta=0.0
% INFO    : Bus 50510	: V=0.9987867, theta=-74.190922 -> V=1.0, theta=0.0
% INFO    : Bus 50511	: V=1.0056741, theta=-69.25011 -> V=1.0, theta=0.0
% INFO    : Bus 50512	: V=1.0146055, theta=-61.767251 -> V=1.0, theta=0.0
% INFO    : Bus 50513	: V=0.9976083, theta=-61.864646 -> V=1.0, theta=0.0
% INFO    : Bus 50514	: V=1.0187152, theta=-55.209332 -> V=1.0, theta=0.0
% INFO    : Bus 50515	: V=1.02, theta=-74.816782 -> V=1.0, theta=0.0
% INFO    : Bus 50516	: V=0.9960654, theta=-69.110972 -> V=1.0, theta=0.0
% INFO    : Bus 50517	: V=1.0131394, theta=-68.876431 -> V=1.0, theta=0.0
% INFO    : Bus 50518	: V=1.0090104, theta=-69.515717 -> V=1.0, theta=0.0
% INFO    : Bus 50519	: V=1.0105833, theta=-68.995407 -> V=1.0, theta=0.0
% INFO    : Bus 50520	: V=1.02, theta=-56.477138 -> V=1.0, theta=0.0
% INFO    : Bus 50521	: V=1.0148297, theta=-68.380083 -> V=1.0, theta=0.0
% INFO    : Bus 50522	: V=1.0191568, theta=-56.915235 -> V=1.0, theta=0.0
% INFO    : Bus 50523	: V=1.02, theta=-44.787205 -> V=1.0, theta=0.0
% INFO    : Bus 50524	: V=1.0152214, theta=-67.804826 -> V=1.0, theta=0.0
% INFO    : Bus 50525	: V=0.9997914, theta=-57.658095 -> V=1.0, theta=0.0
% INFO    : Bus 50526	: V=0.9676947, theta=-79.314596 -> V=1.0, theta=0.0
% INFO    : Bus 50527	: V=1.0198213, theta=-51.139308 -> V=1.0, theta=0.0
% INFO    : Bus 50528	: V=1.0015806, theta=-67.037634 -> V=1.0, theta=0.0
% INFO    : Bus 50529	: V=1.015682, theta=-65.349002 -> V=1.0, theta=0.0
% INFO    : Bus 50530	: V=1.02, theta=-67.896559 -> V=1.0, theta=0.0
% INFO    : Bus 50531	: V=1.02, theta=-56.908122 -> V=1.0, theta=0.0
% INFO    : Bus 50532	: V=1.0165533, theta=-58.442141 -> V=1.0, theta=0.0
% INFO    : Bus 50533	: V=0.9818993, theta=-68.235304 -> V=1.0, theta=0.0
% INFO    : Bus 50534	: V=1.02, theta=-75.167825 -> V=1.0, theta=0.0
% INFO    : Bus 50535	: V=1.02, theta=-65.0602 -> V=1.0, theta=0.0
% INFO    : Bus 50536	: V=0.9900876, theta=-53.289267 -> V=1.0, theta=0.0
% INFO    : Bus 50537	: V=1.0143462, theta=-75.540627 -> V=1.0, theta=0.0
% INFO    : Bus 50538	: V=1.0199698, theta=-57.227039 -> V=1.0, theta=0.0
% INFO    : Bus 50539	: V=1.0180869, theta=-61.818648 -> V=1.0, theta=0.0
% INFO    : Bus 50540	: V=0.989795, theta=-67.724015 -> V=1.0, theta=0.0
% INFO    : Bus 50541	: V=1.0143508, theta=-55.778929 -> V=1.0, theta=0.0
% INFO    : Bus 50542	: V=0.9815736, theta=-60.940319 -> V=1.0, theta=0.0
% INFO    : Bus 50543	: V=1.02, theta=-61.338632 -> V=1.0, theta=0.0
% INFO    : Bus 50544	: V=1.0117119, theta=-70.290986 -> V=1.0, theta=0.0
% INFO    : Bus 50545	: V=1.0092054, theta=-66.798838 -> V=1.0, theta=0.0
% INFO    : Bus 50546	: V=1.000539, theta=-71.498914 -> V=1.0, theta=0.0
% INFO    : Bus 50547	: V=1.0185953, theta=-56.911533 -> V=1.0, theta=0.0
% INFO    : Bus 50548	: V=1.0163473, theta=-58.432421 -> V=1.0, theta=0.0
% INFO    : Bus 50549	: V=0.9877738, theta=-64.786919 -> V=1.0, theta=0.0
% INFO    : Bus 50550	: V=0.9874367, theta=-18.603741 -> V=1.0, theta=0.0
% INFO    : Bus 50551	: V=0.993032, theta=-20.257226 -> V=1.0, theta=0.0
% INFO    : Bus 50552	: V=0.9770237, theta=-20.019884 -> V=1.0, theta=0.0
% INFO    : Bus 50553	: V=0.9896448, theta=-20.472802 -> V=1.0, theta=0.0
% INFO    : Bus 50554	: V=0.9880192, theta=-20.745494 -> V=1.0, theta=0.0
% INFO    : Bus 50555	: V=0.9854443, theta=-16.168276 -> V=1.0, theta=0.0
% INFO    : Bus 50556	: V=0.9731347, theta=-18.445692 -> V=1.0, theta=0.0
% INFO    : Bus 50557	: V=1.0124726, theta=-7.225059 -> V=1.0, theta=0.0
% INFO    : Bus 50558	: V=0.9951436, theta=-7.501703 -> V=1.0, theta=0.0
% INFO    : Bus 50559	: V=1.0128432, theta=-6.712247 -> V=1.0, theta=0.0
% INFO    : Bus 50560	: V=1.013071, theta=-6.580468 -> V=1.0, theta=0.0
% INFO    : Bus 50561	: V=0.9914451, theta=-46.921875 -> V=1.0, theta=0.0
% INFO    : Bus 50562	: V=0.9930863, theta=-48.298733 -> V=1.0, theta=0.0
% INFO    : Bus 50563	: V=0.9967621, theta=-43.791936 -> V=1.0, theta=0.0
% INFO    : Bus 50564	: V=0.995029, theta=-46.244187 -> V=1.0, theta=0.0
% INFO    : Bus 50565	: V=0.9986449, theta=-45.255283 -> V=1.0, theta=0.0
% INFO    : Bus 50566	: V=1.0034362, theta=-45.049152 -> V=1.0, theta=0.0
% INFO    : Bus 50567	: V=1.0139969, theta=-43.977978 -> V=1.0, theta=0.0
% INFO    : Bus 50568	: V=1.0038544, theta=-45.061387 -> V=1.0, theta=0.0
% INFO    : Bus 50569	: V=1.0043515, theta=-45.031007 -> V=1.0, theta=0.0
% INFO    : Bus 50570	: V=1.0111333, theta=-43.934303 -> V=1.0, theta=0.0
% INFO    : Bus 50571	: V=0.9856102, theta=-15.356119 -> V=1.0, theta=0.0
% INFO    : Bus 50572	: V=0.9765237, theta=-17.305402 -> V=1.0, theta=0.0
% INFO    : Bus 50573	: V=0.9735641, theta=-15.76062 -> V=1.0, theta=0.0
% INFO    : Bus 50574	: V=0.9876665, theta=-15.25236 -> V=1.0, theta=0.0
% INFO    : Bus 50575	: V=0.9775601, theta=-15.634534 -> V=1.0, theta=0.0
% INFO    : Bus 50576	: V=0.9970655, theta=-8.650613 -> V=1.0, theta=0.0
% INFO    : Bus 50577	: V=1.0129339, theta=-6.412548 -> V=1.0, theta=0.0
% INFO    : Bus 50578	: V=1.0032325, theta=-7.678586 -> V=1.0, theta=0.0
% INFO    : Bus 50579	: V=0.9805969, theta=-32.794682 -> V=1.0, theta=0.0
% INFO    : Bus 50580	: V=0.9791023, theta=-34.931941 -> V=1.0, theta=0.0
% INFO    : Bus 50581	: V=0.9757132, theta=-38.117891 -> V=1.0, theta=0.0
% INFO    : Bus 50582	: V=0.9763751, theta=-37.544718 -> V=1.0, theta=0.0
% INFO    : Bus 50583	: V=0.9663163, theta=-34.61807 -> V=1.0, theta=0.0
% INFO    : Bus 50584	: V=0.9691139, theta=-34.612075 -> V=1.0, theta=0.0
% INFO    : Bus 50585	: V=0.9778919, theta=-34.024045 -> V=1.0, theta=0.0
% INFO    : Bus 50586	: V=0.9613177, theta=-38.004742 -> V=1.0, theta=0.0
% INFO    : Bus 50587	: V=0.979737, theta=-35.659544 -> V=1.0, theta=0.0
% INFO    : Bus 50588	: V=0.9798026, theta=-36.026187 -> V=1.0, theta=0.0
% INFO    : Bus 50589	: V=0.9806572, theta=-35.787069 -> V=1.0, theta=0.0
% INFO    : Bus 50590	: V=0.9606813, theta=-39.93636 -> V=1.0, theta=0.0
% INFO    : Bus 50591	: V=0.9830811, theta=-35.981519 -> V=1.0, theta=0.0
% INFO    : Bus 50592	: V=0.9926, theta=-26.85806 -> V=1.0, theta=0.0
% INFO    : Bus 50593	: V=0.9645726, theta=-33.862256 -> V=1.0, theta=0.0
% INFO    : Bus 50594	: V=0.987177, theta=-23.41907 -> V=1.0, theta=0.0
% INFO    : Bus 50595	: V=0.9766457, theta=-24.493408 -> V=1.0, theta=0.0
% INFO    : Bus 50596	: V=0.981129, theta=-24.491266 -> V=1.0, theta=0.0
% INFO    : Bus 50597	: V=1.0052722, theta=-25.45553 -> V=1.0, theta=0.0
% INFO    : Bus 50598	: V=0.9887495, theta=-25.763527 -> V=1.0, theta=0.0
% INFO    : Bus 50599	: V=0.9868235, theta=-25.900573 -> V=1.0, theta=0.0
% INFO    : Bus 50600	: V=0.9733083, theta=-48.766314 -> V=1.0, theta=0.0
% INFO    : Bus 50601	: V=0.9927043, theta=-54.008598 -> V=1.0, theta=0.0
% INFO    : Bus 50602	: V=0.9880572, theta=-25.917431 -> V=1.0, theta=0.0
% INFO    : Bus 50603	: V=0.9859183, theta=-25.451573 -> V=1.0, theta=0.0
% INFO    : Bus 50604	: V=0.9972859, theta=-30.942668 -> V=1.0, theta=0.0
% INFO    : Bus 50605	: V=1.0135586, theta=-31.815322 -> V=1.0, theta=0.0
% INFO    : Bus 50606	: V=1.0148042, theta=-31.930859 -> V=1.0, theta=0.0
% INFO    : Bus 50607	: V=1.0068637, theta=-33.329893 -> V=1.0, theta=0.0
% INFO    : Bus 50608	: V=1.011275, theta=-19.66332 -> V=1.0, theta=0.0
% INFO    : Bus 50609	: V=1.0030735, theta=-20.44669 -> V=1.0, theta=0.0
% INFO    : Bus 50610	: V=1.0095481, theta=-20.970417 -> V=1.0, theta=0.0
% INFO    : Bus 50611	: V=1.0102104, theta=-51.834904 -> V=1.0, theta=0.0
% INFO    : Bus 50612	: V=0.9733707, theta=-36.670973 -> V=1.0, theta=0.0
% INFO    : Bus 50613	: V=0.9886423, theta=-36.090338 -> V=1.0, theta=0.0
% INFO    : Bus 50614	: V=1.0015218, theta=-36.196817 -> V=1.0, theta=0.0
% INFO    : Bus 50615	: V=1.0058223, theta=-35.422158 -> V=1.0, theta=0.0
% INFO    : Bus 50616	: V=1.0004871, theta=-34.971034 -> V=1.0, theta=0.0
% INFO    : Bus 50617	: V=1.0008471, theta=-35.33495 -> V=1.0, theta=0.0
% INFO    : Bus 50618	: V=0.9986175, theta=-37.892886 -> V=1.0, theta=0.0
% INFO    : Bus 50619	: V=1.0025854, theta=-37.169836 -> V=1.0, theta=0.0
% INFO    : Bus 50620	: V=0.9925268, theta=-38.258189 -> V=1.0, theta=0.0
% INFO    : Bus 50621	: V=0.9989366, theta=-37.927691 -> V=1.0, theta=0.0
% INFO    : Bus 50622	: V=1.0040549, theta=-37.787121 -> V=1.0, theta=0.0
% INFO    : Bus 50623	: V=0.9804693, theta=-19.101791 -> V=1.0, theta=0.0
% INFO    : Bus 50624	: V=0.9636477, theta=-20.081959 -> V=1.0, theta=0.0
% INFO    : Bus 50625	: V=0.9675892, theta=-19.859427 -> V=1.0, theta=0.0
% INFO    : Bus 50626	: V=0.9811832, theta=-20.715075 -> V=1.0, theta=0.0
% INFO    : Bus 50627	: V=0.9901951, theta=-18.38609 -> V=1.0, theta=0.0
% INFO    : Bus 50628	: V=0.9804161, theta=-20.647307 -> V=1.0, theta=0.0
% INFO    : Bus 50629	: V=0.9832205, theta=-21.600225 -> V=1.0, theta=0.0
% INFO    : Bus 50630	: V=0.9852351, theta=-22.400927 -> V=1.0, theta=0.0
% INFO    : Bus 50631	: V=0.9794617, theta=-21.142067 -> V=1.0, theta=0.0
% INFO    : Bus 50632	: V=0.978909, theta=-21.143481 -> V=1.0, theta=0.0
% INFO    : Bus 50633	: V=0.9791985, theta=-20.971907 -> V=1.0, theta=0.0
% INFO    : Bus 50634	: V=0.9848979, theta=-47.838888 -> V=1.0, theta=0.0
% INFO    : Bus 50635	: V=0.985375, theta=-47.547015 -> V=1.0, theta=0.0
% INFO    : Bus 50636	: V=0.9870104, theta=-28.100035 -> V=1.0, theta=0.0
% INFO    : Bus 50637	: V=1.0108387, theta=-28.483423 -> V=1.0, theta=0.0
% INFO    : Bus 50638	: V=0.9965472, theta=-28.601108 -> V=1.0, theta=0.0
% INFO    : Bus 50639	: V=0.9941712, theta=-28.505909 -> V=1.0, theta=0.0
% INFO    : Bus 50640	: V=0.977769, theta=-27.12228 -> V=1.0, theta=0.0
% INFO    : Bus 50641	: V=0.9736889, theta=-27.012475 -> V=1.0, theta=0.0
% INFO    : Bus 50642	: V=0.9973289, theta=-7.419025 -> V=1.0, theta=0.0
% INFO    : Bus 50643	: V=0.9943813, theta=-7.079594 -> V=1.0, theta=0.0
% INFO    : Bus 50644	: V=0.9930665, theta=-6.689328 -> V=1.0, theta=0.0
% INFO    : Bus 50645	: V=1.0167519, theta=-12.221951 -> V=1.0, theta=0.0
% INFO    : Bus 50646	: V=1.0118161, theta=-12.375994 -> V=1.0, theta=0.0
% INFO    : Bus 50647	: V=1.0145533, theta=-12.375657 -> V=1.0, theta=0.0
% INFO    : Bus 50648	: V=1.006005, theta=-12.941405 -> V=1.0, theta=0.0
% INFO    : Bus 50649	: V=1.0164348, theta=-12.328401 -> V=1.0, theta=0.0
% INFO    : Bus 50650	: V=1.0066222, theta=-12.923528 -> V=1.0, theta=0.0
% INFO    : Bus 50651	: V=1.0106805, theta=-12.732424 -> V=1.0, theta=0.0
% INFO    : Bus 50652	: V=1.0088276, theta=-12.867109 -> V=1.0, theta=0.0
% INFO    : Bus 50653	: V=1.0072398, theta=-12.871605 -> V=1.0, theta=0.0
% INFO    : Bus 50654	: V=1.0047356, theta=-12.966419 -> V=1.0, theta=0.0
% INFO    : Bus 50655	: V=1.00275, theta=-13.05571 -> V=1.0, theta=0.0
% INFO    : Bus 50656	: V=1.0034717, theta=-12.97676 -> V=1.0, theta=0.0
% INFO    : Bus 50657	: V=1.0131945, theta=-12.408478 -> V=1.0, theta=0.0
% INFO    : Bus 50658	: V=1.0051068, theta=-12.969111 -> V=1.0, theta=0.0
% INFO    : Bus 50659	: V=1.0125059, theta=-12.405071 -> V=1.0, theta=0.0
% INFO    : Bus 50660	: V=0.9998949, theta=-12.996194 -> V=1.0, theta=0.0
% INFO    : Bus 50661	: V=0.9987711, theta=-12.989366 -> V=1.0, theta=0.0
% INFO    : Bus 50662	: V=1.000545, theta=-12.151048 -> V=1.0, theta=0.0
% INFO    : Bus 50663	: V=0.9868082, theta=-12.956095 -> V=1.0, theta=0.0
% INFO    : Bus 50664	: V=0.9949684, theta=-13.055124 -> V=1.0, theta=0.0
% INFO    : Bus 50665	: V=1.009412, theta=-13.546253 -> V=1.0, theta=0.0
% INFO    : Bus 50666	: V=1.0052113, theta=-12.984658 -> V=1.0, theta=0.0
% INFO    : Bus 50667	: V=0.9978064, theta=-49.430263 -> V=1.0, theta=0.0
% INFO    : Bus 50668	: V=0.9872595, theta=-50.36918 -> V=1.0, theta=0.0
% INFO    : Bus 50669	: V=0.9864458, theta=-32.240971 -> V=1.0, theta=0.0
% INFO    : Bus 50670	: V=0.9985536, theta=-44.032657 -> V=1.0, theta=0.0
% INFO    : Bus 50671	: V=1.0054312, theta=-44.393196 -> V=1.0, theta=0.0
% INFO    : Bus 50672	: V=0.9982736, theta=-44.452964 -> V=1.0, theta=0.0
% INFO    : Bus 50673	: V=1.0195758, theta=-43.835168 -> V=1.0, theta=0.0
% INFO    : Bus 50674	: V=0.9901394, theta=-45.17609 -> V=1.0, theta=0.0
% INFO    : Bus 50675	: V=0.9909873, theta=-45.637789 -> V=1.0, theta=0.0
% INFO    : Bus 50676	: V=1.0023814, theta=-35.173273 -> V=1.0, theta=0.0
% INFO    : Bus 50677	: V=1.0102657, theta=-36.017055 -> V=1.0, theta=0.0
% INFO    : Bus 50678	: V=1.0118519, theta=-52.760015 -> V=1.0, theta=0.0
% INFO    : Bus 50679	: V=1.0166676, theta=-52.793047 -> V=1.0, theta=0.0
% INFO    : Bus 50680	: V=1.0090973, theta=-53.326386 -> V=1.0, theta=0.0
% INFO    : Bus 50681	: V=1.0082659, theta=-53.335973 -> V=1.0, theta=0.0
% INFO    : Bus 50682	: V=1.0078002, theta=-53.335041 -> V=1.0, theta=0.0
% INFO    : Bus 50683	: V=1.0146988, theta=-52.786888 -> V=1.0, theta=0.0
% INFO    : Bus 50684	: V=1.0066848, theta=-53.307839 -> V=1.0, theta=0.0
% INFO    : Bus 50685	: V=1.0067116, theta=-53.329084 -> V=1.0, theta=0.0
% INFO    : Bus 50686	: V=1.0083, theta=-53.342248 -> V=1.0, theta=0.0
% INFO    : Bus 50687	: V=1.008287, theta=-53.329657 -> V=1.0, theta=0.0
% INFO    : Bus 50688	: V=1.0073671, theta=-53.328365 -> V=1.0, theta=0.0
% INFO    : Bus 50689	: V=1.0201127, theta=-52.330971 -> V=1.0, theta=0.0
% INFO    : Bus 50690	: V=1.0165914, theta=-50.442694 -> V=1.0, theta=0.0
% INFO    : Bus 50691	: V=0.9984151, theta=-52.670738 -> V=1.0, theta=0.0
% INFO    : Bus 50692	: V=1.0148326, theta=-50.741117 -> V=1.0, theta=0.0
% INFO    : Bus 50693	: V=0.9930142, theta=-52.102489 -> V=1.0, theta=0.0
% INFO    : Bus 50694	: V=0.9974925, theta=-52.061282 -> V=1.0, theta=0.0
% INFO    : Bus 50695	: V=1.0109247, theta=-50.925683 -> V=1.0, theta=0.0
% INFO    : Bus 50696	: V=1.0088365, theta=-51.440884 -> V=1.0, theta=0.0
% INFO    : Bus 50697	: V=0.9741787, theta=-17.281824 -> V=1.0, theta=0.0
% INFO    : Bus 50698	: V=0.9742528, theta=-16.784822 -> V=1.0, theta=0.0
% INFO    : Bus 50699	: V=0.9699078, theta=-17.059458 -> V=1.0, theta=0.0
% INFO    : Bus 50700	: V=0.9715762, theta=-17.004698 -> V=1.0, theta=0.0
% INFO    : Bus 50701	: V=0.9757521, theta=-16.034763 -> V=1.0, theta=0.0
% INFO    : Bus 50702	: V=0.9757479, theta=-22.482299 -> V=1.0, theta=0.0
% INFO    : Bus 50703	: V=0.9692573, theta=-23.398586 -> V=1.0, theta=0.0
% INFO    : Bus 50704	: V=0.9697925, theta=-23.385475 -> V=1.0, theta=0.0
% INFO    : Bus 50705	: V=0.9683304, theta=-23.468945 -> V=1.0, theta=0.0
% INFO    : Bus 50706	: V=0.9708314, theta=-23.217727 -> V=1.0, theta=0.0
% INFO    : Bus 50707	: V=0.9706589, theta=-23.299782 -> V=1.0, theta=0.0
% INFO    : Bus 50708	: V=0.9756432, theta=-21.835635 -> V=1.0, theta=0.0
% INFO    : Bus 50709	: V=0.970288, theta=-23.356346 -> V=1.0, theta=0.0
% INFO    : Bus 50710	: V=0.9649958, theta=-52.326278 -> V=1.0, theta=0.0
% INFO    : Bus 50711	: V=0.9893736, theta=-50.967803 -> V=1.0, theta=0.0
% INFO    : Bus 50712	: V=0.9771798, theta=-48.069376 -> V=1.0, theta=0.0
% INFO    : Bus 50713	: V=0.974402, theta=-47.852553 -> V=1.0, theta=0.0
% INFO    : Bus 50714	: V=1.0194348, theta=-52.733181 -> V=1.0, theta=0.0
% INFO    : Bus 50715	: V=1.0088898, theta=-54.418561 -> V=1.0, theta=0.0
% INFO    : Bus 50716	: V=1.0109689, theta=-52.811342 -> V=1.0, theta=0.0
% INFO    : Bus 50717	: V=1.0199529, theta=-51.769587 -> V=1.0, theta=0.0
% INFO    : Bus 50718	: V=0.9830679, theta=-55.089883 -> V=1.0, theta=0.0
% INFO    : Bus 50719	: V=0.9944082, theta=-27.191983 -> V=1.0, theta=0.0
% INFO    : Bus 50720	: V=0.9932252, theta=-29.290955 -> V=1.0, theta=0.0
% INFO    : Bus 50721	: V=0.994911, theta=-29.973044 -> V=1.0, theta=0.0
% INFO    : Bus 50722	: V=0.9896754, theta=-56.390073 -> V=1.0, theta=0.0
% INFO    : Bus 50723	: V=0.9743259, theta=-45.290065 -> V=1.0, theta=0.0
% INFO    : Bus 50724	: V=0.9825732, theta=-45.98803 -> V=1.0, theta=0.0
% INFO    : Bus 50725	: V=0.9670106, theta=-46.459823 -> V=1.0, theta=0.0
% INFO    : Bus 50726	: V=0.9926828, theta=-33.731153 -> V=1.0, theta=0.0
% INFO    : Bus 50727	: V=0.9973687, theta=-34.840739 -> V=1.0, theta=0.0
% INFO    : Bus 50728	: V=0.9966174, theta=-34.802444 -> V=1.0, theta=0.0
% INFO    : Bus 50729	: V=0.9942881, theta=-34.200918 -> V=1.0, theta=0.0
% INFO    : Bus 50730	: V=1.0023632, theta=-34.422244 -> V=1.0, theta=0.0
% INFO    : Bus 50731	: V=1.0188133, theta=-34.41703 -> V=1.0, theta=0.0
% INFO    : Bus 50732	: V=0.9940585, theta=-55.94923 -> V=1.0, theta=0.0
% INFO    : Bus 50733	: V=1.0202251, theta=-49.159596 -> V=1.0, theta=0.0
% INFO    : Bus 50734	: V=1.0125877, theta=-12.046166 -> V=1.0, theta=0.0
% INFO    : Bus 50735	: V=1.0117769, theta=-12.379209 -> V=1.0, theta=0.0
% INFO    : Bus 50736	: V=1.0039023, theta=-13.608469 -> V=1.0, theta=0.0
% INFO    : Bus 50737	: V=1.0136875, theta=-12.55113 -> V=1.0, theta=0.0
% INFO    : Bus 50738	: V=0.9985884, theta=-12.500971 -> V=1.0, theta=0.0
% INFO    : Bus 50739	: V=1.0120423, theta=-10.525819 -> V=1.0, theta=0.0
% INFO    : Bus 50740	: V=0.9987481, theta=-12.096149 -> V=1.0, theta=0.0
% INFO    : Bus 50741	: V=1.014274, theta=-36.047613 -> V=1.0, theta=0.0
% INFO    : Bus 50742	: V=1.0136746, theta=-35.809273 -> V=1.0, theta=0.0
% INFO    : Bus 50743	: V=0.9789795, theta=-9.730615 -> V=1.0, theta=0.0
% INFO    : Bus 50744	: V=0.9783087, theta=-9.814142 -> V=1.0, theta=0.0
% INFO    : Bus 50745	: V=0.9777405, theta=-9.910874 -> V=1.0, theta=0.0
% INFO    : Bus 50746	: V=0.978979, theta=-9.857172 -> V=1.0, theta=0.0
% INFO    : Bus 50747	: V=0.9859557, theta=-9.217791 -> V=1.0, theta=0.0
% INFO    : Bus 50748	: V=0.9775677, theta=-9.950785 -> V=1.0, theta=0.0
% INFO    : Bus 50749	: V=0.9751301, theta=-10.189867 -> V=1.0, theta=0.0
% INFO    : Bus 50750	: V=0.9750564, theta=-10.172718 -> V=1.0, theta=0.0
% INFO    : Bus 50751	: V=0.9759514, theta=-10.128472 -> V=1.0, theta=0.0
% INFO    : Bus 50752	: V=0.9754583, theta=-10.128903 -> V=1.0, theta=0.0
% INFO    : Bus 50753	: V=0.9759816, theta=-9.92136 -> V=1.0, theta=0.0
% INFO    : Bus 50754	: V=0.9744718, theta=-10.121061 -> V=1.0, theta=0.0
% INFO    : Bus 50755	: V=0.9738607, theta=-10.254469 -> V=1.0, theta=0.0
% INFO    : Bus 50756	: V=0.9722801, theta=-10.577162 -> V=1.0, theta=0.0
% INFO    : Bus 50757	: V=0.973593, theta=-10.475675 -> V=1.0, theta=0.0
% INFO    : Bus 50758	: V=0.9744221, theta=-10.06378 -> V=1.0, theta=0.0
% INFO    : Bus 50759	: V=0.979406, theta=-9.771248 -> V=1.0, theta=0.0
% INFO    : Bus 50760	: V=0.9791687, theta=-9.955774 -> V=1.0, theta=0.0
% INFO    : Bus 50761	: V=0.9791572, theta=-10.193144 -> V=1.0, theta=0.0
% INFO    : Bus 50762	: V=0.9726141, theta=-10.557662 -> V=1.0, theta=0.0
% INFO    : Bus 50763	: V=0.9729197, theta=-10.568839 -> V=1.0, theta=0.0
% INFO    : Bus 50764	: V=0.9713395, theta=-10.656176 -> V=1.0, theta=0.0
% INFO    : Bus 50765	: V=0.9710434, theta=-10.740964 -> V=1.0, theta=0.0
% INFO    : Bus 50766	: V=0.9709123, theta=-10.699052 -> V=1.0, theta=0.0
% INFO    : Bus 50767	: V=0.9720762, theta=-10.636919 -> V=1.0, theta=0.0
% INFO    : Bus 50768	: V=0.970785, theta=-10.675163 -> V=1.0, theta=0.0
% INFO    : Bus 50769	: V=0.9707744, theta=-10.631091 -> V=1.0, theta=0.0
% INFO    : Bus 50770	: V=0.9701245, theta=-10.914664 -> V=1.0, theta=0.0
% INFO    : Bus 50771	: V=0.9722565, theta=-10.41947 -> V=1.0, theta=0.0
% INFO    : Bus 50772	: V=0.971446, theta=-10.57403 -> V=1.0, theta=0.0
% INFO    : Bus 50773	: V=0.9703636, theta=-10.763712 -> V=1.0, theta=0.0
% INFO    : Bus 50774	: V=0.9701443, theta=-10.779075 -> V=1.0, theta=0.0
% INFO    : Bus 50775	: V=0.9736879, theta=-10.295764 -> V=1.0, theta=0.0
% INFO    : Bus 50776	: V=0.9831978, theta=-9.48855 -> V=1.0, theta=0.0
% INFO    : Bus 50777	: V=0.9740296, theta=-10.304353 -> V=1.0, theta=0.0
% INFO    : Bus 50778	: V=0.9794514, theta=-9.8309 -> V=1.0, theta=0.0
% INFO    : Bus 50779	: V=0.983892, theta=-9.499718 -> V=1.0, theta=0.0
% INFO    : Bus 50780	: V=0.9824854, theta=-9.510981 -> V=1.0, theta=0.0
% INFO    : Bus 50781	: V=0.9825091, theta=-9.616408 -> V=1.0, theta=0.0
% INFO    : Bus 50782	: V=0.9722824, theta=-10.522849 -> V=1.0, theta=0.0
% INFO    : Bus 50783	: V=0.9739216, theta=-10.35609 -> V=1.0, theta=0.0
% INFO    : Bus 50784	: V=0.9849952, theta=-9.500914 -> V=1.0, theta=0.0
% INFO    : Bus 50785	: V=0.9805741, theta=-9.62686 -> V=1.0, theta=0.0
% INFO    : Bus 50786	: V=0.9703765, theta=-10.991145 -> V=1.0, theta=0.0
% INFO    : Bus 50787	: V=0.9711461, theta=-10.644948 -> V=1.0, theta=0.0
% INFO    : Bus 50788	: V=0.9711956, theta=-10.489017 -> V=1.0, theta=0.0
% INFO    : Bus 50789	: V=0.9700435, theta=-10.634096 -> V=1.0, theta=0.0
% INFO    : Bus 50790	: V=0.9708904, theta=-10.736942 -> V=1.0, theta=0.0
% INFO    : Bus 50791	: V=0.9701467, theta=-10.695538 -> V=1.0, theta=0.0
% INFO    : Bus 50792	: V=0.9706528, theta=-10.696372 -> V=1.0, theta=0.0
% INFO    : Bus 50793	: V=0.9727644, theta=-10.458107 -> V=1.0, theta=0.0
% INFO    : Bus 50794	: V=0.9718224, theta=-10.492745 -> V=1.0, theta=0.0
% INFO    : Bus 50795	: V=0.9710233, theta=-10.568728 -> V=1.0, theta=0.0
% INFO    : Bus 50796	: V=0.9730832, theta=-10.547812 -> V=1.0, theta=0.0
% INFO    : Bus 50797	: V=0.9811658, theta=-10.89066 -> V=1.0, theta=0.0
% INFO    : Bus 50798	: V=0.983559, theta=-11.138842 -> V=1.0, theta=0.0
% INFO    : Bus 50799	: V=0.9735721, theta=-10.526426 -> V=1.0, theta=0.0
% INFO    : Bus 50800	: V=0.9741722, theta=-10.836363 -> V=1.0, theta=0.0
% INFO    : Bus 50801	: V=0.9737541, theta=-10.503658 -> V=1.0, theta=0.0
% INFO    : Bus 50802	: V=0.9741479, theta=-10.479505 -> V=1.0, theta=0.0
% INFO    : Bus 50803	: V=0.9919245, theta=-11.680623 -> V=1.0, theta=0.0
% INFO    : Bus 50804	: V=0.984963, theta=-11.680061 -> V=1.0, theta=0.0
% INFO    : Bus 50805	: V=0.9831041, theta=-11.551532 -> V=1.0, theta=0.0
% INFO    : Bus 50806	: V=0.9838624, theta=-11.402754 -> V=1.0, theta=0.0
% INFO    : Bus 50807	: V=0.9858392, theta=-10.937945 -> V=1.0, theta=0.0
% INFO    : Bus 50808	: V=0.9859754, theta=-10.923581 -> V=1.0, theta=0.0
% INFO    : Bus 50809	: V=0.9842392, theta=-11.422938 -> V=1.0, theta=0.0
% INFO    : Bus 50810	: V=0.9711058, theta=-11.160393 -> V=1.0, theta=0.0
% INFO    : Bus 50811	: V=0.9866531, theta=-10.911312 -> V=1.0, theta=0.0
% INFO    : Bus 50812	: V=0.9709033, theta=-11.082745 -> V=1.0, theta=0.0
% INFO    : Bus 50813	: V=0.9700156, theta=-10.978773 -> V=1.0, theta=0.0
% INFO    : Bus 50814	: V=0.9704063, theta=-11.058646 -> V=1.0, theta=0.0
% INFO    : Bus 50815	: V=0.9809581, theta=-10.702121 -> V=1.0, theta=0.0
% INFO    : Bus 50816	: V=0.9713165, theta=-11.118498 -> V=1.0, theta=0.0
% INFO    : Bus 50817	: V=0.9722651, theta=-11.209994 -> V=1.0, theta=0.0
% INFO    : Bus 50818	: V=0.9716285, theta=-11.148235 -> V=1.0, theta=0.0
% INFO    : Bus 50819	: V=0.9719392, theta=-11.075072 -> V=1.0, theta=0.0
% INFO    : Bus 50820	: V=0.9741134, theta=-11.240549 -> V=1.0, theta=0.0
% INFO    : Bus 50821	: V=0.9737128, theta=-11.272619 -> V=1.0, theta=0.0
% INFO    : Bus 50822	: V=0.9707743, theta=-10.934095 -> V=1.0, theta=0.0
% INFO    : Bus 50823	: V=0.9790806, theta=-10.570447 -> V=1.0, theta=0.0
% INFO    : Bus 50824	: V=0.9716458, theta=-10.979506 -> V=1.0, theta=0.0
% INFO    : Bus 50825	: V=0.9716218, theta=-11.032528 -> V=1.0, theta=0.0
% INFO    : Bus 50826	: V=0.9741136, theta=-11.063741 -> V=1.0, theta=0.0
% INFO    : Bus 50827	: V=0.9730203, theta=-11.075563 -> V=1.0, theta=0.0
% INFO    : Bus 50828	: V=0.9792373, theta=-10.514654 -> V=1.0, theta=0.0
% INFO    : Bus 50829	: V=0.9756404, theta=-10.840806 -> V=1.0, theta=0.0
% INFO    : Bus 50830	: V=0.9759407, theta=-10.92695 -> V=1.0, theta=0.0
% INFO    : Bus 50831	: V=0.9800731, theta=-10.405624 -> V=1.0, theta=0.0
% INFO    : Bus 50832	: V=0.9815835, theta=-10.488016 -> V=1.0, theta=0.0
% INFO    : Bus 50833	: V=0.9757719, theta=-11.309435 -> V=1.0, theta=0.0
% INFO    : Bus 50834	: V=0.975759, theta=-11.103762 -> V=1.0, theta=0.0
% INFO    : Bus 50835	: V=0.983201, theta=-10.523566 -> V=1.0, theta=0.0
% INFO    : Bus 50836	: V=0.9851427, theta=-10.502711 -> V=1.0, theta=0.0
% INFO    : Bus 50837	: V=0.9785765, theta=-10.765052 -> V=1.0, theta=0.0
% INFO    : Bus 50838	: V=0.9840541, theta=-10.598772 -> V=1.0, theta=0.0
% INFO    : Bus 50839	: V=0.9769972, theta=-10.883635 -> V=1.0, theta=0.0
% INFO    : Bus 50840	: V=0.9838415, theta=-10.640392 -> V=1.0, theta=0.0
% INFO    : Bus 50841	: V=0.984364, theta=-10.655232 -> V=1.0, theta=0.0
% INFO    : Bus 50842	: V=0.9771938, theta=-10.768197 -> V=1.0, theta=0.0
% INFO    : Bus 50843	: V=0.9756692, theta=-11.069704 -> V=1.0, theta=0.0
% INFO    : Bus 50844	: V=0.9753374, theta=-11.22044 -> V=1.0, theta=0.0
% INFO    : Bus 50845	: V=0.9752487, theta=-11.143858 -> V=1.0, theta=0.0
% INFO    : Bus 50846	: V=0.9774025, theta=-11.129583 -> V=1.0, theta=0.0
% INFO    : Bus 50847	: V=0.9788858, theta=-11.062095 -> V=1.0, theta=0.0
% INFO    : Bus 50848	: V=0.9895779, theta=-10.970814 -> V=1.0, theta=0.0
% INFO    : Bus 50849	: V=0.9809945, theta=-11.316186 -> V=1.0, theta=0.0
% INFO    : Bus 50850	: V=0.9788741, theta=-11.335188 -> V=1.0, theta=0.0
% INFO    : Bus 50851	: V=0.9763181, theta=-11.333651 -> V=1.0, theta=0.0
% INFO    : Bus 50852	: V=0.990848, theta=-10.992047 -> V=1.0, theta=0.0
% INFO    : Bus 50853	: V=0.9785087, theta=-11.331456 -> V=1.0, theta=0.0
% INFO    : Bus 50854	: V=0.9752656, theta=-11.331831 -> V=1.0, theta=0.0
% INFO    : Bus 50855	: V=0.9847161, theta=-11.411635 -> V=1.0, theta=0.0
% INFO    : Bus 50856	: V=0.9831626, theta=-11.367306 -> V=1.0, theta=0.0
% INFO    : Bus 50857	: V=0.9921075, theta=-11.033198 -> V=1.0, theta=0.0
% INFO    : Bus 50858	: V=0.9858391, theta=-11.405476 -> V=1.0, theta=0.0
% INFO    : Bus 50859	: V=0.9967532, theta=-11.058825 -> V=1.0, theta=0.0
% INFO    : Bus 50860	: V=1.0098055, theta=-11.3795 -> V=1.0, theta=0.0
% INFO    : Bus 50861	: V=1.0139477, theta=-10.955827 -> V=1.0, theta=0.0
% INFO    : Bus 50862	: V=1.0008012, theta=-11.369073 -> V=1.0, theta=0.0
% INFO    : Bus 50863	: V=1.0117384, theta=-11.001571 -> V=1.0, theta=0.0
% INFO    : Bus 50864	: V=1.0146169, theta=-11.042959 -> V=1.0, theta=0.0
% INFO    : Bus 50865	: V=1.0087968, theta=-11.14718 -> V=1.0, theta=0.0
% INFO    : Bus 50866	: V=1.0162097, theta=-11.06475 -> V=1.0, theta=0.0
% INFO    : Bus 50867	: V=0.989878, theta=-11.225249 -> V=1.0, theta=0.0
% INFO    : Bus 50868	: V=1.0058744, theta=-9.361292 -> V=1.0, theta=0.0
% INFO    : Bus 50869	: V=0.9854295, theta=-10.729609 -> V=1.0, theta=0.0
% INFO    : Bus 50870	: V=0.9824278, theta=-10.654102 -> V=1.0, theta=0.0
% INFO    : Bus 50871	: V=0.9719104, theta=-10.535052 -> V=1.0, theta=0.0
% INFO    : Bus 50872	: V=0.9730915, theta=-10.700594 -> V=1.0, theta=0.0
% INFO    : Bus 50873	: V=0.9781933, theta=-56.542747 -> V=1.0, theta=0.0
% INFO    : Bus 50874	: V=0.9639126, theta=-40.831189 -> V=1.0, theta=0.0
% INFO    : Bus 50875	: V=0.9693743, theta=-41.548452 -> V=1.0, theta=0.0
% INFO    : Bus 50876	: V=0.9680905, theta=-43.798986 -> V=1.0, theta=0.0
% INFO    : Bus 50877	: V=1.0058227, theta=-51.343577 -> V=1.0, theta=0.0
% INFO    : Bus 50878	: V=0.9837204, theta=-25.977221 -> V=1.0, theta=0.0
% INFO    : Bus 50879	: V=0.9828784, theta=-26.101145 -> V=1.0, theta=0.0
% INFO    : Bus 50880	: V=0.9853545, theta=-25.57003 -> V=1.0, theta=0.0
% INFO    : Bus 50881	: V=0.9845183, theta=-26.230187 -> V=1.0, theta=0.0
% INFO    : Bus 50882	: V=0.9832728, theta=-26.812081 -> V=1.0, theta=0.0
% INFO    : Bus 50883	: V=0.9867995, theta=-28.272567 -> V=1.0, theta=0.0
% INFO    : Bus 50884	: V=0.9890071, theta=-26.432855 -> V=1.0, theta=0.0
% INFO    : Bus 50885	: V=0.9776148, theta=-26.370028 -> V=1.0, theta=0.0
% INFO    : Bus 50886	: V=1.0003095, theta=-51.183287 -> V=1.0, theta=0.0
% INFO    : Bus 50887	: V=0.9963228, theta=-7.277608 -> V=1.0, theta=0.0
% INFO    : Bus 50888	: V=0.9974955, theta=-7.157515 -> V=1.0, theta=0.0
% INFO    : Bus 50889	: V=0.9950895, theta=-7.423751 -> V=1.0, theta=0.0
% INFO    : Bus 50890	: V=0.9951303, theta=-7.325398 -> V=1.0, theta=0.0
% INFO    : Bus 50891	: V=1.0113037, theta=-6.965655 -> V=1.0, theta=0.0
% INFO    : Bus 50892	: V=0.9945236, theta=-7.484396 -> V=1.0, theta=0.0
% INFO    : Bus 50893	: V=1.0118539, theta=-7.044628 -> V=1.0, theta=0.0
% INFO    : Bus 50894	: V=1.004716, theta=-8.677206 -> V=1.0, theta=0.0
% INFO    : Bus 50895	: V=1.0014805, theta=-8.217683 -> V=1.0, theta=0.0
% INFO    : Bus 50896	: V=0.9994319, theta=-8.311261 -> V=1.0, theta=0.0
% INFO    : Bus 50897	: V=0.995078, theta=-10.373518 -> V=1.0, theta=0.0
% INFO    : Bus 50898	: V=0.9893417, theta=-10.446194 -> V=1.0, theta=0.0
% INFO    : Bus 50899	: V=0.992023, theta=-11.47818 -> V=1.0, theta=0.0
% INFO    : Bus 50900	: V=1.0013367, theta=-10.10203 -> V=1.0, theta=0.0
% INFO    : Bus 50901	: V=1.0008411, theta=-10.700921 -> V=1.0, theta=0.0
% INFO    : Bus 50902	: V=1.011015, theta=-6.979651 -> V=1.0, theta=0.0
% INFO    : Bus 50903	: V=1.0139295, theta=-32.938328 -> V=1.0, theta=0.0
% INFO    : Bus 50904	: V=1.0076906, theta=-10.456053 -> V=1.0, theta=0.0
% INFO    : Bus 50905	: V=0.9993494, theta=-11.867763 -> V=1.0, theta=0.0
% INFO    : Bus 50906	: V=0.9752359, theta=-51.385724 -> V=1.0, theta=0.0
% INFO    : Bus 50907	: V=1.0055049, theta=-21.413653 -> V=1.0, theta=0.0
% INFO    : Bus 50908	: V=1.00268, theta=-22.222152 -> V=1.0, theta=0.0
% INFO    : Bus 50909	: V=1.0036924, theta=-21.92046 -> V=1.0, theta=0.0
% INFO    : Bus 50910	: V=0.989641, theta=-22.654228 -> V=1.0, theta=0.0
% INFO    : Bus 50911	: V=1.0043882, theta=-21.699379 -> V=1.0, theta=0.0
% INFO    : Bus 50912	: V=1.0048814, theta=-20.04358 -> V=1.0, theta=0.0
% INFO    : Bus 50913	: V=1.0008616, theta=-22.646995 -> V=1.0, theta=0.0
% INFO    : Bus 50914	: V=1.0010876, theta=-22.707926 -> V=1.0, theta=0.0
% INFO    : Bus 50915	: V=1.0043802, theta=-33.251251 -> V=1.0, theta=0.0
% INFO    : Bus 50916	: V=1.0073783, theta=-32.953476 -> V=1.0, theta=0.0
% INFO    : Bus 50917	: V=0.9845579, theta=-34.340985 -> V=1.0, theta=0.0
% INFO    : Bus 50918	: V=1.0139104, theta=-33.473218 -> V=1.0, theta=0.0
% INFO    : Bus 50919	: V=1.0167838, theta=-33.524367 -> V=1.0, theta=0.0
% INFO    : Bus 50920	: V=1.018193, theta=-33.5345 -> V=1.0, theta=0.0
% INFO    : Bus 50921	: V=1.0050474, theta=-34.110931 -> V=1.0, theta=0.0
% INFO    : Bus 50922	: V=0.9854713, theta=-29.191152 -> V=1.0, theta=0.0
% INFO    : Bus 50923	: V=0.982204, theta=-32.163458 -> V=1.0, theta=0.0
% INFO    : Bus 50924	: V=0.9850357, theta=-28.938468 -> V=1.0, theta=0.0
% INFO    : Bus 50925	: V=0.985318, theta=-30.304726 -> V=1.0, theta=0.0
% INFO    : Bus 50926	: V=0.9957513, theta=-17.710557 -> V=1.0, theta=0.0
% INFO    : Bus 50927	: V=1.0011427, theta=-19.832224 -> V=1.0, theta=0.0
% INFO    : Bus 50928	: V=1.0054229, theta=-19.065059 -> V=1.0, theta=0.0
% INFO    : Bus 50929	: V=1.0006666, theta=-19.601588 -> V=1.0, theta=0.0
% INFO    : Bus 50930	: V=1.0065842, theta=-54.564795 -> V=1.0, theta=0.0
% INFO    : Bus 50931	: V=1.0194478, theta=-51.878849 -> V=1.0, theta=0.0
% INFO    : Bus 50932	: V=1.0167692, theta=-11.348101 -> V=1.0, theta=0.0
% INFO    : Bus 50933	: V=1.002727, theta=-10.602295 -> V=1.0, theta=0.0
% INFO    : Bus 50934	: V=1.0163591, theta=-7.2835 -> V=1.0, theta=0.0
% INFO    : Bus 50935	: V=1.0184258, theta=-7.024912 -> V=1.0, theta=0.0
% INFO    : Bus 50936	: V=1.0168858, theta=-11.205028 -> V=1.0, theta=0.0
% INFO    : Bus 50937	: V=1.0180911, theta=-11.60438 -> V=1.0, theta=0.0
% INFO    : Bus 50938	: V=1.0067958, theta=-11.962082 -> V=1.0, theta=0.0
% INFO    : Bus 50939	: V=0.9896487, theta=-13.910159 -> V=1.0, theta=0.0
% INFO    : Bus 50940	: V=1.0113544, theta=-33.879837 -> V=1.0, theta=0.0
% INFO    : Bus 50941	: V=1.0100507, theta=-34.817617 -> V=1.0, theta=0.0
% INFO    : Bus 50942	: V=0.9732968, theta=-29.653152 -> V=1.0, theta=0.0
% INFO    : Bus 50943	: V=0.9751453, theta=-31.014288 -> V=1.0, theta=0.0
% INFO    : Bus 50944	: V=0.973368, theta=-31.031887 -> V=1.0, theta=0.0
% INFO    : Bus 50945	: V=0.9712584, theta=-31.795594 -> V=1.0, theta=0.0
% INFO    : Bus 50946	: V=0.9720969, theta=-32.267848 -> V=1.0, theta=0.0
% INFO    : Bus 50947	: V=0.9708832, theta=-32.607948 -> V=1.0, theta=0.0
% INFO    : Bus 50948	: V=0.9693418, theta=-33.319971 -> V=1.0, theta=0.0
% INFO    : Bus 50949	: V=0.9812963, theta=-34.007719 -> V=1.0, theta=0.0
% INFO    : Bus 50950	: V=0.9824971, theta=-33.859269 -> V=1.0, theta=0.0
% INFO    : Bus 50951	: V=0.9840717, theta=-33.903944 -> V=1.0, theta=0.0
% INFO    : Bus 50952	: V=0.9766448, theta=-33.872991 -> V=1.0, theta=0.0
% INFO    : Bus 50953	: V=0.9773802, theta=-33.972428 -> V=1.0, theta=0.0
% INFO    : Bus 50954	: V=0.9706479, theta=-34.446072 -> V=1.0, theta=0.0
% INFO    : Bus 50955	: V=0.977714, theta=-24.919973 -> V=1.0, theta=0.0
% INFO    : Bus 50956	: V=0.9844162, theta=-23.597645 -> V=1.0, theta=0.0
% INFO    : Bus 50957	: V=0.9992271, theta=-57.720468 -> V=1.0, theta=0.0
% INFO    : Bus 50958	: V=0.9952376, theta=-11.518808 -> V=1.0, theta=0.0
% INFO    : Bus 50959	: V=1.0049389, theta=-12.652648 -> V=1.0, theta=0.0
% INFO    : Bus 50960	: V=1.0056152, theta=-12.483534 -> V=1.0, theta=0.0
% INFO    : Bus 50961	: V=1.0151493, theta=-24.214426 -> V=1.0, theta=0.0
% INFO    : Bus 50962	: V=0.9847019, theta=-20.057246 -> V=1.0, theta=0.0
% INFO    : Bus 50963	: V=0.9896676, theta=-21.099445 -> V=1.0, theta=0.0
% INFO    : Bus 50964	: V=0.9873843, theta=-21.811117 -> V=1.0, theta=0.0
% INFO    : Bus 50965	: V=0.9882284, theta=-23.932454 -> V=1.0, theta=0.0
% INFO    : Bus 50966	: V=0.9935421, theta=-47.925951 -> V=1.0, theta=0.0
% INFO    : Bus 50967	: V=0.9995077, theta=-49.131112 -> V=1.0, theta=0.0
% INFO    : Bus 50968	: V=1.0053995, theta=-43.822673 -> V=1.0, theta=0.0
% INFO    : Bus 50969	: V=0.9836568, theta=-17.172143 -> V=1.0, theta=0.0
% INFO    : Bus 50970	: V=1.0049162, theta=-16.698855 -> V=1.0, theta=0.0
% INFO    : Bus 50971	: V=0.9926075, theta=-18.812184 -> V=1.0, theta=0.0
% INFO    : Bus 50972	: V=1.003805, theta=-18.402061 -> V=1.0, theta=0.0
% INFO    : Bus 50973	: V=0.9827811, theta=-18.016293 -> V=1.0, theta=0.0
% INFO    : Bus 50974	: V=1.006962, theta=-39.41677 -> V=1.0, theta=0.0
% INFO    : Bus 50975	: V=0.969118, theta=-33.883748 -> V=1.0, theta=0.0
% INFO    : Bus 50976	: V=0.9991706, theta=-31.982175 -> V=1.0, theta=0.0
% INFO    : Bus 50977	: V=0.995263, theta=-46.648522 -> V=1.0, theta=0.0
% INFO    : Bus 50978	: V=0.993353, theta=-47.692339 -> V=1.0, theta=0.0
% INFO    : Bus 50979	: V=1.0010516, theta=-42.849773 -> V=1.0, theta=0.0
% INFO    : Bus 50980	: V=1.0007609, theta=-43.576481 -> V=1.0, theta=0.0
% INFO    : Bus 50981	: V=1.0048623, theta=-42.599989 -> V=1.0, theta=0.0
% INFO    : Bus 50982	: V=0.9793967, theta=-20.285833 -> V=1.0, theta=0.0
% INFO    : Bus 50983	: V=0.9965794, theta=-18.310341 -> V=1.0, theta=0.0
% INFO    : Bus 50984	: V=1.0112229, theta=-15.233518 -> V=1.0, theta=0.0
% INFO    : Bus 50985	: V=1.0149375, theta=-15.996891 -> V=1.0, theta=0.0
% INFO    : Bus 50986	: V=0.9752669, theta=-48.725428 -> V=1.0, theta=0.0
% INFO    : Bus 50987	: V=0.9885927, theta=-46.639067 -> V=1.0, theta=0.0
% INFO    : Bus 50988	: V=0.9885715, theta=-46.715412 -> V=1.0, theta=0.0
% INFO    : Bus 50989	: V=0.9872204, theta=-46.632624 -> V=1.0, theta=0.0
% INFO    : Bus 50990	: V=1.0185153, theta=-35.452781 -> V=1.0, theta=0.0
% INFO    : Bus 50991	: V=1.0159493, theta=-35.582216 -> V=1.0, theta=0.0
% INFO    : Bus 50992	: V=1.0141844, theta=-35.662913 -> V=1.0, theta=0.0
% INFO    : Bus 50993	: V=1.0029083, theta=-36.394389 -> V=1.0, theta=0.0
% INFO    : Bus 50994	: V=1.0035988, theta=-36.39571 -> V=1.0, theta=0.0
% INFO    : Bus 50995	: V=1.0023767, theta=-36.446966 -> V=1.0, theta=0.0
% INFO    : Bus 50996	: V=1.0146489, theta=-35.615311 -> V=1.0, theta=0.0
% INFO    : Bus 50997	: V=1.0014039, theta=-36.505747 -> V=1.0, theta=0.0
% INFO    : Bus 50998	: V=1.0086675, theta=-35.712717 -> V=1.0, theta=0.0
% INFO    : Bus 50999	: V=1.0190473, theta=-35.391539 -> V=1.0, theta=0.0
% INFO    : Bus 51000	: V=1.0112496, theta=-35.879784 -> V=1.0, theta=0.0
% INFO    : Bus 51001	: V=1.0015682, theta=-36.552343 -> V=1.0, theta=0.0
% INFO    : Bus 51002	: V=1.0059181, theta=-36.319041 -> V=1.0, theta=0.0
% INFO    : Bus 51003	: V=1.0017079, theta=-36.358726 -> V=1.0, theta=0.0
% INFO    : Bus 51004	: V=1.0043052, theta=-36.342173 -> V=1.0, theta=0.0
% INFO    : Bus 51005	: V=0.9868891, theta=-40.817601 -> V=1.0, theta=0.0
% INFO    : Bus 51006	: V=0.9829484, theta=-39.604492 -> V=1.0, theta=0.0
% INFO    : Bus 51007	: V=1.0075487, theta=-30.211274 -> V=1.0, theta=0.0
% INFO    : Bus 51008	: V=1.0086621, theta=-31.546466 -> V=1.0, theta=0.0
% INFO    : Bus 51009	: V=1.0083665, theta=-31.065664 -> V=1.0, theta=0.0
% INFO    : Bus 51010	: V=0.9951604, theta=-36.074368 -> V=1.0, theta=0.0
% INFO    : Bus 51011	: V=0.9960765, theta=-36.176284 -> V=1.0, theta=0.0
% INFO    : Bus 51012	: V=0.9988969, theta=-36.157113 -> V=1.0, theta=0.0
% INFO    : Bus 51013	: V=0.9712264, theta=-21.539512 -> V=1.0, theta=0.0
% INFO    : Bus 51014	: V=0.9780927, theta=-21.259683 -> V=1.0, theta=0.0
% INFO    : Bus 51015	: V=0.978353, theta=-21.173478 -> V=1.0, theta=0.0
% INFO    : Bus 51016	: V=0.9726504, theta=-21.340365 -> V=1.0, theta=0.0
% INFO    : Bus 51017	: V=0.9783547, theta=-21.774079 -> V=1.0, theta=0.0
% INFO    : Bus 51018	: V=0.9790609, theta=-21.028441 -> V=1.0, theta=0.0
% INFO    : Bus 51019	: V=0.9732689, theta=-21.279138 -> V=1.0, theta=0.0
% INFO    : Bus 51020	: V=0.9739183, theta=-21.233337 -> V=1.0, theta=0.0
% INFO    : Bus 51021	: V=0.9838306, theta=-20.210482 -> V=1.0, theta=0.0
% INFO    : Bus 51022	: V=0.9705821, theta=-23.442938 -> V=1.0, theta=0.0
% INFO    : Bus 51023	: V=0.9778201, theta=-21.373657 -> V=1.0, theta=0.0
% INFO    : Bus 51024	: V=0.9712337, theta=-21.788962 -> V=1.0, theta=0.0
% INFO    : Bus 51025	: V=0.985387, theta=-22.862237 -> V=1.0, theta=0.0
% INFO    : Bus 51026	: V=0.9819714, theta=-22.331692 -> V=1.0, theta=0.0
% INFO    : Bus 51027	: V=0.987393, theta=-45.325487 -> V=1.0, theta=0.0
% INFO    : Bus 51028	: V=0.9903619, theta=-45.883236 -> V=1.0, theta=0.0
% INFO    : Bus 51029	: V=0.9927432, theta=-46.482511 -> V=1.0, theta=0.0
% INFO    : Bus 51030	: V=0.9865741, theta=-46.701766 -> V=1.0, theta=0.0
% INFO    : Bus 51031	: V=1.0120963, theta=-39.772609 -> V=1.0, theta=0.0
% INFO    : Bus 51032	: V=1.0064686, theta=-38.858795 -> V=1.0, theta=0.0
% INFO    : Bus 51033	: V=0.9944701, theta=-30.147736 -> V=1.0, theta=0.0
% INFO    : Bus 51034	: V=0.9785951, theta=-31.502525 -> V=1.0, theta=0.0
% INFO    : Bus 51035	: V=0.9769097, theta=-31.411343 -> V=1.0, theta=0.0
% INFO    : Bus 51036	: V=0.9744629, theta=-31.521914 -> V=1.0, theta=0.0
% INFO    : Bus 51037	: V=0.9749004, theta=-31.509825 -> V=1.0, theta=0.0
% INFO    : Bus 51038	: V=0.9744085, theta=-31.415183 -> V=1.0, theta=0.0
% INFO    : Bus 51039	: V=0.9758701, theta=-31.319335 -> V=1.0, theta=0.0
% INFO    : Bus 51040	: V=0.9768566, theta=-31.28852 -> V=1.0, theta=0.0
% INFO    : Bus 51041	: V=0.9779549, theta=-31.283811 -> V=1.0, theta=0.0
% INFO    : Bus 51042	: V=0.9794531, theta=-31.151726 -> V=1.0, theta=0.0
% INFO    : Bus 51043	: V=0.9924405, theta=-31.244365 -> V=1.0, theta=0.0
% INFO    : Bus 51044	: V=0.9990055, theta=-31.744434 -> V=1.0, theta=0.0
% INFO    : Bus 51045	: V=1.0205548, theta=-50.308771 -> V=1.0, theta=0.0
% INFO    : Bus 51046	: V=0.9821978, theta=-38.808489 -> V=1.0, theta=0.0
% INFO    : Bus 51047	: V=0.9814669, theta=-38.847254 -> V=1.0, theta=0.0
% INFO    : Bus 51048	: V=0.9809841, theta=-38.872835 -> V=1.0, theta=0.0
% INFO    : Bus 51049	: V=0.9809753, theta=-38.873336 -> V=1.0, theta=0.0
% INFO    : Bus 51050	: V=0.9802845, theta=-38.901203 -> V=1.0, theta=0.0
% INFO    : Bus 51051	: V=0.9682824, theta=-39.677655 -> V=1.0, theta=0.0
% INFO    : Bus 51052	: V=0.9686745, theta=-39.670533 -> V=1.0, theta=0.0
% INFO    : Bus 51053	: V=0.9676755, theta=-39.65222 -> V=1.0, theta=0.0
% INFO    : Bus 51054	: V=0.9662928, theta=-39.735944 -> V=1.0, theta=0.0
% INFO    : Bus 51055	: V=0.9671631, theta=-39.738778 -> V=1.0, theta=0.0
% INFO    : Bus 51056	: V=0.9725852, theta=-39.321074 -> V=1.0, theta=0.0
% INFO    : Bus 51057	: V=0.9747359, theta=-39.513025 -> V=1.0, theta=0.0
% INFO    : Bus 51058	: V=0.970068, theta=-39.620018 -> V=1.0, theta=0.0
% INFO    : Bus 51059	: V=0.9668647, theta=-39.737649 -> V=1.0, theta=0.0
% INFO    : Bus 51060	: V=0.9658252, theta=-39.783606 -> V=1.0, theta=0.0
% INFO    : Bus 51061	: V=0.9647399, theta=-39.835708 -> V=1.0, theta=0.0
% INFO    : Bus 51062	: V=0.9650947, theta=-39.818486 -> V=1.0, theta=0.0
% INFO    : Bus 51063	: V=0.9680806, theta=-39.709186 -> V=1.0, theta=0.0
% INFO    : Bus 51064	: V=0.9696826, theta=-39.648322 -> V=1.0, theta=0.0
% INFO    : Bus 51065	: V=0.9711234, theta=-39.614534 -> V=1.0, theta=0.0
% INFO    : Bus 51066	: V=0.97332, theta=-39.553266 -> V=1.0, theta=0.0
% INFO    : Bus 51067	: V=0.9874545, theta=-38.689895 -> V=1.0, theta=0.0
% INFO    : Bus 51068	: V=0.9885663, theta=-38.650615 -> V=1.0, theta=0.0
% INFO    : Bus 51069	: V=0.9758662, theta=-39.498345 -> V=1.0, theta=0.0
% INFO    : Bus 51070	: V=0.9762858, theta=-39.496729 -> V=1.0, theta=0.0
% INFO    : Bus 51071	: V=0.9702224, theta=-39.61503 -> V=1.0, theta=0.0
% INFO    : Bus 51072	: V=0.9693531, theta=-39.742582 -> V=1.0, theta=0.0
% INFO    : Bus 51073	: V=0.9678665, theta=-39.707981 -> V=1.0, theta=0.0
% INFO    : Bus 51074	: V=0.9645463, theta=-39.846541 -> V=1.0, theta=0.0
% INFO    : Bus 51075	: V=0.9650333, theta=-39.84545 -> V=1.0, theta=0.0
% INFO    : Bus 51076	: V=0.9681663, theta=-39.721322 -> V=1.0, theta=0.0
% INFO    : Bus 51077	: V=0.969052, theta=-39.844929 -> V=1.0, theta=0.0
% INFO    : Bus 51078	: V=0.9688748, theta=-39.81554 -> V=1.0, theta=0.0
% INFO    : Bus 51079	: V=0.9835516, theta=-38.808855 -> V=1.0, theta=0.0
% INFO    : Bus 51080	: V=0.9709821, theta=-39.922996 -> V=1.0, theta=0.0
% INFO    : Bus 51081	: V=0.9784919, theta=-39.450699 -> V=1.0, theta=0.0
% INFO    : Bus 51082	: V=0.9697916, theta=-39.963539 -> V=1.0, theta=0.0
% INFO    : Bus 51083	: V=1.0000947, theta=-38.795706 -> V=1.0, theta=0.0
% INFO    : Bus 51084	: V=0.9678455, theta=-40.142542 -> V=1.0, theta=0.0
% INFO    : Bus 51085	: V=0.9667243, theta=-40.136286 -> V=1.0, theta=0.0
% INFO    : Bus 51086	: V=0.9676513, theta=-40.207428 -> V=1.0, theta=0.0
% INFO    : Bus 51087	: V=0.9712266, theta=-40.061397 -> V=1.0, theta=0.0
% INFO    : Bus 51088	: V=0.9639673, theta=-39.9124 -> V=1.0, theta=0.0
% INFO    : Bus 51089	: V=0.9662863, theta=-39.919998 -> V=1.0, theta=0.0
% INFO    : Bus 51090	: V=0.9697078, theta=-39.919888 -> V=1.0, theta=0.0
% INFO    : Bus 51091	: V=0.9663998, theta=-39.839878 -> V=1.0, theta=0.0
% INFO    : Bus 51092	: V=0.9674382, theta=-39.759801 -> V=1.0, theta=0.0
% INFO    : Bus 51093	: V=0.9656316, theta=-39.851545 -> V=1.0, theta=0.0
% INFO    : Bus 51094	: V=0.9660027, theta=-39.82707 -> V=1.0, theta=0.0
% INFO    : Bus 51095	: V=0.9665753, theta=-39.800226 -> V=1.0, theta=0.0
% INFO    : Bus 51096	: V=0.9744544, theta=-39.044131 -> V=1.0, theta=0.0
% INFO    : Bus 51097	: V=0.9641659, theta=-39.857852 -> V=1.0, theta=0.0
% INFO    : Bus 51098	: V=0.9636795, theta=-39.864341 -> V=1.0, theta=0.0
% INFO    : Bus 51099	: V=0.9639266, theta=-39.845601 -> V=1.0, theta=0.0
% INFO    : Bus 51100	: V=0.9625992, theta=-39.864904 -> V=1.0, theta=0.0
% INFO    : Bus 51101	: V=0.9631477, theta=-39.820316 -> V=1.0, theta=0.0
% INFO    : Bus 51102	: V=0.9642037, theta=-39.766777 -> V=1.0, theta=0.0
% INFO    : Bus 51103	: V=0.9739419, theta=-38.673228 -> V=1.0, theta=0.0
% INFO    : Bus 51104	: V=0.9738624, theta=-38.905418 -> V=1.0, theta=0.0
% INFO    : Bus 51105	: V=0.9740138, theta=-38.762984 -> V=1.0, theta=0.0
% INFO    : Bus 51106	: V=0.9667131, theta=-39.607592 -> V=1.0, theta=0.0
% INFO    : Bus 51107	: V=0.9638153, theta=-39.815086 -> V=1.0, theta=0.0
% INFO    : Bus 51108	: V=0.9646344, theta=-39.834601 -> V=1.0, theta=0.0
% INFO    : Bus 51109	: V=0.9676055, theta=-39.626972 -> V=1.0, theta=0.0
% INFO    : Bus 51110	: V=0.9679404, theta=-39.608496 -> V=1.0, theta=0.0
% INFO    : Bus 51111	: V=0.9702514, theta=-39.483594 -> V=1.0, theta=0.0
% INFO    : Bus 51112	: V=0.9677311, theta=-39.674829 -> V=1.0, theta=0.0
% INFO    : Bus 51113	: V=0.9759356, theta=-39.100422 -> V=1.0, theta=0.0
% INFO    : Bus 51114	: V=0.9919998, theta=-38.710816 -> V=1.0, theta=0.0
% INFO    : Bus 51115	: V=0.9830178, theta=-38.764547 -> V=1.0, theta=0.0
% INFO    : Bus 51116	: V=0.9772377, theta=-39.211234 -> V=1.0, theta=0.0
% INFO    : Bus 51117	: V=0.9759938, theta=-39.272217 -> V=1.0, theta=0.0
% INFO    : Bus 51118	: V=0.975292, theta=-39.278267 -> V=1.0, theta=0.0
% INFO    : Bus 51119	: V=0.9764679, theta=-39.275621 -> V=1.0, theta=0.0
% INFO    : Bus 51120	: V=0.9747275, theta=-39.274374 -> V=1.0, theta=0.0
% INFO    : Bus 51121	: V=0.9775288, theta=-39.262733 -> V=1.0, theta=0.0
% INFO    : Bus 51122	: V=0.9900243, theta=-38.512389 -> V=1.0, theta=0.0
% INFO    : Bus 51123	: V=0.989467, theta=-38.618086 -> V=1.0, theta=0.0
% INFO    : Bus 51124	: V=0.9938661, theta=-38.769202 -> V=1.0, theta=0.0
% INFO    : Bus 51125	: V=0.9849274, theta=-39.219964 -> V=1.0, theta=0.0
% INFO    : Bus 51126	: V=0.9918145, theta=-38.287264 -> V=1.0, theta=0.0
% INFO    : Bus 51127	: V=0.9808002, theta=-38.848236 -> V=1.0, theta=0.0
% INFO    : Bus 51128	: V=0.9814573, theta=-38.828277 -> V=1.0, theta=0.0
% INFO    : Bus 51129	: V=0.9826609, theta=-38.820889 -> V=1.0, theta=0.0
% INFO    : Bus 51130	: V=0.9934616, theta=-38.02646 -> V=1.0, theta=0.0
% INFO    : Bus 51131	: V=0.9802868, theta=-38.860029 -> V=1.0, theta=0.0
% INFO    : Bus 51132	: V=0.9807451, theta=-38.82539 -> V=1.0, theta=0.0
% INFO    : Bus 51133	: V=0.9792399, theta=-38.853591 -> V=1.0, theta=0.0
% INFO    : Bus 51134	: V=0.9979713, theta=-37.66862 -> V=1.0, theta=0.0
% INFO    : Bus 51135	: V=0.9989271, theta=-37.62148 -> V=1.0, theta=0.0
% INFO    : Bus 51136	: V=0.9973595, theta=-37.922879 -> V=1.0, theta=0.0
% INFO    : Bus 51137	: V=0.9876059, theta=-38.788327 -> V=1.0, theta=0.0
% INFO    : Bus 51138	: V=0.9864089, theta=-38.907712 -> V=1.0, theta=0.0
% INFO    : Bus 51139	: V=0.9842888, theta=-38.811374 -> V=1.0, theta=0.0
% INFO    : Bus 51140	: V=0.9841949, theta=-38.592178 -> V=1.0, theta=0.0
% INFO    : Bus 51141	: V=1.0025862, theta=-38.73321 -> V=1.0, theta=0.0
% INFO    : Bus 51142	: V=0.997513, theta=-39.337958 -> V=1.0, theta=0.0
% INFO    : Bus 51143	: V=0.9994416, theta=-38.776229 -> V=1.0, theta=0.0
% INFO    : Bus 51144	: V=0.9718594, theta=-40.016978 -> V=1.0, theta=0.0
% INFO    : Bus 51145	: V=0.9621331, theta=-40.384414 -> V=1.0, theta=0.0
% INFO    : Bus 51146	: V=0.9619003, theta=-40.359802 -> V=1.0, theta=0.0
% INFO    : Bus 51147	: V=0.9748485, theta=-39.38494 -> V=1.0, theta=0.0
% INFO    : Bus 51148	: V=0.9749624, theta=-38.456476 -> V=1.0, theta=0.0
% INFO    : Bus 51149	: V=0.9694739, theta=-38.735655 -> V=1.0, theta=0.0
% INFO    : Bus 51150	: V=0.9739789, theta=-38.904422 -> V=1.0, theta=0.0
% INFO    : Bus 51151	: V=0.9632641, theta=-39.865547 -> V=1.0, theta=0.0
% INFO    : Bus 51152	: V=0.96427, theta=-40.334069 -> V=1.0, theta=0.0
% INFO    : Bus 51153	: V=0.9670508, theta=-39.545568 -> V=1.0, theta=0.0
% INFO    : Bus 51154	: V=0.9649369, theta=-39.721273 -> V=1.0, theta=0.0
% INFO    : Bus 51155	: V=0.9643653, theta=-39.722035 -> V=1.0, theta=0.0
% INFO    : Bus 51156	: V=0.9644194, theta=-39.760488 -> V=1.0, theta=0.0
% INFO    : Bus 51157	: V=0.9642304, theta=-39.775795 -> V=1.0, theta=0.0
% INFO    : Bus 51158	: V=0.9783024, theta=-38.941439 -> V=1.0, theta=0.0
% INFO    : Bus 51159	: V=0.9803444, theta=-38.881282 -> V=1.0, theta=0.0
% INFO    : Bus 51160	: V=0.968247, theta=-39.227556 -> V=1.0, theta=0.0
% INFO    : Bus 51161	: V=0.9615087, theta=-39.141169 -> V=1.0, theta=0.0
% INFO    : Bus 51162	: V=0.9937145, theta=-37.065286 -> V=1.0, theta=0.0
% INFO    : Bus 51163	: V=0.9945767, theta=-37.500888 -> V=1.0, theta=0.0
% INFO    : Bus 51164	: V=0.9950799, theta=-36.728745 -> V=1.0, theta=0.0
% INFO    : Bus 51165	: V=1.0010493, theta=-36.8887 -> V=1.0, theta=0.0
% INFO    : Bus 51166	: V=0.9744445, theta=-38.721746 -> V=1.0, theta=0.0
% INFO    : Bus 51167	: V=0.9648548, theta=-38.944082 -> V=1.0, theta=0.0
% INFO    : Bus 51168	: V=0.9658442, theta=-39.66842 -> V=1.0, theta=0.0
% INFO    : Bus 51169	: V=0.966766, theta=-39.607809 -> V=1.0, theta=0.0
% INFO    : Bus 51170	: V=0.9928046, theta=-56.899179 -> V=1.0, theta=0.0
% INFO    : Bus 51171	: V=0.9888508, theta=-57.079425 -> V=1.0, theta=0.0
% INFO    : Bus 51172	: V=0.971725, theta=-58.29864 -> V=1.0, theta=0.0
% INFO    : Bus 51173	: V=0.9862653, theta=-57.255878 -> V=1.0, theta=0.0
% INFO    : Bus 51174	: V=0.9881174, theta=-57.152854 -> V=1.0, theta=0.0
% INFO    : Bus 51175	: V=0.9856012, theta=-15.889607 -> V=1.0, theta=0.0
% INFO    : Bus 51176	: V=0.9861836, theta=-15.880834 -> V=1.0, theta=0.0
% INFO    : Bus 51177	: V=0.9874759, theta=-15.87845 -> V=1.0, theta=0.0
% INFO    : Bus 51178	: V=1.0076785, theta=-14.598698 -> V=1.0, theta=0.0
% INFO    : Bus 51179	: V=0.9894622, theta=-15.748079 -> V=1.0, theta=0.0
% INFO    : Bus 51180	: V=0.9935561, theta=-15.684676 -> V=1.0, theta=0.0
% INFO    : Bus 51181	: V=0.9910012, theta=-15.784868 -> V=1.0, theta=0.0
% INFO    : Bus 51182	: V=0.9900428, theta=-15.822289 -> V=1.0, theta=0.0
% INFO    : Bus 51183	: V=0.9881034, theta=-15.851958 -> V=1.0, theta=0.0
% INFO    : Bus 51184	: V=0.9886022, theta=-15.839194 -> V=1.0, theta=0.0
% INFO    : Bus 51185	: V=0.9868392, theta=-15.894427 -> V=1.0, theta=0.0
% INFO    : Bus 51186	: V=0.9863086, theta=-15.890522 -> V=1.0, theta=0.0
% INFO    : Bus 51187	: V=0.9862499, theta=-15.898884 -> V=1.0, theta=0.0
% INFO    : Bus 51188	: V=0.985599, theta=-15.906072 -> V=1.0, theta=0.0
% INFO    : Bus 51189	: V=0.985908, theta=-15.893947 -> V=1.0, theta=0.0
% INFO    : Bus 51190	: V=0.9865195, theta=-15.877059 -> V=1.0, theta=0.0
% INFO    : Bus 51191	: V=0.9863665, theta=-15.885019 -> V=1.0, theta=0.0
% INFO    : Bus 51192	: V=0.9883537, theta=-15.844736 -> V=1.0, theta=0.0
% INFO    : Bus 51193	: V=0.9888118, theta=-15.773383 -> V=1.0, theta=0.0
% INFO    : Bus 51194	: V=0.987273, theta=-15.848651 -> V=1.0, theta=0.0
% INFO    : Bus 51195	: V=0.9882883, theta=-15.808024 -> V=1.0, theta=0.0
% INFO    : Bus 51196	: V=0.9996624, theta=-14.880917 -> V=1.0, theta=0.0
% INFO    : Bus 51197	: V=0.9875495, theta=-15.855442 -> V=1.0, theta=0.0
% INFO    : Bus 51198	: V=0.9882056, theta=-15.863104 -> V=1.0, theta=0.0
% INFO    : Bus 51199	: V=0.9853235, theta=-15.89397 -> V=1.0, theta=0.0
% INFO    : Bus 51200	: V=0.9855431, theta=-15.872118 -> V=1.0, theta=0.0
% INFO    : Bus 51201	: V=0.9873366, theta=-15.845338 -> V=1.0, theta=0.0
% INFO    : Bus 51202	: V=0.9886431, theta=-15.813111 -> V=1.0, theta=0.0
% INFO    : Bus 51203	: V=0.9913099, theta=-15.715668 -> V=1.0, theta=0.0
% INFO    : Bus 51204	: V=0.9887762, theta=-15.904003 -> V=1.0, theta=0.0
% INFO    : Bus 51205	: V=0.9855771, theta=-15.896104 -> V=1.0, theta=0.0
% INFO    : Bus 51206	: V=0.9832319, theta=-15.983098 -> V=1.0, theta=0.0
% INFO    : Bus 51207	: V=1.003124, theta=-14.925557 -> V=1.0, theta=0.0
% INFO    : Bus 51208	: V=0.9873483, theta=-15.539636 -> V=1.0, theta=0.0
% INFO    : Bus 51209	: V=0.9846617, theta=-15.896693 -> V=1.0, theta=0.0
% INFO    : Bus 51210	: V=0.9866629, theta=-15.903052 -> V=1.0, theta=0.0
% INFO    : Bus 51211	: V=0.9909147, theta=-15.714723 -> V=1.0, theta=0.0
% INFO    : Bus 51212	: V=1.0005559, theta=-14.959754 -> V=1.0, theta=0.0
% INFO    : Bus 51213	: V=1.0086029, theta=-14.780577 -> V=1.0, theta=0.0
% INFO    : Bus 51214	: V=1.0005099, theta=-14.846619 -> V=1.0, theta=0.0
% INFO    : Bus 51215	: V=0.9870715, theta=-16.431419 -> V=1.0, theta=0.0
% INFO    : Bus 51216	: V=0.987212, theta=-15.866578 -> V=1.0, theta=0.0
% INFO    : Bus 51217	: V=0.987005, theta=-15.88388 -> V=1.0, theta=0.0
% INFO    : Bus 51218	: V=0.9825343, theta=-49.105798 -> V=1.0, theta=0.0
% INFO    : Bus 51219	: V=0.9842547, theta=-49.240151 -> V=1.0, theta=0.0
% INFO    : Bus 51220	: V=0.9725524, theta=-51.360855 -> V=1.0, theta=0.0
% INFO    : Bus 51221	: V=0.9730745, theta=-52.137959 -> V=1.0, theta=0.0
% INFO    : Bus 51222	: V=1.0102796, theta=-38.606432 -> V=1.0, theta=0.0
% INFO    : Bus 51223	: V=1.0129602, theta=-36.756158 -> V=1.0, theta=0.0
% INFO    : Bus 51224	: V=0.9905532, theta=-44.996662 -> V=1.0, theta=0.0
% INFO    : Bus 51225	: V=0.9899032, theta=-45.70232 -> V=1.0, theta=0.0
% INFO    : Bus 51226	: V=1.0072065, theta=-55.56319 -> V=1.0, theta=0.0
% INFO    : Bus 51227	: V=1.0177553, theta=-53.323883 -> V=1.0, theta=0.0
% INFO    : Bus 51228	: V=0.9801042, theta=-57.861912 -> V=1.0, theta=0.0
% INFO    : Bus 51229	: V=0.9781629, theta=-39.543857 -> V=1.0, theta=0.0
% INFO    : Bus 51230	: V=0.9928208, theta=-40.86962 -> V=1.0, theta=0.0
% INFO    : Bus 51231	: V=0.9787484, theta=-42.19056 -> V=1.0, theta=0.0
% INFO    : Bus 51232	: V=0.9905225, theta=-40.282979 -> V=1.0, theta=0.0
% INFO    : Bus 51233	: V=0.988481, theta=-39.991911 -> V=1.0, theta=0.0
% INFO    : Bus 51234	: V=0.9905053, theta=-38.807901 -> V=1.0, theta=0.0
% INFO    : Bus 51235	: V=0.9737601, theta=-50.447702 -> V=1.0, theta=0.0
% INFO    : Bus 51236	: V=0.9523297, theta=-52.770318 -> V=1.0, theta=0.0
% INFO    : Bus 51237	: V=0.9949951, theta=-46.745943 -> V=1.0, theta=0.0
% INFO    : Bus 51238	: V=0.9968902, theta=-18.91912 -> V=1.0, theta=0.0
% INFO    : Bus 51239	: V=0.9998409, theta=-19.432863 -> V=1.0, theta=0.0
% INFO    : Bus 51240	: V=0.9768422, theta=-53.871835 -> V=1.0, theta=0.0
% INFO    : Bus 51241	: V=1.0000058, theta=-25.342262 -> V=1.0, theta=0.0
% INFO    : Bus 51242	: V=0.9949696, theta=-23.510565 -> V=1.0, theta=0.0
% INFO    : Bus 51243	: V=0.9918699, theta=-52.888588 -> V=1.0, theta=0.0
% INFO    : Bus 51244	: V=0.9832896, theta=-21.144389 -> V=1.0, theta=0.0
% INFO    : Bus 51245	: V=0.9780072, theta=-23.970901 -> V=1.0, theta=0.0
% INFO    : Bus 51246	: V=0.9750604, theta=-24.014145 -> V=1.0, theta=0.0
% INFO    : Bus 51247	: V=0.9759982, theta=-24.393965 -> V=1.0, theta=0.0
% INFO    : Bus 51248	: V=0.995135, theta=-22.150201 -> V=1.0, theta=0.0
% INFO    : Bus 51249	: V=0.9865482, theta=-22.57965 -> V=1.0, theta=0.0
% INFO    : Bus 51250	: V=0.9948717, theta=-8.362414 -> V=1.0, theta=0.0
% INFO    : Bus 51251	: V=0.9932103, theta=-8.555742 -> V=1.0, theta=0.0
% INFO    : Bus 51252	: V=1.0085591, theta=-7.287686 -> V=1.0, theta=0.0
% INFO    : Bus 51253	: V=0.9974614, theta=-8.288415 -> V=1.0, theta=0.0
% INFO    : Bus 51254	: V=0.9970165, theta=-8.324619 -> V=1.0, theta=0.0
% INFO    : Bus 51255	: V=0.9967663, theta=-8.370881 -> V=1.0, theta=0.0
% INFO    : Bus 51256	: V=0.9965707, theta=-8.361078 -> V=1.0, theta=0.0
% INFO    : Bus 51257	: V=0.9962704, theta=-8.347944 -> V=1.0, theta=0.0
% INFO    : Bus 51258	: V=0.9941769, theta=-8.506611 -> V=1.0, theta=0.0
% INFO    : Bus 51259	: V=0.994502, theta=-8.470044 -> V=1.0, theta=0.0
% INFO    : Bus 51260	: V=0.9941441, theta=-8.434054 -> V=1.0, theta=0.0
% INFO    : Bus 51261	: V=0.9938247, theta=-8.466493 -> V=1.0, theta=0.0
% INFO    : Bus 51262	: V=0.9954267, theta=-8.400854 -> V=1.0, theta=0.0
% INFO    : Bus 51263	: V=0.9959845, theta=-8.417371 -> V=1.0, theta=0.0
% INFO    : Bus 51264	: V=0.995247, theta=-8.500723 -> V=1.0, theta=0.0
% INFO    : Bus 51265	: V=0.995351, theta=-8.48257 -> V=1.0, theta=0.0
% INFO    : Bus 51266	: V=0.9945692, theta=-8.454936 -> V=1.0, theta=0.0
% INFO    : Bus 51267	: V=0.9936031, theta=-8.49103 -> V=1.0, theta=0.0
% INFO    : Bus 51268	: V=0.9920855, theta=-8.608664 -> V=1.0, theta=0.0
% INFO    : Bus 51269	: V=0.9933687, theta=-8.519088 -> V=1.0, theta=0.0
% INFO    : Bus 51270	: V=0.9931834, theta=-8.541016 -> V=1.0, theta=0.0
% INFO    : Bus 51271	: V=0.9940369, theta=-8.495413 -> V=1.0, theta=0.0
% INFO    : Bus 51272	: V=0.992106, theta=-8.767171 -> V=1.0, theta=0.0
% INFO    : Bus 51273	: V=0.9943201, theta=-8.486884 -> V=1.0, theta=0.0
% INFO    : Bus 51274	: V=0.9922326, theta=-8.609224 -> V=1.0, theta=0.0
% INFO    : Bus 51275	: V=0.990956, theta=-8.703397 -> V=1.0, theta=0.0
% INFO    : Bus 51276	: V=0.9948407, theta=-8.469405 -> V=1.0, theta=0.0
% INFO    : Bus 51277	: V=0.9908038, theta=-8.902382 -> V=1.0, theta=0.0
% INFO    : Bus 51278	: V=0.9860866, theta=-9.292538 -> V=1.0, theta=0.0
% INFO    : Bus 51279	: V=0.9939498, theta=-8.517034 -> V=1.0, theta=0.0
% INFO    : Bus 51280	: V=0.9893284, theta=-8.83512 -> V=1.0, theta=0.0
% INFO    : Bus 51281	: V=0.9795947, theta=-9.693344 -> V=1.0, theta=0.0
% INFO    : Bus 51282	: V=0.9819742, theta=-9.595437 -> V=1.0, theta=0.0
% INFO    : Bus 51283	: V=0.9816643, theta=-9.593772 -> V=1.0, theta=0.0
% INFO    : Bus 51284	: V=0.9833632, theta=-9.503959 -> V=1.0, theta=0.0
% INFO    : Bus 51285	: V=0.9856624, theta=-9.291286 -> V=1.0, theta=0.0
% INFO    : Bus 51286	: V=0.9865062, theta=-9.498702 -> V=1.0, theta=0.0
% INFO    : Bus 51287	: V=0.9854007, theta=-9.381716 -> V=1.0, theta=0.0
% INFO    : Bus 51288	: V=1.0102578, theta=-7.139768 -> V=1.0, theta=0.0
% INFO    : Bus 51289	: V=0.9962721, theta=-8.427008 -> V=1.0, theta=0.0
% INFO    : Bus 51290	: V=0.9939054, theta=-8.649838 -> V=1.0, theta=0.0
% INFO    : Bus 51291	: V=0.993718, theta=-8.646417 -> V=1.0, theta=0.0
% INFO    : Bus 51292	: V=0.9853351, theta=-9.644082 -> V=1.0, theta=0.0
% INFO    : Bus 51293	: V=0.9843314, theta=-9.808044 -> V=1.0, theta=0.0
% INFO    : Bus 51294	: V=0.9878262, theta=-9.481431 -> V=1.0, theta=0.0
% INFO    : Bus 51295	: V=0.988356, theta=-9.388184 -> V=1.0, theta=0.0
% INFO    : Bus 51296	: V=0.9867433, theta=-9.510651 -> V=1.0, theta=0.0
% INFO    : Bus 51297	: V=0.9875011, theta=-9.445125 -> V=1.0, theta=0.0
% INFO    : Bus 51298	: V=0.9942844, theta=-8.648251 -> V=1.0, theta=0.0
% INFO    : Bus 51299	: V=0.9886017, theta=-9.349753 -> V=1.0, theta=0.0
% INFO    : Bus 51300	: V=0.9950119, theta=-8.608431 -> V=1.0, theta=0.0
% INFO    : Bus 51301	: V=0.9965583, theta=-8.489989 -> V=1.0, theta=0.0
% INFO    : Bus 51302	: V=0.9929109, theta=-9.028005 -> V=1.0, theta=0.0
% INFO    : Bus 51303	: V=0.9918224, theta=-9.130667 -> V=1.0, theta=0.0
% INFO    : Bus 51304	: V=0.9970004, theta=-8.37726 -> V=1.0, theta=0.0
% INFO    : Bus 51305	: V=0.9982677, theta=-8.280978 -> V=1.0, theta=0.0
% INFO    : Bus 51306	: V=0.9917742, theta=-9.082073 -> V=1.0, theta=0.0
% INFO    : Bus 51307	: V=0.9881807, theta=-9.765988 -> V=1.0, theta=0.0
% INFO    : Bus 51308	: V=0.9873423, theta=-9.427887 -> V=1.0, theta=0.0
% INFO    : Bus 51309	: V=0.9870866, theta=-9.437335 -> V=1.0, theta=0.0
% INFO    : Bus 51310	: V=0.9873454, theta=-9.836078 -> V=1.0, theta=0.0
% INFO    : Bus 51311	: V=0.990584, theta=-9.397727 -> V=1.0, theta=0.0
% INFO    : Bus 51312	: V=0.9754334, theta=-10.406272 -> V=1.0, theta=0.0
% INFO    : Bus 51313	: V=0.9894825, theta=-9.976324 -> V=1.0, theta=0.0
% INFO    : Bus 51314	: V=0.9761525, theta=-10.359333 -> V=1.0, theta=0.0
% INFO    : Bus 51315	: V=0.9827972, theta=-9.437441 -> V=1.0, theta=0.0
% INFO    : Bus 51316	: V=0.9808345, theta=-9.526815 -> V=1.0, theta=0.0
% INFO    : Bus 51317	: V=0.9872493, theta=-9.014219 -> V=1.0, theta=0.0
% INFO    : Bus 51318	: V=1.012982, theta=-34.172999 -> V=1.0, theta=0.0
% INFO    : Bus 51319	: V=1.016625, theta=-34.687249 -> V=1.0, theta=0.0
% INFO    : Bus 51320	: V=1.0153503, theta=-33.940567 -> V=1.0, theta=0.0
% INFO    : Bus 51321	: V=1.0182246, theta=-34.598655 -> V=1.0, theta=0.0
% INFO    : Bus 51322	: V=1.0153441, theta=-34.756985 -> V=1.0, theta=0.0
% INFO    : Bus 51323	: V=1.0149481, theta=-34.347882 -> V=1.0, theta=0.0
% INFO    : Bus 51324	: V=1.0153741, theta=-34.536342 -> V=1.0, theta=0.0
% INFO    : Bus 51325	: V=1.0152556, theta=-34.784901 -> V=1.0, theta=0.0
% INFO    : Bus 51326	: V=1.0157528, theta=-35.46776 -> V=1.0, theta=0.0
% INFO    : Bus 51327	: V=0.9935953, theta=-4.978415 -> V=1.0, theta=0.0
% INFO    : Bus 51328	: V=0.9920247, theta=-5.753473 -> V=1.0, theta=0.0
% INFO    : Bus 51329	: V=0.9909639, theta=-6.233807 -> V=1.0, theta=0.0
% INFO    : Bus 51330	: V=1.0073163, theta=-40.188771 -> V=1.0, theta=0.0
% INFO    : Bus 51331	: V=0.9602096, theta=-44.461192 -> V=1.0, theta=0.0
% INFO    : Bus 51332	: V=1.0334519, theta=-31.056003 -> V=1.0, theta=0.0
% INFO    : Bus 51333	: V=0.9909359, theta=-11.847983 -> V=1.0, theta=0.0
% INFO    : Bus 51334	: V=0.9902844, theta=-12.34159 -> V=1.0, theta=0.0
% INFO    : Bus 51335	: V=0.9795405, theta=-27.351898 -> V=1.0, theta=0.0
% INFO    : Bus 51336	: V=0.9764714, theta=-29.764697 -> V=1.0, theta=0.0
% INFO    : Bus 51337	: V=0.9769282, theta=-31.249702 -> V=1.0, theta=0.0
% INFO    : Bus 51338	: V=1.0106604, theta=-4.648257 -> V=1.0, theta=0.0
% INFO    : Bus 51339	: V=1.0189285, theta=-24.255729 -> V=1.0, theta=0.0
% INFO    : Bus 51340	: V=1.0114269, theta=-31.326689 -> V=1.0, theta=0.0
% INFO    : Bus 51341	: V=1.0038664, theta=-39.968343 -> V=1.0, theta=0.0
% INFO    : Bus 51342	: V=1.009735, theta=-34.028547 -> V=1.0, theta=0.0
% INFO    : Bus 51343	: V=1.0064627, theta=-37.657374 -> V=1.0, theta=0.0
% INFO    : Bus 51344	: V=1.0105349, theta=-34.622027 -> V=1.0, theta=0.0
% INFO    : Bus 51345	: V=1.0077906, theta=-38.404592 -> V=1.0, theta=0.0
% INFO    : Bus 51346	: V=1.0095524, theta=-37.686526 -> V=1.0, theta=0.0
% INFO    : Bus 51347	: V=1.0076026, theta=-37.570167 -> V=1.0, theta=0.0
% INFO    : Bus 51348	: V=1.0072596, theta=-37.621062 -> V=1.0, theta=0.0
% INFO    : Bus 51349	: V=1.008504, theta=-38.323959 -> V=1.0, theta=0.0
% INFO    : Bus 51350	: V=1.0100651, theta=-38.115593 -> V=1.0, theta=0.0
% INFO    : Bus 51351	: V=0.9913005, theta=4.739864 -> V=1.0, theta=0.0
% INFO    : Bus 51352	: V=0.9980961, theta=5.440399 -> V=1.0, theta=0.0
% INFO    : Bus 51353	: V=0.989306, theta=4.24717 -> V=1.0, theta=0.0
% INFO    : Bus 51354	: V=0.9885423, theta=-12.950948 -> V=1.0, theta=0.0
% INFO    : Bus 51355	: V=0.9867783, theta=-13.317411 -> V=1.0, theta=0.0
% INFO    : Bus 51356	: V=0.9851185, theta=-14.472117 -> V=1.0, theta=0.0
% INFO    : Bus 51357	: V=0.9888355, theta=1.935929 -> V=1.0, theta=0.0
% INFO    : Bus 51358	: V=0.9919137, theta=1.653057 -> V=1.0, theta=0.0
% INFO    : Bus 51359	: V=0.9770848, theta=-7.863647 -> V=1.0, theta=0.0
% INFO    : Bus 51360	: V=0.9805864, theta=-6.301814 -> V=1.0, theta=0.0
% INFO    : Bus 51361	: V=1.011354, theta=0.771827 -> V=1.0, theta=0.0
% INFO    : Bus 51362	: V=0.9907188, theta=1.51261 -> V=1.0, theta=0.0
% INFO    : Bus 51363	: V=0.9780194, theta=1.949875 -> V=1.0, theta=0.0
% INFO    : Bus 51364	: V=0.9897164, theta=-0.534283 -> V=1.0, theta=0.0
% INFO    : Bus 51365	: V=0.9856355, theta=-44.237981 -> V=1.0, theta=0.0
% INFO    : Bus 51366	: V=1.0135008, theta=-15.042315 -> V=1.0, theta=0.0
% INFO    : Bus 51367	: V=1.0111634, theta=-24.103001 -> V=1.0, theta=0.0
% INFO    : Bus 51368	: V=0.9815823, theta=-40.039905 -> V=1.0, theta=0.0
% INFO    : Bus 51369	: V=0.9798073, theta=-42.070408 -> V=1.0, theta=0.0
% INFO    : Bus 51370	: V=0.9795344, theta=-42.123562 -> V=1.0, theta=0.0
% INFO    : Bus 51371	: V=1.0153946, theta=-33.887242 -> V=1.0, theta=0.0
% INFO    : Bus 51372	: V=1.0154375, theta=-33.773942 -> V=1.0, theta=0.0
% INFO    : Bus 51373	: V=0.9747766, theta=-3.535045 -> V=1.0, theta=0.0
% INFO    : Bus 51374	: V=0.9715738, theta=-4.19087 -> V=1.0, theta=0.0
% INFO    : Bus 51375	: V=0.9698267, theta=-4.515137 -> V=1.0, theta=0.0
% INFO    : Bus 51376	: V=0.9713631, theta=-2.002977 -> V=1.0, theta=0.0
% INFO    : Bus 51377	: V=0.9840128, theta=2.443329 -> V=1.0, theta=0.0
% INFO    : Bus 51378	: V=0.9719955, theta=-0.392439 -> V=1.0, theta=0.0
% INFO    : Bus 51379	: V=1.0330469, theta=-26.796827 -> V=1.0, theta=0.0
% INFO    : Bus 51380	: V=1.0178144, theta=-36.640023 -> V=1.0, theta=0.0
% INFO    : Bus 51381	: V=1.0263154, theta=-30.472621 -> V=1.0, theta=0.0
% INFO    : Bus 51382	: V=1.0257988, theta=-31.222618 -> V=1.0, theta=0.0
% INFO    : Bus 51383	: V=0.9998063, theta=8.930752 -> V=1.0, theta=0.0
% INFO    : Bus 51384	: V=1.000689, theta=9.081587 -> V=1.0, theta=0.0
% INFO    : Bus 51385	: V=0.9990381, theta=8.163427 -> V=1.0, theta=0.0
% INFO    : Bus 51386	: V=0.9907131, theta=5.980091 -> V=1.0, theta=0.0
% INFO    : Bus 51387	: V=0.9892029, theta=-22.37038 -> V=1.0, theta=0.0
% INFO    : Bus 51388	: V=0.9902235, theta=-19.634497 -> V=1.0, theta=0.0
% INFO    : Bus 51389	: V=1.0031472, theta=-42.963386 -> V=1.0, theta=0.0
% INFO    : Bus 51390	: V=1.0141697, theta=-42.016538 -> V=1.0, theta=0.0
% INFO    : Bus 51391	: V=1.0146208, theta=-41.914193 -> V=1.0, theta=0.0
% INFO    : Bus 51392	: V=1.0139741, theta=-42.00636 -> V=1.0, theta=0.0
% INFO    : Bus 51393	: V=1.0153701, theta=-41.791199 -> V=1.0, theta=0.0
% INFO    : Bus 51394	: V=1.0150342, theta=-43.042516 -> V=1.0, theta=0.0
% INFO    : Bus 51395	: V=1.0129237, theta=-42.810412 -> V=1.0, theta=0.0
% INFO    : Bus 51396	: V=0.9848406, theta=-42.031764 -> V=1.0, theta=0.0
% INFO    : Bus 51397	: V=0.9862396, theta=7.567965 -> V=1.0, theta=0.0
% INFO    : Bus 51398	: V=0.984581, theta=3.683063 -> V=1.0, theta=0.0
% INFO    : Bus 51399	: V=0.9861506, theta=2.643384 -> V=1.0, theta=0.0
% INFO    : Bus 51400	: V=0.9718392, theta=-1.325703 -> V=1.0, theta=0.0
% INFO    : Bus 51401	: V=1.0036216, theta=3.635447 -> V=1.0, theta=0.0
% INFO    : Bus 51402	: V=1.0014121, theta=2.968359 -> V=1.0, theta=0.0
% INFO    : Bus 51403	: V=0.9991858, theta=2.23317 -> V=1.0, theta=0.0
% INFO    : Bus 51404	: V=1.0041273, theta=3.347595 -> V=1.0, theta=0.0
% INFO    : Bus 51405	: V=1.0025784, theta=3.069657 -> V=1.0, theta=0.0
% INFO    : Bus 51406	: V=1.0005696, theta=2.53957 -> V=1.0, theta=0.0
% INFO    : Bus 51407	: V=1.0006363, theta=2.884669 -> V=1.0, theta=0.0
% INFO    : Bus 51408	: V=0.9992028, theta=4.169028 -> V=1.0, theta=0.0
% INFO    : Bus 51409	: V=0.9965136, theta=4.036958 -> V=1.0, theta=0.0
% INFO    : Bus 51410	: V=1.0191933, theta=5.790737 -> V=1.0, theta=0.0
% INFO    : Bus 51411	: V=1.0008472, theta=4.412836 -> V=1.0, theta=0.0
% INFO    : Bus 51412	: V=0.996168, theta=4.037432 -> V=1.0, theta=0.0
% INFO    : Bus 51413	: V=0.9994811, theta=4.313355 -> V=1.0, theta=0.0
% INFO    : Bus 51414	: V=0.9941401, theta=3.90429 -> V=1.0, theta=0.0
% INFO    : Bus 51415	: V=0.9913793, theta=3.73721 -> V=1.0, theta=0.0
% INFO    : Bus 51416	: V=0.9917985, theta=3.749914 -> V=1.0, theta=0.0
% INFO    : Bus 51417	: V=1.0013186, theta=4.279504 -> V=1.0, theta=0.0
% INFO    : Bus 51418	: V=1.0023955, theta=4.292173 -> V=1.0, theta=0.0
% INFO    : Bus 51419	: V=0.9935543, theta=3.724036 -> V=1.0, theta=0.0
% INFO    : Bus 51420	: V=1.002817, theta=4.177873 -> V=1.0, theta=0.0
% INFO    : Bus 51421	: V=0.9946513, theta=3.828165 -> V=1.0, theta=0.0
% INFO    : Bus 51422	: V=1.0197095, theta=4.563086 -> V=1.0, theta=0.0
% INFO    : Bus 51423	: V=1.0135822, theta=4.343448 -> V=1.0, theta=0.0
% INFO    : Bus 51424	: V=1.003054, theta=4.183412 -> V=1.0, theta=0.0
% INFO    : Bus 51425	: V=1.0032149, theta=4.197451 -> V=1.0, theta=0.0
% INFO    : Bus 51426	: V=1.0019103, theta=3.880371 -> V=1.0, theta=0.0
% INFO    : Bus 51427	: V=1.0033339, theta=4.171039 -> V=1.0, theta=0.0
% INFO    : Bus 51428	: V=1.003518, theta=4.159727 -> V=1.0, theta=0.0
% INFO    : Bus 51429	: V=0.997948, theta=3.690513 -> V=1.0, theta=0.0
% INFO    : Bus 51430	: V=0.9968144, theta=3.672697 -> V=1.0, theta=0.0
% INFO    : Bus 51431	: V=1.0034225, theta=4.014629 -> V=1.0, theta=0.0
% INFO    : Bus 51432	: V=1.0000951, theta=3.788492 -> V=1.0, theta=0.0
% INFO    : Bus 51433	: V=0.9926894, theta=3.672594 -> V=1.0, theta=0.0
% INFO    : Bus 51434	: V=0.9925965, theta=3.550889 -> V=1.0, theta=0.0
% INFO    : Bus 51435	: V=0.9942133, theta=3.597812 -> V=1.0, theta=0.0
% INFO    : Bus 51436	: V=0.9879555, theta=3.345759 -> V=1.0, theta=0.0
% INFO    : Bus 51437	: V=0.9868422, theta=3.299201 -> V=1.0, theta=0.0
% INFO    : Bus 51438	: V=0.9882301, theta=3.405701 -> V=1.0, theta=0.0
% INFO    : Bus 51439	: V=0.9903391, theta=3.482983 -> V=1.0, theta=0.0
% INFO    : Bus 51440	: V=0.9923617, theta=3.658907 -> V=1.0, theta=0.0
% INFO    : Bus 51441	: V=0.9925702, theta=3.65768 -> V=1.0, theta=0.0
% INFO    : Bus 51442	: V=0.989327, theta=3.492704 -> V=1.0, theta=0.0
% INFO    : Bus 51443	: V=0.9890044, theta=3.498587 -> V=1.0, theta=0.0
% INFO    : Bus 51444	: V=0.9885524, theta=3.461034 -> V=1.0, theta=0.0
% INFO    : Bus 51445	: V=0.9880027, theta=3.462139 -> V=1.0, theta=0.0
% INFO    : Bus 51446	: V=0.9867162, theta=3.339949 -> V=1.0, theta=0.0
% INFO    : Bus 51447	: V=0.9868446, theta=3.372506 -> V=1.0, theta=0.0
% INFO    : Bus 51448	: V=0.9955712, theta=4.096315 -> V=1.0, theta=0.0
% INFO    : Bus 51449	: V=0.995209, theta=4.076359 -> V=1.0, theta=0.0
% INFO    : Bus 51450	: V=0.9891894, theta=3.54933 -> V=1.0, theta=0.0
% INFO    : Bus 51451	: V=0.9886838, theta=3.551014 -> V=1.0, theta=0.0
% INFO    : Bus 51452	: V=0.9911371, theta=3.727181 -> V=1.0, theta=0.0
% INFO    : Bus 51453	: V=0.9910721, theta=3.719019 -> V=1.0, theta=0.0
% INFO    : Bus 51454	: V=0.9906302, theta=3.69967 -> V=1.0, theta=0.0
% INFO    : Bus 51455	: V=0.9964125, theta=4.147922 -> V=1.0, theta=0.0
% INFO    : Bus 51456	: V=0.9874277, theta=3.484526 -> V=1.0, theta=0.0
% INFO    : Bus 51457	: V=0.9887239, theta=3.590038 -> V=1.0, theta=0.0
% INFO    : Bus 51458	: V=0.9975699, theta=4.215176 -> V=1.0, theta=0.0
% INFO    : Bus 51459	: V=0.998119, theta=4.247841 -> V=1.0, theta=0.0
% INFO    : Bus 51460	: V=0.99201, theta=3.745782 -> V=1.0, theta=0.0
% INFO    : Bus 51461	: V=0.9988094, theta=4.288275 -> V=1.0, theta=0.0
% INFO    : Bus 51462	: V=0.9992982, theta=4.343925 -> V=1.0, theta=0.0
% INFO    : Bus 51463	: V=0.9996963, theta=4.344265 -> V=1.0, theta=0.0
% INFO    : Bus 51464	: V=1.0010963, theta=4.415213 -> V=1.0, theta=0.0
% INFO    : Bus 51465	: V=0.9988014, theta=4.345913 -> V=1.0, theta=0.0
% INFO    : Bus 51466	: V=0.9901874, theta=3.653884 -> V=1.0, theta=0.0
% INFO    : Bus 51467	: V=0.9893354, theta=3.617615 -> V=1.0, theta=0.0
% INFO    : Bus 51468	: V=0.9859878, theta=3.346621 -> V=1.0, theta=0.0
% INFO    : Bus 51469	: V=0.9942485, theta=4.054712 -> V=1.0, theta=0.0
% INFO    : Bus 51470	: V=0.9851903, theta=3.323318 -> V=1.0, theta=0.0
% INFO    : Bus 51471	: V=0.9908547, theta=3.667171 -> V=1.0, theta=0.0
% INFO    : Bus 51472	: V=0.9903037, theta=3.655947 -> V=1.0, theta=0.0
% INFO    : Bus 51473	: V=0.9842833, theta=3.170758 -> V=1.0, theta=0.0
% INFO    : Bus 51474	: V=0.9856697, theta=3.340888 -> V=1.0, theta=0.0
% INFO    : Bus 51475	: V=0.9853701, theta=3.33818 -> V=1.0, theta=0.0
% INFO    : Bus 51476	: V=0.9909821, theta=3.418705 -> V=1.0, theta=0.0
% INFO    : Bus 51477	: V=0.9880511, theta=3.242933 -> V=1.0, theta=0.0
% INFO    : Bus 51478	: V=0.9841343, theta=2.883554 -> V=1.0, theta=0.0
% INFO    : Bus 51479	: V=0.9828302, theta=2.636922 -> V=1.0, theta=0.0
% INFO    : Bus 51480	: V=0.9818279, theta=2.650165 -> V=1.0, theta=0.0
% INFO    : Bus 51481	: V=0.9832228, theta=2.825855 -> V=1.0, theta=0.0
% INFO    : Bus 51482	: V=0.9906343, theta=3.344136 -> V=1.0, theta=0.0
% INFO    : Bus 51483	: V=0.9814561, theta=2.493589 -> V=1.0, theta=0.0
% INFO    : Bus 51484	: V=0.9821418, theta=2.649504 -> V=1.0, theta=0.0
% INFO    : Bus 51485	: V=0.9815662, theta=2.654467 -> V=1.0, theta=0.0
% INFO    : Bus 51486	: V=0.9904986, theta=3.291035 -> V=1.0, theta=0.0
% INFO    : Bus 51487	: V=0.986705, theta=3.228607 -> V=1.0, theta=0.0
% INFO    : Bus 51488	: V=0.9879299, theta=3.278948 -> V=1.0, theta=0.0
% INFO    : Bus 51489	: V=0.9978477, theta=3.484564 -> V=1.0, theta=0.0
% INFO    : Bus 51490	: V=0.9983223, theta=3.488121 -> V=1.0, theta=0.0
% INFO    : Bus 51491	: V=0.999024, theta=3.496095 -> V=1.0, theta=0.0
% INFO    : Bus 51492	: V=1.0024702, theta=4.752082 -> V=1.0, theta=0.0
% INFO    : Bus 51493	: V=1.0006812, theta=4.487546 -> V=1.0, theta=0.0
% INFO    : Bus 51494	: V=0.9932771, theta=3.960131 -> V=1.0, theta=0.0
% INFO    : Bus 51495	: V=0.9875615, theta=3.469291 -> V=1.0, theta=0.0
% INFO    : Bus 51496	: V=0.9929441, theta=3.927236 -> V=1.0, theta=0.0
% INFO    : Bus 51497	: V=0.9896523, theta=3.602826 -> V=1.0, theta=0.0
% INFO    : Bus 51498	: V=0.9959863, theta=4.183339 -> V=1.0, theta=0.0
% INFO    : Bus 51499	: V=0.9917166, theta=3.757004 -> V=1.0, theta=0.0
% INFO    : Bus 51500	: V=0.9844444, theta=3.254922 -> V=1.0, theta=0.0
% INFO    : Bus 51501	: V=0.9836471, theta=3.217592 -> V=1.0, theta=0.0
% INFO    : Bus 51502	: V=0.9966122, theta=4.280542 -> V=1.0, theta=0.0
% INFO    : Bus 51503	: V=0.9919609, theta=3.683043 -> V=1.0, theta=0.0
% INFO    : Bus 51504	: V=0.9784643, theta=2.781581 -> V=1.0, theta=0.0
% INFO    : Bus 51505	: V=0.9845657, theta=2.737105 -> V=1.0, theta=0.0
% INFO    : Bus 51506	: V=0.9867873, theta=3.02869 -> V=1.0, theta=0.0
% INFO    : Bus 51507	: V=0.9863091, theta=2.881848 -> V=1.0, theta=0.0
% INFO    : Bus 51508	: V=0.9976486, theta=3.143409 -> V=1.0, theta=0.0
% INFO    : Bus 51509	: V=0.9848472, theta=3.281415 -> V=1.0, theta=0.0
% INFO    : Bus 51510	: V=0.9745803, theta=2.605754 -> V=1.0, theta=0.0
% INFO    : Bus 51511	: V=0.9820912, theta=3.114106 -> V=1.0, theta=0.0
% INFO    : Bus 51512	: V=0.9834463, theta=3.225242 -> V=1.0, theta=0.0
% INFO    : Bus 51513	: V=0.9862807, theta=3.382218 -> V=1.0, theta=0.0
% INFO    : Bus 51514	: V=0.9906528, theta=3.688838 -> V=1.0, theta=0.0
% INFO    : Bus 51515	: V=0.9879505, theta=3.48615 -> V=1.0, theta=0.0
% INFO    : Bus 51516	: V=0.9855214, theta=3.32993 -> V=1.0, theta=0.0
% INFO    : Bus 51517	: V=0.9813018, theta=3.038877 -> V=1.0, theta=0.0
% INFO    : Bus 51518	: V=0.9877297, theta=3.433973 -> V=1.0, theta=0.0
% INFO    : Bus 51519	: V=0.9888511, theta=3.480832 -> V=1.0, theta=0.0
% INFO    : Bus 51520	: V=0.9761475, theta=2.742596 -> V=1.0, theta=0.0
% INFO    : Bus 51521	: V=0.9768273, theta=2.733475 -> V=1.0, theta=0.0
% INFO    : Bus 51522	: V=0.987165, theta=3.409459 -> V=1.0, theta=0.0
% INFO    : Bus 51523	: V=0.9883311, theta=3.364596 -> V=1.0, theta=0.0
% INFO    : Bus 51524	: V=0.9841217, theta=3.217373 -> V=1.0, theta=0.0
% INFO    : Bus 51525	: V=0.9749544, theta=2.677405 -> V=1.0, theta=0.0
% INFO    : Bus 51526	: V=0.9744962, theta=2.647892 -> V=1.0, theta=0.0
% INFO    : Bus 51527	: V=0.9812035, theta=2.903258 -> V=1.0, theta=0.0
% INFO    : Bus 51528	: V=0.9694642, theta=2.401877 -> V=1.0, theta=0.0
% INFO    : Bus 51529	: V=0.9736287, theta=2.61442 -> V=1.0, theta=0.0
% INFO    : Bus 51530	: V=0.9707467, theta=2.39751 -> V=1.0, theta=0.0
% INFO    : Bus 51531	: V=0.9692265, theta=2.299311 -> V=1.0, theta=0.0
% INFO    : Bus 51532	: V=0.970483, theta=2.241523 -> V=1.0, theta=0.0
% INFO    : Bus 51533	: V=0.9719692, theta=2.211912 -> V=1.0, theta=0.0
% INFO    : Bus 51534	: V=0.974088, theta=2.198582 -> V=1.0, theta=0.0
% INFO    : Bus 51535	: V=0.9775304, theta=2.247978 -> V=1.0, theta=0.0
% INFO    : Bus 51536	: V=0.9795547, theta=2.404803 -> V=1.0, theta=0.0
% INFO    : Bus 51537	: V=0.9869738, theta=2.920645 -> V=1.0, theta=0.0
% INFO    : Bus 51538	: V=0.9904784, theta=3.209173 -> V=1.0, theta=0.0
% INFO    : Bus 51539	: V=0.9680415, theta=1.950106 -> V=1.0, theta=0.0
% INFO    : Bus 51540	: V=0.9690823, theta=1.944604 -> V=1.0, theta=0.0
% INFO    : Bus 51541	: V=0.9706779, theta=2.023056 -> V=1.0, theta=0.0
% INFO    : Bus 51542	: V=0.9726602, theta=2.109639 -> V=1.0, theta=0.0
% INFO    : Bus 51543	: V=0.9858351, theta=2.653134 -> V=1.0, theta=0.0
% INFO    : Bus 51544	: V=0.9871566, theta=2.753782 -> V=1.0, theta=0.0
% INFO    : Bus 51545	: V=0.9851043, theta=2.85598 -> V=1.0, theta=0.0
% INFO    : Bus 51546	: V=0.9861832, theta=2.879011 -> V=1.0, theta=0.0
% INFO    : Bus 51547	: V=0.9906613, theta=3.175609 -> V=1.0, theta=0.0
% INFO    : Bus 51548	: V=0.9785075, theta=2.914653 -> V=1.0, theta=0.0
% INFO    : Bus 51549	: V=0.9814812, theta=3.096434 -> V=1.0, theta=0.0
% INFO    : Bus 51550	: V=0.9754685, theta=2.731067 -> V=1.0, theta=0.0
% INFO    : Bus 51551	: V=0.9787809, theta=2.869318 -> V=1.0, theta=0.0
% INFO    : Bus 51552	: V=0.9964466, theta=3.498814 -> V=1.0, theta=0.0
% INFO    : Bus 51553	: V=0.9931669, theta=3.578886 -> V=1.0, theta=0.0
% INFO    : Bus 51554	: V=0.9690496, theta=2.479399 -> V=1.0, theta=0.0
% INFO    : Bus 51555	: V=0.9595512, theta=1.170757 -> V=1.0, theta=0.0
% INFO    : Bus 51556	: V=0.9631233, theta=1.288762 -> V=1.0, theta=0.0
% INFO    : Bus 51557	: V=0.9737255, theta=2.644192 -> V=1.0, theta=0.0
% INFO    : Bus 51558	: V=0.9710257, theta=2.464238 -> V=1.0, theta=0.0
% INFO    : Bus 51559	: V=0.9691279, theta=2.384356 -> V=1.0, theta=0.0
% INFO    : Bus 51560	: V=0.967834, theta=2.345038 -> V=1.0, theta=0.0
% INFO    : Bus 51561	: V=0.9676973, theta=2.301421 -> V=1.0, theta=0.0
% INFO    : Bus 51562	: V=0.9669889, theta=2.306407 -> V=1.0, theta=0.0
% INFO    : Bus 51563	: V=0.9673405, theta=2.298532 -> V=1.0, theta=0.0
% INFO    : Bus 51564	: V=0.9781346, theta=-46.596181 -> V=1.0, theta=0.0
% INFO    : Bus 51565	: V=0.9914421, theta=-28.266126 -> V=1.0, theta=0.0
% INFO    : Bus 51566	: V=0.9856438, theta=-31.77058 -> V=1.0, theta=0.0
% INFO    : Bus 51567	: V=1.0136767, theta=-39.412863 -> V=1.0, theta=0.0
% INFO    : Bus 51568	: V=1.0087784, theta=-40.061155 -> V=1.0, theta=0.0
% INFO    : Bus 51569	: V=1.0059921, theta=-43.938709 -> V=1.0, theta=0.0
% INFO    : Bus 51570	: V=1.027158, theta=-40.143372 -> V=1.0, theta=0.0
% INFO    : Bus 51571	: V=1.0066397, theta=-15.771655 -> V=1.0, theta=0.0
% INFO    : Bus 51572	: V=1.0078849, theta=-19.411861 -> V=1.0, theta=0.0
% INFO    : Bus 51573	: V=0.9965886, theta=-19.918903 -> V=1.0, theta=0.0
% INFO    : Bus 51574	: V=1.00771, theta=-17.456172 -> V=1.0, theta=0.0
% INFO    : Bus 51575	: V=1.0085606, theta=-17.820361 -> V=1.0, theta=0.0
% INFO    : Bus 51576	: V=1.0093947, theta=-18.025305 -> V=1.0, theta=0.0
% INFO    : Bus 51577	: V=1.0029064, theta=-18.957327 -> V=1.0, theta=0.0
% INFO    : Bus 51578	: V=0.992817, theta=-38.315622 -> V=1.0, theta=0.0
% INFO    : Bus 51579	: V=1.0168047, theta=-19.801942 -> V=1.0, theta=0.0
% INFO    : Bus 51580	: V=1.010676, theta=-43.012092 -> V=1.0, theta=0.0
% INFO    : Bus 51581	: V=1.0146619, theta=-37.371083 -> V=1.0, theta=0.0
% INFO    : Bus 51582	: V=1.0058786, theta=-18.076944 -> V=1.0, theta=0.0
% INFO    : Bus 51583	: V=1.0094205, theta=-32.927564 -> V=1.0, theta=0.0
% INFO    : Bus 51584	: V=1.0187999, theta=-29.449935 -> V=1.0, theta=0.0
% INFO    : Bus 51585	: V=1.0194, theta=-29.410789 -> V=1.0, theta=0.0
% INFO    : Bus 51586	: V=1.0124855, theta=-30.842429 -> V=1.0, theta=0.0
% INFO    : Bus 51587	: V=1.0117724, theta=-31.348186 -> V=1.0, theta=0.0
% INFO    : Bus 51588	: V=1.0142038, theta=-31.240763 -> V=1.0, theta=0.0
% INFO    : Bus 51589	: V=1.0153179, theta=-30.778968 -> V=1.0, theta=0.0
% INFO    : Bus 51590	: V=1.015761, theta=-30.714476 -> V=1.0, theta=0.0
% INFO    : Bus 51591	: V=1.0156091, theta=-30.611182 -> V=1.0, theta=0.0
% INFO    : Bus 51592	: V=1.0135364, theta=-30.465682 -> V=1.0, theta=0.0
% INFO    : Bus 51593	: V=1.0145955, theta=-30.82662 -> V=1.0, theta=0.0
% INFO    : Bus 51594	: V=1.0169796, theta=-30.708711 -> V=1.0, theta=0.0
% INFO    : Bus 51595	: V=1.0100009, theta=-32.116512 -> V=1.0, theta=0.0
% INFO    : Bus 51596	: V=1.0057837, theta=-33.430577 -> V=1.0, theta=0.0
% INFO    : Bus 51597	: V=0.999902, theta=-30.393141 -> V=1.0, theta=0.0
% INFO    : Bus 51598	: V=1.0046229, theta=-30.827969 -> V=1.0, theta=0.0
% INFO    : Bus 51599	: V=1.0047129, theta=-29.044738 -> V=1.0, theta=0.0
% INFO    : Bus 51600	: V=1.0179602, theta=-39.703217 -> V=1.0, theta=0.0
% INFO    : Bus 51601	: V=0.9984795, theta=-43.35353 -> V=1.0, theta=0.0
% INFO    : Bus 51602	: V=0.9998434, theta=-44.074479 -> V=1.0, theta=0.0
% INFO    : Bus 51603	: V=1.0057089, theta=-6.375487 -> V=1.0, theta=0.0
% INFO    : Bus 51604	: V=1.0025751, theta=-9.708976 -> V=1.0, theta=0.0
% INFO    : Bus 51605	: V=1.0036935, theta=-7.567251 -> V=1.0, theta=0.0
% INFO    : Bus 51606	: V=1.0005771, theta=-9.192604 -> V=1.0, theta=0.0
% INFO    : Bus 51607	: V=1.0167572, theta=-32.781664 -> V=1.0, theta=0.0
% INFO    : Bus 51608	: V=0.9942146, theta=-34.41954 -> V=1.0, theta=0.0
% INFO    : Bus 51609	: V=1.0010404, theta=-34.08279 -> V=1.0, theta=0.0
% INFO    : Bus 51610	: V=0.990433, theta=-25.361365 -> V=1.0, theta=0.0
% INFO    : Bus 51611	: V=0.9906481, theta=-25.736664 -> V=1.0, theta=0.0
% INFO    : Bus 51612	: V=0.9927501, theta=-25.904537 -> V=1.0, theta=0.0
% INFO    : Bus 51613	: V=1.0004348, theta=-13.003072 -> V=1.0, theta=0.0
% INFO    : Bus 51614	: V=1.001464, theta=-11.110014 -> V=1.0, theta=0.0
% INFO    : Bus 51615	: V=1.0110398, theta=-35.284603 -> V=1.0, theta=0.0
% INFO    : Bus 51616	: V=1.0136866, theta=-37.796075 -> V=1.0, theta=0.0
% INFO    : Bus 51617	: V=1.0112921, theta=-44.292063 -> V=1.0, theta=0.0
% INFO    : Bus 51618	: V=1.0125295, theta=-44.343303 -> V=1.0, theta=0.0
% INFO    : Bus 51619	: V=1.019416, theta=-43.998811 -> V=1.0, theta=0.0
% INFO    : Bus 51620	: V=1.0187123, theta=-20.520856 -> V=1.0, theta=0.0
% INFO    : Bus 51621	: V=0.9715126, theta=-43.278944 -> V=1.0, theta=0.0
% INFO    : Bus 51622	: V=0.9974143, theta=-2.966099 -> V=1.0, theta=0.0
% INFO    : Bus 51623	: V=0.9931965, theta=-1.658012 -> V=1.0, theta=0.0
% INFO    : Bus 51624	: V=0.9989716, theta=-1.958093 -> V=1.0, theta=0.0
% INFO    : Bus 51625	: V=1.0039492, theta=-11.934364 -> V=1.0, theta=0.0
% INFO    : Bus 51626	: V=0.9997169, theta=-11.999546 -> V=1.0, theta=0.0
% INFO    : Bus 51627	: V=0.9914551, theta=-12.962716 -> V=1.0, theta=0.0
% INFO    : Bus 51628	: V=0.9905219, theta=-13.063785 -> V=1.0, theta=0.0
% INFO    : Bus 51629	: V=0.9900123, theta=-13.287086 -> V=1.0, theta=0.0
% INFO    : Bus 51630	: V=0.9897494, theta=-13.40308 -> V=1.0, theta=0.0
% INFO    : Bus 51631	: V=0.9901677, theta=-13.352749 -> V=1.0, theta=0.0
% INFO    : Bus 51632	: V=0.9901142, theta=-13.31742 -> V=1.0, theta=0.0
% INFO    : Bus 51633	: V=0.9894207, theta=-13.312276 -> V=1.0, theta=0.0
% INFO    : Bus 51634	: V=0.9912115, theta=-13.077234 -> V=1.0, theta=0.0
% INFO    : Bus 51635	: V=0.9933349, theta=-12.755567 -> V=1.0, theta=0.0
% INFO    : Bus 51636	: V=0.9980844, theta=-11.934 -> V=1.0, theta=0.0
% INFO    : Bus 51637	: V=0.9982807, theta=-11.968513 -> V=1.0, theta=0.0
% INFO    : Bus 51638	: V=1.0012801, theta=-11.968989 -> V=1.0, theta=0.0
% INFO    : Bus 51639	: V=0.9876011, theta=-11.888857 -> V=1.0, theta=0.0
% INFO    : Bus 51640	: V=0.987847, theta=-11.877919 -> V=1.0, theta=0.0
% INFO    : Bus 51641	: V=0.9980655, theta=-11.830106 -> V=1.0, theta=0.0
% INFO    : Bus 51642	: V=0.9981908, theta=-11.694981 -> V=1.0, theta=0.0
% INFO    : Bus 51643	: V=0.9945271, theta=-12.574097 -> V=1.0, theta=0.0
% INFO    : Bus 51644	: V=0.9943342, theta=-12.565404 -> V=1.0, theta=0.0
% INFO    : Bus 51645	: V=0.9943494, theta=-12.668077 -> V=1.0, theta=0.0
% INFO    : Bus 51646	: V=1.0027129, theta=-12.581096 -> V=1.0, theta=0.0
% INFO    : Bus 51647	: V=0.99083, theta=-13.318904 -> V=1.0, theta=0.0
% INFO    : Bus 51648	: V=0.9911225, theta=-13.286796 -> V=1.0, theta=0.0
% INFO    : Bus 51649	: V=0.9925098, theta=-13.206418 -> V=1.0, theta=0.0
% INFO    : Bus 51650	: V=1.0024651, theta=-12.614487 -> V=1.0, theta=0.0
% INFO    : Bus 51651	: V=1.0012225, theta=-12.67502 -> V=1.0, theta=0.0
% INFO    : Bus 51652	: V=1.004555, theta=-12.540697 -> V=1.0, theta=0.0
% INFO    : Bus 51653	: V=1.0035508, theta=-12.526652 -> V=1.0, theta=0.0
% INFO    : Bus 51654	: V=1.0046537, theta=-12.466042 -> V=1.0, theta=0.0
% INFO    : Bus 51655	: V=0.9943216, theta=-12.499627 -> V=1.0, theta=0.0
% INFO    : Bus 51656	: V=0.9944205, theta=-12.372988 -> V=1.0, theta=0.0
% INFO    : Bus 51657	: V=0.9949685, theta=-12.369558 -> V=1.0, theta=0.0
% INFO    : Bus 51658	: V=1.0061, theta=-12.387511 -> V=1.0, theta=0.0
% INFO    : Bus 51659	: V=1.0086352, theta=-12.29623 -> V=1.0, theta=0.0
% INFO    : Bus 51660	: V=1.0063344, theta=-12.369537 -> V=1.0, theta=0.0
% INFO    : Bus 51661	: V=1.0052033, theta=-12.409763 -> V=1.0, theta=0.0
% INFO    : Bus 51662	: V=0.9899515, theta=-13.354087 -> V=1.0, theta=0.0
% INFO    : Bus 51663	: V=0.9953204, theta=-12.931197 -> V=1.0, theta=0.0
% INFO    : Bus 51664	: V=0.9901623, theta=-13.40993 -> V=1.0, theta=0.0
% INFO    : Bus 51665	: V=0.9943701, theta=-12.981235 -> V=1.0, theta=0.0
% INFO    : Bus 51666	: V=0.987015, theta=-13.991394 -> V=1.0, theta=0.0
% INFO    : Bus 51667	: V=0.9882615, theta=-13.490772 -> V=1.0, theta=0.0
% INFO    : Bus 51668	: V=0.984864, theta=-13.980067 -> V=1.0, theta=0.0
% INFO    : Bus 51669	: V=0.984613, theta=-13.771993 -> V=1.0, theta=0.0
% INFO    : Bus 51670	: V=0.9863461, theta=-13.761291 -> V=1.0, theta=0.0
% INFO    : Bus 51671	: V=0.9940427, theta=-12.921591 -> V=1.0, theta=0.0
% INFO    : Bus 51672	: V=0.9980862, theta=-12.595937 -> V=1.0, theta=0.0
% INFO    : Bus 51673	: V=1.0048977, theta=-12.449988 -> V=1.0, theta=0.0
% INFO    : Bus 51674	: V=1.0081207, theta=-12.277847 -> V=1.0, theta=0.0
% INFO    : Bus 51675	: V=1.0054158, theta=-12.225647 -> V=1.0, theta=0.0
% INFO    : Bus 51676	: V=1.0034014, theta=-12.45682 -> V=1.0, theta=0.0
% INFO    : Bus 51677	: V=1.0064366, theta=-12.253939 -> V=1.0, theta=0.0
% INFO    : Bus 51678	: V=0.9962942, theta=-12.423427 -> V=1.0, theta=0.0
% INFO    : Bus 51679	: V=0.9984539, theta=-11.532833 -> V=1.0, theta=0.0
% INFO    : Bus 51680	: V=0.9989649, theta=-11.370398 -> V=1.0, theta=0.0
% INFO    : Bus 51681	: V=0.9986139, theta=-12.448748 -> V=1.0, theta=0.0
% INFO    : Bus 51682	: V=0.9960548, theta=-12.328615 -> V=1.0, theta=0.0
% INFO    : Bus 51683	: V=0.9998954, theta=-11.748073 -> V=1.0, theta=0.0
% INFO    : Bus 51684	: V=1.0026141, theta=-11.463979 -> V=1.0, theta=0.0
% INFO    : Bus 51685	: V=1.0036224, theta=-11.91048 -> V=1.0, theta=0.0
% INFO    : Bus 51686	: V=1.0045726, theta=-12.18987 -> V=1.0, theta=0.0
% INFO    : Bus 51687	: V=0.9864315, theta=-11.372409 -> V=1.0, theta=0.0
% INFO    : Bus 51688	: V=0.9908999, theta=-11.57414 -> V=1.0, theta=0.0
% INFO    : Bus 51689	: V=0.9984686, theta=-9.108707 -> V=1.0, theta=0.0
% INFO    : Bus 51690	: V=0.9968891, theta=-12.263727 -> V=1.0, theta=0.0
% INFO    : Bus 51691	: V=0.9899242, theta=-11.811502 -> V=1.0, theta=0.0
% INFO    : Bus 51692	: V=0.9888501, theta=-11.850198 -> V=1.0, theta=0.0
% INFO    : Bus 51693	: V=1.0116387, theta=-11.790403 -> V=1.0, theta=0.0
% INFO    : Bus 51694	: V=0.9865966, theta=-13.59292 -> V=1.0, theta=0.0
% INFO    : Bus 51695	: V=0.9833767, theta=-13.931669 -> V=1.0, theta=0.0
% INFO    : Bus 51696	: V=1.0147347, theta=-14.137499 -> V=1.0, theta=0.0
% INFO    : Bus 51697	: V=0.9988465, theta=-7.980705 -> V=1.0, theta=0.0
% INFO    : Bus 51698	: V=0.9862401, theta=-13.924973 -> V=1.0, theta=0.0
% INFO    : Bus 51699	: V=1.0119429, theta=-40.962699 -> V=1.0, theta=0.0
% INFO    : Bus 51700	: V=1.0096758, theta=-38.58831 -> V=1.0, theta=0.0
% INFO    : Bus 51701	: V=1.0066289, theta=-40.008551 -> V=1.0, theta=0.0
% INFO    : Bus 51702	: V=1.0069406, theta=-40.300079 -> V=1.0, theta=0.0
% INFO    : Bus 51703	: V=1.0017794, theta=-40.719454 -> V=1.0, theta=0.0
% INFO    : Bus 51704	: V=1.0007944, theta=-40.597765 -> V=1.0, theta=0.0
% INFO    : Bus 51705	: V=1.0050768, theta=-40.943035 -> V=1.0, theta=0.0
% INFO    : Bus 51706	: V=1.0123683, theta=-40.883353 -> V=1.0, theta=0.0
% INFO    : Bus 51707	: V=1.0096395, theta=-37.277735 -> V=1.0, theta=0.0
% INFO    : Bus 51708	: V=1.0295065, theta=-26.946693 -> V=1.0, theta=0.0
% INFO    : Bus 51709	: V=1.0127615, theta=-35.96329 -> V=1.0, theta=0.0
% INFO    : Bus 51710	: V=0.988468, theta=-0.164437 -> V=1.0, theta=0.0
% INFO    : Bus 51711	: V=0.9893459, theta=-0.382534 -> V=1.0, theta=0.0
% INFO    : Bus 51712	: V=0.9870703, theta=-1.063426 -> V=1.0, theta=0.0
% INFO    : Bus 51713	: V=0.985674, theta=-1.165142 -> V=1.0, theta=0.0
% INFO    : Bus 51714	: V=0.9875096, theta=-1.047714 -> V=1.0, theta=0.0
% INFO    : Bus 51715	: V=0.9886188, theta=-0.985572 -> V=1.0, theta=0.0
% INFO    : Bus 51716	: V=1.0007382, theta=1.746018 -> V=1.0, theta=0.0
% INFO    : Bus 51717	: V=0.9895511, theta=-1.677602 -> V=1.0, theta=0.0
% INFO    : Bus 51718	: V=0.987354, theta=-4.382596 -> V=1.0, theta=0.0
% INFO    : Bus 51719	: V=0.9920581, theta=-26.160415 -> V=1.0, theta=0.0
% INFO    : Bus 51720	: V=0.9914649, theta=-28.222651 -> V=1.0, theta=0.0
% INFO    : Bus 51721	: V=0.9953975, theta=-26.395859 -> V=1.0, theta=0.0
% INFO    : Bus 51722	: V=0.9789603, theta=-35.74704 -> V=1.0, theta=0.0
% INFO    : Bus 51723	: V=0.9889454, theta=-23.298343 -> V=1.0, theta=0.0
% INFO    : Bus 51724	: V=0.9824438, theta=-7.246688 -> V=1.0, theta=0.0
% INFO    : Bus 51725	: V=1.0134821, theta=-4.83293 -> V=1.0, theta=0.0
% INFO    : Bus 51726	: V=1.0114077, theta=-33.024281 -> V=1.0, theta=0.0
% INFO    : Bus 51727	: V=1.0100504, theta=-32.571917 -> V=1.0, theta=0.0
% INFO    : Bus 51728	: V=1.0038908, theta=-1.384214 -> V=1.0, theta=0.0
% INFO    : Bus 51729	: V=1.0052843, theta=-4.187216 -> V=1.0, theta=0.0
% INFO    : Bus 51730	: V=1.0013496, theta=-5.959158 -> V=1.0, theta=0.0
% INFO    : Bus 51731	: V=1.018108, theta=-0.926434 -> V=1.0, theta=0.0
% INFO    : Bus 51732	: V=1.017689, theta=-0.937318 -> V=1.0, theta=0.0
% INFO    : Bus 51733	: V=1.0001634, theta=-11.962922 -> V=1.0, theta=0.0
% INFO    : Bus 51734	: V=1.0142313, theta=-39.996773 -> V=1.0, theta=0.0
% INFO    : Bus 51735	: V=1.0369179, theta=-43.40689 -> V=1.0, theta=0.0
% INFO    : Bus 51736	: V=1.0385473, theta=-44.123985 -> V=1.0, theta=0.0
% INFO    : Bus 51737	: V=1.0393516, theta=-44.547337 -> V=1.0, theta=0.0
% INFO    : Bus 51738	: V=0.9764826, theta=-1.929028 -> V=1.0, theta=0.0
% INFO    : Bus 51739	: V=0.9869587, theta=-1.304936 -> V=1.0, theta=0.0
% INFO    : Bus 51740	: V=0.98726, theta=-7.416464 -> V=1.0, theta=0.0
% INFO    : Bus 51741	: V=0.9899277, theta=-10.061793 -> V=1.0, theta=0.0
% INFO    : Bus 51742	: V=0.9914269, theta=-11.260126 -> V=1.0, theta=0.0
% INFO    : Bus 51743	: V=0.9930641, theta=-11.644268 -> V=1.0, theta=0.0
% INFO    : Bus 51744	: V=0.988089, theta=-10.679455 -> V=1.0, theta=0.0
% INFO    : Bus 51745	: V=0.9922238, theta=-11.742157 -> V=1.0, theta=0.0
% INFO    : Bus 51746	: V=0.9916277, theta=-11.843716 -> V=1.0, theta=0.0
% INFO    : Bus 51747	: V=0.9863965, theta=-15.659046 -> V=1.0, theta=0.0
% INFO    : Bus 51748	: V=0.9855079, theta=-17.856566 -> V=1.0, theta=0.0
% INFO    : Bus 51749	: V=0.9910219, theta=-46.411302 -> V=1.0, theta=0.0
% INFO    : Bus 51750	: V=0.9916124, theta=-46.927314 -> V=1.0, theta=0.0
% INFO    : Bus 51751	: V=0.9940992, theta=-46.000299 -> V=1.0, theta=0.0
% INFO    : Bus 51752	: V=1.0034155, theta=-6.924313 -> V=1.0, theta=0.0
% INFO    : Bus 51753	: V=1.0015269, theta=-9.787075 -> V=1.0, theta=0.0
% INFO    : Bus 51754	: V=1.014321, theta=-5.615982 -> V=1.0, theta=0.0
% INFO    : Bus 51755	: V=1.0187312, theta=-22.736324 -> V=1.0, theta=0.0
% INFO    : Bus 51756	: V=1.0093132, theta=-15.906308 -> V=1.0, theta=0.0
% INFO    : Bus 51757	: V=0.9885727, theta=-23.286443 -> V=1.0, theta=0.0
% INFO    : Bus 51758	: V=1.0038481, theta=-19.356012 -> V=1.0, theta=0.0
% INFO    : Bus 51759	: V=1.0112166, theta=-17.873041 -> V=1.0, theta=0.0
% INFO    : Bus 51760	: V=0.9996808, theta=3.680511 -> V=1.0, theta=0.0
% INFO    : Bus 51761	: V=1.0044417, theta=4.167912 -> V=1.0, theta=0.0
% INFO    : Bus 51762	: V=1.0060813, theta=4.207615 -> V=1.0, theta=0.0
% INFO    : Bus 51763	: V=1.00513, theta=4.126376 -> V=1.0, theta=0.0
% INFO    : Bus 51764	: V=0.997258, theta=3.536196 -> V=1.0, theta=0.0
% INFO    : Bus 51765	: V=1.0051136, theta=4.176447 -> V=1.0, theta=0.0
% INFO    : Bus 51766	: V=0.9976938, theta=3.454749 -> V=1.0, theta=0.0
% INFO    : Bus 51767	: V=1.0042243, theta=3.903657 -> V=1.0, theta=0.0
% INFO    : Bus 51768	: V=0.9956624, theta=3.287015 -> V=1.0, theta=0.0
% INFO    : Bus 51769	: V=1.0015281, theta=3.664548 -> V=1.0, theta=0.0
% INFO    : Bus 51770	: V=0.9950654, theta=3.220492 -> V=1.0, theta=0.0
% INFO    : Bus 51771	: V=1.0084517, theta=2.893216 -> V=1.0, theta=0.0
% INFO    : Bus 51772	: V=0.995153, theta=3.350858 -> V=1.0, theta=0.0
% INFO    : Bus 51773	: V=0.9957569, theta=3.244054 -> V=1.0, theta=0.0
% INFO    : Bus 51774	: V=1.0001897, theta=3.587957 -> V=1.0, theta=0.0
% INFO    : Bus 51775	: V=1.0051645, theta=4.093543 -> V=1.0, theta=0.0
% INFO    : Bus 51776	: V=1.0042848, theta=3.97876 -> V=1.0, theta=0.0
% INFO    : Bus 51777	: V=1.0078417, theta=3.95736 -> V=1.0, theta=0.0
% INFO    : Bus 51778	: V=0.9974226, theta=3.434576 -> V=1.0, theta=0.0
% INFO    : Bus 51779	: V=0.9945615, theta=3.295999 -> V=1.0, theta=0.0
% INFO    : Bus 51780	: V=0.9910302, theta=3.145823 -> V=1.0, theta=0.0
% INFO    : Bus 51781	: V=0.9915659, theta=3.158129 -> V=1.0, theta=0.0
% INFO    : Bus 51782	: V=0.9910893, theta=2.967686 -> V=1.0, theta=0.0
% INFO    : Bus 51783	: V=0.9917998, theta=3.108988 -> V=1.0, theta=0.0
% INFO    : Bus 51784	: V=0.9973585, theta=3.40989 -> V=1.0, theta=0.0
% INFO    : Bus 51785	: V=0.9933108, theta=3.19543 -> V=1.0, theta=0.0
% INFO    : Bus 51786	: V=0.994881, theta=3.28987 -> V=1.0, theta=0.0
% INFO    : Bus 51787	: V=0.9919794, theta=3.024513 -> V=1.0, theta=0.0
% INFO    : Bus 51788	: V=0.9901499, theta=2.927607 -> V=1.0, theta=0.0
% INFO    : Bus 51789	: V=0.990688, theta=2.848129 -> V=1.0, theta=0.0
% INFO    : Bus 51790	: V=0.9903807, theta=2.697385 -> V=1.0, theta=0.0
% INFO    : Bus 51791	: V=0.9685919, theta=1.865237 -> V=1.0, theta=0.0
% INFO    : Bus 51792	: V=0.9679246, theta=1.769847 -> V=1.0, theta=0.0
% INFO    : Bus 51793	: V=0.9676209, theta=1.688923 -> V=1.0, theta=0.0
% INFO    : Bus 51794	: V=0.9667685, theta=1.399051 -> V=1.0, theta=0.0
% INFO    : Bus 51795	: V=0.9690131, theta=1.67975 -> V=1.0, theta=0.0
% INFO    : Bus 51796	: V=0.9675023, theta=1.529178 -> V=1.0, theta=0.0
% INFO    : Bus 51797	: V=0.9639197, theta=0.983772 -> V=1.0, theta=0.0
% INFO    : Bus 51798	: V=0.9817625, theta=1.735275 -> V=1.0, theta=0.0
% INFO    : Bus 51799	: V=0.9706488, theta=1.939839 -> V=1.0, theta=0.0
% INFO    : Bus 51800	: V=0.9720304, theta=2.116635 -> V=1.0, theta=0.0
% INFO    : Bus 51801	: V=0.9816509, theta=1.064941 -> V=1.0, theta=0.0
% INFO    : Bus 51802	: V=0.9905126, theta=2.341205 -> V=1.0, theta=0.0
% INFO    : Bus 51803	: V=0.9845257, theta=-0.233508 -> V=1.0, theta=0.0
% INFO    : Bus 51804	: V=0.9737196, theta=-7.126609 -> V=1.0, theta=0.0
% INFO    : Bus 51805	: V=0.9686481, theta=-1.669229 -> V=1.0, theta=0.0
% INFO    : Bus 51806	: V=0.9700752, theta=-0.91944 -> V=1.0, theta=0.0
% INFO    : Bus 51807	: V=0.9743039, theta=-0.542872 -> V=1.0, theta=0.0
% INFO    : Bus 51808	: V=0.9707521, theta=-39.356066 -> V=1.0, theta=0.0
% INFO    : Bus 51809	: V=0.9707549, theta=-35.607522 -> V=1.0, theta=0.0
% INFO    : Bus 51810	: V=0.9622471, theta=-40.679938 -> V=1.0, theta=0.0
% INFO    : Bus 51811	: V=0.9718393, theta=-39.919431 -> V=1.0, theta=0.0
% INFO    : Bus 51812	: V=0.9701422, theta=-36.648502 -> V=1.0, theta=0.0
% INFO    : Bus 51813	: V=0.9728119, theta=-39.07753 -> V=1.0, theta=0.0
% INFO    : Bus 51814	: V=0.9727608, theta=-39.054797 -> V=1.0, theta=0.0
% INFO    : Bus 51815	: V=0.9729149, theta=-39.572284 -> V=1.0, theta=0.0
% INFO    : Bus 51816	: V=0.9699818, theta=-37.184818 -> V=1.0, theta=0.0
% INFO    : Bus 51817	: V=0.9725055, theta=-39.536667 -> V=1.0, theta=0.0
% INFO    : Bus 51818	: V=0.9733223, theta=-39.498113 -> V=1.0, theta=0.0
% INFO    : Bus 51819	: V=0.9824519, theta=-16.028772 -> V=1.0, theta=0.0
% INFO    : Bus 51820	: V=0.986108, theta=-18.65341 -> V=1.0, theta=0.0
% INFO    : Bus 51821	: V=0.985086, theta=-18.768587 -> V=1.0, theta=0.0
% INFO    : Bus 51822	: V=0.988671, theta=-20.438032 -> V=1.0, theta=0.0
% INFO    : Bus 51823	: V=0.9997224, theta=-22.454834 -> V=1.0, theta=0.0
% INFO    : Bus 51824	: V=0.9854644, theta=-26.038727 -> V=1.0, theta=0.0
% INFO    : Bus 51825	: V=1.0043679, theta=-33.605761 -> V=1.0, theta=0.0
% INFO    : Bus 51826	: V=0.9758188, theta=-28.759423 -> V=1.0, theta=0.0
% INFO    : Bus 51827	: V=0.9787119, theta=-1.813272 -> V=1.0, theta=0.0
% INFO    : Bus 51828	: V=0.9820031, theta=-0.263687 -> V=1.0, theta=0.0
% INFO    : Bus 51829	: V=1.0130339, theta=-31.180054 -> V=1.0, theta=0.0
% INFO    : Bus 51830	: V=1.0130296, theta=-30.121396 -> V=1.0, theta=0.0
% INFO    : Bus 51831	: V=1.0170671, theta=-34.927628 -> V=1.0, theta=0.0
% INFO    : Bus 51832	: V=0.985629, theta=4.525377 -> V=1.0, theta=0.0
% INFO    : Bus 51833	: V=0.9869963, theta=5.132835 -> V=1.0, theta=0.0
% INFO    : Bus 51834	: V=1.0141947, theta=-23.778693 -> V=1.0, theta=0.0
% INFO    : Bus 51835	: V=1.0137294, theta=-23.03402 -> V=1.0, theta=0.0
% INFO    : Bus 51836	: V=1.0064279, theta=5.929547 -> V=1.0, theta=0.0
% INFO    : Bus 51837	: V=1.0126774, theta=6.119856 -> V=1.0, theta=0.0
% INFO    : Bus 51838	: V=1.004663, theta=5.876976 -> V=1.0, theta=0.0
% INFO    : Bus 51839	: V=1.0072326, theta=5.353677 -> V=1.0, theta=0.0
% INFO    : Bus 51840	: V=1.0027367, theta=4.316601 -> V=1.0, theta=0.0
% INFO    : Bus 51841	: V=0.9848869, theta=2.074522 -> V=1.0, theta=0.0
% INFO    : Bus 51842	: V=0.9850004, theta=2.108268 -> V=1.0, theta=0.0
% INFO    : Bus 51843	: V=1.0151368, theta=-35.888629 -> V=1.0, theta=0.0
% INFO    : Bus 51844	: V=1.0148422, theta=-36.073908 -> V=1.0, theta=0.0
% INFO    : Bus 51845	: V=0.9962977, theta=-11.809088 -> V=1.0, theta=0.0
% INFO    : Bus 51846	: V=0.987245, theta=-20.583938 -> V=1.0, theta=0.0
% INFO    : Bus 51847	: V=0.9842664, theta=-21.811147 -> V=1.0, theta=0.0
% INFO    : Bus 51848	: V=0.9833518, theta=-22.175094 -> V=1.0, theta=0.0
% INFO    : Bus 51849	: V=0.9920206, theta=-22.610136 -> V=1.0, theta=0.0
% INFO    : Bus 51850	: V=1.0198431, theta=8.889154 -> V=1.0, theta=0.0
% INFO    : Bus 51851	: V=0.9990826, theta=1.671521 -> V=1.0, theta=0.0
% INFO    : Bus 51852	: V=1.0032709, theta=2.713072 -> V=1.0, theta=0.0
% INFO    : Bus 51853	: V=1.004496, theta=1.969364 -> V=1.0, theta=0.0
% INFO    : Bus 51854	: V=1.0044239, theta=1.887768 -> V=1.0, theta=0.0
% INFO    : Bus 51855	: V=0.9675863, theta=2.626955 -> V=1.0, theta=0.0
% INFO    : Bus 51856	: V=0.9665736, theta=0.064628 -> V=1.0, theta=0.0
% INFO    : Bus 51857	: V=0.97735, theta=2.896526 -> V=1.0, theta=0.0
% INFO    : Bus 51858	: V=0.9703468, theta=4.481019 -> V=1.0, theta=0.0
% INFO    : Bus 51859	: V=0.9804864, theta=7.904982 -> V=1.0, theta=0.0
% INFO    : Bus 51860	: V=0.9517551, theta=-1.981502 -> V=1.0, theta=0.0
% INFO    : Bus 51861	: V=0.9482588, theta=-2.150553 -> V=1.0, theta=0.0
% INFO    : Bus 51862	: V=0.9618617, theta=2.909613 -> V=1.0, theta=0.0
% INFO    : Bus 51863	: V=0.9939274, theta=8.809368 -> V=1.0, theta=0.0
% INFO    : Bus 51864	: V=0.9825995, theta=8.132242 -> V=1.0, theta=0.0
% INFO    : Bus 51865	: V=0.9876185, theta=5.097765 -> V=1.0, theta=0.0
% INFO    : Bus 51866	: V=1.0033069, theta=15.329684 -> V=1.0, theta=0.0
% INFO    : Bus 51867	: V=1.0030613, theta=15.25305 -> V=1.0, theta=0.0
% INFO    : Bus 51868	: V=1.0034566, theta=15.279643 -> V=1.0, theta=0.0
% INFO    : Bus 51869	: V=0.9951498, theta=14.503164 -> V=1.0, theta=0.0
% INFO    : Bus 51870	: V=1.0038665, theta=15.406634 -> V=1.0, theta=0.0
% INFO    : Bus 51871	: V=0.9964177, theta=14.581984 -> V=1.0, theta=0.0
% INFO    : Bus 51872	: V=0.9908317, theta=14.220658 -> V=1.0, theta=0.0
% INFO    : Bus 51873	: V=0.9895145, theta=14.084928 -> V=1.0, theta=0.0
% INFO    : Bus 51874	: V=1.0028237, theta=15.163505 -> V=1.0, theta=0.0
% INFO    : Bus 51875	: V=1.0048368, theta=15.462925 -> V=1.0, theta=0.0
% INFO    : Bus 51876	: V=1.0082379, theta=14.719014 -> V=1.0, theta=0.0
% INFO    : Bus 51877	: V=1.0049376, theta=15.410784 -> V=1.0, theta=0.0
% INFO    : Bus 51878	: V=0.995806, theta=14.596152 -> V=1.0, theta=0.0
% INFO    : Bus 51879	: V=1.0067518, theta=15.53853 -> V=1.0, theta=0.0
% INFO    : Bus 51880	: V=1.0086774, theta=15.512775 -> V=1.0, theta=0.0
% INFO    : Bus 51881	: V=0.9829535, theta=13.821474 -> V=1.0, theta=0.0
% INFO    : Bus 51882	: V=1.001553, theta=14.373911 -> V=1.0, theta=0.0
% INFO    : Bus 51883	: V=1.0093009, theta=12.117447 -> V=1.0, theta=0.0
% INFO    : Bus 51884	: V=1.0134508, theta=15.486411 -> V=1.0, theta=0.0
% INFO    : Bus 51885	: V=0.949837, theta=1.974363 -> V=1.0, theta=0.0
% INFO    : Bus 51886	: V=0.9487786, theta=1.801591 -> V=1.0, theta=0.0
% INFO    : Bus 51887	: V=0.9479533, theta=1.701446 -> V=1.0, theta=0.0
% INFO    : Bus 51888	: V=0.9464019, theta=0.890236 -> V=1.0, theta=0.0
% INFO    : Bus 51889	: V=0.9499497, theta=0.680695 -> V=1.0, theta=0.0
% INFO    : Bus 51890	: V=0.9507487, theta=1.399114 -> V=1.0, theta=0.0
% INFO    : Bus 51891	: V=0.9508534, theta=0.72395 -> V=1.0, theta=0.0
% INFO    : Bus 51892	: V=0.9557218, theta=0.740094 -> V=1.0, theta=0.0
% INFO    : Bus 51893	: V=0.9508762, theta=1.20609 -> V=1.0, theta=0.0
% INFO    : Bus 51894	: V=0.9515032, theta=1.056706 -> V=1.0, theta=0.0
% INFO    : Bus 51895	: V=0.9553697, theta=0.758348 -> V=1.0, theta=0.0
% INFO    : Bus 51896	: V=0.9521872, theta=0.794639 -> V=1.0, theta=0.0
% INFO    : Bus 51897	: V=0.9541621, theta=0.706096 -> V=1.0, theta=0.0
% INFO    : Bus 51898	: V=0.9552494, theta=0.757562 -> V=1.0, theta=0.0
% INFO    : Bus 51899	: V=0.9537062, theta=1.937907 -> V=1.0, theta=0.0
% INFO    : Bus 51900	: V=0.9513506, theta=0.761811 -> V=1.0, theta=0.0
% INFO    : Bus 51901	: V=0.9563243, theta=0.861685 -> V=1.0, theta=0.0
% INFO    : Bus 51902	: V=0.9544276, theta=0.426101 -> V=1.0, theta=0.0
% INFO    : Bus 51903	: V=0.9569669, theta=0.781234 -> V=1.0, theta=0.0
% INFO    : Bus 51904	: V=0.9557631, theta=0.547884 -> V=1.0, theta=0.0
% INFO    : Bus 51905	: V=0.9593483, theta=0.609884 -> V=1.0, theta=0.0
% INFO    : Bus 51906	: V=0.9580585, theta=0.681687 -> V=1.0, theta=0.0
% INFO    : Bus 51907	: V=0.955657, theta=0.439253 -> V=1.0, theta=0.0
% INFO    : Bus 51908	: V=0.9564558, theta=1.378382 -> V=1.0, theta=0.0
% INFO    : Bus 51909	: V=0.9563235, theta=1.076977 -> V=1.0, theta=0.0
% INFO    : Bus 51910	: V=0.9546892, theta=1.718759 -> V=1.0, theta=0.0
% INFO    : Bus 51911	: V=0.953202, theta=1.646346 -> V=1.0, theta=0.0
% INFO    : Bus 51912	: V=0.9860578, theta=1.220948 -> V=1.0, theta=0.0
% INFO    : Bus 51913	: V=0.9586548, theta=0.074344 -> V=1.0, theta=0.0
% INFO    : Bus 51914	: V=0.9737291, theta=0.892776 -> V=1.0, theta=0.0
% INFO    : Bus 51915	: V=0.9647671, theta=0.652222 -> V=1.0, theta=0.0
% INFO    : Bus 51916	: V=0.9613236, theta=1.15202 -> V=1.0, theta=0.0
% INFO    : Bus 51917	: V=0.9671005, theta=1.517743 -> V=1.0, theta=0.0
% INFO    : Bus 51918	: V=0.98323, theta=-3.120003 -> V=1.0, theta=0.0
% INFO    : Bus 51919	: V=0.9879313, theta=-2.958516 -> V=1.0, theta=0.0
% INFO    : Bus 51920	: V=0.9756609, theta=1.079206 -> V=1.0, theta=0.0
% INFO    : Bus 51921	: V=1.0103325, theta=3.050529 -> V=1.0, theta=0.0
% INFO    : Bus 51922	: V=1.0069108, theta=2.471882 -> V=1.0, theta=0.0
% INFO    : Bus 51923	: V=0.9980127, theta=2.762962 -> V=1.0, theta=0.0
% INFO    : Bus 51924	: V=0.9803092, theta=14.423714 -> V=1.0, theta=0.0
% INFO    : Bus 51925	: V=0.9739497, theta=3.27713 -> V=1.0, theta=0.0
% INFO    : Bus 51926	: V=1.0072044, theta=8.177191 -> V=1.0, theta=0.0
% INFO    : Bus 51927	: V=1.0007794, theta=5.314939 -> V=1.0, theta=0.0
% INFO    : Bus 51928	: V=0.9851163, theta=5.517059 -> V=1.0, theta=0.0
% INFO    : Bus 51929	: V=0.9775687, theta=5.35038 -> V=1.0, theta=0.0
% INFO    : Bus 51930	: V=0.9793642, theta=5.201981 -> V=1.0, theta=0.0
% INFO    : Bus 51931	: V=0.9804182, theta=5.229909 -> V=1.0, theta=0.0
% INFO    : Bus 51932	: V=0.9784684, theta=5.081821 -> V=1.0, theta=0.0
% INFO    : Bus 51933	: V=0.9766485, theta=5.36872 -> V=1.0, theta=0.0
% INFO    : Bus 51934	: V=0.9774507, theta=5.300037 -> V=1.0, theta=0.0
% INFO    : Bus 51935	: V=0.9706562, theta=6.408564 -> V=1.0, theta=0.0
% INFO    : Bus 51936	: V=0.9797295, theta=5.266109 -> V=1.0, theta=0.0
% INFO    : Bus 51937	: V=0.9810083, theta=5.255319 -> V=1.0, theta=0.0
% INFO    : Bus 51938	: V=0.9775136, theta=5.265828 -> V=1.0, theta=0.0
% INFO    : Bus 51939	: V=0.9780309, theta=5.272863 -> V=1.0, theta=0.0
% INFO    : Bus 51940	: V=0.9742513, theta=4.924809 -> V=1.0, theta=0.0
% INFO    : Bus 51941	: V=0.9759919, theta=4.968473 -> V=1.0, theta=0.0
% INFO    : Bus 51942	: V=0.9663265, theta=0.63617 -> V=1.0, theta=0.0
% INFO    : Bus 51943	: V=0.9770896, theta=7.444865 -> V=1.0, theta=0.0
% INFO    : Bus 51944	: V=0.9805597, theta=1.58324 -> V=1.0, theta=0.0
% INFO    : Bus 51945	: V=0.973793, theta=4.171379 -> V=1.0, theta=0.0
% INFO    : Bus 51946	: V=0.978214, theta=2.775695 -> V=1.0, theta=0.0
% INFO    : Bus 51947	: V=1.0105664, theta=14.430019 -> V=1.0, theta=0.0
% INFO    : Bus 51948	: V=1.0108805, theta=2.999478 -> V=1.0, theta=0.0
% INFO    : Bus 51949	: V=0.991018, theta=15.206542 -> V=1.0, theta=0.0
% INFO    : Bus 51950	: V=0.9638043, theta=10.938107 -> V=1.0, theta=0.0
% INFO    : Bus 51951	: V=1.0056246, theta=10.854169 -> V=1.0, theta=0.0
% INFO    : Bus 51952	: V=0.9937062, theta=2.90595 -> V=1.0, theta=0.0
% INFO    : Bus 51953	: V=1.0080446, theta=4.326246 -> V=1.0, theta=0.0
% INFO    : Bus 51954	: V=1.0122714, theta=7.137463 -> V=1.0, theta=0.0
% INFO    : Bus 51955	: V=0.9791061, theta=5.080721 -> V=1.0, theta=0.0
% INFO    : Bus 51956	: V=0.9844161, theta=7.848588 -> V=1.0, theta=0.0
% INFO    : Bus 51957	: V=1.0113259, theta=4.268704 -> V=1.0, theta=0.0
% INFO    : Bus 51958	: V=0.9984094, theta=10.654255 -> V=1.0, theta=0.0
% INFO    : Bus 51959	: V=0.9800094, theta=9.101968 -> V=1.0, theta=0.0
% INFO    : Bus 51960	: V=0.9815971, theta=8.784579 -> V=1.0, theta=0.0
% INFO    : Bus 51961	: V=0.9630816, theta=7.775924 -> V=1.0, theta=0.0
% INFO    : Bus 51962	: V=1.0183035, theta=20.826389 -> V=1.0, theta=0.0
% INFO    : Bus 51963	: V=1.0105305, theta=12.716827 -> V=1.0, theta=0.0
% INFO    : Bus 51964	: V=1.0176553, theta=19.842711 -> V=1.0, theta=0.0
% INFO    : Bus 51965	: V=1.0179209, theta=20.240694 -> V=1.0, theta=0.0
% INFO    : Bus 51966	: V=1.0199943, theta=22.891787 -> V=1.0, theta=0.0
% INFO    : Bus 51967	: V=1.0079428, theta=16.012419 -> V=1.0, theta=0.0
% INFO    : Bus 51968	: V=1.0118501, theta=16.459466 -> V=1.0, theta=0.0
% INFO    : Bus 51969	: V=1.010774, theta=15.762275 -> V=1.0, theta=0.0
% INFO    : Bus 51970	: V=0.9967989, theta=13.75611 -> V=1.0, theta=0.0
% INFO    : Bus 51971	: V=1.0147455, theta=17.803767 -> V=1.0, theta=0.0
% INFO    : Bus 51972	: V=1.0132508, theta=12.99788 -> V=1.0, theta=0.0
% INFO    : Bus 51973	: V=1.0057826, theta=10.869966 -> V=1.0, theta=0.0
% INFO    : Bus 51974	: V=1.02, theta=8.174045 -> V=1.0, theta=0.0
% INFO    : Bus 51975	: V=0.9933046, theta=1.068485 -> V=1.0, theta=0.0
% INFO    : Bus 51976	: V=1.0185459, theta=22.948104 -> V=1.0, theta=0.0
% INFO    : Bus 51977	: V=0.9628454, theta=-4.117843 -> V=1.0, theta=0.0
% INFO    : Bus 51978	: V=0.9944726, theta=-2.167287 -> V=1.0, theta=0.0
% INFO    : Bus 51979	: V=0.9709442, theta=-3.280769 -> V=1.0, theta=0.0
% INFO    : Bus 51980	: V=0.9915254, theta=-1.477139 -> V=1.0, theta=0.0
% INFO    : Bus 51981	: V=0.9684461, theta=1.760536 -> V=1.0, theta=0.0
% INFO    : Bus 51982	: V=0.9961596, theta=1.249164 -> V=1.0, theta=0.0
% INFO    : Bus 51983	: V=0.9695817, theta=5.227051 -> V=1.0, theta=0.0
% INFO    : Bus 51984	: V=0.9668193, theta=0.840574 -> V=1.0, theta=0.0
% INFO    : Bus 51985	: V=0.9806915, theta=-0.489981 -> V=1.0, theta=0.0
% INFO    : Bus 51986	: V=0.9766639, theta=2.600442 -> V=1.0, theta=0.0
% INFO    : Bus 51987	: V=0.9753102, theta=1.97111 -> V=1.0, theta=0.0
% INFO    : Bus 51988	: V=0.9719146, theta=1.422562 -> V=1.0, theta=0.0
% INFO    : Bus 51989	: V=0.9823702, theta=2.004878 -> V=1.0, theta=0.0
% INFO    : Bus 51990	: V=0.9634385, theta=4.173205 -> V=1.0, theta=0.0
% INFO    : Bus 51991	: V=0.9685837, theta=2.761512 -> V=1.0, theta=0.0
% INFO    : Bus 51992	: V=0.9666839, theta=4.123838 -> V=1.0, theta=0.0
% INFO    : Bus 51993	: V=0.9734508, theta=7.478098 -> V=1.0, theta=0.0
% INFO    : Bus 51994	: V=0.96777, theta=7.987734 -> V=1.0, theta=0.0
% INFO    : Bus 51995	: V=0.9653116, theta=5.958894 -> V=1.0, theta=0.0
% INFO    : Bus 51996	: V=0.9706173, theta=4.739808 -> V=1.0, theta=0.0
% INFO    : Bus 51997	: V=0.9704429, theta=-2.804738 -> V=1.0, theta=0.0
% INFO    : Bus 51998	: V=0.9627534, theta=-4.074205 -> V=1.0, theta=0.0
% INFO    : Bus 51999	: V=0.9616333, theta=-3.178703 -> V=1.0, theta=0.0
% INFO    : Bus 52000	: V=0.9844842, theta=-0.995098 -> V=1.0, theta=0.0
% INFO    : Bus 52001	: V=0.9860024, theta=1.591468 -> V=1.0, theta=0.0
% INFO    : Bus 52002	: V=0.9621502, theta=1.248251 -> V=1.0, theta=0.0
% INFO    : Bus 52003	: V=1.004517, theta=12.74743 -> V=1.0, theta=0.0
% INFO    : Bus 52004	: V=1.0088393, theta=11.569912 -> V=1.0, theta=0.0
% INFO    : Bus 52005	: V=1.0001122, theta=9.357576 -> V=1.0, theta=0.0
% INFO    : Bus 52006	: V=0.9810379, theta=8.099654 -> V=1.0, theta=0.0
% INFO    : Bus 52007	: V=1.0178207, theta=17.288664 -> V=1.0, theta=0.0
% INFO    : Bus 52008	: V=0.9693105, theta=11.014457 -> V=1.0, theta=0.0
% INFO    : Bus 52009	: V=0.9699402, theta=10.702678 -> V=1.0, theta=0.0
% INFO    : Bus 52010	: V=0.9705244, theta=10.829212 -> V=1.0, theta=0.0
% INFO    : Bus 52011	: V=0.9691477, theta=10.786849 -> V=1.0, theta=0.0
% INFO    : Bus 52012	: V=0.9744048, theta=11.20753 -> V=1.0, theta=0.0
% INFO    : Bus 52013	: V=0.9918389, theta=12.863546 -> V=1.0, theta=0.0
% INFO    : Bus 52014	: V=0.9884881, theta=11.282064 -> V=1.0, theta=0.0
% INFO    : Bus 52015	: V=0.9934805, theta=1.487195 -> V=1.0, theta=0.0
% INFO    : Bus 52016	: V=1.0017223, theta=5.422148 -> V=1.0, theta=0.0
% INFO    : Bus 52017	: V=1.0079655, theta=8.497711 -> V=1.0, theta=0.0
% INFO    : Bus 52018	: V=1.0054441, theta=4.456099 -> V=1.0, theta=0.0
% INFO    : Bus 52019	: V=1.0049088, theta=4.659345 -> V=1.0, theta=0.0
% INFO    : Bus 52020	: V=1.0044955, theta=4.991982 -> V=1.0, theta=0.0
% INFO    : Bus 52021	: V=1.005185, theta=4.38095 -> V=1.0, theta=0.0
% INFO    : Bus 52022	: V=0.9465266, theta=-5.444875 -> V=1.0, theta=0.0
% INFO    : Bus 52023	: V=0.9734385, theta=4.436242 -> V=1.0, theta=0.0
% INFO    : Bus 52024	: V=0.9746019, theta=3.461093 -> V=1.0, theta=0.0
% INFO    : Bus 52025	: V=0.9774318, theta=2.448628 -> V=1.0, theta=0.0
% INFO    : Bus 52026	: V=0.9707359, theta=4.473385 -> V=1.0, theta=0.0
% INFO    : Bus 52027	: V=0.9567187, theta=-0.653073 -> V=1.0, theta=0.0
% INFO    : Bus 52028	: V=0.9566219, theta=-0.929973 -> V=1.0, theta=0.0
% INFO    : Bus 52029	: V=0.9697629, theta=0.120641 -> V=1.0, theta=0.0
% INFO    : Bus 52030	: V=0.976054, theta=-0.607002 -> V=1.0, theta=0.0
% INFO    : Bus 52031	: V=0.9748653, theta=-1.400366 -> V=1.0, theta=0.0
% INFO    : Bus 52032	: V=0.9926349, theta=-1.545248 -> V=1.0, theta=0.0
% INFO    : Bus 52033	: V=0.9789635, theta=7.668692 -> V=1.0, theta=0.0
% INFO    : Bus 52034	: V=0.9775494, theta=7.549818 -> V=1.0, theta=0.0
% INFO    : Bus 52035	: V=0.9716458, theta=6.563891 -> V=1.0, theta=0.0
% INFO    : Bus 52036	: V=0.9702447, theta=6.439651 -> V=1.0, theta=0.0
% INFO    : Bus 52037	: V=0.969984, theta=6.406744 -> V=1.0, theta=0.0
% INFO    : Bus 52038	: V=0.9711132, theta=6.476844 -> V=1.0, theta=0.0
% INFO    : Bus 52039	: V=0.9741667, theta=6.744135 -> V=1.0, theta=0.0
% INFO    : Bus 52040	: V=0.9802255, theta=7.79212 -> V=1.0, theta=0.0
% INFO    : Bus 52041	: V=0.9723425, theta=6.912498 -> V=1.0, theta=0.0
% INFO    : Bus 52042	: V=0.9838057, theta=10.504932 -> V=1.0, theta=0.0
% INFO    : Bus 52043	: V=0.977129, theta=5.793449 -> V=1.0, theta=0.0
% INFO    : Bus 52044	: V=0.9944387, theta=9.549895 -> V=1.0, theta=0.0
% INFO    : Bus 52045	: V=0.9777239, theta=6.826817 -> V=1.0, theta=0.0
% INFO    : Bus 52046	: V=0.9937869, theta=9.025863 -> V=1.0, theta=0.0
% INFO    : Bus 52047	: V=1.0013734, theta=9.61121 -> V=1.0, theta=0.0
% INFO    : Bus 52048	: V=1.0033822, theta=6.842938 -> V=1.0, theta=0.0
% INFO    : Bus 52049	: V=1.0056246, theta=6.812725 -> V=1.0, theta=0.0
% INFO    : Bus 52050	: V=1.02, theta=7.660467 -> V=1.0, theta=0.0
% INFO    : Bus 52051	: V=1.0023756, theta=8.418781 -> V=1.0, theta=0.0
% INFO    : Bus 52052	: V=1.0005341, theta=9.284703 -> V=1.0, theta=0.0
% INFO    : Bus 52053	: V=1.0014216, theta=9.308941 -> V=1.0, theta=0.0
% INFO    : Bus 52054	: V=1.0092784, theta=14.302949 -> V=1.0, theta=0.0
% INFO    : Bus 52055	: V=0.9657223, theta=-34.318441 -> V=1.0, theta=0.0
% INFO    : Bus 52056	: V=0.9664125, theta=-34.944475 -> V=1.0, theta=0.0
% INFO    : Bus 52057	: V=0.9555514, theta=-37.326631 -> V=1.0, theta=0.0
% INFO    : Bus 52058	: V=0.9682258, theta=-35.965148 -> V=1.0, theta=0.0
% INFO    : Bus 52059	: V=0.9719147, theta=-36.165371 -> V=1.0, theta=0.0
% INFO    : Bus 52060	: V=0.9790746, theta=-48.954334 -> V=1.0, theta=0.0
% INFO    : Bus 52061	: V=0.9774093, theta=-50.342176 -> V=1.0, theta=0.0
% INFO    : Bus 52062	: V=0.9758605, theta=-51.802706 -> V=1.0, theta=0.0
% INFO    : Bus 52063	: V=1.0163667, theta=-46.487812 -> V=1.0, theta=0.0
% INFO    : Bus 52064	: V=1.0043385, theta=-50.492128 -> V=1.0, theta=0.0
% INFO    : Bus 52065	: V=0.999058, theta=-52.459467 -> V=1.0, theta=0.0
% INFO    : Bus 52066	: V=0.9695326, theta=-50.970615 -> V=1.0, theta=0.0
% INFO    : Bus 52067	: V=1.0090799, theta=-56.667912 -> V=1.0, theta=0.0
% INFO    : Bus 52068	: V=0.9747225, theta=-59.74027 -> V=1.0, theta=0.0
% INFO    : Bus 52069	: V=0.9951741, theta=-57.183287 -> V=1.0, theta=0.0
% INFO    : Bus 52070	: V=0.996105, theta=-55.347775 -> V=1.0, theta=0.0
% INFO    : Bus 52071	: V=0.9991012, theta=-55.017313 -> V=1.0, theta=0.0
% INFO    : Bus 52072	: V=0.9825594, theta=-56.670724 -> V=1.0, theta=0.0
% INFO    : Bus 52073	: V=0.9967834, theta=-55.421229 -> V=1.0, theta=0.0
% INFO    : Bus 52074	: V=0.9764732, theta=-54.121417 -> V=1.0, theta=0.0
% INFO    : Bus 52075	: V=0.981342, theta=-55.346425 -> V=1.0, theta=0.0
% INFO    : Bus 52076	: V=0.9707719, theta=-56.006898 -> V=1.0, theta=0.0
% INFO    : Bus 52077	: V=0.9828014, theta=-56.395174 -> V=1.0, theta=0.0
% INFO    : Bus 52078	: V=0.9824319, theta=-56.774099 -> V=1.0, theta=0.0
% INFO    : Bus 52079	: V=0.9992915, theta=-57.678097 -> V=1.0, theta=0.0
% INFO    : Bus 52080	: V=0.9964265, theta=-54.525169 -> V=1.0, theta=0.0
% INFO    : Bus 52081	: V=0.9873889, theta=-62.390823 -> V=1.0, theta=0.0
% INFO    : Bus 52082	: V=0.9937802, theta=-58.758656 -> V=1.0, theta=0.0
% INFO    : Bus 52083	: V=1.0017763, theta=-61.00485 -> V=1.0, theta=0.0
% INFO    : Bus 52084	: V=0.9949136, theta=-59.205142 -> V=1.0, theta=0.0
% INFO    : Bus 52085	: V=0.9950624, theta=-59.268261 -> V=1.0, theta=0.0
% INFO    : Bus 52086	: V=0.9852771, theta=-59.892979 -> V=1.0, theta=0.0
% INFO    : Bus 52087	: V=0.9834376, theta=-59.905112 -> V=1.0, theta=0.0
% INFO    : Bus 52088	: V=1.0030505, theta=-60.448541 -> V=1.0, theta=0.0
% INFO    : Bus 52089	: V=1.0055187, theta=-61.042356 -> V=1.0, theta=0.0
% INFO    : Bus 52090	: V=1.0001521, theta=-57.561805 -> V=1.0, theta=0.0
% INFO    : Bus 52091	: V=0.99597, theta=-57.775627 -> V=1.0, theta=0.0
% INFO    : Bus 52092	: V=1.006479, theta=-59.418622 -> V=1.0, theta=0.0
% INFO    : Bus 52093	: V=1.0143667, theta=-56.909243 -> V=1.0, theta=0.0
% INFO    : Bus 52094	: V=1.0079564, theta=-57.023444 -> V=1.0, theta=0.0
% INFO    : Bus 52095	: V=1.0194211, theta=-56.538445 -> V=1.0, theta=0.0
% INFO    : Bus 52096	: V=1.0034904, theta=-60.444146 -> V=1.0, theta=0.0
% INFO    : Bus 52097	: V=0.9683074, theta=-62.262518 -> V=1.0, theta=0.0
% INFO    : Bus 52098	: V=0.977592, theta=-55.895967 -> V=1.0, theta=0.0
% INFO    : Bus 52099	: V=0.9844348, theta=-53.11196 -> V=1.0, theta=0.0
% INFO    : Bus 52100	: V=0.9774047, theta=-54.437775 -> V=1.0, theta=0.0
% INFO    : Bus 52101	: V=0.9648851, theta=-55.740847 -> V=1.0, theta=0.0
% INFO    : Bus 52102	: V=0.9777897, theta=-54.74921 -> V=1.0, theta=0.0
% INFO    : Bus 52103	: V=0.978091, theta=-54.798685 -> V=1.0, theta=0.0
% INFO    : Bus 52104	: V=0.9785811, theta=-54.765924 -> V=1.0, theta=0.0
% INFO    : Bus 52105	: V=1.0034879, theta=-53.04979 -> V=1.0, theta=0.0
% INFO    : Bus 52106	: V=0.9638028, theta=-54.748114 -> V=1.0, theta=0.0
% INFO    : Bus 52107	: V=0.9640974, theta=-54.637882 -> V=1.0, theta=0.0
% INFO    : Bus 52108	: V=0.9723362, theta=-53.667354 -> V=1.0, theta=0.0
% INFO    : Bus 52109	: V=0.9727374, theta=-53.77485 -> V=1.0, theta=0.0
% INFO    : Bus 52110	: V=0.963308, theta=-54.774223 -> V=1.0, theta=0.0
% INFO    : Bus 52111	: V=0.9731861, theta=-53.795589 -> V=1.0, theta=0.0
% INFO    : Bus 52112	: V=0.9750871, theta=-53.787495 -> V=1.0, theta=0.0
% INFO    : Bus 52113	: V=0.9748639, theta=-54.083354 -> V=1.0, theta=0.0
% INFO    : Bus 52114	: V=0.9772262, theta=-53.508995 -> V=1.0, theta=0.0
% INFO    : Bus 52115	: V=0.9746347, theta=-54.013732 -> V=1.0, theta=0.0
% INFO    : Bus 52116	: V=0.9622991, theta=-54.758515 -> V=1.0, theta=0.0
% INFO    : Bus 52117	: V=0.9686627, theta=-54.593882 -> V=1.0, theta=0.0
% INFO    : Bus 52118	: V=0.9628738, theta=-54.773073 -> V=1.0, theta=0.0
% INFO    : Bus 52119	: V=0.9641678, theta=-54.707905 -> V=1.0, theta=0.0
% INFO    : Bus 52120	: V=0.9632889, theta=-54.746395 -> V=1.0, theta=0.0
% INFO    : Bus 52121	: V=0.9762983, theta=-54.163793 -> V=1.0, theta=0.0
% INFO    : Bus 52122	: V=0.9749223, theta=-53.989781 -> V=1.0, theta=0.0
% INFO    : Bus 52123	: V=0.9750169, theta=-54.416599 -> V=1.0, theta=0.0
% INFO    : Bus 52124	: V=0.9627623, theta=-55.140805 -> V=1.0, theta=0.0
% INFO    : Bus 52125	: V=0.9651853, theta=-54.69077 -> V=1.0, theta=0.0
% INFO    : Bus 52126	: V=0.9743464, theta=-54.177891 -> V=1.0, theta=0.0
% INFO    : Bus 52127	: V=0.9978886, theta=-55.978227 -> V=1.0, theta=0.0
% INFO    : Bus 52128	: V=0.9720065, theta=-65.730717 -> V=1.0, theta=0.0
% INFO    : Bus 52129	: V=0.9689187, theta=-66.253393 -> V=1.0, theta=0.0
% INFO    : Bus 52130	: V=0.9684287, theta=-66.422324 -> V=1.0, theta=0.0
% INFO    : Bus 52131	: V=0.9747761, theta=-61.566879 -> V=1.0, theta=0.0
% INFO    : Bus 52132	: V=0.9986793, theta=-55.873794 -> V=1.0, theta=0.0
% INFO    : Bus 52133	: V=0.9754658, theta=-61.991071 -> V=1.0, theta=0.0
% INFO    : Bus 52134	: V=0.9733139, theta=-61.98588 -> V=1.0, theta=0.0
% INFO    : Bus 52135	: V=0.9723808, theta=-61.834805 -> V=1.0, theta=0.0
% INFO    : Bus 52136	: V=0.9713634, theta=-61.930035 -> V=1.0, theta=0.0
% INFO    : Bus 52137	: V=0.9732715, theta=-61.742202 -> V=1.0, theta=0.0
% INFO    : Bus 52138	: V=0.9956456, theta=-33.210285 -> V=1.0, theta=0.0
% INFO    : Bus 52139	: V=0.9847521, theta=-35.098878 -> V=1.0, theta=0.0
% INFO    : Bus 52140	: V=0.9732542, theta=-35.637105 -> V=1.0, theta=0.0
% INFO    : Bus 52141	: V=0.9827243, theta=-34.411426 -> V=1.0, theta=0.0
% INFO    : Bus 52142	: V=0.9711897, theta=-35.683402 -> V=1.0, theta=0.0
% INFO    : Bus 52143	: V=0.9800171, theta=-34.761994 -> V=1.0, theta=0.0
% INFO    : Bus 52144	: V=0.9642609, theta=-35.411674 -> V=1.0, theta=0.0
% INFO    : Bus 52145	: V=0.97306, theta=-37.484664 -> V=1.0, theta=0.0
% INFO    : Bus 52146	: V=0.9736924, theta=-36.75251 -> V=1.0, theta=0.0
% INFO    : Bus 52147	: V=1.0134685, theta=-48.564881 -> V=1.0, theta=0.0
% INFO    : Bus 52148	: V=0.9887986, theta=-52.193702 -> V=1.0, theta=0.0
% INFO    : Bus 52149	: V=1.0065903, theta=-51.303542 -> V=1.0, theta=0.0
% INFO    : Bus 52150	: V=1.0071281, theta=-50.790026 -> V=1.0, theta=0.0
% INFO    : Bus 52151	: V=0.9779892, theta=-52.325405 -> V=1.0, theta=0.0
% INFO    : Bus 52152	: V=0.9902121, theta=-58.75957 -> V=1.0, theta=0.0
% INFO    : Bus 52153	: V=0.9987088, theta=-58.169493 -> V=1.0, theta=0.0
% INFO    : Bus 52154	: V=0.9769129, theta=-53.730609 -> V=1.0, theta=0.0
% INFO    : Bus 52155	: V=0.9781452, theta=-53.602501 -> V=1.0, theta=0.0
% INFO    : Bus 52156	: V=0.98201, theta=-53.378479 -> V=1.0, theta=0.0
% INFO    : Bus 52157	: V=0.9818644, theta=-53.389318 -> V=1.0, theta=0.0
% INFO    : Bus 52158	: V=0.9816743, theta=-53.424483 -> V=1.0, theta=0.0
% INFO    : Bus 52159	: V=0.9668383, theta=-54.48054 -> V=1.0, theta=0.0
% INFO    : Bus 52160	: V=0.965684, theta=-54.513929 -> V=1.0, theta=0.0
% INFO    : Bus 52161	: V=0.9794215, theta=-53.487536 -> V=1.0, theta=0.0
% INFO    : Bus 52162	: V=0.9966837, theta=-52.146369 -> V=1.0, theta=0.0
% INFO    : Bus 52163	: V=0.9696493, theta=-54.323463 -> V=1.0, theta=0.0
% INFO    : Bus 52164	: V=0.9720089, theta=-54.130926 -> V=1.0, theta=0.0
% INFO    : Bus 52165	: V=0.9660857, theta=-54.739203 -> V=1.0, theta=0.0
% INFO    : Bus 52166	: V=0.9677976, theta=-54.56907 -> V=1.0, theta=0.0
% INFO    : Bus 52167	: V=0.9704752, theta=-54.36872 -> V=1.0, theta=0.0
% INFO    : Bus 52168	: V=0.981719, theta=-53.441688 -> V=1.0, theta=0.0
% INFO    : Bus 52169	: V=0.9682557, theta=-54.402048 -> V=1.0, theta=0.0
% INFO    : Bus 52170	: V=0.9970151, theta=-52.362024 -> V=1.0, theta=0.0
% INFO    : Bus 52171	: V=0.9796657, theta=-53.165091 -> V=1.0, theta=0.0
% INFO    : Bus 52172	: V=0.9595887, theta=-54.639769 -> V=1.0, theta=0.0
% INFO    : Bus 52173	: V=0.9626345, theta=-54.593815 -> V=1.0, theta=0.0
% INFO    : Bus 52174	: V=0.9700118, theta=-54.409149 -> V=1.0, theta=0.0
% INFO    : Bus 52175	: V=0.9683686, theta=-54.471231 -> V=1.0, theta=0.0
% INFO    : Bus 52176	: V=0.9669428, theta=-54.604204 -> V=1.0, theta=0.0
% INFO    : Bus 52177	: V=0.9829614, theta=-53.283859 -> V=1.0, theta=0.0
% INFO    : Bus 52178	: V=0.9886886, theta=-53.177004 -> V=1.0, theta=0.0
% INFO    : Bus 52179	: V=0.9631073, theta=-53.952095 -> V=1.0, theta=0.0
% INFO    : Bus 52180	: V=0.9750085, theta=-53.199425 -> V=1.0, theta=0.0
% INFO    : Bus 52181	: V=0.9765925, theta=-53.121252 -> V=1.0, theta=0.0
% INFO    : Bus 52182	: V=0.9753689, theta=-53.721686 -> V=1.0, theta=0.0
% INFO    : Bus 52183	: V=0.9916151, theta=-53.043287 -> V=1.0, theta=0.0
% INFO    : Bus 52184	: V=0.9841308, theta=-53.647508 -> V=1.0, theta=0.0
% INFO    : Bus 52185	: V=0.9725975, theta=-53.605894 -> V=1.0, theta=0.0
% INFO    : Bus 52186	: V=0.9706402, theta=-53.587931 -> V=1.0, theta=0.0
% INFO    : Bus 52187	: V=0.983277, theta=-53.905065 -> V=1.0, theta=0.0
% INFO    : Bus 52188	: V=0.9875985, theta=-53.098995 -> V=1.0, theta=0.0
% INFO    : Bus 52189	: V=0.973143, theta=-53.739335 -> V=1.0, theta=0.0
% INFO    : Bus 52190	: V=0.9719696, theta=-53.367342 -> V=1.0, theta=0.0
% INFO    : Bus 52191	: V=0.9848622, theta=-53.12823 -> V=1.0, theta=0.0
% INFO    : Bus 52192	: V=0.9692634, theta=-53.722358 -> V=1.0, theta=0.0
% INFO    : Bus 52193	: V=0.9679514, theta=-53.359697 -> V=1.0, theta=0.0
% INFO    : Bus 52194	: V=0.9684476, theta=-53.299964 -> V=1.0, theta=0.0
% INFO    : Bus 52195	: V=0.9735455, theta=-53.275589 -> V=1.0, theta=0.0
% INFO    : Bus 52196	: V=0.9724058, theta=-53.338757 -> V=1.0, theta=0.0
% INFO    : Bus 52197	: V=0.9764496, theta=-52.931487 -> V=1.0, theta=0.0
% INFO    : Bus 52198	: V=0.9720731, theta=-53.186951 -> V=1.0, theta=0.0
% INFO    : Bus 52199	: V=0.9683693, theta=-53.32531 -> V=1.0, theta=0.0
% INFO    : Bus 52200	: V=0.9784643, theta=-53.012537 -> V=1.0, theta=0.0
% INFO    : Bus 52201	: V=0.9793901, theta=-52.95034 -> V=1.0, theta=0.0
% INFO    : Bus 52202	: V=0.9795752, theta=-52.83737 -> V=1.0, theta=0.0
% INFO    : Bus 52203	: V=0.9684431, theta=-53.276008 -> V=1.0, theta=0.0
% INFO    : Bus 52204	: V=0.9969873, theta=-51.655929 -> V=1.0, theta=0.0
% INFO    : Bus 52205	: V=0.9816577, theta=-53.098636 -> V=1.0, theta=0.0
% INFO    : Bus 52206	: V=0.9983022, theta=-52.818706 -> V=1.0, theta=0.0
% INFO    : Bus 52207	: V=0.9743479, theta=-53.559943 -> V=1.0, theta=0.0
% INFO    : Bus 52208	: V=0.9867621, theta=-51.842747 -> V=1.0, theta=0.0
% INFO    : Bus 52209	: V=0.9939034, theta=-50.94249 -> V=1.0, theta=0.0
% INFO    : Bus 52210	: V=0.959962, theta=-54.180449 -> V=1.0, theta=0.0
% INFO    : Bus 52211	: V=0.95791, theta=-54.59983 -> V=1.0, theta=0.0
% INFO    : Bus 52212	: V=0.9755488, theta=-54.612164 -> V=1.0, theta=0.0
% INFO    : Bus 52213	: V=0.972375, theta=-55.085005 -> V=1.0, theta=0.0
% INFO    : Bus 52214	: V=0.9965974, theta=-52.677612 -> V=1.0, theta=0.0
% INFO    : Bus 52215	: V=0.9684693, theta=-55.120191 -> V=1.0, theta=0.0
% INFO    : Bus 52216	: V=1.0004957, theta=-49.210975 -> V=1.0, theta=0.0
% INFO    : Bus 52217	: V=0.9634627, theta=-52.859414 -> V=1.0, theta=0.0
% INFO    : Bus 52218	: V=0.9771567, theta=-63.889926 -> V=1.0, theta=0.0
% INFO    : Bus 52219	: V=0.9727287, theta=-63.910394 -> V=1.0, theta=0.0
% INFO    : Bus 52220	: V=0.9738782, theta=-63.886824 -> V=1.0, theta=0.0
% INFO    : Bus 52221	: V=0.974859, theta=-63.791354 -> V=1.0, theta=0.0
% INFO    : Bus 52222	: V=0.9768323, theta=-63.692512 -> V=1.0, theta=0.0
% INFO    : Bus 52223	: V=0.9905403, theta=-62.620828 -> V=1.0, theta=0.0
% INFO    : Bus 52224	: V=0.9726667, theta=-63.866402 -> V=1.0, theta=0.0
% INFO    : Bus 52225	: V=0.9760844, theta=-63.856691 -> V=1.0, theta=0.0
% INFO    : Bus 52226	: V=0.9749733, theta=-63.936269 -> V=1.0, theta=0.0
% INFO    : Bus 52227	: V=0.983912, theta=-63.203504 -> V=1.0, theta=0.0
% INFO    : Bus 52228	: V=0.9761562, theta=-63.92095 -> V=1.0, theta=0.0
% INFO    : Bus 52229	: V=0.9755814, theta=-63.94706 -> V=1.0, theta=0.0
% INFO    : Bus 52230	: V=0.9756015, theta=-63.960857 -> V=1.0, theta=0.0
% INFO    : Bus 52231	: V=0.9749375, theta=-63.942542 -> V=1.0, theta=0.0
% INFO    : Bus 52232	: V=0.9749536, theta=-63.954306 -> V=1.0, theta=0.0
% INFO    : Bus 52233	: V=0.9754118, theta=-63.970974 -> V=1.0, theta=0.0
% INFO    : Bus 52234	: V=0.9766986, theta=-64.027198 -> V=1.0, theta=0.0
% INFO    : Bus 52235	: V=0.9772787, theta=-64.018278 -> V=1.0, theta=0.0
% INFO    : Bus 52236	: V=0.9758295, theta=-63.889118 -> V=1.0, theta=0.0
% INFO    : Bus 52237	: V=0.9964853, theta=-63.325058 -> V=1.0, theta=0.0
% INFO    : Bus 52238	: V=1.0029036, theta=-63.299753 -> V=1.0, theta=0.0
% INFO    : Bus 52239	: V=0.9981069, theta=-63.941595 -> V=1.0, theta=0.0
% INFO    : Bus 52240	: V=1.0031687, theta=-63.394254 -> V=1.0, theta=0.0
% INFO    : Bus 52241	: V=1.0037226, theta=-63.373197 -> V=1.0, theta=0.0
% INFO    : Bus 52242	: V=0.9639025, theta=-63.934086 -> V=1.0, theta=0.0
% INFO    : Bus 52243	: V=1.0064816, theta=-60.927524 -> V=1.0, theta=0.0
% INFO    : Bus 52244	: V=0.9665892, theta=-63.968491 -> V=1.0, theta=0.0
% INFO    : Bus 52245	: V=0.9870761, theta=-62.617189 -> V=1.0, theta=0.0
% INFO    : Bus 52246	: V=0.9956107, theta=-62.075015 -> V=1.0, theta=0.0
% INFO    : Bus 52247	: V=1.0052645, theta=-62.679557 -> V=1.0, theta=0.0
% INFO    : Bus 52248	: V=0.9775963, theta=-63.532265 -> V=1.0, theta=0.0
% INFO    : Bus 52249	: V=0.9759554, theta=-63.988322 -> V=1.0, theta=0.0
% INFO    : Bus 52250	: V=0.988603, theta=-63.484707 -> V=1.0, theta=0.0
% INFO    : Bus 52251	: V=0.984687, theta=-63.504355 -> V=1.0, theta=0.0
% INFO    : Bus 52252	: V=0.986095, theta=-30.135092 -> V=1.0, theta=0.0
% INFO    : Bus 52253	: V=0.9914969, theta=-31.755172 -> V=1.0, theta=0.0
% INFO    : Bus 52254	: V=0.9766554, theta=-32.22638 -> V=1.0, theta=0.0
% INFO    : Bus 52255	: V=0.9736885, theta=-32.302589 -> V=1.0, theta=0.0
% INFO    : Bus 52256	: V=0.9747257, theta=-31.987634 -> V=1.0, theta=0.0
% INFO    : Bus 52257	: V=0.9992176, theta=-38.190884 -> V=1.0, theta=0.0
% INFO    : Bus 52258	: V=0.9918493, theta=-38.718138 -> V=1.0, theta=0.0
% INFO    : Bus 52259	: V=0.9896775, theta=-38.814216 -> V=1.0, theta=0.0
% INFO    : Bus 52260	: V=0.9886251, theta=-39.85119 -> V=1.0, theta=0.0
% INFO    : Bus 52261	: V=0.9927059, theta=-39.074058 -> V=1.0, theta=0.0
% INFO    : Bus 52262	: V=0.9709449, theta=-43.217309 -> V=1.0, theta=0.0
% INFO    : Bus 52263	: V=0.9740471, theta=-42.637276 -> V=1.0, theta=0.0
% INFO    : Bus 52264	: V=0.9736525, theta=-41.579579 -> V=1.0, theta=0.0
% INFO    : Bus 52265	: V=0.9792254, theta=-40.665475 -> V=1.0, theta=0.0
% INFO    : Bus 52266	: V=0.9816323, theta=-40.447584 -> V=1.0, theta=0.0
% INFO    : Bus 52267	: V=0.9713635, theta=-43.005437 -> V=1.0, theta=0.0
% INFO    : Bus 52268	: V=0.9715457, theta=-43.309057 -> V=1.0, theta=0.0
% INFO    : Bus 52269	: V=0.9728824, theta=-43.353267 -> V=1.0, theta=0.0
% INFO    : Bus 52270	: V=0.9721591, theta=-45.231912 -> V=1.0, theta=0.0
% INFO    : Bus 52271	: V=0.9797578, theta=-41.678433 -> V=1.0, theta=0.0
% INFO    : Bus 52272	: V=0.9855935, theta=-39.264101 -> V=1.0, theta=0.0
% INFO    : Bus 52273	: V=0.988236, theta=-39.327926 -> V=1.0, theta=0.0
% INFO    : Bus 52274	: V=1.0051513, theta=-37.835299 -> V=1.0, theta=0.0
% INFO    : Bus 52275	: V=0.9894324, theta=-39.228387 -> V=1.0, theta=0.0
% INFO    : Bus 52276	: V=0.9904806, theta=-39.471389 -> V=1.0, theta=0.0
% INFO    : Bus 52277	: V=0.9921858, theta=-39.025285 -> V=1.0, theta=0.0
% INFO    : Bus 52278	: V=0.9909751, theta=-57.52558 -> V=1.0, theta=0.0
% INFO    : Bus 52279	: V=0.9891873, theta=-57.191426 -> V=1.0, theta=0.0
% INFO    : Bus 52280	: V=0.9933071, theta=-57.545837 -> V=1.0, theta=0.0
% INFO    : Bus 52281	: V=0.9880792, theta=-57.615249 -> V=1.0, theta=0.0
% INFO    : Bus 52282	: V=0.9889453, theta=-56.92428 -> V=1.0, theta=0.0
% INFO    : Bus 52283	: V=0.9705947, theta=-31.374935 -> V=1.0, theta=0.0
% INFO    : Bus 52284	: V=0.9629021, theta=-30.571827 -> V=1.0, theta=0.0
% INFO    : Bus 52285	: V=0.9718096, theta=-30.751447 -> V=1.0, theta=0.0
% INFO    : Bus 52286	: V=0.9849804, theta=-31.015157 -> V=1.0, theta=0.0
% INFO    : Bus 52287	: V=0.9763452, theta=-30.72735 -> V=1.0, theta=0.0
% INFO    : Bus 52288	: V=1.0050608, theta=-31.587569 -> V=1.0, theta=0.0
% INFO    : Bus 52289	: V=0.9693462, theta=-32.313846 -> V=1.0, theta=0.0
% INFO    : Bus 52290	: V=0.999107, theta=-32.014311 -> V=1.0, theta=0.0
% INFO    : Bus 52291	: V=0.9661748, theta=-33.479704 -> V=1.0, theta=0.0
% INFO    : Bus 52292	: V=0.9832861, theta=-55.678467 -> V=1.0, theta=0.0
% INFO    : Bus 52293	: V=1.0038658, theta=-56.338061 -> V=1.0, theta=0.0
% INFO    : Bus 52294	: V=0.9942375, theta=-56.733823 -> V=1.0, theta=0.0
% INFO    : Bus 52295	: V=0.9813348, theta=-56.265854 -> V=1.0, theta=0.0
% INFO    : Bus 52296	: V=0.9779451, theta=-57.211639 -> V=1.0, theta=0.0
% INFO    : Bus 52297	: V=0.9795788, theta=-49.445252 -> V=1.0, theta=0.0
% INFO    : Bus 52298	: V=0.9810806, theta=-48.964031 -> V=1.0, theta=0.0
% INFO    : Bus 52299	: V=0.9817531, theta=-49.686127 -> V=1.0, theta=0.0
% INFO    : Bus 52300	: V=0.9828785, theta=-49.591314 -> V=1.0, theta=0.0
% INFO    : Bus 52301	: V=0.9800307, theta=-47.954367 -> V=1.0, theta=0.0
% INFO    : Bus 52302	: V=0.9921957, theta=-46.398295 -> V=1.0, theta=0.0
% INFO    : Bus 52303	: V=0.9704412, theta=-50.604276 -> V=1.0, theta=0.0
% INFO    : Bus 52304	: V=0.9839918, theta=-49.473339 -> V=1.0, theta=0.0
% INFO    : Bus 52305	: V=0.9691416, theta=-50.689181 -> V=1.0, theta=0.0
% INFO    : Bus 52306	: V=0.9915209, theta=-45.659087 -> V=1.0, theta=0.0
% INFO    : Bus 52307	: V=0.9655795, theta=-50.960558 -> V=1.0, theta=0.0
% INFO    : Bus 52308	: V=0.9776887, theta=-49.621508 -> V=1.0, theta=0.0
% INFO    : Bus 52309	: V=0.9907727, theta=-54.244359 -> V=1.0, theta=0.0
% INFO    : Bus 52310	: V=0.9705946, theta=-55.728584 -> V=1.0, theta=0.0
% INFO    : Bus 52311	: V=0.9742078, theta=-55.700483 -> V=1.0, theta=0.0
% INFO    : Bus 52312	: V=0.9786104, theta=-55.631951 -> V=1.0, theta=0.0
% INFO    : Bus 52313	: V=0.9989793, theta=-53.423534 -> V=1.0, theta=0.0
% INFO    : Bus 52314	: V=0.9722778, theta=-56.93672 -> V=1.0, theta=0.0
% INFO    : Bus 52315	: V=0.9568807, theta=-61.300253 -> V=1.0, theta=0.0
% INFO    : Bus 52316	: V=0.959789, theta=-60.318802 -> V=1.0, theta=0.0
% INFO    : Bus 52317	: V=0.9647648, theta=-59.022138 -> V=1.0, theta=0.0
% INFO    : Bus 52318	: V=0.9703234, theta=-58.894371 -> V=1.0, theta=0.0
% INFO    : Bus 52319	: V=0.9699748, theta=-59.083147 -> V=1.0, theta=0.0
% INFO    : Bus 52320	: V=0.9853487, theta=-58.518128 -> V=1.0, theta=0.0
% INFO    : Bus 52321	: V=0.9896306, theta=-58.380609 -> V=1.0, theta=0.0
% INFO    : Bus 52322	: V=0.9622116, theta=-61.167468 -> V=1.0, theta=0.0
% INFO    : Bus 52323	: V=0.9863524, theta=-56.164651 -> V=1.0, theta=0.0
% INFO    : Bus 52324	: V=0.9835917, theta=-55.50375 -> V=1.0, theta=0.0
% INFO    : Bus 52325	: V=0.9814203, theta=-55.28531 -> V=1.0, theta=0.0
% INFO    : Bus 52326	: V=0.96773, theta=-55.099656 -> V=1.0, theta=0.0
% INFO    : Bus 52327	: V=0.9682475, theta=-59.155188 -> V=1.0, theta=0.0
% INFO    : Bus 52328	: V=0.9767186, theta=-46.85237 -> V=1.0, theta=0.0
% INFO    : Bus 52329	: V=0.9738061, theta=-45.323548 -> V=1.0, theta=0.0
% INFO    : Bus 52330	: V=0.9927824, theta=-57.202143 -> V=1.0, theta=0.0
% INFO    : Bus 52331	: V=0.9909474, theta=-58.436578 -> V=1.0, theta=0.0
% INFO    : Bus 52332	: V=0.9695607, theta=-60.657989 -> V=1.0, theta=0.0
% INFO    : Bus 52333	: V=1.0172607, theta=-52.138173 -> V=1.0, theta=0.0
% INFO    : Bus 52334	: V=1.0217179, theta=-51.213315 -> V=1.0, theta=0.0
% INFO    : Bus 52335	: V=1.0042731, theta=-38.618546 -> V=1.0, theta=0.0
% INFO    : Bus 52336	: V=0.9851532, theta=-39.829563 -> V=1.0, theta=0.0
% INFO    : Bus 52337	: V=0.9848973, theta=-40.863078 -> V=1.0, theta=0.0
% INFO    : Bus 52338	: V=0.9785559, theta=-40.974041 -> V=1.0, theta=0.0
% INFO    : Bus 52339	: V=0.9716359, theta=-45.144294 -> V=1.0, theta=0.0
% INFO    : Bus 52340	: V=0.9646271, theta=-49.445076 -> V=1.0, theta=0.0
% INFO    : Bus 52341	: V=0.9766906, theta=-50.245962 -> V=1.0, theta=0.0
% INFO    : Bus 52342	: V=0.9662119, theta=-49.97049 -> V=1.0, theta=0.0
% INFO    : Bus 52343	: V=0.9891857, theta=-49.223296 -> V=1.0, theta=0.0
% INFO    : Bus 52344	: V=0.9974622, theta=-60.029735 -> V=1.0, theta=0.0
% INFO    : Bus 52345	: V=0.9740234, theta=-60.812691 -> V=1.0, theta=0.0
% INFO    : Bus 52346	: V=0.9910762, theta=-59.896851 -> V=1.0, theta=0.0
% INFO    : Bus 52347	: V=0.9942605, theta=-59.644859 -> V=1.0, theta=0.0
% INFO    : Bus 52348	: V=1.0174884, theta=-58.661101 -> V=1.0, theta=0.0
% INFO    : Bus 52349	: V=0.9856641, theta=-60.252785 -> V=1.0, theta=0.0
% INFO    : Bus 52350	: V=0.9838899, theta=-60.255293 -> V=1.0, theta=0.0
% INFO    : Bus 52351	: V=0.9835029, theta=-60.304655 -> V=1.0, theta=0.0
% INFO    : Bus 52352	: V=0.965777, theta=-67.142337 -> V=1.0, theta=0.0
% INFO    : Bus 52353	: V=0.9718154, theta=-67.095155 -> V=1.0, theta=0.0
% INFO    : Bus 52354	: V=0.965349, theta=-66.952176 -> V=1.0, theta=0.0
% INFO    : Bus 52355	: V=0.991583, theta=-56.276639 -> V=1.0, theta=0.0
% INFO    : Bus 52356	: V=0.975417, theta=-57.788405 -> V=1.0, theta=0.0
% INFO    : Bus 52357	: V=0.9719213, theta=-57.774912 -> V=1.0, theta=0.0
% INFO    : Bus 52358	: V=1.0073999, theta=-39.461986 -> V=1.0, theta=0.0
% INFO    : Bus 52359	: V=1.0004961, theta=-39.861239 -> V=1.0, theta=0.0
% INFO    : Bus 52360	: V=1.0075056, theta=-39.262824 -> V=1.0, theta=0.0
% INFO    : Bus 52361	: V=1.0090361, theta=-39.57456 -> V=1.0, theta=0.0
% INFO    : Bus 52362	: V=0.9992564, theta=-39.895414 -> V=1.0, theta=0.0
% INFO    : Bus 52363	: V=0.9993591, theta=-39.891688 -> V=1.0, theta=0.0
% INFO    : Bus 52364	: V=1.0030923, theta=-39.711739 -> V=1.0, theta=0.0
% INFO    : Bus 52365	: V=0.9538042, theta=-43.656347 -> V=1.0, theta=0.0
% INFO    : Bus 52366	: V=1.0063134, theta=-38.666005 -> V=1.0, theta=0.0
% INFO    : Bus 52367	: V=0.9203138, theta=-48.963262 -> V=1.0, theta=0.0
% INFO    : Bus 52368	: V=0.9742201, theta=-41.212309 -> V=1.0, theta=0.0
% INFO    : Bus 52369	: V=0.9774931, theta=-49.844342 -> V=1.0, theta=0.0
% INFO    : Bus 52370	: V=0.9719135, theta=-52.186401 -> V=1.0, theta=0.0
% INFO    : Bus 52371	: V=0.9694981, theta=-53.152908 -> V=1.0, theta=0.0
% INFO    : Bus 52372	: V=0.9694758, theta=-53.667746 -> V=1.0, theta=0.0
% INFO    : Bus 52373	: V=1.0002641, theta=-58.578499 -> V=1.0, theta=0.0
% INFO    : Bus 52374	: V=0.9905279, theta=-58.651038 -> V=1.0, theta=0.0
% INFO    : Bus 52375	: V=0.9784933, theta=-60.059551 -> V=1.0, theta=0.0
% INFO    : Bus 52376	: V=0.990308, theta=-41.689901 -> V=1.0, theta=0.0
% INFO    : Bus 52377	: V=0.982757, theta=-43.061726 -> V=1.0, theta=0.0
% INFO    : Bus 52378	: V=0.9877591, theta=-43.493719 -> V=1.0, theta=0.0
% INFO    : Bus 52379	: V=0.9761613, theta=-39.977116 -> V=1.0, theta=0.0
% INFO    : Bus 52380	: V=0.9715934, theta=-38.083647 -> V=1.0, theta=0.0
% INFO    : Bus 52381	: V=1.0121275, theta=-38.032509 -> V=1.0, theta=0.0
% INFO    : Bus 52382	: V=1.0047352, theta=-39.498054 -> V=1.0, theta=0.0
% INFO    : Bus 52383	: V=0.9771847, theta=-41.358645 -> V=1.0, theta=0.0
% INFO    : Bus 52384	: V=1.0031204, theta=-38.212294 -> V=1.0, theta=0.0
% INFO    : Bus 52385	: V=0.9775426, theta=-41.375408 -> V=1.0, theta=0.0
% INFO    : Bus 52386	: V=0.9806462, theta=-41.114009 -> V=1.0, theta=0.0
% INFO    : Bus 52387	: V=0.9984881, theta=-40.365869 -> V=1.0, theta=0.0
% INFO    : Bus 52388	: V=1.000634, theta=-40.196805 -> V=1.0, theta=0.0
% INFO    : Bus 52389	: V=0.9972228, theta=-40.762328 -> V=1.0, theta=0.0
% INFO    : Bus 52390	: V=0.9962657, theta=-41.894302 -> V=1.0, theta=0.0
% INFO    : Bus 52391	: V=0.9907281, theta=-44.617628 -> V=1.0, theta=0.0
% INFO    : Bus 52392	: V=0.9888994, theta=-46.261888 -> V=1.0, theta=0.0
% INFO    : Bus 52393	: V=1.003095, theta=-48.117243 -> V=1.0, theta=0.0
% INFO    : Bus 52394	: V=0.9815442, theta=-50.741152 -> V=1.0, theta=0.0
% INFO    : Bus 52395	: V=0.9825358, theta=-48.564031 -> V=1.0, theta=0.0
% INFO    : Bus 52396	: V=0.9897294, theta=-47.951782 -> V=1.0, theta=0.0
% INFO    : Bus 52397	: V=0.9946265, theta=-46.682771 -> V=1.0, theta=0.0
% INFO    : Bus 52398	: V=1.006862, theta=-47.834569 -> V=1.0, theta=0.0
% INFO    : Bus 52399	: V=0.9885653, theta=-48.987316 -> V=1.0, theta=0.0
% INFO    : Bus 52400	: V=1.004948, theta=-48.124466 -> V=1.0, theta=0.0
% INFO    : Bus 52401	: V=1.001102, theta=-48.725167 -> V=1.0, theta=0.0
% INFO    : Bus 52402	: V=1.0078158, theta=-47.696539 -> V=1.0, theta=0.0
% INFO    : Bus 52403	: V=1.000948, theta=-47.647422 -> V=1.0, theta=0.0
% INFO    : Bus 52404	: V=0.9957628, theta=-47.534729 -> V=1.0, theta=0.0
% INFO    : Bus 52405	: V=0.9998836, theta=-48.446545 -> V=1.0, theta=0.0
% INFO    : Bus 52406	: V=0.9646061, theta=-65.901641 -> V=1.0, theta=0.0
% INFO    : Bus 52407	: V=0.9633139, theta=-66.62802 -> V=1.0, theta=0.0
% INFO    : Bus 52408	: V=0.9675194, theta=-67.198147 -> V=1.0, theta=0.0
% INFO    : Bus 52409	: V=0.9780899, theta=-54.35934 -> V=1.0, theta=0.0
% INFO    : Bus 52410	: V=0.9583664, theta=-56.630295 -> V=1.0, theta=0.0
% INFO    : Bus 52411	: V=0.9707727, theta=-57.662363 -> V=1.0, theta=0.0
% INFO    : Bus 52412	: V=0.9957883, theta=-52.918973 -> V=1.0, theta=0.0
% INFO    : Bus 52413	: V=0.970139, theta=-55.105787 -> V=1.0, theta=0.0
% INFO    : Bus 52414	: V=0.9689466, theta=-55.458834 -> V=1.0, theta=0.0
% INFO    : Bus 52415	: V=0.9970889, theta=-43.224862 -> V=1.0, theta=0.0
% INFO    : Bus 52416	: V=1.0008937, theta=-48.361489 -> V=1.0, theta=0.0
% INFO    : Bus 52417	: V=1.0057625, theta=-48.867202 -> V=1.0, theta=0.0
% INFO    : Bus 52418	: V=0.9938843, theta=-44.580796 -> V=1.0, theta=0.0
% INFO    : Bus 52419	: V=0.9938132, theta=-45.058697 -> V=1.0, theta=0.0
% INFO    : Bus 52420	: V=0.9992799, theta=-49.303188 -> V=1.0, theta=0.0
% INFO    : Bus 52421	: V=0.9966069, theta=-48.161692 -> V=1.0, theta=0.0
% INFO    : Bus 52422	: V=0.9921592, theta=-48.839871 -> V=1.0, theta=0.0
% INFO    : Bus 52423	: V=0.9767397, theta=-39.339916 -> V=1.0, theta=0.0
% INFO    : Bus 52424	: V=0.9924077, theta=-38.269138 -> V=1.0, theta=0.0
% INFO    : Bus 52425	: V=0.9605965, theta=-41.949493 -> V=1.0, theta=0.0
% INFO    : Bus 52426	: V=0.9722646, theta=-42.448113 -> V=1.0, theta=0.0
% INFO    : Bus 52427	: V=0.9864056, theta=-40.659098 -> V=1.0, theta=0.0
% INFO    : Bus 52428	: V=0.989781, theta=-39.491829 -> V=1.0, theta=0.0
% INFO    : Bus 52429	: V=0.9774171, theta=-52.483338 -> V=1.0, theta=0.0
% INFO    : Bus 52430	: V=0.9853009, theta=-55.155718 -> V=1.0, theta=0.0
% INFO    : Bus 52431	: V=0.9762399, theta=-53.498793 -> V=1.0, theta=0.0
% INFO    : Bus 52432	: V=0.9781809, theta=-61.931826 -> V=1.0, theta=0.0
% INFO    : Bus 52433	: V=0.9746493, theta=-61.461187 -> V=1.0, theta=0.0
% INFO    : Bus 52434	: V=0.9832669, theta=-61.697308 -> V=1.0, theta=0.0
% INFO    : Bus 52435	: V=0.98646, theta=-61.050718 -> V=1.0, theta=0.0
% INFO    : Bus 52436	: V=1.0093313, theta=-32.346252 -> V=1.0, theta=0.0
% INFO    : Bus 52437	: V=1.007675, theta=-32.477443 -> V=1.0, theta=0.0
% INFO    : Bus 52438	: V=1.0086559, theta=-32.193624 -> V=1.0, theta=0.0
% INFO    : Bus 52439	: V=1.0183748, theta=-31.806356 -> V=1.0, theta=0.0
% INFO    : Bus 52440	: V=0.9949055, theta=-32.59491 -> V=1.0, theta=0.0
% INFO    : Bus 52441	: V=1.0169032, theta=-31.481697 -> V=1.0, theta=0.0
% INFO    : Bus 52442	: V=1.0139446, theta=-31.268408 -> V=1.0, theta=0.0
% INFO    : Bus 52443	: V=1.0039793, theta=-31.370758 -> V=1.0, theta=0.0
% INFO    : Bus 52444	: V=0.98699, theta=-33.133857 -> V=1.0, theta=0.0
% INFO    : Bus 52445	: V=0.9720225, theta=-57.341524 -> V=1.0, theta=0.0
% INFO    : Bus 52446	: V=0.9888958, theta=-55.945396 -> V=1.0, theta=0.0
% INFO    : Bus 52447	: V=0.9734941, theta=-57.028175 -> V=1.0, theta=0.0
% INFO    : Bus 52448	: V=1.0117766, theta=-34.215109 -> V=1.0, theta=0.0
% INFO    : Bus 52449	: V=1.0026165, theta=-34.648371 -> V=1.0, theta=0.0
% INFO    : Bus 52450	: V=1.0132555, theta=-34.055458 -> V=1.0, theta=0.0
% INFO    : Bus 52451	: V=1.018512, theta=-33.19262 -> V=1.0, theta=0.0
% INFO    : Bus 52452	: V=1.01862, theta=-33.419978 -> V=1.0, theta=0.0
% INFO    : Bus 52453	: V=1.015407, theta=-33.848008 -> V=1.0, theta=0.0
% INFO    : Bus 52454	: V=1.0193088, theta=-33.232756 -> V=1.0, theta=0.0
% INFO    : Bus 52455	: V=1.0158433, theta=-33.736377 -> V=1.0, theta=0.0
% INFO    : Bus 52456	: V=1.0190153, theta=-33.320474 -> V=1.0, theta=0.0
% INFO    : Bus 52457	: V=1.0021807, theta=-34.656127 -> V=1.0, theta=0.0
% INFO    : Bus 52458	: V=1.0021365, theta=-36.057259 -> V=1.0, theta=0.0
% INFO    : Bus 52459	: V=1.0041638, theta=-35.308238 -> V=1.0, theta=0.0
% INFO    : Bus 52460	: V=1.0106016, theta=-35.528958 -> V=1.0, theta=0.0
% INFO    : Bus 52461	: V=1.0099748, theta=-34.064027 -> V=1.0, theta=0.0
% INFO    : Bus 52462	: V=1.0048729, theta=-38.090535 -> V=1.0, theta=0.0
% INFO    : Bus 52463	: V=0.9903273, theta=-37.496492 -> V=1.0, theta=0.0
% INFO    : Bus 52464	: V=1.0064596, theta=-42.311879 -> V=1.0, theta=0.0
% INFO    : Bus 52465	: V=0.9738229, theta=-49.631665 -> V=1.0, theta=0.0
% INFO    : Bus 52466	: V=0.9721166, theta=-49.891245 -> V=1.0, theta=0.0
% INFO    : Bus 52467	: V=0.9714144, theta=-49.993691 -> V=1.0, theta=0.0
% INFO    : Bus 52468	: V=0.9792301, theta=-34.210789 -> V=1.0, theta=0.0
% INFO    : Bus 52469	: V=0.9827082, theta=-34.48438 -> V=1.0, theta=0.0
% INFO    : Bus 52470	: V=0.9807586, theta=-36.594951 -> V=1.0, theta=0.0
% INFO    : Bus 52471	: V=0.9882345, theta=-34.839523 -> V=1.0, theta=0.0
% INFO    : Bus 52472	: V=0.967727, theta=-46.940209 -> V=1.0, theta=0.0
% INFO    : Bus 52473	: V=0.975353, theta=-47.176833 -> V=1.0, theta=0.0
% INFO    : Bus 52474	: V=0.9673088, theta=-47.322584 -> V=1.0, theta=0.0
% INFO    : Bus 52475	: V=0.9693663, theta=-44.66327 -> V=1.0, theta=0.0
% INFO    : Bus 52476	: V=0.972295, theta=-52.930156 -> V=1.0, theta=0.0
% INFO    : Bus 52477	: V=0.9729523, theta=-52.880737 -> V=1.0, theta=0.0
% INFO    : Bus 52478	: V=0.9722356, theta=-52.949622 -> V=1.0, theta=0.0
% INFO    : Bus 52479	: V=0.9583906, theta=-54.410499 -> V=1.0, theta=0.0
% INFO    : Bus 52480	: V=0.9598359, theta=-54.119897 -> V=1.0, theta=0.0
% INFO    : Bus 52481	: V=0.9622156, theta=-53.948303 -> V=1.0, theta=0.0
% INFO    : Bus 52482	: V=0.9722603, theta=-52.962994 -> V=1.0, theta=0.0
% INFO    : Bus 52483	: V=0.9602954, theta=-53.876862 -> V=1.0, theta=0.0
% INFO    : Bus 52484	: V=0.9609629, theta=-54.64645 -> V=1.0, theta=0.0
% INFO    : Bus 52485	: V=0.9739676, theta=-52.824172 -> V=1.0, theta=0.0
% INFO    : Bus 52486	: V=0.9629062, theta=-53.912027 -> V=1.0, theta=0.0
% INFO    : Bus 52487	: V=0.9623749, theta=-53.94825 -> V=1.0, theta=0.0
% INFO    : Bus 52488	: V=0.9603999, theta=-54.222234 -> V=1.0, theta=0.0
% INFO    : Bus 52489	: V=0.9603586, theta=-54.057643 -> V=1.0, theta=0.0
% INFO    : Bus 52490	: V=0.96047, theta=-54.074369 -> V=1.0, theta=0.0
% INFO    : Bus 52491	: V=0.961283, theta=-54.013002 -> V=1.0, theta=0.0
% INFO    : Bus 52492	: V=0.9617684, theta=-53.979479 -> V=1.0, theta=0.0
% INFO    : Bus 52493	: V=0.9622738, theta=-53.952176 -> V=1.0, theta=0.0
% INFO    : Bus 52494	: V=0.9740241, theta=-52.869293 -> V=1.0, theta=0.0
% INFO    : Bus 52495	: V=0.9623569, theta=-54.551951 -> V=1.0, theta=0.0
% INFO    : Bus 52496	: V=0.9613411, theta=-54.630755 -> V=1.0, theta=0.0
% INFO    : Bus 52497	: V=0.9610077, theta=-54.649877 -> V=1.0, theta=0.0
% INFO    : Bus 52498	: V=0.9626609, theta=-54.533459 -> V=1.0, theta=0.0
% INFO    : Bus 52499	: V=0.9741598, theta=-52.908946 -> V=1.0, theta=0.0
% INFO    : Bus 52500	: V=0.9618673, theta=-53.932312 -> V=1.0, theta=0.0
% INFO    : Bus 52501	: V=0.9599245, theta=-54.020027 -> V=1.0, theta=0.0
% INFO    : Bus 52502	: V=0.9606082, theta=-54.050449 -> V=1.0, theta=0.0
% INFO    : Bus 52503	: V=0.9607553, theta=-54.202185 -> V=1.0, theta=0.0
% INFO    : Bus 52504	: V=0.9776908, theta=-52.569676 -> V=1.0, theta=0.0
% INFO    : Bus 52505	: V=0.9604018, theta=-54.019888 -> V=1.0, theta=0.0
% INFO    : Bus 52506	: V=0.962597, theta=-53.880104 -> V=1.0, theta=0.0
% INFO    : Bus 52507	: V=0.9743862, theta=-52.942912 -> V=1.0, theta=0.0
% INFO    : Bus 52508	: V=0.9747695, theta=-52.977569 -> V=1.0, theta=0.0
% INFO    : Bus 52509	: V=0.964396, theta=-54.306695 -> V=1.0, theta=0.0
% INFO    : Bus 52510	: V=0.9632039, theta=-53.863921 -> V=1.0, theta=0.0
% INFO    : Bus 52511	: V=0.967055, theta=-53.646642 -> V=1.0, theta=0.0
% INFO    : Bus 52512	: V=0.965033, theta=-53.757336 -> V=1.0, theta=0.0
% INFO    : Bus 52513	: V=0.961818, theta=-53.929407 -> V=1.0, theta=0.0
% INFO    : Bus 52514	: V=0.978999, theta=-52.592203 -> V=1.0, theta=0.0
% INFO    : Bus 52515	: V=0.9635259, theta=-53.792188 -> V=1.0, theta=0.0
% INFO    : Bus 52516	: V=0.9972867, theta=-50.938948 -> V=1.0, theta=0.0
% INFO    : Bus 52517	: V=0.967122, theta=-53.698452 -> V=1.0, theta=0.0
% INFO    : Bus 52518	: V=0.9765108, theta=-52.881354 -> V=1.0, theta=0.0
% INFO    : Bus 52519	: V=0.9673704, theta=-53.598162 -> V=1.0, theta=0.0
% INFO    : Bus 52520	: V=0.9663687, theta=-53.620023 -> V=1.0, theta=0.0
% INFO    : Bus 52521	: V=0.965237, theta=-53.700624 -> V=1.0, theta=0.0
% INFO    : Bus 52522	: V=0.9642584, theta=-53.764769 -> V=1.0, theta=0.0
% INFO    : Bus 52523	: V=0.9706045, theta=-53.346607 -> V=1.0, theta=0.0
% INFO    : Bus 52524	: V=0.9791937, theta=-52.537463 -> V=1.0, theta=0.0
% INFO    : Bus 52525	: V=0.9674333, theta=-53.552038 -> V=1.0, theta=0.0
% INFO    : Bus 52526	: V=0.9860715, theta=-51.569956 -> V=1.0, theta=0.0
% INFO    : Bus 52527	: V=0.9576384, theta=-54.472195 -> V=1.0, theta=0.0
% INFO    : Bus 52528	: V=0.9574438, theta=-54.477787 -> V=1.0, theta=0.0
% INFO    : Bus 52529	: V=0.998168, theta=-50.711219 -> V=1.0, theta=0.0
% INFO    : Bus 52530	: V=0.9685303, theta=-53.444804 -> V=1.0, theta=0.0
% INFO    : Bus 52531	: V=0.9669295, theta=-53.704703 -> V=1.0, theta=0.0
% INFO    : Bus 52532	: V=0.9622021, theta=-53.924427 -> V=1.0, theta=0.0
% INFO    : Bus 52533	: V=0.9748799, theta=-52.944515 -> V=1.0, theta=0.0
% INFO    : Bus 52534	: V=0.9642683, theta=-54.322022 -> V=1.0, theta=0.0
% INFO    : Bus 52535	: V=0.9601065, theta=-54.046778 -> V=1.0, theta=0.0
% INFO    : Bus 52536	: V=0.9605723, theta=-53.944395 -> V=1.0, theta=0.0
% INFO    : Bus 52537	: V=0.9599987, theta=-54.082187 -> V=1.0, theta=0.0
% INFO    : Bus 52538	: V=0.9592978, theta=-54.121964 -> V=1.0, theta=0.0
% INFO    : Bus 52539	: V=0.9586637, theta=-54.159912 -> V=1.0, theta=0.0
% INFO    : Bus 52540	: V=0.9693932, theta=-52.888659 -> V=1.0, theta=0.0
% INFO    : Bus 52541	: V=0.9670145, theta=-53.199835 -> V=1.0, theta=0.0
% INFO    : Bus 52542	: V=0.9778582, theta=-52.271925 -> V=1.0, theta=0.0
% INFO    : Bus 52543	: V=0.9730589, theta=-52.811517 -> V=1.0, theta=0.0
% INFO    : Bus 52544	: V=0.9751125, theta=-52.603719 -> V=1.0, theta=0.0
% INFO    : Bus 52545	: V=0.9734675, theta=-52.781684 -> V=1.0, theta=0.0
% INFO    : Bus 52546	: V=0.972823, theta=-52.848956 -> V=1.0, theta=0.0
% INFO    : Bus 52547	: V=0.9707888, theta=-52.959737 -> V=1.0, theta=0.0
% INFO    : Bus 52548	: V=0.9717129, theta=-52.884616 -> V=1.0, theta=0.0
% INFO    : Bus 52549	: V=0.9723885, theta=-52.893642 -> V=1.0, theta=0.0
% INFO    : Bus 52550	: V=0.9603759, theta=-53.940964 -> V=1.0, theta=0.0
% INFO    : Bus 52551	: V=0.9690832, theta=-53.122643 -> V=1.0, theta=0.0
% INFO    : Bus 52552	: V=0.9697876, theta=-53.100341 -> V=1.0, theta=0.0
% INFO    : Bus 52553	: V=0.9604255, theta=-54.004357 -> V=1.0, theta=0.0
% INFO    : Bus 52554	: V=0.9695776, theta=-53.096783 -> V=1.0, theta=0.0
% INFO    : Bus 52555	: V=0.9628695, theta=-53.820883 -> V=1.0, theta=0.0
% INFO    : Bus 52556	: V=0.9621424, theta=-53.91351 -> V=1.0, theta=0.0
% INFO    : Bus 52557	: V=0.9698825, theta=-53.050765 -> V=1.0, theta=0.0
% INFO    : Bus 52558	: V=0.9702681, theta=-53.01323 -> V=1.0, theta=0.0
% INFO    : Bus 52559	: V=0.9695291, theta=-53.090084 -> V=1.0, theta=0.0
% INFO    : Bus 52560	: V=0.9606555, theta=-54.0673 -> V=1.0, theta=0.0
% INFO    : Bus 52561	: V=0.9611775, theta=-54.182831 -> V=1.0, theta=0.0
% INFO    : Bus 52562	: V=0.9608721, theta=-54.001385 -> V=1.0, theta=0.0
% INFO    : Bus 52563	: V=0.9609047, theta=-53.972382 -> V=1.0, theta=0.0
% INFO    : Bus 52564	: V=0.971075, theta=-53.376934 -> V=1.0, theta=0.0
% INFO    : Bus 52565	: V=0.9606906, theta=-54.158482 -> V=1.0, theta=0.0
% INFO    : Bus 52566	: V=0.959769, theta=-54.112618 -> V=1.0, theta=0.0
% INFO    : Bus 52567	: V=0.9601133, theta=-54.086955 -> V=1.0, theta=0.0
% INFO    : Bus 52568	: V=0.9594948, theta=-54.148908 -> V=1.0, theta=0.0
% INFO    : Bus 52569	: V=0.9708612, theta=-53.481276 -> V=1.0, theta=0.0
% INFO    : Bus 52570	: V=0.9601579, theta=-54.175539 -> V=1.0, theta=0.0
% INFO    : Bus 52571	: V=0.9761217, theta=-53.364117 -> V=1.0, theta=0.0
% INFO    : Bus 52572	: V=0.9618954, theta=-54.053486 -> V=1.0, theta=0.0
% INFO    : Bus 52573	: V=0.9716129, theta=-53.498726 -> V=1.0, theta=0.0
% INFO    : Bus 52574	: V=0.9698248, theta=-53.770108 -> V=1.0, theta=0.0
% INFO    : Bus 52575	: V=0.975461, theta=-53.437016 -> V=1.0, theta=0.0
% INFO    : Bus 52576	: V=0.9765207, theta=-53.450868 -> V=1.0, theta=0.0
% INFO    : Bus 52577	: V=1.0025297, theta=-51.595294 -> V=1.0, theta=0.0
% INFO    : Bus 52578	: V=0.9753864, theta=-53.263885 -> V=1.0, theta=0.0
% INFO    : Bus 52579	: V=0.9733723, theta=-53.486322 -> V=1.0, theta=0.0
% INFO    : Bus 52580	: V=0.9604465, theta=-54.184193 -> V=1.0, theta=0.0
% INFO    : Bus 52581	: V=0.9651834, theta=-53.821736 -> V=1.0, theta=0.0
% INFO    : Bus 52582	: V=0.9591493, theta=-54.149266 -> V=1.0, theta=0.0
% INFO    : Bus 52583	: V=0.9828911, theta=-53.262895 -> V=1.0, theta=0.0
% INFO    : Bus 52584	: V=0.96882, theta=-53.704007 -> V=1.0, theta=0.0
% INFO    : Bus 52585	: V=0.9804111, theta=-53.200971 -> V=1.0, theta=0.0
% INFO    : Bus 52586	: V=0.9716201, theta=-53.381168 -> V=1.0, theta=0.0
% INFO    : Bus 52587	: V=0.9656817, theta=-53.614654 -> V=1.0, theta=0.0
% INFO    : Bus 52588	: V=0.9660822, theta=-53.561859 -> V=1.0, theta=0.0
% INFO    : Bus 52589	: V=0.9692214, theta=-53.706703 -> V=1.0, theta=0.0
% INFO    : Bus 52590	: V=0.9693263, theta=-53.690954 -> V=1.0, theta=0.0
% INFO    : Bus 52591	: V=0.9818559, theta=-53.154671 -> V=1.0, theta=0.0
% INFO    : Bus 52592	: V=0.9801596, theta=-53.154604 -> V=1.0, theta=0.0
% INFO    : Bus 52593	: V=0.9652962, theta=-53.676017 -> V=1.0, theta=0.0
% INFO    : Bus 52594	: V=0.9786561, theta=-53.09928 -> V=1.0, theta=0.0
% INFO    : Bus 52595	: V=0.9676031, theta=-53.699832 -> V=1.0, theta=0.0
% INFO    : Bus 52596	: V=0.9668449, theta=-53.668586 -> V=1.0, theta=0.0
% INFO    : Bus 52597	: V=0.9665433, theta=-53.62955 -> V=1.0, theta=0.0
% INFO    : Bus 52598	: V=0.9665534, theta=-53.639103 -> V=1.0, theta=0.0
% INFO    : Bus 52599	: V=0.9662207, theta=-53.676919 -> V=1.0, theta=0.0
% INFO    : Bus 52600	: V=0.9666747, theta=-53.679627 -> V=1.0, theta=0.0
% INFO    : Bus 52601	: V=0.9651857, theta=-53.568026 -> V=1.0, theta=0.0
% INFO    : Bus 52602	: V=0.9659941, theta=-53.641357 -> V=1.0, theta=0.0
% INFO    : Bus 52603	: V=0.9670574, theta=-53.519817 -> V=1.0, theta=0.0
% INFO    : Bus 52604	: V=0.980176, theta=-52.493104 -> V=1.0, theta=0.0
% INFO    : Bus 52605	: V=0.9730241, theta=-52.968593 -> V=1.0, theta=0.0
% INFO    : Bus 52606	: V=0.9799092, theta=-52.498202 -> V=1.0, theta=0.0
% INFO    : Bus 52607	: V=0.9806915, theta=-52.474664 -> V=1.0, theta=0.0
% INFO    : Bus 52608	: V=0.9839109, theta=-52.140676 -> V=1.0, theta=0.0
% INFO    : Bus 52609	: V=0.9807149, theta=-52.398969 -> V=1.0, theta=0.0
% INFO    : Bus 52610	: V=0.98862, theta=-51.908811 -> V=1.0, theta=0.0
% INFO    : Bus 52611	: V=1.0006249, theta=-50.671343 -> V=1.0, theta=0.0
% INFO    : Bus 52612	: V=0.9713261, theta=-52.84443 -> V=1.0, theta=0.0
% INFO    : Bus 52613	: V=0.9725332, theta=-52.83122 -> V=1.0, theta=0.0
% INFO    : Bus 52614	: V=0.9822345, theta=-52.175739 -> V=1.0, theta=0.0
% INFO    : Bus 52615	: V=0.9729632, theta=-52.814046 -> V=1.0, theta=0.0
% INFO    : Bus 52616	: V=0.9713884, theta=-52.829803 -> V=1.0, theta=0.0
% INFO    : Bus 52617	: V=0.983224, theta=-51.870056 -> V=1.0, theta=0.0
% INFO    : Bus 52618	: V=0.9712276, theta=-52.85356 -> V=1.0, theta=0.0
% INFO    : Bus 52619	: V=0.9808494, theta=-52.238927 -> V=1.0, theta=0.0
% INFO    : Bus 52620	: V=0.9810581, theta=-52.222145 -> V=1.0, theta=0.0
% INFO    : Bus 52621	: V=0.9814998, theta=-52.209235 -> V=1.0, theta=0.0
% INFO    : Bus 52622	: V=0.9707118, theta=-53.003316 -> V=1.0, theta=0.0
% INFO    : Bus 52623	: V=0.9799896, theta=-52.36382 -> V=1.0, theta=0.0
% INFO    : Bus 52624	: V=0.9732661, theta=-52.874592 -> V=1.0, theta=0.0
% INFO    : Bus 52625	: V=1.0011625, theta=-50.311113 -> V=1.0, theta=0.0
% INFO    : Bus 52626	: V=0.9803606, theta=-52.391408 -> V=1.0, theta=0.0
% INFO    : Bus 52627	: V=0.9801834, theta=-52.382069 -> V=1.0, theta=0.0
% INFO    : Bus 52628	: V=0.9715996, theta=-52.981837 -> V=1.0, theta=0.0
% INFO    : Bus 52629	: V=0.9726423, theta=-52.937336 -> V=1.0, theta=0.0
% INFO    : Bus 52630	: V=0.9719192, theta=-52.803691 -> V=1.0, theta=0.0
% INFO    : Bus 52631	: V=0.9809374, theta=-52.151657 -> V=1.0, theta=0.0
% INFO    : Bus 52632	: V=0.9694139, theta=-52.583049 -> V=1.0, theta=0.0
% INFO    : Bus 52633	: V=0.9803468, theta=-52.261509 -> V=1.0, theta=0.0
% INFO    : Bus 52634	: V=0.9804855, theta=-52.24619 -> V=1.0, theta=0.0
% INFO    : Bus 52635	: V=0.9663664, theta=-52.95817 -> V=1.0, theta=0.0
% INFO    : Bus 52636	: V=0.9676026, theta=-52.92793 -> V=1.0, theta=0.0
% INFO    : Bus 52637	: V=0.9829251, theta=-51.972367 -> V=1.0, theta=0.0
% INFO    : Bus 52638	: V=0.9818856, theta=-52.053427 -> V=1.0, theta=0.0
% INFO    : Bus 52639	: V=0.9702811, theta=-52.409017 -> V=1.0, theta=0.0
% INFO    : Bus 52640	: V=0.9986351, theta=-49.452948 -> V=1.0, theta=0.0
% INFO    : Bus 52641	: V=0.9901719, theta=-50.688476 -> V=1.0, theta=0.0
% INFO    : Bus 52642	: V=0.9903318, theta=-50.968713 -> V=1.0, theta=0.0
% INFO    : Bus 52643	: V=0.9742724, theta=-52.101915 -> V=1.0, theta=0.0
% INFO    : Bus 52644	: V=0.9891366, theta=-51.050215 -> V=1.0, theta=0.0
% INFO    : Bus 52645	: V=0.9895684, theta=-50.775478 -> V=1.0, theta=0.0
% INFO    : Bus 52646	: V=0.9861121, theta=-51.174089 -> V=1.0, theta=0.0
% INFO    : Bus 52647	: V=0.9869085, theta=-51.125653 -> V=1.0, theta=0.0
% INFO    : Bus 52648	: V=0.9780645, theta=-51.752209 -> V=1.0, theta=0.0
% INFO    : Bus 52649	: V=0.9894181, theta=-50.771172 -> V=1.0, theta=0.0
% INFO    : Bus 52650	: V=0.9863512, theta=-51.157616 -> V=1.0, theta=0.0
% INFO    : Bus 52651	: V=0.9649032, theta=-52.473069 -> V=1.0, theta=0.0
% INFO    : Bus 52652	: V=0.9767441, theta=-51.640414 -> V=1.0, theta=0.0
% INFO    : Bus 52653	: V=0.9866422, theta=-51.280378 -> V=1.0, theta=0.0
% INFO    : Bus 52654	: V=0.9779446, theta=-51.758655 -> V=1.0, theta=0.0
% INFO    : Bus 52655	: V=0.9790114, theta=-51.743303 -> V=1.0, theta=0.0
% INFO    : Bus 52656	: V=0.9833292, theta=-51.771713 -> V=1.0, theta=0.0
% INFO    : Bus 52657	: V=0.9860878, theta=-51.514206 -> V=1.0, theta=0.0
% INFO    : Bus 52658	: V=0.987629, theta=-51.081128 -> V=1.0, theta=0.0
% INFO    : Bus 52659	: V=0.9755471, theta=-51.727626 -> V=1.0, theta=0.0
% INFO    : Bus 52660	: V=0.9801755, theta=-51.935856 -> V=1.0, theta=0.0
% INFO    : Bus 52661	: V=0.9824347, theta=-51.609921 -> V=1.0, theta=0.0
% INFO    : Bus 52662	: V=0.9845646, theta=-51.32676 -> V=1.0, theta=0.0
% INFO    : Bus 52663	: V=0.9768052, theta=-51.841017 -> V=1.0, theta=0.0
% INFO    : Bus 52664	: V=0.9744508, theta=-52.69156 -> V=1.0, theta=0.0
% INFO    : Bus 52665	: V=0.9743323, theta=-52.681169 -> V=1.0, theta=0.0
% INFO    : Bus 52666	: V=0.9737137, theta=-52.557357 -> V=1.0, theta=0.0
% INFO    : Bus 52667	: V=0.9759517, theta=-52.587604 -> V=1.0, theta=0.0
% INFO    : Bus 52668	: V=0.9745337, theta=-52.485681 -> V=1.0, theta=0.0
% INFO    : Bus 52669	: V=0.9781367, theta=-52.305047 -> V=1.0, theta=0.0
% INFO    : Bus 52670	: V=0.980556, theta=-52.050241 -> V=1.0, theta=0.0
% INFO    : Bus 52671	: V=0.9865173, theta=-51.32174 -> V=1.0, theta=0.0
% INFO    : Bus 52672	: V=0.9855588, theta=-51.446918 -> V=1.0, theta=0.0
% INFO    : Bus 52673	: V=0.9669183, theta=-53.084546 -> V=1.0, theta=0.0
% INFO    : Bus 52674	: V=0.9664775, theta=-53.08573 -> V=1.0, theta=0.0
% INFO    : Bus 52675	: V=0.9727969, theta=-52.79571 -> V=1.0, theta=0.0
% INFO    : Bus 52676	: V=0.9754607, theta=-52.88341 -> V=1.0, theta=0.0
% INFO    : Bus 52677	: V=0.9671906, theta=-53.091651 -> V=1.0, theta=0.0
% INFO    : Bus 52678	: V=0.968424, theta=-53.076482 -> V=1.0, theta=0.0
% INFO    : Bus 52679	: V=0.9640651, theta=-53.804919 -> V=1.0, theta=0.0
% INFO    : Bus 52680	: V=0.9806745, theta=-52.607247 -> V=1.0, theta=0.0
% INFO    : Bus 52681	: V=0.9988128, theta=-50.950605 -> V=1.0, theta=0.0
% INFO    : Bus 52682	: V=0.9730923, theta=-53.196018 -> V=1.0, theta=0.0
% INFO    : Bus 52683	: V=0.9719778, theta=-53.290457 -> V=1.0, theta=0.0
% INFO    : Bus 52684	: V=0.9640969, theta=-53.928507 -> V=1.0, theta=0.0
% INFO    : Bus 52685	: V=0.9754436, theta=-52.783701 -> V=1.0, theta=0.0
% INFO    : Bus 52686	: V=0.975661, theta=-52.675145 -> V=1.0, theta=0.0
% INFO    : Bus 52687	: V=0.9625985, theta=-54.036889 -> V=1.0, theta=0.0
% INFO    : Bus 52688	: V=0.9641437, theta=-54.037131 -> V=1.0, theta=0.0
% INFO    : Bus 52689	: V=0.9644269, theta=-54.221183 -> V=1.0, theta=0.0
% INFO    : Bus 52690	: V=0.972668, theta=-53.416275 -> V=1.0, theta=0.0
% INFO    : Bus 52691	: V=0.9728192, theta=-53.364888 -> V=1.0, theta=0.0
% INFO    : Bus 52692	: V=0.9758584, theta=-52.970791 -> V=1.0, theta=0.0
% INFO    : Bus 52693	: V=0.9671446, theta=-53.64009 -> V=1.0, theta=0.0
% INFO    : Bus 52694	: V=0.9744138, theta=-53.086093 -> V=1.0, theta=0.0
% INFO    : Bus 52695	: V=0.9739594, theta=-53.17314 -> V=1.0, theta=0.0
% INFO    : Bus 52696	: V=0.9747268, theta=-53.335756 -> V=1.0, theta=0.0
% INFO    : Bus 52697	: V=0.9757328, theta=-53.191534 -> V=1.0, theta=0.0
% INFO    : Bus 52698	: V=0.9765545, theta=-53.701563 -> V=1.0, theta=0.0
% INFO    : Bus 52699	: V=0.9787484, theta=-52.345703 -> V=1.0, theta=0.0
% INFO    : Bus 52700	: V=0.9747267, theta=-52.18566 -> V=1.0, theta=0.0
% INFO    : Bus 52701	: V=0.9707233, theta=-52.325847 -> V=1.0, theta=0.0
% INFO    : Bus 52702	: V=0.9720887, theta=-52.767765 -> V=1.0, theta=0.0
% INFO    : Bus 52703	: V=0.9709779, theta=-52.816805 -> V=1.0, theta=0.0
% INFO    : Bus 52704	: V=1.0007765, theta=-50.42886 -> V=1.0, theta=0.0
% INFO    : Bus 52705	: V=0.9975783, theta=-50.661995 -> V=1.0, theta=0.0
% INFO    : Bus 52706	: V=0.9852003, theta=-51.787539 -> V=1.0, theta=0.0
% INFO    : Bus 52707	: V=0.9907843, theta=-51.299573 -> V=1.0, theta=0.0
% INFO    : Bus 52708	: V=0.972982, theta=-52.429329 -> V=1.0, theta=0.0
% INFO    : Bus 52709	: V=0.9766504, theta=-52.245719 -> V=1.0, theta=0.0
% INFO    : Bus 52710	: V=0.989708, theta=-50.524148 -> V=1.0, theta=0.0
% INFO    : Bus 52711	: V=1.0177124, theta=-48.589948 -> V=1.0, theta=0.0
% INFO    : Bus 52712	: V=1.0035083, theta=-50.256832 -> V=1.0, theta=0.0
% INFO    : Bus 52713	: V=1.0165348, theta=-49.193152 -> V=1.0, theta=0.0
% INFO    : Bus 52714	: V=0.9626, theta=-53.886692 -> V=1.0, theta=0.0
% INFO    : Bus 52715	: V=0.9943281, theta=-50.281771 -> V=1.0, theta=0.0
% INFO    : Bus 52716	: V=1.0198854, theta=-47.997734 -> V=1.0, theta=0.0
% INFO    : Bus 52717	: V=0.9765675, theta=-40.507452 -> V=1.0, theta=0.0
% INFO    : Bus 52718	: V=0.975133, theta=-40.963572 -> V=1.0, theta=0.0
% INFO    : Bus 52719	: V=0.9744311, theta=-41.309481 -> V=1.0, theta=0.0
% INFO    : Bus 52720	: V=0.9609139, theta=-43.116519 -> V=1.0, theta=0.0
% INFO    : Bus 52721	: V=0.973568, theta=-41.12606 -> V=1.0, theta=0.0
% INFO    : Bus 52722	: V=0.9824124, theta=-40.136865 -> V=1.0, theta=0.0
% INFO    : Bus 52723	: V=0.9833364, theta=-38.876803 -> V=1.0, theta=0.0
% INFO    : Bus 52724	: V=0.9556259, theta=-43.497297 -> V=1.0, theta=0.0
% INFO    : Bus 52725	: V=0.9695398, theta=-43.463974 -> V=1.0, theta=0.0
% INFO    : Bus 52726	: V=0.9687274, theta=-44.055409 -> V=1.0, theta=0.0
% INFO    : Bus 52727	: V=0.9719303, theta=-39.796249 -> V=1.0, theta=0.0
% INFO    : Bus 52728	: V=0.9748587, theta=-39.063507 -> V=1.0, theta=0.0
% INFO    : Bus 52729	: V=0.9950845, theta=-40.264687 -> V=1.0, theta=0.0
% INFO    : Bus 52730	: V=0.9739123, theta=-37.387999 -> V=1.0, theta=0.0
% INFO    : Bus 52731	: V=0.9742273, theta=-38.244721 -> V=1.0, theta=0.0
% INFO    : Bus 52732	: V=0.9802994, theta=-38.579847 -> V=1.0, theta=0.0
% INFO    : Bus 52733	: V=0.9684406, theta=-41.737223 -> V=1.0, theta=0.0
% INFO    : Bus 52734	: V=0.9781106, theta=-37.886005 -> V=1.0, theta=0.0
% INFO    : Bus 52735	: V=0.9675892, theta=-37.603249 -> V=1.0, theta=0.0
% INFO    : Bus 52736	: V=0.9816577, theta=-36.981814 -> V=1.0, theta=0.0
% INFO    : Bus 52737	: V=0.9627238, theta=-41.30056 -> V=1.0, theta=0.0
% INFO    : Bus 52738	: V=0.9782038, theta=-28.312983 -> V=1.0, theta=0.0
% INFO    : Bus 52739	: V=0.9644257, theta=-29.926832 -> V=1.0, theta=0.0
% INFO    : Bus 52740	: V=0.9646511, theta=-30.106581 -> V=1.0, theta=0.0
% INFO    : Bus 52741	: V=0.9728727, theta=-29.304987 -> V=1.0, theta=0.0
% INFO    : Bus 52742	: V=0.9726701, theta=-29.375027 -> V=1.0, theta=0.0
% INFO    : Bus 52743	: V=0.9677154, theta=-29.70279 -> V=1.0, theta=0.0
% INFO    : Bus 52744	: V=0.9724863, theta=-29.639731 -> V=1.0, theta=0.0
% INFO    : Bus 52745	: V=0.9740066, theta=-30.3233 -> V=1.0, theta=0.0
% INFO    : Bus 52746	: V=0.9645655, theta=-30.16652 -> V=1.0, theta=0.0
% INFO    : Bus 52747	: V=0.9720634, theta=-40.88776 -> V=1.0, theta=0.0
% INFO    : Bus 52748	: V=0.9836484, theta=-39.81828 -> V=1.0, theta=0.0
% INFO    : Bus 52749	: V=0.9740721, theta=-41.505622 -> V=1.0, theta=0.0
% INFO    : Bus 52750	: V=0.9789919, theta=-41.483238 -> V=1.0, theta=0.0
% INFO    : Bus 52751	: V=0.9853893, theta=-42.05486 -> V=1.0, theta=0.0
% INFO    : Bus 52752	: V=1.0089249, theta=-44.269783 -> V=1.0, theta=0.0
% INFO    : Bus 52753	: V=0.9963184, theta=-45.422218 -> V=1.0, theta=0.0
% INFO    : Bus 52754	: V=1.0030547, theta=-45.676948 -> V=1.0, theta=0.0
% INFO    : Bus 52755	: V=0.9858156, theta=-46.050669 -> V=1.0, theta=0.0
% INFO    : Bus 52756	: V=1.0077637, theta=-44.7617 -> V=1.0, theta=0.0
% INFO    : Bus 52757	: V=0.9958242, theta=-45.453695 -> V=1.0, theta=0.0
% INFO    : Bus 52758	: V=0.9856842, theta=-46.122611 -> V=1.0, theta=0.0
% INFO    : Bus 52759	: V=0.9825078, theta=-46.147887 -> V=1.0, theta=0.0
% INFO    : Bus 52760	: V=0.9838039, theta=-46.125974 -> V=1.0, theta=0.0
% INFO    : Bus 52761	: V=1.0075735, theta=-45.063029 -> V=1.0, theta=0.0
% INFO    : Bus 52762	: V=1.0074728, theta=-45.629213 -> V=1.0, theta=0.0
% INFO    : Bus 52763	: V=0.983445, theta=-45.897018 -> V=1.0, theta=0.0
% INFO    : Bus 52764	: V=0.98828, theta=-45.746399 -> V=1.0, theta=0.0
% INFO    : Bus 52765	: V=0.9766969, theta=-43.207444 -> V=1.0, theta=0.0
% INFO    : Bus 52766	: V=0.9779557, theta=-44.181507 -> V=1.0, theta=0.0
% INFO    : Bus 52767	: V=0.9809881, theta=-44.698797 -> V=1.0, theta=0.0
% INFO    : Bus 52768	: V=0.9851749, theta=-45.420678 -> V=1.0, theta=0.0
% INFO    : Bus 52769	: V=0.9834498, theta=-41.683112 -> V=1.0, theta=0.0
% INFO    : Bus 52770	: V=0.9821189, theta=-42.364372 -> V=1.0, theta=0.0
% INFO    : Bus 52771	: V=0.9617707, theta=-44.550917 -> V=1.0, theta=0.0
% INFO    : Bus 52772	: V=0.9814339, theta=-45.905993 -> V=1.0, theta=0.0
% INFO    : Bus 52773	: V=0.9770874, theta=-44.427458 -> V=1.0, theta=0.0
% INFO    : Bus 52774	: V=0.9770447, theta=-44.795324 -> V=1.0, theta=0.0
% INFO    : Bus 52775	: V=0.9627572, theta=-45.800582 -> V=1.0, theta=0.0
% INFO    : Bus 52776	: V=0.962928, theta=-45.939841 -> V=1.0, theta=0.0
% INFO    : Bus 52777	: V=0.9805945, theta=-45.119368 -> V=1.0, theta=0.0
% INFO    : Bus 52778	: V=0.9619971, theta=-46.117928 -> V=1.0, theta=0.0
% INFO    : Bus 52779	: V=1.0142717, theta=-44.751015 -> V=1.0, theta=0.0
% INFO    : Bus 52780	: V=0.9879104, theta=-45.999672 -> V=1.0, theta=0.0
% INFO    : Bus 52781	: V=1.0094076, theta=-46.691284 -> V=1.0, theta=0.0
% INFO    : Bus 52782	: V=0.9794894, theta=-51.946776 -> V=1.0, theta=0.0
% INFO    : Bus 52783	: V=0.9577655, theta=-53.328669 -> V=1.0, theta=0.0
% INFO    : Bus 52784	: V=0.9734603, theta=-52.572 -> V=1.0, theta=0.0
% INFO    : Bus 52785	: V=0.9640967, theta=-54.386462 -> V=1.0, theta=0.0
% INFO    : Bus 52786	: V=0.960934, theta=-54.633118 -> V=1.0, theta=0.0
% INFO    : Bus 52787	: V=0.9870821, theta=-53.286246 -> V=1.0, theta=0.0
% INFO    : Bus 52788	: V=0.9662813, theta=-54.335368 -> V=1.0, theta=0.0
% INFO    : Bus 52789	: V=0.9619513, theta=-54.563681 -> V=1.0, theta=0.0
% INFO    : Bus 52790	: V=1.0005684, theta=-53.646003 -> V=1.0, theta=0.0
% INFO    : Bus 52791	: V=0.9493146, theta=-53.710683 -> V=1.0, theta=0.0
% INFO    : Bus 52792	: V=0.9944739, theta=-50.842682 -> V=1.0, theta=0.0
% INFO    : Bus 52793	: V=0.9885843, theta=-51.464913 -> V=1.0, theta=0.0
% INFO    : Bus 52794	: V=0.9894005, theta=-51.479376 -> V=1.0, theta=0.0
% INFO    : Bus 52795	: V=0.9869759, theta=-51.453895 -> V=1.0, theta=0.0
% INFO    : Bus 52796	: V=1.0100656, theta=-50.288986 -> V=1.0, theta=0.0
% INFO    : Bus 52797	: V=0.9946232, theta=-50.584216 -> V=1.0, theta=0.0
% INFO    : Bus 52798	: V=0.9866146, theta=-51.463692 -> V=1.0, theta=0.0
% INFO    : Bus 52799	: V=0.9934194, theta=-50.519334 -> V=1.0, theta=0.0
% INFO    : Bus 52800	: V=0.9901546, theta=-50.218473 -> V=1.0, theta=0.0
% INFO    : Bus 52801	: V=1.0102458, theta=-49.696962 -> V=1.0, theta=0.0
% INFO    : Bus 52802	: V=0.9690442, theta=-51.373189 -> V=1.0, theta=0.0
% INFO    : Bus 52803	: V=0.9759403, theta=-51.163295 -> V=1.0, theta=0.0
% INFO    : Bus 52804	: V=1.0116579, theta=-50.64245 -> V=1.0, theta=0.0
% INFO    : Bus 52805	: V=0.9899226, theta=-51.65082 -> V=1.0, theta=0.0
% INFO    : Bus 52806	: V=1.0162516, theta=-51.347778 -> V=1.0, theta=0.0
% INFO    : Bus 52807	: V=0.9928119, theta=-53.113879 -> V=1.0, theta=0.0
% INFO    : Bus 52808	: V=0.9926543, theta=-44.92838 -> V=1.0, theta=0.0
% INFO    : Bus 52809	: V=1.0041793, theta=-49.422361 -> V=1.0, theta=0.0
% INFO    : Bus 52810	: V=1.0008161, theta=-46.565611 -> V=1.0, theta=0.0
% INFO    : Bus 52811	: V=0.9778048, theta=-57.536794 -> V=1.0, theta=0.0
% INFO    : Bus 52812	: V=0.9998448, theta=-34.516037 -> V=1.0, theta=0.0
% INFO    : Bus 52813	: V=0.9981962, theta=-34.47715 -> V=1.0, theta=0.0
% INFO    : Bus 52814	: V=0.9987968, theta=-34.495346 -> V=1.0, theta=0.0
% INFO    : Bus 52815	: V=0.9869325, theta=-35.230073 -> V=1.0, theta=0.0
% INFO    : Bus 52816	: V=0.9955886, theta=-34.297445 -> V=1.0, theta=0.0
% INFO    : Bus 52817	: V=0.9973436, theta=-34.385843 -> V=1.0, theta=0.0
% INFO    : Bus 52818	: V=0.9969896, theta=-34.328691 -> V=1.0, theta=0.0
% INFO    : Bus 52819	: V=0.9981866, theta=-34.09347 -> V=1.0, theta=0.0
% INFO    : Bus 52820	: V=0.9888888, theta=-34.615892 -> V=1.0, theta=0.0
% INFO    : Bus 52821	: V=0.9881093, theta=-34.6633 -> V=1.0, theta=0.0
% INFO    : Bus 52822	: V=0.9873273, theta=-35.221418 -> V=1.0, theta=0.0
% INFO    : Bus 52823	: V=1.0121442, theta=-33.973893 -> V=1.0, theta=0.0
% INFO    : Bus 52824	: V=0.9902987, theta=-36.264658 -> V=1.0, theta=0.0
% INFO    : Bus 52825	: V=0.9986711, theta=-35.135966 -> V=1.0, theta=0.0
% INFO    : Bus 52826	: V=0.9630135, theta=-38.158164 -> V=1.0, theta=0.0
% INFO    : Bus 52827	: V=0.9999126, theta=-34.960458 -> V=1.0, theta=0.0
% INFO    : Bus 52828	: V=1.0023788, theta=-34.487839 -> V=1.0, theta=0.0
% INFO    : Bus 52829	: V=0.992852, theta=-35.683168 -> V=1.0, theta=0.0
% INFO    : Bus 52830	: V=1.0134655, theta=-32.740903 -> V=1.0, theta=0.0
% INFO    : Bus 52831	: V=0.9944871, theta=-33.790882 -> V=1.0, theta=0.0
% INFO    : Bus 52832	: V=1.0075349, theta=-33.930862 -> V=1.0, theta=0.0
% INFO    : Bus 52833	: V=1.0042116, theta=-34.289934 -> V=1.0, theta=0.0
% INFO    : Bus 52834	: V=1.0090632, theta=-33.621641 -> V=1.0, theta=0.0
% INFO    : Bus 52835	: V=0.9980991, theta=-34.009732 -> V=1.0, theta=0.0
% INFO    : Bus 52836	: V=0.9922889, theta=-33.070239 -> V=1.0, theta=0.0
% INFO    : Bus 52837	: V=0.9925211, theta=-33.193318 -> V=1.0, theta=0.0
% INFO    : Bus 52838	: V=1.0170127, theta=-33.786666 -> V=1.0, theta=0.0
% INFO    : Bus 52839	: V=0.9981489, theta=-34.745474 -> V=1.0, theta=0.0
% INFO    : Bus 52840	: V=0.9682073, theta=-48.568857 -> V=1.0, theta=0.0
% INFO    : Bus 52841	: V=0.9696483, theta=-49.769826 -> V=1.0, theta=0.0
% INFO    : Bus 52842	: V=0.9640033, theta=-51.814422 -> V=1.0, theta=0.0
% INFO    : Bus 52843	: V=0.9723367, theta=-50.494175 -> V=1.0, theta=0.0
% INFO    : Bus 52844	: V=0.9741309, theta=-50.76506 -> V=1.0, theta=0.0
% INFO    : Bus 52845	: V=0.9738199, theta=-49.855175 -> V=1.0, theta=0.0
% INFO    : Bus 52846	: V=0.9807156, theta=-51.286765 -> V=1.0, theta=0.0
% INFO    : Bus 52847	: V=0.9943525, theta=-52.013015 -> V=1.0, theta=0.0
% INFO    : Bus 52848	: V=0.9846957, theta=-50.813993 -> V=1.0, theta=0.0
% INFO    : Bus 52849	: V=0.9700401, theta=-39.734692 -> V=1.0, theta=0.0
% INFO    : Bus 52850	: V=0.9830041, theta=-37.625966 -> V=1.0, theta=0.0
% INFO    : Bus 52851	: V=0.984175, theta=-37.362031 -> V=1.0, theta=0.0
% INFO    : Bus 52852	: V=1.0031545, theta=-37.24212 -> V=1.0, theta=0.0
% INFO    : Bus 52853	: V=1.0016472, theta=-37.459668 -> V=1.0, theta=0.0
% INFO    : Bus 52854	: V=1.0001229, theta=-37.769664 -> V=1.0, theta=0.0
% INFO    : Bus 52855	: V=1.0002707, theta=-37.829314 -> V=1.0, theta=0.0
% INFO    : Bus 52856	: V=0.9963749, theta=-38.333048 -> V=1.0, theta=0.0
% INFO    : Bus 52857	: V=0.988231, theta=-37.944354 -> V=1.0, theta=0.0
% INFO    : Bus 52858	: V=0.9840382, theta=-65.562778 -> V=1.0, theta=0.0
% INFO    : Bus 52859	: V=0.9718809, theta=-66.598017 -> V=1.0, theta=0.0
% INFO    : Bus 52860	: V=0.9683862, theta=-66.882428 -> V=1.0, theta=0.0
% INFO    : Bus 52861	: V=0.9725598, theta=-66.503447 -> V=1.0, theta=0.0
% INFO    : Bus 52862	: V=0.9696242, theta=-66.794636 -> V=1.0, theta=0.0
% INFO    : Bus 52863	: V=0.9816746, theta=-65.725467 -> V=1.0, theta=0.0
% INFO    : Bus 52864	: V=0.9880338, theta=-65.14158 -> V=1.0, theta=0.0
% INFO    : Bus 52865	: V=0.9725048, theta=-66.992285 -> V=1.0, theta=0.0
% INFO    : Bus 52866	: V=0.952445, theta=-65.49544 -> V=1.0, theta=0.0
% INFO    : Bus 52867	: V=0.9749702, theta=-65.864237 -> V=1.0, theta=0.0
% INFO    : Bus 52868	: V=0.965101, theta=-67.025062 -> V=1.0, theta=0.0
% INFO    : Bus 52869	: V=0.9790453, theta=-57.593968 -> V=1.0, theta=0.0
% INFO    : Bus 52870	: V=0.9730522, theta=-58.274745 -> V=1.0, theta=0.0
% INFO    : Bus 52871	: V=0.9783212, theta=-58.075169 -> V=1.0, theta=0.0
% INFO    : Bus 52872	: V=0.9922596, theta=-56.893574 -> V=1.0, theta=0.0
% INFO    : Bus 52873	: V=1.0266466, theta=-57.381031 -> V=1.0, theta=0.0
% INFO    : Bus 52874	: V=0.9899753, theta=-61.946662 -> V=1.0, theta=0.0
% INFO    : Bus 52875	: V=0.9943419, theta=-60.727118 -> V=1.0, theta=0.0
% INFO    : Bus 52876	: V=0.9922175, theta=-61.360019 -> V=1.0, theta=0.0
% INFO    : Bus 52877	: V=0.9918129, theta=-61.592464 -> V=1.0, theta=0.0
% INFO    : Bus 52878	: V=0.9883738, theta=-62.206434 -> V=1.0, theta=0.0
% INFO    : Bus 52879	: V=0.9816381, theta=-38.047009 -> V=1.0, theta=0.0
% INFO    : Bus 52880	: V=0.9809703, theta=-38.047592 -> V=1.0, theta=0.0
% INFO    : Bus 52881	: V=0.9718235, theta=-38.911035 -> V=1.0, theta=0.0
% INFO    : Bus 52882	: V=0.9802544, theta=-38.199766 -> V=1.0, theta=0.0
% INFO    : Bus 52883	: V=0.9801111, theta=-38.324221 -> V=1.0, theta=0.0
% INFO    : Bus 52884	: V=0.9800748, theta=-38.395535 -> V=1.0, theta=0.0
% INFO    : Bus 52885	: V=0.9800688, theta=-38.441615 -> V=1.0, theta=0.0
% INFO    : Bus 52886	: V=0.9801115, theta=-38.482189 -> V=1.0, theta=0.0
% INFO    : Bus 52887	: V=0.980684, theta=-38.642848 -> V=1.0, theta=0.0
% INFO    : Bus 52888	: V=0.9759513, theta=-38.928346 -> V=1.0, theta=0.0
% INFO    : Bus 52889	: V=0.9811483, theta=-38.576785 -> V=1.0, theta=0.0
% INFO    : Bus 52890	: V=0.9764689, theta=-38.768713 -> V=1.0, theta=0.0
% INFO    : Bus 52891	: V=0.9805698, theta=-38.449164 -> V=1.0, theta=0.0
% INFO    : Bus 52892	: V=0.9709194, theta=-39.008674 -> V=1.0, theta=0.0
% INFO    : Bus 52893	: V=0.9812729, theta=-38.062172 -> V=1.0, theta=0.0
% INFO    : Bus 52894	: V=0.9693536, theta=-39.052787 -> V=1.0, theta=0.0
% INFO    : Bus 52895	: V=0.9703738, theta=-39.031931 -> V=1.0, theta=0.0
% INFO    : Bus 52896	: V=0.9712919, theta=-39.008905 -> V=1.0, theta=0.0
% INFO    : Bus 52897	: V=0.9730665, theta=-38.948541 -> V=1.0, theta=0.0
% INFO    : Bus 52898	: V=0.9816692, theta=-38.549763 -> V=1.0, theta=0.0
% INFO    : Bus 52899	: V=0.9818193, theta=-38.590732 -> V=1.0, theta=0.0
% INFO    : Bus 52900	: V=0.9820534, theta=-38.753333 -> V=1.0, theta=0.0
% INFO    : Bus 52901	: V=0.9807277, theta=-38.699381 -> V=1.0, theta=0.0
% INFO    : Bus 52902	: V=0.9745321, theta=-39.31216 -> V=1.0, theta=0.0
% INFO    : Bus 52903	: V=0.9736785, theta=-39.336789 -> V=1.0, theta=0.0
% INFO    : Bus 52904	: V=0.9832682, theta=-38.755075 -> V=1.0, theta=0.0
% INFO    : Bus 52905	: V=0.9769045, theta=-38.998156 -> V=1.0, theta=0.0
% INFO    : Bus 52906	: V=0.9827769, theta=-38.562915 -> V=1.0, theta=0.0
% INFO    : Bus 52907	: V=0.9825934, theta=-38.571038 -> V=1.0, theta=0.0
% INFO    : Bus 52908	: V=0.9818384, theta=-38.544075 -> V=1.0, theta=0.0
% INFO    : Bus 52909	: V=0.981999, theta=-38.546226 -> V=1.0, theta=0.0
% INFO    : Bus 52910	: V=0.9736505, theta=-38.946135 -> V=1.0, theta=0.0
% INFO    : Bus 52911	: V=0.9828607, theta=-38.047302 -> V=1.0, theta=0.0
% INFO    : Bus 52912	: V=0.9739026, theta=-38.900552 -> V=1.0, theta=0.0
% INFO    : Bus 52913	: V=0.9842028, theta=-38.005276 -> V=1.0, theta=0.0
% INFO    : Bus 52914	: V=0.9840281, theta=-38.034626 -> V=1.0, theta=0.0
% INFO    : Bus 52915	: V=0.982613, theta=-38.542916 -> V=1.0, theta=0.0
% INFO    : Bus 52916	: V=0.9839885, theta=-38.545621 -> V=1.0, theta=0.0
% INFO    : Bus 52917	: V=0.9851936, theta=-38.502911 -> V=1.0, theta=0.0
% INFO    : Bus 52918	: V=0.9858911, theta=-38.532365 -> V=1.0, theta=0.0
% INFO    : Bus 52919	: V=0.9853708, theta=-38.549083 -> V=1.0, theta=0.0
% INFO    : Bus 52920	: V=0.9842862, theta=-38.750218 -> V=1.0, theta=0.0
% INFO    : Bus 52921	: V=0.9854244, theta=-38.80643 -> V=1.0, theta=0.0
% INFO    : Bus 52922	: V=0.986343, theta=-38.76248 -> V=1.0, theta=0.0
% INFO    : Bus 52923	: V=1.0072697, theta=-37.6614 -> V=1.0, theta=0.0
% INFO    : Bus 52924	: V=0.9861188, theta=-38.659373 -> V=1.0, theta=0.0
% INFO    : Bus 52925	: V=0.9862706, theta=-38.532255 -> V=1.0, theta=0.0
% INFO    : Bus 52926	: V=0.9862073, theta=-38.292259 -> V=1.0, theta=0.0
% INFO    : Bus 52927	: V=0.9857335, theta=-38.144099 -> V=1.0, theta=0.0
% INFO    : Bus 52928	: V=0.983802, theta=-37.996024 -> V=1.0, theta=0.0
% INFO    : Bus 52929	: V=0.967684, theta=-37.014367 -> V=1.0, theta=0.0
% INFO    : Bus 52930	: V=0.9908027, theta=-35.756398 -> V=1.0, theta=0.0
% INFO    : Bus 52931	: V=0.9842954, theta=-36.594742 -> V=1.0, theta=0.0
% INFO    : Bus 52932	: V=0.9759432, theta=-37.406381 -> V=1.0, theta=0.0
% INFO    : Bus 52933	: V=0.9816654, theta=-37.888832 -> V=1.0, theta=0.0
% INFO    : Bus 52934	: V=0.9737429, theta=-37.627052 -> V=1.0, theta=0.0
% INFO    : Bus 52935	: V=0.9855432, theta=-36.802297 -> V=1.0, theta=0.0
% INFO    : Bus 52936	: V=0.9864385, theta=-36.694646 -> V=1.0, theta=0.0
% INFO    : Bus 52937	: V=0.9871788, theta=-36.626151 -> V=1.0, theta=0.0
% INFO    : Bus 52938	: V=0.9847816, theta=-37.016921 -> V=1.0, theta=0.0
% INFO    : Bus 52939	: V=0.9983448, theta=-35.406049 -> V=1.0, theta=0.0
% INFO    : Bus 52940	: V=0.9671789, theta=-39.100933 -> V=1.0, theta=0.0
% INFO    : Bus 52941	: V=0.9803503, theta=-38.279049 -> V=1.0, theta=0.0
% INFO    : Bus 52942	: V=0.9767139, theta=-39.525092 -> V=1.0, theta=0.0
% INFO    : Bus 52943	: V=0.9842021, theta=-39.1155 -> V=1.0, theta=0.0
% INFO    : Bus 52944	: V=1.0152545, theta=-35.92453 -> V=1.0, theta=0.0
% INFO    : Bus 52945	: V=1.008462, theta=-37.433619 -> V=1.0, theta=0.0
% INFO    : Bus 52946	: V=0.9993882, theta=-37.932566 -> V=1.0, theta=0.0
% INFO    : Bus 52947	: V=1.0109393, theta=-37.147881 -> V=1.0, theta=0.0
% INFO    : Bus 52948	: V=1.0182842, theta=-37.019368 -> V=1.0, theta=0.0
% INFO    : Bus 52949	: V=1.0058307, theta=-37.53504 -> V=1.0, theta=0.0
% INFO    : Bus 52950	: V=0.9794421, theta=-38.877959 -> V=1.0, theta=0.0
% INFO    : Bus 52951	: V=0.9879154, theta=-38.401734 -> V=1.0, theta=0.0
% INFO    : Bus 52952	: V=0.9800332, theta=-38.871984 -> V=1.0, theta=0.0
% INFO    : Bus 52953	: V=0.9804956, theta=-38.45395 -> V=1.0, theta=0.0
% INFO    : Bus 52954	: V=0.9830783, theta=-38.275191 -> V=1.0, theta=0.0
% INFO    : Bus 52955	: V=0.9827651, theta=-38.222457 -> V=1.0, theta=0.0
% INFO    : Bus 52956	: V=1.0032086, theta=-35.984998 -> V=1.0, theta=0.0
% INFO    : Bus 52957	: V=0.9814322, theta=-38.228434 -> V=1.0, theta=0.0
% INFO    : Bus 52958	: V=0.9818818, theta=-38.218374 -> V=1.0, theta=0.0
% INFO    : Bus 52959	: V=0.9849775, theta=-37.936798 -> V=1.0, theta=0.0
% INFO    : Bus 52960	: V=0.963612, theta=-39.265124 -> V=1.0, theta=0.0
% INFO    : Bus 52961	: V=0.9718164, theta=-38.724171 -> V=1.0, theta=0.0
% INFO    : Bus 52962	: V=0.966427, theta=-39.12636 -> V=1.0, theta=0.0
% INFO    : Bus 52963	: V=0.9710766, theta=-38.761241 -> V=1.0, theta=0.0
% INFO    : Bus 52964	: V=0.9659355, theta=-38.775076 -> V=1.0, theta=0.0
% INFO    : Bus 52965	: V=0.9673969, theta=-38.720086 -> V=1.0, theta=0.0
% INFO    : Bus 52966	: V=0.9822518, theta=-37.805319 -> V=1.0, theta=0.0
% INFO    : Bus 52967	: V=0.9839716, theta=-37.644288 -> V=1.0, theta=0.0
% INFO    : Bus 52968	: V=0.9691321, theta=-38.615936 -> V=1.0, theta=0.0
% INFO    : Bus 52969	: V=0.9846011, theta=-37.504649 -> V=1.0, theta=0.0
% INFO    : Bus 52970	: V=0.9862387, theta=-37.509945 -> V=1.0, theta=0.0
% INFO    : Bus 52971	: V=1.0120104, theta=-35.97792 -> V=1.0, theta=0.0
% INFO    : Bus 52972	: V=1.0074463, theta=-36.235585 -> V=1.0, theta=0.0
% INFO    : Bus 52973	: V=1.0132839, theta=-35.593269 -> V=1.0, theta=0.0
% INFO    : Bus 52974	: V=0.9919199, theta=-37.260003 -> V=1.0, theta=0.0
% INFO    : Bus 52975	: V=0.9837375, theta=-38.145197 -> V=1.0, theta=0.0
% INFO    : Bus 52976	: V=0.9938005, theta=-37.417761 -> V=1.0, theta=0.0
% INFO    : Bus 52977	: V=0.9872054, theta=-37.887213 -> V=1.0, theta=0.0
% INFO    : Bus 52978	: V=1.0035234, theta=-36.565064 -> V=1.0, theta=0.0
% INFO    : Bus 52979	: V=1.0116509, theta=-35.710739 -> V=1.0, theta=0.0
% INFO    : Bus 52980	: V=0.9988136, theta=-36.953443 -> V=1.0, theta=0.0
% INFO    : Bus 52981	: V=0.9996748, theta=-36.821774 -> V=1.0, theta=0.0
% INFO    : Bus 52982	: V=1.0012636, theta=-36.661863 -> V=1.0, theta=0.0
% INFO    : Bus 52983	: V=0.9921249, theta=-37.313601 -> V=1.0, theta=0.0
% INFO    : Bus 52984	: V=0.9908837, theta=-37.523976 -> V=1.0, theta=0.0
% INFO    : Bus 52985	: V=0.9982313, theta=-36.974121 -> V=1.0, theta=0.0
% INFO    : Bus 52986	: V=0.9966198, theta=-36.930037 -> V=1.0, theta=0.0
% INFO    : Bus 52987	: V=0.9928424, theta=-37.258222 -> V=1.0, theta=0.0
% INFO    : Bus 52988	: V=0.9996178, theta=-37.140605 -> V=1.0, theta=0.0
% INFO    : Bus 52989	: V=1.0013899, theta=-36.779163 -> V=1.0, theta=0.0
% INFO    : Bus 52990	: V=0.9930391, theta=-37.295793 -> V=1.0, theta=0.0
% INFO    : Bus 52991	: V=0.9955071, theta=-37.235234 -> V=1.0, theta=0.0
% INFO    : Bus 52992	: V=0.9967362, theta=-37.110099 -> V=1.0, theta=0.0
% INFO    : Bus 52993	: V=0.9991823, theta=-37.304339 -> V=1.0, theta=0.0
% INFO    : Bus 52994	: V=0.9923998, theta=-37.142611 -> V=1.0, theta=0.0
% INFO    : Bus 52995	: V=0.9934682, theta=-37.147498 -> V=1.0, theta=0.0
% INFO    : Bus 52996	: V=0.9955211, theta=-37.451835 -> V=1.0, theta=0.0
% INFO    : Bus 52997	: V=0.9756308, theta=-39.137007 -> V=1.0, theta=0.0
% INFO    : Bus 52998	: V=0.9893148, theta=-38.344795 -> V=1.0, theta=0.0
% INFO    : Bus 52999	: V=0.9892155, theta=-38.282338 -> V=1.0, theta=0.0
% INFO    : Bus 53000	: V=0.9909474, theta=-38.247812 -> V=1.0, theta=0.0
% INFO    : Bus 53001	: V=0.9818969, theta=-38.405043 -> V=1.0, theta=0.0
% INFO    : Bus 53002	: V=0.9840072, theta=-38.328381 -> V=1.0, theta=0.0
% INFO    : Bus 53003	: V=0.9909461, theta=-38.129136 -> V=1.0, theta=0.0
% INFO    : Bus 53004	: V=0.9825561, theta=-38.271744 -> V=1.0, theta=0.0
% INFO    : Bus 53005	: V=0.9831592, theta=-38.205066 -> V=1.0, theta=0.0
% INFO    : Bus 53006	: V=0.9930641, theta=-37.455339 -> V=1.0, theta=0.0
% INFO    : Bus 53007	: V=0.9832924, theta=-38.280815 -> V=1.0, theta=0.0
% INFO    : Bus 53008	: V=0.992608, theta=-38.044467 -> V=1.0, theta=0.0
% INFO    : Bus 53009	: V=0.9948048, theta=-37.505785 -> V=1.0, theta=0.0
% INFO    : Bus 53010	: V=0.9932552, theta=-38.184896 -> V=1.0, theta=0.0
% INFO    : Bus 53011	: V=0.9825889, theta=-38.334825 -> V=1.0, theta=0.0
% INFO    : Bus 53012	: V=0.9975137, theta=-37.470383 -> V=1.0, theta=0.0
% INFO    : Bus 53013	: V=0.9864201, theta=-38.238317 -> V=1.0, theta=0.0
% INFO    : Bus 53014	: V=0.9948321, theta=-37.9517 -> V=1.0, theta=0.0
% INFO    : Bus 53015	: V=0.997031, theta=-37.864763 -> V=1.0, theta=0.0
% INFO    : Bus 53016	: V=0.9906371, theta=-38.073708 -> V=1.0, theta=0.0
% INFO    : Bus 53017	: V=0.9993585, theta=-37.405522 -> V=1.0, theta=0.0
% INFO    : Bus 53018	: V=1.0008505, theta=-37.446832 -> V=1.0, theta=0.0
% INFO    : Bus 53019	: V=1.0000162, theta=-37.571394 -> V=1.0, theta=0.0
% INFO    : Bus 53020	: V=1.0007955, theta=-37.720253 -> V=1.0, theta=0.0
% INFO    : Bus 53021	: V=0.9819148, theta=-38.334601 -> V=1.0, theta=0.0
% INFO    : Bus 53022	: V=0.9833067, theta=-38.781287 -> V=1.0, theta=0.0
% INFO    : Bus 53023	: V=0.982877, theta=-38.780645 -> V=1.0, theta=0.0
% INFO    : Bus 53024	: V=0.9939076, theta=-38.238898 -> V=1.0, theta=0.0
% INFO    : Bus 53025	: V=0.9935684, theta=-38.97312 -> V=1.0, theta=0.0
% INFO    : Bus 53026	: V=0.9916069, theta=-37.303849 -> V=1.0, theta=0.0
% INFO    : Bus 53027	: V=0.989547, theta=-38.237525 -> V=1.0, theta=0.0
% INFO    : Bus 53028	: V=0.9802699, theta=-37.970496 -> V=1.0, theta=0.0
% INFO    : Bus 53029	: V=0.9813081, theta=-37.960323 -> V=1.0, theta=0.0
% INFO    : Bus 53030	: V=0.9801273, theta=-38.136994 -> V=1.0, theta=0.0
% INFO    : Bus 53031	: V=0.9669262, theta=-39.08317 -> V=1.0, theta=0.0
% INFO    : Bus 53032	: V=0.9677508, theta=-39.039684 -> V=1.0, theta=0.0
% INFO    : Bus 53033	: V=0.9847206, theta=-37.862452 -> V=1.0, theta=0.0
% INFO    : Bus 53034	: V=0.9847953, theta=-37.808008 -> V=1.0, theta=0.0
% INFO    : Bus 53035	: V=0.9849594, theta=-37.844949 -> V=1.0, theta=0.0
% INFO    : Bus 53036	: V=0.9855571, theta=-37.981739 -> V=1.0, theta=0.0
% INFO    : Bus 53037	: V=0.9874907, theta=-38.295611 -> V=1.0, theta=0.0
% INFO    : Bus 53038	: V=0.9754903, theta=-39.298671 -> V=1.0, theta=0.0
% INFO    : Bus 53039	: V=0.9693656, theta=-38.927863 -> V=1.0, theta=0.0
% INFO    : Bus 53040	: V=1.0106748, theta=-35.729798 -> V=1.0, theta=0.0
% INFO    : Bus 53041	: V=0.9856834, theta=-37.716874 -> V=1.0, theta=0.0
% INFO    : Bus 53042	: V=0.9683858, theta=-38.704757 -> V=1.0, theta=0.0
% INFO    : Bus 53043	: V=0.9859918, theta=-37.528649 -> V=1.0, theta=0.0
% INFO    : Bus 53044	: V=0.9867512, theta=-37.633743 -> V=1.0, theta=0.0
% INFO    : Bus 53045	: V=0.9857325, theta=-37.681599 -> V=1.0, theta=0.0
% INFO    : Bus 53046	: V=0.9812362, theta=-37.599995 -> V=1.0, theta=0.0
% INFO    : Bus 53047	: V=0.9826835, theta=-37.579337 -> V=1.0, theta=0.0
% INFO    : Bus 53048	: V=0.9981197, theta=-38.529282 -> V=1.0, theta=0.0
% INFO    : Bus 53049	: V=0.9793704, theta=-39.818302 -> V=1.0, theta=0.0
% INFO    : Bus 53050	: V=0.9841238, theta=-39.306258 -> V=1.0, theta=0.0
% INFO    : Bus 53051	: V=0.9846012, theta=-39.29732 -> V=1.0, theta=0.0
% INFO    : Bus 53052	: V=0.9827178, theta=-39.654125 -> V=1.0, theta=0.0
% INFO    : Bus 53053	: V=0.9981115, theta=-35.783478 -> V=1.0, theta=0.0
% INFO    : Bus 53054	: V=1.0095934, theta=-34.123499 -> V=1.0, theta=0.0
% INFO    : Bus 53055	: V=1.0096172, theta=-34.169794 -> V=1.0, theta=0.0
% INFO    : Bus 53056	: V=1.0110377, theta=-33.458375 -> V=1.0, theta=0.0
% INFO    : Bus 53057	: V=1.0120324, theta=-33.97066 -> V=1.0, theta=0.0
% INFO    : Bus 53058	: V=1.0088612, theta=-34.495931 -> V=1.0, theta=0.0
% INFO    : Bus 53059	: V=0.9921908, theta=-36.067727 -> V=1.0, theta=0.0
% INFO    : Bus 53060	: V=0.9662395, theta=-38.214316 -> V=1.0, theta=0.0
% INFO    : Bus 53061	: V=0.9691216, theta=-38.16564 -> V=1.0, theta=0.0
% INFO    : Bus 53062	: V=0.9712295, theta=-38.114047 -> V=1.0, theta=0.0
% INFO    : Bus 53063	: V=1.0150492, theta=-35.431438 -> V=1.0, theta=0.0
% INFO    : Bus 53064	: V=0.9949003, theta=-36.275143 -> V=1.0, theta=0.0
% INFO    : Bus 53065	: V=0.9977459, theta=-36.709354 -> V=1.0, theta=0.0
% INFO    : Bus 53066	: V=0.9748407, theta=-38.014598 -> V=1.0, theta=0.0
% INFO    : Bus 53067	: V=0.9953343, theta=-36.360431 -> V=1.0, theta=0.0
% INFO    : Bus 53068	: V=0.9966807, theta=-36.359255 -> V=1.0, theta=0.0
% INFO    : Bus 53069	: V=1.0020417, theta=-36.348038 -> V=1.0, theta=0.0
% INFO    : Bus 53070	: V=0.9997626, theta=-36.616281 -> V=1.0, theta=0.0
% INFO    : Bus 53071	: V=1.0070796, theta=-35.898304 -> V=1.0, theta=0.0
% INFO    : Bus 53072	: V=0.9986932, theta=-36.537581 -> V=1.0, theta=0.0
% INFO    : Bus 53073	: V=1.0154855, theta=-35.0681 -> V=1.0, theta=0.0
% INFO    : Bus 53074	: V=1.0173608, theta=-34.323064 -> V=1.0, theta=0.0
% INFO    : Bus 53075	: V=1.0082112, theta=-35.465171 -> V=1.0, theta=0.0
% INFO    : Bus 53076	: V=0.9778593, theta=-36.745562 -> V=1.0, theta=0.0
% INFO    : Bus 53077	: V=0.9795726, theta=-36.356508 -> V=1.0, theta=0.0
% INFO    : Bus 53078	: V=0.9799371, theta=-36.22852 -> V=1.0, theta=0.0
% INFO    : Bus 53079	: V=0.9792965, theta=-36.02207 -> V=1.0, theta=0.0
% INFO    : Bus 53080	: V=0.9753932, theta=-36.71293 -> V=1.0, theta=0.0
% INFO    : Bus 53081	: V=0.9819208, theta=-36.108553 -> V=1.0, theta=0.0
% INFO    : Bus 53082	: V=0.9814651, theta=-36.201152 -> V=1.0, theta=0.0
% INFO    : Bus 53083	: V=0.9778106, theta=-36.783021 -> V=1.0, theta=0.0
% INFO    : Bus 53084	: V=0.9776268, theta=-36.775644 -> V=1.0, theta=0.0
% INFO    : Bus 53085	: V=0.9726485, theta=-35.027 -> V=1.0, theta=0.0
% INFO    : Bus 53086	: V=0.9766261, theta=-35.744166 -> V=1.0, theta=0.0
% INFO    : Bus 53087	: V=0.9762514, theta=-36.922696 -> V=1.0, theta=0.0
% INFO    : Bus 53088	: V=1.0115901, theta=-34.281467 -> V=1.0, theta=0.0
% INFO    : Bus 53089	: V=0.9915564, theta=-56.515095 -> V=1.0, theta=0.0
% INFO    : Bus 53090	: V=0.9882227, theta=-57.919259 -> V=1.0, theta=0.0
% INFO    : Bus 53091	: V=0.9765408, theta=-59.611809 -> V=1.0, theta=0.0
% INFO    : Bus 53092	: V=0.974762, theta=-59.698462 -> V=1.0, theta=0.0
% INFO    : Bus 53093	: V=1.0178397, theta=-49.61202 -> V=1.0, theta=0.0
% INFO    : Bus 53094	: V=0.9803, theta=-51.039906 -> V=1.0, theta=0.0
% INFO    : Bus 53095	: V=0.9974001, theta=-53.234006 -> V=1.0, theta=0.0
% INFO    : Bus 53096	: V=1.0179439, theta=-53.138381 -> V=1.0, theta=0.0
% INFO    : Bus 53097	: V=1.0144312, theta=-55.035199 -> V=1.0, theta=0.0
% INFO    : Bus 53098	: V=1.0149119, theta=-54.128189 -> V=1.0, theta=0.0
% INFO    : Bus 53099	: V=1.0154725, theta=-53.496029 -> V=1.0, theta=0.0
% INFO    : Bus 53100	: V=1.0111194, theta=-54.53584 -> V=1.0, theta=0.0
% INFO    : Bus 53101	: V=1.0197682, theta=-3.779581 -> V=1.0, theta=0.0
% INFO    : Bus 53102	: V=1.0025859, theta=-0.362031 -> V=1.0, theta=0.0
% INFO    : Bus 53103	: V=1.0061276, theta=-1.346727 -> V=1.0, theta=0.0
% INFO    : Bus 53104	: V=0.9974425, theta=-1.463081 -> V=1.0, theta=0.0
% INFO    : Bus 53105	: V=1.0050599, theta=-1.089276 -> V=1.0, theta=0.0
% INFO    : Bus 53106	: V=1.0049653, theta=-1.053322 -> V=1.0, theta=0.0
% INFO    : Bus 53107	: V=1.0033568, theta=-0.844993 -> V=1.0, theta=0.0
% INFO    : Bus 53108	: V=1.0142621, theta=-17.206854 -> V=1.0, theta=0.0
% INFO    : Bus 53109	: V=1.0148924, theta=-16.795587 -> V=1.0, theta=0.0
% INFO    : Bus 53110	: V=0.9941109, theta=-1.652378 -> V=1.0, theta=0.0
% INFO    : Bus 53111	: V=0.9860145, theta=-2.858806 -> V=1.0, theta=0.0
% INFO    : Bus 53112	: V=1.0117866, theta=10.299933 -> V=1.0, theta=0.0
% INFO    : Bus 53113	: V=1.011292, theta=9.366895 -> V=1.0, theta=0.0
% INFO    : Bus 53114	: V=1.0058112, theta=10.046347 -> V=1.0, theta=0.0
% INFO    : Bus 53115	: V=1.0006574, theta=9.957763 -> V=1.0, theta=0.0
% INFO    : Bus 53116	: V=1.0078599, theta=10.149847 -> V=1.0, theta=0.0
% INFO    : Bus 53117	: V=1.0036878, theta=9.972793 -> V=1.0, theta=0.0
% INFO    : Bus 53118	: V=0.9857519, theta=-0.095444 -> V=1.0, theta=0.0
% INFO    : Bus 53119	: V=0.9923281, theta=0.225374 -> V=1.0, theta=0.0
% INFO    : Bus 53120	: V=0.9917109, theta=0.196985 -> V=1.0, theta=0.0
% INFO    : Bus 53121	: V=0.9878395, theta=-0.194607 -> V=1.0, theta=0.0
% INFO    : Bus 53122	: V=0.9865104, theta=-0.324484 -> V=1.0, theta=0.0
% INFO    : Bus 53123	: V=0.9919599, theta=0.1528 -> V=1.0, theta=0.0
% INFO    : Bus 53124	: V=0.9935632, theta=0.118383 -> V=1.0, theta=0.0
% INFO    : Bus 53125	: V=0.9976629, theta=0.981752 -> V=1.0, theta=0.0
% INFO    : Bus 53126	: V=1.0229818, theta=-3.492722 -> V=1.0, theta=0.0
% INFO    : Bus 53127	: V=1.0220864, theta=-3.741905 -> V=1.0, theta=0.0
% INFO    : Bus 53128	: V=1.020688, theta=-4.583388 -> V=1.0, theta=0.0
% INFO    : Bus 53129	: V=1.0113556, theta=1.33186 -> V=1.0, theta=0.0
% INFO    : Bus 53130	: V=1.000555, theta=-5.22703 -> V=1.0, theta=0.0
% INFO    : Bus 53131	: V=0.9990457, theta=5.567339 -> V=1.0, theta=0.0
% INFO    : Bus 53132	: V=1.0207593, theta=-2.436388 -> V=1.0, theta=0.0
% INFO    : Bus 53133	: V=0.996933, theta=-3.078526 -> V=1.0, theta=0.0
% INFO    : Bus 53134	: V=1.0229555, theta=-2.973175 -> V=1.0, theta=0.0
% INFO    : Bus 53135	: V=1.0054929, theta=2.658694 -> V=1.0, theta=0.0
% INFO    : Bus 53136	: V=0.9968976, theta=8.37663 -> V=1.0, theta=0.0
% INFO    : Bus 53137	: V=1.0180792, theta=10.882232 -> V=1.0, theta=0.0
% INFO    : Bus 53138	: V=0.9953606, theta=8.304196 -> V=1.0, theta=0.0
% INFO    : Bus 53139	: V=0.9990192, theta=5.799046 -> V=1.0, theta=0.0
% INFO    : Bus 53140	: V=0.9922602, theta=4.474048 -> V=1.0, theta=0.0
% INFO    : Bus 53141	: V=0.9975985, theta=5.064658 -> V=1.0, theta=0.0
% INFO    : Bus 53142	: V=0.99785, theta=4.950573 -> V=1.0, theta=0.0
% INFO    : Bus 53143	: V=0.9965386, theta=4.776804 -> V=1.0, theta=0.0
% INFO    : Bus 53144	: V=0.9971381, theta=4.630259 -> V=1.0, theta=0.0
% INFO    : Bus 53145	: V=0.9901876, theta=3.150414 -> V=1.0, theta=0.0
% INFO    : Bus 53146	: V=1.0089505, theta=9.329935 -> V=1.0, theta=0.0
% INFO    : Bus 53147	: V=1.015844, theta=6.647634 -> V=1.0, theta=0.0
% INFO    : Bus 53148	: V=1.002165, theta=-8.163982 -> V=1.0, theta=0.0
% INFO    : Bus 53149	: V=1.0040663, theta=-7.291639 -> V=1.0, theta=0.0
% INFO    : Bus 53150	: V=0.9755532, theta=-4.184862 -> V=1.0, theta=0.0
% INFO    : Bus 53151	: V=0.990342, theta=-2.820848 -> V=1.0, theta=0.0
% INFO    : Bus 53152	: V=0.9897754, theta=-3.027795 -> V=1.0, theta=0.0
% INFO    : Bus 53153	: V=0.9900701, theta=-3.107319 -> V=1.0, theta=0.0
% INFO    : Bus 53154	: V=1.019371, theta=4.96217 -> V=1.0, theta=0.0
% INFO    : Bus 53155	: V=0.9875017, theta=3.734295 -> V=1.0, theta=0.0
% INFO    : Bus 53156	: V=0.9862377, theta=4.011135 -> V=1.0, theta=0.0
% INFO    : Bus 53157	: V=1.0108525, theta=11.485198 -> V=1.0, theta=0.0
% INFO    : Bus 53158	: V=0.9922021, theta=12.322341 -> V=1.0, theta=0.0
% INFO    : Bus 53159	: V=0.9946733, theta=3.701562 -> V=1.0, theta=0.0
% INFO    : Bus 53160	: V=1.0122498, theta=4.496565 -> V=1.0, theta=0.0
% INFO    : Bus 53161	: V=1.0192292, theta=-3.430214 -> V=1.0, theta=0.0
% INFO    : Bus 53162	: V=1.0063482, theta=0.016644 -> V=1.0, theta=0.0
% INFO    : Bus 53163	: V=1.004669, theta=0.730359 -> V=1.0, theta=0.0
% INFO    : Bus 53164	: V=0.9777637, theta=-10.541546 -> V=1.0, theta=0.0
% INFO    : Bus 53165	: V=0.9897167, theta=-9.75412 -> V=1.0, theta=0.0
% INFO    : Bus 53166	: V=1.0091889, theta=-1.207771 -> V=1.0, theta=0.0
% INFO    : Bus 53167	: V=1.0096534, theta=9.148092 -> V=1.0, theta=0.0
% INFO    : Bus 53168	: V=1.0044366, theta=7.741262 -> V=1.0, theta=0.0
% INFO    : Bus 53169	: V=1.0174281, theta=-4.412754 -> V=1.0, theta=0.0
% INFO    : Bus 53170	: V=1.0142437, theta=-4.599017 -> V=1.0, theta=0.0
% INFO    : Bus 53171	: V=1.0235952, theta=-2.358032 -> V=1.0, theta=0.0
% INFO    : Bus 53172	: V=0.9913311, theta=5.785505 -> V=1.0, theta=0.0
% INFO    : Bus 53173	: V=0.9950977, theta=4.58544 -> V=1.0, theta=0.0
% INFO    : Bus 53174	: V=1.0060417, theta=-1.87789 -> V=1.0, theta=0.0
% INFO    : Bus 53175	: V=1.0102615, theta=-1.621581 -> V=1.0, theta=0.0
% INFO    : Bus 53176	: V=0.9746668, theta=-3.310659 -> V=1.0, theta=0.0
% INFO    : Bus 53177	: V=1.0157247, theta=4.471417 -> V=1.0, theta=0.0
% INFO    : Bus 53178	: V=1.0202586, theta=-3.865638 -> V=1.0, theta=0.0
% INFO    : Bus 53179	: V=1.020553, theta=-3.924196 -> V=1.0, theta=0.0
% INFO    : Bus 53180	: V=1.0201079, theta=-3.848945 -> V=1.0, theta=0.0
% INFO    : Bus 53181	: V=1.0210808, theta=-3.993951 -> V=1.0, theta=0.0
% INFO    : Bus 53182	: V=0.9885913, theta=-0.992395 -> V=1.0, theta=0.0
% INFO    : Bus 53183	: V=0.9889926, theta=-2.432639 -> V=1.0, theta=0.0
% INFO    : Bus 53184	: V=0.9887546, theta=-1.886148 -> V=1.0, theta=0.0
% INFO    : Bus 53185	: V=1.0197435, theta=-2.511759 -> V=1.0, theta=0.0
% INFO    : Bus 53186	: V=0.9993059, theta=-12.18356 -> V=1.0, theta=0.0
% INFO    : Bus 53187	: V=1.0069781, theta=-6.787295 -> V=1.0, theta=0.0
% INFO    : Bus 53188	: V=1.0200211, theta=-4.083022 -> V=1.0, theta=0.0
% INFO    : Bus 53189	: V=1.0005433, theta=-9.330107 -> V=1.0, theta=0.0
% INFO    : Bus 53190	: V=0.9981877, theta=4.7671 -> V=1.0, theta=0.0
% INFO    : Bus 53191	: V=1.0031754, theta=1.613222 -> V=1.0, theta=0.0
% INFO    : Bus 53192	: V=0.9935174, theta=5.708069 -> V=1.0, theta=0.0
% INFO    : Bus 53193	: V=0.9929767, theta=5.911121 -> V=1.0, theta=0.0
% INFO    : Bus 53194	: V=0.9915126, theta=6.322702 -> V=1.0, theta=0.0
% INFO    : Bus 53195	: V=1.02, theta=-2.572738 -> V=1.0, theta=0.0
% INFO    : Bus 53196	: V=1.0045002, theta=-3.791554 -> V=1.0, theta=0.0
% INFO    : Bus 53197	: V=1.0031411, theta=-4.726912 -> V=1.0, theta=0.0
% INFO    : Bus 53198	: V=0.9977794, theta=-3.969437 -> V=1.0, theta=0.0
% INFO    : Bus 53199	: V=1.0117736, theta=-4.397733 -> V=1.0, theta=0.0
% INFO    : Bus 53200	: V=0.9777611, theta=5.909682 -> V=1.0, theta=0.0
% INFO    : Bus 53201	: V=0.9834845, theta=6.984473 -> V=1.0, theta=0.0
% INFO    : Bus 53202	: V=0.9800137, theta=6.712971 -> V=1.0, theta=0.0
% INFO    : Bus 53203	: V=0.9902974, theta=8.673099 -> V=1.0, theta=0.0
% INFO    : Bus 53204	: V=0.9780568, theta=5.652454 -> V=1.0, theta=0.0
% INFO    : Bus 53205	: V=0.9872245, theta=9.060667 -> V=1.0, theta=0.0
% INFO    : Bus 53206	: V=0.9886956, theta=8.539987 -> V=1.0, theta=0.0
% INFO    : Bus 53207	: V=0.9847861, theta=7.291796 -> V=1.0, theta=0.0
% INFO    : Bus 53208	: V=0.9870344, theta=8.548291 -> V=1.0, theta=0.0
% INFO    : Bus 53209	: V=0.9849444, theta=6.57394 -> V=1.0, theta=0.0
% INFO    : Bus 53210	: V=0.9867872, theta=8.742526 -> V=1.0, theta=0.0
% INFO    : Bus 53211	: V=0.9647325, theta=-4.676338 -> V=1.0, theta=0.0
% INFO    : Bus 53212	: V=0.9724423, theta=-4.576143 -> V=1.0, theta=0.0
% INFO    : Bus 53213	: V=0.9901506, theta=4.448423 -> V=1.0, theta=0.0
% INFO    : Bus 53214	: V=0.9887292, theta=4.632686 -> V=1.0, theta=0.0
% INFO    : Bus 53215	: V=1.0022048, theta=1.906331 -> V=1.0, theta=0.0
% INFO    : Bus 53216	: V=0.9677798, theta=1.6076 -> V=1.0, theta=0.0
% INFO    : Bus 53217	: V=1.0077049, theta=-4.932669 -> V=1.0, theta=0.0
% INFO    : Bus 53218	: V=1.0102657, theta=-4.363268 -> V=1.0, theta=0.0
% INFO    : Bus 53219	: V=1.0195609, theta=-0.957674 -> V=1.0, theta=0.0
% INFO    : Bus 53220	: V=1.0153899, theta=-2.81587 -> V=1.0, theta=0.0
% INFO    : Bus 53221	: V=1.0232316, theta=2.68562 -> V=1.0, theta=0.0
% INFO    : Bus 53222	: V=0.997747, theta=-12.149836 -> V=1.0, theta=0.0
% INFO    : Bus 53223	: V=0.9955942, theta=2.937746 -> V=1.0, theta=0.0
% INFO    : Bus 53224	: V=0.9992877, theta=8.982913 -> V=1.0, theta=0.0
% INFO    : Bus 53225	: V=0.9956149, theta=8.762068 -> V=1.0, theta=0.0
% INFO    : Bus 53226	: V=0.9965963, theta=8.744072 -> V=1.0, theta=0.0
% INFO    : Bus 53227	: V=1.0011639, theta=9.075218 -> V=1.0, theta=0.0
% INFO    : Bus 53228	: V=0.9923821, theta=8.4813 -> V=1.0, theta=0.0
% INFO    : Bus 53229	: V=0.9966654, theta=9.476808 -> V=1.0, theta=0.0
% INFO    : Bus 53230	: V=0.9953649, theta=9.296387 -> V=1.0, theta=0.0
% INFO    : Bus 53231	: V=0.9888031, theta=8.964646 -> V=1.0, theta=0.0
% INFO    : Bus 53232	: V=0.9984046, theta=9.683107 -> V=1.0, theta=0.0
% INFO    : Bus 53233	: V=0.9945595, theta=9.139477 -> V=1.0, theta=0.0
% INFO    : Bus 53234	: V=0.9901768, theta=8.277275 -> V=1.0, theta=0.0
% INFO    : Bus 53235	: V=0.9905114, theta=8.234096 -> V=1.0, theta=0.0
% INFO    : Bus 53236	: V=0.9941181, theta=8.672593 -> V=1.0, theta=0.0
% INFO    : Bus 53237	: V=0.9823877, theta=6.829866 -> V=1.0, theta=0.0
% INFO    : Bus 53238	: V=0.9845054, theta=7.095321 -> V=1.0, theta=0.0
% INFO    : Bus 53239	: V=0.9899875, theta=8.190625 -> V=1.0, theta=0.0
% INFO    : Bus 53240	: V=0.9809554, theta=6.744458 -> V=1.0, theta=0.0
% INFO    : Bus 53241	: V=0.9804329, theta=6.734739 -> V=1.0, theta=0.0
% INFO    : Bus 53242	: V=0.9830405, theta=6.964895 -> V=1.0, theta=0.0
% INFO    : Bus 53243	: V=0.9824339, theta=6.86213 -> V=1.0, theta=0.0
% INFO    : Bus 53244	: V=0.9880499, theta=8.01032 -> V=1.0, theta=0.0
% INFO    : Bus 53245	: V=0.9922897, theta=8.660524 -> V=1.0, theta=0.0
% INFO    : Bus 53246	: V=0.992817, theta=8.838118 -> V=1.0, theta=0.0
% INFO    : Bus 53247	: V=0.9911029, theta=8.405162 -> V=1.0, theta=0.0
% INFO    : Bus 53248	: V=0.9887112, theta=8.634866 -> V=1.0, theta=0.0
% INFO    : Bus 53249	: V=0.9884588, theta=8.66773 -> V=1.0, theta=0.0
% INFO    : Bus 53250	: V=0.9878519, theta=8.616328 -> V=1.0, theta=0.0
% INFO    : Bus 53251	: V=0.992224, theta=8.801434 -> V=1.0, theta=0.0
% INFO    : Bus 53252	: V=0.9916227, theta=8.7652 -> V=1.0, theta=0.0
% INFO    : Bus 53253	: V=1.004899, theta=9.947341 -> V=1.0, theta=0.0
% INFO    : Bus 53254	: V=1.0026617, theta=9.753655 -> V=1.0, theta=0.0
% INFO    : Bus 53255	: V=0.9916559, theta=7.226802 -> V=1.0, theta=0.0
% INFO    : Bus 53256	: V=0.9779904, theta=6.121921 -> V=1.0, theta=0.0
% INFO    : Bus 53257	: V=0.9878933, theta=9.079901 -> V=1.0, theta=0.0
% INFO    : Bus 53258	: V=0.9969, theta=11.920037 -> V=1.0, theta=0.0
% INFO    : Bus 53259	: V=1.0053818, theta=10.046019 -> V=1.0, theta=0.0
% INFO    : Bus 53260	: V=0.9969233, theta=8.561713 -> V=1.0, theta=0.0
% INFO    : Bus 53261	: V=0.9838034, theta=7.199181 -> V=1.0, theta=0.0
% INFO    : Bus 53262	: V=0.9814143, theta=6.802338 -> V=1.0, theta=0.0
% INFO    : Bus 53263	: V=0.992012, theta=10.561222 -> V=1.0, theta=0.0
% INFO    : Bus 53264	: V=0.9895526, theta=10.138682 -> V=1.0, theta=0.0
% INFO    : Bus 53265	: V=0.9921389, theta=8.564015 -> V=1.0, theta=0.0
% INFO    : Bus 53266	: V=1.0008013, theta=9.674353 -> V=1.0, theta=0.0
% INFO    : Bus 53267	: V=0.9897163, theta=9.064679 -> V=1.0, theta=0.0
% INFO    : Bus 53268	: V=1.0132711, theta=-3.919623 -> V=1.0, theta=0.0
% INFO    : Bus 53269	: V=1.0159591, theta=-3.669755 -> V=1.0, theta=0.0
% INFO    : Bus 53270	: V=1.0065378, theta=-4.774979 -> V=1.0, theta=0.0
% INFO    : Bus 53271	: V=1.0126142, theta=-4.054152 -> V=1.0, theta=0.0
% INFO    : Bus 53272	: V=1.0086831, theta=-4.772082 -> V=1.0, theta=0.0
% INFO    : Bus 53273	: V=1.0120735, theta=-4.45138 -> V=1.0, theta=0.0
% INFO    : Bus 53274	: V=1.0131564, theta=-4.442568 -> V=1.0, theta=0.0
% INFO    : Bus 53275	: V=1.004783, theta=-5.109201 -> V=1.0, theta=0.0
% INFO    : Bus 53276	: V=1.0100576, theta=-4.661246 -> V=1.0, theta=0.0
% INFO    : Bus 53277	: V=1.0031322, theta=-5.398759 -> V=1.0, theta=0.0
% INFO    : Bus 53278	: V=1.0116991, theta=-4.256012 -> V=1.0, theta=0.0
% INFO    : Bus 53279	: V=1.0063544, theta=-5.073374 -> V=1.0, theta=0.0
% INFO    : Bus 53280	: V=1.0159578, theta=-4.357786 -> V=1.0, theta=0.0
% INFO    : Bus 53281	: V=1.0161523, theta=-4.30199 -> V=1.0, theta=0.0
% INFO    : Bus 53282	: V=1.0097068, theta=-5.058605 -> V=1.0, theta=0.0
% INFO    : Bus 53283	: V=1.0024255, theta=-5.939123 -> V=1.0, theta=0.0
% INFO    : Bus 53284	: V=1.0185188, theta=-4.193337 -> V=1.0, theta=0.0
% INFO    : Bus 53285	: V=1.0190622, theta=-4.190308 -> V=1.0, theta=0.0
% INFO    : Bus 53286	: V=1.0126721, theta=-4.122886 -> V=1.0, theta=0.0
% INFO    : Bus 53287	: V=1.0139689, theta=-3.69673 -> V=1.0, theta=0.0
% INFO    : Bus 53288	: V=0.9995422, theta=-5.381663 -> V=1.0, theta=0.0
% INFO    : Bus 53289	: V=1.0111944, theta=-4.579663 -> V=1.0, theta=0.0
% INFO    : Bus 53290	: V=1.0077324, theta=-5.893322 -> V=1.0, theta=0.0
% INFO    : Bus 53291	: V=1.0116446, theta=6.513535 -> V=1.0, theta=0.0
% INFO    : Bus 53292	: V=1.0198201, theta=0.683545 -> V=1.0, theta=0.0
% INFO    : Bus 53293	: V=0.9754791, theta=4.655574 -> V=1.0, theta=0.0
% INFO    : Bus 53294	: V=0.9849077, theta=6.334038 -> V=1.0, theta=0.0
% INFO    : Bus 53295	: V=0.9741328, theta=4.670321 -> V=1.0, theta=0.0
% INFO    : Bus 53296	: V=0.9829759, theta=6.254495 -> V=1.0, theta=0.0
% INFO    : Bus 53297	: V=0.99669, theta=-1.540985 -> V=1.0, theta=0.0
% INFO    : Bus 53298	: V=0.9987597, theta=-15.913047 -> V=1.0, theta=0.0
% INFO    : Bus 53299	: V=1.0143596, theta=-9.940108 -> V=1.0, theta=0.0
% INFO    : Bus 53300	: V=1.0057968, theta=-15.711753 -> V=1.0, theta=0.0
% INFO    : Bus 53301	: V=0.9966961, theta=-0.831924 -> V=1.0, theta=0.0
% INFO    : Bus 53302	: V=0.9973224, theta=-0.912014 -> V=1.0, theta=0.0
% INFO    : Bus 53303	: V=0.9950268, theta=0.243489 -> V=1.0, theta=0.0
% INFO    : Bus 53304	: V=1.0207261, theta=-3.783368 -> V=1.0, theta=0.0
% INFO    : Bus 53305	: V=1.0202225, theta=-1.67428 -> V=1.0, theta=0.0
% INFO    : Bus 53306	: V=1.0000738, theta=-15.808074 -> V=1.0, theta=0.0
% INFO    : Bus 53307	: V=1.0052497, theta=-14.698918 -> V=1.0, theta=0.0
% INFO    : Bus 53308	: V=0.9942261, theta=-15.337581 -> V=1.0, theta=0.0
% INFO    : Bus 53309	: V=1.0081848, theta=-14.676584 -> V=1.0, theta=0.0
% INFO    : Bus 53310	: V=0.9874233, theta=4.971202 -> V=1.0, theta=0.0
% INFO    : Bus 53311	: V=0.9852331, theta=4.65117 -> V=1.0, theta=0.0
% INFO    : Bus 53312	: V=0.9907252, theta=8.506848 -> V=1.0, theta=0.0
% INFO    : Bus 53313	: V=0.9916167, theta=7.956025 -> V=1.0, theta=0.0
% INFO    : Bus 53314	: V=0.9916047, theta=7.326659 -> V=1.0, theta=0.0
% INFO    : Bus 53315	: V=1.018573, theta=2.97648 -> V=1.0, theta=0.0
% INFO    : Bus 53316	: V=1.0171365, theta=4.952119 -> V=1.0, theta=0.0
% INFO    : Bus 53317	: V=0.9780587, theta=0.675768 -> V=1.0, theta=0.0
% INFO    : Bus 53318	: V=0.9798469, theta=1.711358 -> V=1.0, theta=0.0
% INFO    : Bus 53319	: V=0.9952573, theta=-1.238519 -> V=1.0, theta=0.0
% INFO    : Bus 53320	: V=0.9790414, theta=1.562988 -> V=1.0, theta=0.0
% INFO    : Bus 53321	: V=0.9812343, theta=2.511912 -> V=1.0, theta=0.0
% INFO    : Bus 53322	: V=1.0190174, theta=3.215724 -> V=1.0, theta=0.0
% INFO    : Bus 53323	: V=0.9667567, theta=-67.288789 -> V=1.0, theta=0.0
% INFO    : Bus 53324	: V=0.9768502, theta=-68.729208 -> V=1.0, theta=0.0
% INFO    : Bus 53325	: V=1.0035242, theta=-67.055076 -> V=1.0, theta=0.0
% INFO    : Bus 53326	: V=0.9596383, theta=-69.027801 -> V=1.0, theta=0.0
% INFO    : Bus 53327	: V=0.9648662, theta=-68.803295 -> V=1.0, theta=0.0
% INFO    : Bus 53328	: V=0.966992, theta=-68.694511 -> V=1.0, theta=0.0
% INFO    : Bus 53329	: V=0.9778585, theta=-67.410261 -> V=1.0, theta=0.0
% INFO    : Bus 53330	: V=0.9644992, theta=-68.810549 -> V=1.0, theta=0.0
% INFO    : Bus 53331	: V=0.9818065, theta=-66.932039 -> V=1.0, theta=0.0
% INFO    : Bus 53332	: V=0.9599638, theta=-70.266357 -> V=1.0, theta=0.0
% INFO    : Bus 53333	: V=0.9922973, theta=-66.90297 -> V=1.0, theta=0.0
% INFO    : Bus 53334	: V=0.9964406, theta=-57.25198 -> V=1.0, theta=0.0
% INFO    : Bus 53335	: V=0.9951295, theta=-57.233424 -> V=1.0, theta=0.0
% INFO    : Bus 53336	: V=0.9870136, theta=-57.939395 -> V=1.0, theta=0.0
% INFO    : Bus 53337	: V=0.9731346, theta=-58.056913 -> V=1.0, theta=0.0
% INFO    : Bus 53338	: V=0.9655817, theta=-68.491387 -> V=1.0, theta=0.0
% INFO    : Bus 53339	: V=0.950394, theta=-70.244912 -> V=1.0, theta=0.0
% INFO    : Bus 53340	: V=0.9574186, theta=-70.503874 -> V=1.0, theta=0.0
% INFO    : Bus 53341	: V=0.9628475, theta=-69.684979 -> V=1.0, theta=0.0
% INFO    : Bus 53342	: V=0.961097, theta=-70.425409 -> V=1.0, theta=0.0
% INFO    : Bus 53343	: V=0.9603204, theta=-70.143366 -> V=1.0, theta=0.0
% INFO    : Bus 53344	: V=0.9397739, theta=-73.74841 -> V=1.0, theta=0.0
% INFO    : Bus 53345	: V=0.9572426, theta=-70.527927 -> V=1.0, theta=0.0
% INFO    : Bus 53346	: V=0.9418466, theta=-73.532081 -> V=1.0, theta=0.0
% INFO    : Bus 53347	: V=0.9389549, theta=-73.76145 -> V=1.0, theta=0.0
% INFO    : Bus 53348	: V=0.9447659, theta=-73.154868 -> V=1.0, theta=0.0
% INFO    : Bus 53349	: V=0.9580533, theta=-70.629495 -> V=1.0, theta=0.0
% INFO    : Bus 53350	: V=0.9928494, theta=-65.788382 -> V=1.0, theta=0.0
% INFO    : Bus 53351	: V=0.9520133, theta=-71.236473 -> V=1.0, theta=0.0
% INFO    : Bus 53352	: V=0.9610104, theta=-70.060953 -> V=1.0, theta=0.0
% INFO    : Bus 53353	: V=0.9675677, theta=-70.633523 -> V=1.0, theta=0.0
% INFO    : Bus 53354	: V=0.9640968, theta=-70.44536 -> V=1.0, theta=0.0
% INFO    : Bus 53355	: V=0.992807, theta=-60.91213 -> V=1.0, theta=0.0
% INFO    : Bus 53356	: V=0.9808413, theta=-61.394136 -> V=1.0, theta=0.0
% INFO    : Bus 53357	: V=0.9952521, theta=-60.167667 -> V=1.0, theta=0.0
% INFO    : Bus 53358	: V=0.9797213, theta=-61.396458 -> V=1.0, theta=0.0
% INFO    : Bus 53359	: V=0.999756, theta=-59.605995 -> V=1.0, theta=0.0
% INFO    : Bus 53360	: V=0.9552891, theta=-66.862828 -> V=1.0, theta=0.0
% INFO    : Bus 53361	: V=0.9625828, theta=-60.331424 -> V=1.0, theta=0.0
% INFO    : Bus 53362	: V=0.9531306, theta=-60.594974 -> V=1.0, theta=0.0
% INFO    : Bus 53363	: V=0.9645938, theta=-60.697747 -> V=1.0, theta=0.0
% INFO    : Bus 53364	: V=0.9908908, theta=-68.589752 -> V=1.0, theta=0.0
% INFO    : Bus 53365	: V=0.9691736, theta=-72.010202 -> V=1.0, theta=0.0
% INFO    : Bus 53366	: V=0.990683, theta=-69.417701 -> V=1.0, theta=0.0
% INFO    : Bus 53367	: V=0.9913719, theta=-69.22289 -> V=1.0, theta=0.0
% INFO    : Bus 53368	: V=0.9849249, theta=-70.009073 -> V=1.0, theta=0.0
% INFO    : Bus 53369	: V=0.9931414, theta=-68.976087 -> V=1.0, theta=0.0
% INFO    : Bus 53370	: V=0.9915549, theta=-68.395577 -> V=1.0, theta=0.0
% INFO    : Bus 53371	: V=0.9984791, theta=-67.799053 -> V=1.0, theta=0.0
% INFO    : Bus 53372	: V=0.9942233, theta=-70.123189 -> V=1.0, theta=0.0
% INFO    : Bus 53373	: V=0.9989388, theta=-71.022136 -> V=1.0, theta=0.0
% INFO    : Bus 53374	: V=1.0043618, theta=-70.239789 -> V=1.0, theta=0.0
% INFO    : Bus 53375	: V=1.0026927, theta=-70.191293 -> V=1.0, theta=0.0
% INFO    : Bus 53376	: V=0.987301, theta=-72.456152 -> V=1.0, theta=0.0
% INFO    : Bus 53377	: V=0.9852943, theta=-72.890596 -> V=1.0, theta=0.0
% INFO    : Bus 53378	: V=0.9849629, theta=-57.781306 -> V=1.0, theta=0.0
% INFO    : Bus 53379	: V=0.9385617, theta=-77.993651 -> V=1.0, theta=0.0
% INFO    : Bus 53380	: V=0.9356137, theta=-78.499457 -> V=1.0, theta=0.0
% INFO    : Bus 53381	: V=0.9413771, theta=-76.379653 -> V=1.0, theta=0.0
% INFO    : Bus 53382	: V=0.9434001, theta=-77.471015 -> V=1.0, theta=0.0
% INFO    : Bus 53383	: V=0.9491508, theta=-76.903695 -> V=1.0, theta=0.0
% INFO    : Bus 53384	: V=0.9908791, theta=-69.792148 -> V=1.0, theta=0.0
% INFO    : Bus 53385	: V=0.9834283, theta=-70.375002 -> V=1.0, theta=0.0
% INFO    : Bus 53386	: V=0.9972948, theta=-69.349689 -> V=1.0, theta=0.0
% INFO    : Bus 53387	: V=1.0088053, theta=-68.460733 -> V=1.0, theta=0.0
% INFO    : Bus 53388	: V=0.9953854, theta=-69.20633 -> V=1.0, theta=0.0
% INFO    : Bus 53389	: V=1.0079496, theta=-68.208265 -> V=1.0, theta=0.0
% INFO    : Bus 53390	: V=1.0138595, theta=-68.434643 -> V=1.0, theta=0.0
% INFO    : Bus 53391	: V=1.015135, theta=-68.409308 -> V=1.0, theta=0.0
% INFO    : Bus 53392	: V=0.9746183, theta=-71.341881 -> V=1.0, theta=0.0
% INFO    : Bus 53393	: V=0.9648925, theta=-72.480037 -> V=1.0, theta=0.0
% INFO    : Bus 53394	: V=1.0001425, theta=-57.630623 -> V=1.0, theta=0.0
% INFO    : Bus 53395	: V=0.9598281, theta=-68.607431 -> V=1.0, theta=0.0
% INFO    : Bus 53396	: V=0.9931867, theta=-62.04569 -> V=1.0, theta=0.0
% INFO    : Bus 53397	: V=0.9626304, theta=-65.030168 -> V=1.0, theta=0.0
% INFO    : Bus 53398	: V=0.9533053, theta=-67.882303 -> V=1.0, theta=0.0
% INFO    : Bus 53399	: V=0.9551178, theta=-67.620917 -> V=1.0, theta=0.0
% INFO    : Bus 53400	: V=0.9558866, theta=-67.598662 -> V=1.0, theta=0.0
% INFO    : Bus 53401	: V=0.9717615, theta=-64.266831 -> V=1.0, theta=0.0
% INFO    : Bus 53402	: V=0.9472046, theta=-75.221215 -> V=1.0, theta=0.0
% INFO    : Bus 53403	: V=0.9514065, theta=-74.838049 -> V=1.0, theta=0.0
% INFO    : Bus 53404	: V=0.961241, theta=-73.436322 -> V=1.0, theta=0.0
% INFO    : Bus 53405	: V=0.957425, theta=-73.896828 -> V=1.0, theta=0.0
% INFO    : Bus 53406	: V=0.956084, theta=-74.344155 -> V=1.0, theta=0.0
% INFO    : Bus 53407	: V=0.9478662, theta=-75.067141 -> V=1.0, theta=0.0
% INFO    : Bus 53408	: V=0.9501105, theta=-74.98656 -> V=1.0, theta=0.0
% INFO    : Bus 53409	: V=0.9553531, theta=-74.147182 -> V=1.0, theta=0.0
% INFO    : Bus 53410	: V=0.9519383, theta=-75.421049 -> V=1.0, theta=0.0
% INFO    : Bus 53411	: V=0.955543, theta=-74.166962 -> V=1.0, theta=0.0
% INFO    : Bus 53412	: V=0.9501404, theta=-75.688587 -> V=1.0, theta=0.0
% INFO    : Bus 53413	: V=0.9517282, theta=-75.511681 -> V=1.0, theta=0.0
% INFO    : Bus 53414	: V=0.9511789, theta=-75.592841 -> V=1.0, theta=0.0
% INFO    : Bus 53415	: V=0.9529142, theta=-75.307043 -> V=1.0, theta=0.0
% INFO    : Bus 53416	: V=0.9567764, theta=-73.957297 -> V=1.0, theta=0.0
% INFO    : Bus 53417	: V=0.9564305, theta=-73.987193 -> V=1.0, theta=0.0
% INFO    : Bus 53418	: V=0.953212, theta=-75.315764 -> V=1.0, theta=0.0
% INFO    : Bus 53419	: V=0.9519766, theta=-75.472508 -> V=1.0, theta=0.0
% INFO    : Bus 53420	: V=0.9524495, theta=-75.402537 -> V=1.0, theta=0.0
% INFO    : Bus 53421	: V=0.9516735, theta=-75.507681 -> V=1.0, theta=0.0
% INFO    : Bus 53422	: V=0.9548102, theta=-75.076562 -> V=1.0, theta=0.0
% INFO    : Bus 53423	: V=0.9625562, theta=-72.337107 -> V=1.0, theta=0.0
% INFO    : Bus 53424	: V=0.9530566, theta=-74.606369 -> V=1.0, theta=0.0
% INFO    : Bus 53425	: V=0.9507325, theta=-74.766636 -> V=1.0, theta=0.0
% INFO    : Bus 53426	: V=0.9516223, theta=-74.742031 -> V=1.0, theta=0.0
% INFO    : Bus 53427	: V=0.9639301, theta=-71.282846 -> V=1.0, theta=0.0
% INFO    : Bus 53428	: V=0.9615763, theta=-71.223507 -> V=1.0, theta=0.0
% INFO    : Bus 53429	: V=0.9662581, theta=-70.376456 -> V=1.0, theta=0.0
% INFO    : Bus 53430	: V=0.9609939, theta=-71.27686 -> V=1.0, theta=0.0
% INFO    : Bus 53431	: V=0.9517434, theta=-73.261508 -> V=1.0, theta=0.0
% INFO    : Bus 53432	: V=0.9608292, theta=-70.817905 -> V=1.0, theta=0.0
% INFO    : Bus 53433	: V=0.9602563, theta=-70.874948 -> V=1.0, theta=0.0
% INFO    : Bus 53434	: V=0.9598978, theta=-70.923756 -> V=1.0, theta=0.0
% INFO    : Bus 53435	: V=0.9591928, theta=-70.943581 -> V=1.0, theta=0.0
% INFO    : Bus 53436	: V=0.9608497, theta=-70.855298 -> V=1.0, theta=0.0
% INFO    : Bus 53437	: V=0.9612678, theta=-70.846483 -> V=1.0, theta=0.0
% INFO    : Bus 53438	: V=0.9684778, theta=-69.678603 -> V=1.0, theta=0.0
% INFO    : Bus 53439	: V=0.9609676, theta=-71.197392 -> V=1.0, theta=0.0
% INFO    : Bus 53440	: V=0.9678201, theta=-69.880846 -> V=1.0, theta=0.0
% INFO    : Bus 53441	: V=0.9676468, theta=-69.956302 -> V=1.0, theta=0.0
% INFO    : Bus 53442	: V=0.9681238, theta=-69.783191 -> V=1.0, theta=0.0
% INFO    : Bus 53443	: V=0.9691621, theta=-69.516399 -> V=1.0, theta=0.0
% INFO    : Bus 53444	: V=0.9695234, theta=-69.662631 -> V=1.0, theta=0.0
% INFO    : Bus 53445	: V=0.9623272, theta=-70.669344 -> V=1.0, theta=0.0
% INFO    : Bus 53446	: V=0.962752, theta=-70.561307 -> V=1.0, theta=0.0
% INFO    : Bus 53447	: V=0.9698321, theta=-69.375332 -> V=1.0, theta=0.0
% INFO    : Bus 53448	: V=0.9627541, theta=-69.793014 -> V=1.0, theta=0.0
% INFO    : Bus 53449	: V=0.9688592, theta=-69.473495 -> V=1.0, theta=0.0
% INFO    : Bus 53450	: V=0.9687533, theta=-69.474459 -> V=1.0, theta=0.0
% INFO    : Bus 53451	: V=0.9822168, theta=-68.034048 -> V=1.0, theta=0.0
% INFO    : Bus 53452	: V=0.9640199, theta=-70.146425 -> V=1.0, theta=0.0
% INFO    : Bus 53453	: V=0.9616001, theta=-69.838697 -> V=1.0, theta=0.0
% INFO    : Bus 53454	: V=0.9839737, theta=-66.654968 -> V=1.0, theta=0.0
% INFO    : Bus 53455	: V=0.9682207, theta=-69.472308 -> V=1.0, theta=0.0
% INFO    : Bus 53456	: V=0.9835034, theta=-66.428316 -> V=1.0, theta=0.0
% INFO    : Bus 53457	: V=0.9707564, theta=-69.139676 -> V=1.0, theta=0.0
% INFO    : Bus 53458	: V=0.9593139, theta=-70.914926 -> V=1.0, theta=0.0
% INFO    : Bus 53459	: V=0.9832649, theta=-68.262425 -> V=1.0, theta=0.0
% INFO    : Bus 53460	: V=0.9643764, theta=-73.992798 -> V=1.0, theta=0.0
% INFO    : Bus 53461	: V=0.9653857, theta=-71.867365 -> V=1.0, theta=0.0
% INFO    : Bus 53462	: V=0.9698909, theta=-71.275242 -> V=1.0, theta=0.0
% INFO    : Bus 53463	: V=0.9633158, theta=-70.545408 -> V=1.0, theta=0.0
% INFO    : Bus 53464	: V=0.9712933, theta=-69.178087 -> V=1.0, theta=0.0
% INFO    : Bus 53465	: V=0.9714852, theta=-69.176138 -> V=1.0, theta=0.0
% INFO    : Bus 53466	: V=0.9588058, theta=-70.930789 -> V=1.0, theta=0.0
% INFO    : Bus 53467	: V=0.9594369, theta=-74.329935 -> V=1.0, theta=0.0
% INFO    : Bus 53468	: V=0.9737626, theta=-72.41655 -> V=1.0, theta=0.0
% INFO    : Bus 53469	: V=0.9738027, theta=-72.457833 -> V=1.0, theta=0.0
% INFO    : Bus 53470	: V=0.9580855, theta=-74.442436 -> V=1.0, theta=0.0
% INFO    : Bus 53471	: V=0.9674748, theta=-73.106422 -> V=1.0, theta=0.0
% INFO    : Bus 53472	: V=0.9677952, theta=-73.085203 -> V=1.0, theta=0.0
% INFO    : Bus 53473	: V=0.9755474, theta=-72.102937 -> V=1.0, theta=0.0
% INFO    : Bus 53474	: V=0.9760834, theta=-72.060346 -> V=1.0, theta=0.0
% INFO    : Bus 53475	: V=0.990529, theta=-70.077443 -> V=1.0, theta=0.0
% INFO    : Bus 53476	: V=0.9615305, theta=-73.9981 -> V=1.0, theta=0.0
% INFO    : Bus 53477	: V=0.9684061, theta=-73.10359 -> V=1.0, theta=0.0
% INFO    : Bus 53478	: V=0.9905364, theta=-70.084015 -> V=1.0, theta=0.0
% INFO    : Bus 53479	: V=0.9571632, theta=-73.998033 -> V=1.0, theta=0.0
% INFO    : Bus 53480	: V=0.9625956, theta=-73.70266 -> V=1.0, theta=0.0
% INFO    : Bus 53481	: V=0.9598279, theta=-74.345124 -> V=1.0, theta=0.0
% INFO    : Bus 53482	: V=0.9596863, theta=-74.290578 -> V=1.0, theta=0.0
% INFO    : Bus 53483	: V=0.959658, theta=-73.911425 -> V=1.0, theta=0.0
% INFO    : Bus 53484	: V=0.9575805, theta=-74.112649 -> V=1.0, theta=0.0
% INFO    : Bus 53485	: V=0.9583403, theta=-73.96131 -> V=1.0, theta=0.0
% INFO    : Bus 53486	: V=0.9565765, theta=-74.211629 -> V=1.0, theta=0.0
% INFO    : Bus 53487	: V=0.9547864, theta=-75.033212 -> V=1.0, theta=0.0
% INFO    : Bus 53488	: V=0.9575662, theta=-74.513368 -> V=1.0, theta=0.0
% INFO    : Bus 53489	: V=0.9586544, theta=-74.180907 -> V=1.0, theta=0.0
% INFO    : Bus 53490	: V=0.9696982, theta=-72.735698 -> V=1.0, theta=0.0
% INFO    : Bus 53491	: V=0.9545236, theta=-74.941172 -> V=1.0, theta=0.0
% INFO    : Bus 53492	: V=0.9529443, theta=-75.114414 -> V=1.0, theta=0.0
% INFO    : Bus 53493	: V=0.9530978, theta=-75.073054 -> V=1.0, theta=0.0
% INFO    : Bus 53494	: V=0.9537251, theta=-74.994602 -> V=1.0, theta=0.0
% INFO    : Bus 53495	: V=0.9555184, theta=-74.883851 -> V=1.0, theta=0.0
% INFO    : Bus 53496	: V=0.9567079, theta=-74.673016 -> V=1.0, theta=0.0
% INFO    : Bus 53497	: V=0.9550462, theta=-74.804254 -> V=1.0, theta=0.0
% INFO    : Bus 53498	: V=0.9566836, theta=-74.594124 -> V=1.0, theta=0.0
% INFO    : Bus 53499	: V=0.9618345, theta=-74.092102 -> V=1.0, theta=0.0
% INFO    : Bus 53500	: V=0.9569642, theta=-74.131758 -> V=1.0, theta=0.0
% INFO    : Bus 53501	: V=0.9584328, theta=-74.124049 -> V=1.0, theta=0.0
% INFO    : Bus 53502	: V=0.9599226, theta=-73.895831 -> V=1.0, theta=0.0
% INFO    : Bus 53503	: V=0.9849579, theta=-70.896785 -> V=1.0, theta=0.0
% INFO    : Bus 53504	: V=0.9756025, theta=-71.701251 -> V=1.0, theta=0.0
% INFO    : Bus 53505	: V=0.9870102, theta=-70.696297 -> V=1.0, theta=0.0
% INFO    : Bus 53506	: V=1.0058015, theta=-68.298067 -> V=1.0, theta=0.0
% INFO    : Bus 53507	: V=0.9820077, theta=-71.067628 -> V=1.0, theta=0.0
% INFO    : Bus 53508	: V=0.9830128, theta=-71.00728 -> V=1.0, theta=0.0
% INFO    : Bus 53509	: V=0.9702333, theta=-72.215159 -> V=1.0, theta=0.0
% INFO    : Bus 53510	: V=0.9693133, theta=-72.144543 -> V=1.0, theta=0.0
% INFO    : Bus 53511	: V=0.9728912, theta=-71.87489 -> V=1.0, theta=0.0
% INFO    : Bus 53512	: V=0.9731404, theta=-71.872506 -> V=1.0, theta=0.0
% INFO    : Bus 53513	: V=0.9834323, theta=-70.914399 -> V=1.0, theta=0.0
% INFO    : Bus 53514	: V=0.97205, theta=-72.204269 -> V=1.0, theta=0.0
% INFO    : Bus 53515	: V=0.96867, theta=-72.613953 -> V=1.0, theta=0.0
% INFO    : Bus 53516	: V=0.9663418, theta=-72.870305 -> V=1.0, theta=0.0
% INFO    : Bus 53517	: V=0.9844027, theta=-70.812415 -> V=1.0, theta=0.0
% INFO    : Bus 53518	: V=0.9682362, theta=-72.675066 -> V=1.0, theta=0.0
% INFO    : Bus 53519	: V=0.9631585, theta=-73.401716 -> V=1.0, theta=0.0
% INFO    : Bus 53520	: V=0.9628947, theta=-73.686025 -> V=1.0, theta=0.0
% INFO    : Bus 53521	: V=0.9609247, theta=-73.894922 -> V=1.0, theta=0.0
% INFO    : Bus 53522	: V=0.9596428, theta=-74.131732 -> V=1.0, theta=0.0
% INFO    : Bus 53523	: V=0.9600277, theta=-73.991509 -> V=1.0, theta=0.0
% INFO    : Bus 53524	: V=0.9583073, theta=-74.423208 -> V=1.0, theta=0.0
% INFO    : Bus 53525	: V=0.9589452, theta=-74.293162 -> V=1.0, theta=0.0
% INFO    : Bus 53526	: V=0.9608116, theta=-73.519289 -> V=1.0, theta=0.0
% INFO    : Bus 53527	: V=0.9601371, theta=-73.531518 -> V=1.0, theta=0.0
% INFO    : Bus 53528	: V=0.9534191, theta=-75.106186 -> V=1.0, theta=0.0
% INFO    : Bus 53529	: V=0.9547383, theta=-75.052342 -> V=1.0, theta=0.0
% INFO    : Bus 53530	: V=0.9547004, theta=-74.976416 -> V=1.0, theta=0.0
% INFO    : Bus 53531	: V=0.9524442, theta=-75.07219 -> V=1.0, theta=0.0
% INFO    : Bus 53532	: V=0.9578242, theta=-74.501508 -> V=1.0, theta=0.0
% INFO    : Bus 53533	: V=0.9575911, theta=-74.33277 -> V=1.0, theta=0.0
% INFO    : Bus 53534	: V=0.9656969, theta=-72.71666 -> V=1.0, theta=0.0
% INFO    : Bus 53535	: V=0.9708648, theta=-72.580019 -> V=1.0, theta=0.0
% INFO    : Bus 53536	: V=0.9785506, theta=-71.742906 -> V=1.0, theta=0.0
% INFO    : Bus 53537	: V=0.9828143, theta=-71.375163 -> V=1.0, theta=0.0
% INFO    : Bus 53538	: V=0.9853673, theta=-71.042807 -> V=1.0, theta=0.0
% INFO    : Bus 53539	: V=0.988607, theta=-70.64915 -> V=1.0, theta=0.0
% INFO    : Bus 53540	: V=0.9833821, theta=-71.23145 -> V=1.0, theta=0.0
% INFO    : Bus 53541	: V=0.9824549, theta=-71.300657 -> V=1.0, theta=0.0
% INFO    : Bus 53542	: V=0.9817386, theta=-71.353158 -> V=1.0, theta=0.0
% INFO    : Bus 53543	: V=1.0090284, theta=-67.984865 -> V=1.0, theta=0.0
% INFO    : Bus 53544	: V=1.0101539, theta=-67.879018 -> V=1.0, theta=0.0
% INFO    : Bus 53545	: V=1.0108194, theta=-67.830414 -> V=1.0, theta=0.0
% INFO    : Bus 53546	: V=0.9920579, theta=-70.236143 -> V=1.0, theta=0.0
% INFO    : Bus 53547	: V=1.0115327, theta=-67.777762 -> V=1.0, theta=0.0
% INFO    : Bus 53548	: V=1.0123609, theta=-67.703774 -> V=1.0, theta=0.0
% INFO    : Bus 53549	: V=1.014556, theta=-67.490808 -> V=1.0, theta=0.0
% INFO    : Bus 53550	: V=0.9630541, theta=-71.769195 -> V=1.0, theta=0.0
% INFO    : Bus 53551	: V=0.9803473, theta=-71.125674 -> V=1.0, theta=0.0
% INFO    : Bus 53552	: V=0.9816506, theta=-71.115674 -> V=1.0, theta=0.0
% INFO    : Bus 53553	: V=0.9756141, theta=-71.623139 -> V=1.0, theta=0.0
% INFO    : Bus 53554	: V=0.9793815, theta=-71.316417 -> V=1.0, theta=0.0
% INFO    : Bus 53555	: V=0.977027, theta=-71.512457 -> V=1.0, theta=0.0
% INFO    : Bus 53556	: V=0.9753471, theta=-71.731812 -> V=1.0, theta=0.0
% INFO    : Bus 53557	: V=0.9673431, theta=-72.110432 -> V=1.0, theta=0.0
% INFO    : Bus 53558	: V=0.9705568, theta=-72.26585 -> V=1.0, theta=0.0
% INFO    : Bus 53559	: V=0.9703588, theta=-72.045742 -> V=1.0, theta=0.0
% INFO    : Bus 53560	: V=0.9688496, theta=-72.075852 -> V=1.0, theta=0.0
% INFO    : Bus 53561	: V=0.9699293, theta=-72.051725 -> V=1.0, theta=0.0
% INFO    : Bus 53562	: V=0.9670075, theta=-72.067719 -> V=1.0, theta=0.0
% INFO    : Bus 53563	: V=0.9694404, theta=-72.008984 -> V=1.0, theta=0.0
% INFO    : Bus 53564	: V=0.9717041, theta=-71.883798 -> V=1.0, theta=0.0
% INFO    : Bus 53565	: V=0.9737601, theta=-71.756206 -> V=1.0, theta=0.0
% INFO    : Bus 53566	: V=1.009325, theta=-67.946018 -> V=1.0, theta=0.0
% INFO    : Bus 53567	: V=0.9694372, theta=-71.530615 -> V=1.0, theta=0.0
% INFO    : Bus 53568	: V=0.9608174, theta=-72.170046 -> V=1.0, theta=0.0
% INFO    : Bus 53569	: V=0.9807174, theta=-71.652799 -> V=1.0, theta=0.0
% INFO    : Bus 53570	: V=0.9623598, theta=-74.248856 -> V=1.0, theta=0.0
% INFO    : Bus 53571	: V=0.9784889, theta=-71.482197 -> V=1.0, theta=0.0
% INFO    : Bus 53572	: V=0.9799898, theta=-71.470338 -> V=1.0, theta=0.0
% INFO    : Bus 53573	: V=0.9865739, theta=-70.907596 -> V=1.0, theta=0.0
% INFO    : Bus 53574	: V=0.9803047, theta=-71.436436 -> V=1.0, theta=0.0
% INFO    : Bus 53575	: V=0.9879279, theta=-70.763015 -> V=1.0, theta=0.0
% INFO    : Bus 53576	: V=0.9888498, theta=-70.722502 -> V=1.0, theta=0.0
% INFO    : Bus 53577	: V=0.9901547, theta=-70.534384 -> V=1.0, theta=0.0
% INFO    : Bus 53578	: V=0.9909607, theta=-70.440203 -> V=1.0, theta=0.0
% INFO    : Bus 53579	: V=0.9844461, theta=-71.441384 -> V=1.0, theta=0.0
% INFO    : Bus 53580	: V=0.9921822, theta=-70.295146 -> V=1.0, theta=0.0
% INFO    : Bus 53581	: V=0.9906121, theta=-70.463674 -> V=1.0, theta=0.0
% INFO    : Bus 53582	: V=0.9938779, theta=-70.077473 -> V=1.0, theta=0.0
% INFO    : Bus 53583	: V=0.996089, theta=-69.851045 -> V=1.0, theta=0.0
% INFO    : Bus 53584	: V=0.9947772, theta=-69.980994 -> V=1.0, theta=0.0
% INFO    : Bus 53585	: V=0.9941221, theta=-70.047021 -> V=1.0, theta=0.0
% INFO    : Bus 53586	: V=0.9876855, theta=-70.450378 -> V=1.0, theta=0.0
% INFO    : Bus 53587	: V=0.9986709, theta=-69.58428 -> V=1.0, theta=0.0
% INFO    : Bus 53588	: V=1.0108098, theta=-68.209877 -> V=1.0, theta=0.0
% INFO    : Bus 53589	: V=1.00714, theta=-68.239184 -> V=1.0, theta=0.0
% INFO    : Bus 53590	: V=0.9765486, theta=-72.200614 -> V=1.0, theta=0.0
% INFO    : Bus 53591	: V=0.9658347, theta=-73.538269 -> V=1.0, theta=0.0
% INFO    : Bus 53592	: V=0.9657976, theta=-73.32407 -> V=1.0, theta=0.0
% INFO    : Bus 53593	: V=0.9809069, theta=-71.967187 -> V=1.0, theta=0.0
% INFO    : Bus 53594	: V=0.981953, theta=-71.901597 -> V=1.0, theta=0.0
% INFO    : Bus 53595	: V=0.9854076, theta=-71.253163 -> V=1.0, theta=0.0
% INFO    : Bus 53596	: V=0.9762218, theta=-72.252651 -> V=1.0, theta=0.0
% INFO    : Bus 53597	: V=0.9876475, theta=-70.904122 -> V=1.0, theta=0.0
% INFO    : Bus 53598	: V=0.9805249, theta=-72.118974 -> V=1.0, theta=0.0
% INFO    : Bus 53599	: V=0.9873426, theta=-71.078793 -> V=1.0, theta=0.0
% INFO    : Bus 53600	: V=0.9849669, theta=-71.537701 -> V=1.0, theta=0.0
% INFO    : Bus 53601	: V=0.9932355, theta=-71.051331 -> V=1.0, theta=0.0
% INFO    : Bus 53602	: V=0.9809677, theta=-71.969439 -> V=1.0, theta=0.0
% INFO    : Bus 53603	: V=0.9932548, theta=-70.859799 -> V=1.0, theta=0.0
% INFO    : Bus 53604	: V=0.9893917, theta=-70.899882 -> V=1.0, theta=0.0
% INFO    : Bus 53605	: V=0.9797789, theta=-72.129703 -> V=1.0, theta=0.0
% INFO    : Bus 53606	: V=0.9919413, theta=-70.641531 -> V=1.0, theta=0.0
% INFO    : Bus 53607	: V=0.9933271, theta=-70.610333 -> V=1.0, theta=0.0
% INFO    : Bus 53608	: V=0.9985165, theta=-69.742445 -> V=1.0, theta=0.0
% INFO    : Bus 53609	: V=0.9830654, theta=-70.793529 -> V=1.0, theta=0.0
% INFO    : Bus 53610	: V=0.997328, theta=-69.438614 -> V=1.0, theta=0.0
% INFO    : Bus 53611	: V=1.0011688, theta=-69.111864 -> V=1.0, theta=0.0
% INFO    : Bus 53612	: V=1.0055825, theta=-68.767178 -> V=1.0, theta=0.0
% INFO    : Bus 53613	: V=0.9751154, theta=-72.423381 -> V=1.0, theta=0.0
% INFO    : Bus 53614	: V=0.9661507, theta=-73.51694 -> V=1.0, theta=0.0
% INFO    : Bus 53615	: V=0.9791738, theta=-72.068223 -> V=1.0, theta=0.0
% INFO    : Bus 53616	: V=0.9725982, theta=-72.691537 -> V=1.0, theta=0.0
% INFO    : Bus 53617	: V=0.9673251, theta=-73.20305 -> V=1.0, theta=0.0
% INFO    : Bus 53618	: V=0.9650831, theta=-73.338807 -> V=1.0, theta=0.0
% INFO    : Bus 53619	: V=0.9695319, theta=-72.806461 -> V=1.0, theta=0.0
% INFO    : Bus 53620	: V=0.9764037, theta=-72.595165 -> V=1.0, theta=0.0
% INFO    : Bus 53621	: V=0.970972, theta=-72.778078 -> V=1.0, theta=0.0
% INFO    : Bus 53622	: V=0.9848302, theta=-71.719734 -> V=1.0, theta=0.0
% INFO    : Bus 53623	: V=0.987874, theta=-71.624808 -> V=1.0, theta=0.0
% INFO    : Bus 53624	: V=0.9896964, theta=-71.890622 -> V=1.0, theta=0.0
% INFO    : Bus 53625	: V=0.9930428, theta=-71.399339 -> V=1.0, theta=0.0
% INFO    : Bus 53626	: V=0.9682408, theta=-72.368242 -> V=1.0, theta=0.0
% INFO    : Bus 53627	: V=0.9892787, theta=-71.654341 -> V=1.0, theta=0.0
% INFO    : Bus 53628	: V=0.9876156, theta=-71.743019 -> V=1.0, theta=0.0
% INFO    : Bus 53629	: V=0.9889997, theta=-71.866631 -> V=1.0, theta=0.0
% INFO    : Bus 53630	: V=0.9781876, theta=-72.403765 -> V=1.0, theta=0.0
% INFO    : Bus 53631	: V=0.9840289, theta=-71.92716 -> V=1.0, theta=0.0
% INFO    : Bus 53632	: V=0.9784236, theta=-72.525946 -> V=1.0, theta=0.0
% INFO    : Bus 53633	: V=0.9855613, theta=-71.853834 -> V=1.0, theta=0.0
% INFO    : Bus 53634	: V=0.9776894, theta=-72.518918 -> V=1.0, theta=0.0
% INFO    : Bus 53635	: V=0.9776218, theta=-72.550833 -> V=1.0, theta=0.0
% INFO    : Bus 53636	: V=0.9816811, theta=-72.358456 -> V=1.0, theta=0.0
% INFO    : Bus 53637	: V=0.967629, theta=-73.729092 -> V=1.0, theta=0.0
% INFO    : Bus 53638	: V=0.9562281, theta=-73.654411 -> V=1.0, theta=0.0
% INFO    : Bus 53639	: V=0.970464, theta=-71.98897 -> V=1.0, theta=0.0
% INFO    : Bus 53640	: V=0.9736957, theta=-71.542275 -> V=1.0, theta=0.0
% INFO    : Bus 53641	: V=0.9606806, theta=-73.050137 -> V=1.0, theta=0.0
% INFO    : Bus 53642	: V=0.9602803, theta=-74.160748 -> V=1.0, theta=0.0
% INFO    : Bus 53643	: V=0.9613631, theta=-74.0447 -> V=1.0, theta=0.0
% INFO    : Bus 53644	: V=0.9677321, theta=-73.221331 -> V=1.0, theta=0.0
% INFO    : Bus 53645	: V=0.9741568, theta=-72.611976 -> V=1.0, theta=0.0
% INFO    : Bus 53646	: V=0.9578701, theta=-74.418365 -> V=1.0, theta=0.0
% INFO    : Bus 53647	: V=0.9572983, theta=-74.442223 -> V=1.0, theta=0.0
% INFO    : Bus 53648	: V=0.9588171, theta=-74.309391 -> V=1.0, theta=0.0
% INFO    : Bus 53649	: V=0.9560017, theta=-74.542658 -> V=1.0, theta=0.0
% INFO    : Bus 53650	: V=0.9566826, theta=-74.514192 -> V=1.0, theta=0.0
% INFO    : Bus 53651	: V=0.968616, theta=-73.388433 -> V=1.0, theta=0.0
% INFO    : Bus 53652	: V=0.9735978, theta=-72.709941 -> V=1.0, theta=0.0
% INFO    : Bus 53653	: V=0.9732551, theta=-72.781756 -> V=1.0, theta=0.0
% INFO    : Bus 53654	: V=0.9659077, theta=-73.462138 -> V=1.0, theta=0.0
% INFO    : Bus 53655	: V=0.9710267, theta=-72.984454 -> V=1.0, theta=0.0
% INFO    : Bus 53656	: V=0.9696894, theta=-73.108501 -> V=1.0, theta=0.0
% INFO    : Bus 53657	: V=0.9689059, theta=-73.173578 -> V=1.0, theta=0.0
% INFO    : Bus 53658	: V=0.9649767, theta=-73.841587 -> V=1.0, theta=0.0
% INFO    : Bus 53659	: V=0.9729468, theta=-73.014809 -> V=1.0, theta=0.0
% INFO    : Bus 53660	: V=0.9659979, theta=-73.893047 -> V=1.0, theta=0.0
% INFO    : Bus 53661	: V=0.9743033, theta=-72.839995 -> V=1.0, theta=0.0
% INFO    : Bus 53662	: V=0.9593992, theta=-73.874703 -> V=1.0, theta=0.0
% INFO    : Bus 53663	: V=0.9617107, theta=-75.14004 -> V=1.0, theta=0.0
% INFO    : Bus 53664	: V=0.9967211, theta=-69.631368 -> V=1.0, theta=0.0
% INFO    : Bus 53665	: V=0.9611162, theta=-73.837563 -> V=1.0, theta=0.0
% INFO    : Bus 53666	: V=0.9621201, theta=-73.78482 -> V=1.0, theta=0.0
% INFO    : Bus 53667	: V=0.968824, theta=-73.636087 -> V=1.0, theta=0.0
% INFO    : Bus 53668	: V=0.9636075, theta=-74.630591 -> V=1.0, theta=0.0
% INFO    : Bus 53669	: V=0.9647941, theta=-74.007361 -> V=1.0, theta=0.0
% INFO    : Bus 53670	: V=0.9546688, theta=-75.808638 -> V=1.0, theta=0.0
% INFO    : Bus 53671	: V=0.955575, theta=-75.770561 -> V=1.0, theta=0.0
% INFO    : Bus 53672	: V=0.9550875, theta=-75.781979 -> V=1.0, theta=0.0
% INFO    : Bus 53673	: V=0.959424, theta=-75.049397 -> V=1.0, theta=0.0
% INFO    : Bus 53674	: V=0.9480554, theta=-76.778187 -> V=1.0, theta=0.0
% INFO    : Bus 53675	: V=0.9496548, theta=-76.65725 -> V=1.0, theta=0.0
% INFO    : Bus 53676	: V=0.9664654, theta=-74.431164 -> V=1.0, theta=0.0
% INFO    : Bus 53677	: V=0.9613315, theta=-74.922468 -> V=1.0, theta=0.0
% INFO    : Bus 53678	: V=0.9644221, theta=-74.642679 -> V=1.0, theta=0.0
% INFO    : Bus 53679	: V=0.9602635, theta=-74.949575 -> V=1.0, theta=0.0
% INFO    : Bus 53680	: V=0.9612085, theta=-75.206464 -> V=1.0, theta=0.0
% INFO    : Bus 53681	: V=0.954108, theta=-75.995584 -> V=1.0, theta=0.0
% INFO    : Bus 53682	: V=0.9557761, theta=-75.94816 -> V=1.0, theta=0.0
% INFO    : Bus 53683	: V=0.9562376, theta=-75.565495 -> V=1.0, theta=0.0
% INFO    : Bus 53684	: V=0.9466251, theta=-76.870156 -> V=1.0, theta=0.0
% INFO    : Bus 53685	: V=0.9462503, theta=-76.752672 -> V=1.0, theta=0.0
% INFO    : Bus 53686	: V=0.9478568, theta=-76.715759 -> V=1.0, theta=0.0
% INFO    : Bus 53687	: V=0.9443861, theta=-77.234673 -> V=1.0, theta=0.0
% INFO    : Bus 53688	: V=0.9465351, theta=-77.003687 -> V=1.0, theta=0.0
% INFO    : Bus 53689	: V=0.9590327, theta=-74.230176 -> V=1.0, theta=0.0
% INFO    : Bus 53690	: V=0.9586885, theta=-74.254493 -> V=1.0, theta=0.0
% INFO    : Bus 53691	: V=0.9582457, theta=-74.262248 -> V=1.0, theta=0.0
% INFO    : Bus 53692	: V=0.9582812, theta=-74.277902 -> V=1.0, theta=0.0
% INFO    : Bus 53693	: V=0.967416, theta=-73.29006 -> V=1.0, theta=0.0
% INFO    : Bus 53694	: V=0.9688893, theta=-73.176954 -> V=1.0, theta=0.0
% INFO    : Bus 53695	: V=0.9620058, theta=-74.307231 -> V=1.0, theta=0.0
% INFO    : Bus 53696	: V=0.9632118, theta=-74.165089 -> V=1.0, theta=0.0
% INFO    : Bus 53697	: V=0.9641724, theta=-74.036025 -> V=1.0, theta=0.0
% INFO    : Bus 53698	: V=0.9666216, theta=-73.35424 -> V=1.0, theta=0.0
% INFO    : Bus 53699	: V=0.957165, theta=-75.521527 -> V=1.0, theta=0.0
% INFO    : Bus 53700	: V=0.9620762, theta=-74.282254 -> V=1.0, theta=0.0
% INFO    : Bus 53701	: V=0.952966, theta=-75.835388 -> V=1.0, theta=0.0
% INFO    : Bus 53702	: V=0.9564407, theta=-75.633072 -> V=1.0, theta=0.0
% INFO    : Bus 53703	: V=0.965814, theta=-73.403653 -> V=1.0, theta=0.0
% INFO    : Bus 53704	: V=0.9653411, theta=-73.43355 -> V=1.0, theta=0.0
% INFO    : Bus 53705	: V=0.9654205, theta=-73.418732 -> V=1.0, theta=0.0
% INFO    : Bus 53706	: V=0.9597215, theta=-74.232947 -> V=1.0, theta=0.0
% INFO    : Bus 53707	: V=0.9531013, theta=-75.896808 -> V=1.0, theta=0.0
% INFO    : Bus 53708	: V=0.953269, theta=-75.878942 -> V=1.0, theta=0.0
% INFO    : Bus 53709	: V=0.953971, theta=-75.806393 -> V=1.0, theta=0.0
% INFO    : Bus 53710	: V=0.9518361, theta=-76.014096 -> V=1.0, theta=0.0
% INFO    : Bus 53711	: V=0.9514745, theta=-76.021951 -> V=1.0, theta=0.0
% INFO    : Bus 53712	: V=0.9500836, theta=-76.353849 -> V=1.0, theta=0.0
% INFO    : Bus 53713	: V=0.9506652, theta=-76.308581 -> V=1.0, theta=0.0
% INFO    : Bus 53714	: V=0.9519364, theta=-76.175091 -> V=1.0, theta=0.0
% INFO    : Bus 53715	: V=0.9613142, theta=-74.414698 -> V=1.0, theta=0.0
% INFO    : Bus 53716	: V=0.9548718, theta=-75.786011 -> V=1.0, theta=0.0
% INFO    : Bus 53717	: V=0.9600872, theta=-74.614114 -> V=1.0, theta=0.0
% INFO    : Bus 53718	: V=0.9546956, theta=-75.9125 -> V=1.0, theta=0.0
% INFO    : Bus 53719	: V=0.9550293, theta=-75.751377 -> V=1.0, theta=0.0
% INFO    : Bus 53720	: V=0.9614083, theta=-74.461838 -> V=1.0, theta=0.0
% INFO    : Bus 53721	: V=0.9622542, theta=-74.393729 -> V=1.0, theta=0.0
% INFO    : Bus 53722	: V=0.9652068, theta=-74.121796 -> V=1.0, theta=0.0
% INFO    : Bus 53723	: V=0.9591247, theta=-75.578903 -> V=1.0, theta=0.0
% INFO    : Bus 53724	: V=0.9509925, theta=-76.360632 -> V=1.0, theta=0.0
% INFO    : Bus 53725	: V=0.9625118, theta=-74.393914 -> V=1.0, theta=0.0
% INFO    : Bus 53726	: V=0.9636427, theta=-74.26875 -> V=1.0, theta=0.0
% INFO    : Bus 53727	: V=0.9511465, theta=-76.376144 -> V=1.0, theta=0.0
% INFO    : Bus 53728	: V=0.9518964, theta=-76.316821 -> V=1.0, theta=0.0
% INFO    : Bus 53729	: V=0.9532949, theta=-76.159802 -> V=1.0, theta=0.0
% INFO    : Bus 53730	: V=0.9532682, theta=-76.039629 -> V=1.0, theta=0.0
% INFO    : Bus 53731	: V=0.9490212, theta=-76.621453 -> V=1.0, theta=0.0
% INFO    : Bus 53732	: V=0.9490734, theta=-76.52817 -> V=1.0, theta=0.0
% INFO    : Bus 53733	: V=0.9499227, theta=-76.449531 -> V=1.0, theta=0.0
% INFO    : Bus 53734	: V=0.9492682, theta=-76.464156 -> V=1.0, theta=0.0
% INFO    : Bus 53735	: V=0.9491617, theta=-76.547426 -> V=1.0, theta=0.0
% INFO    : Bus 53736	: V=0.9486728, theta=-76.549741 -> V=1.0, theta=0.0
% INFO    : Bus 53737	: V=0.9483405, theta=-76.594015 -> V=1.0, theta=0.0
% INFO    : Bus 53738	: V=0.9568145, theta=-75.831215 -> V=1.0, theta=0.0
% INFO    : Bus 53739	: V=0.9477027, theta=-76.683656 -> V=1.0, theta=0.0
% INFO    : Bus 53740	: V=0.9550911, theta=-75.997099 -> V=1.0, theta=0.0
% INFO    : Bus 53741	: V=0.9492438, theta=-76.625263 -> V=1.0, theta=0.0
% INFO    : Bus 53742	: V=0.9477584, theta=-76.733781 -> V=1.0, theta=0.0
% INFO    : Bus 53743	: V=0.9509944, theta=-76.417054 -> V=1.0, theta=0.0
% INFO    : Bus 53744	: V=0.9499871, theta=-76.500708 -> V=1.0, theta=0.0
% INFO    : Bus 53745	: V=0.9597701, theta=-74.644038 -> V=1.0, theta=0.0
% INFO    : Bus 53746	: V=0.9532853, theta=-76.078338 -> V=1.0, theta=0.0
% INFO    : Bus 53747	: V=0.9515657, theta=-76.297685 -> V=1.0, theta=0.0
% INFO    : Bus 53748	: V=0.9525729, theta=-75.914027 -> V=1.0, theta=0.0
% INFO    : Bus 53749	: V=0.9542167, theta=-75.836975 -> V=1.0, theta=0.0
% INFO    : Bus 53750	: V=0.953997, theta=-75.812868 -> V=1.0, theta=0.0
% INFO    : Bus 53751	: V=0.961151, theta=-74.539463 -> V=1.0, theta=0.0
% INFO    : Bus 53752	: V=0.9538988, theta=-75.93549 -> V=1.0, theta=0.0
% INFO    : Bus 53753	: V=0.9535895, theta=-76.022242 -> V=1.0, theta=0.0
% INFO    : Bus 53754	: V=0.9617496, theta=-74.48608 -> V=1.0, theta=0.0
% INFO    : Bus 53755	: V=0.9728047, theta=-72.445301 -> V=1.0, theta=0.0
% INFO    : Bus 53756	: V=0.9529762, theta=-76.070144 -> V=1.0, theta=0.0
% INFO    : Bus 53757	: V=0.9525273, theta=-76.183619 -> V=1.0, theta=0.0
% INFO    : Bus 53758	: V=0.9526812, theta=-76.07982 -> V=1.0, theta=0.0
% INFO    : Bus 53759	: V=0.9536792, theta=-76.050905 -> V=1.0, theta=0.0
% INFO    : Bus 53760	: V=0.9510801, theta=-76.375853 -> V=1.0, theta=0.0
% INFO    : Bus 53761	: V=0.9523289, theta=-76.163691 -> V=1.0, theta=0.0
% INFO    : Bus 53762	: V=0.9526607, theta=-76.110823 -> V=1.0, theta=0.0
% INFO    : Bus 53763	: V=0.9484274, theta=-76.422025 -> V=1.0, theta=0.0
% INFO    : Bus 53764	: V=0.949803, theta=-76.50616 -> V=1.0, theta=0.0
% INFO    : Bus 53765	: V=0.952819, theta=-76.015688 -> V=1.0, theta=0.0
% INFO    : Bus 53766	: V=0.9510562, theta=-76.192211 -> V=1.0, theta=0.0
% INFO    : Bus 53767	: V=0.9460738, theta=-78.063135 -> V=1.0, theta=0.0
% INFO    : Bus 53768	: V=0.9482411, theta=-77.796195 -> V=1.0, theta=0.0
% INFO    : Bus 53769	: V=0.9452262, theta=-77.946158 -> V=1.0, theta=0.0
% INFO    : Bus 53770	: V=0.9447239, theta=-76.859302 -> V=1.0, theta=0.0
% INFO    : Bus 53771	: V=0.9466536, theta=-76.72084 -> V=1.0, theta=0.0
% INFO    : Bus 53772	: V=0.9693118, theta=-72.89833 -> V=1.0, theta=0.0
% INFO    : Bus 53773	: V=0.9620809, theta=-73.832858 -> V=1.0, theta=0.0
% INFO    : Bus 53774	: V=0.9606775, theta=-73.93055 -> V=1.0, theta=0.0
% INFO    : Bus 53775	: V=0.9607524, theta=-73.988205 -> V=1.0, theta=0.0
% INFO    : Bus 53776	: V=0.9614396, theta=-73.931502 -> V=1.0, theta=0.0
% INFO    : Bus 53777	: V=0.9676656, theta=-73.064573 -> V=1.0, theta=0.0
% INFO    : Bus 53778	: V=0.9594337, theta=-74.102219 -> V=1.0, theta=0.0
% INFO    : Bus 53779	: V=0.9589063, theta=-74.031052 -> V=1.0, theta=0.0
% INFO    : Bus 53780	: V=0.9601025, theta=-74.095125 -> V=1.0, theta=0.0
% INFO    : Bus 53781	: V=0.9594997, theta=-74.02507 -> V=1.0, theta=0.0
% INFO    : Bus 53782	: V=0.9599382, theta=-74.030206 -> V=1.0, theta=0.0
% INFO    : Bus 53783	: V=0.9563519, theta=-74.849773 -> V=1.0, theta=0.0
% INFO    : Bus 53784	: V=0.9583038, theta=-74.412687 -> V=1.0, theta=0.0
% INFO    : Bus 53785	: V=0.9604518, theta=-74.15817 -> V=1.0, theta=0.0
% INFO    : Bus 53786	: V=0.9568671, theta=-74.516925 -> V=1.0, theta=0.0
% INFO    : Bus 53787	: V=0.958854, theta=-74.033479 -> V=1.0, theta=0.0
% INFO    : Bus 53788	: V=0.9598943, theta=-74.12653 -> V=1.0, theta=0.0
% INFO    : Bus 53789	: V=0.9551554, theta=-74.904677 -> V=1.0, theta=0.0
% INFO    : Bus 53790	: V=0.9555808, theta=-74.550648 -> V=1.0, theta=0.0
% INFO    : Bus 53791	: V=0.9555107, theta=-74.894053 -> V=1.0, theta=0.0
% INFO    : Bus 53792	: V=0.9563557, theta=-74.870122 -> V=1.0, theta=0.0
% INFO    : Bus 53793	: V=0.9607708, theta=-74.325036 -> V=1.0, theta=0.0
% INFO    : Bus 53794	: V=0.9580987, theta=-74.715637 -> V=1.0, theta=0.0
% INFO    : Bus 53795	: V=0.949725, theta=-76.339298 -> V=1.0, theta=0.0
% INFO    : Bus 53796	: V=0.9479269, theta=-75.869396 -> V=1.0, theta=0.0
% INFO    : Bus 53797	: V=0.9523213, theta=-75.853632 -> V=1.0, theta=0.0
% INFO    : Bus 53798	: V=0.9517596, theta=-75.971932 -> V=1.0, theta=0.0
% INFO    : Bus 53799	: V=0.9529535, theta=-75.826985 -> V=1.0, theta=0.0
% INFO    : Bus 53800	: V=0.953445, theta=-75.625234 -> V=1.0, theta=0.0
% INFO    : Bus 53801	: V=0.9484221, theta=-76.376926 -> V=1.0, theta=0.0
% INFO    : Bus 53802	: V=0.9486705, theta=-76.416555 -> V=1.0, theta=0.0
% INFO    : Bus 53803	: V=0.952746, theta=-75.905155 -> V=1.0, theta=0.0
% INFO    : Bus 53804	: V=0.9487513, theta=-76.367834 -> V=1.0, theta=0.0
% INFO    : Bus 53805	: V=0.9497167, theta=-76.374279 -> V=1.0, theta=0.0
% INFO    : Bus 53806	: V=0.9494536, theta=-76.382158 -> V=1.0, theta=0.0
% INFO    : Bus 53807	: V=0.9517888, theta=-75.472715 -> V=1.0, theta=0.0
% INFO    : Bus 53808	: V=0.9496902, theta=-75.749774 -> V=1.0, theta=0.0
% INFO    : Bus 53809	: V=0.9445623, theta=-76.018244 -> V=1.0, theta=0.0
% INFO    : Bus 53810	: V=0.9463815, theta=-76.047585 -> V=1.0, theta=0.0
% INFO    : Bus 53811	: V=0.9507144, theta=-76.244632 -> V=1.0, theta=0.0
% INFO    : Bus 53812	: V=0.9509462, theta=-75.366271 -> V=1.0, theta=0.0
% INFO    : Bus 53813	: V=0.9425455, theta=-76.15378 -> V=1.0, theta=0.0
% INFO    : Bus 53814	: V=0.9497083, theta=-75.432826 -> V=1.0, theta=0.0
% INFO    : Bus 53815	: V=0.9571362, theta=-74.769065 -> V=1.0, theta=0.0
% INFO    : Bus 53816	: V=0.9499005, theta=-75.508613 -> V=1.0, theta=0.0
% INFO    : Bus 53817	: V=0.956887, theta=-74.777137 -> V=1.0, theta=0.0
% INFO    : Bus 53818	: V=0.942954, theta=-76.128989 -> V=1.0, theta=0.0
% INFO    : Bus 53819	: V=0.9492779, theta=-75.693456 -> V=1.0, theta=0.0
% INFO    : Bus 53820	: V=0.9490261, theta=-75.741357 -> V=1.0, theta=0.0
% INFO    : Bus 53821	: V=0.9489263, theta=-75.578862 -> V=1.0, theta=0.0
% INFO    : Bus 53822	: V=0.9611153, theta=-74.038447 -> V=1.0, theta=0.0
% INFO    : Bus 53823	: V=0.9658901, theta=-73.371046 -> V=1.0, theta=0.0
% INFO    : Bus 53824	: V=0.9781451, theta=-71.992039 -> V=1.0, theta=0.0
% INFO    : Bus 53825	: V=0.9950094, theta=-70.225424 -> V=1.0, theta=0.0
% INFO    : Bus 53826	: V=0.9641078, theta=-73.563941 -> V=1.0, theta=0.0
% INFO    : Bus 53827	: V=0.9985852, theta=-69.337042 -> V=1.0, theta=0.0
% INFO    : Bus 53828	: V=0.9728808, theta=-72.717086 -> V=1.0, theta=0.0
% INFO    : Bus 53829	: V=0.9788573, theta=-72.527213 -> V=1.0, theta=0.0
% INFO    : Bus 53830	: V=0.9798175, theta=-71.386559 -> V=1.0, theta=0.0
% INFO    : Bus 53831	: V=0.9466542, theta=-76.722957 -> V=1.0, theta=0.0
% INFO    : Bus 53832	: V=1.0009554, theta=-69.178121 -> V=1.0, theta=0.0
% INFO    : Bus 53833	: V=0.9945211, theta=-69.187138 -> V=1.0, theta=0.0
% INFO    : Bus 53834	: V=0.9629979, theta=-72.562493 -> V=1.0, theta=0.0
% INFO    : Bus 53835	: V=1.015959, theta=-53.563843 -> V=1.0, theta=0.0
% INFO    : Bus 53836	: V=0.994703, theta=-65.91033 -> V=1.0, theta=0.0
% INFO    : Bus 53837	: V=0.9921632, theta=-66.541235 -> V=1.0, theta=0.0
% INFO    : Bus 53838	: V=0.997775, theta=-66.574559 -> V=1.0, theta=0.0
% INFO    : Bus 53839	: V=0.9988376, theta=-65.56007 -> V=1.0, theta=0.0
% INFO    : Bus 53840	: V=0.9834951, theta=-67.278036 -> V=1.0, theta=0.0
% INFO    : Bus 53841	: V=1.0098179, theta=-66.517268 -> V=1.0, theta=0.0
% INFO    : Bus 53842	: V=0.9773831, theta=-68.178258 -> V=1.0, theta=0.0
% INFO    : Bus 53843	: V=0.9502357, theta=-56.560614 -> V=1.0, theta=0.0
% INFO    : Bus 53844	: V=0.9802545, theta=-52.313905 -> V=1.0, theta=0.0
% INFO    : Bus 53845	: V=0.9531892, theta=-56.289905 -> V=1.0, theta=0.0
% INFO    : Bus 53846	: V=0.9537882, theta=-56.191572 -> V=1.0, theta=0.0
% INFO    : Bus 53847	: V=0.9514185, theta=-56.474143 -> V=1.0, theta=0.0
% INFO    : Bus 53848	: V=0.9548675, theta=-56.167481 -> V=1.0, theta=0.0
% INFO    : Bus 53849	: V=0.958716, theta=-55.663466 -> V=1.0, theta=0.0
% INFO    : Bus 53850	: V=0.9755022, theta=-52.642703 -> V=1.0, theta=0.0
% INFO    : Bus 53851	: V=0.9595293, theta=-55.59267 -> V=1.0, theta=0.0
% INFO    : Bus 53852	: V=0.9803635, theta=-52.631854 -> V=1.0, theta=0.0
% INFO    : Bus 53853	: V=0.9585648, theta=-55.611234 -> V=1.0, theta=0.0
% INFO    : Bus 53854	: V=0.9843568, theta=-49.394012 -> V=1.0, theta=0.0
% INFO    : Bus 53855	: V=0.9695679, theta=-55.882463 -> V=1.0, theta=0.0
% INFO    : Bus 53856	: V=0.9692498, theta=-55.881135 -> V=1.0, theta=0.0
% INFO    : Bus 53857	: V=0.9861496, theta=-52.127925 -> V=1.0, theta=0.0
% INFO    : Bus 53858	: V=0.9845067, theta=-50.593945 -> V=1.0, theta=0.0
% INFO    : Bus 53859	: V=0.9858552, theta=-50.031459 -> V=1.0, theta=0.0
% INFO    : Bus 53860	: V=0.9931521, theta=-52.991097 -> V=1.0, theta=0.0
% INFO    : Bus 53861	: V=0.9440269, theta=-80.125112 -> V=1.0, theta=0.0
% INFO    : Bus 53862	: V=0.9618199, theta=-76.628182 -> V=1.0, theta=0.0
% INFO    : Bus 53863	: V=0.9622254, theta=-76.672333 -> V=1.0, theta=0.0
% INFO    : Bus 53864	: V=0.9618425, theta=-76.760208 -> V=1.0, theta=0.0
% INFO    : Bus 53865	: V=0.9617889, theta=-76.461769 -> V=1.0, theta=0.0
% INFO    : Bus 53866	: V=0.9531394, theta=-76.649378 -> V=1.0, theta=0.0
% INFO    : Bus 53867	: V=0.9779502, theta=-73.525015 -> V=1.0, theta=0.0
% INFO    : Bus 53868	: V=0.9713009, theta=-74.676385 -> V=1.0, theta=0.0
% INFO    : Bus 53869	: V=0.9585505, theta=-75.313576 -> V=1.0, theta=0.0
% INFO    : Bus 53870	: V=0.9507745, theta=-78.135724 -> V=1.0, theta=0.0
% INFO    : Bus 53871	: V=0.9494745, theta=-78.181904 -> V=1.0, theta=0.0
% INFO    : Bus 53872	: V=0.9639367, theta=-76.36057 -> V=1.0, theta=0.0
% INFO    : Bus 53873	: V=0.9672308, theta=-75.789031 -> V=1.0, theta=0.0
% INFO    : Bus 53874	: V=0.9732256, theta=-75.508771 -> V=1.0, theta=0.0
% INFO    : Bus 53875	: V=0.9759026, theta=-75.435237 -> V=1.0, theta=0.0
% INFO    : Bus 53876	: V=0.9662605, theta=-75.530705 -> V=1.0, theta=0.0
% INFO    : Bus 53877	: V=0.9741371, theta=-75.541959 -> V=1.0, theta=0.0
% INFO    : Bus 53878	: V=0.9694019, theta=-75.288574 -> V=1.0, theta=0.0
% INFO    : Bus 53879	: V=0.9725484, theta=-74.53489 -> V=1.0, theta=0.0
% INFO    : Bus 53880	: V=0.9944631, theta=-73.624687 -> V=1.0, theta=0.0
% INFO    : Bus 53881	: V=0.9967767, theta=-73.3819 -> V=1.0, theta=0.0
% INFO    : Bus 53882	: V=1.0012913, theta=-72.584373 -> V=1.0, theta=0.0
% INFO    : Bus 53883	: V=0.9772708, theta=-73.523128 -> V=1.0, theta=0.0
% INFO    : Bus 53884	: V=0.9867408, theta=-71.817332 -> V=1.0, theta=0.0
% INFO    : Bus 53885	: V=1.0160166, theta=-65.670397 -> V=1.0, theta=0.0
% INFO    : Bus 53886	: V=1.0000149, theta=-69.534472 -> V=1.0, theta=0.0
% INFO    : Bus 53887	: V=0.9947265, theta=-71.183771 -> V=1.0, theta=0.0
% INFO    : Bus 53888	: V=0.998099, theta=-70.243172 -> V=1.0, theta=0.0
% INFO    : Bus 53889	: V=0.995878, theta=-71.645698 -> V=1.0, theta=0.0
% INFO    : Bus 53890	: V=1.003117, theta=-68.966805 -> V=1.0, theta=0.0
% INFO    : Bus 53891	: V=0.9939128, theta=-68.198869 -> V=1.0, theta=0.0
% INFO    : Bus 53892	: V=1.0150833, theta=-64.831122 -> V=1.0, theta=0.0
% INFO    : Bus 53893	: V=1.0088662, theta=-66.049343 -> V=1.0, theta=0.0
% INFO    : Bus 53894	: V=1.0053781, theta=-67.502401 -> V=1.0, theta=0.0
% INFO    : Bus 53895	: V=1.0102207, theta=-68.222763 -> V=1.0, theta=0.0
% INFO    : Bus 53896	: V=1.0022436, theta=-69.714716 -> V=1.0, theta=0.0
% INFO    : Bus 53897	: V=1.0064193, theta=-69.254106 -> V=1.0, theta=0.0
% INFO    : Bus 53898	: V=1.0071363, theta=-68.546132 -> V=1.0, theta=0.0
% INFO    : Bus 53899	: V=1.0070523, theta=-68.311906 -> V=1.0, theta=0.0
% INFO    : Bus 53900	: V=1.007223, theta=-68.782957 -> V=1.0, theta=0.0
% INFO    : Bus 53901	: V=0.998521, theta=-70.063338 -> V=1.0, theta=0.0
% INFO    : Bus 53902	: V=0.9972729, theta=-70.146646 -> V=1.0, theta=0.0
% INFO    : Bus 53903	: V=1.0049835, theta=-69.74177 -> V=1.0, theta=0.0
% INFO    : Bus 53904	: V=1.007149, theta=-69.332736 -> V=1.0, theta=0.0
% INFO    : Bus 53905	: V=0.9956163, theta=-70.216836 -> V=1.0, theta=0.0
% INFO    : Bus 53906	: V=0.9207331, theta=-81.04675 -> V=1.0, theta=0.0
% INFO    : Bus 53907	: V=1.0120289, theta=-68.911597 -> V=1.0, theta=0.0
% INFO    : Bus 53908	: V=1.0001794, theta=-70.291391 -> V=1.0, theta=0.0
% INFO    : Bus 53909	: V=0.9959071, theta=-69.935535 -> V=1.0, theta=0.0
% INFO    : Bus 53910	: V=1.0068557, theta=-66.516382 -> V=1.0, theta=0.0
% INFO    : Bus 53911	: V=1.0130425, theta=-69.321905 -> V=1.0, theta=0.0
% INFO    : Bus 53912	: V=1.013451, theta=-69.233349 -> V=1.0, theta=0.0
% INFO    : Bus 53913	: V=1.0114415, theta=-69.236838 -> V=1.0, theta=0.0
% INFO    : Bus 53914	: V=1.0025776, theta=-71.071486 -> V=1.0, theta=0.0
% INFO    : Bus 53915	: V=1.0131269, theta=-70.041163 -> V=1.0, theta=0.0
% INFO    : Bus 53916	: V=1.0127069, theta=-69.48741 -> V=1.0, theta=0.0
% INFO    : Bus 53917	: V=1.0109928, theta=-70.206714 -> V=1.0, theta=0.0
% INFO    : Bus 53918	: V=1.0116229, theta=-70.178184 -> V=1.0, theta=0.0
% INFO    : Bus 53919	: V=1.0114376, theta=-70.231139 -> V=1.0, theta=0.0
% INFO    : Bus 53920	: V=1.0114089, theta=-70.272459 -> V=1.0, theta=0.0
% INFO    : Bus 53921	: V=1.0106268, theta=-70.251117 -> V=1.0, theta=0.0
% INFO    : Bus 53922	: V=1.0104323, theta=-70.281517 -> V=1.0, theta=0.0
% INFO    : Bus 53923	: V=1.0110222, theta=-70.305089 -> V=1.0, theta=0.0
% INFO    : Bus 53924	: V=1.0096585, theta=-70.384477 -> V=1.0, theta=0.0
% INFO    : Bus 53925	: V=0.9919712, theta=-71.853141 -> V=1.0, theta=0.0
% INFO    : Bus 53926	: V=1.0079932, theta=-70.43626 -> V=1.0, theta=0.0
% INFO    : Bus 53927	: V=0.998921, theta=-71.155985 -> V=1.0, theta=0.0
% INFO    : Bus 53928	: V=1.0074525, theta=-70.469715 -> V=1.0, theta=0.0
% INFO    : Bus 53929	: V=1.0086417, theta=-70.429786 -> V=1.0, theta=0.0
% INFO    : Bus 53930	: V=1.0071436, theta=-70.490389 -> V=1.0, theta=0.0
% INFO    : Bus 53931	: V=1.0064736, theta=-70.510294 -> V=1.0, theta=0.0
% INFO    : Bus 53932	: V=1.0067422, theta=-70.503548 -> V=1.0, theta=0.0
% INFO    : Bus 53933	: V=0.9980834, theta=-71.231876 -> V=1.0, theta=0.0
% INFO    : Bus 53934	: V=1.0069317, theta=-70.49015 -> V=1.0, theta=0.0
% INFO    : Bus 53935	: V=0.9984047, theta=-71.110879 -> V=1.0, theta=0.0
% INFO    : Bus 53936	: V=1.0064656, theta=-70.499616 -> V=1.0, theta=0.0
% INFO    : Bus 53937	: V=0.9986448, theta=-71.129709 -> V=1.0, theta=0.0
% INFO    : Bus 53938	: V=0.998483, theta=-71.113765 -> V=1.0, theta=0.0
% INFO    : Bus 53939	: V=1.0091049, theta=-70.368921 -> V=1.0, theta=0.0
% INFO    : Bus 53940	: V=1.0075776, theta=-70.431222 -> V=1.0, theta=0.0
% INFO    : Bus 53941	: V=1.0083005, theta=-70.339562 -> V=1.0, theta=0.0
% INFO    : Bus 53942	: V=1.0053573, theta=-70.546277 -> V=1.0, theta=0.0
% INFO    : Bus 53943	: V=1.0051763, theta=-70.548272 -> V=1.0, theta=0.0
% INFO    : Bus 53944	: V=0.9981806, theta=-70.767127 -> V=1.0, theta=0.0
% INFO    : Bus 53945	: V=1.0132107, theta=-69.94823 -> V=1.0, theta=0.0
% INFO    : Bus 53946	: V=1.0112301, theta=-70.19623 -> V=1.0, theta=0.0
% INFO    : Bus 53947	: V=1.0093306, theta=-70.422639 -> V=1.0, theta=0.0
% INFO    : Bus 53948	: V=1.008761, theta=-70.421951 -> V=1.0, theta=0.0
% INFO    : Bus 53949	: V=0.9948599, theta=-71.2503 -> V=1.0, theta=0.0
% INFO    : Bus 53950	: V=0.9926451, theta=-71.278119 -> V=1.0, theta=0.0
% INFO    : Bus 53951	: V=1.0076864, theta=-70.468529 -> V=1.0, theta=0.0
% INFO    : Bus 53952	: V=1.0001182, theta=-71.187429 -> V=1.0, theta=0.0
% INFO    : Bus 53953	: V=0.9701346, theta=-64.921942 -> V=1.0, theta=0.0
% INFO    : Bus 53954	: V=0.9675665, theta=-65.94256 -> V=1.0, theta=0.0
% INFO    : Bus 53955	: V=0.9613944, theta=-66.631145 -> V=1.0, theta=0.0
% INFO    : Bus 53956	: V=0.9841453, theta=-59.629691 -> V=1.0, theta=0.0
% INFO    : Bus 53957	: V=0.9870161, theta=-63.119543 -> V=1.0, theta=0.0
% INFO    : Bus 53958	: V=0.9864037, theta=-62.757997 -> V=1.0, theta=0.0
% INFO    : Bus 53959	: V=1.0061271, theta=-54.927781 -> V=1.0, theta=0.0
% INFO    : Bus 53960	: V=1.0117071, theta=-52.446111 -> V=1.0, theta=0.0
% INFO    : Bus 53961	: V=1.0009249, theta=-55.860806 -> V=1.0, theta=0.0
% INFO    : Bus 53962	: V=0.9985571, theta=-53.642583 -> V=1.0, theta=0.0
% INFO    : Bus 53963	: V=1.0048715, theta=-54.30115 -> V=1.0, theta=0.0
% INFO    : Bus 53964	: V=1.0097228, theta=-53.892635 -> V=1.0, theta=0.0
% INFO    : Bus 53965	: V=1.0097501, theta=-53.985118 -> V=1.0, theta=0.0
% INFO    : Bus 53966	: V=1.007736, theta=-54.213344 -> V=1.0, theta=0.0
% INFO    : Bus 53967	: V=1.0082373, theta=-54.199113 -> V=1.0, theta=0.0
% INFO    : Bus 53968	: V=1.0096072, theta=-54.08478 -> V=1.0, theta=0.0
% INFO    : Bus 53969	: V=1.0099581, theta=-53.679913 -> V=1.0, theta=0.0
% INFO    : Bus 53970	: V=0.9981062, theta=-54.902914 -> V=1.0, theta=0.0
% INFO    : Bus 53971	: V=1.008642, theta=-69.538142 -> V=1.0, theta=0.0
% INFO    : Bus 53972	: V=1.0052028, theta=-69.13321 -> V=1.0, theta=0.0
% INFO    : Bus 53973	: V=1.0056465, theta=-69.088249 -> V=1.0, theta=0.0
% INFO    : Bus 53974	: V=0.9858515, theta=-71.120874 -> V=1.0, theta=0.0
% INFO    : Bus 53975	: V=1.0084763, theta=-68.482588 -> V=1.0, theta=0.0
% INFO    : Bus 53976	: V=0.9757636, theta=-69.04594 -> V=1.0, theta=0.0
% INFO    : Bus 53977	: V=0.980257, theta=-67.840123 -> V=1.0, theta=0.0
% INFO    : Bus 53978	: V=0.9850699, theta=-68.780661 -> V=1.0, theta=0.0
% INFO    : Bus 53979	: V=0.9855299, theta=-68.480299 -> V=1.0, theta=0.0
% INFO    : Bus 53980	: V=1.0182942, theta=-67.00058 -> V=1.0, theta=0.0
% INFO    : Bus 53981	: V=1.0020292, theta=-67.671976 -> V=1.0, theta=0.0
% INFO    : Bus 53982	: V=0.9977631, theta=-68.86971 -> V=1.0, theta=0.0
% INFO    : Bus 53983	: V=0.9907829, theta=-69.619528 -> V=1.0, theta=0.0
% INFO    : Bus 53984	: V=0.9511188, theta=-73.990813 -> V=1.0, theta=0.0
% INFO    : Bus 53985	: V=0.944955, theta=-74.398347 -> V=1.0, theta=0.0
% INFO    : Bus 53986	: V=0.9506417, theta=-74.258984 -> V=1.0, theta=0.0
% INFO    : Bus 53987	: V=0.9487096, theta=-74.321526 -> V=1.0, theta=0.0
% INFO    : Bus 53988	: V=0.9484489, theta=-74.273685 -> V=1.0, theta=0.0
% INFO    : Bus 53989	: V=0.9623859, theta=-72.965519 -> V=1.0, theta=0.0
% INFO    : Bus 53990	: V=0.9531854, theta=-73.33782 -> V=1.0, theta=0.0
% INFO    : Bus 53991	: V=0.9608861, theta=-72.877503 -> V=1.0, theta=0.0
% INFO    : Bus 53992	: V=1.0088734, theta=-62.050462 -> V=1.0, theta=0.0
% INFO    : Bus 53993	: V=1.0117063, theta=-61.812335 -> V=1.0, theta=0.0
% INFO    : Bus 53994	: V=1.01619, theta=-60.873847 -> V=1.0, theta=0.0
% INFO    : Bus 53995	: V=1.0161207, theta=-61.008225 -> V=1.0, theta=0.0
% INFO    : Bus 53996	: V=1.001612, theta=-63.562965 -> V=1.0, theta=0.0
% INFO    : Bus 53997	: V=1.0168726, theta=-50.066177 -> V=1.0, theta=0.0
% INFO    : Bus 53998	: V=1.0122231, theta=-49.63382 -> V=1.0, theta=0.0
% INFO    : Bus 53999	: V=1.0166458, theta=-51.807851 -> V=1.0, theta=0.0
% INFO    : Bus 54000	: V=0.9771935, theta=-71.266887 -> V=1.0, theta=0.0
% INFO    : Bus 54001	: V=0.9815452, theta=-66.535971 -> V=1.0, theta=0.0
% INFO    : Bus 54002	: V=0.9847079, theta=-66.344109 -> V=1.0, theta=0.0
% INFO    : Bus 54003	: V=0.9835958, theta=-66.122414 -> V=1.0, theta=0.0
% INFO    : Bus 54004	: V=0.9575108, theta=-68.655227 -> V=1.0, theta=0.0
% INFO    : Bus 54005	: V=0.9820915, theta=-66.399899 -> V=1.0, theta=0.0
% INFO    : Bus 54006	: V=0.9601405, theta=-68.845982 -> V=1.0, theta=0.0
% INFO    : Bus 54007	: V=0.9820219, theta=-66.481662 -> V=1.0, theta=0.0
% INFO    : Bus 54008	: V=0.9604165, theta=-68.84034 -> V=1.0, theta=0.0
% INFO    : Bus 54009	: V=0.9602933, theta=-68.866775 -> V=1.0, theta=0.0
% INFO    : Bus 54010	: V=0.9610629, theta=-68.857316 -> V=1.0, theta=0.0
% INFO    : Bus 54011	: V=1.002179, theta=-63.38433 -> V=1.0, theta=0.0
% INFO    : Bus 54012	: V=0.9828693, theta=-66.512827 -> V=1.0, theta=0.0
% INFO    : Bus 54013	: V=0.9605799, theta=-68.831731 -> V=1.0, theta=0.0
% INFO    : Bus 54014	: V=0.9837934, theta=-66.487731 -> V=1.0, theta=0.0
% INFO    : Bus 54015	: V=0.9850969, theta=-66.449874 -> V=1.0, theta=0.0
% INFO    : Bus 54016	: V=0.9865446, theta=-66.405463 -> V=1.0, theta=0.0
% INFO    : Bus 54017	: V=0.9883338, theta=-66.344633 -> V=1.0, theta=0.0
% INFO    : Bus 54018	: V=0.9840275, theta=-66.581778 -> V=1.0, theta=0.0
% INFO    : Bus 54019	: V=0.9729479, theta=-67.918578 -> V=1.0, theta=0.0
% INFO    : Bus 54020	: V=0.9717572, theta=-67.969735 -> V=1.0, theta=0.0
% INFO    : Bus 54021	: V=0.9886475, theta=-66.57469 -> V=1.0, theta=0.0
% INFO    : Bus 54022	: V=0.9815813, theta=-66.892861 -> V=1.0, theta=0.0
% INFO    : Bus 54023	: V=0.9797072, theta=-67.009681 -> V=1.0, theta=0.0
% INFO    : Bus 54024	: V=0.9747004, theta=-66.969392 -> V=1.0, theta=0.0
% INFO    : Bus 54025	: V=0.9743134, theta=-66.983563 -> V=1.0, theta=0.0
% INFO    : Bus 54026	: V=0.9646687, theta=-67.507331 -> V=1.0, theta=0.0
% INFO    : Bus 54027	: V=0.9578787, theta=-68.945099 -> V=1.0, theta=0.0
% INFO    : Bus 54028	: V=0.9722307, theta=-67.338309 -> V=1.0, theta=0.0
% INFO    : Bus 54029	: V=0.9720308, theta=-67.962932 -> V=1.0, theta=0.0
% INFO    : Bus 54030	: V=0.9667112, theta=-68.088787 -> V=1.0, theta=0.0
% INFO    : Bus 54031	: V=0.9843298, theta=-70.197005 -> V=1.0, theta=0.0
% INFO    : Bus 54032	: V=0.9764612, theta=-70.676766 -> V=1.0, theta=0.0
% INFO    : Bus 54033	: V=0.9741325, theta=-72.376624 -> V=1.0, theta=0.0
% INFO    : Bus 54034	: V=0.9733982, theta=-72.46225 -> V=1.0, theta=0.0
% INFO    : Bus 54035	: V=0.9918599, theta=-70.963486 -> V=1.0, theta=0.0
% INFO    : Bus 54036	: V=0.9890047, theta=-71.147382 -> V=1.0, theta=0.0
% INFO    : Bus 54037	: V=0.9992191, theta=-71.020173 -> V=1.0, theta=0.0
% INFO    : Bus 54038	: V=0.9951925, theta=-68.031672 -> V=1.0, theta=0.0
% INFO    : Bus 54039	: V=0.999365, theta=-68.667515 -> V=1.0, theta=0.0
% INFO    : Bus 54040	: V=0.9976579, theta=-70.73125 -> V=1.0, theta=0.0
% INFO    : Bus 54041	: V=0.9973414, theta=-70.50151 -> V=1.0, theta=0.0
% INFO    : Bus 54042	: V=0.9886437, theta=-70.426166 -> V=1.0, theta=0.0
% INFO    : Bus 54043	: V=0.9954703, theta=-72.312445 -> V=1.0, theta=0.0
% INFO    : Bus 54044	: V=0.9882417, theta=-72.455753 -> V=1.0, theta=0.0
% INFO    : Bus 54045	: V=0.9879199, theta=-72.503784 -> V=1.0, theta=0.0
% INFO    : Bus 54046	: V=0.9960497, theta=-72.306279 -> V=1.0, theta=0.0
% INFO    : Bus 54047	: V=0.9846884, theta=-70.217779 -> V=1.0, theta=0.0
% INFO    : Bus 54048	: V=1.006644, theta=-71.192401 -> V=1.0, theta=0.0
% INFO    : Bus 54049	: V=1.0028768, theta=-71.747879 -> V=1.0, theta=0.0
% INFO    : Bus 54050	: V=1.0001458, theta=-72.063647 -> V=1.0, theta=0.0
% INFO    : Bus 54051	: V=1.0010434, theta=-72.018838 -> V=1.0, theta=0.0
% INFO    : Bus 54052	: V=1.0023692, theta=-71.924838 -> V=1.0, theta=0.0
% INFO    : Bus 54053	: V=0.9962458, theta=-72.256784 -> V=1.0, theta=0.0
% INFO    : Bus 54054	: V=0.9986951, theta=-72.170399 -> V=1.0, theta=0.0
% INFO    : Bus 54055	: V=0.9986269, theta=-72.17714 -> V=1.0, theta=0.0
% INFO    : Bus 54056	: V=0.9939571, theta=-72.274118 -> V=1.0, theta=0.0
% INFO    : Bus 54057	: V=0.9922569, theta=-72.468869 -> V=1.0, theta=0.0
% INFO    : Bus 54058	: V=0.9940048, theta=-72.382464 -> V=1.0, theta=0.0
% INFO    : Bus 54059	: V=0.9925373, theta=-72.456002 -> V=1.0, theta=0.0
% INFO    : Bus 54060	: V=0.9928452, theta=-72.370866 -> V=1.0, theta=0.0
% INFO    : Bus 54061	: V=0.9952942, theta=-72.363859 -> V=1.0, theta=0.0
% INFO    : Bus 54062	: V=0.9923236, theta=-72.619482 -> V=1.0, theta=0.0
% INFO    : Bus 54063	: V=0.9918831, theta=-72.639097 -> V=1.0, theta=0.0
% INFO    : Bus 54064	: V=0.9993133, theta=-72.212126 -> V=1.0, theta=0.0
% INFO    : Bus 54065	: V=0.9918147, theta=-72.677442 -> V=1.0, theta=0.0
% INFO    : Bus 54066	: V=0.9914612, theta=-72.693497 -> V=1.0, theta=0.0
% INFO    : Bus 54067	: V=1.0006613, theta=-72.049042 -> V=1.0, theta=0.0
% INFO    : Bus 54068	: V=1.0003417, theta=-72.096105 -> V=1.0, theta=0.0
% INFO    : Bus 54069	: V=1.0035839, theta=-71.821633 -> V=1.0, theta=0.0
% INFO    : Bus 54070	: V=1.0056746, theta=-71.343565 -> V=1.0, theta=0.0
% INFO    : Bus 54071	: V=1.0169076, theta=-69.114667 -> V=1.0, theta=0.0
% INFO    : Bus 54072	: V=1.0022674, theta=-71.949141 -> V=1.0, theta=0.0
% INFO    : Bus 54073	: V=1.0001944, theta=-72.150238 -> V=1.0, theta=0.0
% INFO    : Bus 54074	: V=0.9951853, theta=-72.410415 -> V=1.0, theta=0.0
% INFO    : Bus 54075	: V=0.9979542, theta=-72.289766 -> V=1.0, theta=0.0
% INFO    : Bus 54076	: V=0.9956792, theta=-72.413795 -> V=1.0, theta=0.0
% INFO    : Bus 54077	: V=0.9997773, theta=-72.190876 -> V=1.0, theta=0.0
% INFO    : Bus 54078	: V=1.0047926, theta=-71.680515 -> V=1.0, theta=0.0
% INFO    : Bus 54079	: V=0.9905611, theta=-72.943911 -> V=1.0, theta=0.0
% INFO    : Bus 54080	: V=0.9863592, theta=-73.220806 -> V=1.0, theta=0.0
% INFO    : Bus 54081	: V=0.9934877, theta=-72.509301 -> V=1.0, theta=0.0
% INFO    : Bus 54082	: V=0.9890682, theta=-72.332415 -> V=1.0, theta=0.0
% INFO    : Bus 54083	: V=0.9969399, theta=-72.238717 -> V=1.0, theta=0.0
% INFO    : Bus 54084	: V=0.987919, theta=-66.138781 -> V=1.0, theta=0.0
% INFO    : Bus 54085	: V=0.9923581, theta=-72.552316 -> V=1.0, theta=0.0
% INFO    : Bus 54086	: V=1.0103863, theta=-56.64567 -> V=1.0, theta=0.0
% INFO    : Bus 54087	: V=1.0109833, theta=-56.574761 -> V=1.0, theta=0.0
% INFO    : Bus 54088	: V=1.0191075, theta=-54.727975 -> V=1.0, theta=0.0
% INFO    : Bus 54089	: V=1.0077045, theta=-57.278493 -> V=1.0, theta=0.0
% INFO    : Bus 54090	: V=1.0130237, theta=-56.840553 -> V=1.0, theta=0.0
% INFO    : Bus 54091	: V=0.9873445, theta=-54.336438 -> V=1.0, theta=0.0
% INFO    : Bus 54092	: V=0.9767284, theta=-55.637335 -> V=1.0, theta=0.0
% INFO    : Bus 54093	: V=0.9841227, theta=-54.780497 -> V=1.0, theta=0.0
% INFO    : Bus 54094	: V=0.988371, theta=-54.347701 -> V=1.0, theta=0.0
% INFO    : Bus 54095	: V=0.9786021, theta=-56.295954 -> V=1.0, theta=0.0
% INFO    : Bus 54096	: V=0.9982723, theta=-54.727278 -> V=1.0, theta=0.0
% INFO    : Bus 54097	: V=1.0192728, theta=-54.672583 -> V=1.0, theta=0.0
% INFO    : Bus 54098	: V=0.9807418, theta=-58.853772 -> V=1.0, theta=0.0
% INFO    : Bus 54099	: V=0.9950456, theta=-57.598437 -> V=1.0, theta=0.0
% INFO    : Bus 54100	: V=0.9884278, theta=-58.802704 -> V=1.0, theta=0.0
% INFO    : Bus 54101	: V=1.0066006, theta=-75.01996 -> V=1.0, theta=0.0
% INFO    : Bus 54102	: V=1.0186268, theta=-74.105202 -> V=1.0, theta=0.0
% INFO    : Bus 54103	: V=0.9829227, theta=-74.397868 -> V=1.0, theta=0.0
% INFO    : Bus 54104	: V=0.9987084, theta=-73.10905 -> V=1.0, theta=0.0
% INFO    : Bus 54105	: V=1.0039104, theta=-73.641589 -> V=1.0, theta=0.0
% INFO    : Bus 54106	: V=1.0046517, theta=-60.309852 -> V=1.0, theta=0.0
% INFO    : Bus 54107	: V=0.9809523, theta=-64.278761 -> V=1.0, theta=0.0
% INFO    : Bus 54108	: V=0.9678791, theta=-66.406723 -> V=1.0, theta=0.0
% INFO    : Bus 54109	: V=0.9698742, theta=-65.433049 -> V=1.0, theta=0.0
% INFO    : Bus 54110	: V=0.981588, theta=-64.507975 -> V=1.0, theta=0.0
% INFO    : Bus 54111	: V=0.9739507, theta=-64.396742 -> V=1.0, theta=0.0
% INFO    : Bus 54112	: V=0.9704516, theta=-65.037394 -> V=1.0, theta=0.0
% INFO    : Bus 54113	: V=0.9873573, theta=-65.105756 -> V=1.0, theta=0.0
% INFO    : Bus 54114	: V=0.9624692, theta=-65.269393 -> V=1.0, theta=0.0
% INFO    : Bus 54115	: V=0.9896484, theta=-64.410563 -> V=1.0, theta=0.0
% INFO    : Bus 54116	: V=0.9838841, theta=-66.002865 -> V=1.0, theta=0.0
% INFO    : Bus 54117	: V=0.974588, theta=-67.29445 -> V=1.0, theta=0.0
% INFO    : Bus 54118	: V=0.9738461, theta=-61.255204 -> V=1.0, theta=0.0
% INFO    : Bus 54119	: V=0.9720915, theta=-61.387895 -> V=1.0, theta=0.0
% INFO    : Bus 54120	: V=0.9826367, theta=-64.29592 -> V=1.0, theta=0.0
% INFO    : Bus 54121	: V=0.9830976, theta=-64.080847 -> V=1.0, theta=0.0
% INFO    : Bus 54122	: V=0.9842608, theta=-64.440081 -> V=1.0, theta=0.0
% INFO    : Bus 54123	: V=1.0016488, theta=-56.521901 -> V=1.0, theta=0.0
% INFO    : Bus 54124	: V=0.9841798, theta=-52.451265 -> V=1.0, theta=0.0
% INFO    : Bus 54125	: V=1.0006048, theta=-51.13579 -> V=1.0, theta=0.0
% INFO    : Bus 54126	: V=1.0136667, theta=-50.489411 -> V=1.0, theta=0.0
% INFO    : Bus 54127	: V=0.9893339, theta=-52.402918 -> V=1.0, theta=0.0
% INFO    : Bus 54128	: V=0.9783476, theta=-52.57605 -> V=1.0, theta=0.0
% INFO    : Bus 54129	: V=0.9805195, theta=-68.575896 -> V=1.0, theta=0.0
% INFO    : Bus 54130	: V=0.9772949, theta=-70.57547 -> V=1.0, theta=0.0
% INFO    : Bus 54131	: V=0.9759098, theta=-70.446012 -> V=1.0, theta=0.0
% INFO    : Bus 54132	: V=0.9809658, theta=-69.437167 -> V=1.0, theta=0.0
% INFO    : Bus 54133	: V=0.9623594, theta=-75.741687 -> V=1.0, theta=0.0
% INFO    : Bus 54134	: V=0.9654472, theta=-75.528888 -> V=1.0, theta=0.0
% INFO    : Bus 54135	: V=0.9664343, theta=-74.130347 -> V=1.0, theta=0.0
% INFO    : Bus 54136	: V=0.9653409, theta=-75.444806 -> V=1.0, theta=0.0
% INFO    : Bus 54137	: V=0.9702466, theta=-72.735604 -> V=1.0, theta=0.0
% INFO    : Bus 54138	: V=0.9658016, theta=-75.158643 -> V=1.0, theta=0.0
% INFO    : Bus 54139	: V=0.963685, theta=-77.040841 -> V=1.0, theta=0.0
% INFO    : Bus 54140	: V=0.961837, theta=-77.942931 -> V=1.0, theta=0.0
% INFO    : Bus 54141	: V=0.9608246, theta=-78.104 -> V=1.0, theta=0.0
% INFO    : Bus 54142	: V=0.9599349, theta=-78.270567 -> V=1.0, theta=0.0
% INFO    : Bus 54143	: V=0.9651314, theta=-75.407978 -> V=1.0, theta=0.0
% INFO    : Bus 54144	: V=0.959145, theta=-78.441338 -> V=1.0, theta=0.0
% INFO    : Bus 54145	: V=0.9601958, theta=-78.316909 -> V=1.0, theta=0.0
% INFO    : Bus 54146	: V=0.9617155, theta=-78.031711 -> V=1.0, theta=0.0
% INFO    : Bus 54147	: V=0.9621315, theta=-78.012054 -> V=1.0, theta=0.0
% INFO    : Bus 54148	: V=0.9631815, theta=-77.552954 -> V=1.0, theta=0.0
% INFO    : Bus 54149	: V=0.9624482, theta=-77.767511 -> V=1.0, theta=0.0
% INFO    : Bus 54150	: V=0.9629259, theta=-77.283472 -> V=1.0, theta=0.0
% INFO    : Bus 54151	: V=0.9632184, theta=-77.047585 -> V=1.0, theta=0.0
% INFO    : Bus 54152	: V=0.9642441, theta=-77.031184 -> V=1.0, theta=0.0
% INFO    : Bus 54153	: V=0.9664493, theta=-75.86751 -> V=1.0, theta=0.0
% INFO    : Bus 54154	: V=0.9647937, theta=-75.747356 -> V=1.0, theta=0.0
% INFO    : Bus 54155	: V=0.9645649, theta=-75.947832 -> V=1.0, theta=0.0
% INFO    : Bus 54156	: V=0.9635411, theta=-76.12301 -> V=1.0, theta=0.0
% INFO    : Bus 54157	: V=0.9637797, theta=-76.224734 -> V=1.0, theta=0.0
% INFO    : Bus 54158	: V=0.9624995, theta=-77.08223 -> V=1.0, theta=0.0
% INFO    : Bus 54159	: V=0.9633463, theta=-75.882466 -> V=1.0, theta=0.0
% INFO    : Bus 54160	: V=0.9640786, theta=-75.852684 -> V=1.0, theta=0.0
% INFO    : Bus 54161	: V=0.9633537, theta=-75.920049 -> V=1.0, theta=0.0
% INFO    : Bus 54162	: V=0.9633613, theta=-75.951167 -> V=1.0, theta=0.0
% INFO    : Bus 54163	: V=0.9640506, theta=-75.921235 -> V=1.0, theta=0.0
% INFO    : Bus 54164	: V=0.9647397, theta=-75.781484 -> V=1.0, theta=0.0
% INFO    : Bus 54165	: V=0.9635637, theta=-75.734469 -> V=1.0, theta=0.0
% INFO    : Bus 54166	: V=0.9646058, theta=-75.635097 -> V=1.0, theta=0.0
% INFO    : Bus 54167	: V=0.9656768, theta=-75.390458 -> V=1.0, theta=0.0
% INFO    : Bus 54168	: V=0.9643566, theta=-75.57426 -> V=1.0, theta=0.0
% INFO    : Bus 54169	: V=0.9636776, theta=-76.070579 -> V=1.0, theta=0.0
% INFO    : Bus 54170	: V=0.9636977, theta=-75.685097 -> V=1.0, theta=0.0
% INFO    : Bus 54171	: V=0.9630436, theta=-75.742947 -> V=1.0, theta=0.0
% INFO    : Bus 54172	: V=0.9659502, theta=-75.350607 -> V=1.0, theta=0.0
% INFO    : Bus 54173	: V=0.9725739, theta=-73.336496 -> V=1.0, theta=0.0
% INFO    : Bus 54174	: V=0.9705571, theta=-73.324261 -> V=1.0, theta=0.0
% INFO    : Bus 54175	: V=0.9660547, theta=-75.162078 -> V=1.0, theta=0.0
% INFO    : Bus 54176	: V=0.9717165, theta=-73.295302 -> V=1.0, theta=0.0
% INFO    : Bus 54177	: V=0.9689677, theta=-74.05127 -> V=1.0, theta=0.0
% INFO    : Bus 54178	: V=0.9671693, theta=-74.976414 -> V=1.0, theta=0.0
% INFO    : Bus 54179	: V=0.9687857, theta=-74.530559 -> V=1.0, theta=0.0
% INFO    : Bus 54180	: V=0.9755257, theta=-72.814666 -> V=1.0, theta=0.0
% INFO    : Bus 54181	: V=0.9918921, theta=-70.465601 -> V=1.0, theta=0.0
% INFO    : Bus 54182	: V=0.9768504, theta=-71.779345 -> V=1.0, theta=0.0
% INFO    : Bus 54183	: V=0.9791858, theta=-71.744512 -> V=1.0, theta=0.0
% INFO    : Bus 54184	: V=0.9762751, theta=-70.157463 -> V=1.0, theta=0.0
% INFO    : Bus 54185	: V=0.9965922, theta=-68.702475 -> V=1.0, theta=0.0
% INFO    : Bus 54186	: V=0.9920294, theta=-70.843133 -> V=1.0, theta=0.0
% INFO    : Bus 54187	: V=0.9858231, theta=-72.512687 -> V=1.0, theta=0.0
% INFO    : Bus 54188	: V=0.995731, theta=-70.697821 -> V=1.0, theta=0.0
% INFO    : Bus 54189	: V=0.9956158, theta=-70.271159 -> V=1.0, theta=0.0
% INFO    : Bus 54190	: V=0.9850645, theta=-72.974477 -> V=1.0, theta=0.0
% INFO    : Bus 54191	: V=0.9804874, theta=-73.628841 -> V=1.0, theta=0.0
% INFO    : Bus 54192	: V=0.9819893, theta=-73.33995 -> V=1.0, theta=0.0
% INFO    : Bus 54193	: V=0.9834442, theta=-72.57841 -> V=1.0, theta=0.0
% INFO    : Bus 54194	: V=0.9792025, theta=-73.817756 -> V=1.0, theta=0.0
% INFO    : Bus 54195	: V=0.9841174, theta=-72.650278 -> V=1.0, theta=0.0
% INFO    : Bus 54196	: V=0.9856199, theta=-72.756155 -> V=1.0, theta=0.0
% INFO    : Bus 54197	: V=0.9696116, theta=-75.442198 -> V=1.0, theta=0.0
% INFO    : Bus 54198	: V=0.9706369, theta=-74.007826 -> V=1.0, theta=0.0
% INFO    : Bus 54199	: V=0.9895544, theta=-71.009269 -> V=1.0, theta=0.0
% INFO    : Bus 54200	: V=0.9875989, theta=-71.665642 -> V=1.0, theta=0.0
% INFO    : Bus 54201	: V=0.9799034, theta=-73.547388 -> V=1.0, theta=0.0
% INFO    : Bus 54202	: V=0.9871993, theta=-71.824515 -> V=1.0, theta=0.0
% INFO    : Bus 54203	: V=0.9813941, theta=-73.365822 -> V=1.0, theta=0.0
% INFO    : Bus 54204	: V=0.9872837, theta=-71.77596 -> V=1.0, theta=0.0
% INFO    : Bus 54205	: V=0.9754528, theta=-74.321035 -> V=1.0, theta=0.0
% INFO    : Bus 54206	: V=0.9869387, theta=-71.998671 -> V=1.0, theta=0.0
% INFO    : Bus 54207	: V=0.9720324, theta=-75.186766 -> V=1.0, theta=0.0
% INFO    : Bus 54208	: V=0.9745177, theta=-73.777566 -> V=1.0, theta=0.0
% INFO    : Bus 54209	: V=0.9695835, theta=-75.98441 -> V=1.0, theta=0.0
% INFO    : Bus 54210	: V=0.964403, theta=-77.464857 -> V=1.0, theta=0.0
% INFO    : Bus 54211	: V=0.9665015, theta=-76.397405 -> V=1.0, theta=0.0
% INFO    : Bus 54212	: V=0.9632834, theta=-77.782069 -> V=1.0, theta=0.0
% INFO    : Bus 54213	: V=0.9680364, theta=-76.424504 -> V=1.0, theta=0.0
% INFO    : Bus 54214	: V=0.9671999, theta=-76.593063 -> V=1.0, theta=0.0
% INFO    : Bus 54215	: V=0.9648622, theta=-77.565988 -> V=1.0, theta=0.0
% INFO    : Bus 54216	: V=0.9641738, theta=-77.604455 -> V=1.0, theta=0.0
% INFO    : Bus 54217	: V=0.9651494, theta=-77.468375 -> V=1.0, theta=0.0
% INFO    : Bus 54218	: V=0.965741, theta=-76.676159 -> V=1.0, theta=0.0
% INFO    : Bus 54219	: V=0.9682991, theta=-76.130877 -> V=1.0, theta=0.0
% INFO    : Bus 54220	: V=0.9671638, theta=-76.448938 -> V=1.0, theta=0.0
% INFO    : Bus 54221	: V=0.9731168, theta=-74.764664 -> V=1.0, theta=0.0
% INFO    : Bus 54222	: V=0.9737635, theta=-74.661338 -> V=1.0, theta=0.0
% INFO    : Bus 54223	: V=0.9753429, theta=-74.404568 -> V=1.0, theta=0.0
% INFO    : Bus 54224	: V=0.9675808, theta=-76.229754 -> V=1.0, theta=0.0
% INFO    : Bus 54225	: V=0.9678125, theta=-76.192785 -> V=1.0, theta=0.0
% INFO    : Bus 54226	: V=0.9709503, theta=-75.890682 -> V=1.0, theta=0.0
% INFO    : Bus 54227	: V=0.9658093, theta=-77.1004 -> V=1.0, theta=0.0
% INFO    : Bus 54228	: V=0.9672596, theta=-76.875542 -> V=1.0, theta=0.0
% INFO    : Bus 54229	: V=0.9707953, theta=-75.164337 -> V=1.0, theta=0.0
% INFO    : Bus 54230	: V=0.9647449, theta=-77.204115 -> V=1.0, theta=0.0
% INFO    : Bus 54231	: V=0.9719357, theta=-74.847424 -> V=1.0, theta=0.0
% INFO    : Bus 54232	: V=0.9722195, theta=-74.886733 -> V=1.0, theta=0.0
% INFO    : Bus 54233	: V=0.9660258, theta=-76.31209 -> V=1.0, theta=0.0
% INFO    : Bus 54234	: V=0.9673465, theta=-76.275378 -> V=1.0, theta=0.0
% INFO    : Bus 54235	: V=0.9594654, theta=-78.822658 -> V=1.0, theta=0.0
% INFO    : Bus 54236	: V=0.9603595, theta=-78.687425 -> V=1.0, theta=0.0
% INFO    : Bus 54237	: V=0.9596275, theta=-78.836811 -> V=1.0, theta=0.0
% INFO    : Bus 54238	: V=0.9600841, theta=-78.754202 -> V=1.0, theta=0.0
% INFO    : Bus 54239	: V=0.9680588, theta=-76.391889 -> V=1.0, theta=0.0
% INFO    : Bus 54240	: V=0.9624067, theta=-77.897266 -> V=1.0, theta=0.0
% INFO    : Bus 54241	: V=0.9627594, theta=-77.809954 -> V=1.0, theta=0.0
% INFO    : Bus 54242	: V=0.9622072, theta=-77.861039 -> V=1.0, theta=0.0
% INFO    : Bus 54243	: V=0.9617741, theta=-77.882489 -> V=1.0, theta=0.0
% INFO    : Bus 54244	: V=0.9600655, theta=-78.640992 -> V=1.0, theta=0.0
% INFO    : Bus 54245	: V=0.9606177, theta=-78.519851 -> V=1.0, theta=0.0
% INFO    : Bus 54246	: V=0.961069, theta=-78.498271 -> V=1.0, theta=0.0
% INFO    : Bus 54247	: V=0.9623008, theta=-78.13057 -> V=1.0, theta=0.0
% INFO    : Bus 54248	: V=0.9625918, theta=-78.119238 -> V=1.0, theta=0.0
% INFO    : Bus 54249	: V=0.9624665, theta=-77.99612 -> V=1.0, theta=0.0
% INFO    : Bus 54250	: V=0.969632, theta=-75.333413 -> V=1.0, theta=0.0
% INFO    : Bus 54251	: V=0.9629826, theta=-77.901068 -> V=1.0, theta=0.0
% INFO    : Bus 54252	: V=0.9627026, theta=-77.91002 -> V=1.0, theta=0.0
% INFO    : Bus 54253	: V=0.960699, theta=-78.657125 -> V=1.0, theta=0.0
% INFO    : Bus 54254	: V=0.9612176, theta=-78.470547 -> V=1.0, theta=0.0
% INFO    : Bus 54255	: V=0.9616557, theta=-78.175082 -> V=1.0, theta=0.0
% INFO    : Bus 54256	: V=0.962985, theta=-77.823181 -> V=1.0, theta=0.0
% INFO    : Bus 54257	: V=0.9593373, theta=-79.082748 -> V=1.0, theta=0.0
% INFO    : Bus 54258	: V=0.959073, theta=-79.054875 -> V=1.0, theta=0.0
% INFO    : Bus 54259	: V=0.9598933, theta=-79.001366 -> V=1.0, theta=0.0
% INFO    : Bus 54260	: V=0.959508, theta=-79.026706 -> V=1.0, theta=0.0
% INFO    : Bus 54261	: V=0.9619407, theta=-77.917712 -> V=1.0, theta=0.0
% INFO    : Bus 54262	: V=0.9620472, theta=-77.912564 -> V=1.0, theta=0.0
% INFO    : Bus 54263	: V=0.9622631, theta=-77.902454 -> V=1.0, theta=0.0
% INFO    : Bus 54264	: V=0.9616182, theta=-78.076919 -> V=1.0, theta=0.0
% INFO    : Bus 54265	: V=0.9636294, theta=-77.786982 -> V=1.0, theta=0.0
% INFO    : Bus 54266	: V=0.9641204, theta=-77.757816 -> V=1.0, theta=0.0
% INFO    : Bus 54267	: V=0.9764804, theta=-74.396169 -> V=1.0, theta=0.0
% INFO    : Bus 54268	: V=0.964794, theta=-77.148314 -> V=1.0, theta=0.0
% INFO    : Bus 54269	: V=0.9690481, theta=-76.270645 -> V=1.0, theta=0.0
% INFO    : Bus 54270	: V=0.9659575, theta=-76.957797 -> V=1.0, theta=0.0
% INFO    : Bus 54271	: V=0.9656565, theta=-77.444364 -> V=1.0, theta=0.0
% INFO    : Bus 54272	: V=0.9776936, theta=-74.253017 -> V=1.0, theta=0.0
% INFO    : Bus 54273	: V=0.9707478, theta=-75.973716 -> V=1.0, theta=0.0
% INFO    : Bus 54274	: V=0.9788691, theta=-74.021301 -> V=1.0, theta=0.0
% INFO    : Bus 54275	: V=0.9728766, theta=-74.971404 -> V=1.0, theta=0.0
% INFO    : Bus 54276	: V=0.979361, theta=-74.059295 -> V=1.0, theta=0.0
% INFO    : Bus 54277	: V=0.9800983, theta=-73.763867 -> V=1.0, theta=0.0
% INFO    : Bus 54278	: V=0.9841201, theta=-72.868594 -> V=1.0, theta=0.0
% INFO    : Bus 54279	: V=0.9698337, theta=-75.999111 -> V=1.0, theta=0.0
% INFO    : Bus 54280	: V=0.9781353, theta=-73.771877 -> V=1.0, theta=0.0
% INFO    : Bus 54281	: V=0.9528126, theta=-60.536072 -> V=1.0, theta=0.0
% INFO    : Bus 54282	: V=0.9648394, theta=-72.492575 -> V=1.0, theta=0.0
% INFO    : Bus 54283	: V=0.9449578, theta=-72.556352 -> V=1.0, theta=0.0
% INFO    : Bus 54284	: V=0.9587798, theta=-72.918909 -> V=1.0, theta=0.0
% INFO    : Bus 54285	: V=0.9881712, theta=-70.328621 -> V=1.0, theta=0.0
% INFO    : Bus 54286	: V=0.9480234, theta=-73.794493 -> V=1.0, theta=0.0
% INFO    : Bus 54287	: V=0.9870853, theta=-70.060263 -> V=1.0, theta=0.0
% INFO    : Bus 54288	: V=0.9940377, theta=-69.725345 -> V=1.0, theta=0.0
% INFO    : Bus 54289	: V=1.002359, theta=-68.76982 -> V=1.0, theta=0.0
% INFO    : Bus 54290	: V=1.0010601, theta=-68.929845 -> V=1.0, theta=0.0
% INFO    : Bus 54291	: V=0.9988263, theta=-69.237071 -> V=1.0, theta=0.0
% INFO    : Bus 54292	: V=0.9859282, theta=-70.099435 -> V=1.0, theta=0.0
% INFO    : Bus 54293	: V=0.9925186, theta=-69.797255 -> V=1.0, theta=0.0
% INFO    : Bus 54294	: V=0.9994102, theta=-69.16096 -> V=1.0, theta=0.0
% INFO    : Bus 54295	: V=0.9940553, theta=-69.739038 -> V=1.0, theta=0.0
% INFO    : Bus 54296	: V=0.9573942, theta=-73.079473 -> V=1.0, theta=0.0
% INFO    : Bus 54297	: V=0.9436559, theta=-74.676412 -> V=1.0, theta=0.0
% INFO    : Bus 54298	: V=0.9590909, theta=-73.065895 -> V=1.0, theta=0.0
% INFO    : Bus 54299	: V=0.9469651, theta=-74.302662 -> V=1.0, theta=0.0
% INFO    : Bus 54300	: V=0.9530681, theta=-74.120912 -> V=1.0, theta=0.0
% INFO    : Bus 54301	: V=0.9463841, theta=-74.594382 -> V=1.0, theta=0.0
% INFO    : Bus 54302	: V=0.9604042, theta=-73.819291 -> V=1.0, theta=0.0
% INFO    : Bus 54303	: V=0.9459766, theta=-74.964553 -> V=1.0, theta=0.0
% INFO    : Bus 54304	: V=0.9508597, theta=-74.678745 -> V=1.0, theta=0.0
% INFO    : Bus 54305	: V=0.9483761, theta=-77.330831 -> V=1.0, theta=0.0
% INFO    : Bus 54306	: V=0.9667211, theta=-73.251233 -> V=1.0, theta=0.0
% INFO    : Bus 54307	: V=0.9985561, theta=-69.241965 -> V=1.0, theta=0.0
% INFO    : Bus 54308	: V=0.9735232, theta=-72.400859 -> V=1.0, theta=0.0
% INFO    : Bus 54309	: V=1.0179792, theta=-66.793586 -> V=1.0, theta=0.0
% INFO    : Bus 54310	: V=0.9689511, theta=-72.694422 -> V=1.0, theta=0.0
% INFO    : Bus 54311	: V=1.0172096, theta=-57.073438 -> V=1.0, theta=0.0
% INFO    : Bus 54312	: V=0.993724, theta=-58.092785 -> V=1.0, theta=0.0
% INFO    : Bus 54313	: V=0.9914973, theta=-58.762987 -> V=1.0, theta=0.0
% INFO    : Bus 54314	: V=0.978413, theta=-58.797301 -> V=1.0, theta=0.0
% INFO    : Bus 54315	: V=0.9683459, theta=-61.590049 -> V=1.0, theta=0.0
% INFO    : Bus 54316	: V=0.9560949, theta=-68.815447 -> V=1.0, theta=0.0
% INFO    : Bus 54317	: V=0.9604114, theta=-69.241203 -> V=1.0, theta=0.0
% INFO    : Bus 54318	: V=0.9566176, theta=-69.986756 -> V=1.0, theta=0.0
% INFO    : Bus 54319	: V=0.9542599, theta=-71.381077 -> V=1.0, theta=0.0
% INFO    : Bus 54320	: V=0.9543833, theta=-71.098717 -> V=1.0, theta=0.0
% INFO    : Bus 54321	: V=0.9516365, theta=-72.849742 -> V=1.0, theta=0.0
% INFO    : Bus 54322	: V=0.9524877, theta=-73.135081 -> V=1.0, theta=0.0
% INFO    : Bus 54323	: V=0.9526885, theta=-72.038949 -> V=1.0, theta=0.0
% INFO    : Bus 54324	: V=0.9686577, theta=-69.542194 -> V=1.0, theta=0.0
% INFO    : Bus 54325	: V=0.9746411, theta=-67.453373 -> V=1.0, theta=0.0
% INFO    : Bus 54326	: V=0.9571906, theta=-71.454452 -> V=1.0, theta=0.0
% INFO    : Bus 54327	: V=0.9687007, theta=-69.506338 -> V=1.0, theta=0.0
% INFO    : Bus 54328	: V=0.9697354, theta=-68.836168 -> V=1.0, theta=0.0
% INFO    : Bus 54329	: V=0.9688401, theta=-69.451569 -> V=1.0, theta=0.0
% INFO    : Bus 54330	: V=0.9631066, theta=-70.298623 -> V=1.0, theta=0.0
% INFO    : Bus 54331	: V=0.961867, theta=-70.333335 -> V=1.0, theta=0.0
% INFO    : Bus 54332	: V=0.971403, theta=-68.988284 -> V=1.0, theta=0.0
% INFO    : Bus 54333	: V=0.9612026, theta=-70.343156 -> V=1.0, theta=0.0
% INFO    : Bus 54334	: V=0.9604358, theta=-70.229735 -> V=1.0, theta=0.0
% INFO    : Bus 54335	: V=0.9632244, theta=-70.013612 -> V=1.0, theta=0.0
% INFO    : Bus 54336	: V=0.964336, theta=-69.685261 -> V=1.0, theta=0.0
% INFO    : Bus 54337	: V=0.9638537, theta=-69.973427 -> V=1.0, theta=0.0
% INFO    : Bus 54338	: V=0.9691898, theta=-68.994207 -> V=1.0, theta=0.0
% INFO    : Bus 54339	: V=0.9629165, theta=-70.074603 -> V=1.0, theta=0.0
% INFO    : Bus 54340	: V=0.960601, theta=-70.228126 -> V=1.0, theta=0.0
% INFO    : Bus 54341	: V=0.9615221, theta=-70.201668 -> V=1.0, theta=0.0
% INFO    : Bus 54342	: V=0.9703634, theta=-69.196859 -> V=1.0, theta=0.0
% INFO    : Bus 54343	: V=0.9895065, theta=-60.162973 -> V=1.0, theta=0.0
% INFO    : Bus 54344	: V=1.0100598, theta=-57.373594 -> V=1.0, theta=0.0
% INFO    : Bus 54345	: V=1.0137681, theta=-61.157666 -> V=1.0, theta=0.0
% INFO    : Bus 54346	: V=1.0157247, theta=-56.879799 -> V=1.0, theta=0.0
% INFO    : Bus 54347	: V=1.0128099, theta=-56.76865 -> V=1.0, theta=0.0
% INFO    : Bus 54348	: V=1.0127224, theta=-57.022591 -> V=1.0, theta=0.0
% INFO    : Bus 54349	: V=0.9410584, theta=-76.938717 -> V=1.0, theta=0.0
% INFO    : Bus 54350	: V=1.0016566, theta=-58.319902 -> V=1.0, theta=0.0
% INFO    : Bus 54351	: V=0.9888827, theta=-58.955318 -> V=1.0, theta=0.0
% INFO    : Bus 54352	: V=0.974923, theta=-75.6765 -> V=1.0, theta=0.0
% INFO    : Bus 54353	: V=0.968276, theta=-76.581002 -> V=1.0, theta=0.0
% INFO    : Bus 54354	: V=0.9680752, theta=-76.594066 -> V=1.0, theta=0.0
% INFO    : Bus 54355	: V=0.9727438, theta=-75.894489 -> V=1.0, theta=0.0
% INFO    : Bus 54356	: V=0.9726578, theta=-75.868837 -> V=1.0, theta=0.0
% INFO    : Bus 54357	: V=0.9633014, theta=-77.203272 -> V=1.0, theta=0.0
% INFO    : Bus 54358	: V=0.9635496, theta=-77.174982 -> V=1.0, theta=0.0
% INFO    : Bus 54359	: V=0.9886586, theta=-72.634934 -> V=1.0, theta=0.0
% INFO    : Bus 54360	: V=0.9640471, theta=-77.189386 -> V=1.0, theta=0.0
% INFO    : Bus 54361	: V=0.9635498, theta=-77.136187 -> V=1.0, theta=0.0
% INFO    : Bus 54362	: V=0.9633906, theta=-77.153975 -> V=1.0, theta=0.0
% INFO    : Bus 54363	: V=0.9645727, theta=-77.154712 -> V=1.0, theta=0.0
% INFO    : Bus 54364	: V=0.9654175, theta=-77.100106 -> V=1.0, theta=0.0
% INFO    : Bus 54365	: V=0.9727105, theta=-75.889964 -> V=1.0, theta=0.0
% INFO    : Bus 54366	: V=0.9723723, theta=-75.923176 -> V=1.0, theta=0.0
% INFO    : Bus 54367	: V=0.9731659, theta=-75.853246 -> V=1.0, theta=0.0
% INFO    : Bus 54368	: V=0.9702563, theta=-76.470621 -> V=1.0, theta=0.0
% INFO    : Bus 54369	: V=0.9731196, theta=-75.860871 -> V=1.0, theta=0.0
% INFO    : Bus 54370	: V=0.9733748, theta=-75.83794 -> V=1.0, theta=0.0
% INFO    : Bus 54371	: V=0.9739183, theta=-75.782506 -> V=1.0, theta=0.0
% INFO    : Bus 54372	: V=0.9741699, theta=-75.759757 -> V=1.0, theta=0.0
% INFO    : Bus 54373	: V=0.9766496, theta=-75.504735 -> V=1.0, theta=0.0
% INFO    : Bus 54374	: V=0.9757475, theta=-75.605788 -> V=1.0, theta=0.0
% INFO    : Bus 54375	: V=0.9753797, theta=-75.642578 -> V=1.0, theta=0.0
% INFO    : Bus 54376	: V=0.9748619, theta=-75.692875 -> V=1.0, theta=0.0
% INFO    : Bus 54377	: V=0.974592, theta=-75.72228 -> V=1.0, theta=0.0
% INFO    : Bus 54378	: V=0.9743786, theta=-75.742164 -> V=1.0, theta=0.0
% INFO    : Bus 54379	: V=0.9674171, theta=-77.042746 -> V=1.0, theta=0.0
% INFO    : Bus 54380	: V=0.973684, theta=-75.814386 -> V=1.0, theta=0.0
% INFO    : Bus 54381	: V=0.9739429, theta=-75.789028 -> V=1.0, theta=0.0
% INFO    : Bus 54382	: V=0.9661043, theta=-77.083911 -> V=1.0, theta=0.0
% INFO    : Bus 54383	: V=0.9645937, theta=-77.164745 -> V=1.0, theta=0.0
% INFO    : Bus 54384	: V=0.9658742, theta=-77.092072 -> V=1.0, theta=0.0
% INFO    : Bus 54385	: V=0.9647695, theta=-77.15982 -> V=1.0, theta=0.0
% INFO    : Bus 54386	: V=0.9652131, theta=-77.150162 -> V=1.0, theta=0.0
% INFO    : Bus 54387	: V=0.963394, theta=-77.274105 -> V=1.0, theta=0.0
% INFO    : Bus 54388	: V=0.9627284, theta=-77.551658 -> V=1.0, theta=0.0
% INFO    : Bus 54389	: V=0.963239, theta=-77.311925 -> V=1.0, theta=0.0
% INFO    : Bus 54390	: V=0.9662354, theta=-77.172109 -> V=1.0, theta=0.0
% INFO    : Bus 54391	: V=0.9753252, theta=-75.634193 -> V=1.0, theta=0.0
% INFO    : Bus 54392	: V=0.9765444, theta=-75.491914 -> V=1.0, theta=0.0
% INFO    : Bus 54393	: V=0.9765164, theta=-75.51373 -> V=1.0, theta=0.0
% INFO    : Bus 54394	: V=0.9745709, theta=-75.872019 -> V=1.0, theta=0.0
% INFO    : Bus 54395	: V=0.9633844, theta=-77.321604 -> V=1.0, theta=0.0
% INFO    : Bus 54396	: V=0.9716751, theta=-76.170961 -> V=1.0, theta=0.0
% INFO    : Bus 54397	: V=0.973253, theta=-75.952075 -> V=1.0, theta=0.0
% INFO    : Bus 54398	: V=0.9740374, theta=-75.846826 -> V=1.0, theta=0.0
% INFO    : Bus 54399	: V=0.975051, theta=-75.714237 -> V=1.0, theta=0.0
% INFO    : Bus 54400	: V=0.9743867, theta=-75.842731 -> V=1.0, theta=0.0
% INFO    : Bus 54401	: V=0.9731684, theta=-75.97934 -> V=1.0, theta=0.0
% INFO    : Bus 54402	: V=0.9621739, theta=-77.66625 -> V=1.0, theta=0.0
% INFO    : Bus 54403	: V=0.9628591, theta=-77.539549 -> V=1.0, theta=0.0
% INFO    : Bus 54404	: V=0.964405, theta=-77.405282 -> V=1.0, theta=0.0
% INFO    : Bus 54405	: V=0.9659368, theta=-77.242643 -> V=1.0, theta=0.0
% INFO    : Bus 54406	: V=0.9644805, theta=-77.401526 -> V=1.0, theta=0.0
% INFO    : Bus 54407	: V=0.9669926, theta=-77.24524 -> V=1.0, theta=0.0
% INFO    : Bus 54408	: V=0.9641099, theta=-77.413124 -> V=1.0, theta=0.0
% INFO    : Bus 54409	: V=0.9626565, theta=-77.610471 -> V=1.0, theta=0.0
% INFO    : Bus 54410	: V=0.9620298, theta=-77.693301 -> V=1.0, theta=0.0
% INFO    : Bus 54411	: V=0.9609831, theta=-77.716105 -> V=1.0, theta=0.0
% INFO    : Bus 54412	: V=0.9633501, theta=-77.564862 -> V=1.0, theta=0.0
% INFO    : Bus 54413	: V=0.9644532, theta=-77.488292 -> V=1.0, theta=0.0
% INFO    : Bus 54414	: V=0.9654527, theta=-77.42384 -> V=1.0, theta=0.0
% INFO    : Bus 54415	: V=0.967212, theta=-77.288642 -> V=1.0, theta=0.0
% INFO    : Bus 54416	: V=0.9627125, theta=-77.737194 -> V=1.0, theta=0.0
% INFO    : Bus 54417	: V=0.9636598, theta=-77.690434 -> V=1.0, theta=0.0
% INFO    : Bus 54418	: V=0.9631267, theta=-77.781962 -> V=1.0, theta=0.0
% INFO    : Bus 54419	: V=0.9648352, theta=-77.619666 -> V=1.0, theta=0.0
% INFO    : Bus 54420	: V=0.9702194, theta=-76.941318 -> V=1.0, theta=0.0
% INFO    : Bus 54421	: V=0.9699445, theta=-76.989665 -> V=1.0, theta=0.0
% INFO    : Bus 54422	: V=0.9665498, theta=-77.570862 -> V=1.0, theta=0.0
% INFO    : Bus 54423	: V=0.9697133, theta=-77.034689 -> V=1.0, theta=0.0
% INFO    : Bus 54424	: V=0.9653649, theta=-77.756154 -> V=1.0, theta=0.0
% INFO    : Bus 54425	: V=0.9679124, theta=-77.553015 -> V=1.0, theta=0.0
% INFO    : Bus 54426	: V=0.9675167, theta=-77.544042 -> V=1.0, theta=0.0
% INFO    : Bus 54427	: V=0.9686795, theta=-77.505707 -> V=1.0, theta=0.0
% INFO    : Bus 54428	: V=0.9677209, theta=-77.299462 -> V=1.0, theta=0.0
% INFO    : Bus 54429	: V=0.9692266, theta=-77.081382 -> V=1.0, theta=0.0
% INFO    : Bus 54430	: V=0.9778309, theta=-75.462753 -> V=1.0, theta=0.0
% INFO    : Bus 54431	: V=0.9773482, theta=-75.513211 -> V=1.0, theta=0.0
% INFO    : Bus 54432	: V=0.9768233, theta=-75.545296 -> V=1.0, theta=0.0
% INFO    : Bus 54433	: V=0.9657857, theta=-77.351769 -> V=1.0, theta=0.0
% INFO    : Bus 54434	: V=0.9651559, theta=-77.369409 -> V=1.0, theta=0.0
% INFO    : Bus 54435	: V=0.9698278, theta=-76.664027 -> V=1.0, theta=0.0
% INFO    : Bus 54436	: V=0.9780629, theta=-75.122367 -> V=1.0, theta=0.0
% INFO    : Bus 54437	: V=0.973005, theta=-76.073837 -> V=1.0, theta=0.0
% INFO    : Bus 54438	: V=0.9719236, theta=-76.152856 -> V=1.0, theta=0.0
% INFO    : Bus 54439	: V=0.9686074, theta=-76.762726 -> V=1.0, theta=0.0
% INFO    : Bus 54440	: V=0.9744779, theta=-75.934399 -> V=1.0, theta=0.0
% INFO    : Bus 54441	: V=0.970154, theta=-76.714359 -> V=1.0, theta=0.0
% INFO    : Bus 54442	: V=0.9667832, theta=-76.703817 -> V=1.0, theta=0.0
% INFO    : Bus 54443	: V=0.9678956, theta=-76.861663 -> V=1.0, theta=0.0
% INFO    : Bus 54444	: V=0.967891, theta=-76.70137 -> V=1.0, theta=0.0
% INFO    : Bus 54445	: V=0.9685041, theta=-76.613529 -> V=1.0, theta=0.0
% INFO    : Bus 54446	: V=0.9697887, theta=-76.358068 -> V=1.0, theta=0.0
% INFO    : Bus 54447	: V=0.9686823, theta=-76.456213 -> V=1.0, theta=0.0
% INFO    : Bus 54448	: V=0.9759507, theta=-75.215833 -> V=1.0, theta=0.0
% INFO    : Bus 54449	: V=0.9699561, theta=-76.351809 -> V=1.0, theta=0.0
% INFO    : Bus 54450	: V=0.9778427, theta=-75.018711 -> V=1.0, theta=0.0
% INFO    : Bus 54451	: V=0.9703672, theta=-76.326817 -> V=1.0, theta=0.0
% INFO    : Bus 54452	: V=0.9694418, theta=-76.451843 -> V=1.0, theta=0.0
% INFO    : Bus 54453	: V=0.9700258, theta=-76.453197 -> V=1.0, theta=0.0
% INFO    : Bus 54454	: V=0.9698579, theta=-76.456754 -> V=1.0, theta=0.0
% INFO    : Bus 54455	: V=0.9703691, theta=-76.402491 -> V=1.0, theta=0.0
% INFO    : Bus 54456	: V=0.970877, theta=-76.356725 -> V=1.0, theta=0.0
% INFO    : Bus 54457	: V=0.9690016, theta=-76.529842 -> V=1.0, theta=0.0
% INFO    : Bus 54458	: V=0.9674459, theta=-76.590103 -> V=1.0, theta=0.0
% INFO    : Bus 54459	: V=0.9717388, theta=-76.257745 -> V=1.0, theta=0.0
% INFO    : Bus 54460	: V=0.9709354, theta=-76.253982 -> V=1.0, theta=0.0
% INFO    : Bus 54461	: V=0.9716429, theta=-76.2604 -> V=1.0, theta=0.0
% INFO    : Bus 54462	: V=0.9735433, theta=-76.001103 -> V=1.0, theta=0.0
% INFO    : Bus 54463	: V=0.9708049, theta=-76.365197 -> V=1.0, theta=0.0
% INFO    : Bus 54464	: V=0.9703406, theta=-76.405627 -> V=1.0, theta=0.0
% INFO    : Bus 54465	: V=0.9689497, theta=-76.592815 -> V=1.0, theta=0.0
% INFO    : Bus 54466	: V=0.9696173, theta=-76.476384 -> V=1.0, theta=0.0
% INFO    : Bus 54467	: V=0.9693183, theta=-76.50873 -> V=1.0, theta=0.0
% INFO    : Bus 54468	: V=0.969689, theta=-76.488431 -> V=1.0, theta=0.0
% INFO    : Bus 54469	: V=0.9692167, theta=-76.524081 -> V=1.0, theta=0.0
% INFO    : Bus 54470	: V=0.9744018, theta=-75.394654 -> V=1.0, theta=0.0
% INFO    : Bus 54471	: V=0.9740365, theta=-75.43242 -> V=1.0, theta=0.0
% INFO    : Bus 54472	: V=0.9695139, theta=-76.505282 -> V=1.0, theta=0.0
% INFO    : Bus 54473	: V=0.9756587, theta=-75.74017 -> V=1.0, theta=0.0
% INFO    : Bus 54474	: V=0.9765262, theta=-75.638188 -> V=1.0, theta=0.0
% INFO    : Bus 54475	: V=0.978636, theta=-75.215039 -> V=1.0, theta=0.0
% INFO    : Bus 54476	: V=0.9768115, theta=-75.755456 -> V=1.0, theta=0.0
% INFO    : Bus 54477	: V=0.9711387, theta=-76.212703 -> V=1.0, theta=0.0
% INFO    : Bus 54478	: V=0.9666008, theta=-77.367928 -> V=1.0, theta=0.0
% INFO    : Bus 54479	: V=0.9656807, theta=-77.52439 -> V=1.0, theta=0.0
% INFO    : Bus 54480	: V=0.9656479, theta=-77.559191 -> V=1.0, theta=0.0
% INFO    : Bus 54481	: V=0.9714112, theta=-76.756573 -> V=1.0, theta=0.0
% INFO    : Bus 54482	: V=0.9719977, theta=-76.654024 -> V=1.0, theta=0.0
% INFO    : Bus 54483	: V=0.9642365, theta=-77.649518 -> V=1.0, theta=0.0
% INFO    : Bus 54484	: V=0.965046, theta=-77.576577 -> V=1.0, theta=0.0
% INFO    : Bus 54485	: V=0.9611054, theta=-77.759713 -> V=1.0, theta=0.0
% INFO    : Bus 54486	: V=0.9818865, theta=-74.852199 -> V=1.0, theta=0.0
% INFO    : Bus 54487	: V=0.9799538, theta=-75.14851 -> V=1.0, theta=0.0
% INFO    : Bus 54488	: V=0.9766528, theta=-75.650804 -> V=1.0, theta=0.0
% INFO    : Bus 54489	: V=0.9799699, theta=-75.177062 -> V=1.0, theta=0.0
% INFO    : Bus 54490	: V=0.9800037, theta=-75.189288 -> V=1.0, theta=0.0
% INFO    : Bus 54491	: V=0.9797459, theta=-75.205613 -> V=1.0, theta=0.0
% INFO    : Bus 54492	: V=0.9822859, theta=-74.903928 -> V=1.0, theta=0.0
% INFO    : Bus 54493	: V=0.9808395, theta=-75.086514 -> V=1.0, theta=0.0
% INFO    : Bus 54494	: V=0.9761913, theta=-75.693066 -> V=1.0, theta=0.0
% INFO    : Bus 54495	: V=0.9784925, theta=-75.432267 -> V=1.0, theta=0.0
% INFO    : Bus 54496	: V=0.9740796, theta=-75.835663 -> V=1.0, theta=0.0
% INFO    : Bus 54497	: V=0.9717611, theta=-76.651981 -> V=1.0, theta=0.0
% INFO    : Bus 54498	: V=0.9707494, theta=-76.780901 -> V=1.0, theta=0.0
% INFO    : Bus 54499	: V=0.9671789, theta=-77.033567 -> V=1.0, theta=0.0
% INFO    : Bus 54500	: V=0.9692334, theta=-76.22123 -> V=1.0, theta=0.0
% INFO    : Bus 54501	: V=0.9670494, theta=-77.253184 -> V=1.0, theta=0.0
% INFO    : Bus 54502	: V=0.9677017, theta=-77.236889 -> V=1.0, theta=0.0
% INFO    : Bus 54503	: V=0.9711859, theta=-76.161756 -> V=1.0, theta=0.0
% INFO    : Bus 54504	: V=0.9715912, theta=-76.117285 -> V=1.0, theta=0.0
% INFO    : Bus 54505	: V=0.9709392, theta=-76.161877 -> V=1.0, theta=0.0
% INFO    : Bus 54506	: V=0.9663376, theta=-77.452298 -> V=1.0, theta=0.0
% INFO    : Bus 54507	: V=0.9647513, theta=-77.46653 -> V=1.0, theta=0.0
% INFO    : Bus 54508	: V=0.9637773, theta=-77.493926 -> V=1.0, theta=0.0
% INFO    : Bus 54509	: V=0.9735151, theta=-75.910197 -> V=1.0, theta=0.0
% INFO    : Bus 54510	: V=0.9727451, theta=-75.954532 -> V=1.0, theta=0.0
% INFO    : Bus 54511	: V=0.9730899, theta=-75.936657 -> V=1.0, theta=0.0
% INFO    : Bus 54512	: V=0.9851794, theta=-72.548994 -> V=1.0, theta=0.0
% INFO    : Bus 54513	: V=0.9891726, theta=-72.451554 -> V=1.0, theta=0.0
% INFO    : Bus 54514	: V=0.9683791, theta=-76.816467 -> V=1.0, theta=0.0
% INFO    : Bus 54515	: V=0.9670228, theta=-77.045872 -> V=1.0, theta=0.0
% INFO    : Bus 54516	: V=0.9820213, theta=-74.163609 -> V=1.0, theta=0.0
% INFO    : Bus 54517	: V=0.9688911, theta=-76.944844 -> V=1.0, theta=0.0
% INFO    : Bus 54518	: V=0.9763239, theta=-75.572735 -> V=1.0, theta=0.0
% INFO    : Bus 54519	: V=0.9759534, theta=-75.610007 -> V=1.0, theta=0.0
% INFO    : Bus 54520	: V=0.9840117, theta=-74.740988 -> V=1.0, theta=0.0
% INFO    : Bus 54521	: V=0.9806082, theta=-75.154491 -> V=1.0, theta=0.0
% INFO    : Bus 54522	: V=0.9801104, theta=-75.234379 -> V=1.0, theta=0.0
% INFO    : Bus 54523	: V=0.9725588, theta=-76.591696 -> V=1.0, theta=0.0
% INFO    : Bus 54524	: V=0.9768443, theta=-75.569786 -> V=1.0, theta=0.0
% INFO    : Bus 54525	: V=0.9778971, theta=-75.470342 -> V=1.0, theta=0.0
% INFO    : Bus 54526	: V=0.9611067, theta=-78.631054 -> V=1.0, theta=0.0
% INFO    : Bus 54527	: V=0.9696401, theta=-77.351243 -> V=1.0, theta=0.0
% INFO    : Bus 54528	: V=0.9694118, theta=-77.300118 -> V=1.0, theta=0.0
% INFO    : Bus 54529	: V=0.963536, theta=-77.989553 -> V=1.0, theta=0.0
% INFO    : Bus 54530	: V=0.9641773, theta=-77.877072 -> V=1.0, theta=0.0
% INFO    : Bus 54531	: V=0.9607741, theta=-78.737077 -> V=1.0, theta=0.0
% INFO    : Bus 54532	: V=0.9596252, theta=-78.79114 -> V=1.0, theta=0.0
% INFO    : Bus 54533	: V=0.9593507, theta=-78.861971 -> V=1.0, theta=0.0
% INFO    : Bus 54534	: V=0.9598203, theta=-78.839944 -> V=1.0, theta=0.0
% INFO    : Bus 54535	: V=0.9624774, theta=-78.612613 -> V=1.0, theta=0.0
% INFO    : Bus 54536	: V=0.9636427, theta=-78.490015 -> V=1.0, theta=0.0
% INFO    : Bus 54537	: V=0.9728367, theta=-76.510444 -> V=1.0, theta=0.0
% INFO    : Bus 54538	: V=0.9765947, theta=-75.567645 -> V=1.0, theta=0.0
% INFO    : Bus 54539	: V=0.9782197, theta=-75.456565 -> V=1.0, theta=0.0
% INFO    : Bus 54540	: V=0.9786268, theta=-75.784024 -> V=1.0, theta=0.0
% INFO    : Bus 54541	: V=0.9772728, theta=-75.893322 -> V=1.0, theta=0.0
% INFO    : Bus 54542	: V=0.9784708, theta=-75.810885 -> V=1.0, theta=0.0
% INFO    : Bus 54543	: V=0.9846049, theta=-74.63431 -> V=1.0, theta=0.0
% INFO    : Bus 54544	: V=0.9816108, theta=-75.064939 -> V=1.0, theta=0.0
% INFO    : Bus 54545	: V=0.9849545, theta=-74.435786 -> V=1.0, theta=0.0
% INFO    : Bus 54546	: V=1.0035506, theta=-72.003092 -> V=1.0, theta=0.0
% INFO    : Bus 54547	: V=0.979191, theta=-75.182787 -> V=1.0, theta=0.0
% INFO    : Bus 54548	: V=0.9764308, theta=-75.7788 -> V=1.0, theta=0.0
% INFO    : Bus 54549	: V=0.9859824, theta=-73.908577 -> V=1.0, theta=0.0
% INFO    : Bus 54550	: V=0.9776758, theta=-75.378799 -> V=1.0, theta=0.0
% INFO    : Bus 54551	: V=0.9746981, theta=-75.798937 -> V=1.0, theta=0.0
% INFO    : Bus 54552	: V=0.9756252, theta=-75.779534 -> V=1.0, theta=0.0
% INFO    : Bus 54553	: V=0.9805432, theta=-75.011825 -> V=1.0, theta=0.0
% INFO    : Bus 54554	: V=0.9795511, theta=-74.880313 -> V=1.0, theta=0.0
% INFO    : Bus 54555	: V=0.9801377, theta=-74.841824 -> V=1.0, theta=0.0
% INFO    : Bus 54556	: V=0.9797512, theta=-74.882931 -> V=1.0, theta=0.0
% INFO    : Bus 54557	: V=0.9852345, theta=-74.081106 -> V=1.0, theta=0.0
% INFO    : Bus 54558	: V=0.9867348, theta=-73.841572 -> V=1.0, theta=0.0
% INFO    : Bus 54559	: V=0.9838049, theta=-74.356861 -> V=1.0, theta=0.0
% INFO    : Bus 54560	: V=0.9867214, theta=-73.819699 -> V=1.0, theta=0.0
% INFO    : Bus 54561	: V=0.9841475, theta=-74.191853 -> V=1.0, theta=0.0
% INFO    : Bus 54562	: V=0.9841612, theta=-74.001548 -> V=1.0, theta=0.0
% INFO    : Bus 54563	: V=0.9832291, theta=-74.271031 -> V=1.0, theta=0.0
% INFO    : Bus 54564	: V=0.9762283, theta=-75.544229 -> V=1.0, theta=0.0
% INFO    : Bus 54565	: V=0.9728158, theta=-76.035924 -> V=1.0, theta=0.0
% INFO    : Bus 54566	: V=0.974198, theta=-75.791445 -> V=1.0, theta=0.0
% INFO    : Bus 54567	: V=0.9747752, theta=-75.628729 -> V=1.0, theta=0.0
% INFO    : Bus 54568	: V=0.9738709, theta=-75.993029 -> V=1.0, theta=0.0
% INFO    : Bus 54569	: V=0.9753209, theta=-75.803992 -> V=1.0, theta=0.0
% INFO    : Bus 54570	: V=0.9761582, theta=-75.517887 -> V=1.0, theta=0.0
% INFO    : Bus 54571	: V=0.9753915, theta=-75.611725 -> V=1.0, theta=0.0
% INFO    : Bus 54572	: V=0.9672075, theta=-76.636537 -> V=1.0, theta=0.0
% INFO    : Bus 54573	: V=0.9680204, theta=-76.573474 -> V=1.0, theta=0.0
% INFO    : Bus 54574	: V=0.9684826, theta=-76.557835 -> V=1.0, theta=0.0
% INFO    : Bus 54575	: V=0.9676585, theta=-76.584122 -> V=1.0, theta=0.0
% INFO    : Bus 54576	: V=0.9710476, theta=-75.908021 -> V=1.0, theta=0.0
% INFO    : Bus 54577	: V=0.9667407, theta=-76.677702 -> V=1.0, theta=0.0
% INFO    : Bus 54578	: V=0.9667422, theta=-77.015813 -> V=1.0, theta=0.0
% INFO    : Bus 54579	: V=0.9691071, theta=-76.878389 -> V=1.0, theta=0.0
% INFO    : Bus 54580	: V=0.963888, theta=-77.809378 -> V=1.0, theta=0.0
% INFO    : Bus 54581	: V=0.9643199, theta=-77.823575 -> V=1.0, theta=0.0
% INFO    : Bus 54582	: V=0.964441, theta=-77.320887 -> V=1.0, theta=0.0
% INFO    : Bus 54583	: V=0.965215, theta=-77.437915 -> V=1.0, theta=0.0
% INFO    : Bus 54584	: V=0.9652944, theta=-77.302482 -> V=1.0, theta=0.0
% INFO    : Bus 54585	: V=0.9710947, theta=-75.892884 -> V=1.0, theta=0.0
% INFO    : Bus 54586	: V=0.9631143, theta=-77.918084 -> V=1.0, theta=0.0
% INFO    : Bus 54587	: V=0.9647055, theta=-77.444479 -> V=1.0, theta=0.0
% INFO    : Bus 54588	: V=0.9640986, theta=-77.917585 -> V=1.0, theta=0.0
% INFO    : Bus 54589	: V=0.962565, theta=-78.040229 -> V=1.0, theta=0.0
% INFO    : Bus 54590	: V=0.9637251, theta=-77.7759 -> V=1.0, theta=0.0
% INFO    : Bus 54591	: V=0.963462, theta=-77.967635 -> V=1.0, theta=0.0
% INFO    : Bus 54592	: V=0.9639418, theta=-77.881545 -> V=1.0, theta=0.0
% INFO    : Bus 54593	: V=0.9639305, theta=-77.82383 -> V=1.0, theta=0.0
% INFO    : Bus 54594	: V=0.9642994, theta=-77.661324 -> V=1.0, theta=0.0
% INFO    : Bus 54595	: V=0.9645135, theta=-77.567539 -> V=1.0, theta=0.0
% INFO    : Bus 54596	: V=0.9640243, theta=-77.607356 -> V=1.0, theta=0.0
% INFO    : Bus 54597	: V=0.9638244, theta=-77.615357 -> V=1.0, theta=0.0
% INFO    : Bus 54598	: V=0.964171, theta=-77.474977 -> V=1.0, theta=0.0
% INFO    : Bus 54599	: V=0.9634521, theta=-78.399267 -> V=1.0, theta=0.0
% INFO    : Bus 54600	: V=0.9637178, theta=-78.316689 -> V=1.0, theta=0.0
% INFO    : Bus 54601	: V=0.9651803, theta=-77.096263 -> V=1.0, theta=0.0
% INFO    : Bus 54602	: V=0.963276, theta=-78.477921 -> V=1.0, theta=0.0
% INFO    : Bus 54603	: V=0.9630646, theta=-78.472156 -> V=1.0, theta=0.0
% INFO    : Bus 54604	: V=0.9618052, theta=-78.712688 -> V=1.0, theta=0.0
% INFO    : Bus 54605	: V=0.9625811, theta=-78.592196 -> V=1.0, theta=0.0
% INFO    : Bus 54606	: V=0.9624939, theta=-78.51639 -> V=1.0, theta=0.0
% INFO    : Bus 54607	: V=0.9640435, theta=-77.052277 -> V=1.0, theta=0.0
% INFO    : Bus 54608	: V=0.9597531, theta=-78.952213 -> V=1.0, theta=0.0
% INFO    : Bus 54609	: V=0.9603337, theta=-78.990518 -> V=1.0, theta=0.0
% INFO    : Bus 54610	: V=0.9599921, theta=-78.9161 -> V=1.0, theta=0.0
% INFO    : Bus 54611	: V=0.965618, theta=-76.921339 -> V=1.0, theta=0.0
% INFO    : Bus 54612	: V=0.9648423, theta=-77.984049 -> V=1.0, theta=0.0
% INFO    : Bus 54613	: V=0.9603186, theta=-79.0426 -> V=1.0, theta=0.0
% INFO    : Bus 54614	: V=0.964508, theta=-78.081392 -> V=1.0, theta=0.0
% INFO    : Bus 54615	: V=0.9663765, theta=-77.651954 -> V=1.0, theta=0.0
% INFO    : Bus 54616	: V=0.9653399, theta=-77.964825 -> V=1.0, theta=0.0
% INFO    : Bus 54617	: V=0.9683544, theta=-76.476564 -> V=1.0, theta=0.0
% INFO    : Bus 54618	: V=0.9629821, theta=-78.519181 -> V=1.0, theta=0.0
% INFO    : Bus 54619	: V=0.9640746, theta=-78.168942 -> V=1.0, theta=0.0
% INFO    : Bus 54620	: V=0.9646625, theta=-77.949629 -> V=1.0, theta=0.0
% INFO    : Bus 54621	: V=0.9835224, theta=-72.929182 -> V=1.0, theta=0.0
% INFO    : Bus 54622	: V=0.963232, theta=-77.427159 -> V=1.0, theta=0.0
% INFO    : Bus 54623	: V=0.959001, theta=-78.526653 -> V=1.0, theta=0.0
% INFO    : Bus 54624	: V=0.9591705, theta=-78.468609 -> V=1.0, theta=0.0
% INFO    : Bus 54625	: V=0.9610262, theta=-78.264233 -> V=1.0, theta=0.0
% INFO    : Bus 54626	: V=0.9603032, theta=-78.311802 -> V=1.0, theta=0.0
% INFO    : Bus 54627	: V=0.9604508, theta=-78.933713 -> V=1.0, theta=0.0
% INFO    : Bus 54628	: V=0.9621362, theta=-78.614194 -> V=1.0, theta=0.0
% INFO    : Bus 54629	: V=0.9630976, theta=-78.538711 -> V=1.0, theta=0.0
% INFO    : Bus 54630	: V=0.9620858, theta=-78.601589 -> V=1.0, theta=0.0
% INFO    : Bus 54631	: V=0.9587458, theta=-79.162249 -> V=1.0, theta=0.0
% INFO    : Bus 54632	: V=0.9523126, theta=-80.33951 -> V=1.0, theta=0.0
% INFO    : Bus 54633	: V=0.9593095, theta=-79.121189 -> V=1.0, theta=0.0
% INFO    : Bus 54634	: V=0.9604178, theta=-78.954865 -> V=1.0, theta=0.0
% INFO    : Bus 54635	: V=0.9593347, theta=-79.100915 -> V=1.0, theta=0.0
% INFO    : Bus 54636	: V=0.9623372, theta=-78.674337 -> V=1.0, theta=0.0
% INFO    : Bus 54637	: V=0.9610157, theta=-78.867633 -> V=1.0, theta=0.0
% INFO    : Bus 54638	: V=0.9627133, theta=-78.556942 -> V=1.0, theta=0.0
% INFO    : Bus 54639	: V=0.9582439, theta=-78.562557 -> V=1.0, theta=0.0
% INFO    : Bus 54640	: V=0.9618827, theta=-78.696077 -> V=1.0, theta=0.0
% INFO    : Bus 54641	: V=0.9612773, theta=-78.773242 -> V=1.0, theta=0.0
% INFO    : Bus 54642	: V=0.9600053, theta=-78.962382 -> V=1.0, theta=0.0
% INFO    : Bus 54643	: V=0.9584193, theta=-79.196262 -> V=1.0, theta=0.0
% INFO    : Bus 54644	: V=0.9577313, theta=-79.228968 -> V=1.0, theta=0.0
% INFO    : Bus 54645	: V=0.9597013, theta=-78.451366 -> V=1.0, theta=0.0
% INFO    : Bus 54646	: V=0.9623964, theta=-77.598705 -> V=1.0, theta=0.0
% INFO    : Bus 54647	: V=0.9592691, theta=-78.471971 -> V=1.0, theta=0.0
% INFO    : Bus 54648	: V=0.9659237, theta=-77.192113 -> V=1.0, theta=0.0
% INFO    : Bus 54649	: V=0.9605974, theta=-78.309366 -> V=1.0, theta=0.0
% INFO    : Bus 54650	: V=0.9613219, theta=-78.137386 -> V=1.0, theta=0.0
% INFO    : Bus 54651	: V=0.9598666, theta=-78.573812 -> V=1.0, theta=0.0
% INFO    : Bus 54652	: V=0.9600824, theta=-78.41313 -> V=1.0, theta=0.0
% INFO    : Bus 54653	: V=0.9594692, theta=-78.454457 -> V=1.0, theta=0.0
% INFO    : Bus 54654	: V=0.9590571, theta=-78.481572 -> V=1.0, theta=0.0
% INFO    : Bus 54655	: V=0.9594736, theta=-79.070504 -> V=1.0, theta=0.0
% INFO    : Bus 54656	: V=0.9595632, theta=-78.774899 -> V=1.0, theta=0.0
% INFO    : Bus 54657	: V=0.9655424, theta=-77.46029 -> V=1.0, theta=0.0
% INFO    : Bus 54658	: V=0.9617831, theta=-77.879449 -> V=1.0, theta=0.0
% INFO    : Bus 54659	: V=0.9618221, theta=-77.901381 -> V=1.0, theta=0.0
% INFO    : Bus 54660	: V=0.9692552, theta=-76.174325 -> V=1.0, theta=0.0
% INFO    : Bus 54661	: V=0.9639068, theta=-77.716207 -> V=1.0, theta=0.0
% INFO    : Bus 54662	: V=0.9608732, theta=-77.903337 -> V=1.0, theta=0.0
% INFO    : Bus 54663	: V=0.9612426, theta=-77.941524 -> V=1.0, theta=0.0
% INFO    : Bus 54664	: V=0.9607658, theta=-77.989321 -> V=1.0, theta=0.0
% INFO    : Bus 54665	: V=0.9607419, theta=-78.024783 -> V=1.0, theta=0.0
% INFO    : Bus 54666	: V=0.9611457, theta=-77.97076 -> V=1.0, theta=0.0
% INFO    : Bus 54667	: V=0.9627852, theta=-77.571128 -> V=1.0, theta=0.0
% INFO    : Bus 54668	: V=0.9636144, theta=-77.505397 -> V=1.0, theta=0.0
% INFO    : Bus 54669	: V=0.9644183, theta=-77.431601 -> V=1.0, theta=0.0
% INFO    : Bus 54670	: V=0.9620308, theta=-77.853024 -> V=1.0, theta=0.0
% INFO    : Bus 54671	: V=0.9655214, theta=-77.3482 -> V=1.0, theta=0.0
% INFO    : Bus 54672	: V=0.9673687, theta=-77.086539 -> V=1.0, theta=0.0
% INFO    : Bus 54673	: V=0.9737961, theta=-75.737919 -> V=1.0, theta=0.0
% INFO    : Bus 54674	: V=0.9617383, theta=-77.867433 -> V=1.0, theta=0.0
% INFO    : Bus 54675	: V=0.9729628, theta=-75.775842 -> V=1.0, theta=0.0
% INFO    : Bus 54676	: V=0.9627966, theta=-77.728736 -> V=1.0, theta=0.0
% INFO    : Bus 54677	: V=0.964119, theta=-77.589016 -> V=1.0, theta=0.0
% INFO    : Bus 54678	: V=0.9682815, theta=-76.929369 -> V=1.0, theta=0.0
% INFO    : Bus 54679	: V=0.9733654, theta=-75.666414 -> V=1.0, theta=0.0
% INFO    : Bus 54680	: V=0.9635358, theta=-77.543013 -> V=1.0, theta=0.0
% INFO    : Bus 54681	: V=0.9651702, theta=-77.224313 -> V=1.0, theta=0.0
% INFO    : Bus 54682	: V=0.9719468, theta=-76.324957 -> V=1.0, theta=0.0
% INFO    : Bus 54683	: V=0.9718071, theta=-76.432586 -> V=1.0, theta=0.0
% INFO    : Bus 54684	: V=0.9723103, theta=-76.418611 -> V=1.0, theta=0.0
% INFO    : Bus 54685	: V=0.9712934, theta=-76.517141 -> V=1.0, theta=0.0
% INFO    : Bus 54686	: V=0.9715996, theta=-76.404112 -> V=1.0, theta=0.0
% INFO    : Bus 54687	: V=0.9741853, theta=-76.21629 -> V=1.0, theta=0.0
% INFO    : Bus 54688	: V=0.9854486, theta=-73.837729 -> V=1.0, theta=0.0
% INFO    : Bus 54689	: V=0.9695582, theta=-76.683674 -> V=1.0, theta=0.0
% INFO    : Bus 54690	: V=0.9695914, theta=-76.771731 -> V=1.0, theta=0.0
% INFO    : Bus 54691	: V=0.9690556, theta=-76.786629 -> V=1.0, theta=0.0
% INFO    : Bus 54692	: V=0.9877716, theta=-73.419533 -> V=1.0, theta=0.0
% INFO    : Bus 54693	: V=0.9683489, theta=-76.953576 -> V=1.0, theta=0.0
% INFO    : Bus 54694	: V=0.967336, theta=-77.054302 -> V=1.0, theta=0.0
% INFO    : Bus 54695	: V=0.9657557, theta=-77.16362 -> V=1.0, theta=0.0
% INFO    : Bus 54696	: V=0.9654746, theta=-77.171531 -> V=1.0, theta=0.0
% INFO    : Bus 54697	: V=0.9661653, theta=-77.596779 -> V=1.0, theta=0.0
% INFO    : Bus 54698	: V=0.9663929, theta=-77.092981 -> V=1.0, theta=0.0
% INFO    : Bus 54699	: V=0.9658844, theta=-77.24527 -> V=1.0, theta=0.0
% INFO    : Bus 54700	: V=0.9653069, theta=-77.341295 -> V=1.0, theta=0.0
% INFO    : Bus 54701	: V=0.9642991, theta=-77.366577 -> V=1.0, theta=0.0
% INFO    : Bus 54702	: V=0.9615949, theta=-78.167999 -> V=1.0, theta=0.0
% INFO    : Bus 54703	: V=0.9589585, theta=-77.57439 -> V=1.0, theta=0.0
% INFO    : Bus 54704	: V=0.9616872, theta=-78.164637 -> V=1.0, theta=0.0
% INFO    : Bus 54705	: V=0.9624339, theta=-78.099571 -> V=1.0, theta=0.0
% INFO    : Bus 54706	: V=0.9630707, theta=-78.610071 -> V=1.0, theta=0.0
% INFO    : Bus 54707	: V=0.9624249, theta=-78.043088 -> V=1.0, theta=0.0
% INFO    : Bus 54708	: V=0.9634284, theta=-77.782603 -> V=1.0, theta=0.0
% INFO    : Bus 54709	: V=0.9635193, theta=-76.723163 -> V=1.0, theta=0.0
% INFO    : Bus 54710	: V=0.9630072, theta=-76.808917 -> V=1.0, theta=0.0
% INFO    : Bus 54711	: V=0.9638758, theta=-76.639584 -> V=1.0, theta=0.0
% INFO    : Bus 54712	: V=0.9625951, theta=-78.579873 -> V=1.0, theta=0.0
% INFO    : Bus 54713	: V=0.9617763, theta=-78.774214 -> V=1.0, theta=0.0
% INFO    : Bus 54714	: V=0.9624767, theta=-78.395514 -> V=1.0, theta=0.0
% INFO    : Bus 54715	: V=0.9628255, theta=-78.163127 -> V=1.0, theta=0.0
% INFO    : Bus 54716	: V=1.0027176, theta=-72.813089 -> V=1.0, theta=0.0
% INFO    : Bus 54717	: V=0.9636282, theta=-77.86023 -> V=1.0, theta=0.0
% INFO    : Bus 54718	: V=0.9581118, theta=-77.825084 -> V=1.0, theta=0.0
% INFO    : Bus 54719	: V=0.9582671, theta=-78.005948 -> V=1.0, theta=0.0
% INFO    : Bus 54720	: V=0.9676133, theta=-77.641466 -> V=1.0, theta=0.0
% INFO    : Bus 54721	: V=0.9612782, theta=-78.947767 -> V=1.0, theta=0.0
% INFO    : Bus 54722	: V=0.9619627, theta=-78.620227 -> V=1.0, theta=0.0
% INFO    : Bus 54723	: V=0.9633358, theta=-78.974246 -> V=1.0, theta=0.0
% INFO    : Bus 54724	: V=0.9642851, theta=-77.80483 -> V=1.0, theta=0.0
% INFO    : Bus 54725	: V=0.9606276, theta=-79.201586 -> V=1.0, theta=0.0
% INFO    : Bus 54726	: V=0.9605192, theta=-77.22578 -> V=1.0, theta=0.0
% INFO    : Bus 54727	: V=0.9666716, theta=-76.058024 -> V=1.0, theta=0.0
% INFO    : Bus 54728	: V=0.9605641, theta=-79.047583 -> V=1.0, theta=0.0
% INFO    : Bus 54729	: V=0.9613046, theta=-79.082168 -> V=1.0, theta=0.0
% INFO    : Bus 54730	: V=0.962552, theta=-79.054297 -> V=1.0, theta=0.0
% INFO    : Bus 54731	: V=0.9640054, theta=-77.844066 -> V=1.0, theta=0.0
% INFO    : Bus 54732	: V=0.9647448, theta=-77.750554 -> V=1.0, theta=0.0
% INFO    : Bus 54733	: V=0.9652932, theta=-77.675884 -> V=1.0, theta=0.0
% INFO    : Bus 54734	: V=0.9623641, theta=-78.895097 -> V=1.0, theta=0.0
% INFO    : Bus 54735	: V=0.9591985, theta=-77.240348 -> V=1.0, theta=0.0
% INFO    : Bus 54736	: V=0.9615112, theta=-78.28218 -> V=1.0, theta=0.0
% INFO    : Bus 54737	: V=0.965301, theta=-76.338228 -> V=1.0, theta=0.0
% INFO    : Bus 54738	: V=0.970859, theta=-76.79127 -> V=1.0, theta=0.0
% INFO    : Bus 54739	: V=0.9633432, theta=-78.726995 -> V=1.0, theta=0.0
% INFO    : Bus 54740	: V=0.9643028, theta=-78.401618 -> V=1.0, theta=0.0
% INFO    : Bus 54741	: V=0.9693848, theta=-77.486598 -> V=1.0, theta=0.0
% INFO    : Bus 54742	: V=0.9638588, theta=-78.298646 -> V=1.0, theta=0.0
% INFO    : Bus 54743	: V=0.9711212, theta=-77.294842 -> V=1.0, theta=0.0
% INFO    : Bus 54744	: V=0.9685256, theta=-77.578244 -> V=1.0, theta=0.0
% INFO    : Bus 54745	: V=0.97521, theta=-76.774664 -> V=1.0, theta=0.0
% INFO    : Bus 54746	: V=0.9786388, theta=-76.464265 -> V=1.0, theta=0.0
% INFO    : Bus 54747	: V=0.9915314, theta=-73.360225 -> V=1.0, theta=0.0
% INFO    : Bus 54748	: V=0.983097, theta=-74.997665 -> V=1.0, theta=0.0
% INFO    : Bus 54749	: V=0.9818553, theta=-75.097661 -> V=1.0, theta=0.0
% INFO    : Bus 54750	: V=0.9803297, theta=-75.189771 -> V=1.0, theta=0.0
% INFO    : Bus 54751	: V=0.9862035, theta=-74.373104 -> V=1.0, theta=0.0
% INFO    : Bus 54752	: V=0.9867347, theta=-74.376496 -> V=1.0, theta=0.0
% INFO    : Bus 54753	: V=0.9881848, theta=-74.193747 -> V=1.0, theta=0.0
% INFO    : Bus 54754	: V=0.9890956, theta=-74.065691 -> V=1.0, theta=0.0
% INFO    : Bus 54755	: V=0.9927777, theta=-73.535418 -> V=1.0, theta=0.0
% INFO    : Bus 54756	: V=0.9931513, theta=-73.519956 -> V=1.0, theta=0.0
% INFO    : Bus 54757	: V=0.9942776, theta=-73.442135 -> V=1.0, theta=0.0
% INFO    : Bus 54758	: V=0.9904752, theta=-73.87606 -> V=1.0, theta=0.0
% INFO    : Bus 54759	: V=0.9911934, theta=-73.659518 -> V=1.0, theta=0.0
% INFO    : Bus 54760	: V=0.9895771, theta=-73.912956 -> V=1.0, theta=0.0
% INFO    : Bus 54761	: V=1.0054558, theta=-71.931741 -> V=1.0, theta=0.0
% INFO    : Bus 54762	: V=0.9861881, theta=-74.395677 -> V=1.0, theta=0.0
% INFO    : Bus 54763	: V=0.9862139, theta=-74.304089 -> V=1.0, theta=0.0
% INFO    : Bus 54764	: V=0.9877669, theta=-74.139215 -> V=1.0, theta=0.0
% INFO    : Bus 54765	: V=0.9919614, theta=-73.441179 -> V=1.0, theta=0.0
% INFO    : Bus 54766	: V=0.9863921, theta=-74.427184 -> V=1.0, theta=0.0
% INFO    : Bus 54767	: V=0.986721, theta=-74.404805 -> V=1.0, theta=0.0
% INFO    : Bus 54768	: V=0.986272, theta=-74.104214 -> V=1.0, theta=0.0
% INFO    : Bus 54769	: V=0.9852207, theta=-74.280886 -> V=1.0, theta=0.0
% INFO    : Bus 54770	: V=0.9849782, theta=-74.232908 -> V=1.0, theta=0.0
% INFO    : Bus 54771	: V=0.9798759, theta=-75.097105 -> V=1.0, theta=0.0
% INFO    : Bus 54772	: V=0.9913292, theta=-73.293368 -> V=1.0, theta=0.0
% INFO    : Bus 54773	: V=0.9901741, theta=-73.464205 -> V=1.0, theta=0.0
% INFO    : Bus 54774	: V=0.9856547, theta=-74.230865 -> V=1.0, theta=0.0
% INFO    : Bus 54775	: V=0.9874282, theta=-73.911422 -> V=1.0, theta=0.0
% INFO    : Bus 54776	: V=0.9885301, theta=-73.723066 -> V=1.0, theta=0.0
% INFO    : Bus 54777	: V=0.9849747, theta=-74.163132 -> V=1.0, theta=0.0
% INFO    : Bus 54778	: V=0.9864535, theta=-73.838545 -> V=1.0, theta=0.0
% INFO    : Bus 54779	: V=0.9809132, theta=-75.059779 -> V=1.0, theta=0.0
% INFO    : Bus 54780	: V=0.993942, theta=-72.998311 -> V=1.0, theta=0.0
% INFO    : Bus 54781	: V=0.9853115, theta=-73.882759 -> V=1.0, theta=0.0
% INFO    : Bus 54782	: V=0.9930334, theta=-72.843424 -> V=1.0, theta=0.0
% INFO    : Bus 54783	: V=1.001986, theta=-71.469262 -> V=1.0, theta=0.0
% INFO    : Bus 54784	: V=1.0042487, theta=-71.343953 -> V=1.0, theta=0.0
% INFO    : Bus 54785	: V=0.9807733, theta=-73.912171 -> V=1.0, theta=0.0
% INFO    : Bus 54786	: V=0.9873125, theta=-73.225132 -> V=1.0, theta=0.0
% INFO    : Bus 54787	: V=0.9831375, theta=-73.32151 -> V=1.0, theta=0.0
% INFO    : Bus 54788	: V=0.9778466, theta=-74.144635 -> V=1.0, theta=0.0
% INFO    : Bus 54789	: V=0.9895309, theta=-72.481253 -> V=1.0, theta=0.0
% INFO    : Bus 54790	: V=0.9875098, theta=-73.763037 -> V=1.0, theta=0.0
% INFO    : Bus 54791	: V=0.9870494, theta=-73.796138 -> V=1.0, theta=0.0
% INFO    : Bus 54792	: V=0.9904705, theta=-73.256664 -> V=1.0, theta=0.0
% INFO    : Bus 54793	: V=0.9892336, theta=-73.442344 -> V=1.0, theta=0.0
% INFO    : Bus 54794	: V=0.9878853, theta=-73.645302 -> V=1.0, theta=0.0
% INFO    : Bus 54795	: V=0.9937482, theta=-72.787855 -> V=1.0, theta=0.0
% INFO    : Bus 54796	: V=0.9892606, theta=-72.768374 -> V=1.0, theta=0.0
% INFO    : Bus 54797	: V=0.9924748, theta=-72.130147 -> V=1.0, theta=0.0
% INFO    : Bus 54798	: V=0.9881742, theta=-72.817985 -> V=1.0, theta=0.0
% INFO    : Bus 54799	: V=0.9881057, theta=-73.370709 -> V=1.0, theta=0.0
% INFO    : Bus 54800	: V=0.9965856, theta=-72.216404 -> V=1.0, theta=0.0
% INFO    : Bus 54801	: V=0.9886513, theta=-73.662375 -> V=1.0, theta=0.0
% INFO    : Bus 54802	: V=0.982015, theta=-73.822545 -> V=1.0, theta=0.0
% INFO    : Bus 54803	: V=0.9898998, theta=-72.564552 -> V=1.0, theta=0.0
% INFO    : Bus 54804	: V=0.996444, theta=-72.22086 -> V=1.0, theta=0.0
% INFO    : Bus 54805	: V=0.9965668, theta=-72.350343 -> V=1.0, theta=0.0
% INFO    : Bus 54806	: V=0.9864415, theta=-73.530017 -> V=1.0, theta=0.0
% INFO    : Bus 54807	: V=0.9981969, theta=-74.242399 -> V=1.0, theta=0.0
% INFO    : Bus 54808	: V=0.9904115, theta=-73.152928 -> V=1.0, theta=0.0
% INFO    : Bus 54809	: V=1.000254, theta=-71.557181 -> V=1.0, theta=0.0
% INFO    : Bus 54810	: V=0.999405, theta=-71.669079 -> V=1.0, theta=0.0
% INFO    : Bus 54811	: V=0.9982373, theta=-71.823698 -> V=1.0, theta=0.0
% INFO    : Bus 54812	: V=0.9891929, theta=-73.454256 -> V=1.0, theta=0.0
% INFO    : Bus 54813	: V=0.9884418, theta=-73.654459 -> V=1.0, theta=0.0
% INFO    : Bus 54814	: V=0.9960638, theta=-71.965761 -> V=1.0, theta=0.0
% INFO    : Bus 54815	: V=0.9715533, theta=-76.161228 -> V=1.0, theta=0.0
% INFO    : Bus 54816	: V=0.9733524, theta=-75.931815 -> V=1.0, theta=0.0
% INFO    : Bus 54817	: V=0.9941708, theta=-72.135662 -> V=1.0, theta=0.0
% INFO    : Bus 54818	: V=0.9824659, theta=-74.282577 -> V=1.0, theta=0.0
% INFO    : Bus 54819	: V=0.9827849, theta=-74.237706 -> V=1.0, theta=0.0
% INFO    : Bus 54820	: V=0.9837134, theta=-74.127742 -> V=1.0, theta=0.0
% INFO    : Bus 54821	: V=0.9831968, theta=-74.188691 -> V=1.0, theta=0.0
% INFO    : Bus 54822	: V=0.9721633, theta=-75.952656 -> V=1.0, theta=0.0
% INFO    : Bus 54823	: V=0.9725067, theta=-76.033518 -> V=1.0, theta=0.0
% INFO    : Bus 54824	: V=0.9733802, theta=-75.813093 -> V=1.0, theta=0.0
% INFO    : Bus 54825	: V=0.9721679, theta=-75.917039 -> V=1.0, theta=0.0
% INFO    : Bus 54826	: V=0.9717925, theta=-76.096927 -> V=1.0, theta=0.0
% INFO    : Bus 54827	: V=0.973197, theta=-75.940715 -> V=1.0, theta=0.0
% INFO    : Bus 54828	: V=0.9739655, theta=-75.9093 -> V=1.0, theta=0.0
% INFO    : Bus 54829	: V=0.9710636, theta=-75.961876 -> V=1.0, theta=0.0
% INFO    : Bus 54830	: V=0.9697244, theta=-76.163634 -> V=1.0, theta=0.0
% INFO    : Bus 54831	: V=0.9684265, theta=-76.256283 -> V=1.0, theta=0.0
% INFO    : Bus 54832	: V=0.9714864, theta=-76.07493 -> V=1.0, theta=0.0
% INFO    : Bus 54833	: V=0.9774886, theta=-74.375528 -> V=1.0, theta=0.0
% INFO    : Bus 54834	: V=0.9783874, theta=-74.343091 -> V=1.0, theta=0.0
% INFO    : Bus 54835	: V=0.9760236, theta=-74.890729 -> V=1.0, theta=0.0
% INFO    : Bus 54836	: V=0.9683571, theta=-76.261748 -> V=1.0, theta=0.0
% INFO    : Bus 54837	: V=0.9687239, theta=-76.231511 -> V=1.0, theta=0.0
% INFO    : Bus 54838	: V=0.9775024, theta=-74.444988 -> V=1.0, theta=0.0
% INFO    : Bus 54839	: V=0.9715334, theta=-75.916897 -> V=1.0, theta=0.0
% INFO    : Bus 54840	: V=0.972139, theta=-75.900314 -> V=1.0, theta=0.0
% INFO    : Bus 54841	: V=0.9720468, theta=-76.086438 -> V=1.0, theta=0.0
% INFO    : Bus 54842	: V=0.9716638, theta=-76.138051 -> V=1.0, theta=0.0
% INFO    : Bus 54843	: V=0.9715098, theta=-75.714804 -> V=1.0, theta=0.0
% INFO    : Bus 54844	: V=0.9763622, theta=-74.680008 -> V=1.0, theta=0.0
% INFO    : Bus 54845	: V=0.9698738, theta=-76.100058 -> V=1.0, theta=0.0
% INFO    : Bus 54846	: V=0.974799, theta=-75.036266 -> V=1.0, theta=0.0
% INFO    : Bus 54847	: V=0.9899916, theta=-72.434948 -> V=1.0, theta=0.0
% INFO    : Bus 54848	: V=0.9715669, theta=-76.099724 -> V=1.0, theta=0.0
% INFO    : Bus 54849	: V=0.976309, theta=-74.840961 -> V=1.0, theta=0.0
% INFO    : Bus 54850	: V=0.975973, theta=-74.303628 -> V=1.0, theta=0.0
% INFO    : Bus 54851	: V=0.9743942, theta=-75.203594 -> V=1.0, theta=0.0
% INFO    : Bus 54852	: V=0.9704625, theta=-76.543589 -> V=1.0, theta=0.0
% INFO    : Bus 54853	: V=0.9688392, theta=-76.883609 -> V=1.0, theta=0.0
% INFO    : Bus 54854	: V=0.9725111, theta=-75.665458 -> V=1.0, theta=0.0
% INFO    : Bus 54855	: V=0.9650325, theta=-77.593522 -> V=1.0, theta=0.0
% INFO    : Bus 54856	: V=0.9661505, theta=-77.37123 -> V=1.0, theta=0.0
% INFO    : Bus 54857	: V=0.9715729, theta=-75.826164 -> V=1.0, theta=0.0
% INFO    : Bus 54858	: V=0.9670919, theta=-76.648304 -> V=1.0, theta=0.0
% INFO    : Bus 54859	: V=0.9661112, theta=-76.790207 -> V=1.0, theta=0.0
% INFO    : Bus 54860	: V=0.9722361, theta=-76.103167 -> V=1.0, theta=0.0
% INFO    : Bus 54861	: V=0.9723158, theta=-76.104765 -> V=1.0, theta=0.0
% INFO    : Bus 54862	: V=0.9686874, theta=-76.649453 -> V=1.0, theta=0.0
% INFO    : Bus 54863	: V=0.9735213, theta=-75.485383 -> V=1.0, theta=0.0
% INFO    : Bus 54864	: V=0.9680266, theta=-76.745089 -> V=1.0, theta=0.0
% INFO    : Bus 54865	: V=0.9685274, theta=-76.72578 -> V=1.0, theta=0.0
% INFO    : Bus 54866	: V=0.9683812, theta=-76.800777 -> V=1.0, theta=0.0
% INFO    : Bus 54867	: V=0.9676228, theta=-76.892221 -> V=1.0, theta=0.0
% INFO    : Bus 54868	: V=0.9667554, theta=-76.936071 -> V=1.0, theta=0.0
% INFO    : Bus 54869	: V=0.9645217, theta=-77.086899 -> V=1.0, theta=0.0
% INFO    : Bus 54870	: V=0.9715462, theta=-76.582313 -> V=1.0, theta=0.0
% INFO    : Bus 54871	: V=0.9510598, theta=-80.526994 -> V=1.0, theta=0.0
% INFO    : Bus 54872	: V=0.9684587, theta=-76.494198 -> V=1.0, theta=0.0
% INFO    : Bus 54873	: V=0.9767703, theta=-75.752284 -> V=1.0, theta=0.0
% INFO    : Bus 54874	: V=0.971149, theta=-76.469547 -> V=1.0, theta=0.0
% INFO    : Bus 54875	: V=0.9704398, theta=-76.315357 -> V=1.0, theta=0.0
% INFO    : Bus 54876	: V=0.9683515, theta=-77.065765 -> V=1.0, theta=0.0
% INFO    : Bus 54877	: V=0.9721569, theta=-76.358392 -> V=1.0, theta=0.0
% INFO    : Bus 54878	: V=0.9645165, theta=-77.079734 -> V=1.0, theta=0.0
% INFO    : Bus 54879	: V=0.9590519, theta=-79.13407 -> V=1.0, theta=0.0
% INFO    : Bus 54880	: V=0.9822082, theta=-74.103243 -> V=1.0, theta=0.0
% INFO    : Bus 54881	: V=0.9785805, theta=-58.6493 -> V=1.0, theta=0.0
% INFO    : Bus 54882	: V=0.975132, theta=-58.645322 -> V=1.0, theta=0.0
% INFO    : Bus 54883	: V=0.9769265, theta=-58.614471 -> V=1.0, theta=0.0
% INFO    : Bus 54884	: V=0.9706134, theta=-58.997426 -> V=1.0, theta=0.0
% INFO    : Bus 54885	: V=0.9898367, theta=-58.203628 -> V=1.0, theta=0.0
% INFO    : Bus 54886	: V=0.9823299, theta=-58.888537 -> V=1.0, theta=0.0
% INFO    : Bus 54887	: V=0.9900163, theta=-58.184758 -> V=1.0, theta=0.0
% INFO    : Bus 54888	: V=0.9921339, theta=-58.138563 -> V=1.0, theta=0.0
% INFO    : Bus 54889	: V=0.9927019, theta=-59.340913 -> V=1.0, theta=0.0
% INFO    : Bus 54890	: V=0.9922894, theta=-59.48013 -> V=1.0, theta=0.0
% INFO    : Bus 54891	: V=0.957352, theta=-73.322472 -> V=1.0, theta=0.0
% INFO    : Bus 54892	: V=0.9599517, theta=-74.310157 -> V=1.0, theta=0.0
% INFO    : Bus 54893	: V=0.9595664, theta=-74.443484 -> V=1.0, theta=0.0
% INFO    : Bus 54894	: V=0.9665745, theta=-73.333902 -> V=1.0, theta=0.0
% INFO    : Bus 54895	: V=0.9622119, theta=-74.582147 -> V=1.0, theta=0.0
% INFO    : Bus 54896	: V=0.9657304, theta=-74.392776 -> V=1.0, theta=0.0
% INFO    : Bus 54897	: V=0.9635526, theta=-75.720352 -> V=1.0, theta=0.0
% INFO    : Bus 54898	: V=0.9650076, theta=-74.76747 -> V=1.0, theta=0.0
% INFO    : Bus 54899	: V=0.9648657, theta=-74.921893 -> V=1.0, theta=0.0
% INFO    : Bus 54900	: V=0.963478, theta=-75.722146 -> V=1.0, theta=0.0
% INFO    : Bus 54901	: V=0.9649003, theta=-74.52761 -> V=1.0, theta=0.0
% INFO    : Bus 54902	: V=0.9646418, theta=-74.574036 -> V=1.0, theta=0.0
% INFO    : Bus 54903	: V=0.961912, theta=-74.782506 -> V=1.0, theta=0.0
% INFO    : Bus 54904	: V=0.9604905, theta=-73.605477 -> V=1.0, theta=0.0
% INFO    : Bus 54905	: V=0.9546748, theta=-74.845802 -> V=1.0, theta=0.0
% INFO    : Bus 54906	: V=0.9547761, theta=-73.744477 -> V=1.0, theta=0.0
% INFO    : Bus 54907	: V=0.96508, theta=-72.890105 -> V=1.0, theta=0.0
% INFO    : Bus 54908	: V=0.9668022, theta=-74.641685 -> V=1.0, theta=0.0
% INFO    : Bus 54909	: V=0.9674942, theta=-74.861876 -> V=1.0, theta=0.0
% INFO    : Bus 54910	: V=0.9714102, theta=-73.675994 -> V=1.0, theta=0.0
% INFO    : Bus 54911	: V=0.969505, theta=-74.332925 -> V=1.0, theta=0.0
% INFO    : Bus 54912	: V=0.9757903, theta=-72.370442 -> V=1.0, theta=0.0
% INFO    : Bus 54913	: V=0.9702433, theta=-73.078207 -> V=1.0, theta=0.0
% INFO    : Bus 54914	: V=0.9677732, theta=-73.470818 -> V=1.0, theta=0.0
% INFO    : Bus 54915	: V=0.9587195, theta=-74.360981 -> V=1.0, theta=0.0
% INFO    : Bus 54916	: V=0.9596077, theta=-74.48316 -> V=1.0, theta=0.0
% INFO    : Bus 54917	: V=0.9660861, theta=-73.772539 -> V=1.0, theta=0.0
% INFO    : Bus 54918	: V=0.9597053, theta=-74.611034 -> V=1.0, theta=0.0
% INFO    : Bus 54919	: V=0.9667957, theta=-72.825596 -> V=1.0, theta=0.0
% INFO    : Bus 54920	: V=0.9607046, theta=-74.557453 -> V=1.0, theta=0.0
% INFO    : Bus 54921	: V=0.9832035, theta=-67.795585 -> V=1.0, theta=0.0
% INFO    : Bus 54922	: V=0.9618093, theta=-74.457965 -> V=1.0, theta=0.0
% INFO    : Bus 54923	: V=0.9690474, theta=-73.223542 -> V=1.0, theta=0.0
% INFO    : Bus 54924	: V=0.9663984, theta=-73.75196 -> V=1.0, theta=0.0
% INFO    : Bus 54925	: V=0.9664151, theta=-73.709126 -> V=1.0, theta=0.0
% INFO    : Bus 54926	: V=0.9665369, theta=-73.737106 -> V=1.0, theta=0.0
% INFO    : Bus 54927	: V=0.9668801, theta=-73.721477 -> V=1.0, theta=0.0
% INFO    : Bus 54928	: V=0.9609607, theta=-74.72657 -> V=1.0, theta=0.0
% INFO    : Bus 54929	: V=0.9695617, theta=-73.635989 -> V=1.0, theta=0.0
% INFO    : Bus 54930	: V=0.9689719, theta=-73.57701 -> V=1.0, theta=0.0
% INFO    : Bus 54931	: V=0.9653633, theta=-74.437409 -> V=1.0, theta=0.0
% INFO    : Bus 54932	: V=0.9686409, theta=-74.010359 -> V=1.0, theta=0.0
% INFO    : Bus 54933	: V=0.9626996, theta=-74.896816 -> V=1.0, theta=0.0
% INFO    : Bus 54934	: V=1.0103977, theta=-71.706183 -> V=1.0, theta=0.0
% INFO    : Bus 54935	: V=0.9651733, theta=-75.218122 -> V=1.0, theta=0.0
% INFO    : Bus 54936	: V=0.9659261, theta=-74.5395 -> V=1.0, theta=0.0
% INFO    : Bus 54937	: V=0.9677857, theta=-73.534127 -> V=1.0, theta=0.0
% INFO    : Bus 54938	: V=0.9621413, theta=-74.990366 -> V=1.0, theta=0.0
% INFO    : Bus 54939	: V=0.9675329, theta=-74.277884 -> V=1.0, theta=0.0
% INFO    : Bus 54940	: V=0.9650824, theta=-75.74126 -> V=1.0, theta=0.0
% INFO    : Bus 54941	: V=0.966662, theta=-74.494245 -> V=1.0, theta=0.0
% INFO    : Bus 54942	: V=0.9633453, theta=-77.704545 -> V=1.0, theta=0.0
% INFO    : Bus 54943	: V=0.9644366, theta=-75.777384 -> V=1.0, theta=0.0
% INFO    : Bus 54944	: V=0.9666931, theta=-74.558148 -> V=1.0, theta=0.0
% INFO    : Bus 54945	: V=0.9647249, theta=-75.545427 -> V=1.0, theta=0.0
% INFO    : Bus 54946	: V=0.9653714, theta=-75.239611 -> V=1.0, theta=0.0
% INFO    : Bus 54947	: V=0.9607328, theta=-77.218924 -> V=1.0, theta=0.0
% INFO    : Bus 54948	: V=0.956025, theta=-78.96237 -> V=1.0, theta=0.0
% INFO    : Bus 54949	: V=0.9600332, theta=-78.157942 -> V=1.0, theta=0.0
% INFO    : Bus 54950	: V=0.9570518, theta=-78.841394 -> V=1.0, theta=0.0
% INFO    : Bus 54951	: V=0.9579582, theta=-78.492434 -> V=1.0, theta=0.0
% INFO    : Bus 54952	: V=0.9571772, theta=-78.528442 -> V=1.0, theta=0.0
% INFO    : Bus 54953	: V=0.9567922, theta=-78.585377 -> V=1.0, theta=0.0
% INFO    : Bus 54954	: V=0.9565117, theta=-78.598977 -> V=1.0, theta=0.0
% INFO    : Bus 54955	: V=0.9579091, theta=-78.505494 -> V=1.0, theta=0.0
% INFO    : Bus 54956	: V=0.9576189, theta=-78.519215 -> V=1.0, theta=0.0
% INFO    : Bus 54957	: V=0.9616613, theta=-77.068042 -> V=1.0, theta=0.0
% INFO    : Bus 54958	: V=0.9649104, theta=-75.053313 -> V=1.0, theta=0.0
% INFO    : Bus 54959	: V=0.9648222, theta=-74.980038 -> V=1.0, theta=0.0
% INFO    : Bus 54960	: V=0.9590546, theta=-78.952371 -> V=1.0, theta=0.0
% INFO    : Bus 54961	: V=0.9584689, theta=-79.010735 -> V=1.0, theta=0.0
% INFO    : Bus 54962	: V=0.9580948, theta=-79.028969 -> V=1.0, theta=0.0
% INFO    : Bus 54963	: V=0.9578546, theta=-79.071099 -> V=1.0, theta=0.0
% INFO    : Bus 54964	: V=0.9581692, theta=-79.252099 -> V=1.0, theta=0.0
% INFO    : Bus 54965	: V=0.9583546, theta=-79.236213 -> V=1.0, theta=0.0
% INFO    : Bus 54966	: V=0.9637474, theta=-77.60802 -> V=1.0, theta=0.0
% INFO    : Bus 54967	: V=0.960198, theta=-78.170182 -> V=1.0, theta=0.0
% INFO    : Bus 54968	: V=0.9625297, theta=-78.511122 -> V=1.0, theta=0.0
% INFO    : Bus 54969	: V=0.9590438, theta=-78.985928 -> V=1.0, theta=0.0
% INFO    : Bus 54970	: V=0.9584881, theta=-79.042006 -> V=1.0, theta=0.0
% INFO    : Bus 54971	: V=0.9602682, theta=-78.501561 -> V=1.0, theta=0.0
% INFO    : Bus 54972	: V=0.9626898, theta=-76.830458 -> V=1.0, theta=0.0
% INFO    : Bus 54973	: V=0.9562227, theta=-79.005408 -> V=1.0, theta=0.0
% INFO    : Bus 54974	: V=0.9593177, theta=-78.671184 -> V=1.0, theta=0.0
% INFO    : Bus 54975	: V=0.9588933, theta=-78.893957 -> V=1.0, theta=0.0
% INFO    : Bus 54976	: V=0.9576833, theta=-79.00092 -> V=1.0, theta=0.0
% INFO    : Bus 54977	: V=0.9572331, theta=-79.011624 -> V=1.0, theta=0.0
% INFO    : Bus 54978	: V=0.9591885, theta=-78.795544 -> V=1.0, theta=0.0
% INFO    : Bus 54979	: V=0.9583491, theta=-78.951125 -> V=1.0, theta=0.0
% INFO    : Bus 54980	: V=0.9575135, theta=-79.289982 -> V=1.0, theta=0.0
% INFO    : Bus 54981	: V=0.9570125, theta=-79.121667 -> V=1.0, theta=0.0
% INFO    : Bus 54982	: V=0.9586635, theta=-79.183673 -> V=1.0, theta=0.0
% INFO    : Bus 54983	: V=0.9589164, theta=-79.130066 -> V=1.0, theta=0.0
% INFO    : Bus 54984	: V=0.95928, theta=-79.046163 -> V=1.0, theta=0.0
% INFO    : Bus 54985	: V=0.9581901, theta=-79.247422 -> V=1.0, theta=0.0
% INFO    : Bus 54986	: V=0.958623, theta=-79.216385 -> V=1.0, theta=0.0
% INFO    : Bus 54987	: V=0.9646228, theta=-75.708203 -> V=1.0, theta=0.0
% INFO    : Bus 54988	: V=0.9641552, theta=-77.429456 -> V=1.0, theta=0.0
% INFO    : Bus 54989	: V=0.964321, theta=-77.224283 -> V=1.0, theta=0.0
% INFO    : Bus 54990	: V=0.9661326, theta=-74.744509 -> V=1.0, theta=0.0
% INFO    : Bus 54991	: V=0.9656108, theta=-75.026465 -> V=1.0, theta=0.0
% INFO    : Bus 54992	: V=0.9650268, theta=-75.538407 -> V=1.0, theta=0.0
% INFO    : Bus 54993	: V=0.9651553, theta=-75.60099 -> V=1.0, theta=0.0
% INFO    : Bus 54994	: V=0.9646746, theta=-77.137335 -> V=1.0, theta=0.0
% INFO    : Bus 54995	: V=0.9640877, theta=-77.398631 -> V=1.0, theta=0.0
% INFO    : Bus 54996	: V=0.9642072, theta=-77.227602 -> V=1.0, theta=0.0
% INFO    : Bus 54997	: V=0.9629586, theta=-77.308052 -> V=1.0, theta=0.0
% INFO    : Bus 54998	: V=0.9637945, theta=-77.268567 -> V=1.0, theta=0.0
% INFO    : Bus 54999	: V=0.9672824, theta=-75.5516 -> V=1.0, theta=0.0
% INFO    : Bus 55000	: V=0.9626452, theta=-77.761158 -> V=1.0, theta=0.0
% INFO    : Bus 55001	: V=0.9643962, theta=-77.353894 -> V=1.0, theta=0.0
% INFO    : Bus 55002	: V=0.9621111, theta=-77.845966 -> V=1.0, theta=0.0
% INFO    : Bus 55003	: V=0.9628554, theta=-77.813225 -> V=1.0, theta=0.0
% INFO    : Bus 55004	: V=0.9631275, theta=-77.796917 -> V=1.0, theta=0.0
% INFO    : Bus 55005	: V=0.9648551, theta=-76.495111 -> V=1.0, theta=0.0
% INFO    : Bus 55006	: V=0.9646127, theta=-76.60667 -> V=1.0, theta=0.0
% INFO    : Bus 55007	: V=0.9644162, theta=-76.698333 -> V=1.0, theta=0.0
% INFO    : Bus 55008	: V=0.9632275, theta=-78.446739 -> V=1.0, theta=0.0
% INFO    : Bus 55009	: V=0.9626884, theta=-78.562105 -> V=1.0, theta=0.0
% INFO    : Bus 55010	: V=0.9629488, theta=-78.492579 -> V=1.0, theta=0.0
% INFO    : Bus 55011	: V=0.9619416, theta=-77.959997 -> V=1.0, theta=0.0
% INFO    : Bus 55012	: V=0.9627101, theta=-77.881722 -> V=1.0, theta=0.0
% INFO    : Bus 55013	: V=0.962495, theta=-77.830199 -> V=1.0, theta=0.0
% INFO    : Bus 55014	: V=0.9637608, theta=-77.443036 -> V=1.0, theta=0.0
% INFO    : Bus 55015	: V=0.9632997, theta=-77.472953 -> V=1.0, theta=0.0
% INFO    : Bus 55016	: V=0.9603138, theta=-78.114528 -> V=1.0, theta=0.0
% INFO    : Bus 55017	: V=0.9608366, theta=-78.089751 -> V=1.0, theta=0.0
% INFO    : Bus 55018	: V=0.9636784, theta=-77.40728 -> V=1.0, theta=0.0
% INFO    : Bus 55019	: V=0.9628443, theta=-77.512057 -> V=1.0, theta=0.0
% INFO    : Bus 55020	: V=0.9616457, theta=-77.563936 -> V=1.0, theta=0.0
% INFO    : Bus 55021	: V=0.9644576, theta=-77.248455 -> V=1.0, theta=0.0
% INFO    : Bus 55022	: V=0.9653762, theta=-75.352354 -> V=1.0, theta=0.0
% INFO    : Bus 55023	: V=0.9651342, theta=-77.029683 -> V=1.0, theta=0.0
% INFO    : Bus 55024	: V=0.9643836, theta=-77.074419 -> V=1.0, theta=0.0
% INFO    : Bus 55025	: V=0.9621493, theta=-77.36739 -> V=1.0, theta=0.0
% INFO    : Bus 55026	: V=0.9583841, theta=-78.501734 -> V=1.0, theta=0.0
% INFO    : Bus 55027	: V=0.9591813, theta=-78.384479 -> V=1.0, theta=0.0
% INFO    : Bus 55028	: V=0.9617799, theta=-68.554 -> V=1.0, theta=0.0
% INFO    : Bus 55029	: V=0.9794642, theta=-66.544016 -> V=1.0, theta=0.0
% INFO    : Bus 55030	: V=0.9947676, theta=-64.550757 -> V=1.0, theta=0.0
% INFO    : Bus 55031	: V=1.0097508, theta=-62.937605 -> V=1.0, theta=0.0
% INFO    : Bus 55032	: V=0.985992, theta=-64.204103 -> V=1.0, theta=0.0
% INFO    : Bus 55033	: V=1.0118051, theta=-56.030577 -> V=1.0, theta=0.0
% INFO    : Bus 55034	: V=0.9874339, theta=-70.23919 -> V=1.0, theta=0.0
% INFO    : Bus 55035	: V=0.9777022, theta=-70.902825 -> V=1.0, theta=0.0
% INFO    : Bus 55036	: V=0.9524197, theta=-61.505537 -> V=1.0, theta=0.0
% INFO    : Bus 55037	: V=0.9513624, theta=-61.50045 -> V=1.0, theta=0.0
% INFO    : Bus 55038	: V=0.9589808, theta=-68.44722 -> V=1.0, theta=0.0
% INFO    : Bus 55039	: V=0.9660713, theta=-69.160591 -> V=1.0, theta=0.0
% INFO    : Bus 55040	: V=0.9863587, theta=-65.605904 -> V=1.0, theta=0.0
% INFO    : Bus 55041	: V=1.0194664, theta=-57.829266 -> V=1.0, theta=0.0
% INFO    : Bus 55042	: V=1.0187749, theta=-57.044929 -> V=1.0, theta=0.0
% INFO    : Bus 55043	: V=1.0159816, theta=-55.604814 -> V=1.0, theta=0.0
% INFO    : Bus 55044	: V=1.0168003, theta=-54.180767 -> V=1.0, theta=0.0
% INFO    : Bus 55045	: V=1.0179018, theta=-56.229791 -> V=1.0, theta=0.0
% INFO    : Bus 55046	: V=1.0108108, theta=-55.664946 -> V=1.0, theta=0.0
% INFO    : Bus 55047	: V=1.0023458, theta=-56.558645 -> V=1.0, theta=0.0
% INFO    : Bus 55048	: V=1.0040985, theta=-56.412054 -> V=1.0, theta=0.0
% INFO    : Bus 55049	: V=1.0030261, theta=-56.524049 -> V=1.0, theta=0.0
% INFO    : Bus 55050	: V=1.0041113, theta=-56.434142 -> V=1.0, theta=0.0
% INFO    : Bus 55051	: V=1.0151913, theta=-55.446382 -> V=1.0, theta=0.0
% INFO    : Bus 55052	: V=1.0138231, theta=-55.514713 -> V=1.0, theta=0.0
% INFO    : Bus 55053	: V=1.0042438, theta=-56.70066 -> V=1.0, theta=0.0
% INFO    : Bus 55054	: V=1.0085166, theta=-56.138564 -> V=1.0, theta=0.0
% INFO    : Bus 55055	: V=1.0151627, theta=-55.522152 -> V=1.0, theta=0.0
% INFO    : Bus 55056	: V=1.0027557, theta=-56.550274 -> V=1.0, theta=0.0
% INFO    : Bus 55057	: V=1.0051968, theta=-56.333324 -> V=1.0, theta=0.0
% INFO    : Bus 55058	: V=1.004602, theta=-56.336467 -> V=1.0, theta=0.0
% INFO    : Bus 55059	: V=1.0088052, theta=-56.097851 -> V=1.0, theta=0.0
% INFO    : Bus 55060	: V=1.0087116, theta=-56.102723 -> V=1.0, theta=0.0
% INFO    : Bus 55061	: V=1.0097427, theta=-55.939716 -> V=1.0, theta=0.0
% INFO    : Bus 55062	: V=1.0007998, theta=-56.907799 -> V=1.0, theta=0.0
% INFO    : Bus 55063	: V=1.0073218, theta=-56.092558 -> V=1.0, theta=0.0
% INFO    : Bus 55064	: V=0.9998382, theta=-56.639396 -> V=1.0, theta=0.0
% INFO    : Bus 55065	: V=0.9991128, theta=-57.11138 -> V=1.0, theta=0.0
% INFO    : Bus 55066	: V=1.0029622, theta=-56.502125 -> V=1.0, theta=0.0
% INFO    : Bus 55067	: V=1.000399, theta=-56.628326 -> V=1.0, theta=0.0
% INFO    : Bus 55068	: V=1.0053573, theta=-56.342916 -> V=1.0, theta=0.0
% INFO    : Bus 55069	: V=1.0107547, theta=-56.110739 -> V=1.0, theta=0.0
% INFO    : Bus 55070	: V=1.0099738, theta=-56.044478 -> V=1.0, theta=0.0
% INFO    : Bus 55071	: V=0.9940778, theta=-56.9896 -> V=1.0, theta=0.0
% INFO    : Bus 55072	: V=1.0065644, theta=-55.610005 -> V=1.0, theta=0.0
% INFO    : Bus 55073	: V=1.0097572, theta=-55.887488 -> V=1.0, theta=0.0
% INFO    : Bus 55074	: V=0.960889, theta=-68.600163 -> V=1.0, theta=0.0
% INFO    : Bus 55075	: V=0.9825813, theta=-76.007526 -> V=1.0, theta=0.0
% INFO    : Bus 55076	: V=0.9866339, theta=-75.462863 -> V=1.0, theta=0.0
% INFO    : Bus 55077	: V=0.9655437, theta=-77.648689 -> V=1.0, theta=0.0
% INFO    : Bus 55078	: V=0.9668709, theta=-77.500824 -> V=1.0, theta=0.0
% INFO    : Bus 55079	: V=0.9685777, theta=-77.232097 -> V=1.0, theta=0.0
% INFO    : Bus 55080	: V=0.9662714, theta=-76.661775 -> V=1.0, theta=0.0
% INFO    : Bus 55081	: V=0.9630431, theta=-77.377412 -> V=1.0, theta=0.0
% INFO    : Bus 55082	: V=0.9653085, theta=-76.683662 -> V=1.0, theta=0.0
% INFO    : Bus 55083	: V=0.9657888, theta=-76.063504 -> V=1.0, theta=0.0
% INFO    : Bus 55084	: V=0.96955, theta=-76.497387 -> V=1.0, theta=0.0
% INFO    : Bus 55085	: V=0.9715534, theta=-76.674961 -> V=1.0, theta=0.0
% INFO    : Bus 55086	: V=0.9628039, theta=-77.516937 -> V=1.0, theta=0.0
% INFO    : Bus 55087	: V=0.9721278, theta=-75.792801 -> V=1.0, theta=0.0
% INFO    : Bus 55088	: V=0.974603, theta=-75.456651 -> V=1.0, theta=0.0
% INFO    : Bus 55089	: V=0.9672388, theta=-76.248498 -> V=1.0, theta=0.0
% INFO    : Bus 55090	: V=0.9705182, theta=-76.02073 -> V=1.0, theta=0.0
% INFO    : Bus 55091	: V=0.9629112, theta=-75.979899 -> V=1.0, theta=0.0
% INFO    : Bus 55092	: V=0.9705138, theta=-75.334629 -> V=1.0, theta=0.0
% INFO    : Bus 55093	: V=0.9610769, theta=-77.955956 -> V=1.0, theta=0.0
% INFO    : Bus 55094	: V=0.9662094, theta=-75.74296 -> V=1.0, theta=0.0
% INFO    : Bus 55095	: V=0.9715062, theta=-73.571834 -> V=1.0, theta=0.0
% INFO    : Bus 55096	: V=0.9660265, theta=-75.891717 -> V=1.0, theta=0.0
% INFO    : Bus 55097	: V=0.9601915, theta=-75.916008 -> V=1.0, theta=0.0
% INFO    : Bus 55098	: V=0.9825588, theta=-73.216713 -> V=1.0, theta=0.0
% INFO    : Bus 55099	: V=0.9803082, theta=-74.604031 -> V=1.0, theta=0.0
% INFO    : Bus 55100	: V=0.9908571, theta=-73.175744 -> V=1.0, theta=0.0
% INFO    : Bus 55101	: V=0.9929349, theta=-74.509284 -> V=1.0, theta=0.0
% INFO    : Bus 55102	: V=0.996442, theta=-73.960395 -> V=1.0, theta=0.0
% INFO    : Bus 55103	: V=0.9878651, theta=-75.162194 -> V=1.0, theta=0.0
% INFO    : Bus 55104	: V=0.992316, theta=-73.812273 -> V=1.0, theta=0.0
% INFO    : Bus 55105	: V=0.9903798, theta=-73.290439 -> V=1.0, theta=0.0
% INFO    : Bus 55106	: V=1.0083865, theta=-73.752366 -> V=1.0, theta=0.0
% INFO    : Bus 55107	: V=1.0168117, theta=-71.418245 -> V=1.0, theta=0.0
% INFO    : Bus 55108	: V=1.0116844, theta=-73.201547 -> V=1.0, theta=0.0
% INFO    : Bus 55109	: V=1.0109923, theta=-73.232423 -> V=1.0, theta=0.0
% INFO    : Bus 55110	: V=1.0108398, theta=-73.332143 -> V=1.0, theta=0.0
% INFO    : Bus 55111	: V=1.0102982, theta=-73.41659 -> V=1.0, theta=0.0
% INFO    : Bus 55112	: V=1.0095746, theta=-73.507804 -> V=1.0, theta=0.0
% INFO    : Bus 55113	: V=1.009983, theta=-73.489407 -> V=1.0, theta=0.0
% INFO    : Bus 55114	: V=1.0100324, theta=-72.769459 -> V=1.0, theta=0.0
% INFO    : Bus 55115	: V=1.0090694, theta=-72.949538 -> V=1.0, theta=0.0
% INFO    : Bus 55116	: V=1.0079834, theta=-73.120334 -> V=1.0, theta=0.0
% INFO    : Bus 55117	: V=1.0096448, theta=-73.525145 -> V=1.0, theta=0.0
% INFO    : Bus 55118	: V=1.0089719, theta=-73.540864 -> V=1.0, theta=0.0
% INFO    : Bus 55119	: V=1.0059403, theta=-73.42223 -> V=1.0, theta=0.0
% INFO    : Bus 55120	: V=1.0068666, theta=-73.291409 -> V=1.0, theta=0.0
% INFO    : Bus 55121	: V=1.0049189, theta=-73.623972 -> V=1.0, theta=0.0
% INFO    : Bus 55122	: V=1.0055169, theta=-73.516127 -> V=1.0, theta=0.0
% INFO    : Bus 55123	: V=1.0055048, theta=-73.531272 -> V=1.0, theta=0.0
% INFO    : Bus 55124	: V=1.0032465, theta=-74.427417 -> V=1.0, theta=0.0
% INFO    : Bus 55125	: V=1.0020718, theta=-74.599895 -> V=1.0, theta=0.0
% INFO    : Bus 55126	: V=1.0006708, theta=-74.327563 -> V=1.0, theta=0.0
% INFO    : Bus 55127	: V=0.9955202, theta=-75.185636 -> V=1.0, theta=0.0
% INFO    : Bus 55128	: V=0.9960743, theta=-75.162478 -> V=1.0, theta=0.0
% INFO    : Bus 55129	: V=1.0000284, theta=-75.662892 -> V=1.0, theta=0.0
% INFO    : Bus 55130	: V=0.9998057, theta=-74.727525 -> V=1.0, theta=0.0
% INFO    : Bus 55131	: V=0.9998753, theta=-74.663947 -> V=1.0, theta=0.0
% INFO    : Bus 55132	: V=0.9999907, theta=-74.59814 -> V=1.0, theta=0.0
% INFO    : Bus 55133	: V=0.998989, theta=-75.689779 -> V=1.0, theta=0.0
% INFO    : Bus 55134	: V=0.999458, theta=-75.697827 -> V=1.0, theta=0.0
% INFO    : Bus 55135	: V=1.0001399, theta=-75.661047 -> V=1.0, theta=0.0
% INFO    : Bus 55136	: V=0.9997211, theta=-75.692232 -> V=1.0, theta=0.0
% INFO    : Bus 55137	: V=0.9947918, theta=-75.924722 -> V=1.0, theta=0.0
% INFO    : Bus 55138	: V=1.0014853, theta=-75.622172 -> V=1.0, theta=0.0
% INFO    : Bus 55139	: V=1.0015034, theta=-75.58821 -> V=1.0, theta=0.0
% INFO    : Bus 55140	: V=0.9993715, theta=-75.736773 -> V=1.0, theta=0.0
% INFO    : Bus 55141	: V=1.002295, theta=-75.546728 -> V=1.0, theta=0.0
% INFO    : Bus 55142	: V=1.0001725, theta=-75.72472 -> V=1.0, theta=0.0
% INFO    : Bus 55143	: V=0.9957602, theta=-75.777356 -> V=1.0, theta=0.0
% INFO    : Bus 55144	: V=0.9940863, theta=-76.043286 -> V=1.0, theta=0.0
% INFO    : Bus 55145	: V=0.9941473, theta=-76.048611 -> V=1.0, theta=0.0
% INFO    : Bus 55146	: V=0.9938538, theta=-76.104247 -> V=1.0, theta=0.0
% INFO    : Bus 55147	: V=0.9937725, theta=-76.113616 -> V=1.0, theta=0.0
% INFO    : Bus 55148	: V=0.9935659, theta=-76.121401 -> V=1.0, theta=0.0
% INFO    : Bus 55149	: V=0.9939101, theta=-76.085429 -> V=1.0, theta=0.0
% INFO    : Bus 55150	: V=0.9941167, theta=-76.020777 -> V=1.0, theta=0.0
% INFO    : Bus 55151	: V=0.9945563, theta=-75.989832 -> V=1.0, theta=0.0
% INFO    : Bus 55152	: V=0.9939062, theta=-76.064239 -> V=1.0, theta=0.0
% INFO    : Bus 55153	: V=0.994168, theta=-76.033773 -> V=1.0, theta=0.0
% INFO    : Bus 55154	: V=0.9938847, theta=-75.775876 -> V=1.0, theta=0.0
% INFO    : Bus 55155	: V=0.9945929, theta=-75.730846 -> V=1.0, theta=0.0
% INFO    : Bus 55156	: V=0.9966135, theta=-75.100624 -> V=1.0, theta=0.0
% INFO    : Bus 55157	: V=0.9951283, theta=-75.652137 -> V=1.0, theta=0.0
% INFO    : Bus 55158	: V=0.9957045, theta=-75.567085 -> V=1.0, theta=0.0
% INFO    : Bus 55159	: V=0.9990032, theta=-73.898142 -> V=1.0, theta=0.0
% INFO    : Bus 55160	: V=0.9968113, theta=-75.254339 -> V=1.0, theta=0.0
% INFO    : Bus 55161	: V=0.9973375, theta=-75.073744 -> V=1.0, theta=0.0
% INFO    : Bus 55162	: V=0.9982366, theta=-74.879003 -> V=1.0, theta=0.0
% INFO    : Bus 55163	: V=0.9979331, theta=-75.007453 -> V=1.0, theta=0.0
% INFO    : Bus 55164	: V=1.0005462, theta=-71.186215 -> V=1.0, theta=0.0
% INFO    : Bus 55165	: V=0.9992432, theta=-73.803191 -> V=1.0, theta=0.0
% INFO    : Bus 55166	: V=0.9975259, theta=-75.091134 -> V=1.0, theta=0.0
% INFO    : Bus 55167	: V=1.0008089, theta=-70.985979 -> V=1.0, theta=0.0
% INFO    : Bus 55168	: V=0.9970786, theta=-74.990447 -> V=1.0, theta=0.0
% INFO    : Bus 55169	: V=0.9977831, theta=-74.852579 -> V=1.0, theta=0.0
% INFO    : Bus 55170	: V=0.99914, theta=-74.500704 -> V=1.0, theta=0.0
% INFO    : Bus 55171	: V=0.9972334, theta=-73.936052 -> V=1.0, theta=0.0
% INFO    : Bus 55172	: V=1.0003192, theta=-74.520472 -> V=1.0, theta=0.0
% INFO    : Bus 55173	: V=0.9947488, theta=-74.024949 -> V=1.0, theta=0.0
% INFO    : Bus 55174	: V=0.9937264, theta=-74.048056 -> V=1.0, theta=0.0
% INFO    : Bus 55175	: V=0.993149, theta=-74.054997 -> V=1.0, theta=0.0
% INFO    : Bus 55176	: V=0.9901175, theta=-75.113054 -> V=1.0, theta=0.0
% INFO    : Bus 55177	: V=0.9896894, theta=-75.90514 -> V=1.0, theta=0.0
% INFO    : Bus 55178	: V=0.9899699, theta=-75.374289 -> V=1.0, theta=0.0
% INFO    : Bus 55179	: V=0.9921504, theta=-75.519069 -> V=1.0, theta=0.0
% INFO    : Bus 55180	: V=0.9894014, theta=-74.826672 -> V=1.0, theta=0.0
% INFO    : Bus 55181	: V=0.9898775, theta=-75.82952 -> V=1.0, theta=0.0
% INFO    : Bus 55182	: V=0.9953242, theta=-74.215402 -> V=1.0, theta=0.0
% INFO    : Bus 55183	: V=0.9922858, theta=-74.055706 -> V=1.0, theta=0.0
% INFO    : Bus 55184	: V=0.9954073, theta=-75.000938 -> V=1.0, theta=0.0
% INFO    : Bus 55185	: V=0.994306, theta=-75.036226 -> V=1.0, theta=0.0
% INFO    : Bus 55186	: V=0.994103, theta=-75.045487 -> V=1.0, theta=0.0
% INFO    : Bus 55187	: V=0.9976717, theta=-74.932879 -> V=1.0, theta=0.0
% INFO    : Bus 55188	: V=1.0002209, theta=-74.728752 -> V=1.0, theta=0.0
% INFO    : Bus 55189	: V=0.9965884, theta=-75.272877 -> V=1.0, theta=0.0
% INFO    : Bus 55190	: V=0.9915953, theta=-75.782569 -> V=1.0, theta=0.0
% INFO    : Bus 55191	: V=0.991073, theta=-75.001189 -> V=1.0, theta=0.0
% INFO    : Bus 55192	: V=0.9914233, theta=-75.037311 -> V=1.0, theta=0.0
% INFO    : Bus 55193	: V=0.9959563, theta=-75.293567 -> V=1.0, theta=0.0
% INFO    : Bus 55194	: V=0.995289, theta=-74.360275 -> V=1.0, theta=0.0
% INFO    : Bus 55195	: V=0.9945837, theta=-74.415881 -> V=1.0, theta=0.0
% INFO    : Bus 55196	: V=0.9928326, theta=-74.492424 -> V=1.0, theta=0.0
% INFO    : Bus 55197	: V=0.9907954, theta=-74.865089 -> V=1.0, theta=0.0
% INFO    : Bus 55198	: V=0.9983704, theta=-75.02133 -> V=1.0, theta=0.0
% INFO    : Bus 55199	: V=0.9962399, theta=-75.065518 -> V=1.0, theta=0.0
% INFO    : Bus 55200	: V=0.9921051, theta=-74.508781 -> V=1.0, theta=0.0
% INFO    : Bus 55201	: V=0.992001, theta=-74.420227 -> V=1.0, theta=0.0
% INFO    : Bus 55202	: V=1.0107245, theta=-72.626089 -> V=1.0, theta=0.0
% INFO    : Bus 55203	: V=1.0003936, theta=-74.680344 -> V=1.0, theta=0.0
% INFO    : Bus 55204	: V=1.0009214, theta=-74.64674 -> V=1.0, theta=0.0
% INFO    : Bus 55205	: V=1.0056083, theta=-74.682864 -> V=1.0, theta=0.0
% INFO    : Bus 55206	: V=1.0192281, theta=-70.997992 -> V=1.0, theta=0.0
% INFO    : Bus 55207	: V=1.018721, theta=-71.118297 -> V=1.0, theta=0.0
% INFO    : Bus 55208	: V=1.0135527, theta=-73.139651 -> V=1.0, theta=0.0
% INFO    : Bus 55209	: V=1.016852, theta=-72.267756 -> V=1.0, theta=0.0
% INFO    : Bus 55210	: V=1.003121, theta=-75.357275 -> V=1.0, theta=0.0
% INFO    : Bus 55211	: V=1.0031051, theta=-75.252163 -> V=1.0, theta=0.0
% INFO    : Bus 55212	: V=1.0035602, theta=-75.380408 -> V=1.0, theta=0.0
% INFO    : Bus 55213	: V=1.003002, theta=-75.456112 -> V=1.0, theta=0.0
% INFO    : Bus 55214	: V=1.0023381, theta=-75.466182 -> V=1.0, theta=0.0
% INFO    : Bus 55215	: V=1.0018204, theta=-75.510383 -> V=1.0, theta=0.0
% INFO    : Bus 55216	: V=1.0036753, theta=-75.374572 -> V=1.0, theta=0.0
% INFO    : Bus 55217	: V=1.0108847, theta=-73.80691 -> V=1.0, theta=0.0
% INFO    : Bus 55218	: V=1.0133033, theta=-72.669924 -> V=1.0, theta=0.0
% INFO    : Bus 55219	: V=1.0085824, theta=-74.165557 -> V=1.0, theta=0.0
% INFO    : Bus 55220	: V=0.9951035, theta=-75.332667 -> V=1.0, theta=0.0
% INFO    : Bus 55221	: V=0.9940965, theta=-75.572344 -> V=1.0, theta=0.0
% INFO    : Bus 55222	: V=0.9910325, theta=-74.997532 -> V=1.0, theta=0.0
% INFO    : Bus 55223	: V=0.991147, theta=-75.750868 -> V=1.0, theta=0.0
% INFO    : Bus 55224	: V=0.9917881, theta=-75.717544 -> V=1.0, theta=0.0
% INFO    : Bus 55225	: V=0.9915031, theta=-75.758586 -> V=1.0, theta=0.0
% INFO    : Bus 55226	: V=0.9849196, theta=-74.281228 -> V=1.0, theta=0.0
% INFO    : Bus 55227	: V=0.9909135, theta=-74.955146 -> V=1.0, theta=0.0
% INFO    : Bus 55228	: V=0.9912535, theta=-75.78022 -> V=1.0, theta=0.0
% INFO    : Bus 55229	: V=0.9910849, theta=-74.80758 -> V=1.0, theta=0.0
% INFO    : Bus 55230	: V=0.9909316, theta=-74.886711 -> V=1.0, theta=0.0
% INFO    : Bus 55231	: V=0.9916129, theta=-75.701237 -> V=1.0, theta=0.0
% INFO    : Bus 55232	: V=0.9914289, theta=-75.750112 -> V=1.0, theta=0.0
% INFO    : Bus 55233	: V=0.9914957, theta=-75.600043 -> V=1.0, theta=0.0
% INFO    : Bus 55234	: V=0.9881505, theta=-76.020842 -> V=1.0, theta=0.0
% INFO    : Bus 55235	: V=0.990273, theta=-74.871409 -> V=1.0, theta=0.0
% INFO    : Bus 55236	: V=0.9897561, theta=-74.888358 -> V=1.0, theta=0.0
% INFO    : Bus 55237	: V=0.981431, theta=-74.142148 -> V=1.0, theta=0.0
% INFO    : Bus 55238	: V=0.9827831, theta=-73.521062 -> V=1.0, theta=0.0
% INFO    : Bus 55239	: V=0.9792432, theta=-74.471474 -> V=1.0, theta=0.0
% INFO    : Bus 55240	: V=0.9773983, theta=-73.756348 -> V=1.0, theta=0.0
% INFO    : Bus 55241	: V=0.9918245, theta=-74.281711 -> V=1.0, theta=0.0
% INFO    : Bus 55242	: V=0.9915173, theta=-74.106686 -> V=1.0, theta=0.0
% INFO    : Bus 55243	: V=0.9868543, theta=-70.791992 -> V=1.0, theta=0.0
% INFO    : Bus 55244	: V=0.9887449, theta=-75.181691 -> V=1.0, theta=0.0
% INFO    : Bus 55245	: V=0.9890167, theta=-74.071663 -> V=1.0, theta=0.0
% INFO    : Bus 55246	: V=0.9896419, theta=-74.607472 -> V=1.0, theta=0.0
% INFO    : Bus 55247	: V=0.9778762, theta=-70.324196 -> V=1.0, theta=0.0
% INFO    : Bus 55248	: V=0.9847862, theta=-73.280435 -> V=1.0, theta=0.0
% INFO    : Bus 55249	: V=0.9794555, theta=-76.557037 -> V=1.0, theta=0.0
% INFO    : Bus 55250	: V=0.9869124, theta=-76.127031 -> V=1.0, theta=0.0
% INFO    : Bus 55251	: V=0.9882497, theta=-75.986966 -> V=1.0, theta=0.0
% INFO    : Bus 55252	: V=0.982532, theta=-77.996825 -> V=1.0, theta=0.0
% INFO    : Bus 55253	: V=0.987075, theta=-76.446299 -> V=1.0, theta=0.0
% INFO    : Bus 55254	: V=0.983636, theta=-77.874654 -> V=1.0, theta=0.0
% INFO    : Bus 55255	: V=0.9857207, theta=-77.377899 -> V=1.0, theta=0.0
% INFO    : Bus 55256	: V=0.9844815, theta=-77.688692 -> V=1.0, theta=0.0
% INFO    : Bus 55257	: V=0.9840262, theta=-77.800236 -> V=1.0, theta=0.0
% INFO    : Bus 55258	: V=0.9905967, theta=-75.740972 -> V=1.0, theta=0.0
% INFO    : Bus 55259	: V=0.9880278, theta=-76.336419 -> V=1.0, theta=0.0
% INFO    : Bus 55260	: V=0.9762223, theta=-78.905279 -> V=1.0, theta=0.0
% INFO    : Bus 55261	: V=0.9652229, theta=-80.164663 -> V=1.0, theta=0.0
% INFO    : Bus 55262	: V=0.966013, theta=-80.119606 -> V=1.0, theta=0.0
% INFO    : Bus 55263	: V=0.9706285, theta=-79.696825 -> V=1.0, theta=0.0
% INFO    : Bus 55264	: V=0.9684069, theta=-80.021896 -> V=1.0, theta=0.0
% INFO    : Bus 55265	: V=1.0038966, theta=-74.327869 -> V=1.0, theta=0.0
% INFO    : Bus 55266	: V=0.9947621, theta=-75.368129 -> V=1.0, theta=0.0
% INFO    : Bus 55267	: V=1.0182799, theta=-58.434618 -> V=1.0, theta=0.0
% INFO    : Bus 55268	: V=1.0181005, theta=-60.289828 -> V=1.0, theta=0.0
% INFO    : Bus 55269	: V=1.0022005, theta=-60.44479 -> V=1.0, theta=0.0
% INFO    : Bus 55270	: V=1.0172114, theta=-58.429747 -> V=1.0, theta=0.0
% INFO    : Bus 55271	: V=1.0172647, theta=-59.458953 -> V=1.0, theta=0.0
% INFO    : Bus 55272	: V=1.0176099, theta=-59.844252 -> V=1.0, theta=0.0
% INFO    : Bus 55273	: V=1.0173881, theta=-59.701607 -> V=1.0, theta=0.0
% INFO    : Bus 55274	: V=1.0059648, theta=-61.699089 -> V=1.0, theta=0.0
% INFO    : Bus 55275	: V=0.955932, theta=-73.43019 -> V=1.0, theta=0.0
% INFO    : Bus 55276	: V=0.9505548, theta=-73.680011 -> V=1.0, theta=0.0
% INFO    : Bus 55277	: V=0.9527397, theta=-73.598301 -> V=1.0, theta=0.0
% INFO    : Bus 55278	: V=0.9499801, theta=-74.077481 -> V=1.0, theta=0.0
% INFO    : Bus 55279	: V=0.9492617, theta=-73.802908 -> V=1.0, theta=0.0
% INFO    : Bus 55280	: V=0.9591631, theta=-72.901524 -> V=1.0, theta=0.0
% INFO    : Bus 55281	: V=0.9866148, theta=-60.575667 -> V=1.0, theta=0.0
% INFO    : Bus 55282	: V=1.0017334, theta=-62.302055 -> V=1.0, theta=0.0
% INFO    : Bus 55283	: V=1.0014457, theta=-61.948462 -> V=1.0, theta=0.0
% INFO    : Bus 55284	: V=1.0020706, theta=-61.752971 -> V=1.0, theta=0.0
% INFO    : Bus 55285	: V=0.9858688, theta=-61.711528 -> V=1.0, theta=0.0
% INFO    : Bus 55286	: V=0.992603, theta=-63.11209 -> V=1.0, theta=0.0
% INFO    : Bus 55287	: V=0.9824611, theta=-63.160173 -> V=1.0, theta=0.0
% INFO    : Bus 55288	: V=0.9850516, theta=-65.895064 -> V=1.0, theta=0.0
% INFO    : Bus 55289	: V=0.9827449, theta=-59.801074 -> V=1.0, theta=0.0
% INFO    : Bus 55290	: V=0.9850392, theta=-70.057094 -> V=1.0, theta=0.0
% INFO    : Bus 55291	: V=1.014823, theta=-68.840764 -> V=1.0, theta=0.0
% INFO    : Bus 55292	: V=1.012736, theta=-68.974466 -> V=1.0, theta=0.0
% INFO    : Bus 55293	: V=0.9940791, theta=-70.199726 -> V=1.0, theta=0.0
% INFO    : Bus 55294	: V=0.9998648, theta=-69.651434 -> V=1.0, theta=0.0
% INFO    : Bus 55295	: V=0.9994618, theta=-69.945199 -> V=1.0, theta=0.0
% INFO    : Bus 55296	: V=1.0101717, theta=-69.482186 -> V=1.0, theta=0.0
% INFO    : Bus 55297	: V=1.017586, theta=-45.414109 -> V=1.0, theta=0.0
% INFO    : Bus 55298	: V=1.0143619, theta=-50.138922 -> V=1.0, theta=0.0
% INFO    : Bus 55299	: V=1.009029, theta=-59.10787 -> V=1.0, theta=0.0
% INFO    : Bus 55300	: V=1.0069684, theta=-57.56385 -> V=1.0, theta=0.0
% INFO    : Bus 55301	: V=0.9981321, theta=-58.235817 -> V=1.0, theta=0.0
% INFO    : Bus 55302	: V=1.0006523, theta=-70.551083 -> V=1.0, theta=0.0
% INFO    : Bus 55303	: V=0.97695, theta=-73.150364 -> V=1.0, theta=0.0
% INFO    : Bus 55304	: V=0.9872691, theta=-71.884557 -> V=1.0, theta=0.0
% INFO    : Bus 55305	: V=0.9869278, theta=-71.887743 -> V=1.0, theta=0.0
% INFO    : Bus 55306	: V=0.9769265, theta=-72.819607 -> V=1.0, theta=0.0
% INFO    : Bus 55307	: V=0.9711857, theta=-73.20282 -> V=1.0, theta=0.0
% INFO    : Bus 55308	: V=0.9868124, theta=-71.848273 -> V=1.0, theta=0.0
% INFO    : Bus 55309	: V=0.9868553, theta=-71.873439 -> V=1.0, theta=0.0
% INFO    : Bus 55310	: V=1.0022283, theta=-70.184501 -> V=1.0, theta=0.0
% INFO    : Bus 55311	: V=0.9927597, theta=-71.349454 -> V=1.0, theta=0.0
% INFO    : Bus 55312	: V=0.9879993, theta=-71.677658 -> V=1.0, theta=0.0
% INFO    : Bus 55313	: V=0.9910958, theta=-71.595847 -> V=1.0, theta=0.0
% INFO    : Bus 55314	: V=0.9870934, theta=-71.608 -> V=1.0, theta=0.0
% INFO    : Bus 55315	: V=0.9850381, theta=-71.798142 -> V=1.0, theta=0.0
% INFO    : Bus 55316	: V=0.9816999, theta=-72.828957 -> V=1.0, theta=0.0
% INFO    : Bus 55317	: V=0.9822172, theta=-72.806355 -> V=1.0, theta=0.0
% INFO    : Bus 55318	: V=0.9836076, theta=-72.580052 -> V=1.0, theta=0.0
% INFO    : Bus 55319	: V=0.9797285, theta=-73.139818 -> V=1.0, theta=0.0
% INFO    : Bus 55320	: V=0.9858208, theta=-72.200291 -> V=1.0, theta=0.0
% INFO    : Bus 55321	: V=0.9897598, theta=-71.272791 -> V=1.0, theta=0.0
% INFO    : Bus 55322	: V=1.0094804, theta=-68.453678 -> V=1.0, theta=0.0
% INFO    : Bus 55323	: V=0.9877221, theta=-71.929051 -> V=1.0, theta=0.0
% INFO    : Bus 55324	: V=0.9838712, theta=-72.538068 -> V=1.0, theta=0.0
% INFO    : Bus 55325	: V=0.9754357, theta=-73.792278 -> V=1.0, theta=0.0
% INFO    : Bus 55326	: V=0.9532659, theta=-77.608938 -> V=1.0, theta=0.0
% INFO    : Bus 55327	: V=0.9736246, theta=-74.577364 -> V=1.0, theta=0.0
% INFO    : Bus 55328	: V=0.9524342, theta=-77.682395 -> V=1.0, theta=0.0
% INFO    : Bus 55329	: V=0.9832861, theta=-72.747624 -> V=1.0, theta=0.0
% INFO    : Bus 55330	: V=0.9788287, theta=-73.578031 -> V=1.0, theta=0.0
% INFO    : Bus 55331	: V=0.9641318, theta=-76.153477 -> V=1.0, theta=0.0
% INFO    : Bus 55332	: V=0.9653467, theta=-76.013887 -> V=1.0, theta=0.0
% INFO    : Bus 55333	: V=0.9623518, theta=-76.286142 -> V=1.0, theta=0.0
% INFO    : Bus 55334	: V=0.9639808, theta=-76.098241 -> V=1.0, theta=0.0
% INFO    : Bus 55335	: V=0.9639998, theta=-76.098167 -> V=1.0, theta=0.0
% INFO    : Bus 55336	: V=0.9632664, theta=-76.143436 -> V=1.0, theta=0.0
% INFO    : Bus 55337	: V=0.9705115, theta=-74.864784 -> V=1.0, theta=0.0
% INFO    : Bus 55338	: V=0.9815603, theta=-72.481905 -> V=1.0, theta=0.0
% INFO    : Bus 55339	: V=0.9841208, theta=-72.099722 -> V=1.0, theta=0.0
% INFO    : Bus 55340	: V=0.9779903, theta=-73.039426 -> V=1.0, theta=0.0
% INFO    : Bus 55341	: V=0.9617523, theta=-76.629588 -> V=1.0, theta=0.0
% INFO    : Bus 55342	: V=0.9594982, theta=-75.150295 -> V=1.0, theta=0.0
% INFO    : Bus 55343	: V=0.9590314, theta=-75.212448 -> V=1.0, theta=0.0
% INFO    : Bus 55344	: V=0.9662646, theta=-75.254815 -> V=1.0, theta=0.0
% INFO    : Bus 55345	: V=0.9655374, theta=-75.217156 -> V=1.0, theta=0.0
% INFO    : Bus 55346	: V=0.9735249, theta=-74.454738 -> V=1.0, theta=0.0
% INFO    : Bus 55347	: V=0.9604796, theta=-75.576937 -> V=1.0, theta=0.0
% INFO    : Bus 55348	: V=0.9685659, theta=-73.547602 -> V=1.0, theta=0.0
% INFO    : Bus 55349	: V=0.9820203, theta=-72.384536 -> V=1.0, theta=0.0
% INFO    : Bus 55350	: V=0.9862474, theta=-71.76597 -> V=1.0, theta=0.0
% INFO    : Bus 55351	: V=0.9773048, theta=-72.580026 -> V=1.0, theta=0.0
% INFO    : Bus 55352	: V=0.9902402, theta=-71.205035 -> V=1.0, theta=0.0
% INFO    : Bus 55353	: V=0.9887401, theta=-71.468115 -> V=1.0, theta=0.0
% INFO    : Bus 55354	: V=0.9850129, theta=-71.755707 -> V=1.0, theta=0.0
% INFO    : Bus 55355	: V=1.0107342, theta=-68.304175 -> V=1.0, theta=0.0
% INFO    : Bus 55356	: V=0.989993, theta=-71.596867 -> V=1.0, theta=0.0
% INFO    : Bus 55357	: V=0.9932203, theta=-71.151295 -> V=1.0, theta=0.0
% INFO    : Bus 55358	: V=0.999379, theta=-70.067949 -> V=1.0, theta=0.0
% INFO    : Bus 55359	: V=0.9981694, theta=-70.466209 -> V=1.0, theta=0.0
% INFO    : Bus 55360	: V=0.9798728, theta=-72.058927 -> V=1.0, theta=0.0
% INFO    : Bus 55361	: V=0.9973744, theta=-70.665813 -> V=1.0, theta=0.0
% INFO    : Bus 55362	: V=0.9867054, theta=-71.153227 -> V=1.0, theta=0.0
% INFO    : Bus 55363	: V=1.0038842, theta=-69.359535 -> V=1.0, theta=0.0
% INFO    : Bus 55364	: V=0.9879646, theta=-71.115535 -> V=1.0, theta=0.0
% INFO    : Bus 55365	: V=0.9856277, theta=-71.3048 -> V=1.0, theta=0.0
% INFO    : Bus 55366	: V=1.014462, theta=-67.796203 -> V=1.0, theta=0.0
% INFO    : Bus 55367	: V=0.989951, theta=-70.067351 -> V=1.0, theta=0.0
% INFO    : Bus 55368	: V=0.9878402, theta=-70.26638 -> V=1.0, theta=0.0
% INFO    : Bus 55369	: V=0.9919147, theta=-70.236684 -> V=1.0, theta=0.0
% INFO    : Bus 55370	: V=0.9960368, theta=-70.249182 -> V=1.0, theta=0.0
% INFO    : Bus 55371	: V=1.0004698, theta=-69.195692 -> V=1.0, theta=0.0
% INFO    : Bus 55372	: V=0.9997117, theta=-69.24057 -> V=1.0, theta=0.0
% INFO    : Bus 55373	: V=0.9907762, theta=-69.767649 -> V=1.0, theta=0.0
% INFO    : Bus 55374	: V=1.0020917, theta=-69.651179 -> V=1.0, theta=0.0
% INFO    : Bus 55375	: V=1.0177242, theta=-66.546024 -> V=1.0, theta=0.0
% INFO    : Bus 55376	: V=1.0054613, theta=-68.303479 -> V=1.0, theta=0.0
% INFO    : Bus 55377	: V=0.9898762, theta=-69.739513 -> V=1.0, theta=0.0
% INFO    : Bus 55378	: V=1.0148766, theta=-56.73438 -> V=1.0, theta=0.0
% INFO    : Bus 55379	: V=0.9976313, theta=-57.882711 -> V=1.0, theta=0.0
% INFO    : Bus 55380	: V=1.0105397, theta=-57.54444 -> V=1.0, theta=0.0
% INFO    : Bus 55381	: V=1.0197553, theta=-65.673532 -> V=1.0, theta=0.0
% INFO    : Bus 55382	: V=1.0126531, theta=-66.532704 -> V=1.0, theta=0.0
% INFO    : Bus 55383	: V=1.01241, theta=-66.544434 -> V=1.0, theta=0.0
% INFO    : Bus 55384	: V=0.9939857, theta=-68.740549 -> V=1.0, theta=0.0
% INFO    : Bus 55385	: V=1.0117052, theta=-66.553084 -> V=1.0, theta=0.0
% INFO    : Bus 55386	: V=0.9991277, theta=-67.349657 -> V=1.0, theta=0.0
% INFO    : Bus 55387	: V=0.9899297, theta=-68.536206 -> V=1.0, theta=0.0
% INFO    : Bus 55388	: V=0.9979136, theta=-68.790509 -> V=1.0, theta=0.0
% INFO    : Bus 55389	: V=1.0098625, theta=-68.361532 -> V=1.0, theta=0.0
% INFO    : Bus 55390	: V=0.973481, theta=-70.62084 -> V=1.0, theta=0.0
% INFO    : Bus 55391	: V=0.9842023, theta=-58.191795 -> V=1.0, theta=0.0
% INFO    : Bus 55392	: V=1.0055023, theta=-56.169167 -> V=1.0, theta=0.0
% INFO    : Bus 55393	: V=0.9883383, theta=-57.789311 -> V=1.0, theta=0.0
% INFO    : Bus 55394	: V=0.9484189, theta=-79.985728 -> V=1.0, theta=0.0
% INFO    : Bus 55395	: V=0.9471013, theta=-79.345248 -> V=1.0, theta=0.0
% INFO    : Bus 55396	: V=0.9471519, theta=-79.292355 -> V=1.0, theta=0.0
% INFO    : Bus 55397	: V=0.9488522, theta=-79.208463 -> V=1.0, theta=0.0
% INFO    : Bus 55398	: V=0.9471343, theta=-79.34205 -> V=1.0, theta=0.0
% INFO    : Bus 55399	: V=0.9619645, theta=-78.355511 -> V=1.0, theta=0.0
% INFO    : Bus 55400	: V=0.9490672, theta=-79.782083 -> V=1.0, theta=0.0
% INFO    : Bus 55401	: V=0.9634502, theta=-78.036603 -> V=1.0, theta=0.0
% INFO    : Bus 55402	: V=0.9661745, theta=-77.528591 -> V=1.0, theta=0.0
% INFO    : Bus 55403	: V=0.9701069, theta=-78.649748 -> V=1.0, theta=0.0
% INFO    : Bus 55404	: V=0.9738392, theta=-78.341459 -> V=1.0, theta=0.0
% INFO    : Bus 55405	: V=0.97602, theta=-78.136774 -> V=1.0, theta=0.0
% INFO    : Bus 55406	: V=0.980023, theta=-78.081487 -> V=1.0, theta=0.0
% INFO    : Bus 55407	: V=0.9762429, theta=-78.513322 -> V=1.0, theta=0.0
% INFO    : Bus 55408	: V=0.9717926, theta=-79.167874 -> V=1.0, theta=0.0
% INFO    : Bus 55409	: V=0.9739082, theta=-78.84526 -> V=1.0, theta=0.0
% INFO    : Bus 55410	: V=0.9539418, theta=-80.191409 -> V=1.0, theta=0.0
% INFO    : Bus 55411	: V=0.9712752, theta=-79.271112 -> V=1.0, theta=0.0
% INFO    : Bus 55412	: V=0.9713712, theta=-79.319539 -> V=1.0, theta=0.0
% INFO    : Bus 55413	: V=0.9752352, theta=-78.596707 -> V=1.0, theta=0.0
% INFO    : Bus 55414	: V=0.9636156, theta=-79.525789 -> V=1.0, theta=0.0
% INFO    : Bus 55415	: V=0.9618927, theta=-79.553709 -> V=1.0, theta=0.0
% INFO    : Bus 55416	: V=0.9854802, theta=-77.324312 -> V=1.0, theta=0.0
% INFO    : Bus 55417	: V=0.9955622, theta=-76.263524 -> V=1.0, theta=0.0
% INFO    : Bus 55418	: V=1.0136504, theta=-74.734208 -> V=1.0, theta=0.0
% INFO    : Bus 55419	: V=0.9978826, theta=-76.175328 -> V=1.0, theta=0.0
% INFO    : Bus 55420	: V=0.9966846, theta=-76.219527 -> V=1.0, theta=0.0
% INFO    : Bus 55421	: V=1.0199153, theta=-74.276607 -> V=1.0, theta=0.0
% INFO    : Bus 55422	: V=0.9947693, theta=-76.043191 -> V=1.0, theta=0.0
% INFO    : Bus 55423	: V=0.990652, theta=-76.382648 -> V=1.0, theta=0.0
% INFO    : Bus 55424	: V=0.987072, theta=-76.854007 -> V=1.0, theta=0.0
% INFO    : Bus 55425	: V=0.9863167, theta=-76.898124 -> V=1.0, theta=0.0
% INFO    : Bus 55426	: V=0.9860142, theta=-76.91126 -> V=1.0, theta=0.0
% INFO    : Bus 55427	: V=0.9847013, theta=-76.901281 -> V=1.0, theta=0.0
% INFO    : Bus 55428	: V=0.9915844, theta=-75.985702 -> V=1.0, theta=0.0
% INFO    : Bus 55429	: V=0.9647882, theta=-78.6175 -> V=1.0, theta=0.0
% INFO    : Bus 55430	: V=0.9715637, theta=-76.720325 -> V=1.0, theta=0.0
% INFO    : Bus 55431	: V=0.9935312, theta=-75.432165 -> V=1.0, theta=0.0
% INFO    : Bus 55432	: V=0.9638073, theta=-78.353079 -> V=1.0, theta=0.0
% INFO    : Bus 55433	: V=0.9969144, theta=-74.791287 -> V=1.0, theta=0.0
% INFO    : Bus 55434	: V=0.9852799, theta=-76.90543 -> V=1.0, theta=0.0
% INFO    : Bus 55435	: V=1.0145329, theta=-74.408176 -> V=1.0, theta=0.0
% INFO    : Bus 55436	: V=0.9989207, theta=-74.729107 -> V=1.0, theta=0.0
% INFO    : Bus 55437	: V=1.0167615, theta=-74.474715 -> V=1.0, theta=0.0
% INFO    : Bus 55438	: V=0.9992734, theta=-75.60806 -> V=1.0, theta=0.0
% INFO    : Bus 55439	: V=0.9993094, theta=-75.631809 -> V=1.0, theta=0.0
% INFO    : Bus 55440	: V=0.9994764, theta=-75.665865 -> V=1.0, theta=0.0
% INFO    : Bus 55441	: V=0.9927974, theta=-76.222487 -> V=1.0, theta=0.0
% INFO    : Bus 55442	: V=0.9930078, theta=-76.191614 -> V=1.0, theta=0.0
% INFO    : Bus 55443	: V=0.9939761, theta=-76.159347 -> V=1.0, theta=0.0
% INFO    : Bus 55444	: V=0.9933535, theta=-76.186966 -> V=1.0, theta=0.0
% INFO    : Bus 55445	: V=0.9930719, theta=-76.201387 -> V=1.0, theta=0.0
% INFO    : Bus 55446	: V=0.9928412, theta=-76.168078 -> V=1.0, theta=0.0
% INFO    : Bus 55447	: V=0.9876317, theta=-76.887813 -> V=1.0, theta=0.0
% INFO    : Bus 55448	: V=0.9932463, theta=-76.166347 -> V=1.0, theta=0.0
% INFO    : Bus 55449	: V=0.9874506, theta=-76.912366 -> V=1.0, theta=0.0
% INFO    : Bus 55450	: V=0.9871893, theta=-76.914178 -> V=1.0, theta=0.0
% INFO    : Bus 55451	: V=1.0002316, theta=-75.728564 -> V=1.0, theta=0.0
% INFO    : Bus 55452	: V=0.9878438, theta=-76.889157 -> V=1.0, theta=0.0
% INFO    : Bus 55453	: V=1.0006354, theta=-75.708225 -> V=1.0, theta=0.0
% INFO    : Bus 55454	: V=1.0010007, theta=-75.689138 -> V=1.0, theta=0.0
% INFO    : Bus 55455	: V=1.013783, theta=-74.477829 -> V=1.0, theta=0.0
% INFO    : Bus 55456	: V=1.0135472, theta=-74.497562 -> V=1.0, theta=0.0
% INFO    : Bus 55457	: V=0.9963743, theta=-76.0099 -> V=1.0, theta=0.0
% INFO    : Bus 55458	: V=0.9842813, theta=-74.725125 -> V=1.0, theta=0.0
% INFO    : Bus 55459	: V=1.0182129, theta=-74.449716 -> V=1.0, theta=0.0
% INFO    : Bus 55460	: V=1.0134158, theta=-53.430694 -> V=1.0, theta=0.0
% INFO    : Bus 55461	: V=0.9599242, theta=-73.2635 -> V=1.0, theta=0.0
% INFO    : Bus 55462	: V=0.9312324, theta=-77.974404 -> V=1.0, theta=0.0
% INFO    : Bus 55463	: V=0.9507991, theta=-71.892069 -> V=1.0, theta=0.0
% INFO    : Bus 55464	: V=0.9509469, theta=-73.284114 -> V=1.0, theta=0.0
% INFO    : Bus 55465	: V=0.9498663, theta=-75.26637 -> V=1.0, theta=0.0
% INFO    : Bus 55466	: V=1.0149984, theta=-52.041798 -> V=1.0, theta=0.0
% INFO    : Bus 55467	: V=1.0096584, theta=-60.716091 -> V=1.0, theta=0.0
% INFO    : Bus 55468	: V=0.9911942, theta=-65.132965 -> V=1.0, theta=0.0
% INFO    : Bus 55469	: V=0.9674149, theta=-71.477379 -> V=1.0, theta=0.0
% INFO    : Bus 55470	: V=0.9520511, theta=-72.049254 -> V=1.0, theta=0.0
% INFO    : Bus 55471	: V=0.9524112, theta=-72.014053 -> V=1.0, theta=0.0
% INFO    : Bus 55472	: V=0.9532284, theta=-71.855041 -> V=1.0, theta=0.0
% INFO    : Bus 55473	: V=0.9766871, theta=-69.930264 -> V=1.0, theta=0.0
% INFO    : Bus 55474	: V=0.9640221, theta=-69.746661 -> V=1.0, theta=0.0
% INFO    : Bus 55475	: V=0.9967419, theta=-57.837261 -> V=1.0, theta=0.0
% INFO    : Bus 55476	: V=1.0022216, theta=-57.636786 -> V=1.0, theta=0.0
% INFO    : Bus 55477	: V=1.0026634, theta=-57.623126 -> V=1.0, theta=0.0
% INFO    : Bus 55478	: V=1.0020307, theta=-57.637599 -> V=1.0, theta=0.0
% INFO    : Bus 55479	: V=1.0019609, theta=-57.632784 -> V=1.0, theta=0.0
% INFO    : Bus 55480	: V=1.0024661, theta=-57.60317 -> V=1.0, theta=0.0
% INFO    : Bus 55481	: V=1.0008832, theta=-57.789524 -> V=1.0, theta=0.0
% INFO    : Bus 55482	: V=1.0037794, theta=-61.580425 -> V=1.0, theta=0.0
% INFO    : Bus 55483	: V=0.9974835, theta=-63.792424 -> V=1.0, theta=0.0
% INFO    : Bus 55484	: V=0.9974496, theta=-62.05038 -> V=1.0, theta=0.0
% INFO    : Bus 55485	: V=0.9885489, theta=-62.342479 -> V=1.0, theta=0.0
% INFO    : Bus 55486	: V=0.9864505, theta=-62.171394 -> V=1.0, theta=0.0
% INFO    : Bus 55487	: V=0.9673847, theta=-66.531122 -> V=1.0, theta=0.0
% INFO    : Bus 55488	: V=0.9821454, theta=-63.574701 -> V=1.0, theta=0.0
% INFO    : Bus 55489	: V=0.995557, theta=-62.236065 -> V=1.0, theta=0.0
% INFO    : Bus 55490	: V=0.995338, theta=-62.328308 -> V=1.0, theta=0.0
% INFO    : Bus 55491	: V=1.0032528, theta=-61.538871 -> V=1.0, theta=0.0
% INFO    : Bus 55492	: V=0.9946908, theta=-62.389797 -> V=1.0, theta=0.0
% INFO    : Bus 55493	: V=0.9919859, theta=-62.479789 -> V=1.0, theta=0.0
% INFO    : Bus 55494	: V=0.99, theta=-62.530493 -> V=1.0, theta=0.0
% INFO    : Bus 55495	: V=0.9894891, theta=-62.65271 -> V=1.0, theta=0.0
% INFO    : Bus 55496	: V=0.9690122, theta=-64.710441 -> V=1.0, theta=0.0
% INFO    : Bus 55497	: V=0.9538018, theta=-66.063754 -> V=1.0, theta=0.0
% INFO    : Bus 55498	: V=0.9714697, theta=-64.789564 -> V=1.0, theta=0.0
% INFO    : Bus 55499	: V=0.9727879, theta=-64.745936 -> V=1.0, theta=0.0
% INFO    : Bus 55500	: V=0.9925692, theta=-62.642458 -> V=1.0, theta=0.0
% INFO    : Bus 55501	: V=0.9917705, theta=-64.088021 -> V=1.0, theta=0.0
% INFO    : Bus 55502	: V=0.9739059, theta=-64.551431 -> V=1.0, theta=0.0
% INFO    : Bus 55503	: V=0.9958476, theta=-64.296526 -> V=1.0, theta=0.0
% INFO    : Bus 55504	: V=0.9896293, theta=-66.298474 -> V=1.0, theta=0.0
% INFO    : Bus 55505	: V=0.9816228, theta=-67.710335 -> V=1.0, theta=0.0
% INFO    : Bus 55506	: V=0.9722302, theta=-66.720576 -> V=1.0, theta=0.0
% INFO    : Bus 55507	: V=0.976632, theta=-64.50657 -> V=1.0, theta=0.0
% INFO    : Bus 55508	: V=1.0014616, theta=-58.192289 -> V=1.0, theta=0.0
% INFO    : Bus 55509	: V=1.0016694, theta=-58.250043 -> V=1.0, theta=0.0
% INFO    : Bus 55510	: V=1.0003731, theta=-58.291038 -> V=1.0, theta=0.0
% INFO    : Bus 55511	: V=1.0007185, theta=-58.338911 -> V=1.0, theta=0.0
% INFO    : Bus 55512	: V=0.9996337, theta=-58.432838 -> V=1.0, theta=0.0
% INFO    : Bus 55513	: V=0.9986091, theta=-58.602909 -> V=1.0, theta=0.0
% INFO    : Bus 55514	: V=0.9995709, theta=-58.374156 -> V=1.0, theta=0.0
% INFO    : Bus 55515	: V=0.9794743, theta=-60.056513 -> V=1.0, theta=0.0
% INFO    : Bus 55516	: V=0.9779084, theta=-60.111036 -> V=1.0, theta=0.0
% INFO    : Bus 55517	: V=0.997361, theta=-58.809198 -> V=1.0, theta=0.0
% INFO    : Bus 55518	: V=0.9998883, theta=-58.231142 -> V=1.0, theta=0.0
% INFO    : Bus 55519	: V=1.0041941, theta=-58.025929 -> V=1.0, theta=0.0
% INFO    : Bus 55520	: V=1.0063393, theta=-57.820804 -> V=1.0, theta=0.0
% INFO    : Bus 55521	: V=1.0041043, theta=-57.922447 -> V=1.0, theta=0.0
% INFO    : Bus 55522	: V=1.0167164, theta=-57.018941 -> V=1.0, theta=0.0
% INFO    : Bus 55523	: V=1.0127609, theta=-57.177148 -> V=1.0, theta=0.0
% INFO    : Bus 55524	: V=1.0005586, theta=-58.260149 -> V=1.0, theta=0.0
% INFO    : Bus 55525	: V=0.9938731, theta=-59.217811 -> V=1.0, theta=0.0
% INFO    : Bus 55526	: V=0.9772306, theta=-60.115139 -> V=1.0, theta=0.0
% INFO    : Bus 55527	: V=0.9963097, theta=-58.986669 -> V=1.0, theta=0.0
% INFO    : Bus 55528	: V=0.9835725, theta=-60.451357 -> V=1.0, theta=0.0
% INFO    : Bus 55529	: V=1.0074388, theta=-57.825119 -> V=1.0, theta=0.0
% INFO    : Bus 55530	: V=1.0014096, theta=-59.066035 -> V=1.0, theta=0.0
% INFO    : Bus 55531	: V=1.0133085, theta=-57.497451 -> V=1.0, theta=0.0
% INFO    : Bus 55532	: V=0.996067, theta=-58.831573 -> V=1.0, theta=0.0
% INFO    : Bus 55533	: V=1.0040876, theta=-70.99826 -> V=1.0, theta=0.0
% INFO    : Bus 55534	: V=0.9781492, theta=-74.663322 -> V=1.0, theta=0.0
% INFO    : Bus 55535	: V=0.9967201, theta=-73.069044 -> V=1.0, theta=0.0
% INFO    : Bus 55536	: V=1.0141797, theta=-69.597893 -> V=1.0, theta=0.0
% INFO    : Bus 55537	: V=1.0192382, theta=-69.591721 -> V=1.0, theta=0.0
% INFO    : Bus 55538	: V=0.9939807, theta=-72.065205 -> V=1.0, theta=0.0
% INFO    : Bus 55539	: V=1.0002128, theta=-69.06371 -> V=1.0, theta=0.0
% INFO    : Bus 55540	: V=1.0053985, theta=-68.633338 -> V=1.0, theta=0.0
% INFO    : Bus 55541	: V=0.9862422, theta=-70.518572 -> V=1.0, theta=0.0
% INFO    : Bus 55542	: V=0.9977123, theta=-69.189355 -> V=1.0, theta=0.0
% INFO    : Bus 55543	: V=1.0011446, theta=-69.231738 -> V=1.0, theta=0.0
% INFO    : Bus 55544	: V=0.9867271, theta=-70.492303 -> V=1.0, theta=0.0
% INFO    : Bus 55545	: V=0.9929585, theta=-69.941722 -> V=1.0, theta=0.0
% INFO    : Bus 55546	: V=1.0013817, theta=-69.005018 -> V=1.0, theta=0.0
% INFO    : Bus 55547	: V=0.9898361, theta=-69.705344 -> V=1.0, theta=0.0
% INFO    : Bus 55548	: V=0.9939063, theta=-69.679365 -> V=1.0, theta=0.0
% INFO    : Bus 55549	: V=0.9907752, theta=-70.168271 -> V=1.0, theta=0.0
% INFO    : Bus 55550	: V=1.0020569, theta=-68.962843 -> V=1.0, theta=0.0
% INFO    : Bus 55551	: V=0.9989212, theta=-69.224978 -> V=1.0, theta=0.0
% INFO    : Bus 55552	: V=1.0000785, theta=-69.120886 -> V=1.0, theta=0.0
% INFO    : Bus 55553	: V=0.9799685, theta=-71.070632 -> V=1.0, theta=0.0
% INFO    : Bus 55554	: V=0.9848076, theta=-70.760541 -> V=1.0, theta=0.0
% INFO    : Bus 55555	: V=0.973998, theta=-72.036077 -> V=1.0, theta=0.0
% INFO    : Bus 55556	: V=0.9806347, theta=-71.046287 -> V=1.0, theta=0.0
% INFO    : Bus 55557	: V=0.9826085, theta=-70.919429 -> V=1.0, theta=0.0
% INFO    : Bus 55558	: V=0.9805572, theta=-71.051924 -> V=1.0, theta=0.0
% INFO    : Bus 55559	: V=0.9825924, theta=-70.921701 -> V=1.0, theta=0.0
% INFO    : Bus 55560	: V=0.9810304, theta=-70.996047 -> V=1.0, theta=0.0
% INFO    : Bus 55561	: V=0.983841, theta=-70.899057 -> V=1.0, theta=0.0
% INFO    : Bus 55562	: V=0.9894822, theta=-70.345325 -> V=1.0, theta=0.0
% INFO    : Bus 55563	: V=0.9821433, theta=-70.611458 -> V=1.0, theta=0.0
% INFO    : Bus 55564	: V=0.9765205, theta=-70.846871 -> V=1.0, theta=0.0
% INFO    : Bus 55565	: V=0.9757655, theta=-71.390674 -> V=1.0, theta=0.0
% INFO    : Bus 55566	: V=1.0018098, theta=-68.886028 -> V=1.0, theta=0.0
% INFO    : Bus 55567	: V=0.9933339, theta=-69.239969 -> V=1.0, theta=0.0
% INFO    : Bus 55568	: V=1.0076633, theta=-58.1786 -> V=1.0, theta=0.0
% INFO    : Bus 55569	: V=1.0071807, theta=-57.965113 -> V=1.0, theta=0.0
% INFO    : Bus 55570	: V=1.0079312, theta=-57.914601 -> V=1.0, theta=0.0
% INFO    : Bus 55571	: V=0.999477, theta=-58.907004 -> V=1.0, theta=0.0
% INFO    : Bus 55572	: V=0.996664, theta=-59.178322 -> V=1.0, theta=0.0
% INFO    : Bus 55573	: V=1.0192174, theta=-56.52921 -> V=1.0, theta=0.0
% INFO    : Bus 55574	: V=1.0039468, theta=-57.932041 -> V=1.0, theta=0.0
% INFO    : Bus 55575	: V=0.9971899, theta=-59.486091 -> V=1.0, theta=0.0
% INFO    : Bus 55576	: V=0.9959265, theta=-58.622452 -> V=1.0, theta=0.0
% INFO    : Bus 55577	: V=0.9996182, theta=-59.85947 -> V=1.0, theta=0.0
% INFO    : Bus 55578	: V=0.9986028, theta=-63.631198 -> V=1.0, theta=0.0
% INFO    : Bus 55579	: V=0.9862575, theta=-63.957305 -> V=1.0, theta=0.0
% INFO    : Bus 55580	: V=0.9894136, theta=-63.891479 -> V=1.0, theta=0.0
% INFO    : Bus 55581	: V=1.014879, theta=-55.663372 -> V=1.0, theta=0.0
% INFO    : Bus 55582	: V=1.0049864, theta=-57.153434 -> V=1.0, theta=0.0
% INFO    : Bus 55583	: V=0.9939249, theta=-59.673615 -> V=1.0, theta=0.0
% INFO    : Bus 55584	: V=0.9998482, theta=-71.98898 -> V=1.0, theta=0.0
% INFO    : Bus 55585	: V=0.9920169, theta=-72.292134 -> V=1.0, theta=0.0
% INFO    : Bus 55586	: V=1.0064426, theta=-70.88859 -> V=1.0, theta=0.0
% INFO    : Bus 55587	: V=0.9882374, theta=-72.309623 -> V=1.0, theta=0.0
% INFO    : Bus 55588	: V=1.0066221, theta=-70.157289 -> V=1.0, theta=0.0
% INFO    : Bus 55589	: V=1.0077557, theta=-70.096355 -> V=1.0, theta=0.0
% INFO    : Bus 55590	: V=1.0084034, theta=-69.892671 -> V=1.0, theta=0.0
% INFO    : Bus 55591	: V=1.0118982, theta=-69.455473 -> V=1.0, theta=0.0
% INFO    : Bus 55592	: V=1.0097493, theta=-69.873276 -> V=1.0, theta=0.0
% INFO    : Bus 55593	: V=1.0067834, theta=-69.837685 -> V=1.0, theta=0.0
% INFO    : Bus 55594	: V=1.0036736, theta=-69.750799 -> V=1.0, theta=0.0
% INFO    : Bus 55595	: V=0.9767623, theta=-75.847192 -> V=1.0, theta=0.0
% INFO    : Bus 55596	: V=0.9614485, theta=-78.515203 -> V=1.0, theta=0.0
% INFO    : Bus 55597	: V=0.9572329, theta=-79.040866 -> V=1.0, theta=0.0
% INFO    : Bus 55598	: V=0.9605059, theta=-78.835477 -> V=1.0, theta=0.0
% INFO    : Bus 55599	: V=0.9575556, theta=-79.050982 -> V=1.0, theta=0.0
% INFO    : Bus 55600	: V=0.9597074, theta=-78.92654 -> V=1.0, theta=0.0
% INFO    : Bus 55601	: V=0.9609986, theta=-78.816334 -> V=1.0, theta=0.0
% INFO    : Bus 55602	: V=0.9629553, theta=-78.816237 -> V=1.0, theta=0.0
% INFO    : Bus 55603	: V=0.9606861, theta=-78.928249 -> V=1.0, theta=0.0
% INFO    : Bus 55604	: V=0.9619918, theta=-78.870784 -> V=1.0, theta=0.0
% INFO    : Bus 55605	: V=0.9649181, theta=-78.770451 -> V=1.0, theta=0.0
% INFO    : Bus 55606	: V=0.961461, theta=-78.904927 -> V=1.0, theta=0.0
% INFO    : Bus 55607	: V=0.9525481, theta=-79.788312 -> V=1.0, theta=0.0
% INFO    : Bus 55608	: V=0.9542805, theta=-79.845613 -> V=1.0, theta=0.0
% INFO    : Bus 55609	: V=0.9611526, theta=-78.929471 -> V=1.0, theta=0.0
% INFO    : Bus 55610	: V=0.9674344, theta=-78.708382 -> V=1.0, theta=0.0
% INFO    : Bus 55611	: V=0.9667271, theta=-78.845784 -> V=1.0, theta=0.0
% INFO    : Bus 55612	: V=0.9599204, theta=-78.868233 -> V=1.0, theta=0.0
% INFO    : Bus 55613	: V=0.9666705, theta=-78.906205 -> V=1.0, theta=0.0
% INFO    : Bus 55614	: V=0.9956449, theta=-73.762083 -> V=1.0, theta=0.0
% INFO    : Bus 55615	: V=0.9619492, theta=-78.812836 -> V=1.0, theta=0.0
% INFO    : Bus 55616	: V=0.9598328, theta=-78.904285 -> V=1.0, theta=0.0
% INFO    : Bus 55617	: V=0.9682278, theta=-78.00966 -> V=1.0, theta=0.0
% INFO    : Bus 55618	: V=0.9611555, theta=-78.770989 -> V=1.0, theta=0.0
% INFO    : Bus 55619	: V=0.9669636, theta=-77.986028 -> V=1.0, theta=0.0
% INFO    : Bus 55620	: V=0.9610807, theta=-78.751874 -> V=1.0, theta=0.0
% INFO    : Bus 55621	: V=0.9637287, theta=-78.644851 -> V=1.0, theta=0.0
% INFO    : Bus 55622	: V=0.964607, theta=-78.624153 -> V=1.0, theta=0.0
% INFO    : Bus 55623	: V=0.9662269, theta=-78.429364 -> V=1.0, theta=0.0
% INFO    : Bus 55624	: V=0.9649596, theta=-78.451013 -> V=1.0, theta=0.0
% INFO    : Bus 55625	: V=0.9639435, theta=-78.481081 -> V=1.0, theta=0.0
% INFO    : Bus 55626	: V=0.9672729, theta=-77.73638 -> V=1.0, theta=0.0
% INFO    : Bus 55627	: V=0.9620361, theta=-78.609492 -> V=1.0, theta=0.0
% INFO    : Bus 55628	: V=0.9670571, theta=-77.851724 -> V=1.0, theta=0.0
% INFO    : Bus 55629	: V=0.9673847, theta=-77.75354 -> V=1.0, theta=0.0
% INFO    : Bus 55630	: V=0.9685106, theta=-77.578783 -> V=1.0, theta=0.0
% INFO    : Bus 55631	: V=0.9677587, theta=-77.672223 -> V=1.0, theta=0.0
% INFO    : Bus 55632	: V=0.9631156, theta=-78.393974 -> V=1.0, theta=0.0
% INFO    : Bus 55633	: V=0.9647074, theta=-78.296676 -> V=1.0, theta=0.0
% INFO    : Bus 55634	: V=0.964543, theta=-78.340905 -> V=1.0, theta=0.0
% INFO    : Bus 55635	: V=0.9653237, theta=-78.334063 -> V=1.0, theta=0.0
% INFO    : Bus 55636	: V=0.9685027, theta=-78.206552 -> V=1.0, theta=0.0
% INFO    : Bus 55637	: V=0.966677, theta=-78.06084 -> V=1.0, theta=0.0
% INFO    : Bus 55638	: V=0.9682535, theta=-77.597668 -> V=1.0, theta=0.0
% INFO    : Bus 55639	: V=0.9665024, theta=-77.844203 -> V=1.0, theta=0.0
% INFO    : Bus 55640	: V=0.9669983, theta=-77.731875 -> V=1.0, theta=0.0
% INFO    : Bus 55641	: V=0.9673787, theta=-77.76871 -> V=1.0, theta=0.0
% INFO    : Bus 55642	: V=0.9667576, theta=-77.73828 -> V=1.0, theta=0.0
% INFO    : Bus 55643	: V=0.9743407, theta=-76.892842 -> V=1.0, theta=0.0
% INFO    : Bus 55644	: V=0.9643694, theta=-78.193925 -> V=1.0, theta=0.0
% INFO    : Bus 55645	: V=0.9933926, theta=-74.665431 -> V=1.0, theta=0.0
% INFO    : Bus 55646	: V=0.9760491, theta=-76.933657 -> V=1.0, theta=0.0
% INFO    : Bus 55647	: V=0.9654201, theta=-78.231176 -> V=1.0, theta=0.0
% INFO    : Bus 55648	: V=0.9662356, theta=-78.194302 -> V=1.0, theta=0.0
% INFO    : Bus 55649	: V=0.9641753, theta=-78.26054 -> V=1.0, theta=0.0
% INFO    : Bus 55650	: V=0.9629835, theta=-78.80728 -> V=1.0, theta=0.0
% INFO    : Bus 55651	: V=0.9883615, theta=-76.704452 -> V=1.0, theta=0.0
% INFO    : Bus 55652	: V=0.9702046, theta=-78.309441 -> V=1.0, theta=0.0
% INFO    : Bus 55653	: V=0.9664197, theta=-78.554915 -> V=1.0, theta=0.0
% INFO    : Bus 55654	: V=0.9685523, theta=-78.307958 -> V=1.0, theta=0.0
% INFO    : Bus 55655	: V=0.9869411, theta=-76.667716 -> V=1.0, theta=0.0
% INFO    : Bus 55656	: V=0.9869973, theta=-76.610833 -> V=1.0, theta=0.0
% INFO    : Bus 55657	: V=0.9764264, theta=-77.87028 -> V=1.0, theta=0.0
% INFO    : Bus 55658	: V=0.9746039, theta=-78.147286 -> V=1.0, theta=0.0
% INFO    : Bus 55659	: V=0.9768265, theta=-77.923501 -> V=1.0, theta=0.0
% INFO    : Bus 55660	: V=1.0182054, theta=-75.194263 -> V=1.0, theta=0.0
% INFO    : Bus 55661	: V=0.9778722, theta=-77.929169 -> V=1.0, theta=0.0
% INFO    : Bus 55662	: V=0.9771579, theta=-77.928386 -> V=1.0, theta=0.0
% INFO    : Bus 55663	: V=0.9716049, theta=-78.135491 -> V=1.0, theta=0.0
% INFO    : Bus 55664	: V=0.9728922, theta=-78.078255 -> V=1.0, theta=0.0
% INFO    : Bus 55665	: V=0.9734491, theta=-78.040827 -> V=1.0, theta=0.0
% INFO    : Bus 55666	: V=0.9880351, theta=-76.360606 -> V=1.0, theta=0.0
% INFO    : Bus 55667	: V=0.9695218, theta=-78.346078 -> V=1.0, theta=0.0
% INFO    : Bus 55668	: V=0.9637929, theta=-78.959203 -> V=1.0, theta=0.0
% INFO    : Bus 55669	: V=0.9611979, theta=-79.226967 -> V=1.0, theta=0.0
% INFO    : Bus 55670	: V=0.9660549, theta=-78.24458 -> V=1.0, theta=0.0
% INFO    : Bus 55671	: V=0.9597684, theta=-79.405538 -> V=1.0, theta=0.0
% INFO    : Bus 55672	: V=0.9794045, theta=-77.890643 -> V=1.0, theta=0.0
% INFO    : Bus 55673	: V=0.9819661, theta=-77.792403 -> V=1.0, theta=0.0
% INFO    : Bus 55674	: V=1.0023741, theta=-76.144416 -> V=1.0, theta=0.0
% INFO    : Bus 55675	: V=0.992647, theta=-77.143455 -> V=1.0, theta=0.0
% INFO    : Bus 55676	: V=0.9910944, theta=-77.161705 -> V=1.0, theta=0.0
% INFO    : Bus 55677	: V=0.9838928, theta=-77.794826 -> V=1.0, theta=0.0
% INFO    : Bus 55678	: V=0.9819827, theta=-77.862147 -> V=1.0, theta=0.0
% INFO    : Bus 55679	: V=0.9832603, theta=-77.788553 -> V=1.0, theta=0.0
% INFO    : Bus 55680	: V=0.9841794, theta=-77.733659 -> V=1.0, theta=0.0
% INFO    : Bus 55681	: V=0.972605, theta=-78.797238 -> V=1.0, theta=0.0
% INFO    : Bus 55682	: V=0.9813575, theta=-77.696359 -> V=1.0, theta=0.0
% INFO    : Bus 55683	: V=0.984972, theta=-77.560475 -> V=1.0, theta=0.0
% INFO    : Bus 55684	: V=0.9902566, theta=-77.315054 -> V=1.0, theta=0.0
% INFO    : Bus 55685	: V=0.9893509, theta=-77.382029 -> V=1.0, theta=0.0
% INFO    : Bus 55686	: V=0.9876184, theta=-77.513266 -> V=1.0, theta=0.0
% INFO    : Bus 55687	: V=0.9973464, theta=-77.016538 -> V=1.0, theta=0.0
% INFO    : Bus 55688	: V=0.993326, theta=-77.23473 -> V=1.0, theta=0.0
% INFO    : Bus 55689	: V=0.9850239, theta=-77.698612 -> V=1.0, theta=0.0
% INFO    : Bus 55690	: V=0.9938029, theta=-76.364106 -> V=1.0, theta=0.0
% INFO    : Bus 55691	: V=0.9714602, theta=-78.833685 -> V=1.0, theta=0.0
% INFO    : Bus 55692	: V=0.971339, theta=-78.812437 -> V=1.0, theta=0.0
% INFO    : Bus 55693	: V=0.9594915, theta=-79.421283 -> V=1.0, theta=0.0
% INFO    : Bus 55694	: V=0.9735793, theta=-78.367205 -> V=1.0, theta=0.0
% INFO    : Bus 55695	: V=0.9886638, theta=-76.361825 -> V=1.0, theta=0.0
% INFO    : Bus 55696	: V=0.9916761, theta=-76.348271 -> V=1.0, theta=0.0
% INFO    : Bus 55697	: V=0.9740227, theta=-76.879253 -> V=1.0, theta=0.0
% INFO    : Bus 55698	: V=0.996097, theta=-74.182143 -> V=1.0, theta=0.0
% INFO    : Bus 55699	: V=0.9758591, theta=-76.681642 -> V=1.0, theta=0.0
% INFO    : Bus 55700	: V=0.9672831, theta=-77.640641 -> V=1.0, theta=0.0
% INFO    : Bus 55701	: V=0.973849, theta=-76.839846 -> V=1.0, theta=0.0
% INFO    : Bus 55702	: V=0.9644853, theta=-77.486368 -> V=1.0, theta=0.0
% INFO    : Bus 55703	: V=0.9759058, theta=-76.658799 -> V=1.0, theta=0.0
% INFO    : Bus 55704	: V=0.9652989, theta=-77.422263 -> V=1.0, theta=0.0
% INFO    : Bus 55705	: V=0.9737914, theta=-76.751682 -> V=1.0, theta=0.0
% INFO    : Bus 55706	: V=0.9635969, theta=-78.796767 -> V=1.0, theta=0.0
% INFO    : Bus 55707	: V=0.962167, theta=-79.15688 -> V=1.0, theta=0.0
% INFO    : Bus 55708	: V=0.9602777, theta=-77.793743 -> V=1.0, theta=0.0
% INFO    : Bus 55709	: V=0.9696861, theta=-76.881756 -> V=1.0, theta=0.0
% INFO    : Bus 55710	: V=0.9637149, theta=-77.598358 -> V=1.0, theta=0.0
% INFO    : Bus 55711	: V=0.9635148, theta=-77.593882 -> V=1.0, theta=0.0
% INFO    : Bus 55712	: V=0.9628732, theta=-77.609855 -> V=1.0, theta=0.0
% INFO    : Bus 55713	: V=0.9708168, theta=-76.807856 -> V=1.0, theta=0.0
% INFO    : Bus 55714	: V=0.9571245, theta=-79.379463 -> V=1.0, theta=0.0
% INFO    : Bus 55715	: V=0.968226, theta=-77.988572 -> V=1.0, theta=0.0
% INFO    : Bus 55716	: V=0.9668889, theta=-78.148268 -> V=1.0, theta=0.0
% INFO    : Bus 55717	: V=0.9595147, theta=-79.43918 -> V=1.0, theta=0.0
% INFO    : Bus 55718	: V=0.9673995, theta=-78.103589 -> V=1.0, theta=0.0
% INFO    : Bus 55719	: V=0.9693404, theta=-77.98359 -> V=1.0, theta=0.0
% INFO    : Bus 55720	: V=0.9701655, theta=-77.875199 -> V=1.0, theta=0.0
% INFO    : Bus 55721	: V=0.9714129, theta=-77.841848 -> V=1.0, theta=0.0
% INFO    : Bus 55722	: V=0.9695803, theta=-77.871274 -> V=1.0, theta=0.0
% INFO    : Bus 55723	: V=0.9682253, theta=-77.983461 -> V=1.0, theta=0.0
% INFO    : Bus 55724	: V=0.9602956, theta=-78.912642 -> V=1.0, theta=0.0
% INFO    : Bus 55725	: V=0.9637716, theta=-78.760217 -> V=1.0, theta=0.0
% INFO    : Bus 55726	: V=0.9641223, theta=-78.675624 -> V=1.0, theta=0.0
% INFO    : Bus 55727	: V=0.97074, theta=-77.474714 -> V=1.0, theta=0.0
% INFO    : Bus 55728	: V=0.9622224, theta=-78.641227 -> V=1.0, theta=0.0
% INFO    : Bus 55729	: V=0.9602574, theta=-78.89736 -> V=1.0, theta=0.0
% INFO    : Bus 55730	: V=0.9624621, theta=-78.425169 -> V=1.0, theta=0.0
% INFO    : Bus 55731	: V=0.9623571, theta=-78.600932 -> V=1.0, theta=0.0
% INFO    : Bus 55732	: V=0.9659729, theta=-78.102988 -> V=1.0, theta=0.0
% INFO    : Bus 55733	: V=0.96493, theta=-78.207402 -> V=1.0, theta=0.0
% INFO    : Bus 55734	: V=0.9707117, theta=-76.975757 -> V=1.0, theta=0.0
% INFO    : Bus 55735	: V=0.9700524, theta=-77.37567 -> V=1.0, theta=0.0
% INFO    : Bus 55736	: V=0.969833, theta=-77.274609 -> V=1.0, theta=0.0
% INFO    : Bus 55737	: V=0.961344, theta=-77.532239 -> V=1.0, theta=0.0
% INFO    : Bus 55738	: V=0.9788394, theta=-76.930887 -> V=1.0, theta=0.0
% INFO    : Bus 55739	: V=0.9972854, theta=-75.344495 -> V=1.0, theta=0.0
% INFO    : Bus 55740	: V=0.9889557, theta=-76.584038 -> V=1.0, theta=0.0
% INFO    : Bus 55741	: V=0.9904846, theta=-76.650672 -> V=1.0, theta=0.0
% INFO    : Bus 55742	: V=0.9809115, theta=-77.336555 -> V=1.0, theta=0.0
% INFO    : Bus 55743	: V=0.9924224, theta=-76.684649 -> V=1.0, theta=0.0
% INFO    : Bus 55744	: V=1.0085345, theta=-75.636491 -> V=1.0, theta=0.0
% INFO    : Bus 55745	: V=0.9940092, theta=-77.083825 -> V=1.0, theta=0.0
% INFO    : Bus 55746	: V=0.9982574, theta=-76.773139 -> V=1.0, theta=0.0
% INFO    : Bus 55747	: V=1.0174576, theta=-75.074046 -> V=1.0, theta=0.0
% INFO    : Bus 55748	: V=1.0162995, theta=-75.131658 -> V=1.0, theta=0.0
% INFO    : Bus 55749	: V=1.0103346, theta=-75.595777 -> V=1.0, theta=0.0
% INFO    : Bus 55750	: V=0.9903842, theta=-76.288074 -> V=1.0, theta=0.0
% INFO    : Bus 55751	: V=0.9953788, theta=-76.132703 -> V=1.0, theta=0.0
% INFO    : Bus 55752	: V=1.0067134, theta=-76.003802 -> V=1.0, theta=0.0
% INFO    : Bus 55753	: V=0.9985842, theta=-76.19513 -> V=1.0, theta=0.0
% INFO    : Bus 55754	: V=1.004065, theta=-75.903206 -> V=1.0, theta=0.0
% INFO    : Bus 55755	: V=1.0083534, theta=-75.619545 -> V=1.0, theta=0.0
% INFO    : Bus 55756	: V=1.0098306, theta=-75.713838 -> V=1.0, theta=0.0
% INFO    : Bus 55757	: V=1.0194366, theta=-74.88015 -> V=1.0, theta=0.0
% INFO    : Bus 55758	: V=1.0104914, theta=-75.67864 -> V=1.0, theta=0.0
% INFO    : Bus 55759	: V=1.0077316, theta=-75.694517 -> V=1.0, theta=0.0
% INFO    : Bus 55760	: V=1.0084212, theta=-75.607423 -> V=1.0, theta=0.0
% INFO    : Bus 55761	: V=1.014852, theta=-74.822271 -> V=1.0, theta=0.0
% INFO    : Bus 55762	: V=1.0196858, theta=-74.03642 -> V=1.0, theta=0.0
% INFO    : Bus 55763	: V=1.0139209, theta=-75.045585 -> V=1.0, theta=0.0
% INFO    : Bus 55764	: V=1.0192385, theta=-74.123047 -> V=1.0, theta=0.0
% INFO    : Bus 55765	: V=1.0130591, theta=-75.250569 -> V=1.0, theta=0.0
% INFO    : Bus 55766	: V=1.0188754, theta=-74.188857 -> V=1.0, theta=0.0
% INFO    : Bus 55767	: V=1.0128734, theta=-75.299149 -> V=1.0, theta=0.0
% INFO    : Bus 55768	: V=1.0183138, theta=-74.291573 -> V=1.0, theta=0.0
% INFO    : Bus 55769	: V=1.017648, theta=-74.410978 -> V=1.0, theta=0.0
% INFO    : Bus 55770	: V=1.0021865, theta=-75.357858 -> V=1.0, theta=0.0
% INFO    : Bus 55771	: V=0.9622306, theta=-78.666718 -> V=1.0, theta=0.0
% INFO    : Bus 55772	: V=0.9529966, theta=-79.581438 -> V=1.0, theta=0.0
% INFO    : Bus 55773	: V=0.9526753, theta=-79.592884 -> V=1.0, theta=0.0
% INFO    : Bus 55774	: V=0.9618418, theta=-78.811333 -> V=1.0, theta=0.0
% INFO    : Bus 55775	: V=0.9618894, theta=-78.907976 -> V=1.0, theta=0.0
% INFO    : Bus 55776	: V=0.9518873, theta=-79.739317 -> V=1.0, theta=0.0
% INFO    : Bus 55777	: V=0.9514678, theta=-79.730458 -> V=1.0, theta=0.0
% INFO    : Bus 55778	: V=0.9510354, theta=-79.859304 -> V=1.0, theta=0.0
% INFO    : Bus 55779	: V=0.9509238, theta=-79.915642 -> V=1.0, theta=0.0
% INFO    : Bus 55780	: V=0.9520173, theta=-79.980947 -> V=1.0, theta=0.0
% INFO    : Bus 55781	: V=0.9520862, theta=-79.889819 -> V=1.0, theta=0.0
% INFO    : Bus 55782	: V=0.9521631, theta=-79.775738 -> V=1.0, theta=0.0
% INFO    : Bus 55783	: V=0.9522957, theta=-79.781205 -> V=1.0, theta=0.0
% INFO    : Bus 55784	: V=0.9649395, theta=-79.016177 -> V=1.0, theta=0.0
% INFO    : Bus 55785	: V=0.9531102, theta=-79.745002 -> V=1.0, theta=0.0
% INFO    : Bus 55786	: V=0.9525862, theta=-79.719923 -> V=1.0, theta=0.0
% INFO    : Bus 55787	: V=0.9514264, theta=-79.669959 -> V=1.0, theta=0.0
% INFO    : Bus 55788	: V=0.9517889, theta=-79.6113 -> V=1.0, theta=0.0
% INFO    : Bus 55789	: V=0.9568533, theta=-77.929722 -> V=1.0, theta=0.0
% INFO    : Bus 55790	: V=0.957371, theta=-77.850276 -> V=1.0, theta=0.0
% INFO    : Bus 55791	: V=0.9579659, theta=-77.759019 -> V=1.0, theta=0.0
% INFO    : Bus 55792	: V=0.9542949, theta=-79.355795 -> V=1.0, theta=0.0
% INFO    : Bus 55793	: V=0.9548928, theta=-79.041596 -> V=1.0, theta=0.0
% INFO    : Bus 55794	: V=0.955192, theta=-79.033858 -> V=1.0, theta=0.0
% INFO    : Bus 55795	: V=0.9552927, theta=-78.909276 -> V=1.0, theta=0.0
% INFO    : Bus 55796	: V=0.9570557, theta=-78.732934 -> V=1.0, theta=0.0
% INFO    : Bus 55797	: V=0.9557157, theta=-79.013687 -> V=1.0, theta=0.0
% INFO    : Bus 55798	: V=0.9564677, theta=-78.088107 -> V=1.0, theta=0.0
% INFO    : Bus 55799	: V=0.9593449, theta=-77.544322 -> V=1.0, theta=0.0
% INFO    : Bus 55800	: V=0.9566428, theta=-78.743746 -> V=1.0, theta=0.0
% INFO    : Bus 55801	: V=0.9927411, theta=-71.897171 -> V=1.0, theta=0.0
% INFO    : Bus 55802	: V=0.956422, theta=-78.098107 -> V=1.0, theta=0.0
% INFO    : Bus 55803	: V=0.9506981, theta=-79.43033 -> V=1.0, theta=0.0
% INFO    : Bus 55804	: V=0.9584861, theta=-77.526033 -> V=1.0, theta=0.0
% INFO    : Bus 55805	: V=0.9521565, theta=-79.248546 -> V=1.0, theta=0.0
% INFO    : Bus 55806	: V=0.9531577, theta=-79.064977 -> V=1.0, theta=0.0
% INFO    : Bus 55807	: V=0.9539379, theta=-78.973711 -> V=1.0, theta=0.0
% INFO    : Bus 55808	: V=0.9554954, theta=-78.795591 -> V=1.0, theta=0.0
% INFO    : Bus 55809	: V=0.9596258, theta=-77.367326 -> V=1.0, theta=0.0
% INFO    : Bus 55810	: V=0.9588404, theta=-78.561982 -> V=1.0, theta=0.0
% INFO    : Bus 55811	: V=0.9582659, theta=-78.315226 -> V=1.0, theta=0.0
% INFO    : Bus 55812	: V=0.961409, theta=-77.763138 -> V=1.0, theta=0.0
% INFO    : Bus 55813	: V=0.960141, theta=-78.070909 -> V=1.0, theta=0.0
% INFO    : Bus 55814	: V=0.9534366, theta=-79.704798 -> V=1.0, theta=0.0
% INFO    : Bus 55815	: V=0.9690447, theta=-78.779227 -> V=1.0, theta=0.0
% INFO    : Bus 55816	: V=0.9708887, theta=-78.710176 -> V=1.0, theta=0.0
% INFO    : Bus 55817	: V=0.9567164, theta=-79.606865 -> V=1.0, theta=0.0
% INFO    : Bus 55818	: V=0.9578328, theta=-79.566679 -> V=1.0, theta=0.0
% INFO    : Bus 55819	: V=0.9541132, theta=-79.537329 -> V=1.0, theta=0.0
% INFO    : Bus 55820	: V=0.9653524, theta=-77.792877 -> V=1.0, theta=0.0
% INFO    : Bus 55821	: V=0.9614206, theta=-78.934084 -> V=1.0, theta=0.0
% INFO    : Bus 55822	: V=0.9602174, theta=-79.068129 -> V=1.0, theta=0.0
% INFO    : Bus 55823	: V=0.9578051, theta=-79.307181 -> V=1.0, theta=0.0
% INFO    : Bus 55824	: V=0.975329, theta=-78.249169 -> V=1.0, theta=0.0
% INFO    : Bus 55825	: V=0.9599173, theta=-79.160281 -> V=1.0, theta=0.0
% INFO    : Bus 55826	: V=0.9558974, theta=-79.45945 -> V=1.0, theta=0.0
% INFO    : Bus 55827	: V=0.9568356, theta=-79.37084 -> V=1.0, theta=0.0
% INFO    : Bus 55828	: V=0.9558708, theta=-79.468875 -> V=1.0, theta=0.0
% INFO    : Bus 55829	: V=0.9577968, theta=-79.475666 -> V=1.0, theta=0.0
% INFO    : Bus 55830	: V=0.960776, theta=-79.406614 -> V=1.0, theta=0.0
% INFO    : Bus 55831	: V=0.9641295, theta=-79.344763 -> V=1.0, theta=0.0
% INFO    : Bus 55832	: V=0.96969, theta=-79.122886 -> V=1.0, theta=0.0
% INFO    : Bus 55833	: V=0.9799804, theta=-77.885582 -> V=1.0, theta=0.0
% INFO    : Bus 55834	: V=0.9760326, theta=-78.182463 -> V=1.0, theta=0.0
% INFO    : Bus 55835	: V=0.9802268, theta=-77.867523 -> V=1.0, theta=0.0
% INFO    : Bus 55836	: V=0.9901765, theta=-77.143761 -> V=1.0, theta=0.0
% INFO    : Bus 55837	: V=1.000309, theta=-74.601746 -> V=1.0, theta=0.0
% INFO    : Bus 55838	: V=0.9852322, theta=-77.497727 -> V=1.0, theta=0.0
% INFO    : Bus 55839	: V=0.9821995, theta=-77.709406 -> V=1.0, theta=0.0
% INFO    : Bus 55840	: V=0.976642, theta=-78.175042 -> V=1.0, theta=0.0
% INFO    : Bus 55841	: V=0.9781891, theta=-78.157048 -> V=1.0, theta=0.0
% INFO    : Bus 55842	: V=0.9776482, theta=-78.177523 -> V=1.0, theta=0.0
% INFO    : Bus 55843	: V=0.9765838, theta=-78.175005 -> V=1.0, theta=0.0
% INFO    : Bus 55844	: V=0.9578278, theta=-79.555238 -> V=1.0, theta=0.0
% INFO    : Bus 55845	: V=0.9560086, theta=-79.543897 -> V=1.0, theta=0.0
% INFO    : Bus 55846	: V=0.9766651, theta=-78.207607 -> V=1.0, theta=0.0
% INFO    : Bus 55847	: V=0.9786192, theta=-78.121983 -> V=1.0, theta=0.0
% INFO    : Bus 55848	: V=0.9641755, theta=-79.509599 -> V=1.0, theta=0.0
% INFO    : Bus 55849	: V=0.9590765, theta=-79.574127 -> V=1.0, theta=0.0
% INFO    : Bus 55850	: V=0.9606597, theta=-79.55666 -> V=1.0, theta=0.0
% INFO    : Bus 55851	: V=0.9841791, theta=-77.748431 -> V=1.0, theta=0.0
% INFO    : Bus 55852	: V=0.976791, theta=-78.320943 -> V=1.0, theta=0.0
% INFO    : Bus 55853	: V=0.9978219, theta=-74.402368 -> V=1.0, theta=0.0
% INFO    : Bus 55854	: V=0.9920375, theta=-76.388177 -> V=1.0, theta=0.0
% INFO    : Bus 55855	: V=0.9980684, theta=-71.220338 -> V=1.0, theta=0.0
% INFO    : Bus 55856	: V=0.9732857, theta=-74.151997 -> V=1.0, theta=0.0
% INFO    : Bus 55857	: V=0.9697319, theta=-74.41669 -> V=1.0, theta=0.0
% INFO    : Bus 55858	: V=0.9734927, theta=-73.112833 -> V=1.0, theta=0.0
% INFO    : Bus 55859	: V=0.9607858, theta=-76.724494 -> V=1.0, theta=0.0
% INFO    : Bus 55860	: V=0.9828322, theta=-72.351222 -> V=1.0, theta=0.0
% INFO    : Bus 55861	: V=0.9785142, theta=-73.642544 -> V=1.0, theta=0.0
% INFO    : Bus 55862	: V=0.9991781, theta=-70.920369 -> V=1.0, theta=0.0
% INFO    : Bus 55863	: V=0.9999788, theta=-70.717526 -> V=1.0, theta=0.0
% INFO    : Bus 55864	: V=0.9649866, theta=-75.751133 -> V=1.0, theta=0.0
% INFO    : Bus 55865	: V=0.9604953, theta=-77.324151 -> V=1.0, theta=0.0
% INFO    : Bus 55866	: V=0.956187, theta=-78.696531 -> V=1.0, theta=0.0
% INFO    : Bus 55867	: V=0.9570362, theta=-78.570316 -> V=1.0, theta=0.0
% INFO    : Bus 55868	: V=0.9698248, theta=-75.613062 -> V=1.0, theta=0.0
% INFO    : Bus 55869	: V=0.9570632, theta=-78.538933 -> V=1.0, theta=0.0
% INFO    : Bus 55870	: V=0.9559866, theta=-78.005149 -> V=1.0, theta=0.0
% INFO    : Bus 55871	: V=0.9549492, theta=-78.276341 -> V=1.0, theta=0.0
% INFO    : Bus 55872	: V=0.9558262, theta=-78.588688 -> V=1.0, theta=0.0
% INFO    : Bus 55873	: V=0.9551103, theta=-78.778064 -> V=1.0, theta=0.0
% INFO    : Bus 55874	: V=0.955685, theta=-78.741233 -> V=1.0, theta=0.0
% INFO    : Bus 55875	: V=0.954887, theta=-78.847362 -> V=1.0, theta=0.0
% INFO    : Bus 55876	: V=0.9537419, theta=-78.937888 -> V=1.0, theta=0.0
% INFO    : Bus 55877	: V=0.9515375, theta=-79.266504 -> V=1.0, theta=0.0
% INFO    : Bus 55878	: V=0.9506742, theta=-79.565268 -> V=1.0, theta=0.0
% INFO    : Bus 55879	: V=0.9536988, theta=-79.075116 -> V=1.0, theta=0.0
% INFO    : Bus 55880	: V=0.9542374, theta=-78.92596 -> V=1.0, theta=0.0
% INFO    : Bus 55881	: V=0.9543771, theta=-79.187985 -> V=1.0, theta=0.0
% INFO    : Bus 55882	: V=0.9529179, theta=-79.316035 -> V=1.0, theta=0.0
% INFO    : Bus 55883	: V=0.9515737, theta=-79.529329 -> V=1.0, theta=0.0
% INFO    : Bus 55884	: V=0.9512448, theta=-79.638935 -> V=1.0, theta=0.0
% INFO    : Bus 55885	: V=0.9521414, theta=-79.665129 -> V=1.0, theta=0.0
% INFO    : Bus 55886	: V=0.9516284, theta=-79.548228 -> V=1.0, theta=0.0
% INFO    : Bus 55887	: V=0.9515981, theta=-79.463295 -> V=1.0, theta=0.0
% INFO    : Bus 55888	: V=0.9521203, theta=-79.440315 -> V=1.0, theta=0.0
% INFO    : Bus 55889	: V=0.9531281, theta=-79.42889 -> V=1.0, theta=0.0
% INFO    : Bus 55890	: V=0.9938727, theta=-73.854347 -> V=1.0, theta=0.0
% INFO    : Bus 55891	: V=0.9518122, theta=-79.32192 -> V=1.0, theta=0.0
% INFO    : Bus 55892	: V=0.9558707, theta=-79.060268 -> V=1.0, theta=0.0
% INFO    : Bus 55893	: V=0.9929889, theta=-73.35891 -> V=1.0, theta=0.0
% INFO    : Bus 55894	: V=0.9644688, theta=-76.89188 -> V=1.0, theta=0.0
% INFO    : Bus 55895	: V=0.9459958, theta=-79.311193 -> V=1.0, theta=0.0
% INFO    : Bus 55896	: V=0.9631487, theta=-78.020478 -> V=1.0, theta=0.0
% INFO    : Bus 55897	: V=0.9620795, theta=-78.149085 -> V=1.0, theta=0.0
% INFO    : Bus 55898	: V=0.95096, theta=-79.6804 -> V=1.0, theta=0.0
% INFO    : Bus 55899	: V=0.9495369, theta=-79.834964 -> V=1.0, theta=0.0
% INFO    : Bus 55900	: V=0.997297, theta=-71.438847 -> V=1.0, theta=0.0
% INFO    : Bus 55901	: V=0.9666322, theta=-79.148154 -> V=1.0, theta=0.0
% INFO    : Bus 55902	: V=0.9803953, theta=-77.003826 -> V=1.0, theta=0.0
% INFO    : Bus 55903	: V=0.9804839, theta=-78.203012 -> V=1.0, theta=0.0
% INFO    : Bus 55904	: V=0.9725514, theta=-79.565628 -> V=1.0, theta=0.0
% INFO    : Bus 55905	: V=0.9626393, theta=-79.598743 -> V=1.0, theta=0.0
% INFO    : Bus 55906	: V=0.9709116, theta=-79.180876 -> V=1.0, theta=0.0
% INFO    : Bus 55907	: V=0.9685016, theta=-79.179405 -> V=1.0, theta=0.0
% INFO    : Bus 55908	: V=0.9664401, theta=-79.169016 -> V=1.0, theta=0.0
% INFO    : Bus 55909	: V=0.9618245, theta=-79.572469 -> V=1.0, theta=0.0
% INFO    : Bus 55910	: V=0.9646778, theta=-79.104239 -> V=1.0, theta=0.0
% INFO    : Bus 55911	: V=0.964573, theta=-79.386398 -> V=1.0, theta=0.0
% INFO    : Bus 55912	: V=0.957579, theta=-79.690518 -> V=1.0, theta=0.0
% INFO    : Bus 55913	: V=0.9603563, theta=-79.638968 -> V=1.0, theta=0.0
% INFO    : Bus 55914	: V=0.9626043, theta=-78.936453 -> V=1.0, theta=0.0
% INFO    : Bus 55915	: V=0.9568362, theta=-79.826644 -> V=1.0, theta=0.0
% INFO    : Bus 55916	: V=0.9675696, theta=-79.223268 -> V=1.0, theta=0.0
% INFO    : Bus 55917	: V=0.9684131, theta=-79.187289 -> V=1.0, theta=0.0
% INFO    : Bus 55918	: V=0.9661443, theta=-79.204283 -> V=1.0, theta=0.0
% INFO    : Bus 55919	: V=0.9927825, theta=-77.177104 -> V=1.0, theta=0.0
% INFO    : Bus 55920	: V=0.9711805, theta=-79.600013 -> V=1.0, theta=0.0
% INFO    : Bus 55921	: V=0.9711064, theta=-79.493605 -> V=1.0, theta=0.0
% INFO    : Bus 55922	: V=0.9717688, theta=-79.737669 -> V=1.0, theta=0.0
% INFO    : Bus 55923	: V=0.9858677, theta=-77.866774 -> V=1.0, theta=0.0
% INFO    : Bus 55924	: V=0.9867527, theta=-77.857999 -> V=1.0, theta=0.0
% INFO    : Bus 55925	: V=0.9853408, theta=-77.837951 -> V=1.0, theta=0.0
% INFO    : Bus 55926	: V=0.9612779, theta=-79.548953 -> V=1.0, theta=0.0
% INFO    : Bus 55927	: V=0.9823448, theta=-77.854261 -> V=1.0, theta=0.0
% INFO    : Bus 55928	: V=0.9835647, theta=-77.813021 -> V=1.0, theta=0.0
% INFO    : Bus 55929	: V=0.9857136, theta=-77.706458 -> V=1.0, theta=0.0
% INFO    : Bus 55930	: V=0.9924197, theta=-77.022743 -> V=1.0, theta=0.0
% INFO    : Bus 55931	: V=1.005714, theta=-74.879927 -> V=1.0, theta=0.0
% INFO    : Bus 55932	: V=1.0087661, theta=-74.910187 -> V=1.0, theta=0.0
% INFO    : Bus 55933	: V=1.0122588, theta=-74.944614 -> V=1.0, theta=0.0
% INFO    : Bus 55934	: V=0.992549, theta=-77.250475 -> V=1.0, theta=0.0
% INFO    : Bus 55935	: V=0.9900757, theta=-77.465972 -> V=1.0, theta=0.0
% INFO    : Bus 55936	: V=0.9776656, theta=-80.007129 -> V=1.0, theta=0.0
% INFO    : Bus 55937	: V=0.9985932, theta=-76.47401 -> V=1.0, theta=0.0
% INFO    : Bus 55938	: V=1.0133026, theta=-74.947635 -> V=1.0, theta=0.0
% INFO    : Bus 55939	: V=1.0020567, theta=-76.217147 -> V=1.0, theta=0.0
% INFO    : Bus 55940	: V=1.015598, theta=-74.986225 -> V=1.0, theta=0.0
% INFO    : Bus 55941	: V=1.0144877, theta=-75.079347 -> V=1.0, theta=0.0
% INFO    : Bus 55942	: V=0.9461331, theta=-80.063059 -> V=1.0, theta=0.0
% INFO    : Bus 55943	: V=0.9476803, theta=-79.949843 -> V=1.0, theta=0.0
% INFO    : Bus 55944	: V=0.9466612, theta=-80.02949 -> V=1.0, theta=0.0
% INFO    : Bus 55945	: V=0.9539218, theta=-79.655614 -> V=1.0, theta=0.0
% INFO    : Bus 55946	: V=0.9572248, theta=-79.604955 -> V=1.0, theta=0.0
% INFO    : Bus 55947	: V=0.9546149, theta=-79.757673 -> V=1.0, theta=0.0
% INFO    : Bus 55948	: V=0.9600663, theta=-78.533286 -> V=1.0, theta=0.0
% INFO    : Bus 55949	: V=0.9509827, theta=-79.840931 -> V=1.0, theta=0.0
% INFO    : Bus 55950	: V=0.9601918, theta=-78.558679 -> V=1.0, theta=0.0
% INFO    : Bus 55951	: V=0.9612758, theta=-78.573699 -> V=1.0, theta=0.0
% INFO    : Bus 55952	: V=0.9622492, theta=-78.375143 -> V=1.0, theta=0.0
% INFO    : Bus 55953	: V=0.9617512, theta=-78.352127 -> V=1.0, theta=0.0
% INFO    : Bus 55954	: V=0.9547476, theta=-79.089495 -> V=1.0, theta=0.0
% INFO    : Bus 55955	: V=0.9538692, theta=-79.077872 -> V=1.0, theta=0.0
% INFO    : Bus 55956	: V=0.9538437, theta=-79.065507 -> V=1.0, theta=0.0
% INFO    : Bus 55957	: V=0.954917, theta=-79.051867 -> V=1.0, theta=0.0
% INFO    : Bus 55958	: V=0.9546102, theta=-78.978677 -> V=1.0, theta=0.0
% INFO    : Bus 55959	: V=0.9544392, theta=-79.022392 -> V=1.0, theta=0.0
% INFO    : Bus 55960	: V=0.9544354, theta=-79.000176 -> V=1.0, theta=0.0
% INFO    : Bus 55961	: V=0.9540434, theta=-78.948452 -> V=1.0, theta=0.0
% INFO    : Bus 55962	: V=0.9547047, theta=-78.929658 -> V=1.0, theta=0.0
% INFO    : Bus 55963	: V=0.9542196, theta=-79.009389 -> V=1.0, theta=0.0
% INFO    : Bus 55964	: V=0.9532294, theta=-79.096327 -> V=1.0, theta=0.0
% INFO    : Bus 55965	: V=0.9553411, theta=-78.921973 -> V=1.0, theta=0.0
% INFO    : Bus 55966	: V=0.9553243, theta=-78.235568 -> V=1.0, theta=0.0
% INFO    : Bus 55967	: V=0.9554101, theta=-78.886245 -> V=1.0, theta=0.0
% INFO    : Bus 55968	: V=0.9592731, theta=-77.289161 -> V=1.0, theta=0.0
% INFO    : Bus 55969	: V=0.9546942, theta=-78.973012 -> V=1.0, theta=0.0
% INFO    : Bus 55970	: V=0.9595284, theta=-77.24686 -> V=1.0, theta=0.0
% INFO    : Bus 55971	: V=0.9554977, theta=-78.052419 -> V=1.0, theta=0.0
% INFO    : Bus 55972	: V=0.9594946, theta=-77.30128 -> V=1.0, theta=0.0
% INFO    : Bus 55973	: V=0.9542676, theta=-78.942234 -> V=1.0, theta=0.0
% INFO    : Bus 55974	: V=0.9599384, theta=-77.310988 -> V=1.0, theta=0.0
% INFO    : Bus 55975	: V=0.9602032, theta=-77.305858 -> V=1.0, theta=0.0
% INFO    : Bus 55976	: V=0.9594224, theta=-77.357663 -> V=1.0, theta=0.0
% INFO    : Bus 55977	: V=0.9597075, theta=-77.29993 -> V=1.0, theta=0.0
% INFO    : Bus 55978	: V=0.9596826, theta=-77.27915 -> V=1.0, theta=0.0
% INFO    : Bus 55979	: V=0.9603222, theta=-77.560962 -> V=1.0, theta=0.0
% INFO    : Bus 55980	: V=0.9598157, theta=-77.24114 -> V=1.0, theta=0.0
% INFO    : Bus 55981	: V=0.96001, theta=-77.195879 -> V=1.0, theta=0.0
% INFO    : Bus 55982	: V=0.9604057, theta=-77.178109 -> V=1.0, theta=0.0
% INFO    : Bus 55983	: V=0.9612478, theta=-77.108773 -> V=1.0, theta=0.0
% INFO    : Bus 55984	: V=0.9601711, theta=-77.238484 -> V=1.0, theta=0.0
% INFO    : Bus 55985	: V=0.9599689, theta=-77.288656 -> V=1.0, theta=0.0
% INFO    : Bus 55986	: V=0.9568737, theta=-77.888421 -> V=1.0, theta=0.0
% INFO    : Bus 55987	: V=0.9596105, theta=-77.330559 -> V=1.0, theta=0.0
% INFO    : Bus 55988	: V=0.9623917, theta=-77.520169 -> V=1.0, theta=0.0
% INFO    : Bus 55989	: V=0.9619049, theta=-76.565401 -> V=1.0, theta=0.0
% INFO    : Bus 55990	: V=0.969602, theta=-75.573126 -> V=1.0, theta=0.0
% INFO    : Bus 55991	: V=0.9690575, theta=-75.631425 -> V=1.0, theta=0.0
% INFO    : Bus 55992	: V=0.9690501, theta=-75.595801 -> V=1.0, theta=0.0
% INFO    : Bus 55993	: V=0.968683, theta=-75.595676 -> V=1.0, theta=0.0
% INFO    : Bus 55994	: V=0.9687183, theta=-75.607205 -> V=1.0, theta=0.0
% INFO    : Bus 55995	: V=0.9686563, theta=-75.672859 -> V=1.0, theta=0.0
% INFO    : Bus 55996	: V=0.9598965, theta=-77.251287 -> V=1.0, theta=0.0
% INFO    : Bus 55997	: V=0.9608789, theta=-77.082158 -> V=1.0, theta=0.0
% INFO    : Bus 55998	: V=0.9603812, theta=-77.128487 -> V=1.0, theta=0.0
% INFO    : Bus 55999	: V=0.960441, theta=-77.116411 -> V=1.0, theta=0.0
% INFO    : Bus 56000	: V=0.9556497, theta=-78.187939 -> V=1.0, theta=0.0
% INFO    : Bus 56001	: V=0.9562075, theta=-78.054977 -> V=1.0, theta=0.0
% INFO    : Bus 56002	: V=0.9565167, theta=-78.051216 -> V=1.0, theta=0.0
% INFO    : Bus 56003	: V=0.9622321, theta=-76.843286 -> V=1.0, theta=0.0
% INFO    : Bus 56004	: V=0.956783, theta=-78.02337 -> V=1.0, theta=0.0
% INFO    : Bus 56005	: V=0.9550376, theta=-78.157893 -> V=1.0, theta=0.0
% INFO    : Bus 56006	: V=0.9554169, theta=-78.149543 -> V=1.0, theta=0.0
% INFO    : Bus 56007	: V=0.9610443, theta=-77.026149 -> V=1.0, theta=0.0
% INFO    : Bus 56008	: V=0.9613863, theta=-76.993285 -> V=1.0, theta=0.0
% INFO    : Bus 56009	: V=0.9609478, theta=-77.13634 -> V=1.0, theta=0.0
% INFO    : Bus 56010	: V=0.9604949, theta=-77.193677 -> V=1.0, theta=0.0
% INFO    : Bus 56011	: V=0.9681875, theta=-75.725476 -> V=1.0, theta=0.0
% INFO    : Bus 56012	: V=0.9623602, theta=-76.577413 -> V=1.0, theta=0.0
% INFO    : Bus 56013	: V=0.9684926, theta=-75.614049 -> V=1.0, theta=0.0
% INFO    : Bus 56014	: V=0.961511, theta=-76.681207 -> V=1.0, theta=0.0
% INFO    : Bus 56015	: V=0.9685634, theta=-75.619551 -> V=1.0, theta=0.0
% INFO    : Bus 56016	: V=0.9623252, theta=-76.604857 -> V=1.0, theta=0.0
% INFO    : Bus 56017	: V=0.9610492, theta=-76.652086 -> V=1.0, theta=0.0
% INFO    : Bus 56018	: V=0.9616073, theta=-76.631072 -> V=1.0, theta=0.0
% INFO    : Bus 56019	: V=0.9678558, theta=-75.767579 -> V=1.0, theta=0.0
% INFO    : Bus 56020	: V=0.9617938, theta=-77.006474 -> V=1.0, theta=0.0
% INFO    : Bus 56021	: V=0.9608894, theta=-77.042842 -> V=1.0, theta=0.0
% INFO    : Bus 56022	: V=0.9631341, theta=-76.600542 -> V=1.0, theta=0.0
% INFO    : Bus 56023	: V=0.9642461, theta=-76.330611 -> V=1.0, theta=0.0
% INFO    : Bus 56024	: V=0.9657895, theta=-75.995439 -> V=1.0, theta=0.0
% INFO    : Bus 56025	: V=0.9615704, theta=-76.703591 -> V=1.0, theta=0.0
% INFO    : Bus 56026	: V=1.0037645, theta=-69.526875 -> V=1.0, theta=0.0
% INFO    : Bus 56027	: V=0.965505, theta=-76.159559 -> V=1.0, theta=0.0
% INFO    : Bus 56028	: V=0.9817198, theta=-73.407826 -> V=1.0, theta=0.0
% INFO    : Bus 56029	: V=0.9623201, theta=-76.644581 -> V=1.0, theta=0.0
% INFO    : Bus 56030	: V=0.9693612, theta=-75.572071 -> V=1.0, theta=0.0
% INFO    : Bus 56031	: V=0.9623317, theta=-76.570813 -> V=1.0, theta=0.0
% INFO    : Bus 56032	: V=0.9637211, theta=-76.446032 -> V=1.0, theta=0.0
% INFO    : Bus 56033	: V=0.964592, theta=-76.306795 -> V=1.0, theta=0.0
% INFO    : Bus 56034	: V=0.961468, theta=-76.628865 -> V=1.0, theta=0.0
% INFO    : Bus 56035	: V=0.9540721, theta=-78.545783 -> V=1.0, theta=0.0
% INFO    : Bus 56036	: V=0.9558521, theta=-78.164147 -> V=1.0, theta=0.0
% INFO    : Bus 56037	: V=0.9610076, theta=-77.190405 -> V=1.0, theta=0.0
% INFO    : Bus 56038	: V=0.9588496, theta=-77.789347 -> V=1.0, theta=0.0
% INFO    : Bus 56039	: V=0.9584671, theta=-77.894267 -> V=1.0, theta=0.0
% INFO    : Bus 56040	: V=0.9599511, theta=-77.348084 -> V=1.0, theta=0.0
% INFO    : Bus 56041	: V=0.9604121, theta=-77.350916 -> V=1.0, theta=0.0
% INFO    : Bus 56042	: V=0.9612988, theta=-77.308771 -> V=1.0, theta=0.0
% INFO    : Bus 56043	: V=0.9598088, theta=-77.315958 -> V=1.0, theta=0.0
% INFO    : Bus 56044	: V=0.9636097, theta=-76.513469 -> V=1.0, theta=0.0
% INFO    : Bus 56045	: V=0.9625278, theta=-76.689655 -> V=1.0, theta=0.0
% INFO    : Bus 56046	: V=0.9626978, theta=-76.673376 -> V=1.0, theta=0.0
% INFO    : Bus 56047	: V=0.9582574, theta=-77.824177 -> V=1.0, theta=0.0
% INFO    : Bus 56048	: V=0.9606146, theta=-77.088869 -> V=1.0, theta=0.0
% INFO    : Bus 56049	: V=0.9604681, theta=-77.093776 -> V=1.0, theta=0.0
% INFO    : Bus 56050	: V=0.9603331, theta=-77.106578 -> V=1.0, theta=0.0
% INFO    : Bus 56051	: V=0.9601497, theta=-77.130189 -> V=1.0, theta=0.0
% INFO    : Bus 56052	: V=0.960038, theta=-77.143837 -> V=1.0, theta=0.0
% INFO    : Bus 56053	: V=0.9544724, theta=-78.257229 -> V=1.0, theta=0.0
% INFO    : Bus 56054	: V=0.9559557, theta=-78.120288 -> V=1.0, theta=0.0
% INFO    : Bus 56055	: V=0.9550005, theta=-78.229738 -> V=1.0, theta=0.0
% INFO    : Bus 56056	: V=0.9536254, theta=-78.312966 -> V=1.0, theta=0.0
% INFO    : Bus 56057	: V=0.9565639, theta=-78.175292 -> V=1.0, theta=0.0
% INFO    : Bus 56058	: V=0.9595499, theta=-77.230494 -> V=1.0, theta=0.0
% INFO    : Bus 56059	: V=0.9598465, theta=-77.199723 -> V=1.0, theta=0.0
% INFO    : Bus 56060	: V=0.9548963, theta=-78.258996 -> V=1.0, theta=0.0
% INFO    : Bus 56061	: V=0.9557927, theta=-78.057746 -> V=1.0, theta=0.0
% INFO    : Bus 56062	: V=0.9610832, theta=-77.002961 -> V=1.0, theta=0.0
% INFO    : Bus 56063	: V=0.9625848, theta=-76.69276 -> V=1.0, theta=0.0
% INFO    : Bus 56064	: V=0.9587449, theta=-77.304561 -> V=1.0, theta=0.0
% INFO    : Bus 56065	: V=0.9579992, theta=-77.299435 -> V=1.0, theta=0.0
% INFO    : Bus 56066	: V=0.9625549, theta=-76.702845 -> V=1.0, theta=0.0
% INFO    : Bus 56067	: V=0.9572247, theta=-77.915723 -> V=1.0, theta=0.0
% INFO    : Bus 56068	: V=0.9563244, theta=-78.035494 -> V=1.0, theta=0.0
% INFO    : Bus 56069	: V=0.9552905, theta=-78.238079 -> V=1.0, theta=0.0
% INFO    : Bus 56070	: V=0.9572721, theta=-77.660278 -> V=1.0, theta=0.0
% INFO    : Bus 56071	: V=0.9581397, theta=-77.602573 -> V=1.0, theta=0.0
% INFO    : Bus 56072	: V=0.9572357, theta=-77.286384 -> V=1.0, theta=0.0
% INFO    : Bus 56073	: V=0.9586176, theta=-77.134169 -> V=1.0, theta=0.0
% INFO    : Bus 56074	: V=0.9582623, theta=-77.261366 -> V=1.0, theta=0.0
% INFO    : Bus 56075	: V=0.9581553, theta=-77.228508 -> V=1.0, theta=0.0
% INFO    : Bus 56076	: V=0.9581083, theta=-77.228527 -> V=1.0, theta=0.0
% INFO    : Bus 56077	: V=0.9585285, theta=-77.18931 -> V=1.0, theta=0.0
% INFO    : Bus 56078	: V=0.9589607, theta=-77.158421 -> V=1.0, theta=0.0
% INFO    : Bus 56079	: V=0.9595993, theta=-77.072598 -> V=1.0, theta=0.0
% INFO    : Bus 56080	: V=0.9596036, theta=-77.109729 -> V=1.0, theta=0.0
% INFO    : Bus 56081	: V=0.9671912, theta=-75.828219 -> V=1.0, theta=0.0
% INFO    : Bus 56082	: V=0.9664282, theta=-75.90359 -> V=1.0, theta=0.0
% INFO    : Bus 56083	: V=0.9620845, theta=-76.823058 -> V=1.0, theta=0.0
% INFO    : Bus 56084	: V=0.9664345, theta=-75.864659 -> V=1.0, theta=0.0
% INFO    : Bus 56085	: V=0.9690953, theta=-74.336091 -> V=1.0, theta=0.0
% INFO    : Bus 56086	: V=0.9628279, theta=-77.107217 -> V=1.0, theta=0.0
% INFO    : Bus 56087	: V=0.9762664, theta=-75.235266 -> V=1.0, theta=0.0
% INFO    : Bus 56088	: V=0.9628384, theta=-76.922015 -> V=1.0, theta=0.0
% INFO    : Bus 56089	: V=0.9625797, theta=-76.851899 -> V=1.0, theta=0.0
% INFO    : Bus 56090	: V=0.9623247, theta=-77.017849 -> V=1.0, theta=0.0
% INFO    : Bus 56091	: V=0.963218, theta=-76.803778 -> V=1.0, theta=0.0
% INFO    : Bus 56092	: V=0.962393, theta=-77.049675 -> V=1.0, theta=0.0
% INFO    : Bus 56093	: V=0.9649417, theta=-76.445923 -> V=1.0, theta=0.0
% INFO    : Bus 56094	: V=0.9643915, theta=-76.485582 -> V=1.0, theta=0.0
% INFO    : Bus 56095	: V=0.9576328, theta=-77.277358 -> V=1.0, theta=0.0
% INFO    : Bus 56096	: V=0.9572127, theta=-77.296809 -> V=1.0, theta=0.0
% INFO    : Bus 56097	: V=0.956984, theta=-77.291822 -> V=1.0, theta=0.0
% INFO    : Bus 56098	: V=0.9613653, theta=-77.088242 -> V=1.0, theta=0.0
% INFO    : Bus 56099	: V=0.9607091, theta=-77.083033 -> V=1.0, theta=0.0
% INFO    : Bus 56100	: V=0.9605028, theta=-77.056123 -> V=1.0, theta=0.0
% INFO    : Bus 56101	: V=0.9625823, theta=-76.799588 -> V=1.0, theta=0.0
% INFO    : Bus 56102	: V=0.9616493, theta=-76.905863 -> V=1.0, theta=0.0
% INFO    : Bus 56103	: V=0.962433, theta=-76.836931 -> V=1.0, theta=0.0
% INFO    : Bus 56104	: V=0.9639326, theta=-76.725833 -> V=1.0, theta=0.0
% INFO    : Bus 56105	: V=0.9624379, theta=-76.946907 -> V=1.0, theta=0.0
% INFO    : Bus 56106	: V=0.9698434, theta=-75.300652 -> V=1.0, theta=0.0
% INFO    : Bus 56107	: V=0.9625668, theta=-76.811548 -> V=1.0, theta=0.0
% INFO    : Bus 56108	: V=0.9638494, theta=-76.139121 -> V=1.0, theta=0.0
% INFO    : Bus 56109	: V=0.9664268, theta=-75.364297 -> V=1.0, theta=0.0
% INFO    : Bus 56110	: V=0.9657429, theta=-75.440023 -> V=1.0, theta=0.0
% INFO    : Bus 56111	: V=0.96574, theta=-75.440551 -> V=1.0, theta=0.0
% INFO    : Bus 56112	: V=0.9581585, theta=-77.216666 -> V=1.0, theta=0.0
% INFO    : Bus 56113	: V=0.9572979, theta=-77.279965 -> V=1.0, theta=0.0
% INFO    : Bus 56114	: V=0.9569818, theta=-77.290098 -> V=1.0, theta=0.0
% INFO    : Bus 56115	: V=0.9577603, theta=-77.226665 -> V=1.0, theta=0.0
% INFO    : Bus 56116	: V=0.9582843, theta=-77.12025 -> V=1.0, theta=0.0
% INFO    : Bus 56117	: V=0.9650505, theta=-75.514703 -> V=1.0, theta=0.0
% INFO    : Bus 56118	: V=0.9690187, theta=-75.077865 -> V=1.0, theta=0.0
% INFO    : Bus 56119	: V=0.9630272, theta=-76.302383 -> V=1.0, theta=0.0
% INFO    : Bus 56120	: V=0.956425, theta=-77.188808 -> V=1.0, theta=0.0
% INFO    : Bus 56121	: V=0.9569912, theta=-77.16073 -> V=1.0, theta=0.0
% INFO    : Bus 56122	: V=0.9564903, theta=-77.190051 -> V=1.0, theta=0.0
% INFO    : Bus 56123	: V=0.9561378, theta=-77.194443 -> V=1.0, theta=0.0
% INFO    : Bus 56124	: V=0.957836, theta=-77.20729 -> V=1.0, theta=0.0
% INFO    : Bus 56125	: V=0.962917, theta=-76.216311 -> V=1.0, theta=0.0
% INFO    : Bus 56126	: V=0.9648404, theta=-76.016476 -> V=1.0, theta=0.0
% INFO    : Bus 56127	: V=0.9552652, theta=-77.398666 -> V=1.0, theta=0.0
% INFO    : Bus 56128	: V=0.9638607, theta=-76.110443 -> V=1.0, theta=0.0
% INFO    : Bus 56129	: V=0.9554205, theta=-77.394159 -> V=1.0, theta=0.0
% INFO    : Bus 56130	: V=0.9561846, theta=-77.313977 -> V=1.0, theta=0.0
% INFO    : Bus 56131	: V=0.9569818, theta=-77.222833 -> V=1.0, theta=0.0
% INFO    : Bus 56132	: V=0.9560922, theta=-77.139366 -> V=1.0, theta=0.0
% INFO    : Bus 56133	: V=0.9631331, theta=-76.185322 -> V=1.0, theta=0.0
% INFO    : Bus 56134	: V=0.9591006, theta=-76.943836 -> V=1.0, theta=0.0
% INFO    : Bus 56135	: V=0.9578635, theta=-77.097532 -> V=1.0, theta=0.0
% INFO    : Bus 56136	: V=0.9613778, theta=-76.43528 -> V=1.0, theta=0.0
% INFO    : Bus 56137	: V=0.9650271, theta=-75.967547 -> V=1.0, theta=0.0
% INFO    : Bus 56138	: V=0.9659224, theta=-75.8998 -> V=1.0, theta=0.0
% INFO    : Bus 56139	: V=0.9648992, theta=-75.869228 -> V=1.0, theta=0.0
% INFO    : Bus 56140	: V=0.9837355, theta=-72.905555 -> V=1.0, theta=0.0
% INFO    : Bus 56141	: V=0.9659146, theta=-75.860547 -> V=1.0, theta=0.0
% INFO    : Bus 56142	: V=0.9630827, theta=-76.217761 -> V=1.0, theta=0.0
% INFO    : Bus 56143	: V=0.9560769, theta=-76.928317 -> V=1.0, theta=0.0
% INFO    : Bus 56144	: V=0.9613594, theta=-76.563384 -> V=1.0, theta=0.0
% INFO    : Bus 56145	: V=0.9643201, theta=-76.435876 -> V=1.0, theta=0.0
% INFO    : Bus 56146	: V=0.9594098, theta=-76.894059 -> V=1.0, theta=0.0
% INFO    : Bus 56147	: V=0.9647197, theta=-76.363973 -> V=1.0, theta=0.0
% INFO    : Bus 56148	: V=0.9607694, theta=-76.710939 -> V=1.0, theta=0.0
% INFO    : Bus 56149	: V=0.9609947, theta=-76.650809 -> V=1.0, theta=0.0
% INFO    : Bus 56150	: V=0.9653432, theta=-76.2687 -> V=1.0, theta=0.0
% INFO    : Bus 56151	: V=0.965993, theta=-76.18137 -> V=1.0, theta=0.0
% INFO    : Bus 56152	: V=0.963099, theta=-76.637788 -> V=1.0, theta=0.0
% INFO    : Bus 56153	: V=0.9671629, theta=-76.037565 -> V=1.0, theta=0.0
% INFO    : Bus 56154	: V=0.961699, theta=-78.461594 -> V=1.0, theta=0.0
% INFO    : Bus 56155	: V=0.957101, theta=-78.998743 -> V=1.0, theta=0.0
% INFO    : Bus 56156	: V=0.9557409, theta=-79.086941 -> V=1.0, theta=0.0
% INFO    : Bus 56157	: V=0.9597997, theta=-78.85512 -> V=1.0, theta=0.0
% INFO    : Bus 56158	: V=0.9557909, theta=-79.077723 -> V=1.0, theta=0.0
% INFO    : Bus 56159	: V=0.9561227, theta=-79.053584 -> V=1.0, theta=0.0
% INFO    : Bus 56160	: V=0.9613378, theta=-78.302161 -> V=1.0, theta=0.0
% INFO    : Bus 56161	: V=0.9556936, theta=-78.963816 -> V=1.0, theta=0.0
% INFO    : Bus 56162	: V=0.9615565, theta=-78.102832 -> V=1.0, theta=0.0
% INFO    : Bus 56163	: V=0.9605668, theta=-77.997392 -> V=1.0, theta=0.0
% INFO    : Bus 56164	: V=0.9568644, theta=-78.919362 -> V=1.0, theta=0.0
% INFO    : Bus 56165	: V=0.9603478, theta=-78.06367 -> V=1.0, theta=0.0
% INFO    : Bus 56166	: V=0.9573369, theta=-78.90496 -> V=1.0, theta=0.0
% INFO    : Bus 56167	: V=0.9596141, theta=-78.859412 -> V=1.0, theta=0.0
% INFO    : Bus 56168	: V=0.957213, theta=-78.995028 -> V=1.0, theta=0.0
% INFO    : Bus 56169	: V=0.9574383, theta=-79.013548 -> V=1.0, theta=0.0
% INFO    : Bus 56170	: V=0.9580734, theta=-78.9713 -> V=1.0, theta=0.0
% INFO    : Bus 56171	: V=0.9578731, theta=-79.008173 -> V=1.0, theta=0.0
% INFO    : Bus 56172	: V=0.9612488, theta=-77.901544 -> V=1.0, theta=0.0
% INFO    : Bus 56173	: V=0.9543954, theta=-78.594587 -> V=1.0, theta=0.0
% INFO    : Bus 56174	: V=0.9621428, theta=-77.773792 -> V=1.0, theta=0.0
% INFO    : Bus 56175	: V=0.9627163, theta=-77.68237 -> V=1.0, theta=0.0
% INFO    : Bus 56176	: V=0.9637359, theta=-77.511471 -> V=1.0, theta=0.0
% INFO    : Bus 56177	: V=0.9640976, theta=-77.430953 -> V=1.0, theta=0.0
% INFO    : Bus 56178	: V=0.9553288, theta=-78.370155 -> V=1.0, theta=0.0
% INFO    : Bus 56179	: V=0.9553194, theta=-78.374718 -> V=1.0, theta=0.0
% INFO    : Bus 56180	: V=0.9593587, theta=-77.861065 -> V=1.0, theta=0.0
% INFO    : Bus 56181	: V=0.9607426, theta=-77.728938 -> V=1.0, theta=0.0
% INFO    : Bus 56182	: V=0.9632274, theta=-77.141723 -> V=1.0, theta=0.0
% INFO    : Bus 56183	: V=0.9615725, theta=-77.708616 -> V=1.0, theta=0.0
% INFO    : Bus 56184	: V=0.9650999, theta=-77.289481 -> V=1.0, theta=0.0
% INFO    : Bus 56185	: V=0.9658591, theta=-77.136452 -> V=1.0, theta=0.0
% INFO    : Bus 56186	: V=0.9814314, theta=-74.123288 -> V=1.0, theta=0.0
% INFO    : Bus 56187	: V=0.9654748, theta=-77.491194 -> V=1.0, theta=0.0
% INFO    : Bus 56188	: V=0.9622145, theta=-77.575453 -> V=1.0, theta=0.0
% INFO    : Bus 56189	: V=0.9608917, theta=-77.731289 -> V=1.0, theta=0.0
% INFO    : Bus 56190	: V=0.966972, theta=-76.904111 -> V=1.0, theta=0.0
% INFO    : Bus 56191	: V=0.9662787, theta=-76.953751 -> V=1.0, theta=0.0
% INFO    : Bus 56192	: V=0.9645167, theta=-77.068258 -> V=1.0, theta=0.0
% INFO    : Bus 56193	: V=0.959623, theta=-77.757516 -> V=1.0, theta=0.0
% INFO    : Bus 56194	: V=0.9587472, theta=-77.920978 -> V=1.0, theta=0.0
% INFO    : Bus 56195	: V=0.9587194, theta=-77.869905 -> V=1.0, theta=0.0
% INFO    : Bus 56196	: V=0.9593667, theta=-77.737289 -> V=1.0, theta=0.0
% INFO    : Bus 56197	: V=0.9597898, theta=-77.601422 -> V=1.0, theta=0.0
% INFO    : Bus 56198	: V=0.9618639, theta=-77.189683 -> V=1.0, theta=0.0
% INFO    : Bus 56199	: V=0.9631037, theta=-77.573261 -> V=1.0, theta=0.0
% INFO    : Bus 56200	: V=0.9605539, theta=-78.036821 -> V=1.0, theta=0.0
% INFO    : Bus 56201	: V=0.9589194, theta=-78.915786 -> V=1.0, theta=0.0
% INFO    : Bus 56202	: V=0.9597426, theta=-78.857641 -> V=1.0, theta=0.0
% INFO    : Bus 56203	: V=0.9588995, theta=-78.872092 -> V=1.0, theta=0.0
% INFO    : Bus 56204	: V=0.9618654, theta=-77.967041 -> V=1.0, theta=0.0
% INFO    : Bus 56205	: V=0.9618206, theta=-78.386752 -> V=1.0, theta=0.0
% INFO    : Bus 56206	: V=0.9624836, theta=-77.869394 -> V=1.0, theta=0.0
% INFO    : Bus 56207	: V=0.9623006, theta=-77.913074 -> V=1.0, theta=0.0
% INFO    : Bus 56208	: V=0.9578112, theta=-78.576375 -> V=1.0, theta=0.0
% INFO    : Bus 56209	: V=0.9582866, theta=-78.542938 -> V=1.0, theta=0.0
% INFO    : Bus 56210	: V=0.9588347, theta=-78.521552 -> V=1.0, theta=0.0
% INFO    : Bus 56211	: V=0.9595265, theta=-78.478857 -> V=1.0, theta=0.0
% INFO    : Bus 56212	: V=0.9597425, theta=-78.444945 -> V=1.0, theta=0.0
% INFO    : Bus 56213	: V=0.9600339, theta=-78.404484 -> V=1.0, theta=0.0
% INFO    : Bus 56214	: V=0.9582555, theta=-78.527305 -> V=1.0, theta=0.0
% INFO    : Bus 56215	: V=0.9591251, theta=-78.502213 -> V=1.0, theta=0.0
% INFO    : Bus 56216	: V=0.9633814, theta=-77.777345 -> V=1.0, theta=0.0
% INFO    : Bus 56217	: V=0.9648951, theta=-77.590386 -> V=1.0, theta=0.0
% INFO    : Bus 56218	: V=0.9667184, theta=-77.369375 -> V=1.0, theta=0.0
% INFO    : Bus 56219	: V=0.9596321, theta=-78.392715 -> V=1.0, theta=0.0
% INFO    : Bus 56220	: V=0.9605301, theta=-78.368541 -> V=1.0, theta=0.0
% INFO    : Bus 56221	: V=0.9665702, theta=-77.30539 -> V=1.0, theta=0.0
% INFO    : Bus 56222	: V=0.9676031, theta=-77.095517 -> V=1.0, theta=0.0
% INFO    : Bus 56223	: V=0.969454, theta=-77.015638 -> V=1.0, theta=0.0
% INFO    : Bus 56224	: V=0.9718936, theta=-76.898996 -> V=1.0, theta=0.0
% INFO    : Bus 56225	: V=0.9719985, theta=-76.910839 -> V=1.0, theta=0.0
% INFO    : Bus 56226	: V=0.972361, theta=-76.906674 -> V=1.0, theta=0.0
% INFO    : Bus 56227	: V=0.9703286, theta=-77.071695 -> V=1.0, theta=0.0
% INFO    : Bus 56228	: V=0.9693145, theta=-77.153131 -> V=1.0, theta=0.0
% INFO    : Bus 56229	: V=0.9648292, theta=-77.984423 -> V=1.0, theta=0.0
% INFO    : Bus 56230	: V=0.9642058, theta=-78.055624 -> V=1.0, theta=0.0
% INFO    : Bus 56231	: V=0.9633952, theta=-78.127963 -> V=1.0, theta=0.0
% INFO    : Bus 56232	: V=0.9627185, theta=-78.147047 -> V=1.0, theta=0.0
% INFO    : Bus 56233	: V=0.9637384, theta=-78.191391 -> V=1.0, theta=0.0
% INFO    : Bus 56234	: V=0.9710948, theta=-77.026199 -> V=1.0, theta=0.0
% INFO    : Bus 56235	: V=0.9695235, theta=-77.415302 -> V=1.0, theta=0.0
% INFO    : Bus 56236	: V=0.9708178, theta=-77.246899 -> V=1.0, theta=0.0
% INFO    : Bus 56237	: V=0.9726016, theta=-77.027538 -> V=1.0, theta=0.0
% INFO    : Bus 56238	: V=0.973568, theta=-76.816393 -> V=1.0, theta=0.0
% INFO    : Bus 56239	: V=0.9743666, theta=-76.761364 -> V=1.0, theta=0.0
% INFO    : Bus 56240	: V=0.9756108, theta=-76.64261 -> V=1.0, theta=0.0
% INFO    : Bus 56241	: V=0.9771593, theta=-76.475403 -> V=1.0, theta=0.0
% INFO    : Bus 56242	: V=0.978555, theta=-76.349779 -> V=1.0, theta=0.0
% INFO    : Bus 56243	: V=0.9751155, theta=-76.672802 -> V=1.0, theta=0.0
% INFO    : Bus 56244	: V=0.9993123, theta=-73.838215 -> V=1.0, theta=0.0
% INFO    : Bus 56245	: V=0.9796974, theta=-76.220211 -> V=1.0, theta=0.0
% INFO    : Bus 56246	: V=0.975938, theta=-76.597506 -> V=1.0, theta=0.0
% INFO    : Bus 56247	: V=0.9648716, theta=-77.969985 -> V=1.0, theta=0.0
% INFO    : Bus 56248	: V=0.9637102, theta=-77.919145 -> V=1.0, theta=0.0
% INFO    : Bus 56249	: V=0.964324, theta=-77.814263 -> V=1.0, theta=0.0
% INFO    : Bus 56250	: V=0.9823488, theta=-74.107708 -> V=1.0, theta=0.0
% INFO    : Bus 56251	: V=0.9606657, theta=-77.727967 -> V=1.0, theta=0.0
% INFO    : Bus 56252	: V=0.9618891, theta=-77.163783 -> V=1.0, theta=0.0
% INFO    : Bus 56253	: V=0.9554131, theta=-78.868936 -> V=1.0, theta=0.0
% INFO    : Bus 56254	: V=0.9521717, theta=-79.003429 -> V=1.0, theta=0.0
% INFO    : Bus 56255	: V=0.9514587, theta=-79.079477 -> V=1.0, theta=0.0
% INFO    : Bus 56256	: V=0.964551, theta=-76.957185 -> V=1.0, theta=0.0
% INFO    : Bus 56257	: V=0.9622303, theta=-77.322389 -> V=1.0, theta=0.0
% INFO    : Bus 56258	: V=0.9568837, theta=-78.448894 -> V=1.0, theta=0.0
% INFO    : Bus 56259	: V=0.9621504, theta=-77.322816 -> V=1.0, theta=0.0
% INFO    : Bus 56260	: V=0.9627579, theta=-77.215371 -> V=1.0, theta=0.0
% INFO    : Bus 56261	: V=0.9636973, theta=-77.032208 -> V=1.0, theta=0.0
% INFO    : Bus 56262	: V=0.9589595, theta=-78.020024 -> V=1.0, theta=0.0
% INFO    : Bus 56263	: V=0.9552151, theta=-78.518663 -> V=1.0, theta=0.0
% INFO    : Bus 56264	: V=0.9539219, theta=-78.662258 -> V=1.0, theta=0.0
% INFO    : Bus 56265	: V=0.9618715, theta=-77.243629 -> V=1.0, theta=0.0
% INFO    : Bus 56266	: V=0.9559273, theta=-78.496447 -> V=1.0, theta=0.0
% INFO    : Bus 56267	: V=0.9548824, theta=-78.583189 -> V=1.0, theta=0.0
% INFO    : Bus 56268	: V=0.9624226, theta=-77.109074 -> V=1.0, theta=0.0
% INFO    : Bus 56269	: V=0.9628861, theta=-77.0112 -> V=1.0, theta=0.0
% INFO    : Bus 56270	: V=0.9634314, theta=-76.892637 -> V=1.0, theta=0.0
% INFO    : Bus 56271	: V=0.9547882, theta=-78.624679 -> V=1.0, theta=0.0
% INFO    : Bus 56272	: V=0.9645098, theta=-76.536408 -> V=1.0, theta=0.0
% INFO    : Bus 56273	: V=0.9540409, theta=-77.075038 -> V=1.0, theta=0.0
% INFO    : Bus 56274	: V=0.9637859, theta=-76.607373 -> V=1.0, theta=0.0
% INFO    : Bus 56275	: V=0.9636367, theta=-76.620847 -> V=1.0, theta=0.0
% INFO    : Bus 56276	: V=0.9640328, theta=-76.764732 -> V=1.0, theta=0.0
% INFO    : Bus 56277	: V=0.9508598, theta=-78.905399 -> V=1.0, theta=0.0
% INFO    : Bus 56278	: V=0.9656985, theta=-76.400145 -> V=1.0, theta=0.0
% INFO    : Bus 56279	: V=0.9637445, theta=-76.592995 -> V=1.0, theta=0.0
% INFO    : Bus 56280	: V=0.9640291, theta=-76.537028 -> V=1.0, theta=0.0
% INFO    : Bus 56281	: V=0.9640573, theta=-76.483039 -> V=1.0, theta=0.0
% INFO    : Bus 56282	: V=0.9620932, theta=-76.663214 -> V=1.0, theta=0.0
% INFO    : Bus 56283	: V=0.9675165, theta=-75.989957 -> V=1.0, theta=0.0
% INFO    : Bus 56284	: V=0.9683363, theta=-75.902707 -> V=1.0, theta=0.0
% INFO    : Bus 56285	: V=0.9688763, theta=-75.875689 -> V=1.0, theta=0.0
% INFO    : Bus 56286	: V=0.9672231, theta=-76.124377 -> V=1.0, theta=0.0
% INFO    : Bus 56287	: V=0.9702839, theta=-76.010814 -> V=1.0, theta=0.0
% INFO    : Bus 56288	: V=0.9658864, theta=-76.652076 -> V=1.0, theta=0.0
% INFO    : Bus 56289	: V=0.9525606, theta=-78.759097 -> V=1.0, theta=0.0
% INFO    : Bus 56290	: V=1.0034029, theta=-71.925042 -> V=1.0, theta=0.0
% INFO    : Bus 56291	: V=0.9816081, theta=-74.243248 -> V=1.0, theta=0.0
% INFO    : Bus 56292	: V=0.9739636, theta=-76.837696 -> V=1.0, theta=0.0
% INFO    : Bus 56293	: V=0.9742661, theta=-76.756065 -> V=1.0, theta=0.0
% INFO    : Bus 56294	: V=0.9737987, theta=-76.77617 -> V=1.0, theta=0.0
% INFO    : Bus 56295	: V=0.972133, theta=-76.87355 -> V=1.0, theta=0.0
% INFO    : Bus 56296	: V=0.9642699, theta=-78.505403 -> V=1.0, theta=0.0
% INFO    : Bus 56297	: V=0.9643799, theta=-77.720357 -> V=1.0, theta=0.0
% INFO    : Bus 56298	: V=0.9750342, theta=-76.686346 -> V=1.0, theta=0.0
% INFO    : Bus 56299	: V=0.9757569, theta=-76.603084 -> V=1.0, theta=0.0
% INFO    : Bus 56300	: V=0.9670626, theta=-77.381234 -> V=1.0, theta=0.0
% INFO    : Bus 56301	: V=0.9765187, theta=-76.52042 -> V=1.0, theta=0.0
% INFO    : Bus 56302	: V=0.9794326, theta=-76.22746 -> V=1.0, theta=0.0
% INFO    : Bus 56303	: V=0.9669589, theta=-77.424483 -> V=1.0, theta=0.0
% INFO    : Bus 56304	: V=0.9865854, theta=-75.259971 -> V=1.0, theta=0.0
% INFO    : Bus 56305	: V=0.9779177, theta=-76.213571 -> V=1.0, theta=0.0
% INFO    : Bus 56306	: V=0.9760739, theta=-76.485862 -> V=1.0, theta=0.0
% INFO    : Bus 56307	: V=0.9766025, theta=-76.290743 -> V=1.0, theta=0.0
% INFO    : Bus 56308	: V=0.9734217, theta=-76.755794 -> V=1.0, theta=0.0
% INFO    : Bus 56309	: V=0.9807641, theta=-76.04071 -> V=1.0, theta=0.0
% INFO    : Bus 56310	: V=0.9807197, theta=-76.064441 -> V=1.0, theta=0.0
% INFO    : Bus 56311	: V=0.9642708, theta=-78.015077 -> V=1.0, theta=0.0
% INFO    : Bus 56312	: V=0.9603531, theta=-78.321054 -> V=1.0, theta=0.0
% INFO    : Bus 56313	: V=0.9622771, theta=-78.019383 -> V=1.0, theta=0.0
% INFO    : Bus 56314	: V=0.9623605, theta=-78.106709 -> V=1.0, theta=0.0
% INFO    : Bus 56315	: V=0.9661099, theta=-76.873835 -> V=1.0, theta=0.0
% INFO    : Bus 56316	: V=0.9592906, theta=-78.330727 -> V=1.0, theta=0.0
% INFO    : Bus 56317	: V=0.9575162, theta=-78.385713 -> V=1.0, theta=0.0
% INFO    : Bus 56318	: V=0.9574153, theta=-78.405255 -> V=1.0, theta=0.0
% INFO    : Bus 56319	: V=0.9578567, theta=-78.350141 -> V=1.0, theta=0.0
% INFO    : Bus 56320	: V=0.958684, theta=-78.291236 -> V=1.0, theta=0.0
% INFO    : Bus 56321	: V=0.9582715, theta=-78.275892 -> V=1.0, theta=0.0
% INFO    : Bus 56322	: V=0.9588557, theta=-78.18096 -> V=1.0, theta=0.0
% INFO    : Bus 56323	: V=0.9567248, theta=-78.262434 -> V=1.0, theta=0.0
% INFO    : Bus 56324	: V=0.9644247, theta=-77.82635 -> V=1.0, theta=0.0
% INFO    : Bus 56325	: V=0.9604951, theta=-78.18196 -> V=1.0, theta=0.0
% INFO    : Bus 56326	: V=0.9745999, theta=-76.411662 -> V=1.0, theta=0.0
% INFO    : Bus 56327	: V=0.9727368, theta=-76.511024 -> V=1.0, theta=0.0
% INFO    : Bus 56328	: V=0.9708754, theta=-76.596812 -> V=1.0, theta=0.0
% INFO    : Bus 56329	: V=0.964682, theta=-77.962734 -> V=1.0, theta=0.0
% INFO    : Bus 56330	: V=0.9642644, theta=-78.023615 -> V=1.0, theta=0.0
% INFO    : Bus 56331	: V=0.9626821, theta=-78.065065 -> V=1.0, theta=0.0
% INFO    : Bus 56332	: V=0.9639538, theta=-78.009912 -> V=1.0, theta=0.0
% INFO    : Bus 56333	: V=0.9651921, theta=-77.906309 -> V=1.0, theta=0.0
% INFO    : Bus 56334	: V=0.9650904, theta=-77.890985 -> V=1.0, theta=0.0
% INFO    : Bus 56335	: V=0.9711494, theta=-76.903105 -> V=1.0, theta=0.0
% INFO    : Bus 56336	: V=0.9648544, theta=-77.882096 -> V=1.0, theta=0.0
% INFO    : Bus 56337	: V=0.9710166, theta=-76.868255 -> V=1.0, theta=0.0
% INFO    : Bus 56338	: V=0.9713198, theta=-76.825881 -> V=1.0, theta=0.0
% INFO    : Bus 56339	: V=0.9717213, theta=-76.776368 -> V=1.0, theta=0.0
% INFO    : Bus 56340	: V=0.9660208, theta=-77.785755 -> V=1.0, theta=0.0
% INFO    : Bus 56341	: V=0.9737678, theta=-76.583823 -> V=1.0, theta=0.0
% INFO    : Bus 56342	: V=0.9660875, theta=-77.83668 -> V=1.0, theta=0.0
% INFO    : Bus 56343	: V=0.9743089, theta=-76.493214 -> V=1.0, theta=0.0
% INFO    : Bus 56344	: V=0.9746722, theta=-76.46111 -> V=1.0, theta=0.0
% INFO    : Bus 56345	: V=0.966321, theta=-77.78608 -> V=1.0, theta=0.0
% INFO    : Bus 56346	: V=0.9651505, theta=-77.922201 -> V=1.0, theta=0.0
% INFO    : Bus 56347	: V=0.9644772, theta=-77.97138 -> V=1.0, theta=0.0
% INFO    : Bus 56348	: V=0.9654723, theta=-77.811013 -> V=1.0, theta=0.0
% INFO    : Bus 56349	: V=0.9648899, theta=-77.82437 -> V=1.0, theta=0.0
% INFO    : Bus 56350	: V=0.9676351, theta=-76.745157 -> V=1.0, theta=0.0
% INFO    : Bus 56351	: V=0.968842, theta=-76.684497 -> V=1.0, theta=0.0
% INFO    : Bus 56352	: V=0.9678109, theta=-76.733702 -> V=1.0, theta=0.0
% INFO    : Bus 56353	: V=0.9657912, theta=-76.752775 -> V=1.0, theta=0.0
% INFO    : Bus 56354	: V=0.9657467, theta=-76.584636 -> V=1.0, theta=0.0
% INFO    : Bus 56355	: V=0.9659382, theta=-76.411514 -> V=1.0, theta=0.0
% INFO    : Bus 56356	: V=0.9635503, theta=-77.0315 -> V=1.0, theta=0.0
% INFO    : Bus 56357	: V=0.9671156, theta=-76.736493 -> V=1.0, theta=0.0
% INFO    : Bus 56358	: V=0.9677755, theta=-76.679117 -> V=1.0, theta=0.0
% INFO    : Bus 56359	: V=0.9683612, theta=-76.689339 -> V=1.0, theta=0.0
% INFO    : Bus 56360	: V=0.9607032, theta=-77.994717 -> V=1.0, theta=0.0
% INFO    : Bus 56361	: V=0.9594117, theta=-78.137993 -> V=1.0, theta=0.0
% INFO    : Bus 56362	: V=0.9608955, theta=-77.916467 -> V=1.0, theta=0.0
% INFO    : Bus 56363	: V=0.9760965, theta=-76.11823 -> V=1.0, theta=0.0
% INFO    : Bus 56364	: V=0.9747143, theta=-76.417669 -> V=1.0, theta=0.0
% INFO    : Bus 56365	: V=0.981422, theta=-75.708757 -> V=1.0, theta=0.0
% INFO    : Bus 56366	: V=0.9815694, theta=-75.635186 -> V=1.0, theta=0.0
% INFO    : Bus 56367	: V=0.9818216, theta=-75.548829 -> V=1.0, theta=0.0
% INFO    : Bus 56368	: V=0.9775319, theta=-75.85467 -> V=1.0, theta=0.0
% INFO    : Bus 56369	: V=0.9780104, theta=-75.74885 -> V=1.0, theta=0.0
% INFO    : Bus 56370	: V=0.9655064, theta=-77.317092 -> V=1.0, theta=0.0
% INFO    : Bus 56371	: V=0.965504, theta=-77.463738 -> V=1.0, theta=0.0
% INFO    : Bus 56372	: V=0.9641555, theta=-77.641676 -> V=1.0, theta=0.0
% INFO    : Bus 56373	: V=0.9700513, theta=-76.221111 -> V=1.0, theta=0.0
% INFO    : Bus 56374	: V=0.9682949, theta=-76.499589 -> V=1.0, theta=0.0
% INFO    : Bus 56375	: V=0.9594033, theta=-76.396261 -> V=1.0, theta=0.0
% INFO    : Bus 56376	: V=0.9631136, theta=-76.254263 -> V=1.0, theta=0.0
% INFO    : Bus 56377	: V=0.9668942, theta=-76.044632 -> V=1.0, theta=0.0
% INFO    : Bus 56378	: V=0.9702887, theta=-75.098156 -> V=1.0, theta=0.0
% INFO    : Bus 56379	: V=0.9667844, theta=-77.314616 -> V=1.0, theta=0.0
% INFO    : Bus 56380	: V=0.9854705, theta=-75.690539 -> V=1.0, theta=0.0
% INFO    : Bus 56381	: V=0.9696961, theta=-60.921585 -> V=1.0, theta=0.0
% INFO    : Bus 56382	: V=0.9801625, theta=-57.994893 -> V=1.0, theta=0.0
% INFO    : Bus 56383	: V=0.9546387, theta=-64.918875 -> V=1.0, theta=0.0
% INFO    : Bus 56384	: V=1.0098118, theta=-55.89018 -> V=1.0, theta=0.0
% INFO    : Bus 56385	: V=0.9816286, theta=-58.35552 -> V=1.0, theta=0.0
% INFO    : Bus 56386	: V=0.9864521, theta=-57.875779 -> V=1.0, theta=0.0
% INFO    : Bus 56387	: V=0.9880282, theta=-57.932417 -> V=1.0, theta=0.0
% INFO    : Bus 56388	: V=1.0085132, theta=-56.372406 -> V=1.0, theta=0.0
% INFO    : Bus 56389	: V=0.9846661, theta=-58.237996 -> V=1.0, theta=0.0
% INFO    : Bus 56390	: V=1.0070727, theta=-56.611864 -> V=1.0, theta=0.0
% INFO    : Bus 56391	: V=1.0110862, theta=-56.545865 -> V=1.0, theta=0.0
% INFO    : Bus 56392	: V=1.0199973, theta=-55.605196 -> V=1.0, theta=0.0
% INFO    : Bus 56393	: V=1.0098456, theta=-56.333761 -> V=1.0, theta=0.0
% INFO    : Bus 56394	: V=0.9983522, theta=-57.957995 -> V=1.0, theta=0.0
% INFO    : Bus 56395	: V=1.0217031, theta=-56.829644 -> V=1.0, theta=0.0
% INFO    : Bus 56396	: V=1.0108705, theta=-53.624003 -> V=1.0, theta=0.0
% INFO    : Bus 56397	: V=1.0099797, theta=-53.7807 -> V=1.0, theta=0.0
% INFO    : Bus 56398	: V=0.9818619, theta=-70.963475 -> V=1.0, theta=0.0
% INFO    : Bus 56399	: V=0.9815394, theta=-70.982447 -> V=1.0, theta=0.0
% INFO    : Bus 56400	: V=0.9814755, theta=-70.99032 -> V=1.0, theta=0.0
% INFO    : Bus 56401	: V=0.964359, theta=-72.563889 -> V=1.0, theta=0.0
% INFO    : Bus 56402	: V=0.9797777, theta=-71.118647 -> V=1.0, theta=0.0
% INFO    : Bus 56403	: V=0.9860072, theta=-70.617299 -> V=1.0, theta=0.0
% INFO    : Bus 56404	: V=0.9841681, theta=-70.797315 -> V=1.0, theta=0.0
% INFO    : Bus 56405	: V=0.9804923, theta=-71.180812 -> V=1.0, theta=0.0
% INFO    : Bus 56406	: V=0.9797111, theta=-71.235913 -> V=1.0, theta=0.0
% INFO    : Bus 56407	: V=0.9800725, theta=-71.221639 -> V=1.0, theta=0.0
% INFO    : Bus 56408	: V=0.9486555, theta=-74.594068 -> V=1.0, theta=0.0
% INFO    : Bus 56409	: V=0.9563933, theta=-73.882784 -> V=1.0, theta=0.0
% INFO    : Bus 56410	: V=0.9566946, theta=-74.200298 -> V=1.0, theta=0.0
% INFO    : Bus 56411	: V=0.9520638, theta=-74.515043 -> V=1.0, theta=0.0
% INFO    : Bus 56412	: V=0.9407603, theta=-74.987163 -> V=1.0, theta=0.0
% INFO    : Bus 56413	: V=0.9446235, theta=-75.48356 -> V=1.0, theta=0.0
% INFO    : Bus 56414	: V=0.9504817, theta=-74.883949 -> V=1.0, theta=0.0
% INFO    : Bus 56415	: V=0.97658, theta=-71.885696 -> V=1.0, theta=0.0
% INFO    : Bus 56416	: V=0.9970458, theta=-69.615929 -> V=1.0, theta=0.0
% INFO    : Bus 56417	: V=0.9809265, theta=-71.252501 -> V=1.0, theta=0.0
% INFO    : Bus 56418	: V=0.9760958, theta=-71.269889 -> V=1.0, theta=0.0
% INFO    : Bus 56419	: V=0.9744323, theta=-71.316247 -> V=1.0, theta=0.0
% INFO    : Bus 56420	: V=0.9746039, theta=-71.267466 -> V=1.0, theta=0.0
% INFO    : Bus 56421	: V=0.9567181, theta=-72.70798 -> V=1.0, theta=0.0
% INFO    : Bus 56422	: V=0.9583393, theta=-72.68373 -> V=1.0, theta=0.0
% INFO    : Bus 56423	: V=0.9917057, theta=-57.662634 -> V=1.0, theta=0.0
% INFO    : Bus 56424	: V=0.9802108, theta=-65.332394 -> V=1.0, theta=0.0
% INFO    : Bus 56425	: V=0.9828675, theta=-66.24082 -> V=1.0, theta=0.0
% INFO    : Bus 56426	: V=0.9883387, theta=-67.346719 -> V=1.0, theta=0.0
% INFO    : Bus 56427	: V=0.995371, theta=-67.916082 -> V=1.0, theta=0.0
% INFO    : Bus 56428	: V=0.9882013, theta=-69.487316 -> V=1.0, theta=0.0
% INFO    : Bus 56429	: V=0.9978279, theta=-69.302681 -> V=1.0, theta=0.0
% INFO    : Bus 56430	: V=0.9975301, theta=-69.432871 -> V=1.0, theta=0.0
% INFO    : Bus 56431	: V=0.9986627, theta=-70.0784 -> V=1.0, theta=0.0
% INFO    : Bus 56432	: V=1.0077418, theta=-68.756134 -> V=1.0, theta=0.0
% INFO    : Bus 56433	: V=0.998961, theta=-68.98732 -> V=1.0, theta=0.0
% INFO    : Bus 56434	: V=1.0150254, theta=-67.068923 -> V=1.0, theta=0.0
% INFO    : Bus 56435	: V=1.0009993, theta=-68.568269 -> V=1.0, theta=0.0
% INFO    : Bus 56436	: V=1.0047153, theta=-67.877901 -> V=1.0, theta=0.0
% INFO    : Bus 56437	: V=0.9995608, theta=-67.935464 -> V=1.0, theta=0.0
% INFO    : Bus 56438	: V=0.993697, theta=-67.80417 -> V=1.0, theta=0.0
% INFO    : Bus 56439	: V=0.993199, theta=-67.699748 -> V=1.0, theta=0.0
% INFO    : Bus 56440	: V=0.9723786, theta=-67.760033 -> V=1.0, theta=0.0
% INFO    : Bus 56441	: V=0.9969176, theta=-63.417483 -> V=1.0, theta=0.0
% INFO    : Bus 56442	: V=1.0105802, theta=-62.310431 -> V=1.0, theta=0.0
% INFO    : Bus 56443	: V=1.0077313, theta=-62.899738 -> V=1.0, theta=0.0
% INFO    : Bus 56444	: V=1.0107772, theta=-62.317689 -> V=1.0, theta=0.0
% INFO    : Bus 56445	: V=0.9997024, theta=-63.197869 -> V=1.0, theta=0.0
% INFO    : Bus 56446	: V=0.9957636, theta=-63.45239 -> V=1.0, theta=0.0
% INFO    : Bus 56447	: V=1.0012665, theta=-63.062115 -> V=1.0, theta=0.0
% INFO    : Bus 56448	: V=1.0109395, theta=-62.331946 -> V=1.0, theta=0.0
% INFO    : Bus 56449	: V=1.0053141, theta=-62.730071 -> V=1.0, theta=0.0
% INFO    : Bus 56450	: V=0.9955693, theta=-63.461617 -> V=1.0, theta=0.0
% INFO    : Bus 56451	: V=0.9953999, theta=-63.468738 -> V=1.0, theta=0.0
% INFO    : Bus 56452	: V=0.9841213, theta=-64.648424 -> V=1.0, theta=0.0
% INFO    : Bus 56453	: V=0.9992429, theta=-63.171964 -> V=1.0, theta=0.0
% INFO    : Bus 56454	: V=0.9992958, theta=-63.176321 -> V=1.0, theta=0.0
% INFO    : Bus 56455	: V=0.9788639, theta=-65.022213 -> V=1.0, theta=0.0
% INFO    : Bus 56456	: V=0.9869823, theta=-64.41199 -> V=1.0, theta=0.0
% INFO    : Bus 56457	: V=0.9997744, theta=-63.175857 -> V=1.0, theta=0.0
% INFO    : Bus 56458	: V=0.9809638, theta=-64.766533 -> V=1.0, theta=0.0
% INFO    : Bus 56459	: V=1.000214, theta=-63.127527 -> V=1.0, theta=0.0
% INFO    : Bus 56460	: V=0.9790792, theta=-64.817623 -> V=1.0, theta=0.0
% INFO    : Bus 56461	: V=1.000176, theta=-63.135968 -> V=1.0, theta=0.0
% INFO    : Bus 56462	: V=0.9803359, theta=-64.804779 -> V=1.0, theta=0.0
% INFO    : Bus 56463	: V=0.9994283, theta=-63.237746 -> V=1.0, theta=0.0
% INFO    : Bus 56464	: V=0.9990735, theta=-63.238725 -> V=1.0, theta=0.0
% INFO    : Bus 56465	: V=0.9834973, theta=-64.793095 -> V=1.0, theta=0.0
% INFO    : Bus 56466	: V=1.0085481, theta=-62.556017 -> V=1.0, theta=0.0
% INFO    : Bus 56467	: V=0.9819869, theta=-64.857831 -> V=1.0, theta=0.0
% INFO    : Bus 56468	: V=0.9949202, theta=-63.494623 -> V=1.0, theta=0.0
% INFO    : Bus 56469	: V=0.9792261, theta=-65.022433 -> V=1.0, theta=0.0
% INFO    : Bus 56470	: V=0.9791437, theta=-65.067222 -> V=1.0, theta=0.0
% INFO    : Bus 56471	: V=0.9765998, theta=-65.094596 -> V=1.0, theta=0.0
% INFO    : Bus 56472	: V=0.9638129, theta=-66.106499 -> V=1.0, theta=0.0
% INFO    : Bus 56473	: V=0.9577935, theta=-66.404375 -> V=1.0, theta=0.0
% INFO    : Bus 56474	: V=0.9711438, theta=-65.390765 -> V=1.0, theta=0.0
% INFO    : Bus 56475	: V=0.9751357, theta=-65.247022 -> V=1.0, theta=0.0
% INFO    : Bus 56476	: V=0.9717389, theta=-65.566317 -> V=1.0, theta=0.0
% INFO    : Bus 56477	: V=0.9682521, theta=-65.802232 -> V=1.0, theta=0.0
% INFO    : Bus 56478	: V=0.9758806, theta=-65.244285 -> V=1.0, theta=0.0
% INFO    : Bus 56479	: V=0.9700438, theta=-65.634909 -> V=1.0, theta=0.0
% INFO    : Bus 56480	: V=0.9705072, theta=-65.626912 -> V=1.0, theta=0.0
% INFO    : Bus 56481	: V=0.9750307, theta=-65.365395 -> V=1.0, theta=0.0
% INFO    : Bus 56482	: V=0.9710119, theta=-65.644934 -> V=1.0, theta=0.0
% INFO    : Bus 56483	: V=0.9645486, theta=-66.00059 -> V=1.0, theta=0.0
% INFO    : Bus 56484	: V=0.9636238, theta=-66.012123 -> V=1.0, theta=0.0
% INFO    : Bus 56485	: V=0.9672879, theta=-65.867331 -> V=1.0, theta=0.0
% INFO    : Bus 56486	: V=0.9689481, theta=-65.799212 -> V=1.0, theta=0.0
% INFO    : Bus 56487	: V=0.9622552, theta=-66.11842 -> V=1.0, theta=0.0
% INFO    : Bus 56488	: V=0.9550615, theta=-66.520144 -> V=1.0, theta=0.0
% INFO    : Bus 56489	: V=0.9540507, theta=-66.537863 -> V=1.0, theta=0.0
% INFO    : Bus 56490	: V=0.9645831, theta=-66.032726 -> V=1.0, theta=0.0
% INFO    : Bus 56491	: V=0.9611386, theta=-66.133009 -> V=1.0, theta=0.0
% INFO    : Bus 56492	: V=0.9522393, theta=-66.643796 -> V=1.0, theta=0.0
% INFO    : Bus 56493	: V=0.9557652, theta=-69.349058 -> V=1.0, theta=0.0
% INFO    : Bus 56494	: V=0.9607511, theta=-68.908738 -> V=1.0, theta=0.0
% INFO    : Bus 56495	: V=0.9539775, theta=-69.509188 -> V=1.0, theta=0.0
% INFO    : Bus 56496	: V=0.9518652, theta=-69.632933 -> V=1.0, theta=0.0
% INFO    : Bus 56497	: V=0.9801808, theta=-66.306431 -> V=1.0, theta=0.0
% INFO    : Bus 56498	: V=0.9525666, theta=-69.557163 -> V=1.0, theta=0.0
% INFO    : Bus 56499	: V=0.9570511, theta=-69.206428 -> V=1.0, theta=0.0
% INFO    : Bus 56500	: V=0.9593647, theta=-69.120915 -> V=1.0, theta=0.0
% INFO    : Bus 56501	: V=0.9629327, theta=-68.806993 -> V=1.0, theta=0.0
% INFO    : Bus 56502	: V=0.9649097, theta=-68.440613 -> V=1.0, theta=0.0
% INFO    : Bus 56503	: V=0.9653918, theta=-68.456291 -> V=1.0, theta=0.0
% INFO    : Bus 56504	: V=0.9754143, theta=-66.833014 -> V=1.0, theta=0.0
% INFO    : Bus 56505	: V=0.9642596, theta=-68.679917 -> V=1.0, theta=0.0
% INFO    : Bus 56506	: V=0.9639053, theta=-68.735858 -> V=1.0, theta=0.0
% INFO    : Bus 56507	: V=0.9622262, theta=-68.805339 -> V=1.0, theta=0.0
% INFO    : Bus 56508	: V=0.9564072, theta=-69.382589 -> V=1.0, theta=0.0
% INFO    : Bus 56509	: V=0.9617234, theta=-68.790974 -> V=1.0, theta=0.0
% INFO    : Bus 56510	: V=0.9618449, theta=-68.740584 -> V=1.0, theta=0.0
% INFO    : Bus 56511	: V=0.9736962, theta=-67.010919 -> V=1.0, theta=0.0
% INFO    : Bus 56512	: V=0.9676814, theta=-68.436065 -> V=1.0, theta=0.0
% INFO    : Bus 56513	: V=0.9704563, theta=-68.386008 -> V=1.0, theta=0.0
% INFO    : Bus 56514	: V=1.0049787, theta=-63.104769 -> V=1.0, theta=0.0
% INFO    : Bus 56515	: V=1.0032978, theta=-63.17875 -> V=1.0, theta=0.0
% INFO    : Bus 56516	: V=0.9754544, theta=-65.411377 -> V=1.0, theta=0.0
% INFO    : Bus 56517	: V=0.9854077, theta=-64.321638 -> V=1.0, theta=0.0
% INFO    : Bus 56518	: V=1.0011889, theta=-63.165917 -> V=1.0, theta=0.0
% INFO    : Bus 56519	: V=0.9971125, theta=-63.477086 -> V=1.0, theta=0.0
% INFO    : Bus 56520	: V=0.9785233, theta=-64.773463 -> V=1.0, theta=0.0
% INFO    : Bus 56521	: V=0.9946928, theta=-63.708273 -> V=1.0, theta=0.0
% INFO    : Bus 56522	: V=0.9647105, theta=-65.978543 -> V=1.0, theta=0.0
% INFO    : Bus 56523	: V=0.9689528, theta=-65.726168 -> V=1.0, theta=0.0
% INFO    : Bus 56524	: V=1.0004586, theta=-63.325854 -> V=1.0, theta=0.0
% INFO    : Bus 56525	: V=0.9826918, theta=-64.817602 -> V=1.0, theta=0.0
% INFO    : Bus 56526	: V=0.9946386, theta=-63.556727 -> V=1.0, theta=0.0
% INFO    : Bus 56527	: V=0.997661, theta=-63.393992 -> V=1.0, theta=0.0
% INFO    : Bus 56528	: V=1.0035942, theta=-63.024203 -> V=1.0, theta=0.0
% INFO    : Bus 56529	: V=0.9903964, theta=-64.270572 -> V=1.0, theta=0.0
% INFO    : Bus 56530	: V=1.0033465, theta=-63.091182 -> V=1.0, theta=0.0
% INFO    : Bus 56531	: V=1.0185504, theta=-61.397915 -> V=1.0, theta=0.0
% INFO    : Bus 56532	: V=0.9826622, theta=-64.370512 -> V=1.0, theta=0.0
% INFO    : Bus 56533	: V=0.987246, theta=-64.300588 -> V=1.0, theta=0.0
% INFO    : Bus 56534	: V=0.9918902, theta=-63.83861 -> V=1.0, theta=0.0
% INFO    : Bus 56535	: V=1.0006206, theta=-63.301273 -> V=1.0, theta=0.0
% INFO    : Bus 56536	: V=0.9910846, theta=-64.010435 -> V=1.0, theta=0.0
% INFO    : Bus 56537	: V=1.0108271, theta=-62.136036 -> V=1.0, theta=0.0
% INFO    : Bus 56538	: V=0.9791245, theta=-64.471903 -> V=1.0, theta=0.0
% INFO    : Bus 56539	: V=1.0006974, theta=-63.641188 -> V=1.0, theta=0.0
% INFO    : Bus 56540	: V=0.9871749, theta=-64.131566 -> V=1.0, theta=0.0
% INFO    : Bus 56541	: V=0.9956568, theta=-63.582454 -> V=1.0, theta=0.0
% INFO    : Bus 56542	: V=1.0078375, theta=-62.724112 -> V=1.0, theta=0.0
% INFO    : Bus 56543	: V=1.0039166, theta=-63.432578 -> V=1.0, theta=0.0
% INFO    : Bus 56544	: V=1.0111564, theta=-62.467661 -> V=1.0, theta=0.0
% INFO    : Bus 56545	: V=1.0162295, theta=-61.942684 -> V=1.0, theta=0.0
% INFO    : Bus 56546	: V=0.9966426, theta=-63.302333 -> V=1.0, theta=0.0
% INFO    : Bus 56547	: V=0.9906255, theta=-63.783766 -> V=1.0, theta=0.0
% INFO    : Bus 56548	: V=0.9668582, theta=-65.815419 -> V=1.0, theta=0.0
% INFO    : Bus 56549	: V=0.9721638, theta=-65.761702 -> V=1.0, theta=0.0
% INFO    : Bus 56550	: V=0.9888313, theta=-64.337527 -> V=1.0, theta=0.0
% INFO    : Bus 56551	: V=0.9864202, theta=-65.038699 -> V=1.0, theta=0.0
% INFO    : Bus 56552	: V=0.9848775, theta=-65.585012 -> V=1.0, theta=0.0
% INFO    : Bus 56553	: V=0.9792839, theta=-65.013393 -> V=1.0, theta=0.0
% INFO    : Bus 56554	: V=0.9875719, theta=-69.240201 -> V=1.0, theta=0.0
% INFO    : Bus 56555	: V=1.0039688, theta=-66.88542 -> V=1.0, theta=0.0
% INFO    : Bus 56556	: V=1.0073525, theta=-66.767704 -> V=1.0, theta=0.0
% INFO    : Bus 56557	: V=1.0082412, theta=-66.798345 -> V=1.0, theta=0.0
% INFO    : Bus 56558	: V=1.0076681, theta=-66.786409 -> V=1.0, theta=0.0
% INFO    : Bus 56559	: V=0.9751845, theta=-71.465833 -> V=1.0, theta=0.0
% INFO    : Bus 56560	: V=0.9792252, theta=-71.461363 -> V=1.0, theta=0.0
% INFO    : Bus 56561	: V=0.9897409, theta=-70.344172 -> V=1.0, theta=0.0
% INFO    : Bus 56562	: V=0.9793321, theta=-71.439918 -> V=1.0, theta=0.0
% INFO    : Bus 56563	: V=0.986189, theta=-71.477105 -> V=1.0, theta=0.0
% INFO    : Bus 56564	: V=0.9692713, theta=-71.312984 -> V=1.0, theta=0.0
% INFO    : Bus 56565	: V=0.9864796, theta=-58.894724 -> V=1.0, theta=0.0
% INFO    : Bus 56566	: V=0.9817326, theta=-58.214984 -> V=1.0, theta=0.0
% INFO    : Bus 56567	: V=0.9638189, theta=-60.003596 -> V=1.0, theta=0.0
% INFO    : Bus 56568	: V=0.9789634, theta=-58.432231 -> V=1.0, theta=0.0
% INFO    : Bus 56569	: V=0.9768703, theta=-58.592415 -> V=1.0, theta=0.0
% INFO    : Bus 56570	: V=0.958627, theta=-61.029378 -> V=1.0, theta=0.0
% INFO    : Bus 56571	: V=0.9564129, theta=-60.586299 -> V=1.0, theta=0.0
% INFO    : Bus 56572	: V=1.0077642, theta=-64.146963 -> V=1.0, theta=0.0
% INFO    : Bus 56573	: V=0.9977727, theta=-65.158902 -> V=1.0, theta=0.0
% INFO    : Bus 56574	: V=1.0191124, theta=-62.918885 -> V=1.0, theta=0.0
% INFO    : Bus 56575	: V=1.0089925, theta=-64.210785 -> V=1.0, theta=0.0
% INFO    : Bus 56576	: V=1.0111931, theta=-64.222423 -> V=1.0, theta=0.0
% INFO    : Bus 56577	: V=1.00651, theta=-64.024605 -> V=1.0, theta=0.0
% INFO    : Bus 56578	: V=1.0040063, theta=-65.549418 -> V=1.0, theta=0.0
% INFO    : Bus 56579	: V=1.0087896, theta=-63.978745 -> V=1.0, theta=0.0
% INFO    : Bus 56580	: V=1.0193991, theta=-61.595044 -> V=1.0, theta=0.0
% INFO    : Bus 56581	: V=0.990887, theta=-63.2075 -> V=1.0, theta=0.0
% INFO    : Bus 56582	: V=0.994782, theta=-59.83211 -> V=1.0, theta=0.0
% INFO    : Bus 56583	: V=1.0017893, theta=-62.213392 -> V=1.0, theta=0.0
% INFO    : Bus 56584	: V=1.0074354, theta=-59.449211 -> V=1.0, theta=0.0
% INFO    : Bus 56585	: V=1.0018041, theta=-60.806496 -> V=1.0, theta=0.0
% INFO    : Bus 56586	: V=1.0058856, theta=-60.129621 -> V=1.0, theta=0.0
% INFO    : Bus 56587	: V=1.0063374, theta=-59.924486 -> V=1.0, theta=0.0
% INFO    : Bus 56588	: V=1.0061257, theta=-60.009058 -> V=1.0, theta=0.0
% INFO    : Bus 56589	: V=1.0102485, theta=-58.359964 -> V=1.0, theta=0.0
% INFO    : Bus 56590	: V=1.0014284, theta=-60.701365 -> V=1.0, theta=0.0
% INFO    : Bus 56591	: V=0.9546161, theta=-71.216627 -> V=1.0, theta=0.0
% INFO    : Bus 56592	: V=1.0000075, theta=-68.714638 -> V=1.0, theta=0.0
% INFO    : Bus 56593	: V=0.9616696, theta=-70.94716 -> V=1.0, theta=0.0
% INFO    : Bus 56594	: V=0.9632117, theta=-70.874885 -> V=1.0, theta=0.0
% INFO    : Bus 56595	: V=0.9781794, theta=-69.294712 -> V=1.0, theta=0.0
% INFO    : Bus 56596	: V=0.9799193, theta=-68.744421 -> V=1.0, theta=0.0
% INFO    : Bus 56597	: V=0.9893043, theta=-70.357393 -> V=1.0, theta=0.0
% INFO    : Bus 56598	: V=1.0108594, theta=-52.282446 -> V=1.0, theta=0.0
% INFO    : Bus 56599	: V=1.0162163, theta=-48.850141 -> V=1.0, theta=0.0
% INFO    : Bus 56600	: V=1.0145343, theta=-51.538479 -> V=1.0, theta=0.0
% INFO    : Bus 56601	: V=1.017208, theta=-51.156254 -> V=1.0, theta=0.0
% INFO    : Bus 56602	: V=1.0134527, theta=-51.613669 -> V=1.0, theta=0.0
% INFO    : Bus 56603	: V=1.0189977, theta=-50.844875 -> V=1.0, theta=0.0
% INFO    : Bus 56604	: V=1.0147797, theta=-51.581504 -> V=1.0, theta=0.0
% INFO    : Bus 56605	: V=1.0163302, theta=-51.42845 -> V=1.0, theta=0.0
% INFO    : Bus 56606	: V=1.0148063, theta=-51.732366 -> V=1.0, theta=0.0
% INFO    : Bus 56607	: V=1.0188226, theta=-51.324358 -> V=1.0, theta=0.0
% INFO    : Bus 56608	: V=0.9551841, theta=-74.209939 -> V=1.0, theta=0.0
% INFO    : Bus 56609	: V=0.9821904, theta=-62.489288 -> V=1.0, theta=0.0
% INFO    : Bus 56610	: V=0.9809383, theta=-62.890882 -> V=1.0, theta=0.0
% INFO    : Bus 56611	: V=1.0091727, theta=-65.599786 -> V=1.0, theta=0.0
% INFO    : Bus 56612	: V=1.0141362, theta=-65.379912 -> V=1.0, theta=0.0
% INFO    : Bus 56613	: V=0.9970039, theta=-60.572663 -> V=1.0, theta=0.0
% INFO    : Bus 56614	: V=0.9854821, theta=-62.070958 -> V=1.0, theta=0.0
% INFO    : Bus 56615	: V=0.9990926, theta=-64.174393 -> V=1.0, theta=0.0
% INFO    : Bus 56616	: V=1.0182081, theta=-65.07922 -> V=1.0, theta=0.0
% INFO    : Bus 56617	: V=1.0109066, theta=-65.506863 -> V=1.0, theta=0.0
% INFO    : Bus 56618	: V=1.0046543, theta=-65.787289 -> V=1.0, theta=0.0
% INFO    : Bus 56619	: V=0.9975666, theta=-65.752307 -> V=1.0, theta=0.0
% INFO    : Bus 56620	: V=1.0012021, theta=-65.901192 -> V=1.0, theta=0.0
% INFO    : Bus 56621	: V=0.9965838, theta=-66.709502 -> V=1.0, theta=0.0
% INFO    : Bus 56622	: V=0.995993, theta=-67.564142 -> V=1.0, theta=0.0
% INFO    : Bus 56623	: V=0.9913971, theta=-70.057712 -> V=1.0, theta=0.0
% INFO    : Bus 56624	: V=0.9976655, theta=-67.639761 -> V=1.0, theta=0.0
% INFO    : Bus 56625	: V=0.9980818, theta=-66.593884 -> V=1.0, theta=0.0
% INFO    : Bus 56626	: V=0.9983727, theta=-65.963523 -> V=1.0, theta=0.0
% INFO    : Bus 56627	: V=0.9878329, theta=-66.969083 -> V=1.0, theta=0.0
% INFO    : Bus 56628	: V=1.0008492, theta=-57.260383 -> V=1.0, theta=0.0
% INFO    : Bus 56629	: V=1.0122447, theta=-57.109659 -> V=1.0, theta=0.0
% INFO    : Bus 56630	: V=1.0157309, theta=-56.805015 -> V=1.0, theta=0.0
% INFO    : Bus 56631	: V=1.0175728, theta=-56.667646 -> V=1.0, theta=0.0
% INFO    : Bus 56632	: V=1.0149934, theta=-56.858315 -> V=1.0, theta=0.0
% INFO    : Bus 56633	: V=1.0156641, theta=-56.787003 -> V=1.0, theta=0.0
% INFO    : Bus 56634	: V=1.022836, theta=-55.479116 -> V=1.0, theta=0.0
% INFO    : Bus 56635	: V=0.9847668, theta=-57.09961 -> V=1.0, theta=0.0
% INFO    : Bus 56636	: V=0.9978674, theta=-62.726625 -> V=1.0, theta=0.0
% INFO    : Bus 56637	: V=1.0144097, theta=-61.880646 -> V=1.0, theta=0.0
% INFO    : Bus 56638	: V=1.0138532, theta=-62.964281 -> V=1.0, theta=0.0
% INFO    : Bus 56639	: V=0.9967739, theta=-64.087673 -> V=1.0, theta=0.0
% INFO    : Bus 56640	: V=1.0015528, theta=-63.508249 -> V=1.0, theta=0.0
% INFO    : Bus 56641	: V=1.001744, theta=-63.214014 -> V=1.0, theta=0.0
% INFO    : Bus 56642	: V=0.9806676, theta=-68.476294 -> V=1.0, theta=0.0
% INFO    : Bus 56643	: V=0.9804805, theta=-68.787616 -> V=1.0, theta=0.0
% INFO    : Bus 56644	: V=0.9798069, theta=-68.916487 -> V=1.0, theta=0.0
% INFO    : Bus 56645	: V=0.9811432, theta=-68.907476 -> V=1.0, theta=0.0
% INFO    : Bus 56646	: V=0.9811081, theta=-69.123562 -> V=1.0, theta=0.0
% INFO    : Bus 56647	: V=0.9843257, theta=-68.270072 -> V=1.0, theta=0.0
% INFO    : Bus 56648	: V=1.0102549, theta=-67.939238 -> V=1.0, theta=0.0
% INFO    : Bus 56649	: V=1.0118046, theta=-68.01878 -> V=1.0, theta=0.0
% INFO    : Bus 56650	: V=0.9675045, theta=-66.4063 -> V=1.0, theta=0.0
% INFO    : Bus 56651	: V=0.9934586, theta=-71.236341 -> V=1.0, theta=0.0
% INFO    : Bus 56652	: V=1.0033761, theta=-70.425913 -> V=1.0, theta=0.0
% INFO    : Bus 56653	: V=0.9920168, theta=-71.368637 -> V=1.0, theta=0.0
% INFO    : Bus 56654	: V=1.0020582, theta=-70.511339 -> V=1.0, theta=0.0
% INFO    : Bus 56655	: V=1.0014465, theta=-70.580105 -> V=1.0, theta=0.0
% INFO    : Bus 56656	: V=1.001075, theta=-70.661173 -> V=1.0, theta=0.0
% INFO    : Bus 56657	: V=1.0017275, theta=-70.509655 -> V=1.0, theta=0.0
% INFO    : Bus 56658	: V=0.9873987, theta=-71.603362 -> V=1.0, theta=0.0
% INFO    : Bus 56659	: V=1.0014692, theta=-70.545298 -> V=1.0, theta=0.0
% INFO    : Bus 56660	: V=1.0047638, theta=-70.575327 -> V=1.0, theta=0.0
% INFO    : Bus 56661	: V=1.0016505, theta=-70.567238 -> V=1.0, theta=0.0
% INFO    : Bus 56662	: V=0.9893195, theta=-71.467338 -> V=1.0, theta=0.0
% INFO    : Bus 56663	: V=0.9904669, theta=-71.44323 -> V=1.0, theta=0.0
% INFO    : Bus 56664	: V=0.9903026, theta=-71.447067 -> V=1.0, theta=0.0
% INFO    : Bus 56665	: V=1.0033241, theta=-70.153068 -> V=1.0, theta=0.0
% INFO    : Bus 56666	: V=0.9982127, theta=-70.822497 -> V=1.0, theta=0.0
% INFO    : Bus 56667	: V=1.0017201, theta=-70.436636 -> V=1.0, theta=0.0
% INFO    : Bus 56668	: V=1.0021564, theta=-70.374542 -> V=1.0, theta=0.0
% INFO    : Bus 56669	: V=1.0007319, theta=-70.703395 -> V=1.0, theta=0.0
% INFO    : Bus 56670	: V=0.9952187, theta=-71.106671 -> V=1.0, theta=0.0
% INFO    : Bus 56671	: V=0.9989987, theta=-71.195637 -> V=1.0, theta=0.0
% INFO    : Bus 56672	: V=1.0037103, theta=-70.145333 -> V=1.0, theta=0.0
% INFO    : Bus 56673	: V=1.0032384, theta=-70.205549 -> V=1.0, theta=0.0
% INFO    : Bus 56674	: V=1.0029434, theta=-70.243478 -> V=1.0, theta=0.0
% INFO    : Bus 56675	: V=1.0024152, theta=-70.316061 -> V=1.0, theta=0.0
% INFO    : Bus 56676	: V=0.9990171, theta=-70.956512 -> V=1.0, theta=0.0
% INFO    : Bus 56677	: V=0.9991791, theta=-70.904401 -> V=1.0, theta=0.0
% INFO    : Bus 56678	: V=1.0008606, theta=-70.524738 -> V=1.0, theta=0.0
% INFO    : Bus 56679	: V=0.9991926, theta=-70.893302 -> V=1.0, theta=0.0
% INFO    : Bus 56680	: V=1.0060477, theta=-69.837636 -> V=1.0, theta=0.0
% INFO    : Bus 56681	: V=0.9915552, theta=-71.132475 -> V=1.0, theta=0.0
% INFO    : Bus 56682	: V=0.9954925, theta=-70.870667 -> V=1.0, theta=0.0
% INFO    : Bus 56683	: V=1.0034891, theta=-69.661327 -> V=1.0, theta=0.0
% INFO    : Bus 56684	: V=1.0023117, theta=-69.695522 -> V=1.0, theta=0.0
% INFO    : Bus 56685	: V=1.0123862, theta=-69.029954 -> V=1.0, theta=0.0
% INFO    : Bus 56686	: V=1.0122733, theta=-69.038299 -> V=1.0, theta=0.0
% INFO    : Bus 56687	: V=1.005151, theta=-69.606952 -> V=1.0, theta=0.0
% INFO    : Bus 56688	: V=0.9947586, theta=-70.878301 -> V=1.0, theta=0.0
% INFO    : Bus 56689	: V=1.0029199, theta=-69.632507 -> V=1.0, theta=0.0
% INFO    : Bus 56690	: V=1.011727, theta=-68.487564 -> V=1.0, theta=0.0
% INFO    : Bus 56691	: V=1.0051537, theta=-69.626648 -> V=1.0, theta=0.0
% INFO    : Bus 56692	: V=1.0053474, theta=-69.636947 -> V=1.0, theta=0.0
% INFO    : Bus 56693	: V=1.013013, theta=-68.811743 -> V=1.0, theta=0.0
% INFO    : Bus 56694	: V=0.9962722, theta=-70.700087 -> V=1.0, theta=0.0
% INFO    : Bus 56695	: V=1.005822, theta=-69.649264 -> V=1.0, theta=0.0
% INFO    : Bus 56696	: V=0.9983084, theta=-70.831088 -> V=1.0, theta=0.0
% INFO    : Bus 56697	: V=0.9916145, theta=-70.594097 -> V=1.0, theta=0.0
% INFO    : Bus 56698	: V=0.9923583, theta=-70.583364 -> V=1.0, theta=0.0
% INFO    : Bus 56699	: V=1.0009732, theta=-70.054689 -> V=1.0, theta=0.0
% INFO    : Bus 56700	: V=1.0069167, theta=-69.502667 -> V=1.0, theta=0.0
% INFO    : Bus 56701	: V=1.0060049, theta=-69.469315 -> V=1.0, theta=0.0
% INFO    : Bus 56702	: V=1.0052438, theta=-69.427714 -> V=1.0, theta=0.0
% INFO    : Bus 56703	: V=1.0080165, theta=-69.517845 -> V=1.0, theta=0.0
% INFO    : Bus 56704	: V=1.0156082, theta=-68.235285 -> V=1.0, theta=0.0
% INFO    : Bus 56705	: V=1.0139157, theta=-68.560038 -> V=1.0, theta=0.0
% INFO    : Bus 56706	: V=1.007621, theta=-69.560889 -> V=1.0, theta=0.0
% INFO    : Bus 56707	: V=1.0043679, theta=-70.091648 -> V=1.0, theta=0.0
% INFO    : Bus 56708	: V=1.0134506, theta=-68.652207 -> V=1.0, theta=0.0
% INFO    : Bus 56709	: V=1.0030016, theta=-70.284834 -> V=1.0, theta=0.0
% INFO    : Bus 56710	: V=1.0096746, theta=-69.235553 -> V=1.0, theta=0.0
% INFO    : Bus 56711	: V=1.012149, theta=-68.888291 -> V=1.0, theta=0.0
% INFO    : Bus 56712	: V=0.9953649, theta=-71.212577 -> V=1.0, theta=0.0
% INFO    : Bus 56713	: V=0.9971493, theta=-70.98022 -> V=1.0, theta=0.0
% INFO    : Bus 56714	: V=0.9909918, theta=-71.637692 -> V=1.0, theta=0.0
% INFO    : Bus 56715	: V=0.972713, theta=-73.110336 -> V=1.0, theta=0.0
% INFO    : Bus 56716	: V=0.9870827, theta=-72.118401 -> V=1.0, theta=0.0
% INFO    : Bus 56717	: V=1.0069121, theta=-70.73386 -> V=1.0, theta=0.0
% INFO    : Bus 56718	: V=0.9987176, theta=-71.263378 -> V=1.0, theta=0.0
% INFO    : Bus 56719	: V=1.0056857, theta=-70.067994 -> V=1.0, theta=0.0
% INFO    : Bus 56720	: V=1.0122639, theta=-68.97535 -> V=1.0, theta=0.0
% INFO    : Bus 56721	: V=1.0058469, theta=-69.569512 -> V=1.0, theta=0.0
% INFO    : Bus 56722	: V=0.9936572, theta=-70.741903 -> V=1.0, theta=0.0
% INFO    : Bus 56723	: V=1.0015147, theta=-65.492187 -> V=1.0, theta=0.0
% INFO    : Bus 56724	: V=1.0047012, theta=-65.118298 -> V=1.0, theta=0.0
% INFO    : Bus 56725	: V=0.9626608, theta=-66.673969 -> V=1.0, theta=0.0
% INFO    : Bus 56726	: V=0.972878, theta=-64.909194 -> V=1.0, theta=0.0
% INFO    : Bus 56727	: V=0.9454893, theta=-68.083504 -> V=1.0, theta=0.0
% INFO    : Bus 56728	: V=0.9436608, theta=-68.20919 -> V=1.0, theta=0.0
% INFO    : Bus 56729	: V=0.9495956, theta=-67.771889 -> V=1.0, theta=0.0
% INFO    : Bus 56730	: V=0.9480618, theta=-67.812799 -> V=1.0, theta=0.0
% INFO    : Bus 56731	: V=0.9884824, theta=-62.331043 -> V=1.0, theta=0.0
% INFO    : Bus 56732	: V=1.0119801, theta=-64.654765 -> V=1.0, theta=0.0
% INFO    : Bus 56733	: V=0.9810307, theta=-70.880171 -> V=1.0, theta=0.0
% INFO    : Bus 56734	: V=0.9816155, theta=-70.77262 -> V=1.0, theta=0.0
% INFO    : Bus 56735	: V=0.9799555, theta=-71.178636 -> V=1.0, theta=0.0
% INFO    : Bus 56736	: V=0.9771558, theta=-71.116523 -> V=1.0, theta=0.0
% INFO    : Bus 56737	: V=0.9803737, theta=-70.704712 -> V=1.0, theta=0.0
% INFO    : Bus 56738	: V=0.9822607, theta=-70.626664 -> V=1.0, theta=0.0
% INFO    : Bus 56739	: V=0.9943584, theta=-68.459004 -> V=1.0, theta=0.0
% INFO    : Bus 56740	: V=1.0089957, theta=-65.400367 -> V=1.0, theta=0.0
% INFO    : Bus 56741	: V=1.0082043, theta=-65.607182 -> V=1.0, theta=0.0
% INFO    : Bus 56742	: V=0.9891294, theta=-69.494978 -> V=1.0, theta=0.0
% INFO    : Bus 56743	: V=1.0084661, theta=-65.595322 -> V=1.0, theta=0.0
% INFO    : Bus 56744	: V=0.9861319, theta=-69.643897 -> V=1.0, theta=0.0
% INFO    : Bus 56745	: V=0.9899063, theta=-69.091006 -> V=1.0, theta=0.0
% INFO    : Bus 56746	: V=0.9727185, theta=-72.910458 -> V=1.0, theta=0.0
% INFO    : Bus 56747	: V=0.9745478, theta=-72.307651 -> V=1.0, theta=0.0
% INFO    : Bus 56748	: V=0.9731995, theta=-73.230771 -> V=1.0, theta=0.0
% INFO    : Bus 56749	: V=0.9741836, theta=-72.591723 -> V=1.0, theta=0.0
% INFO    : Bus 56750	: V=0.9809008, theta=-70.429795 -> V=1.0, theta=0.0
% INFO    : Bus 56751	: V=0.9777028, theta=-71.582107 -> V=1.0, theta=0.0
% INFO    : Bus 56752	: V=0.9837301, theta=-69.866915 -> V=1.0, theta=0.0
% INFO    : Bus 56753	: V=1.0014475, theta=-66.883765 -> V=1.0, theta=0.0
% INFO    : Bus 56754	: V=1.0053581, theta=-66.150052 -> V=1.0, theta=0.0
% INFO    : Bus 56755	: V=0.9964889, theta=-67.629455 -> V=1.0, theta=0.0
% INFO    : Bus 56756	: V=0.9964652, theta=-67.653456 -> V=1.0, theta=0.0
% INFO    : Bus 56757	: V=0.9835784, theta=-68.789608 -> V=1.0, theta=0.0
% INFO    : Bus 56758	: V=0.9971915, theta=-67.506764 -> V=1.0, theta=0.0
% INFO    : Bus 56759	: V=0.9966745, theta=-67.588663 -> V=1.0, theta=0.0
% INFO    : Bus 56760	: V=1.0180736, theta=-49.347566 -> V=1.0, theta=0.0
% INFO    : Bus 56761	: V=1.0179102, theta=-48.863816 -> V=1.0, theta=0.0
% INFO    : Bus 56762	: V=1.0121399, theta=-49.976568 -> V=1.0, theta=0.0
% INFO    : Bus 56763	: V=1.0131314, theta=-48.365239 -> V=1.0, theta=0.0
% INFO    : Bus 56764	: V=1.010905, theta=-51.551275 -> V=1.0, theta=0.0
% INFO    : Bus 56765	: V=1.0124145, theta=-49.98761 -> V=1.0, theta=0.0
% INFO    : Bus 56766	: V=0.9913488, theta=-67.011505 -> V=1.0, theta=0.0
% INFO    : Bus 56767	: V=0.9517482, theta=-71.39663 -> V=1.0, theta=0.0
% INFO    : Bus 56768	: V=0.951945, theta=-71.145119 -> V=1.0, theta=0.0
% INFO    : Bus 56769	: V=0.997409, theta=-65.06681 -> V=1.0, theta=0.0
% INFO    : Bus 56770	: V=0.9987232, theta=-72.944253 -> V=1.0, theta=0.0
% INFO    : Bus 56771	: V=0.9858288, theta=-74.733124 -> V=1.0, theta=0.0
% INFO    : Bus 56772	: V=0.9905904, theta=-73.154669 -> V=1.0, theta=0.0
% INFO    : Bus 56773	: V=0.9929338, theta=-73.050088 -> V=1.0, theta=0.0
% INFO    : Bus 56774	: V=0.9965382, theta=-72.9679 -> V=1.0, theta=0.0
% INFO    : Bus 56775	: V=0.9918059, theta=-71.550792 -> V=1.0, theta=0.0
% INFO    : Bus 56776	: V=0.9904633, theta=-71.337963 -> V=1.0, theta=0.0
% INFO    : Bus 56777	: V=1.0141089, theta=-71.239689 -> V=1.0, theta=0.0
% INFO    : Bus 56778	: V=0.9926134, theta=-70.229585 -> V=1.0, theta=0.0
% INFO    : Bus 56779	: V=0.9893518, theta=-72.041155 -> V=1.0, theta=0.0
% INFO    : Bus 56780	: V=0.9934051, theta=-69.931791 -> V=1.0, theta=0.0
% INFO    : Bus 56781	: V=0.9949896, theta=-70.560323 -> V=1.0, theta=0.0
% INFO    : Bus 56782	: V=0.9916265, theta=-72.371214 -> V=1.0, theta=0.0
% INFO    : Bus 56783	: V=0.9867995, theta=-72.180127 -> V=1.0, theta=0.0
% INFO    : Bus 56784	: V=0.9881731, theta=-72.143521 -> V=1.0, theta=0.0
% INFO    : Bus 56785	: V=0.9945482, theta=-69.997873 -> V=1.0, theta=0.0
% INFO    : Bus 56786	: V=0.9936777, theta=-71.276646 -> V=1.0, theta=0.0
% INFO    : Bus 56787	: V=0.9969883, theta=-70.023755 -> V=1.0, theta=0.0
% INFO    : Bus 56788	: V=0.947101, theta=-77.390772 -> V=1.0, theta=0.0
% INFO    : Bus 56789	: V=0.9433059, theta=-78.109201 -> V=1.0, theta=0.0
% INFO    : Bus 56790	: V=0.9420863, theta=-78.160188 -> V=1.0, theta=0.0
% INFO    : Bus 56791	: V=0.9441024, theta=-78.232183 -> V=1.0, theta=0.0
% INFO    : Bus 56792	: V=0.9415212, theta=-78.093965 -> V=1.0, theta=0.0
% INFO    : Bus 56793	: V=0.944436, theta=-78.089335 -> V=1.0, theta=0.0
% INFO    : Bus 56794	: V=1.0151869, theta=-58.229031 -> V=1.0, theta=0.0
% INFO    : Bus 56795	: V=1.0111091, theta=-53.243709 -> V=1.0, theta=0.0
% INFO    : Bus 56796	: V=0.9463007, theta=-74.359611 -> V=1.0, theta=0.0
% INFO    : Bus 56797	: V=0.9344752, theta=-77.80905 -> V=1.0, theta=0.0
% INFO    : Bus 56798	: V=0.946794, theta=-72.900589 -> V=1.0, theta=0.0
% INFO    : Bus 56799	: V=0.9510404, theta=-71.798345 -> V=1.0, theta=0.0
% INFO    : Bus 56800	: V=0.9364242, theta=-77.555741 -> V=1.0, theta=0.0
% INFO    : Bus 56801	: V=0.9389258, theta=-77.096162 -> V=1.0, theta=0.0
% INFO    : Bus 56802	: V=0.9363376, theta=-77.734497 -> V=1.0, theta=0.0
% INFO    : Bus 56803	: V=0.9382102, theta=-77.466545 -> V=1.0, theta=0.0
% INFO    : Bus 56804	: V=0.9316008, theta=-77.906821 -> V=1.0, theta=0.0
% INFO    : Bus 56805	: V=0.9412866, theta=-77.459691 -> V=1.0, theta=0.0
% INFO    : Bus 56806	: V=0.9609848, theta=-66.961902 -> V=1.0, theta=0.0
% INFO    : Bus 56807	: V=0.9613882, theta=-66.821338 -> V=1.0, theta=0.0
% INFO    : Bus 56808	: V=1.0003932, theta=-52.689902 -> V=1.0, theta=0.0
% INFO    : Bus 56809	: V=0.9708826, theta=-68.647166 -> V=1.0, theta=0.0
% INFO    : Bus 56810	: V=1.0136217, theta=-58.496564 -> V=1.0, theta=0.0
% INFO    : Bus 56811	: V=0.9984374, theta=-60.9009 -> V=1.0, theta=0.0
% INFO    : Bus 56812	: V=0.9970384, theta=-61.108019 -> V=1.0, theta=0.0
% INFO    : Bus 56813	: V=0.9961118, theta=-61.168701 -> V=1.0, theta=0.0
% INFO    : Bus 56814	: V=0.9968, theta=-61.07057 -> V=1.0, theta=0.0
% INFO    : Bus 56815	: V=1.001432, theta=-56.412498 -> V=1.0, theta=0.0
% INFO    : Bus 56816	: V=1.0037337, theta=-56.400297 -> V=1.0, theta=0.0
% INFO    : Bus 56817	: V=1.0127232, theta=-54.138136 -> V=1.0, theta=0.0
% INFO    : Bus 56818	: V=1.0121007, theta=-56.145296 -> V=1.0, theta=0.0
% INFO    : Bus 56819	: V=1.0080662, theta=-57.149428 -> V=1.0, theta=0.0
% INFO    : Bus 56820	: V=0.9905153, theta=-56.973142 -> V=1.0, theta=0.0
% INFO    : Bus 56821	: V=1.0075406, theta=-55.490931 -> V=1.0, theta=0.0
% INFO    : Bus 56822	: V=1.0071142, theta=-56.173073 -> V=1.0, theta=0.0
% INFO    : Bus 56823	: V=1.0116046, theta=-55.97665 -> V=1.0, theta=0.0
% INFO    : Bus 56824	: V=1.019361, theta=-55.405385 -> V=1.0, theta=0.0
% INFO    : Bus 56825	: V=1.0169841, theta=-55.4964 -> V=1.0, theta=0.0
% INFO    : Bus 56826	: V=1.0125616, theta=-55.316542 -> V=1.0, theta=0.0
% INFO    : Bus 56827	: V=0.996792, theta=-56.777332 -> V=1.0, theta=0.0
% INFO    : Bus 56828	: V=1.009198, theta=-55.467146 -> V=1.0, theta=0.0
% INFO    : Bus 56829	: V=1.0083712, theta=-57.041777 -> V=1.0, theta=0.0
% INFO    : Bus 56830	: V=1.0112438, theta=-56.20527 -> V=1.0, theta=0.0
% INFO    : Bus 56831	: V=1.0069271, theta=-56.26146 -> V=1.0, theta=0.0
% INFO    : Bus 56832	: V=0.9942814, theta=-57.838768 -> V=1.0, theta=0.0
% INFO    : Bus 56833	: V=0.9928601, theta=-58.156937 -> V=1.0, theta=0.0
% INFO    : Bus 56834	: V=0.9755394, theta=-65.59428 -> V=1.0, theta=0.0
% INFO    : Bus 56835	: V=0.9698997, theta=-68.817636 -> V=1.0, theta=0.0
% INFO    : Bus 56836	: V=0.9741635, theta=-67.251958 -> V=1.0, theta=0.0
% INFO    : Bus 56837	: V=0.9743106, theta=-67.956468 -> V=1.0, theta=0.0
% INFO    : Bus 56838	: V=0.9749547, theta=-67.959463 -> V=1.0, theta=0.0
% INFO    : Bus 56839	: V=1.0080576, theta=-67.713253 -> V=1.0, theta=0.0
% INFO    : Bus 56840	: V=0.9446771, theta=-72.005738 -> V=1.0, theta=0.0
% INFO    : Bus 56841	: V=0.9478481, theta=-71.095717 -> V=1.0, theta=0.0
% INFO    : Bus 56842	: V=0.9557392, theta=-71.446922 -> V=1.0, theta=0.0
% INFO    : Bus 56843	: V=0.9618552, theta=-69.667779 -> V=1.0, theta=0.0
% INFO    : Bus 56844	: V=0.9563103, theta=-68.699831 -> V=1.0, theta=0.0
% INFO    : Bus 56845	: V=0.9675305, theta=-68.299387 -> V=1.0, theta=0.0
% INFO    : Bus 56846	: V=1.0084215, theta=-67.276018 -> V=1.0, theta=0.0
% INFO    : Bus 56847	: V=1.0071903, theta=-69.059759 -> V=1.0, theta=0.0
% INFO    : Bus 56848	: V=1.0145622, theta=-67.805816 -> V=1.0, theta=0.0
% INFO    : Bus 56849	: V=1.0103038, theta=-68.857123 -> V=1.0, theta=0.0
% INFO    : Bus 56850	: V=0.9917925, theta=-68.50052 -> V=1.0, theta=0.0
% INFO    : Bus 56851	: V=1.0159276, theta=-66.755434 -> V=1.0, theta=0.0
% INFO    : Bus 56852	: V=1.0192926, theta=-66.197984 -> V=1.0, theta=0.0
% INFO    : Bus 56853	: V=0.9883276, theta=-74.357631 -> V=1.0, theta=0.0
% INFO    : Bus 56854	: V=0.9922601, theta=-74.210262 -> V=1.0, theta=0.0
% INFO    : Bus 56855	: V=0.9832282, theta=-75.091479 -> V=1.0, theta=0.0
% INFO    : Bus 56856	: V=0.9886553, theta=-74.194674 -> V=1.0, theta=0.0
% INFO    : Bus 56857	: V=0.9920022, theta=-73.373299 -> V=1.0, theta=0.0
% INFO    : Bus 56858	: V=0.9955903, theta=-72.879908 -> V=1.0, theta=0.0
% INFO    : Bus 56859	: V=0.987296, theta=-74.730394 -> V=1.0, theta=0.0
% INFO    : Bus 56860	: V=0.9865759, theta=-74.97276 -> V=1.0, theta=0.0
% INFO    : Bus 56861	: V=0.9834516, theta=-75.206157 -> V=1.0, theta=0.0
% INFO    : Bus 56862	: V=1.0015152, theta=-74.947538 -> V=1.0, theta=0.0
% INFO    : Bus 56863	: V=1.0115818, theta=-73.80104 -> V=1.0, theta=0.0
% INFO    : Bus 56864	: V=1.0102391, theta=-73.435671 -> V=1.0, theta=0.0
% INFO    : Bus 56865	: V=0.9872301, theta=-74.591002 -> V=1.0, theta=0.0
% INFO    : Bus 56866	: V=1.0083351, theta=-72.607214 -> V=1.0, theta=0.0
% INFO    : Bus 56867	: V=0.9786901, theta=-70.566567 -> V=1.0, theta=0.0
% INFO    : Bus 56868	: V=0.995196, theta=-69.385571 -> V=1.0, theta=0.0
% INFO    : Bus 56869	: V=0.9962139, theta=-69.321534 -> V=1.0, theta=0.0
% INFO    : Bus 56870	: V=0.997462, theta=-69.123507 -> V=1.0, theta=0.0
% INFO    : Bus 56871	: V=0.9932579, theta=-69.263579 -> V=1.0, theta=0.0
% INFO    : Bus 56872	: V=0.9975574, theta=-69.479913 -> V=1.0, theta=0.0
% INFO    : Bus 56873	: V=1.0069705, theta=-67.855745 -> V=1.0, theta=0.0
% INFO    : Bus 56874	: V=1.0137256, theta=-68.289811 -> V=1.0, theta=0.0
% INFO    : Bus 56875	: V=0.9674914, theta=-60.169037 -> V=1.0, theta=0.0
% INFO    : Bus 56876	: V=0.9698086, theta=-59.110594 -> V=1.0, theta=0.0
% INFO    : Bus 56877	: V=0.9811439, theta=-68.336273 -> V=1.0, theta=0.0
% INFO    : Bus 56878	: V=0.9589351, theta=-68.547513 -> V=1.0, theta=0.0
% INFO    : Bus 56879	: V=0.9531399, theta=-68.240289 -> V=1.0, theta=0.0
% INFO    : Bus 56880	: V=0.952402, theta=-66.747772 -> V=1.0, theta=0.0
% INFO    : Bus 56881	: V=0.976181, theta=-66.444047 -> V=1.0, theta=0.0
% INFO    : Bus 56882	: V=0.9784003, theta=-66.83938 -> V=1.0, theta=0.0
% INFO    : Bus 56883	: V=0.9592393, theta=-67.684371 -> V=1.0, theta=0.0
% INFO    : Bus 56884	: V=1.0116164, theta=-67.554237 -> V=1.0, theta=0.0
% INFO    : Bus 56885	: V=0.9959191, theta=-67.516922 -> V=1.0, theta=0.0
% INFO    : Bus 56886	: V=0.9836884, theta=-67.805699 -> V=1.0, theta=0.0
% INFO    : Bus 56887	: V=0.9569319, theta=-63.348272 -> V=1.0, theta=0.0
% INFO    : Bus 56888	: V=0.979333, theta=-61.038114 -> V=1.0, theta=0.0
% INFO    : Bus 56889	: V=0.9796995, theta=-60.577711 -> V=1.0, theta=0.0
% INFO    : Bus 56890	: V=0.9758725, theta=-61.266551 -> V=1.0, theta=0.0
% INFO    : Bus 56891	: V=0.9728719, theta=-61.423112 -> V=1.0, theta=0.0
% INFO    : Bus 56892	: V=0.9785617, theta=-60.673768 -> V=1.0, theta=0.0
% INFO    : Bus 56893	: V=0.9687018, theta=-61.58627 -> V=1.0, theta=0.0
% INFO    : Bus 56894	: V=0.9694795, theta=-61.559204 -> V=1.0, theta=0.0
% INFO    : Bus 56895	: V=0.9636241, theta=-61.747499 -> V=1.0, theta=0.0
% INFO    : Bus 56896	: V=0.9678352, theta=-61.679829 -> V=1.0, theta=0.0
% INFO    : Bus 56897	: V=0.9782182, theta=-60.693587 -> V=1.0, theta=0.0
% INFO    : Bus 56898	: V=0.9750041, theta=-61.319574 -> V=1.0, theta=0.0
% INFO    : Bus 56899	: V=0.9757802, theta=-61.29145 -> V=1.0, theta=0.0
% INFO    : Bus 56900	: V=0.9750426, theta=-61.312894 -> V=1.0, theta=0.0
% INFO    : Bus 56901	: V=0.9770794, theta=-61.236847 -> V=1.0, theta=0.0
% INFO    : Bus 56902	: V=0.9829065, theta=-60.760712 -> V=1.0, theta=0.0
% INFO    : Bus 56903	: V=0.985784, theta=-60.44636 -> V=1.0, theta=0.0
% INFO    : Bus 56904	: V=0.9898147, theta=-60.03812 -> V=1.0, theta=0.0
% INFO    : Bus 56905	: V=0.974865, theta=-61.335702 -> V=1.0, theta=0.0
% INFO    : Bus 56906	: V=0.974532, theta=-61.333872 -> V=1.0, theta=0.0
% INFO    : Bus 56907	: V=0.9739498, theta=-61.359646 -> V=1.0, theta=0.0
% INFO    : Bus 56908	: V=0.979745, theta=-60.589023 -> V=1.0, theta=0.0
% INFO    : Bus 56909	: V=0.9694243, theta=-61.562231 -> V=1.0, theta=0.0
% INFO    : Bus 56910	: V=0.9785758, theta=-60.651612 -> V=1.0, theta=0.0
% INFO    : Bus 56911	: V=0.9754055, theta=-60.717168 -> V=1.0, theta=0.0
% INFO    : Bus 56912	: V=0.9618479, theta=-61.979346 -> V=1.0, theta=0.0
% INFO    : Bus 56913	: V=0.9745932, theta=-60.69012 -> V=1.0, theta=0.0
% INFO    : Bus 56914	: V=0.9537535, theta=-62.17127 -> V=1.0, theta=0.0
% INFO    : Bus 56915	: V=0.9643685, theta=-61.825444 -> V=1.0, theta=0.0
% INFO    : Bus 56916	: V=0.9668429, theta=-61.688498 -> V=1.0, theta=0.0
% INFO    : Bus 56917	: V=0.9684334, theta=-61.609064 -> V=1.0, theta=0.0
% INFO    : Bus 56918	: V=0.9632072, theta=-61.907427 -> V=1.0, theta=0.0
% INFO    : Bus 56919	: V=0.9613191, theta=-62.000225 -> V=1.0, theta=0.0
% INFO    : Bus 56920	: V=0.9700988, theta=-61.541976 -> V=1.0, theta=0.0
% INFO    : Bus 56921	: V=0.9645085, theta=-61.879286 -> V=1.0, theta=0.0
% INFO    : Bus 56922	: V=0.9625685, theta=-61.974867 -> V=1.0, theta=0.0
% INFO    : Bus 56923	: V=0.9716695, theta=-61.4756 -> V=1.0, theta=0.0
% INFO    : Bus 56924	: V=0.9727372, theta=-61.411827 -> V=1.0, theta=0.0
% INFO    : Bus 56925	: V=0.9655474, theta=-61.853554 -> V=1.0, theta=0.0
% INFO    : Bus 56926	: V=0.9655754, theta=-61.834118 -> V=1.0, theta=0.0
% INFO    : Bus 56927	: V=0.9684622, theta=-61.692171 -> V=1.0, theta=0.0
% INFO    : Bus 56928	: V=0.9674008, theta=-61.771099 -> V=1.0, theta=0.0
% INFO    : Bus 56929	: V=0.9695624, theta=-61.669083 -> V=1.0, theta=0.0
% INFO    : Bus 56930	: V=0.981466, theta=-60.471819 -> V=1.0, theta=0.0
% INFO    : Bus 56931	: V=0.9851181, theta=-60.206841 -> V=1.0, theta=0.0
% INFO    : Bus 56932	: V=1.0178262, theta=-57.072465 -> V=1.0, theta=0.0
% INFO    : Bus 56933	: V=0.9713452, theta=-61.19318 -> V=1.0, theta=0.0
% INFO    : Bus 56934	: V=0.9633994, theta=-61.464188 -> V=1.0, theta=0.0
% INFO    : Bus 56935	: V=0.9611915, theta=-61.791762 -> V=1.0, theta=0.0
% INFO    : Bus 56936	: V=0.9780668, theta=-59.90498 -> V=1.0, theta=0.0
% INFO    : Bus 56937	: V=0.9767061, theta=-60.068587 -> V=1.0, theta=0.0
% INFO    : Bus 56938	: V=0.9630777, theta=-61.730599 -> V=1.0, theta=0.0
% INFO    : Bus 56939	: V=0.9591577, theta=-62.04991 -> V=1.0, theta=0.0
% INFO    : Bus 56940	: V=0.9541217, theta=-62.128768 -> V=1.0, theta=0.0
% INFO    : Bus 56941	: V=0.9740502, theta=-60.44573 -> V=1.0, theta=0.0
% INFO    : Bus 56942	: V=0.9561224, theta=-61.940725 -> V=1.0, theta=0.0
% INFO    : Bus 56943	: V=0.9553165, theta=-62.141262 -> V=1.0, theta=0.0
% INFO    : Bus 56944	: V=0.949628, theta=-62.397541 -> V=1.0, theta=0.0
% INFO    : Bus 56945	: V=0.9602941, theta=-62.033127 -> V=1.0, theta=0.0
% INFO    : Bus 56946	: V=0.9619258, theta=-61.982168 -> V=1.0, theta=0.0
% INFO    : Bus 56947	: V=0.9665151, theta=-61.779848 -> V=1.0, theta=0.0
% INFO    : Bus 56948	: V=0.9672547, theta=-61.696665 -> V=1.0, theta=0.0
% INFO    : Bus 56949	: V=0.9827446, theta=-60.137241 -> V=1.0, theta=0.0
% INFO    : Bus 56950	: V=0.9593702, theta=-62.03931 -> V=1.0, theta=0.0
% INFO    : Bus 56951	: V=0.9638963, theta=-61.889003 -> V=1.0, theta=0.0
% INFO    : Bus 56952	: V=0.980071, theta=-60.41896 -> V=1.0, theta=0.0
% INFO    : Bus 56953	: V=1.0119018, theta=-57.451433 -> V=1.0, theta=0.0
% INFO    : Bus 56954	: V=1.0125754, theta=-57.308179 -> V=1.0, theta=0.0
% INFO    : Bus 56955	: V=0.9788516, theta=-61.045589 -> V=1.0, theta=0.0
% INFO    : Bus 56956	: V=0.9920205, theta=-59.153089 -> V=1.0, theta=0.0
% INFO    : Bus 56957	: V=0.9995784, theta=-58.380132 -> V=1.0, theta=0.0
% INFO    : Bus 56958	: V=0.9859866, theta=-59.107225 -> V=1.0, theta=0.0
% INFO    : Bus 56959	: V=0.9648816, theta=-62.634603 -> V=1.0, theta=0.0
% INFO    : Bus 56960	: V=0.9632458, theta=-63.539253 -> V=1.0, theta=0.0
% INFO    : Bus 56961	: V=0.9656606, theta=-60.316738 -> V=1.0, theta=0.0
% INFO    : Bus 56962	: V=0.9576165, theta=-73.628646 -> V=1.0, theta=0.0
% INFO    : Bus 56963	: V=0.9587403, theta=-73.560454 -> V=1.0, theta=0.0
% INFO    : Bus 56964	: V=0.9571291, theta=-73.598525 -> V=1.0, theta=0.0
% INFO    : Bus 56965	: V=0.9579397, theta=-73.622621 -> V=1.0, theta=0.0
% INFO    : Bus 56966	: V=0.9595693, theta=-73.576418 -> V=1.0, theta=0.0
% INFO    : Bus 56967	: V=0.9614671, theta=-73.439741 -> V=1.0, theta=0.0
% INFO    : Bus 56968	: V=0.9632305, theta=-73.277624 -> V=1.0, theta=0.0
% INFO    : Bus 56969	: V=0.9731487, theta=-71.561579 -> V=1.0, theta=0.0
% INFO    : Bus 56970	: V=0.96018, theta=-73.518633 -> V=1.0, theta=0.0
% INFO    : Bus 56971	: V=0.9730894, theta=-71.538711 -> V=1.0, theta=0.0
% INFO    : Bus 56972	: V=0.959232, theta=-73.580193 -> V=1.0, theta=0.0
% INFO    : Bus 56973	: V=0.9721775, theta=-71.605744 -> V=1.0, theta=0.0
% INFO    : Bus 56974	: V=0.9705193, theta=-71.72266 -> V=1.0, theta=0.0
% INFO    : Bus 56975	: V=0.956993, theta=-73.608019 -> V=1.0, theta=0.0
% INFO    : Bus 56976	: V=0.9703833, theta=-71.74716 -> V=1.0, theta=0.0
% INFO    : Bus 56977	: V=0.9711146, theta=-71.698952 -> V=1.0, theta=0.0
% INFO    : Bus 56978	: V=0.9679975, theta=-71.826172 -> V=1.0, theta=0.0
% INFO    : Bus 56979	: V=0.9583077, theta=-73.561885 -> V=1.0, theta=0.0
% INFO    : Bus 56980	: V=1.0016976, theta=-69.406006 -> V=1.0, theta=0.0
% INFO    : Bus 56981	: V=0.9610952, theta=-73.462658 -> V=1.0, theta=0.0
% INFO    : Bus 56982	: V=0.9749664, theta=-71.497139 -> V=1.0, theta=0.0
% INFO    : Bus 56983	: V=0.9737299, theta=-71.576294 -> V=1.0, theta=0.0
% INFO    : Bus 56984	: V=0.963499, theta=-72.534413 -> V=1.0, theta=0.0
% INFO    : Bus 56985	: V=0.9751788, theta=-71.365462 -> V=1.0, theta=0.0
% INFO    : Bus 56986	: V=0.9749962, theta=-71.361538 -> V=1.0, theta=0.0
% INFO    : Bus 56987	: V=0.974477, theta=-71.385181 -> V=1.0, theta=0.0
% INFO    : Bus 56988	: V=0.9662694, theta=-72.245203 -> V=1.0, theta=0.0
% INFO    : Bus 56989	: V=0.9745366, theta=-71.363655 -> V=1.0, theta=0.0
% INFO    : Bus 56990	: V=0.9689614, theta=-71.449476 -> V=1.0, theta=0.0
% INFO    : Bus 56991	: V=0.9760154, theta=-71.111895 -> V=1.0, theta=0.0
% INFO    : Bus 56992	: V=0.9618928, theta=-72.787557 -> V=1.0, theta=0.0
% INFO    : Bus 56993	: V=0.960848, theta=-72.817497 -> V=1.0, theta=0.0
% INFO    : Bus 56994	: V=0.9626514, theta=-72.495709 -> V=1.0, theta=0.0
% INFO    : Bus 56995	: V=0.9801593, theta=-71.12687 -> V=1.0, theta=0.0
% INFO    : Bus 56996	: V=0.9957641, theta=-70.158328 -> V=1.0, theta=0.0
% INFO    : Bus 56997	: V=1.0052685, theta=-69.666934 -> V=1.0, theta=0.0
% INFO    : Bus 56998	: V=0.9861527, theta=-70.366313 -> V=1.0, theta=0.0
% INFO    : Bus 56999	: V=0.9605341, theta=-72.058884 -> V=1.0, theta=0.0
% INFO    : Bus 57000	: V=0.9640402, theta=-71.91341 -> V=1.0, theta=0.0
% INFO    : Bus 57001	: V=0.9922672, theta=-69.407145 -> V=1.0, theta=0.0
% INFO    : Bus 57002	: V=0.9708933, theta=-71.748744 -> V=1.0, theta=0.0
% INFO    : Bus 57003	: V=0.9629737, theta=-72.479403 -> V=1.0, theta=0.0
% INFO    : Bus 57004	: V=0.967289, theta=-72.577443 -> V=1.0, theta=0.0
% INFO    : Bus 57005	: V=0.9709438, theta=-70.845673 -> V=1.0, theta=0.0
% INFO    : Bus 57006	: V=0.9616409, theta=-71.112722 -> V=1.0, theta=0.0
% INFO    : Bus 57007	: V=0.961512, theta=-71.939422 -> V=1.0, theta=0.0
% INFO    : Bus 57008	: V=0.9793886, theta=-70.576794 -> V=1.0, theta=0.0
% INFO    : Bus 57009	: V=0.9763398, theta=-70.697844 -> V=1.0, theta=0.0
% INFO    : Bus 57010	: V=0.9657213, theta=-71.860564 -> V=1.0, theta=0.0
% INFO    : Bus 57011	: V=0.9771583, theta=-71.371454 -> V=1.0, theta=0.0
% INFO    : Bus 57012	: V=0.9693833, theta=-71.788959 -> V=1.0, theta=0.0
% INFO    : Bus 57013	: V=0.9820637, theta=-68.561079 -> V=1.0, theta=0.0
% INFO    : Bus 57014	: V=0.9972087, theta=-69.236913 -> V=1.0, theta=0.0
% INFO    : Bus 57015	: V=1.0101432, theta=-69.539378 -> V=1.0, theta=0.0
% INFO    : Bus 57016	: V=1.013987, theta=-68.427665 -> V=1.0, theta=0.0
% INFO    : Bus 57017	: V=1.0187492, theta=-68.35343 -> V=1.0, theta=0.0
% INFO    : Bus 57018	: V=0.9866037, theta=-56.698761 -> V=1.0, theta=0.0
% INFO    : Bus 57019	: V=1.0119269, theta=-55.265613 -> V=1.0, theta=0.0
% INFO    : Bus 57020	: V=1.0174418, theta=-55.363188 -> V=1.0, theta=0.0
% INFO    : Bus 57021	: V=1.0071016, theta=-55.259311 -> V=1.0, theta=0.0
% INFO    : Bus 57022	: V=0.9894365, theta=-56.455584 -> V=1.0, theta=0.0
% INFO    : Bus 57023	: V=1.0087818, theta=-54.127687 -> V=1.0, theta=0.0
% INFO    : Bus 57024	: V=0.9513971, theta=-68.100502 -> V=1.0, theta=0.0
% INFO    : Bus 57025	: V=0.9547209, theta=-67.594066 -> V=1.0, theta=0.0
% INFO    : Bus 57026	: V=1.0158221, theta=-62.92041 -> V=1.0, theta=0.0
% INFO    : Bus 57027	: V=1.0153403, theta=-63.760751 -> V=1.0, theta=0.0
% INFO    : Bus 57028	: V=1.0105011, theta=-64.855147 -> V=1.0, theta=0.0
% INFO    : Bus 57029	: V=1.0164888, theta=-62.075439 -> V=1.0, theta=0.0
% INFO    : Bus 57030	: V=1.0090748, theta=-63.362683 -> V=1.0, theta=0.0
% INFO    : Bus 57031	: V=1.0072216, theta=-63.297042 -> V=1.0, theta=0.0
% INFO    : Bus 57032	: V=1.0063718, theta=-63.388861 -> V=1.0, theta=0.0
% INFO    : Bus 57033	: V=0.9942733, theta=-62.628994 -> V=1.0, theta=0.0
% INFO    : Bus 57034	: V=0.9948152, theta=-62.367426 -> V=1.0, theta=0.0
% INFO    : Bus 57035	: V=1.0052785, theta=-62.8514 -> V=1.0, theta=0.0
% INFO    : Bus 57036	: V=0.9651746, theta=-72.037021 -> V=1.0, theta=0.0
% INFO    : Bus 57037	: V=0.9491192, theta=-79.421189 -> V=1.0, theta=0.0
% INFO    : Bus 57038	: V=0.9502149, theta=-79.32051 -> V=1.0, theta=0.0
% INFO    : Bus 57039	: V=0.9449948, theta=-79.982077 -> V=1.0, theta=0.0
% INFO    : Bus 57040	: V=0.9474935, theta=-79.61906 -> V=1.0, theta=0.0
% INFO    : Bus 57041	: V=0.9458106, theta=-79.887229 -> V=1.0, theta=0.0
% INFO    : Bus 57042	: V=0.9480128, theta=-79.597792 -> V=1.0, theta=0.0
% INFO    : Bus 57043	: V=0.9486255, theta=-79.568347 -> V=1.0, theta=0.0
% INFO    : Bus 57044	: V=0.9881704, theta=-70.150206 -> V=1.0, theta=0.0
% INFO    : Bus 57045	: V=0.9618718, theta=-73.161986 -> V=1.0, theta=0.0
% INFO    : Bus 57046	: V=0.9453465, theta=-77.174885 -> V=1.0, theta=0.0
% INFO    : Bus 57047	: V=0.9776176, theta=-71.848581 -> V=1.0, theta=0.0
% INFO    : Bus 57048	: V=0.9697459, theta=-73.222167 -> V=1.0, theta=0.0
% INFO    : Bus 57049	: V=0.9707634, theta=-71.867294 -> V=1.0, theta=0.0
% INFO    : Bus 57050	: V=0.9674445, theta=-72.561808 -> V=1.0, theta=0.0
% INFO    : Bus 57051	: V=0.9879412, theta=-70.618852 -> V=1.0, theta=0.0
% INFO    : Bus 57052	: V=0.9835344, theta=-70.909231 -> V=1.0, theta=0.0
% INFO    : Bus 57053	: V=0.9726749, theta=-63.824049 -> V=1.0, theta=0.0
% INFO    : Bus 57054	: V=0.9757699, theta=-57.630099 -> V=1.0, theta=0.0
% INFO    : Bus 57055	: V=0.9752227, theta=-57.684205 -> V=1.0, theta=0.0
% INFO    : Bus 57056	: V=0.9696512, theta=-58.100109 -> V=1.0, theta=0.0
% INFO    : Bus 57057	: V=0.9698694, theta=-58.071414 -> V=1.0, theta=0.0
% INFO    : Bus 57058	: V=0.9709549, theta=-58.035887 -> V=1.0, theta=0.0
% INFO    : Bus 57059	: V=0.9724819, theta=-57.881391 -> V=1.0, theta=0.0
% INFO    : Bus 57060	: V=0.969221, theta=-58.132878 -> V=1.0, theta=0.0
% INFO    : Bus 57061	: V=0.9691567, theta=-58.1276 -> V=1.0, theta=0.0
% INFO    : Bus 57062	: V=0.9697944, theta=-58.131007 -> V=1.0, theta=0.0
% INFO    : Bus 57063	: V=0.967531, theta=-58.217597 -> V=1.0, theta=0.0
% INFO    : Bus 57064	: V=0.9732471, theta=-57.883299 -> V=1.0, theta=0.0
% INFO    : Bus 57065	: V=0.9728102, theta=-57.92647 -> V=1.0, theta=0.0
% INFO    : Bus 57066	: V=0.9727224, theta=-57.946509 -> V=1.0, theta=0.0
% INFO    : Bus 57067	: V=0.9741049, theta=-57.797017 -> V=1.0, theta=0.0
% INFO    : Bus 57068	: V=0.964798, theta=-58.401553 -> V=1.0, theta=0.0
% INFO    : Bus 57069	: V=0.9644491, theta=-58.384087 -> V=1.0, theta=0.0
% INFO    : Bus 57070	: V=0.9804819, theta=-57.285081 -> V=1.0, theta=0.0
% INFO    : Bus 57071	: V=0.9709604, theta=-58.050509 -> V=1.0, theta=0.0
% INFO    : Bus 57072	: V=0.9692574, theta=-58.125659 -> V=1.0, theta=0.0
% INFO    : Bus 57073	: V=0.9828969, theta=-57.037838 -> V=1.0, theta=0.0
% INFO    : Bus 57074	: V=0.9811956, theta=-57.187771 -> V=1.0, theta=0.0
% INFO    : Bus 57075	: V=0.9976383, theta=-56.621083 -> V=1.0, theta=0.0
% INFO    : Bus 57076	: V=0.9954745, theta=-55.768879 -> V=1.0, theta=0.0
% INFO    : Bus 57077	: V=0.9879989, theta=-56.563133 -> V=1.0, theta=0.0
% INFO    : Bus 57078	: V=0.9722137, theta=-58.171275 -> V=1.0, theta=0.0
% INFO    : Bus 57079	: V=0.9656339, theta=-58.34286 -> V=1.0, theta=0.0
% INFO    : Bus 57080	: V=0.9686413, theta=-58.239707 -> V=1.0, theta=0.0
% INFO    : Bus 57081	: V=0.9538427, theta=-73.093582 -> V=1.0, theta=0.0
% INFO    : Bus 57082	: V=0.9784977, theta=-69.681281 -> V=1.0, theta=0.0
% INFO    : Bus 57083	: V=0.9589803, theta=-72.331342 -> V=1.0, theta=0.0
% INFO    : Bus 57084	: V=0.9683244, theta=-71.452373 -> V=1.0, theta=0.0
% INFO    : Bus 57085	: V=0.9507941, theta=-72.566791 -> V=1.0, theta=0.0
% INFO    : Bus 57086	: V=0.9860665, theta=-69.474421 -> V=1.0, theta=0.0
% INFO    : Bus 57087	: V=0.9976777, theta=-68.622236 -> V=1.0, theta=0.0
% INFO    : Bus 57088	: V=0.9870112, theta=-59.775022 -> V=1.0, theta=0.0
% INFO    : Bus 57089	: V=0.9814332, theta=-61.951276 -> V=1.0, theta=0.0
% INFO    : Bus 57090	: V=1.0208546, theta=-44.852997 -> V=1.0, theta=0.0
% INFO    : Bus 57091	: V=1.023403, theta=-44.880499 -> V=1.0, theta=0.0
% INFO    : Bus 57092	: V=0.9666113, theta=-68.044838 -> V=1.0, theta=0.0
% INFO    : Bus 57093	: V=0.9709383, theta=-67.321649 -> V=1.0, theta=0.0
% INFO    : Bus 57094	: V=0.9708064, theta=-67.364699 -> V=1.0, theta=0.0
% INFO    : Bus 57095	: V=0.9794231, theta=-66.207732 -> V=1.0, theta=0.0
% INFO    : Bus 57096	: V=0.9803266, theta=-66.231062 -> V=1.0, theta=0.0
% INFO    : Bus 57097	: V=0.9682081, theta=-69.061697 -> V=1.0, theta=0.0
% INFO    : Bus 57098	: V=0.9614805, theta=-76.892379 -> V=1.0, theta=0.0
% INFO    : Bus 57099	: V=0.9753152, theta=-75.257105 -> V=1.0, theta=0.0
% INFO    : Bus 57100	: V=0.97336, theta=-75.745229 -> V=1.0, theta=0.0
% INFO    : Bus 57101	: V=0.9622163, theta=-76.671945 -> V=1.0, theta=0.0
% INFO    : Bus 57102	: V=0.9853501, theta=-74.672629 -> V=1.0, theta=0.0
% INFO    : Bus 57103	: V=0.9804556, theta=-75.326505 -> V=1.0, theta=0.0
% INFO    : Bus 57104	: V=0.9847692, theta=-75.064211 -> V=1.0, theta=0.0
% INFO    : Bus 57105	: V=0.9979459, theta=-73.403996 -> V=1.0, theta=0.0
% INFO    : Bus 57106	: V=0.9785602, theta=-75.589051 -> V=1.0, theta=0.0
% INFO    : Bus 57107	: V=0.9790592, theta=-75.596781 -> V=1.0, theta=0.0
% INFO    : Bus 57108	: V=0.9813275, theta=-75.418523 -> V=1.0, theta=0.0
% INFO    : Bus 57109	: V=0.9815816, theta=-75.387995 -> V=1.0, theta=0.0
% INFO    : Bus 57110	: V=0.9807136, theta=-75.483159 -> V=1.0, theta=0.0
% INFO    : Bus 57111	: V=0.9800706, theta=-75.551995 -> V=1.0, theta=0.0
% INFO    : Bus 57112	: V=0.9798765, theta=-75.604948 -> V=1.0, theta=0.0
% INFO    : Bus 57113	: V=0.9792945, theta=-75.619266 -> V=1.0, theta=0.0
% INFO    : Bus 57114	: V=0.9788322, theta=-75.728078 -> V=1.0, theta=0.0
% INFO    : Bus 57115	: V=0.9788005, theta=-75.772391 -> V=1.0, theta=0.0
% INFO    : Bus 57116	: V=0.9786561, theta=-75.763645 -> V=1.0, theta=0.0
% INFO    : Bus 57117	: V=0.9785689, theta=-75.776192 -> V=1.0, theta=0.0
% INFO    : Bus 57118	: V=0.9774602, theta=-75.872689 -> V=1.0, theta=0.0
% INFO    : Bus 57119	: V=0.9841698, theta=-75.115677 -> V=1.0, theta=0.0
% INFO    : Bus 57120	: V=0.9769467, theta=-75.806068 -> V=1.0, theta=0.0
% INFO    : Bus 57121	: V=0.9755744, theta=-76.031874 -> V=1.0, theta=0.0
% INFO    : Bus 57122	: V=0.9742475, theta=-76.131401 -> V=1.0, theta=0.0
% INFO    : Bus 57123	: V=0.9608651, theta=-77.883687 -> V=1.0, theta=0.0
% INFO    : Bus 57124	: V=0.976944, theta=-75.812244 -> V=1.0, theta=0.0
% INFO    : Bus 57125	: V=0.9698376, theta=-76.154344 -> V=1.0, theta=0.0
% INFO    : Bus 57126	: V=0.9697619, theta=-76.95575 -> V=1.0, theta=0.0
% INFO    : Bus 57127	: V=0.9687804, theta=-77.255317 -> V=1.0, theta=0.0
% INFO    : Bus 57128	: V=0.9720013, theta=-76.62601 -> V=1.0, theta=0.0
% INFO    : Bus 57129	: V=0.9652792, theta=-76.544956 -> V=1.0, theta=0.0
% INFO    : Bus 57130	: V=0.9637128, theta=-76.878876 -> V=1.0, theta=0.0
% INFO    : Bus 57131	: V=0.9680666, theta=-76.125844 -> V=1.0, theta=0.0
% INFO    : Bus 57132	: V=0.9790569, theta=-75.388588 -> V=1.0, theta=0.0
% INFO    : Bus 57133	: V=0.9757419, theta=-75.952054 -> V=1.0, theta=0.0
% INFO    : Bus 57134	: V=0.9834656, theta=-74.664795 -> V=1.0, theta=0.0
% INFO    : Bus 57135	: V=0.9932114, theta=-71.436618 -> V=1.0, theta=0.0
% INFO    : Bus 57136	: V=0.98721, theta=-74.540714 -> V=1.0, theta=0.0
% INFO    : Bus 57137	: V=0.985545, theta=-74.527203 -> V=1.0, theta=0.0
% INFO    : Bus 57138	: V=0.9639826, theta=-76.736774 -> V=1.0, theta=0.0
% INFO    : Bus 57139	: V=0.9879321, theta=-74.787848 -> V=1.0, theta=0.0
% INFO    : Bus 57140	: V=0.9888069, theta=-74.530306 -> V=1.0, theta=0.0
% INFO    : Bus 57141	: V=0.9916815, theta=-74.461131 -> V=1.0, theta=0.0
% INFO    : Bus 57142	: V=0.9915609, theta=-74.477121 -> V=1.0, theta=0.0
% INFO    : Bus 57143	: V=0.9992256, theta=-74.033741 -> V=1.0, theta=0.0
% INFO    : Bus 57144	: V=0.9793375, theta=-75.919429 -> V=1.0, theta=0.0
% INFO    : Bus 57145	: V=0.9974567, theta=-74.217123 -> V=1.0, theta=0.0
% INFO    : Bus 57146	: V=0.9816708, theta=-74.03069 -> V=1.0, theta=0.0
% INFO    : Bus 57147	: V=0.9653278, theta=-76.793051 -> V=1.0, theta=0.0
% INFO    : Bus 57148	: V=0.9623806, theta=-77.004295 -> V=1.0, theta=0.0
% INFO    : Bus 57149	: V=1.0172651, theta=-72.670583 -> V=1.0, theta=0.0
% INFO    : Bus 57150	: V=1.0111289, theta=-73.270949 -> V=1.0, theta=0.0
% INFO    : Bus 57151	: V=1.0064454, theta=-72.985026 -> V=1.0, theta=0.0
% INFO    : Bus 57152	: V=0.985028, theta=-74.681402 -> V=1.0, theta=0.0
% INFO    : Bus 57153	: V=0.9961076, theta=-73.804887 -> V=1.0, theta=0.0
% INFO    : Bus 57154	: V=0.990705, theta=-74.230868 -> V=1.0, theta=0.0
% INFO    : Bus 57155	: V=0.9897998, theta=-74.014985 -> V=1.0, theta=0.0
% INFO    : Bus 57156	: V=1.0083458, theta=-72.315028 -> V=1.0, theta=0.0
% INFO    : Bus 57157	: V=0.9938188, theta=-58.38303 -> V=1.0, theta=0.0
% INFO    : Bus 57158	: V=1.0219206, theta=-57.113931 -> V=1.0, theta=0.0
% INFO    : Bus 57159	: V=1.0239554, theta=-57.283417 -> V=1.0, theta=0.0
% INFO    : Bus 57160	: V=1.0070133, theta=-58.257494 -> V=1.0, theta=0.0
% INFO    : Bus 57161	: V=1.00217, theta=-53.926382 -> V=1.0, theta=0.0
% INFO    : Bus 57162	: V=1.0192902, theta=-54.464304 -> V=1.0, theta=0.0
% INFO    : Bus 57163	: V=1.0035664, theta=-56.488399 -> V=1.0, theta=0.0
% INFO    : Bus 57164	: V=1.0143889, theta=-57.749901 -> V=1.0, theta=0.0
% INFO    : Bus 57165	: V=0.9879956, theta=-62.935016 -> V=1.0, theta=0.0
% INFO    : Bus 57166	: V=0.9707747, theta=-65.98297 -> V=1.0, theta=0.0
% INFO    : Bus 57167	: V=0.9680802, theta=-67.345429 -> V=1.0, theta=0.0
% INFO    : Bus 57168	: V=0.9651805, theta=-68.115017 -> V=1.0, theta=0.0
% INFO    : Bus 57169	: V=0.9782706, theta=-64.730792 -> V=1.0, theta=0.0
% INFO    : Bus 57170	: V=0.9576451, theta=-68.972739 -> V=1.0, theta=0.0
% INFO    : Bus 57171	: V=0.9668806, theta=-67.071638 -> V=1.0, theta=0.0
% INFO    : Bus 57172	: V=0.9723641, theta=-66.178851 -> V=1.0, theta=0.0
% INFO    : Bus 57173	: V=0.9715245, theta=-66.426127 -> V=1.0, theta=0.0
% INFO    : Bus 57174	: V=0.9585749, theta=-68.358838 -> V=1.0, theta=0.0
% INFO    : Bus 57175	: V=0.9681784, theta=-67.180313 -> V=1.0, theta=0.0
% INFO    : Bus 57176	: V=0.9664522, theta=-67.154313 -> V=1.0, theta=0.0
% INFO    : Bus 57177	: V=0.9487775, theta=-70.168439 -> V=1.0, theta=0.0
% INFO    : Bus 57178	: V=0.9913887, theta=-71.468494 -> V=1.0, theta=0.0
% INFO    : Bus 57179	: V=0.9912392, theta=-71.191204 -> V=1.0, theta=0.0
% INFO    : Bus 57180	: V=0.9886826, theta=-72.002776 -> V=1.0, theta=0.0
% INFO    : Bus 57181	: V=0.9721567, theta=-72.132989 -> V=1.0, theta=0.0
% INFO    : Bus 57182	: V=0.9757523, theta=-72.310901 -> V=1.0, theta=0.0
% INFO    : Bus 57183	: V=1.0180651, theta=-67.01284 -> V=1.0, theta=0.0
% INFO    : Bus 57184	: V=1.0066557, theta=-68.429684 -> V=1.0, theta=0.0
% INFO    : Bus 57185	: V=0.9748881, theta=-72.326675 -> V=1.0, theta=0.0
% INFO    : Bus 57186	: V=0.9911057, theta=-70.861947 -> V=1.0, theta=0.0
% INFO    : Bus 57187	: V=0.9924981, theta=-70.332907 -> V=1.0, theta=0.0
% INFO    : Bus 57188	: V=0.9853693, theta=-62.780867 -> V=1.0, theta=0.0
% INFO    : Bus 57189	: V=0.9831403, theta=-64.379162 -> V=1.0, theta=0.0
% INFO    : Bus 57190	: V=0.9911994, theta=-68.41672 -> V=1.0, theta=0.0
% INFO    : Bus 57191	: V=1.0185344, theta=-66.094724 -> V=1.0, theta=0.0
% INFO    : Bus 57192	: V=1.0201719, theta=-44.671932 -> V=1.0, theta=0.0
% INFO    : Bus 57193	: V=1.0190572, theta=-43.82918 -> V=1.0, theta=0.0
% INFO    : Bus 57194	: V=1.0188221, theta=-43.9362 -> V=1.0, theta=0.0
% INFO    : Bus 57195	: V=1.0187667, theta=-43.830561 -> V=1.0, theta=0.0
% INFO    : Bus 57196	: V=1.0193133, theta=-42.073787 -> V=1.0, theta=0.0
% INFO    : Bus 57197	: V=1.0082334, theta=-58.943546 -> V=1.0, theta=0.0
% INFO    : Bus 57198	: V=1.0194364, theta=-57.717071 -> V=1.0, theta=0.0
% INFO    : Bus 57199	: V=1.0164467, theta=-58.436952 -> V=1.0, theta=0.0
% INFO    : Bus 57200	: V=1.0026767, theta=-59.56687 -> V=1.0, theta=0.0
% INFO    : Bus 57201	: V=1.0059487, theta=-59.131455 -> V=1.0, theta=0.0
% INFO    : Bus 57202	: V=1.0062471, theta=-59.064527 -> V=1.0, theta=0.0
% INFO    : Bus 57203	: V=1.0071946, theta=-59.007121 -> V=1.0, theta=0.0
% INFO    : Bus 57204	: V=1.005804, theta=-58.97246 -> V=1.0, theta=0.0
% INFO    : Bus 57205	: V=1.0054564, theta=-59.078671 -> V=1.0, theta=0.0
% INFO    : Bus 57206	: V=1.0131586, theta=-58.370918 -> V=1.0, theta=0.0
% INFO    : Bus 57207	: V=1.0026073, theta=-59.208762 -> V=1.0, theta=0.0
% INFO    : Bus 57208	: V=0.9932075, theta=-60.247543 -> V=1.0, theta=0.0
% INFO    : Bus 57209	: V=0.9892921, theta=-60.523783 -> V=1.0, theta=0.0
% INFO    : Bus 57210	: V=0.9858092, theta=-60.763588 -> V=1.0, theta=0.0
% INFO    : Bus 57211	: V=0.9835527, theta=-60.855414 -> V=1.0, theta=0.0
% INFO    : Bus 57212	: V=0.9869018, theta=-60.696563 -> V=1.0, theta=0.0
% INFO    : Bus 57213	: V=0.9824082, theta=-60.849241 -> V=1.0, theta=0.0
% INFO    : Bus 57214	: V=0.9835293, theta=-60.810093 -> V=1.0, theta=0.0
% INFO    : Bus 57215	: V=0.9857736, theta=-60.711308 -> V=1.0, theta=0.0
% INFO    : Bus 57216	: V=0.9869398, theta=-60.641529 -> V=1.0, theta=0.0
% INFO    : Bus 57217	: V=1.0034404, theta=-59.157589 -> V=1.0, theta=0.0
% INFO    : Bus 57218	: V=0.988099, theta=-60.573588 -> V=1.0, theta=0.0
% INFO    : Bus 57219	: V=1.0011797, theta=-59.343983 -> V=1.0, theta=0.0
% INFO    : Bus 57220	: V=0.9936084, theta=-59.983829 -> V=1.0, theta=0.0
% INFO    : Bus 57221	: V=0.9991905, theta=-59.490657 -> V=1.0, theta=0.0
% INFO    : Bus 57222	: V=0.9856943, theta=-60.711063 -> V=1.0, theta=0.0
% INFO    : Bus 57223	: V=0.9842223, theta=-60.781258 -> V=1.0, theta=0.0
% INFO    : Bus 57224	: V=0.9831833, theta=-60.818093 -> V=1.0, theta=0.0
% INFO    : Bus 57225	: V=0.9965733, theta=-59.634698 -> V=1.0, theta=0.0
% INFO    : Bus 57226	: V=0.9983861, theta=-59.531364 -> V=1.0, theta=0.0
% INFO    : Bus 57227	: V=0.9831317, theta=-60.781768 -> V=1.0, theta=0.0
% INFO    : Bus 57228	: V=0.9813695, theta=-60.785324 -> V=1.0, theta=0.0
% INFO    : Bus 57229	: V=0.9824111, theta=-60.79565 -> V=1.0, theta=0.0
% INFO    : Bus 57230	: V=0.9814636, theta=-60.740424 -> V=1.0, theta=0.0
% INFO    : Bus 57231	: V=0.9821985, theta=-60.645305 -> V=1.0, theta=0.0
% INFO    : Bus 57232	: V=0.9804137, theta=-60.788877 -> V=1.0, theta=0.0
% INFO    : Bus 57233	: V=0.980688, theta=-60.721339 -> V=1.0, theta=0.0
% INFO    : Bus 57234	: V=0.9929797, theta=-59.609861 -> V=1.0, theta=0.0
% INFO    : Bus 57235	: V=0.9878233, theta=-60.309881 -> V=1.0, theta=0.0
% INFO    : Bus 57236	: V=0.9956838, theta=-59.450404 -> V=1.0, theta=0.0
% INFO    : Bus 57237	: V=0.99878, theta=-59.261864 -> V=1.0, theta=0.0
% INFO    : Bus 57238	: V=0.9862386, theta=-60.425116 -> V=1.0, theta=0.0
% INFO    : Bus 57239	: V=0.9819052, theta=-60.624879 -> V=1.0, theta=0.0
% INFO    : Bus 57240	: V=0.9821946, theta=-60.688839 -> V=1.0, theta=0.0
% INFO    : Bus 57241	: V=0.9954131, theta=-59.41425 -> V=1.0, theta=0.0
% INFO    : Bus 57242	: V=0.9822784, theta=-60.809925 -> V=1.0, theta=0.0
% INFO    : Bus 57243	: V=0.9809781, theta=-60.830209 -> V=1.0, theta=0.0
% INFO    : Bus 57244	: V=0.9805269, theta=-60.79595 -> V=1.0, theta=0.0
% INFO    : Bus 57245	: V=0.9811876, theta=-60.789061 -> V=1.0, theta=0.0
% INFO    : Bus 57246	: V=0.9837559, theta=-60.771687 -> V=1.0, theta=0.0
% INFO    : Bus 57247	: V=0.9828112, theta=-60.822837 -> V=1.0, theta=0.0
% INFO    : Bus 57248	: V=0.9984248, theta=-61.122063 -> V=1.0, theta=0.0
% INFO    : Bus 57249	: V=1.0176102, theta=-61.87422 -> V=1.0, theta=0.0
% INFO    : Bus 57250	: V=1.0157715, theta=-61.80132 -> V=1.0, theta=0.0
% INFO    : Bus 57251	: V=1.0008231, theta=-60.413807 -> V=1.0, theta=0.0
% INFO    : Bus 57252	: V=1.0161072, theta=-62.111145 -> V=1.0, theta=0.0
% INFO    : Bus 57253	: V=0.9871718, theta=-59.979908 -> V=1.0, theta=0.0
% INFO    : Bus 57254	: V=0.9789355, theta=-60.827209 -> V=1.0, theta=0.0
% INFO    : Bus 57255	: V=0.9936135, theta=-60.064429 -> V=1.0, theta=0.0
% INFO    : Bus 57256	: V=0.9821292, theta=-60.841074 -> V=1.0, theta=0.0
% INFO    : Bus 57257	: V=0.9944736, theta=-59.845984 -> V=1.0, theta=0.0
% INFO    : Bus 57258	: V=0.9942472, theta=-59.892068 -> V=1.0, theta=0.0
% INFO    : Bus 57259	: V=0.9800502, theta=-60.843956 -> V=1.0, theta=0.0
% INFO    : Bus 57260	: V=0.9807023, theta=-60.839414 -> V=1.0, theta=0.0
% INFO    : Bus 57261	: V=0.9773504, theta=-60.906654 -> V=1.0, theta=0.0
% INFO    : Bus 57262	: V=0.9805507, theta=-60.790211 -> V=1.0, theta=0.0
% INFO    : Bus 57263	: V=0.9790639, theta=-60.860103 -> V=1.0, theta=0.0
% INFO    : Bus 57264	: V=0.9788515, theta=-60.879668 -> V=1.0, theta=0.0
% INFO    : Bus 57265	: V=0.9784335, theta=-60.841144 -> V=1.0, theta=0.0
% INFO    : Bus 57266	: V=0.9799998, theta=-60.819662 -> V=1.0, theta=0.0
% INFO    : Bus 57267	: V=0.9913862, theta=-63.032729 -> V=1.0, theta=0.0
% INFO    : Bus 57268	: V=1.0052517, theta=-61.837886 -> V=1.0, theta=0.0
% INFO    : Bus 57269	: V=1.0087646, theta=-62.492684 -> V=1.0, theta=0.0
% INFO    : Bus 57270	: V=0.9929793, theta=-63.323258 -> V=1.0, theta=0.0
% INFO    : Bus 57271	: V=0.9852325, theta=-62.718191 -> V=1.0, theta=0.0
% INFO    : Bus 57272	: V=0.9927293, theta=-61.361799 -> V=1.0, theta=0.0
% INFO    : Bus 57273	: V=1.0041218, theta=-59.874001 -> V=1.0, theta=0.0
% INFO    : Bus 57274	: V=0.9942737, theta=-59.560903 -> V=1.0, theta=0.0
% INFO    : Bus 57275	: V=1.0164051, theta=-58.440201 -> V=1.0, theta=0.0
% INFO    : Bus 57276	: V=1.0088885, theta=-58.749375 -> V=1.0, theta=0.0
% INFO    : Bus 57277	: V=0.9845497, theta=-60.813279 -> V=1.0, theta=0.0
% INFO    : Bus 57278	: V=0.9785405, theta=-59.560279 -> V=1.0, theta=0.0
% INFO    : Bus 57279	: V=0.958597, theta=-61.49648 -> V=1.0, theta=0.0
% INFO    : Bus 57280	: V=0.9601466, theta=-61.393036 -> V=1.0, theta=0.0
% INFO    : Bus 57281	: V=0.991872, theta=-57.442621 -> V=1.0, theta=0.0
% INFO    : Bus 57282	: V=1.0118706, theta=-67.765854 -> V=1.0, theta=0.0
% INFO    : Bus 57283	: V=1.0196769, theta=-66.824279 -> V=1.0, theta=0.0
% INFO    : Bus 57284	: V=1.0123137, theta=-67.882858 -> V=1.0, theta=0.0
% INFO    : Bus 57285	: V=0.9795546, theta=-70.504227 -> V=1.0, theta=0.0
% INFO    : Bus 57286	: V=1.0124823, theta=-67.810055 -> V=1.0, theta=0.0
% INFO    : Bus 57287	: V=1.012131, theta=-67.816941 -> V=1.0, theta=0.0
% INFO    : Bus 57288	: V=1.0123558, theta=-67.610034 -> V=1.0, theta=0.0
% INFO    : Bus 57289	: V=1.0110575, theta=-67.076454 -> V=1.0, theta=0.0
% INFO    : Bus 57290	: V=1.0095111, theta=-68.148441 -> V=1.0, theta=0.0
% INFO    : Bus 57291	: V=1.0114905, theta=-67.750473 -> V=1.0, theta=0.0
% INFO    : Bus 57292	: V=1.0074409, theta=-68.818426 -> V=1.0, theta=0.0
% INFO    : Bus 57293	: V=0.9910553, theta=-70.079518 -> V=1.0, theta=0.0
% INFO    : Bus 57294	: V=0.9851431, theta=-70.505006 -> V=1.0, theta=0.0
% INFO    : Bus 57295	: V=1.0060827, theta=-69.900829 -> V=1.0, theta=0.0
% INFO    : Bus 57296	: V=1.0046402, theta=-69.85818 -> V=1.0, theta=0.0
% INFO    : Bus 57297	: V=1.0064742, theta=-69.139926 -> V=1.0, theta=0.0
% INFO    : Bus 57298	: V=1.0059494, theta=-69.334386 -> V=1.0, theta=0.0
% INFO    : Bus 57299	: V=1.0050112, theta=-69.800383 -> V=1.0, theta=0.0
% INFO    : Bus 57300	: V=1.0080371, theta=-69.12077 -> V=1.0, theta=0.0
% INFO    : Bus 57301	: V=1.0127391, theta=-68.680392 -> V=1.0, theta=0.0
% INFO    : Bus 57302	: V=1.0195542, theta=-67.180523 -> V=1.0, theta=0.0
% INFO    : Bus 57303	: V=1.0042105, theta=-60.150623 -> V=1.0, theta=0.0
% INFO    : Bus 57304	: V=1.0200666, theta=-58.953307 -> V=1.0, theta=0.0
% INFO    : Bus 57305	: V=1.0184999, theta=-60.375116 -> V=1.0, theta=0.0
% INFO    : Bus 57306	: V=1.0151793, theta=-61.391559 -> V=1.0, theta=0.0
% INFO    : Bus 57307	: V=1.0069986, theta=-62.246937 -> V=1.0, theta=0.0
% INFO    : Bus 57308	: V=1.0130214, theta=-62.066749 -> V=1.0, theta=0.0
% INFO    : Bus 57309	: V=1.0142114, theta=-61.70921 -> V=1.0, theta=0.0
% INFO    : Bus 57310	: V=1.012999, theta=-61.780427 -> V=1.0, theta=0.0
% INFO    : Bus 57311	: V=1.0133286, theta=-61.661652 -> V=1.0, theta=0.0
% INFO    : Bus 57312	: V=0.9516981, theta=-64.591831 -> V=1.0, theta=0.0
% INFO    : Bus 57313	: V=1.0052416, theta=-57.644844 -> V=1.0, theta=0.0
% INFO    : Bus 57314	: V=0.979429, theta=-61.584809 -> V=1.0, theta=0.0
% INFO    : Bus 57315	: V=1.0011663, theta=-58.838462 -> V=1.0, theta=0.0
% INFO    : Bus 57316	: V=1.0026444, theta=-59.927086 -> V=1.0, theta=0.0
% INFO    : Bus 57317	: V=0.982483, theta=-60.418819 -> V=1.0, theta=0.0
% INFO    : Bus 57318	: V=1.0030594, theta=-65.800246 -> V=1.0, theta=0.0
% INFO    : Bus 57319	: V=0.9943463, theta=-66.517097 -> V=1.0, theta=0.0
% INFO    : Bus 57320	: V=1.0042624, theta=-65.124422 -> V=1.0, theta=0.0
% INFO    : Bus 57321	: V=1.0057473, theta=-64.415329 -> V=1.0, theta=0.0
% INFO    : Bus 57322	: V=1.0004461, theta=-67.354107 -> V=1.0, theta=0.0
% INFO    : Bus 57323	: V=0.9949855, theta=-68.715297 -> V=1.0, theta=0.0
% INFO    : Bus 57324	: V=1.0010357, theta=-67.968472 -> V=1.0, theta=0.0
% INFO    : Bus 57325	: V=0.9960775, theta=-68.59153 -> V=1.0, theta=0.0
% INFO    : Bus 57326	: V=0.9981344, theta=-67.884956 -> V=1.0, theta=0.0
% INFO    : Bus 57327	: V=1.0097794, theta=-65.088598 -> V=1.0, theta=0.0
% INFO    : Bus 57328	: V=1.0029778, theta=-67.0071 -> V=1.0, theta=0.0
% INFO    : Bus 57329	: V=1.0100177, theta=-64.238067 -> V=1.0, theta=0.0
% INFO    : Bus 57330	: V=1.0110659, theta=-63.057088 -> V=1.0, theta=0.0
% INFO    : Bus 57331	: V=1.0103232, theta=-63.052538 -> V=1.0, theta=0.0
% INFO    : Bus 57332	: V=1.0053466, theta=-63.726716 -> V=1.0, theta=0.0
% INFO    : Bus 57333	: V=1.000189, theta=-67.197251 -> V=1.0, theta=0.0
% INFO    : Bus 57334	: V=0.9979517, theta=-67.864281 -> V=1.0, theta=0.0
% INFO    : Bus 57335	: V=1.0016631, theta=-66.784199 -> V=1.0, theta=0.0
% INFO    : Bus 57336	: V=0.9954712, theta=-68.649746 -> V=1.0, theta=0.0
% INFO    : Bus 57337	: V=1.0146915, theta=-55.22589 -> V=1.0, theta=0.0
% INFO    : Bus 57338	: V=0.9923045, theta=-57.091734 -> V=1.0, theta=0.0
% INFO    : Bus 57339	: V=1.0207921, theta=-57.483299 -> V=1.0, theta=0.0
% INFO    : Bus 57340	: V=0.948848, theta=-65.659085 -> V=1.0, theta=0.0
% INFO    : Bus 57341	: V=0.9500489, theta=-65.589069 -> V=1.0, theta=0.0
% INFO    : Bus 57342	: V=0.9758481, theta=-63.009019 -> V=1.0, theta=0.0
% INFO    : Bus 57343	: V=0.9642873, theta=-75.015891 -> V=1.0, theta=0.0
% INFO    : Bus 57344	: V=0.9854356, theta=-71.214088 -> V=1.0, theta=0.0
% INFO    : Bus 57345	: V=0.9793352, theta=-72.585873 -> V=1.0, theta=0.0
% INFO    : Bus 57346	: V=0.9808978, theta=-73.188082 -> V=1.0, theta=0.0
% INFO    : Bus 57347	: V=0.9787661, theta=-72.369736 -> V=1.0, theta=0.0
% INFO    : Bus 57348	: V=0.9789194, theta=-72.047995 -> V=1.0, theta=0.0
% INFO    : Bus 57349	: V=0.9781827, theta=-71.622513 -> V=1.0, theta=0.0
% INFO    : Bus 57350	: V=0.979839, theta=-70.976116 -> V=1.0, theta=0.0
% INFO    : Bus 57351	: V=0.993989, theta=-66.685552 -> V=1.0, theta=0.0
% INFO    : Bus 57352	: V=0.9851892, theta=-70.319205 -> V=1.0, theta=0.0
% INFO    : Bus 57353	: V=0.9775017, theta=-59.703991 -> V=1.0, theta=0.0
% INFO    : Bus 57354	: V=0.9774221, theta=-59.698986 -> V=1.0, theta=0.0
% INFO    : Bus 57355	: V=0.9774572, theta=-59.687777 -> V=1.0, theta=0.0
% INFO    : Bus 57356	: V=0.9782699, theta=-59.649274 -> V=1.0, theta=0.0
% INFO    : Bus 57357	: V=0.9816333, theta=-59.400387 -> V=1.0, theta=0.0
% INFO    : Bus 57358	: V=0.9833078, theta=-59.246584 -> V=1.0, theta=0.0
% INFO    : Bus 57359	: V=0.9835734, theta=-59.241778 -> V=1.0, theta=0.0
% INFO    : Bus 57360	: V=0.980833, theta=-59.488663 -> V=1.0, theta=0.0
% INFO    : Bus 57361	: V=0.9773439, theta=-59.69479 -> V=1.0, theta=0.0
% INFO    : Bus 57362	: V=0.9844246, theta=-59.035032 -> V=1.0, theta=0.0
% INFO    : Bus 57363	: V=0.9779994, theta=-59.663172 -> V=1.0, theta=0.0
% INFO    : Bus 57364	: V=0.9765576, theta=-59.70298 -> V=1.0, theta=0.0
% INFO    : Bus 57365	: V=0.9820331, theta=-59.41358 -> V=1.0, theta=0.0
% INFO    : Bus 57366	: V=0.9829698, theta=-59.374051 -> V=1.0, theta=0.0
% INFO    : Bus 57367	: V=0.9983025, theta=-57.919721 -> V=1.0, theta=0.0
% INFO    : Bus 57368	: V=0.9946153, theta=-58.208787 -> V=1.0, theta=0.0
% INFO    : Bus 57369	: V=0.9941402, theta=-58.25116 -> V=1.0, theta=0.0
% INFO    : Bus 57370	: V=0.9797624, theta=-59.565359 -> V=1.0, theta=0.0
% INFO    : Bus 57371	: V=0.979222, theta=-59.515713 -> V=1.0, theta=0.0
% INFO    : Bus 57372	: V=0.992817, theta=-58.446714 -> V=1.0, theta=0.0
% INFO    : Bus 57373	: V=0.9953814, theta=-58.175205 -> V=1.0, theta=0.0
% INFO    : Bus 57374	: V=1.0014679, theta=-57.650066 -> V=1.0, theta=0.0
% INFO    : Bus 57375	: V=0.9692184, theta=-60.89546 -> V=1.0, theta=0.0
% INFO    : Bus 57376	: V=0.9925568, theta=-58.445047 -> V=1.0, theta=0.0
% INFO    : Bus 57377	: V=0.9945553, theta=-58.201623 -> V=1.0, theta=0.0
% INFO    : Bus 57378	: V=0.979966, theta=-59.540899 -> V=1.0, theta=0.0
% INFO    : Bus 57379	: V=0.993155, theta=-58.307626 -> V=1.0, theta=0.0
% INFO    : Bus 57380	: V=0.996959, theta=-58.029044 -> V=1.0, theta=0.0
% INFO    : Bus 57381	: V=0.9962699, theta=-58.096288 -> V=1.0, theta=0.0
% INFO    : Bus 57382	: V=1.0091492, theta=-56.788701 -> V=1.0, theta=0.0
% INFO    : Bus 57383	: V=1.0065158, theta=-57.014159 -> V=1.0, theta=0.0
% INFO    : Bus 57384	: V=0.9928525, theta=-58.325113 -> V=1.0, theta=0.0
% INFO    : Bus 57385	: V=0.9927813, theta=-58.324169 -> V=1.0, theta=0.0
% INFO    : Bus 57386	: V=0.9928843, theta=-58.384049 -> V=1.0, theta=0.0
% INFO    : Bus 57387	: V=0.9594945, theta=-67.126441 -> V=1.0, theta=0.0
% INFO    : Bus 57388	: V=0.9552644, theta=-67.83316 -> V=1.0, theta=0.0
% INFO    : Bus 57389	: V=1.0015199, theta=-62.592589 -> V=1.0, theta=0.0
% INFO    : Bus 57390	: V=0.9999952, theta=-63.919547 -> V=1.0, theta=0.0
% INFO    : Bus 57391	: V=0.9835285, theta=-59.084042 -> V=1.0, theta=0.0
% INFO    : Bus 57392	: V=0.9772733, theta=-59.707806 -> V=1.0, theta=0.0
% INFO    : Bus 57393	: V=0.9774123, theta=-59.690789 -> V=1.0, theta=0.0
% INFO    : Bus 57394	: V=0.9793698, theta=-59.554534 -> V=1.0, theta=0.0
% INFO    : Bus 57395	: V=0.9801257, theta=-59.528456 -> V=1.0, theta=0.0
% INFO    : Bus 57396	: V=0.9836443, theta=-59.243293 -> V=1.0, theta=0.0
% INFO    : Bus 57397	: V=0.9854526, theta=-58.979176 -> V=1.0, theta=0.0
% INFO    : Bus 57398	: V=0.9833388, theta=-59.098205 -> V=1.0, theta=0.0
% INFO    : Bus 57399	: V=0.9780794, theta=-59.665782 -> V=1.0, theta=0.0
% INFO    : Bus 57400	: V=0.9837697, theta=-59.071443 -> V=1.0, theta=0.0
% INFO    : Bus 57401	: V=0.9774949, theta=-59.685282 -> V=1.0, theta=0.0
% INFO    : Bus 57402	: V=0.9834057, theta=-59.09104 -> V=1.0, theta=0.0
% INFO    : Bus 57403	: V=0.9773916, theta=-59.704812 -> V=1.0, theta=0.0
% INFO    : Bus 57404	: V=0.9835276, theta=-59.152573 -> V=1.0, theta=0.0
% INFO    : Bus 57405	: V=0.9833481, theta=-59.093676 -> V=1.0, theta=0.0
% INFO    : Bus 57406	: V=0.9767923, theta=-59.730268 -> V=1.0, theta=0.0
% INFO    : Bus 57407	: V=0.983784, theta=-59.092213 -> V=1.0, theta=0.0
% INFO    : Bus 57408	: V=0.9780389, theta=-59.674684 -> V=1.0, theta=0.0
% INFO    : Bus 57409	: V=0.9833037, theta=-59.153967 -> V=1.0, theta=0.0
% INFO    : Bus 57410	: V=0.9836476, theta=-59.119696 -> V=1.0, theta=0.0
% INFO    : Bus 57411	: V=0.9833436, theta=-59.141815 -> V=1.0, theta=0.0
% INFO    : Bus 57412	: V=0.9803677, theta=-59.566498 -> V=1.0, theta=0.0
% INFO    : Bus 57413	: V=0.9828117, theta=-59.299851 -> V=1.0, theta=0.0
% INFO    : Bus 57414	: V=0.9871184, theta=-58.864344 -> V=1.0, theta=0.0
% INFO    : Bus 57415	: V=0.9761389, theta=-59.945635 -> V=1.0, theta=0.0
% INFO    : Bus 57416	: V=0.9767653, theta=-59.936754 -> V=1.0, theta=0.0
% INFO    : Bus 57417	: V=0.9844044, theta=-59.349769 -> V=1.0, theta=0.0
% INFO    : Bus 57418	: V=0.9842258, theta=-59.089253 -> V=1.0, theta=0.0
% INFO    : Bus 57419	: V=1.0160672, theta=-55.872374 -> V=1.0, theta=0.0
% INFO    : Bus 57420	: V=0.9984421, theta=-55.864619 -> V=1.0, theta=0.0
% INFO    : Bus 57421	: V=0.9496887, theta=-72.619064 -> V=1.0, theta=0.0
% INFO    : Bus 57422	: V=0.985597, theta=-52.874013 -> V=1.0, theta=0.0
% INFO    : Bus 57423	: V=0.9985922, theta=-51.886809 -> V=1.0, theta=0.0
% INFO    : Bus 57424	: V=0.9905886, theta=-54.050786 -> V=1.0, theta=0.0
% INFO    : Bus 57425	: V=1.0047368, theta=-50.192956 -> V=1.0, theta=0.0
% INFO    : Bus 57426	: V=0.9653007, theta=-65.251432 -> V=1.0, theta=0.0
% INFO    : Bus 57427	: V=0.966632, theta=-64.716149 -> V=1.0, theta=0.0
% INFO    : Bus 57428	: V=0.9660767, theta=-64.758896 -> V=1.0, theta=0.0
% INFO    : Bus 57429	: V=0.9658842, theta=-64.7933 -> V=1.0, theta=0.0
% INFO    : Bus 57430	: V=0.9676759, theta=-65.663782 -> V=1.0, theta=0.0
% INFO    : Bus 57431	: V=0.9970489, theta=-61.452027 -> V=1.0, theta=0.0
% INFO    : Bus 57432	: V=0.9931427, theta=-61.292486 -> V=1.0, theta=0.0
% INFO    : Bus 57433	: V=0.9653787, theta=-59.497709 -> V=1.0, theta=0.0
% INFO    : Bus 57434	: V=1.019244, theta=-67.652802 -> V=1.0, theta=0.0
% INFO    : Bus 57435	: V=1.0150159, theta=-67.716763 -> V=1.0, theta=0.0
% INFO    : Bus 57436	: V=1.015286, theta=-68.439531 -> V=1.0, theta=0.0
% INFO    : Bus 57437	: V=0.9873676, theta=-70.220545 -> V=1.0, theta=0.0
% INFO    : Bus 57438	: V=1.0002394, theta=-69.862158 -> V=1.0, theta=0.0
% INFO    : Bus 57439	: V=0.9929644, theta=-71.308173 -> V=1.0, theta=0.0
% INFO    : Bus 57440	: V=0.9922157, theta=-71.432468 -> V=1.0, theta=0.0
% INFO    : Bus 57441	: V=0.9940373, theta=-70.917756 -> V=1.0, theta=0.0
% INFO    : Bus 57442	: V=0.9934606, theta=-71.974809 -> V=1.0, theta=0.0
% INFO    : Bus 57443	: V=0.9989502, theta=-69.748138 -> V=1.0, theta=0.0
% INFO    : Bus 57444	: V=0.9974311, theta=-68.522078 -> V=1.0, theta=0.0
% INFO    : Bus 57445	: V=0.9944284, theta=-70.154342 -> V=1.0, theta=0.0
% INFO    : Bus 57446	: V=0.9954153, theta=-71.357527 -> V=1.0, theta=0.0
% INFO    : Bus 57447	: V=0.9962676, theta=-71.885722 -> V=1.0, theta=0.0
% INFO    : Bus 57448	: V=0.991212, theta=-72.016978 -> V=1.0, theta=0.0
% INFO    : Bus 57449	: V=0.9926353, theta=-72.705771 -> V=1.0, theta=0.0
% INFO    : Bus 57450	: V=0.9716092, theta=-52.7422 -> V=1.0, theta=0.0
% INFO    : Bus 57451	: V=0.970759, theta=-52.748975 -> V=1.0, theta=0.0
% INFO    : Bus 57452	: V=0.9607798, theta=-52.20076 -> V=1.0, theta=0.0
% INFO    : Bus 57453	: V=0.9820828, theta=-50.682741 -> V=1.0, theta=0.0
% INFO    : Bus 57454	: V=1.0153578, theta=-57.128773 -> V=1.0, theta=0.0
% INFO    : Bus 57455	: V=0.9906041, theta=-58.877381 -> V=1.0, theta=0.0
% INFO    : Bus 57456	: V=0.9849625, theta=-60.435456 -> V=1.0, theta=0.0
% INFO    : Bus 57457	: V=0.9884188, theta=-60.480155 -> V=1.0, theta=0.0
% INFO    : Bus 57458	: V=1.0062464, theta=-59.621792 -> V=1.0, theta=0.0
% INFO    : Bus 57459	: V=0.9973564, theta=-59.998286 -> V=1.0, theta=0.0
% INFO    : Bus 57460	: V=1.0187574, theta=-57.774377 -> V=1.0, theta=0.0
% INFO    : Bus 57461	: V=1.0035343, theta=-59.71475 -> V=1.0, theta=0.0
% INFO    : Bus 57462	: V=1.0035492, theta=-59.734206 -> V=1.0, theta=0.0
% INFO    : Bus 57463	: V=0.9984546, theta=-60.097334 -> V=1.0, theta=0.0
% INFO    : Bus 57464	: V=1.0022951, theta=-60.305988 -> V=1.0, theta=0.0
% INFO    : Bus 57465	: V=0.98673, theta=-62.727984 -> V=1.0, theta=0.0
% INFO    : Bus 57466	: V=0.999258, theta=-61.395961 -> V=1.0, theta=0.0
% INFO    : Bus 57467	: V=0.9589232, theta=-66.77627 -> V=1.0, theta=0.0
% INFO    : Bus 57468	: V=0.9650321, theta=-66.977844 -> V=1.0, theta=0.0
% INFO    : Bus 57469	: V=0.9574906, theta=-67.283622 -> V=1.0, theta=0.0
% INFO    : Bus 57470	: V=0.9719275, theta=-65.748565 -> V=1.0, theta=0.0
% INFO    : Bus 57471	: V=0.9704604, theta=-65.553538 -> V=1.0, theta=0.0
% INFO    : Bus 57472	: V=0.9749873, theta=-66.995067 -> V=1.0, theta=0.0
% INFO    : Bus 57473	: V=0.9699983, theta=-74.999508 -> V=1.0, theta=0.0
% INFO    : Bus 57474	: V=0.9799018, theta=-73.629149 -> V=1.0, theta=0.0
% INFO    : Bus 57475	: V=0.9788191, theta=-73.113468 -> V=1.0, theta=0.0
% INFO    : Bus 57476	: V=0.973973, theta=-73.147259 -> V=1.0, theta=0.0
% INFO    : Bus 57477	: V=0.9999592, theta=-58.955964 -> V=1.0, theta=0.0
% INFO    : Bus 57478	: V=1.0016907, theta=-58.911658 -> V=1.0, theta=0.0
% INFO    : Bus 57479	: V=1.0090667, theta=-58.397502 -> V=1.0, theta=0.0
% INFO    : Bus 57480	: V=1.0024384, theta=-59.126724 -> V=1.0, theta=0.0
% INFO    : Bus 57481	: V=1.018657, theta=-57.871626 -> V=1.0, theta=0.0
% INFO    : Bus 57482	: V=1.0124773, theta=-58.14232 -> V=1.0, theta=0.0
% INFO    : Bus 57483	: V=1.0110972, theta=-58.189949 -> V=1.0, theta=0.0
% INFO    : Bus 57484	: V=1.0146541, theta=-58.126786 -> V=1.0, theta=0.0
% INFO    : Bus 57485	: V=1.0176667, theta=-57.862884 -> V=1.0, theta=0.0
% INFO    : Bus 57486	: V=1.0128355, theta=-59.358448 -> V=1.0, theta=0.0
% INFO    : Bus 57487	: V=1.01115, theta=-59.624407 -> V=1.0, theta=0.0
% INFO    : Bus 57488	: V=0.9853275, theta=-64.110526 -> V=1.0, theta=0.0
% INFO    : Bus 57489	: V=1.006423, theta=-60.598129 -> V=1.0, theta=0.0
% INFO    : Bus 57490	: V=0.9918531, theta=-63.851545 -> V=1.0, theta=0.0
% INFO    : Bus 57491	: V=0.9541153, theta=-66.704649 -> V=1.0, theta=0.0
% INFO    : Bus 57492	: V=0.9585285, theta=-66.575847 -> V=1.0, theta=0.0
% INFO    : Bus 57493	: V=0.9661784, theta=-64.427553 -> V=1.0, theta=0.0
% INFO    : Bus 57494	: V=0.971497, theta=-64.880624 -> V=1.0, theta=0.0
% INFO    : Bus 57495	: V=0.9829423, theta=-58.671079 -> V=1.0, theta=0.0
% INFO    : Bus 57496	: V=1.0121589, theta=-49.138387 -> V=1.0, theta=0.0
% INFO    : Bus 57497	: V=1.0197804, theta=-48.249337 -> V=1.0, theta=0.0
% INFO    : Bus 57498	: V=1.0190394, theta=-47.139113 -> V=1.0, theta=0.0
% INFO    : Bus 57499	: V=1.0156603, theta=-46.413021 -> V=1.0, theta=0.0
% INFO    : Bus 57500	: V=1.0198643, theta=-51.870719 -> V=1.0, theta=0.0
% INFO    : Bus 57501	: V=0.9715552, theta=-63.444314 -> V=1.0, theta=0.0
% INFO    : Bus 57502	: V=0.9921343, theta=-62.152678 -> V=1.0, theta=0.0
% INFO    : Bus 57503	: V=0.9708525, theta=-64.009368 -> V=1.0, theta=0.0
% INFO    : Bus 57504	: V=0.9709262, theta=-64.196198 -> V=1.0, theta=0.0
% INFO    : Bus 57505	: V=0.9760776, theta=-64.420441 -> V=1.0, theta=0.0
% INFO    : Bus 57506	: V=0.962328, theta=-65.819618 -> V=1.0, theta=0.0
% INFO    : Bus 57507	: V=0.9964753, theta=-58.024586 -> V=1.0, theta=0.0
% INFO    : Bus 57508	: V=0.9688707, theta=-66.29335 -> V=1.0, theta=0.0
% INFO    : Bus 57509	: V=0.9669922, theta=-66.333703 -> V=1.0, theta=0.0
% INFO    : Bus 57510	: V=0.9758491, theta=-65.21887 -> V=1.0, theta=0.0
% INFO    : Bus 57511	: V=0.9801026, theta=-64.515535 -> V=1.0, theta=0.0
% INFO    : Bus 57512	: V=0.9677154, theta=-66.374905 -> V=1.0, theta=0.0
% INFO    : Bus 57513	: V=0.9766434, theta=-65.213342 -> V=1.0, theta=0.0
% INFO    : Bus 57514	: V=0.98817, theta=-63.618573 -> V=1.0, theta=0.0
% INFO    : Bus 57515	: V=0.966286, theta=-66.517168 -> V=1.0, theta=0.0
% INFO    : Bus 57516	: V=0.9736145, theta=-65.703915 -> V=1.0, theta=0.0
% INFO    : Bus 57517	: V=0.9772314, theta=-65.171838 -> V=1.0, theta=0.0
% INFO    : Bus 57518	: V=0.972324, theta=-65.7764 -> V=1.0, theta=0.0
% INFO    : Bus 57519	: V=0.9713437, theta=-65.916495 -> V=1.0, theta=0.0
% INFO    : Bus 57520	: V=0.9702158, theta=-66.005602 -> V=1.0, theta=0.0
% INFO    : Bus 57521	: V=0.9733301, theta=-65.757932 -> V=1.0, theta=0.0
% INFO    : Bus 57522	: V=0.9721241, theta=-65.791309 -> V=1.0, theta=0.0
% INFO    : Bus 57523	: V=0.9789027, theta=-65.433 -> V=1.0, theta=0.0
% INFO    : Bus 57524	: V=0.978629, theta=-65.053932 -> V=1.0, theta=0.0
% INFO    : Bus 57525	: V=0.9761404, theta=-63.952427 -> V=1.0, theta=0.0
% INFO    : Bus 57526	: V=0.9785217, theta=-63.187063 -> V=1.0, theta=0.0
% INFO    : Bus 57527	: V=0.9783753, theta=-64.915945 -> V=1.0, theta=0.0
% INFO    : Bus 57528	: V=0.9791285, theta=-64.865254 -> V=1.0, theta=0.0
% INFO    : Bus 57529	: V=0.9668387, theta=-66.429873 -> V=1.0, theta=0.0
% INFO    : Bus 57530	: V=0.9770431, theta=-64.087671 -> V=1.0, theta=0.0
% INFO    : Bus 57531	: V=0.9872498, theta=-62.627644 -> V=1.0, theta=0.0
% INFO    : Bus 57532	: V=0.9820401, theta=-64.046888 -> V=1.0, theta=0.0
% INFO    : Bus 57533	: V=0.9715784, theta=-65.819965 -> V=1.0, theta=0.0
% INFO    : Bus 57534	: V=0.9685296, theta=-66.170224 -> V=1.0, theta=0.0
% INFO    : Bus 57535	: V=0.9687046, theta=-66.427438 -> V=1.0, theta=0.0
% INFO    : Bus 57536	: V=0.9687784, theta=-66.637978 -> V=1.0, theta=0.0
% INFO    : Bus 57537	: V=0.9704831, theta=-66.774983 -> V=1.0, theta=0.0
% INFO    : Bus 57538	: V=0.9658892, theta=-66.454829 -> V=1.0, theta=0.0
% INFO    : Bus 57539	: V=0.9706505, theta=-65.947971 -> V=1.0, theta=0.0
% INFO    : Bus 57540	: V=0.9696577, theta=-66.096443 -> V=1.0, theta=0.0
% INFO    : Bus 57541	: V=0.969051, theta=-66.266607 -> V=1.0, theta=0.0
% INFO    : Bus 57542	: V=0.9822234, theta=-64.188215 -> V=1.0, theta=0.0
% INFO    : Bus 57543	: V=0.9676552, theta=-66.650601 -> V=1.0, theta=0.0
% INFO    : Bus 57544	: V=0.983475, theta=-63.790435 -> V=1.0, theta=0.0
% INFO    : Bus 57545	: V=0.9889847, theta=-62.716106 -> V=1.0, theta=0.0
% INFO    : Bus 57546	: V=0.9858211, theta=-63.099488 -> V=1.0, theta=0.0
% INFO    : Bus 57547	: V=0.9840394, theta=-63.706156 -> V=1.0, theta=0.0
% INFO    : Bus 57548	: V=0.9664522, theta=-66.441343 -> V=1.0, theta=0.0
% INFO    : Bus 57549	: V=1.0131509, theta=-63.346947 -> V=1.0, theta=0.0
% INFO    : Bus 57550	: V=1.0037485, theta=-64.461536 -> V=1.0, theta=0.0
% INFO    : Bus 57551	: V=0.985536, theta=-66.118714 -> V=1.0, theta=0.0
% INFO    : Bus 57552	: V=0.9671207, theta=-69.368108 -> V=1.0, theta=0.0
% INFO    : Bus 57553	: V=0.9689414, theta=-69.005987 -> V=1.0, theta=0.0
% INFO    : Bus 57554	: V=0.9711861, theta=-67.893685 -> V=1.0, theta=0.0
% INFO    : Bus 57555	: V=0.9731056, theta=-67.877325 -> V=1.0, theta=0.0
% INFO    : Bus 57556	: V=0.9631466, theta=-68.450885 -> V=1.0, theta=0.0
% INFO    : Bus 57557	: V=0.9941019, theta=-68.839461 -> V=1.0, theta=0.0
% INFO    : Bus 57558	: V=0.9654837, theta=-70.188086 -> V=1.0, theta=0.0
% INFO    : Bus 57559	: V=0.9705464, theta=-69.605019 -> V=1.0, theta=0.0
% INFO    : Bus 57560	: V=0.9816366, theta=-66.414216 -> V=1.0, theta=0.0
% INFO    : Bus 57561	: V=0.9844766, theta=-65.990245 -> V=1.0, theta=0.0
% INFO    : Bus 57562	: V=0.9716925, theta=-68.223349 -> V=1.0, theta=0.0
% INFO    : Bus 57563	: V=0.9711254, theta=-68.504444 -> V=1.0, theta=0.0
% INFO    : Bus 57564	: V=0.9673575, theta=-70.099274 -> V=1.0, theta=0.0
% INFO    : Bus 57565	: V=0.9663773, theta=-70.137242 -> V=1.0, theta=0.0
% INFO    : Bus 57566	: V=0.9986195, theta=-56.985007 -> V=1.0, theta=0.0
% INFO    : Bus 57567	: V=1.0036469, theta=-56.834435 -> V=1.0, theta=0.0
% INFO    : Bus 57568	: V=1.0187242, theta=-55.734656 -> V=1.0, theta=0.0
% INFO    : Bus 57569	: V=1.0204131, theta=-48.159702 -> V=1.0, theta=0.0
% INFO    : Bus 57570	: V=1.0120771, theta=-52.178738 -> V=1.0, theta=0.0
% INFO    : Bus 57571	: V=1.0119319, theta=-58.70039 -> V=1.0, theta=0.0
% INFO    : Bus 57572	: V=0.9956903, theta=-58.702428 -> V=1.0, theta=0.0
% INFO    : Bus 57573	: V=0.9989616, theta=-58.485754 -> V=1.0, theta=0.0
% INFO    : Bus 57574	: V=1.0023385, theta=-58.295531 -> V=1.0, theta=0.0
% INFO    : Bus 57575	: V=0.9800644, theta=-73.005098 -> V=1.0, theta=0.0
% INFO    : Bus 57576	: V=0.9804308, theta=-72.858794 -> V=1.0, theta=0.0
% INFO    : Bus 57577	: V=0.9818958, theta=-72.059144 -> V=1.0, theta=0.0
% INFO    : Bus 57578	: V=0.990522, theta=-70.640845 -> V=1.0, theta=0.0
% INFO    : Bus 57579	: V=0.980238, theta=-72.607595 -> V=1.0, theta=0.0
% INFO    : Bus 57580	: V=0.9839862, theta=-71.789103 -> V=1.0, theta=0.0
% INFO    : Bus 57581	: V=0.9812114, theta=-72.340958 -> V=1.0, theta=0.0
% INFO    : Bus 57582	: V=0.9837049, theta=-71.805946 -> V=1.0, theta=0.0
% INFO    : Bus 57583	: V=0.9763865, theta=-73.009047 -> V=1.0, theta=0.0
% INFO    : Bus 57584	: V=0.9967763, theta=-69.251979 -> V=1.0, theta=0.0
% INFO    : Bus 57585	: V=0.9937914, theta=-69.890416 -> V=1.0, theta=0.0
% INFO    : Bus 57586	: V=0.9919429, theta=-70.293123 -> V=1.0, theta=0.0
% INFO    : Bus 57587	: V=0.9912709, theta=-70.443014 -> V=1.0, theta=0.0
% INFO    : Bus 57588	: V=0.9816012, theta=-73.749203 -> V=1.0, theta=0.0
% INFO    : Bus 57589	: V=0.9684113, theta=-74.544479 -> V=1.0, theta=0.0
% INFO    : Bus 57590	: V=0.9861562, theta=-73.9283 -> V=1.0, theta=0.0
% INFO    : Bus 57591	: V=0.9875176, theta=-73.765388 -> V=1.0, theta=0.0
% INFO    : Bus 57592	: V=0.9837782, theta=-73.772481 -> V=1.0, theta=0.0
% INFO    : Bus 57593	: V=0.9802096, theta=-74.621002 -> V=1.0, theta=0.0
% INFO    : Bus 57594	: V=0.9851568, theta=-73.770251 -> V=1.0, theta=0.0
% INFO    : Bus 57595	: V=0.9770093, theta=-74.972798 -> V=1.0, theta=0.0
% INFO    : Bus 57596	: V=0.9689391, theta=-74.504869 -> V=1.0, theta=0.0
% INFO    : Bus 57597	: V=0.9803238, theta=-72.563284 -> V=1.0, theta=0.0
% INFO    : Bus 57598	: V=0.9928807, theta=-70.086205 -> V=1.0, theta=0.0
% INFO    : Bus 57599	: V=0.9766166, theta=-72.486934 -> V=1.0, theta=0.0
% INFO    : Bus 57600	: V=0.9812815, theta=-72.118636 -> V=1.0, theta=0.0
% INFO    : Bus 57601	: V=0.976699, theta=-72.51589 -> V=1.0, theta=0.0
% INFO    : Bus 57602	: V=0.985274, theta=-71.462983 -> V=1.0, theta=0.0
% INFO    : Bus 57603	: V=0.982467, theta=-71.848925 -> V=1.0, theta=0.0
% INFO    : Bus 57604	: V=0.9767507, theta=-72.8479 -> V=1.0, theta=0.0
% INFO    : Bus 57605	: V=0.9822543, theta=-71.914737 -> V=1.0, theta=0.0
% INFO    : Bus 57606	: V=0.9774958, theta=-72.458731 -> V=1.0, theta=0.0
% INFO    : Bus 57607	: V=0.9807559, theta=-72.313299 -> V=1.0, theta=0.0
% INFO    : Bus 57608	: V=0.9805448, theta=-72.412054 -> V=1.0, theta=0.0
% INFO    : Bus 57609	: V=0.9732677, theta=-73.807442 -> V=1.0, theta=0.0
% INFO    : Bus 57610	: V=0.9843775, theta=-73.59269 -> V=1.0, theta=0.0
% INFO    : Bus 57611	: V=0.9858627, theta=-73.643507 -> V=1.0, theta=0.0
% INFO    : Bus 57612	: V=0.986939, theta=-73.687697 -> V=1.0, theta=0.0
% INFO    : Bus 57613	: V=0.9840293, theta=-73.538469 -> V=1.0, theta=0.0
% INFO    : Bus 57614	: V=0.9849149, theta=-73.594505 -> V=1.0, theta=0.0
% INFO    : Bus 57615	: V=0.9815852, theta=-73.2651 -> V=1.0, theta=0.0
% INFO    : Bus 57616	: V=0.9713174, theta=-73.885269 -> V=1.0, theta=0.0
% INFO    : Bus 57617	: V=0.9795141, theta=-72.5427 -> V=1.0, theta=0.0
% INFO    : Bus 57618	: V=0.9708376, theta=-73.839129 -> V=1.0, theta=0.0
% INFO    : Bus 57619	: V=0.9789854, theta=-72.66634 -> V=1.0, theta=0.0
% INFO    : Bus 57620	: V=0.9784933, theta=-72.790288 -> V=1.0, theta=0.0
% INFO    : Bus 57621	: V=0.9776906, theta=-72.86764 -> V=1.0, theta=0.0
% INFO    : Bus 57622	: V=0.9769416, theta=-72.928427 -> V=1.0, theta=0.0
% INFO    : Bus 57623	: V=0.9713323, theta=-73.938169 -> V=1.0, theta=0.0
% INFO    : Bus 57624	: V=0.968837, theta=-74.62299 -> V=1.0, theta=0.0
% INFO    : Bus 57625	: V=0.9804257, theta=-73.795457 -> V=1.0, theta=0.0
% INFO    : Bus 57626	: V=0.9816907, theta=-73.246125 -> V=1.0, theta=0.0
% INFO    : Bus 57627	: V=0.9818762, theta=-73.217206 -> V=1.0, theta=0.0
% INFO    : Bus 57628	: V=0.9827834, theta=-73.422722 -> V=1.0, theta=0.0
% INFO    : Bus 57629	: V=0.9700669, theta=-73.970276 -> V=1.0, theta=0.0
% INFO    : Bus 57630	: V=0.971362, theta=-73.880669 -> V=1.0, theta=0.0
% INFO    : Bus 57631	: V=0.9709438, theta=-74.027324 -> V=1.0, theta=0.0
% INFO    : Bus 57632	: V=0.9726212, theta=-73.622669 -> V=1.0, theta=0.0
% INFO    : Bus 57633	: V=0.9713089, theta=-73.872823 -> V=1.0, theta=0.0
% INFO    : Bus 57634	: V=0.971663, theta=-73.817009 -> V=1.0, theta=0.0
% INFO    : Bus 57635	: V=0.9797159, theta=-73.20383 -> V=1.0, theta=0.0
% INFO    : Bus 57636	: V=0.9795974, theta=-72.955491 -> V=1.0, theta=0.0
% INFO    : Bus 57637	: V=0.989559, theta=-71.005272 -> V=1.0, theta=0.0
% INFO    : Bus 57638	: V=0.9775989, theta=-73.677363 -> V=1.0, theta=0.0
% INFO    : Bus 57639	: V=0.970173, theta=-74.853267 -> V=1.0, theta=0.0
% INFO    : Bus 57640	: V=0.9842068, theta=-71.488872 -> V=1.0, theta=0.0
% INFO    : Bus 57641	: V=0.9743675, theta=-72.259728 -> V=1.0, theta=0.0
% INFO    : Bus 57642	: V=0.9846409, theta=-71.374444 -> V=1.0, theta=0.0
% INFO    : Bus 57643	: V=0.9844099, theta=-71.421272 -> V=1.0, theta=0.0
% INFO    : Bus 57644	: V=0.9803128, theta=-72.381867 -> V=1.0, theta=0.0
% INFO    : Bus 57645	: V=0.9747438, theta=-73.342426 -> V=1.0, theta=0.0
% INFO    : Bus 57646	: V=0.9820292, theta=-72.019438 -> V=1.0, theta=0.0
% INFO    : Bus 57647	: V=0.9838088, theta=-71.770199 -> V=1.0, theta=0.0
% INFO    : Bus 57648	: V=0.9796011, theta=-72.036097 -> V=1.0, theta=0.0
% INFO    : Bus 57649	: V=0.9693993, theta=-73.227685 -> V=1.0, theta=0.0
% INFO    : Bus 57650	: V=0.9800148, theta=-72.02818 -> V=1.0, theta=0.0
% INFO    : Bus 57651	: V=0.9833174, theta=-71.926795 -> V=1.0, theta=0.0
% INFO    : Bus 57652	: V=0.9821434, theta=-71.937888 -> V=1.0, theta=0.0
% INFO    : Bus 57653	: V=0.9709864, theta=-73.090625 -> V=1.0, theta=0.0
% INFO    : Bus 57654	: V=0.9726531, theta=-73.245832 -> V=1.0, theta=0.0
% INFO    : Bus 57655	: V=0.9684939, theta=-73.278972 -> V=1.0, theta=0.0
% INFO    : Bus 57656	: V=0.981204, theta=-71.981073 -> V=1.0, theta=0.0
% INFO    : Bus 57657	: V=0.9805491, theta=-72.011055 -> V=1.0, theta=0.0
% INFO    : Bus 57658	: V=0.9777091, theta=-72.222782 -> V=1.0, theta=0.0
% INFO    : Bus 57659	: V=0.9783153, theta=-72.150509 -> V=1.0, theta=0.0
% INFO    : Bus 57660	: V=0.9787188, theta=-72.105263 -> V=1.0, theta=0.0
% INFO    : Bus 57661	: V=0.9794926, theta=-72.017097 -> V=1.0, theta=0.0
% INFO    : Bus 57662	: V=0.9711156, theta=-74.023097 -> V=1.0, theta=0.0
% INFO    : Bus 57663	: V=0.971378, theta=-73.972311 -> V=1.0, theta=0.0
% INFO    : Bus 57664	: V=0.9754672, theta=-74.187304 -> V=1.0, theta=0.0
% INFO    : Bus 57665	: V=0.9708882, theta=-74.054247 -> V=1.0, theta=0.0
% INFO    : Bus 57666	: V=0.9923561, theta=-69.499144 -> V=1.0, theta=0.0
% INFO    : Bus 57667	: V=0.9727621, theta=-73.660839 -> V=1.0, theta=0.0
% INFO    : Bus 57668	: V=0.982324, theta=-73.357942 -> V=1.0, theta=0.0
% INFO    : Bus 57669	: V=0.9817187, theta=-73.204144 -> V=1.0, theta=0.0
% INFO    : Bus 57670	: V=0.9801408, theta=-73.834633 -> V=1.0, theta=0.0
% INFO    : Bus 57671	: V=0.9840984, theta=-73.490399 -> V=1.0, theta=0.0
% INFO    : Bus 57672	: V=0.9852825, theta=-73.570235 -> V=1.0, theta=0.0
% INFO    : Bus 57673	: V=0.98245, theta=-73.60206 -> V=1.0, theta=0.0
% INFO    : Bus 57674	: V=0.9773301, theta=-75.198446 -> V=1.0, theta=0.0
% INFO    : Bus 57675	: V=0.9848476, theta=-74.096108 -> V=1.0, theta=0.0
% INFO    : Bus 57676	: V=0.9826726, theta=-73.764284 -> V=1.0, theta=0.0
% INFO    : Bus 57677	: V=0.9798554, theta=-74.613045 -> V=1.0, theta=0.0
% INFO    : Bus 57678	: V=0.9803911, theta=-74.414966 -> V=1.0, theta=0.0
% INFO    : Bus 57679	: V=0.9826236, theta=-74.315773 -> V=1.0, theta=0.0
% INFO    : Bus 57680	: V=0.9834262, theta=-74.281668 -> V=1.0, theta=0.0
% INFO    : Bus 57681	: V=1.0015889, theta=-72.788332 -> V=1.0, theta=0.0
% INFO    : Bus 57682	: V=0.9827467, theta=-74.424146 -> V=1.0, theta=0.0
% INFO    : Bus 57683	: V=0.9776467, theta=-75.200824 -> V=1.0, theta=0.0
% INFO    : Bus 57684	: V=0.9780474, theta=-75.180612 -> V=1.0, theta=0.0
% INFO    : Bus 57685	: V=0.9912428, theta=-72.542131 -> V=1.0, theta=0.0
% INFO    : Bus 57686	: V=0.9735931, theta=-75.256917 -> V=1.0, theta=0.0
% INFO    : Bus 57687	: V=0.9768613, theta=-72.995324 -> V=1.0, theta=0.0
% INFO    : Bus 57688	: V=0.9749481, theta=-73.273768 -> V=1.0, theta=0.0
% INFO    : Bus 57689	: V=0.9884265, theta=-71.851383 -> V=1.0, theta=0.0
% INFO    : Bus 57690	: V=0.9807598, theta=-73.50686 -> V=1.0, theta=0.0
% INFO    : Bus 57691	: V=0.9801972, theta=-73.355182 -> V=1.0, theta=0.0
% INFO    : Bus 57692	: V=0.9782998, theta=-73.781189 -> V=1.0, theta=0.0
% INFO    : Bus 57693	: V=0.9887625, theta=-71.556419 -> V=1.0, theta=0.0
% INFO    : Bus 57694	: V=0.9805083, theta=-73.700544 -> V=1.0, theta=0.0
% INFO    : Bus 57695	: V=0.9717964, theta=-74.677625 -> V=1.0, theta=0.0
% INFO    : Bus 57696	: V=0.9832337, theta=-71.799707 -> V=1.0, theta=0.0
% INFO    : Bus 57697	: V=0.9822985, theta=-72.005649 -> V=1.0, theta=0.0
% INFO    : Bus 57698	: V=0.9804451, theta=-71.931197 -> V=1.0, theta=0.0
% INFO    : Bus 57699	: V=0.983333, theta=-71.611613 -> V=1.0, theta=0.0
% INFO    : Bus 57700	: V=0.9804401, theta=-71.68064 -> V=1.0, theta=0.0
% INFO    : Bus 57701	: V=0.9767606, theta=-72.490602 -> V=1.0, theta=0.0
% INFO    : Bus 57702	: V=0.9833367, theta=-71.6066 -> V=1.0, theta=0.0
% INFO    : Bus 57703	: V=0.9855592, theta=-71.204331 -> V=1.0, theta=0.0
% INFO    : Bus 57704	: V=0.9871089, theta=-70.935705 -> V=1.0, theta=0.0
% INFO    : Bus 57705	: V=0.9852961, theta=-71.198141 -> V=1.0, theta=0.0
% INFO    : Bus 57706	: V=0.9913995, theta=-70.25919 -> V=1.0, theta=0.0
% INFO    : Bus 57707	: V=0.9907323, theta=-70.479215 -> V=1.0, theta=0.0
% INFO    : Bus 57708	: V=0.9773858, theta=-72.44291 -> V=1.0, theta=0.0
% INFO    : Bus 57709	: V=0.984175, theta=-71.813046 -> V=1.0, theta=0.0
% INFO    : Bus 57710	: V=0.9953376, theta=-71.685087 -> V=1.0, theta=0.0
% INFO    : Bus 57711	: V=0.990644, theta=-70.510339 -> V=1.0, theta=0.0
% INFO    : Bus 57712	: V=0.9947088, theta=-71.544126 -> V=1.0, theta=0.0
% INFO    : Bus 57713	: V=0.9718053, theta=-73.977532 -> V=1.0, theta=0.0
% INFO    : Bus 57714	: V=0.9797442, theta=-72.121771 -> V=1.0, theta=0.0
% INFO    : Bus 57715	: V=0.9826324, theta=-70.664282 -> V=1.0, theta=0.0
% INFO    : Bus 57716	: V=0.9818362, theta=-69.088348 -> V=1.0, theta=0.0
% INFO    : Bus 57717	: V=0.9804816, theta=-71.673207 -> V=1.0, theta=0.0
% INFO    : Bus 57718	: V=0.9800317, theta=-71.8773 -> V=1.0, theta=0.0
% INFO    : Bus 57719	: V=0.9727177, theta=-71.941018 -> V=1.0, theta=0.0
% INFO    : Bus 57720	: V=0.9833393, theta=-70.494565 -> V=1.0, theta=0.0
% INFO    : Bus 57721	: V=0.9823943, theta=-70.65362 -> V=1.0, theta=0.0
% INFO    : Bus 57722	: V=0.9857119, theta=-70.153637 -> V=1.0, theta=0.0
% INFO    : Bus 57723	: V=0.9890864, theta=-69.476897 -> V=1.0, theta=0.0
% INFO    : Bus 57724	: V=0.9813154, theta=-73.063085 -> V=1.0, theta=0.0
% INFO    : Bus 57725	: V=0.9815668, theta=-73.068042 -> V=1.0, theta=0.0
% INFO    : Bus 57726	: V=0.9817159, theta=-73.045674 -> V=1.0, theta=0.0
% INFO    : Bus 57727	: V=0.9722725, theta=-73.694859 -> V=1.0, theta=0.0
% INFO    : Bus 57728	: V=0.969426, theta=-73.56855 -> V=1.0, theta=0.0
% INFO    : Bus 57729	: V=0.9762738, theta=-72.358251 -> V=1.0, theta=0.0
% INFO    : Bus 57730	: V=0.9733523, theta=-73.470161 -> V=1.0, theta=0.0
% INFO    : Bus 57731	: V=0.9732805, theta=-74.230272 -> V=1.0, theta=0.0
% INFO    : Bus 57732	: V=0.9725409, theta=-73.829307 -> V=1.0, theta=0.0
% INFO    : Bus 57733	: V=0.9605816, theta=-75.496992 -> V=1.0, theta=0.0
% INFO    : Bus 57734	: V=0.9667631, theta=-75.243544 -> V=1.0, theta=0.0
% INFO    : Bus 57735	: V=0.9719441, theta=-73.881535 -> V=1.0, theta=0.0
% INFO    : Bus 57736	: V=0.9607796, theta=-76.460979 -> V=1.0, theta=0.0
% INFO    : Bus 57737	: V=0.9598514, theta=-76.527698 -> V=1.0, theta=0.0
% INFO    : Bus 57738	: V=0.9716014, theta=-74.075891 -> V=1.0, theta=0.0
% INFO    : Bus 57739	: V=0.9591548, theta=-76.883678 -> V=1.0, theta=0.0
% INFO    : Bus 57740	: V=0.9605431, theta=-76.730009 -> V=1.0, theta=0.0
% INFO    : Bus 57741	: V=0.9736068, theta=-74.094364 -> V=1.0, theta=0.0
% INFO    : Bus 57742	: V=0.9746768, theta=-74.017807 -> V=1.0, theta=0.0
% INFO    : Bus 57743	: V=0.9759061, theta=-73.771954 -> V=1.0, theta=0.0
% INFO    : Bus 57744	: V=0.9733238, theta=-73.966484 -> V=1.0, theta=0.0
% INFO    : Bus 57745	: V=0.9727997, theta=-74.329758 -> V=1.0, theta=0.0
% INFO    : Bus 57746	: V=0.9718381, theta=-74.775765 -> V=1.0, theta=0.0
% INFO    : Bus 57747	: V=0.9731462, theta=-74.221923 -> V=1.0, theta=0.0
% INFO    : Bus 57748	: V=0.9748452, theta=-75.7236 -> V=1.0, theta=0.0
% INFO    : Bus 57749	: V=0.9819205, theta=-74.433156 -> V=1.0, theta=0.0
% INFO    : Bus 57750	: V=0.9638311, theta=-76.942055 -> V=1.0, theta=0.0
% INFO    : Bus 57751	: V=0.9646988, theta=-76.913638 -> V=1.0, theta=0.0
% INFO    : Bus 57752	: V=0.9721388, theta=-74.736697 -> V=1.0, theta=0.0
% INFO    : Bus 57753	: V=0.9679081, theta=-76.769109 -> V=1.0, theta=0.0
% INFO    : Bus 57754	: V=0.9752845, theta=-74.878222 -> V=1.0, theta=0.0
% INFO    : Bus 57755	: V=0.9735262, theta=-74.934998 -> V=1.0, theta=0.0
% INFO    : Bus 57756	: V=0.9764785, theta=-74.825507 -> V=1.0, theta=0.0
% INFO    : Bus 57757	: V=0.9634926, theta=-76.465299 -> V=1.0, theta=0.0
% INFO    : Bus 57758	: V=0.978342, theta=-74.704504 -> V=1.0, theta=0.0
% INFO    : Bus 57759	: V=0.981065, theta=-74.366481 -> V=1.0, theta=0.0
% INFO    : Bus 57760	: V=0.9657037, theta=-76.059652 -> V=1.0, theta=0.0
% INFO    : Bus 57761	: V=0.9712911, theta=-76.023419 -> V=1.0, theta=0.0
% INFO    : Bus 57762	: V=0.9731481, theta=-74.895418 -> V=1.0, theta=0.0
% INFO    : Bus 57763	: V=0.9648797, theta=-76.104715 -> V=1.0, theta=0.0
% INFO    : Bus 57764	: V=0.9728161, theta=-74.774027 -> V=1.0, theta=0.0
% INFO    : Bus 57765	: V=0.9649623, theta=-77.052771 -> V=1.0, theta=0.0
% INFO    : Bus 57766	: V=0.9623203, theta=-77.282001 -> V=1.0, theta=0.0
% INFO    : Bus 57767	: V=0.9614935, theta=-77.331225 -> V=1.0, theta=0.0
% INFO    : Bus 57768	: V=0.9597388, theta=-77.518875 -> V=1.0, theta=0.0
% INFO    : Bus 57769	: V=0.9611082, theta=-76.674004 -> V=1.0, theta=0.0
% INFO    : Bus 57770	: V=0.9601509, theta=-76.729115 -> V=1.0, theta=0.0
% INFO    : Bus 57771	: V=0.9680778, theta=-75.951338 -> V=1.0, theta=0.0
% INFO    : Bus 57772	: V=0.9721567, theta=-74.595975 -> V=1.0, theta=0.0
% INFO    : Bus 57773	: V=0.9723851, theta=-74.457313 -> V=1.0, theta=0.0
% INFO    : Bus 57774	: V=0.9799773, theta=-74.51188 -> V=1.0, theta=0.0
% INFO    : Bus 57775	: V=0.9723016, theta=-75.982425 -> V=1.0, theta=0.0
% INFO    : Bus 57776	: V=0.9589658, theta=-76.907774 -> V=1.0, theta=0.0
% INFO    : Bus 57777	: V=0.9581282, theta=-77.146194 -> V=1.0, theta=0.0
% INFO    : Bus 57778	: V=0.9585337, theta=-77.204323 -> V=1.0, theta=0.0
% INFO    : Bus 57779	: V=0.9724327, theta=-74.345895 -> V=1.0, theta=0.0
% INFO    : Bus 57780	: V=0.9666044, theta=-75.521842 -> V=1.0, theta=0.0
% INFO    : Bus 57781	: V=0.9788116, theta=-74.654641 -> V=1.0, theta=0.0
% INFO    : Bus 57782	: V=0.9719305, theta=-75.771971 -> V=1.0, theta=0.0
% INFO    : Bus 57783	: V=0.9898026, theta=-70.767604 -> V=1.0, theta=0.0
% INFO    : Bus 57784	: V=0.9897459, theta=-70.830433 -> V=1.0, theta=0.0
% INFO    : Bus 57785	: V=0.9779005, theta=-74.764481 -> V=1.0, theta=0.0
% INFO    : Bus 57786	: V=0.9730498, theta=-76.032745 -> V=1.0, theta=0.0
% INFO    : Bus 57787	: V=0.9787809, theta=-74.774668 -> V=1.0, theta=0.0
% INFO    : Bus 57788	: V=0.9795866, theta=-74.679188 -> V=1.0, theta=0.0
% INFO    : Bus 57789	: V=0.9704367, theta=-76.105704 -> V=1.0, theta=0.0
% INFO    : Bus 57790	: V=0.9777768, theta=-74.906333 -> V=1.0, theta=0.0
% INFO    : Bus 57791	: V=0.9780585, theta=-74.864273 -> V=1.0, theta=0.0
% INFO    : Bus 57792	: V=0.9744971, theta=-75.54727 -> V=1.0, theta=0.0
% INFO    : Bus 57793	: V=0.9717984, theta=-76.046054 -> V=1.0, theta=0.0
% INFO    : Bus 57794	: V=0.9714507, theta=-76.110894 -> V=1.0, theta=0.0
% INFO    : Bus 57795	: V=0.9709151, theta=-76.094286 -> V=1.0, theta=0.0
% INFO    : Bus 57796	: V=0.9703085, theta=-76.114993 -> V=1.0, theta=0.0
% INFO    : Bus 57797	: V=0.9793034, theta=-73.871274 -> V=1.0, theta=0.0
% INFO    : Bus 57798	: V=0.9684609, theta=-75.211134 -> V=1.0, theta=0.0
% INFO    : Bus 57799	: V=0.9741729, theta=-74.52749 -> V=1.0, theta=0.0
% INFO    : Bus 57800	: V=0.9791253, theta=-73.857112 -> V=1.0, theta=0.0
% INFO    : Bus 57801	: V=0.9785319, theta=-74.374271 -> V=1.0, theta=0.0
% INFO    : Bus 57802	: V=0.9757931, theta=-74.405656 -> V=1.0, theta=0.0
% INFO    : Bus 57803	: V=0.9754321, theta=-74.480732 -> V=1.0, theta=0.0
% INFO    : Bus 57804	: V=0.9778741, theta=-74.220044 -> V=1.0, theta=0.0
% INFO    : Bus 57805	: V=0.9775557, theta=-74.300341 -> V=1.0, theta=0.0
% INFO    : Bus 57806	: V=0.9747786, theta=-74.615548 -> V=1.0, theta=0.0
% INFO    : Bus 57807	: V=0.9772837, theta=-74.40395 -> V=1.0, theta=0.0
% INFO    : Bus 57808	: V=0.9722027, theta=-75.241266 -> V=1.0, theta=0.0
% INFO    : Bus 57809	: V=0.9795455, theta=-74.237836 -> V=1.0, theta=0.0
% INFO    : Bus 57810	: V=0.9765257, theta=-75.214487 -> V=1.0, theta=0.0
% INFO    : Bus 57811	: V=0.97729, theta=-74.560819 -> V=1.0, theta=0.0
% INFO    : Bus 57812	: V=0.9770076, theta=-74.603365 -> V=1.0, theta=0.0
% INFO    : Bus 57813	: V=0.9784875, theta=-74.461778 -> V=1.0, theta=0.0
% INFO    : Bus 57814	: V=0.9694035, theta=-76.007101 -> V=1.0, theta=0.0
% INFO    : Bus 57815	: V=0.9770891, theta=-74.577751 -> V=1.0, theta=0.0
% INFO    : Bus 57816	: V=0.9627798, theta=-77.421082 -> V=1.0, theta=0.0
% INFO    : Bus 57817	: V=0.9608342, theta=-77.597986 -> V=1.0, theta=0.0
% INFO    : Bus 57818	: V=0.975467, theta=-74.82458 -> V=1.0, theta=0.0
% INFO    : Bus 57819	: V=0.9756116, theta=-74.805061 -> V=1.0, theta=0.0
% INFO    : Bus 57820	: V=0.9640913, theta=-77.155488 -> V=1.0, theta=0.0
% INFO    : Bus 57821	: V=0.9746039, theta=-75.034314 -> V=1.0, theta=0.0
% INFO    : Bus 57822	: V=0.9614222, theta=-77.534815 -> V=1.0, theta=0.0
% INFO    : Bus 57823	: V=0.9608009, theta=-77.588961 -> V=1.0, theta=0.0
% INFO    : Bus 57824	: V=0.9606346, theta=-77.60791 -> V=1.0, theta=0.0
% INFO    : Bus 57825	: V=0.9586951, theta=-77.758682 -> V=1.0, theta=0.0
% INFO    : Bus 57826	: V=0.9578301, theta=-77.812584 -> V=1.0, theta=0.0
% INFO    : Bus 57827	: V=0.9704898, theta=-75.838701 -> V=1.0, theta=0.0
% INFO    : Bus 57828	: V=0.9676865, theta=-75.666774 -> V=1.0, theta=0.0
% INFO    : Bus 57829	: V=0.9744834, theta=-74.688105 -> V=1.0, theta=0.0
% INFO    : Bus 57830	: V=0.9743153, theta=-74.741379 -> V=1.0, theta=0.0
% INFO    : Bus 57831	: V=0.976564, theta=-74.645806 -> V=1.0, theta=0.0
% INFO    : Bus 57832	: V=0.9753884, theta=-74.80236 -> V=1.0, theta=0.0
% INFO    : Bus 57833	: V=0.9696791, theta=-75.989593 -> V=1.0, theta=0.0
% INFO    : Bus 57834	: V=0.9675622, theta=-75.897852 -> V=1.0, theta=0.0
% INFO    : Bus 57835	: V=0.9689062, theta=-75.749235 -> V=1.0, theta=0.0
% INFO    : Bus 57836	: V=0.9694691, theta=-75.733752 -> V=1.0, theta=0.0
% INFO    : Bus 57837	: V=0.9667477, theta=-76.383666 -> V=1.0, theta=0.0
% INFO    : Bus 57838	: V=0.9672676, theta=-76.369141 -> V=1.0, theta=0.0
% INFO    : Bus 57839	: V=0.971079, theta=-75.488451 -> V=1.0, theta=0.0
% INFO    : Bus 57840	: V=0.9746077, theta=-74.853478 -> V=1.0, theta=0.0
% INFO    : Bus 57841	: V=0.9756615, theta=-74.75323 -> V=1.0, theta=0.0
% INFO    : Bus 57842	: V=0.9674812, theta=-76.331968 -> V=1.0, theta=0.0
% INFO    : Bus 57843	: V=0.9678001, theta=-75.84927 -> V=1.0, theta=0.0
% INFO    : Bus 57844	: V=0.967126, theta=-75.906548 -> V=1.0, theta=0.0
% INFO    : Bus 57845	: V=0.9660365, theta=-75.954994 -> V=1.0, theta=0.0
% INFO    : Bus 57846	: V=0.9668777, theta=-75.917503 -> V=1.0, theta=0.0
% INFO    : Bus 57847	: V=0.9693961, theta=-75.372538 -> V=1.0, theta=0.0
% INFO    : Bus 57848	: V=0.9859692, theta=-72.77838 -> V=1.0, theta=0.0
% INFO    : Bus 57849	: V=0.966238, theta=-75.888888 -> V=1.0, theta=0.0
% INFO    : Bus 57850	: V=0.9575083, theta=-77.82853 -> V=1.0, theta=0.0
% INFO    : Bus 57851	: V=0.9669665, theta=-75.854137 -> V=1.0, theta=0.0
% INFO    : Bus 57852	: V=0.9677496, theta=-75.832237 -> V=1.0, theta=0.0
% INFO    : Bus 57853	: V=0.9756535, theta=-74.336896 -> V=1.0, theta=0.0
% INFO    : Bus 57854	: V=0.9765686, theta=-74.288068 -> V=1.0, theta=0.0
% INFO    : Bus 57855	: V=0.97729, theta=-74.144128 -> V=1.0, theta=0.0
% INFO    : Bus 57856	: V=0.9784503, theta=-74.061218 -> V=1.0, theta=0.0
% INFO    : Bus 57857	: V=0.9795844, theta=-73.86732 -> V=1.0, theta=0.0
% INFO    : Bus 57858	: V=0.9683014, theta=-75.141709 -> V=1.0, theta=0.0
% INFO    : Bus 57859	: V=0.9679493, theta=-75.201063 -> V=1.0, theta=0.0
% INFO    : Bus 57860	: V=0.9732283, theta=-74.605976 -> V=1.0, theta=0.0
% INFO    : Bus 57861	: V=0.968763, theta=-75.409983 -> V=1.0, theta=0.0
% INFO    : Bus 57862	: V=0.9680694, theta=-75.117756 -> V=1.0, theta=0.0
% INFO    : Bus 57863	: V=0.9666676, theta=-75.63056 -> V=1.0, theta=0.0
% INFO    : Bus 57864	: V=0.9653795, theta=-75.685388 -> V=1.0, theta=0.0
% INFO    : Bus 57865	: V=0.9726116, theta=-74.649735 -> V=1.0, theta=0.0
% INFO    : Bus 57866	: V=0.9727565, theta=-74.832262 -> V=1.0, theta=0.0
% INFO    : Bus 57867	: V=0.9660392, theta=-75.247215 -> V=1.0, theta=0.0
% INFO    : Bus 57868	: V=0.9724665, theta=-74.203357 -> V=1.0, theta=0.0
% INFO    : Bus 57869	: V=0.9724918, theta=-74.480376 -> V=1.0, theta=0.0
% INFO    : Bus 57870	: V=0.9773017, theta=-73.845685 -> V=1.0, theta=0.0
% INFO    : Bus 57871	: V=0.9771677, theta=-74.025701 -> V=1.0, theta=0.0
% INFO    : Bus 57872	: V=0.9771285, theta=-73.949717 -> V=1.0, theta=0.0
% INFO    : Bus 57873	: V=0.9757238, theta=-73.843705 -> V=1.0, theta=0.0
% INFO    : Bus 57874	: V=0.9698982, theta=-74.972194 -> V=1.0, theta=0.0
% INFO    : Bus 57875	: V=0.9733745, theta=-73.732851 -> V=1.0, theta=0.0
% INFO    : Bus 57876	: V=0.9754841, theta=-73.21866 -> V=1.0, theta=0.0
% INFO    : Bus 57877	: V=0.9713085, theta=-74.820931 -> V=1.0, theta=0.0
% INFO    : Bus 57878	: V=0.9721575, theta=-74.79762 -> V=1.0, theta=0.0
% INFO    : Bus 57879	: V=0.9715066, theta=-74.815611 -> V=1.0, theta=0.0
% INFO    : Bus 57880	: V=0.9775341, theta=-72.69962 -> V=1.0, theta=0.0
% INFO    : Bus 57881	: V=0.9602465, theta=-75.504342 -> V=1.0, theta=0.0
% INFO    : Bus 57882	: V=0.971817, theta=-73.754201 -> V=1.0, theta=0.0
% INFO    : Bus 57883	: V=0.963429, theta=-75.228422 -> V=1.0, theta=0.0
% INFO    : Bus 57884	: V=0.9784023, theta=-72.958163 -> V=1.0, theta=0.0
% INFO    : Bus 57885	: V=0.9763138, theta=-72.796277 -> V=1.0, theta=0.0
% INFO    : Bus 57886	: V=0.9796474, theta=-72.576915 -> V=1.0, theta=0.0
% INFO    : Bus 57887	: V=0.9827826, theta=-71.853941 -> V=1.0, theta=0.0
% INFO    : Bus 57888	: V=0.9806817, theta=-72.300603 -> V=1.0, theta=0.0
% INFO    : Bus 57889	: V=0.989402, theta=-70.949889 -> V=1.0, theta=0.0
% INFO    : Bus 57890	: V=0.982586, theta=-71.620219 -> V=1.0, theta=0.0
% INFO    : Bus 57891	: V=1.005376, theta=-68.970881 -> V=1.0, theta=0.0
% INFO    : Bus 57892	: V=0.9927193, theta=-69.435755 -> V=1.0, theta=0.0
% INFO    : Bus 57893	: V=0.9937873, theta=-69.734151 -> V=1.0, theta=0.0
% INFO    : Bus 57894	: V=0.9940898, theta=-69.429995 -> V=1.0, theta=0.0
% INFO    : Bus 57895	: V=0.9848379, theta=-70.899445 -> V=1.0, theta=0.0
% INFO    : Bus 57896	: V=0.9820246, theta=-71.274867 -> V=1.0, theta=0.0
% INFO    : Bus 57897	: V=0.9819846, theta=-74.541568 -> V=1.0, theta=0.0
% INFO    : Bus 57898	: V=0.9807555, theta=-74.660112 -> V=1.0, theta=0.0
% INFO    : Bus 57899	: V=0.9800996, theta=-74.723231 -> V=1.0, theta=0.0
% INFO    : Bus 57900	: V=0.9827658, theta=-74.331507 -> V=1.0, theta=0.0
% INFO    : Bus 57901	: V=0.9819534, theta=-74.255898 -> V=1.0, theta=0.0
% INFO    : Bus 57902	: V=0.9827694, theta=-73.866558 -> V=1.0, theta=0.0
% INFO    : Bus 57903	: V=0.9760376, theta=-74.693949 -> V=1.0, theta=0.0
% INFO    : Bus 57904	: V=0.9756583, theta=-74.777953 -> V=1.0, theta=0.0
% INFO    : Bus 57905	: V=0.9783134, theta=-74.886566 -> V=1.0, theta=0.0
% INFO    : Bus 57906	: V=0.9793523, theta=-74.792208 -> V=1.0, theta=0.0
% INFO    : Bus 57907	: V=0.9789339, theta=-74.823696 -> V=1.0, theta=0.0
% INFO    : Bus 57908	: V=0.9713661, theta=-76.412498 -> V=1.0, theta=0.0
% INFO    : Bus 57909	: V=0.9705568, theta=-76.485696 -> V=1.0, theta=0.0
% INFO    : Bus 57910	: V=0.9698261, theta=-76.544261 -> V=1.0, theta=0.0
% INFO    : Bus 57911	: V=0.9709958, theta=-76.382877 -> V=1.0, theta=0.0
% INFO    : Bus 57912	: V=0.9722478, theta=-76.205006 -> V=1.0, theta=0.0
% INFO    : Bus 57913	: V=0.9734541, theta=-76.009179 -> V=1.0, theta=0.0
% INFO    : Bus 57914	: V=0.9903907, theta=-73.210093 -> V=1.0, theta=0.0
% INFO    : Bus 57915	: V=0.972538, theta=-75.818735 -> V=1.0, theta=0.0
% INFO    : Bus 57916	: V=0.9731457, theta=-75.794189 -> V=1.0, theta=0.0
% INFO    : Bus 57917	: V=0.9776651, theta=-74.745431 -> V=1.0, theta=0.0
% INFO    : Bus 57918	: V=0.9750983, theta=-75.370791 -> V=1.0, theta=0.0
% INFO    : Bus 57919	: V=0.9794745, theta=-74.647801 -> V=1.0, theta=0.0
% INFO    : Bus 57920	: V=0.9780998, theta=-74.731448 -> V=1.0, theta=0.0
% INFO    : Bus 57921	: V=0.9775151, theta=-74.764539 -> V=1.0, theta=0.0
% INFO    : Bus 57922	: V=0.9769297, theta=-74.804811 -> V=1.0, theta=0.0
% INFO    : Bus 57923	: V=0.976068, theta=-74.857572 -> V=1.0, theta=0.0
% INFO    : Bus 57924	: V=0.9823883, theta=-71.767274 -> V=1.0, theta=0.0
% INFO    : Bus 57925	: V=0.9803827, theta=-73.061836 -> V=1.0, theta=0.0
% INFO    : Bus 57926	: V=0.9810412, theta=-72.545642 -> V=1.0, theta=0.0
% INFO    : Bus 57927	: V=0.9802688, theta=-72.590657 -> V=1.0, theta=0.0
% INFO    : Bus 57928	: V=0.9795501, theta=-72.774629 -> V=1.0, theta=0.0
% INFO    : Bus 57929	: V=0.9708158, theta=-74.485088 -> V=1.0, theta=0.0
% INFO    : Bus 57930	: V=0.9793615, theta=-72.84672 -> V=1.0, theta=0.0
% INFO    : Bus 57931	: V=0.9613133, theta=-76.344132 -> V=1.0, theta=0.0
% INFO    : Bus 57932	: V=1.0170803, theta=-48.065405 -> V=1.0, theta=0.0
% INFO    : Bus 57933	: V=1.0167656, theta=-47.886298 -> V=1.0, theta=0.0
% INFO    : Bus 57934	: V=1.016632, theta=-47.766434 -> V=1.0, theta=0.0
% INFO    : Bus 57935	: V=1.0114413, theta=-48.209885 -> V=1.0, theta=0.0
% INFO    : Bus 57936	: V=1.0165283, theta=-47.666347 -> V=1.0, theta=0.0
% INFO    : Bus 57937	: V=1.0164824, theta=-47.610627 -> V=1.0, theta=0.0
% INFO    : Bus 57938	: V=1.0130647, theta=-47.846398 -> V=1.0, theta=0.0
% INFO    : Bus 57939	: V=1.0100248, theta=-48.259299 -> V=1.0, theta=0.0
% INFO    : Bus 57940	: V=1.0168008, theta=-48.024186 -> V=1.0, theta=0.0
% INFO    : Bus 57941	: V=1.0166181, theta=-47.842085 -> V=1.0, theta=0.0
% INFO    : Bus 57942	: V=1.0131481, theta=-47.750745 -> V=1.0, theta=0.0
% INFO    : Bus 57943	: V=1.0050155, theta=-48.486005 -> V=1.0, theta=0.0
% INFO    : Bus 57944	: V=1.0163855, theta=-47.438754 -> V=1.0, theta=0.0
% INFO    : Bus 57945	: V=1.0135298, theta=-47.552316 -> V=1.0, theta=0.0
% INFO    : Bus 57946	: V=1.0165357, theta=-47.632711 -> V=1.0, theta=0.0
% INFO    : Bus 57947	: V=1.0098016, theta=-48.265035 -> V=1.0, theta=0.0
% INFO    : Bus 57948	: V=1.0091481, theta=-48.273444 -> V=1.0, theta=0.0
% INFO    : Bus 57949	: V=1.0107816, theta=-48.182192 -> V=1.0, theta=0.0
% INFO    : Bus 57950	: V=1.0107084, theta=-48.134936 -> V=1.0, theta=0.0
% INFO    : Bus 57951	: V=1.0104978, theta=-47.995838 -> V=1.0, theta=0.0
% INFO    : Bus 57952	: V=1.0164899, theta=-47.512174 -> V=1.0, theta=0.0
% INFO    : Bus 57953	: V=1.010379, theta=-47.849458 -> V=1.0, theta=0.0
% INFO    : Bus 57954	: V=1.0164468, theta=-47.403966 -> V=1.0, theta=0.0
% INFO    : Bus 57955	: V=1.0164835, theta=-47.313725 -> V=1.0, theta=0.0
% INFO    : Bus 57956	: V=1.0109481, theta=-47.701856 -> V=1.0, theta=0.0
% INFO    : Bus 57957	: V=1.0117729, theta=-47.559138 -> V=1.0, theta=0.0
% INFO    : Bus 57958	: V=1.0119475, theta=-47.428915 -> V=1.0, theta=0.0
% INFO    : Bus 57959	: V=1.0167557, theta=-46.845373 -> V=1.0, theta=0.0
% INFO    : Bus 57960	: V=1.0169678, theta=-46.689563 -> V=1.0, theta=0.0
% INFO    : Bus 57961	: V=1.0129204, theta=-47.175413 -> V=1.0, theta=0.0
% INFO    : Bus 57962	: V=0.9954901, theta=-49.023336 -> V=1.0, theta=0.0
% INFO    : Bus 57963	: V=1.0174491, theta=-48.278918 -> V=1.0, theta=0.0
% INFO    : Bus 57964	: V=1.0165515, theta=-46.990053 -> V=1.0, theta=0.0
% INFO    : Bus 57965	: V=1.0027875, theta=-47.573111 -> V=1.0, theta=0.0
% INFO    : Bus 57966	: V=1.0097535, theta=-48.715357 -> V=1.0, theta=0.0
% INFO    : Bus 57967	: V=1.0008034, theta=-45.001237 -> V=1.0, theta=0.0
% INFO    : Bus 57968	: V=1.0189011, theta=-45.679881 -> V=1.0, theta=0.0
% INFO    : Bus 57969	: V=1.0102951, theta=-48.403997 -> V=1.0, theta=0.0
% INFO    : Bus 57970	: V=1.0151235, theta=-59.33675 -> V=1.0, theta=0.0
% INFO    : Bus 57971	: V=0.95174, theta=-60.812663 -> V=1.0, theta=0.0
% INFO    : Bus 57972	: V=0.9544195, theta=-60.649331 -> V=1.0, theta=0.0
% INFO    : Bus 57973	: V=0.9561815, theta=-60.451317 -> V=1.0, theta=0.0
% INFO    : Bus 57974	: V=0.985089, theta=-54.595846 -> V=1.0, theta=0.0
% INFO    : Bus 57975	: V=0.9904115, theta=-55.369715 -> V=1.0, theta=0.0
% INFO    : Bus 57976	: V=1.0084976, theta=-55.876106 -> V=1.0, theta=0.0
% INFO    : Bus 57977	: V=1.0058401, theta=-55.320639 -> V=1.0, theta=0.0
% INFO    : Bus 57978	: V=1.0106775, theta=-54.95862 -> V=1.0, theta=0.0
% INFO    : Bus 57979	: V=1.0077592, theta=-55.420175 -> V=1.0, theta=0.0
% INFO    : Bus 57980	: V=0.9920879, theta=-56.857187 -> V=1.0, theta=0.0
% INFO    : Bus 57981	: V=0.9923383, theta=-56.769692 -> V=1.0, theta=0.0
% INFO    : Bus 57982	: V=0.993088, theta=-56.767866 -> V=1.0, theta=0.0
% INFO    : Bus 57983	: V=0.9705277, theta=-57.443885 -> V=1.0, theta=0.0
% INFO    : Bus 57984	: V=0.9688843, theta=-57.721072 -> V=1.0, theta=0.0
% INFO    : Bus 57985	: V=0.9695013, theta=-57.722508 -> V=1.0, theta=0.0
% INFO    : Bus 57986	: V=0.969071, theta=-57.726312 -> V=1.0, theta=0.0
% INFO    : Bus 57987	: V=0.9679193, theta=-58.202902 -> V=1.0, theta=0.0
% INFO    : Bus 57988	: V=0.9563566, theta=-59.760347 -> V=1.0, theta=0.0
% INFO    : Bus 57989	: V=0.9597157, theta=-59.483456 -> V=1.0, theta=0.0
% INFO    : Bus 57990	: V=0.9610935, theta=-59.27034 -> V=1.0, theta=0.0
% INFO    : Bus 57991	: V=0.967807, theta=-57.844806 -> V=1.0, theta=0.0
% INFO    : Bus 57992	: V=0.9598179, theta=-58.816247 -> V=1.0, theta=0.0
% INFO    : Bus 57993	: V=0.9639987, theta=-58.635234 -> V=1.0, theta=0.0
% INFO    : Bus 57994	: V=0.9636746, theta=-58.56944 -> V=1.0, theta=0.0
% INFO    : Bus 57995	: V=0.9671151, theta=-57.905393 -> V=1.0, theta=0.0
% INFO    : Bus 57996	: V=0.9604264, theta=-58.855618 -> V=1.0, theta=0.0
% INFO    : Bus 57997	: V=0.9671115, theta=-57.910233 -> V=1.0, theta=0.0
% INFO    : Bus 57998	: V=0.9617603, theta=-59.034995 -> V=1.0, theta=0.0
% INFO    : Bus 57999	: V=0.957757, theta=-59.690769 -> V=1.0, theta=0.0
% INFO    : Bus 58000	: V=0.9667416, theta=-59.387981 -> V=1.0, theta=0.0
% INFO    : Bus 58001	: V=0.976619, theta=-56.291109 -> V=1.0, theta=0.0
% INFO    : Bus 58002	: V=0.972475, theta=-57.450489 -> V=1.0, theta=0.0
% INFO    : Bus 58003	: V=0.9672929, theta=-57.898145 -> V=1.0, theta=0.0
% INFO    : Bus 58004	: V=0.9678434, theta=-57.85223 -> V=1.0, theta=0.0
% INFO    : Bus 58005	: V=0.9579802, theta=-59.032128 -> V=1.0, theta=0.0
% INFO    : Bus 58006	: V=0.9683948, theta=-57.795178 -> V=1.0, theta=0.0
% INFO    : Bus 58007	: V=0.9583333, theta=-58.964256 -> V=1.0, theta=0.0
% INFO    : Bus 58008	: V=0.9869348, theta=-71.469013 -> V=1.0, theta=0.0
% INFO    : Bus 58009	: V=0.9814349, theta=-71.863462 -> V=1.0, theta=0.0
% INFO    : Bus 58010	: V=0.9888933, theta=-71.345672 -> V=1.0, theta=0.0
% INFO    : Bus 58011	: V=0.9885855, theta=-71.397182 -> V=1.0, theta=0.0
% INFO    : Bus 58012	: V=0.9888027, theta=-71.199323 -> V=1.0, theta=0.0
% INFO    : Bus 58013	: V=0.9830942, theta=-71.796721 -> V=1.0, theta=0.0
% INFO    : Bus 58014	: V=0.9905727, theta=-71.277372 -> V=1.0, theta=0.0
% INFO    : Bus 58015	: V=0.9922868, theta=-70.763332 -> V=1.0, theta=0.0
% INFO    : Bus 58016	: V=0.9893377, theta=-71.283668 -> V=1.0, theta=0.0
% INFO    : Bus 58017	: V=0.9935492, theta=-70.74404 -> V=1.0, theta=0.0
% INFO    : Bus 58018	: V=0.9878537, theta=-71.310911 -> V=1.0, theta=0.0
% INFO    : Bus 58019	: V=0.9917924, theta=-71.290249 -> V=1.0, theta=0.0
% INFO    : Bus 58020	: V=0.9914446, theta=-71.25786 -> V=1.0, theta=0.0
% INFO    : Bus 58021	: V=0.9915539, theta=-71.290012 -> V=1.0, theta=0.0
% INFO    : Bus 58022	: V=0.9919323, theta=-71.32772 -> V=1.0, theta=0.0
% INFO    : Bus 58023	: V=0.9895801, theta=-71.412264 -> V=1.0, theta=0.0
% INFO    : Bus 58024	: V=0.9744831, theta=-72.79279 -> V=1.0, theta=0.0
% INFO    : Bus 58025	: V=0.9845067, theta=-72.125751 -> V=1.0, theta=0.0
% INFO    : Bus 58026	: V=0.9930133, theta=-70.872907 -> V=1.0, theta=0.0
% INFO    : Bus 58027	: V=0.9897788, theta=-71.091259 -> V=1.0, theta=0.0
% INFO    : Bus 58028	: V=0.991265, theta=-71.318194 -> V=1.0, theta=0.0
% INFO    : Bus 58029	: V=0.9910402, theta=-71.330212 -> V=1.0, theta=0.0
% INFO    : Bus 58030	: V=0.9909156, theta=-71.336708 -> V=1.0, theta=0.0
% INFO    : Bus 58031	: V=0.9907898, theta=-71.150403 -> V=1.0, theta=0.0
% INFO    : Bus 58032	: V=0.9811929, theta=-72.164154 -> V=1.0, theta=0.0
% INFO    : Bus 58033	: V=0.9808413, theta=-72.476429 -> V=1.0, theta=0.0
% INFO    : Bus 58034	: V=0.9866665, theta=-71.540085 -> V=1.0, theta=0.0
% INFO    : Bus 58035	: V=0.9853188, theta=-71.560361 -> V=1.0, theta=0.0
% INFO    : Bus 58036	: V=0.9653391, theta=-73.05456 -> V=1.0, theta=0.0
% INFO    : Bus 58037	: V=0.9861252, theta=-71.496608 -> V=1.0, theta=0.0
% INFO    : Bus 58038	: V=0.9676578, theta=-72.939605 -> V=1.0, theta=0.0
% INFO    : Bus 58039	: V=0.970312, theta=-72.756868 -> V=1.0, theta=0.0
% INFO    : Bus 58040	: V=0.9749666, theta=-72.460318 -> V=1.0, theta=0.0
% INFO    : Bus 58041	: V=0.9756172, theta=-72.418054 -> V=1.0, theta=0.0
% INFO    : Bus 58042	: V=0.97637, theta=-72.333523 -> V=1.0, theta=0.0
% INFO    : Bus 58043	: V=0.9852416, theta=-71.537192 -> V=1.0, theta=0.0
% INFO    : Bus 58044	: V=0.9907098, theta=-71.028077 -> V=1.0, theta=0.0
% INFO    : Bus 58045	: V=0.9859234, theta=-71.265598 -> V=1.0, theta=0.0
% INFO    : Bus 58046	: V=0.9873178, theta=-71.236331 -> V=1.0, theta=0.0
% INFO    : Bus 58047	: V=0.9688394, theta=-73.145945 -> V=1.0, theta=0.0
% INFO    : Bus 58048	: V=0.9745566, theta=-72.836876 -> V=1.0, theta=0.0
% INFO    : Bus 58049	: V=0.9707119, theta=-73.061873 -> V=1.0, theta=0.0
% INFO    : Bus 58050	: V=0.9752927, theta=-72.719723 -> V=1.0, theta=0.0
% INFO    : Bus 58051	: V=0.9728008, theta=-72.93823 -> V=1.0, theta=0.0
% INFO    : Bus 58052	: V=0.9599614, theta=-73.090462 -> V=1.0, theta=0.0
% INFO    : Bus 58053	: V=0.9627884, theta=-72.956927 -> V=1.0, theta=0.0
% INFO    : Bus 58054	: V=0.9623626, theta=-73.048224 -> V=1.0, theta=0.0
% INFO    : Bus 58055	: V=0.9635767, theta=-73.153685 -> V=1.0, theta=0.0
% INFO    : Bus 58056	: V=0.9620851, theta=-73.219926 -> V=1.0, theta=0.0
% INFO    : Bus 58057	: V=0.9668279, theta=-72.563836 -> V=1.0, theta=0.0
% INFO    : Bus 58058	: V=0.9585588, theta=-72.848325 -> V=1.0, theta=0.0
% INFO    : Bus 58059	: V=0.9644268, theta=-73.088557 -> V=1.0, theta=0.0
% INFO    : Bus 58060	: V=0.9788239, theta=-71.884762 -> V=1.0, theta=0.0
% INFO    : Bus 58061	: V=0.9620788, theta=-72.85104 -> V=1.0, theta=0.0
% INFO    : Bus 58062	: V=0.959416, theta=-73.303818 -> V=1.0, theta=0.0
% INFO    : Bus 58063	: V=0.9581288, theta=-73.392995 -> V=1.0, theta=0.0
% INFO    : Bus 58064	: V=0.9601398, theta=-73.169499 -> V=1.0, theta=0.0
% INFO    : Bus 58065	: V=0.9696502, theta=-72.226435 -> V=1.0, theta=0.0
% INFO    : Bus 58066	: V=0.9590005, theta=-73.358715 -> V=1.0, theta=0.0
% INFO    : Bus 58067	: V=0.9554452, theta=-73.500221 -> V=1.0, theta=0.0
% INFO    : Bus 58068	: V=0.9495364, theta=-75.257035 -> V=1.0, theta=0.0
% INFO    : Bus 58069	: V=0.9507874, theta=-75.186165 -> V=1.0, theta=0.0
% INFO    : Bus 58070	: V=1.0002471, theta=-68.664785 -> V=1.0, theta=0.0
% INFO    : Bus 58071	: V=0.956985, theta=-73.426242 -> V=1.0, theta=0.0
% INFO    : Bus 58072	: V=0.9585329, theta=-73.350608 -> V=1.0, theta=0.0
% INFO    : Bus 58073	: V=0.9553879, theta=-73.487292 -> V=1.0, theta=0.0
% INFO    : Bus 58074	: V=0.9593947, theta=-73.385976 -> V=1.0, theta=0.0
% INFO    : Bus 58075	: V=0.9768354, theta=-72.010989 -> V=1.0, theta=0.0
% INFO    : Bus 58076	: V=0.9643873, theta=-73.115472 -> V=1.0, theta=0.0
% INFO    : Bus 58077	: V=0.9650175, theta=-73.109083 -> V=1.0, theta=0.0
% INFO    : Bus 58078	: V=0.9639437, theta=-72.806259 -> V=1.0, theta=0.0
% INFO    : Bus 58079	: V=1.0016115, theta=-68.628098 -> V=1.0, theta=0.0
% INFO    : Bus 58080	: V=0.9609391, theta=-72.80332 -> V=1.0, theta=0.0
% INFO    : Bus 58081	: V=0.9597464, theta=-72.836093 -> V=1.0, theta=0.0
% INFO    : Bus 58082	: V=0.9615602, theta=-72.841115 -> V=1.0, theta=0.0
% INFO    : Bus 58083	: V=0.9622415, theta=-73.042139 -> V=1.0, theta=0.0
% INFO    : Bus 58084	: V=0.9592379, theta=-73.818244 -> V=1.0, theta=0.0
% INFO    : Bus 58085	: V=0.9497182, theta=-75.070656 -> V=1.0, theta=0.0
% INFO    : Bus 58086	: V=0.9526881, theta=-74.543431 -> V=1.0, theta=0.0
% INFO    : Bus 58087	: V=0.9752345, theta=-71.216938 -> V=1.0, theta=0.0
% INFO    : Bus 58088	: V=0.944723, theta=-75.573583 -> V=1.0, theta=0.0
% INFO    : Bus 58089	: V=0.9603256, theta=-73.230624 -> V=1.0, theta=0.0
% INFO    : Bus 58090	: V=0.9711795, theta=-72.129007 -> V=1.0, theta=0.0
% INFO    : Bus 58091	: V=0.9470499, theta=-75.378003 -> V=1.0, theta=0.0
% INFO    : Bus 58092	: V=0.9559681, theta=-73.446793 -> V=1.0, theta=0.0
% INFO    : Bus 58093	: V=0.9481712, theta=-75.319374 -> V=1.0, theta=0.0
% INFO    : Bus 58094	: V=0.9563042, theta=-73.498715 -> V=1.0, theta=0.0
% INFO    : Bus 58095	: V=0.9629553, theta=-73.113506 -> V=1.0, theta=0.0
% INFO    : Bus 58096	: V=0.9567974, theta=-73.434868 -> V=1.0, theta=0.0
% INFO    : Bus 58097	: V=0.9567141, theta=-73.453169 -> V=1.0, theta=0.0
% INFO    : Bus 58098	: V=0.9487206, theta=-75.329121 -> V=1.0, theta=0.0
% INFO    : Bus 58099	: V=0.9534972, theta=-74.887241 -> V=1.0, theta=0.0
% INFO    : Bus 58100	: V=0.9507314, theta=-75.164193 -> V=1.0, theta=0.0
% INFO    : Bus 58101	: V=0.9632581, theta=-72.521393 -> V=1.0, theta=0.0
% INFO    : Bus 58102	: V=0.9621249, theta=-72.611944 -> V=1.0, theta=0.0
% INFO    : Bus 58103	: V=0.9584866, theta=-74.308527 -> V=1.0, theta=0.0
% INFO    : Bus 58104	: V=0.957681, theta=-74.38367 -> V=1.0, theta=0.0
% INFO    : Bus 58105	: V=0.9992134, theta=-68.659233 -> V=1.0, theta=0.0
% INFO    : Bus 58106	: V=0.9790106, theta=-71.389859 -> V=1.0, theta=0.0
% INFO    : Bus 58107	: V=0.9878166, theta=-71.010942 -> V=1.0, theta=0.0
% INFO    : Bus 58108	: V=0.9859635, theta=-71.122358 -> V=1.0, theta=0.0
% INFO    : Bus 58109	: V=0.967815, theta=-72.872753 -> V=1.0, theta=0.0
% INFO    : Bus 58110	: V=0.9927511, theta=-70.639125 -> V=1.0, theta=0.0
% INFO    : Bus 58111	: V=0.99068, theta=-70.874493 -> V=1.0, theta=0.0
% INFO    : Bus 58112	: V=0.9868428, theta=-71.014797 -> V=1.0, theta=0.0
% INFO    : Bus 58113	: V=0.9639765, theta=-73.031023 -> V=1.0, theta=0.0
% INFO    : Bus 58114	: V=0.9847033, theta=-71.195642 -> V=1.0, theta=0.0
% INFO    : Bus 58115	: V=0.9673854, theta=-72.87444 -> V=1.0, theta=0.0
% INFO    : Bus 58116	: V=0.9833701, theta=-71.269583 -> V=1.0, theta=0.0
% INFO    : Bus 58117	: V=0.966853, theta=-72.891821 -> V=1.0, theta=0.0
% INFO    : Bus 58118	: V=0.9651084, theta=-72.67159 -> V=1.0, theta=0.0
% INFO    : Bus 58119	: V=0.9658059, theta=-72.661647 -> V=1.0, theta=0.0
% INFO    : Bus 58120	: V=0.968219, theta=-72.528838 -> V=1.0, theta=0.0
% INFO    : Bus 58121	: V=0.9664826, theta=-72.566914 -> V=1.0, theta=0.0
% INFO    : Bus 58122	: V=0.9710426, theta=-72.089473 -> V=1.0, theta=0.0
% INFO    : Bus 58123	: V=0.969302, theta=-72.265188 -> V=1.0, theta=0.0
% INFO    : Bus 58124	: V=0.9686469, theta=-72.525316 -> V=1.0, theta=0.0
% INFO    : Bus 58125	: V=0.9836441, theta=-71.111856 -> V=1.0, theta=0.0
% INFO    : Bus 58126	: V=0.9870924, theta=-70.937693 -> V=1.0, theta=0.0
% INFO    : Bus 58127	: V=0.9797968, theta=-71.278 -> V=1.0, theta=0.0
% INFO    : Bus 58128	: V=0.9777555, theta=-71.346823 -> V=1.0, theta=0.0
% INFO    : Bus 58129	: V=0.9655736, theta=-72.46449 -> V=1.0, theta=0.0
% INFO    : Bus 58130	: V=0.9763599, theta=-71.28933 -> V=1.0, theta=0.0
% INFO    : Bus 58131	: V=0.9789658, theta=-71.132523 -> V=1.0, theta=0.0
% INFO    : Bus 58132	: V=0.9656413, theta=-72.640654 -> V=1.0, theta=0.0
% INFO    : Bus 58133	: V=0.9661354, theta=-72.611143 -> V=1.0, theta=0.0
% INFO    : Bus 58134	: V=0.9657824, theta=-72.605826 -> V=1.0, theta=0.0
% INFO    : Bus 58135	: V=0.966994, theta=-72.336971 -> V=1.0, theta=0.0
% INFO    : Bus 58136	: V=0.9665928, theta=-72.476406 -> V=1.0, theta=0.0
% INFO    : Bus 58137	: V=0.9775111, theta=-71.363174 -> V=1.0, theta=0.0
% INFO    : Bus 58138	: V=1.0030584, theta=-68.589097 -> V=1.0, theta=0.0
% INFO    : Bus 58139	: V=0.9681158, theta=-72.404944 -> V=1.0, theta=0.0
% INFO    : Bus 58140	: V=0.9755285, theta=-71.314738 -> V=1.0, theta=0.0
% INFO    : Bus 58141	: V=0.9760123, theta=-71.350048 -> V=1.0, theta=0.0
% INFO    : Bus 58142	: V=0.9786924, theta=-70.75234 -> V=1.0, theta=0.0
% INFO    : Bus 58143	: V=0.9599272, theta=-72.633877 -> V=1.0, theta=0.0
% INFO    : Bus 58144	: V=0.9838653, theta=-70.824897 -> V=1.0, theta=0.0
% INFO    : Bus 58145	: V=0.9633399, theta=-72.514285 -> V=1.0, theta=0.0
% INFO    : Bus 58146	: V=0.9592542, theta=-72.694697 -> V=1.0, theta=0.0
% INFO    : Bus 58147	: V=0.974816, theta=-71.035141 -> V=1.0, theta=0.0
% INFO    : Bus 58148	: V=0.9660403, theta=-72.393926 -> V=1.0, theta=0.0
% INFO    : Bus 58149	: V=0.9741756, theta=-71.308561 -> V=1.0, theta=0.0
% INFO    : Bus 58150	: V=0.9744257, theta=-71.312579 -> V=1.0, theta=0.0
% INFO    : Bus 58151	: V=0.9764734, theta=-71.37044 -> V=1.0, theta=0.0
% INFO    : Bus 58152	: V=0.9636298, theta=-72.525338 -> V=1.0, theta=0.0
% INFO    : Bus 58153	: V=0.9664429, theta=-73.035952 -> V=1.0, theta=0.0
% INFO    : Bus 58154	: V=0.96978, theta=-72.484174 -> V=1.0, theta=0.0
% INFO    : Bus 58155	: V=0.9685692, theta=-73.015801 -> V=1.0, theta=0.0
% INFO    : Bus 58156	: V=0.9667878, theta=-73.03324 -> V=1.0, theta=0.0
% INFO    : Bus 58157	: V=0.9626786, theta=-73.575621 -> V=1.0, theta=0.0
% INFO    : Bus 58158	: V=0.9683123, theta=-73.110142 -> V=1.0, theta=0.0
% INFO    : Bus 58159	: V=0.9584083, theta=-73.466218 -> V=1.0, theta=0.0
% INFO    : Bus 58160	: V=0.9584943, theta=-73.442416 -> V=1.0, theta=0.0
% INFO    : Bus 58161	: V=0.9695134, theta=-72.527784 -> V=1.0, theta=0.0
% INFO    : Bus 58162	: V=0.9609087, theta=-73.460349 -> V=1.0, theta=0.0
% INFO    : Bus 58163	: V=0.9642027, theta=-73.346671 -> V=1.0, theta=0.0
% INFO    : Bus 58164	: V=0.9696195, theta=-72.968665 -> V=1.0, theta=0.0
% INFO    : Bus 58165	: V=0.9648761, theta=-73.10787 -> V=1.0, theta=0.0
% INFO    : Bus 58166	: V=0.9652051, theta=-73.095585 -> V=1.0, theta=0.0
% INFO    : Bus 58167	: V=0.9656948, theta=-73.051656 -> V=1.0, theta=0.0
% INFO    : Bus 58168	: V=0.9660429, theta=-73.040727 -> V=1.0, theta=0.0
% INFO    : Bus 58169	: V=0.9955066, theta=-70.503058 -> V=1.0, theta=0.0
% INFO    : Bus 58170	: V=0.9920832, theta=-70.892942 -> V=1.0, theta=0.0
% INFO    : Bus 58171	: V=1.0141402, theta=-68.164471 -> V=1.0, theta=0.0
% INFO    : Bus 58172	: V=1.0143212, theta=-68.146461 -> V=1.0, theta=0.0
% INFO    : Bus 58173	: V=1.0105867, theta=-68.840862 -> V=1.0, theta=0.0
% INFO    : Bus 58174	: V=0.9904486, theta=-71.060156 -> V=1.0, theta=0.0
% INFO    : Bus 58175	: V=0.996748, theta=-70.447663 -> V=1.0, theta=0.0
% INFO    : Bus 58176	: V=0.9956292, theta=-70.528942 -> V=1.0, theta=0.0
% INFO    : Bus 58177	: V=1.0075194, theta=-68.960227 -> V=1.0, theta=0.0
% INFO    : Bus 58178	: V=0.9951192, theta=-70.361403 -> V=1.0, theta=0.0
% INFO    : Bus 58179	: V=0.9953606, theta=-70.32018 -> V=1.0, theta=0.0
% INFO    : Bus 58180	: V=1.0171626, theta=-67.779897 -> V=1.0, theta=0.0
% INFO    : Bus 58181	: V=1.0054263, theta=-69.780017 -> V=1.0, theta=0.0
% INFO    : Bus 58182	: V=1.0156954, theta=-67.987372 -> V=1.0, theta=0.0
% INFO    : Bus 58183	: V=0.9743127, theta=-71.835132 -> V=1.0, theta=0.0
% INFO    : Bus 58184	: V=0.9803767, theta=-71.655726 -> V=1.0, theta=0.0
% INFO    : Bus 58185	: V=1.018039, theta=-67.703146 -> V=1.0, theta=0.0
% INFO    : Bus 58186	: V=1.0180876, theta=-67.707137 -> V=1.0, theta=0.0
% INFO    : Bus 58187	: V=0.9789381, theta=-72.242911 -> V=1.0, theta=0.0
% INFO    : Bus 58188	: V=0.9738048, theta=-72.512474 -> V=1.0, theta=0.0
% INFO    : Bus 58189	: V=0.9708631, theta=-72.749398 -> V=1.0, theta=0.0
% INFO    : Bus 58190	: V=0.9998706, theta=-70.231655 -> V=1.0, theta=0.0
% INFO    : Bus 58191	: V=0.9990591, theta=-70.20522 -> V=1.0, theta=0.0
% INFO    : Bus 58192	: V=0.9905024, theta=-70.863416 -> V=1.0, theta=0.0
% INFO    : Bus 58193	: V=0.9794215, theta=-72.125746 -> V=1.0, theta=0.0
% INFO    : Bus 58194	: V=0.9767027, theta=-72.330661 -> V=1.0, theta=0.0
% INFO    : Bus 58195	: V=0.977249, theta=-72.27774 -> V=1.0, theta=0.0
% INFO    : Bus 58196	: V=0.9825414, theta=-71.861637 -> V=1.0, theta=0.0
% INFO    : Bus 58197	: V=0.9808537, theta=-72.020737 -> V=1.0, theta=0.0
% INFO    : Bus 58198	: V=1.0095079, theta=-69.499649 -> V=1.0, theta=0.0
% INFO    : Bus 58199	: V=0.9633525, theta=-73.186352 -> V=1.0, theta=0.0
% INFO    : Bus 58200	: V=0.9662121, theta=-73.044066 -> V=1.0, theta=0.0
% INFO    : Bus 58201	: V=0.9580943, theta=-73.351588 -> V=1.0, theta=0.0
% INFO    : Bus 58202	: V=0.9621511, theta=-73.212063 -> V=1.0, theta=0.0
% INFO    : Bus 58203	: V=0.9623108, theta=-73.207668 -> V=1.0, theta=0.0
% INFO    : Bus 58204	: V=0.9882402, theta=-71.015749 -> V=1.0, theta=0.0
% INFO    : Bus 58205	: V=0.9721836, theta=-72.605541 -> V=1.0, theta=0.0
% INFO    : Bus 58206	: V=0.9771563, theta=-72.209051 -> V=1.0, theta=0.0
% INFO    : Bus 58207	: V=0.9695048, theta=-72.717654 -> V=1.0, theta=0.0
% INFO    : Bus 58208	: V=0.961975, theta=-73.117104 -> V=1.0, theta=0.0
% INFO    : Bus 58209	: V=0.9631535, theta=-73.039243 -> V=1.0, theta=0.0
% INFO    : Bus 58210	: V=0.9607224, theta=-73.157959 -> V=1.0, theta=0.0
% INFO    : Bus 58211	: V=0.9613365, theta=-73.180798 -> V=1.0, theta=0.0
% INFO    : Bus 58212	: V=0.9642854, theta=-72.887911 -> V=1.0, theta=0.0
% INFO    : Bus 58213	: V=0.9679067, theta=-72.525128 -> V=1.0, theta=0.0
% INFO    : Bus 58214	: V=0.9663646, theta=-72.855695 -> V=1.0, theta=0.0
% INFO    : Bus 58215	: V=0.9727868, theta=-71.470804 -> V=1.0, theta=0.0
% INFO    : Bus 58216	: V=0.9650027, theta=-72.889514 -> V=1.0, theta=0.0
% INFO    : Bus 58217	: V=0.9664243, theta=-72.770794 -> V=1.0, theta=0.0
% INFO    : Bus 58218	: V=1.0078371, theta=-69.247446 -> V=1.0, theta=0.0
% INFO    : Bus 58219	: V=0.9776111, theta=-72.179351 -> V=1.0, theta=0.0
% INFO    : Bus 58220	: V=1.0089252, theta=-69.42394 -> V=1.0, theta=0.0
% INFO    : Bus 58221	: V=0.9757025, theta=-71.200485 -> V=1.0, theta=0.0
% INFO    : Bus 58222	: V=0.9938397, theta=-70.724033 -> V=1.0, theta=0.0
% INFO    : Bus 58223	: V=0.9871313, theta=-71.26931 -> V=1.0, theta=0.0
% INFO    : Bus 58224	: V=0.9614095, theta=-72.815902 -> V=1.0, theta=0.0
% INFO    : Bus 58225	: V=1.0027192, theta=-69.986547 -> V=1.0, theta=0.0
% INFO    : Bus 58226	: V=0.9600988, theta=-69.92536 -> V=1.0, theta=0.0
% INFO    : Bus 58227	: V=0.9778628, theta=-70.684464 -> V=1.0, theta=0.0
% INFO    : Bus 58228	: V=0.9689069, theta=-71.743093 -> V=1.0, theta=0.0
% INFO    : Bus 58229	: V=0.9689912, theta=-72.429073 -> V=1.0, theta=0.0
% INFO    : Bus 58230	: V=0.9679498, theta=-72.239454 -> V=1.0, theta=0.0
% INFO    : Bus 58231	: V=0.9726026, theta=-70.746968 -> V=1.0, theta=0.0
% INFO    : Bus 58232	: V=0.9799467, theta=-70.734363 -> V=1.0, theta=0.0
% INFO    : Bus 58233	: V=0.9782645, theta=-70.770351 -> V=1.0, theta=0.0
% INFO    : Bus 58234	: V=0.9936211, theta=-69.92595 -> V=1.0, theta=0.0
% INFO    : Bus 58235	: V=0.987577, theta=-70.678764 -> V=1.0, theta=0.0
% INFO    : Bus 58236	: V=1.0180883, theta=-55.795357 -> V=1.0, theta=0.0
% INFO    : Bus 58237	: V=1.0053658, theta=-57.487466 -> V=1.0, theta=0.0
% INFO    : Bus 58238	: V=1.0007028, theta=-58.344718 -> V=1.0, theta=0.0
% INFO    : Bus 58239	: V=1.0021102, theta=-58.122968 -> V=1.0, theta=0.0
% INFO    : Bus 58240	: V=0.9930591, theta=-59.867714 -> V=1.0, theta=0.0
% INFO    : Bus 58241	: V=0.9940688, theta=-59.325867 -> V=1.0, theta=0.0
% INFO    : Bus 58242	: V=1.0040636, theta=-57.998506 -> V=1.0, theta=0.0
% INFO    : Bus 58243	: V=0.9678899, theta=-61.474007 -> V=1.0, theta=0.0
% INFO    : Bus 58244	: V=0.9979076, theta=-58.458812 -> V=1.0, theta=0.0
% INFO    : Bus 58245	: V=0.9753643, theta=-71.861819 -> V=1.0, theta=0.0
% INFO    : Bus 58246	: V=0.9732246, theta=-71.684873 -> V=1.0, theta=0.0
% INFO    : Bus 58247	: V=0.9514501, theta=-74.040334 -> V=1.0, theta=0.0
% INFO    : Bus 58248	: V=0.9498925, theta=-74.075247 -> V=1.0, theta=0.0
% INFO    : Bus 58249	: V=0.9541558, theta=-73.797814 -> V=1.0, theta=0.0
% INFO    : Bus 58250	: V=0.9923105, theta=-68.021183 -> V=1.0, theta=0.0
% INFO    : Bus 58251	: V=1.0146874, theta=-65.572082 -> V=1.0, theta=0.0
% INFO    : Bus 58252	: V=0.9956171, theta=-67.878487 -> V=1.0, theta=0.0
% INFO    : Bus 58253	: V=1.0059005, theta=-66.987551 -> V=1.0, theta=0.0
% INFO    : Bus 58254	: V=1.0151293, theta=-65.557061 -> V=1.0, theta=0.0
% INFO    : Bus 58255	: V=1.0056877, theta=-67.016128 -> V=1.0, theta=0.0
% INFO    : Bus 58256	: V=0.9974587, theta=-67.821842 -> V=1.0, theta=0.0
% INFO    : Bus 58257	: V=0.9931153, theta=-68.009768 -> V=1.0, theta=0.0
% INFO    : Bus 58258	: V=1.0146212, theta=-63.36816 -> V=1.0, theta=0.0
% INFO    : Bus 58259	: V=0.9964719, theta=-67.847765 -> V=1.0, theta=0.0
% INFO    : Bus 58260	: V=0.9824353, theta=-65.300298 -> V=1.0, theta=0.0
% INFO    : Bus 58261	: V=0.9798301, theta=-65.253981 -> V=1.0, theta=0.0
% INFO    : Bus 58262	: V=0.9851878, theta=-67.489193 -> V=1.0, theta=0.0
% INFO    : Bus 58263	: V=0.9862744, theta=-68.518121 -> V=1.0, theta=0.0
% INFO    : Bus 58264	: V=0.9855139, theta=-68.203472 -> V=1.0, theta=0.0
% INFO    : Bus 58265	: V=0.9694958, theta=-66.556218 -> V=1.0, theta=0.0
% INFO    : Bus 58266	: V=0.9656768, theta=-66.774978 -> V=1.0, theta=0.0
% INFO    : Bus 58267	: V=0.9792197, theta=-65.953845 -> V=1.0, theta=0.0
% INFO    : Bus 58268	: V=0.966874, theta=-67.200707 -> V=1.0, theta=0.0
% INFO    : Bus 58269	: V=0.9708317, theta=-70.32278 -> V=1.0, theta=0.0
% INFO    : Bus 58270	: V=1.0148694, theta=-61.085434 -> V=1.0, theta=0.0
% INFO    : Bus 58271	: V=1.0132422, theta=-61.200444 -> V=1.0, theta=0.0
% INFO    : Bus 58272	: V=1.0118975, theta=-61.140249 -> V=1.0, theta=0.0
% INFO    : Bus 58273	: V=1.0195564, theta=-60.481577 -> V=1.0, theta=0.0
% INFO    : Bus 58274	: V=1.0124934, theta=-61.127024 -> V=1.0, theta=0.0
% INFO    : Bus 58275	: V=1.0096127, theta=-61.292152 -> V=1.0, theta=0.0
% INFO    : Bus 58276	: V=1.0099948, theta=-61.352387 -> V=1.0, theta=0.0
% INFO    : Bus 58277	: V=1.0100297, theta=-61.327798 -> V=1.0, theta=0.0
% INFO    : Bus 58278	: V=1.0181182, theta=-60.663329 -> V=1.0, theta=0.0
% INFO    : Bus 58279	: V=1.0173377, theta=-60.758743 -> V=1.0, theta=0.0
% INFO    : Bus 58280	: V=1.0115623, theta=-61.561385 -> V=1.0, theta=0.0
% INFO    : Bus 58281	: V=0.9997057, theta=-62.465269 -> V=1.0, theta=0.0
% INFO    : Bus 58282	: V=1.0188166, theta=-61.436269 -> V=1.0, theta=0.0
% INFO    : Bus 58283	: V=1.0110587, theta=-61.646697 -> V=1.0, theta=0.0
% INFO    : Bus 58284	: V=1.0121971, theta=-61.42359 -> V=1.0, theta=0.0
% INFO    : Bus 58285	: V=1.0072068, theta=-61.455825 -> V=1.0, theta=0.0
% INFO    : Bus 58286	: V=1.0090609, theta=-61.604432 -> V=1.0, theta=0.0
% INFO    : Bus 58287	: V=1.0073817, theta=-61.521442 -> V=1.0, theta=0.0
% INFO    : Bus 58288	: V=1.0084662, theta=-61.445748 -> V=1.0, theta=0.0
% INFO    : Bus 58289	: V=1.015282, theta=-61.034079 -> V=1.0, theta=0.0
% INFO    : Bus 58290	: V=1.009626, theta=-61.756959 -> V=1.0, theta=0.0
% INFO    : Bus 58291	: V=1.0142751, theta=-62.391513 -> V=1.0, theta=0.0
% INFO    : Bus 58292	: V=1.0131909, theta=-61.341328 -> V=1.0, theta=0.0
% INFO    : Bus 58293	: V=0.9847073, theta=-71.812645 -> V=1.0, theta=0.0
% INFO    : Bus 58294	: V=0.9747582, theta=-73.155038 -> V=1.0, theta=0.0
% INFO    : Bus 58295	: V=0.9866538, theta=-72.601777 -> V=1.0, theta=0.0
% INFO    : Bus 58296	: V=0.9846747, theta=-73.576241 -> V=1.0, theta=0.0
% INFO    : Bus 58297	: V=1.0046168, theta=-72.321636 -> V=1.0, theta=0.0
% INFO    : Bus 58298	: V=1.0005481, theta=-71.2092 -> V=1.0, theta=0.0
% INFO    : Bus 58299	: V=0.9941876, theta=-72.296822 -> V=1.0, theta=0.0
% INFO    : Bus 58300	: V=0.97527, theta=-73.538494 -> V=1.0, theta=0.0
% INFO    : Bus 58301	: V=0.9724055, theta=-73.625048 -> V=1.0, theta=0.0
% INFO    : Bus 58302	: V=0.9765997, theta=-73.511752 -> V=1.0, theta=0.0
% INFO    : Bus 58303	: V=0.9810972, theta=-73.939819 -> V=1.0, theta=0.0
% INFO    : Bus 58304	: V=0.9937869, theta=-71.779079 -> V=1.0, theta=0.0
% INFO    : Bus 58305	: V=0.9758323, theta=-74.010331 -> V=1.0, theta=0.0
% INFO    : Bus 58306	: V=0.9782022, theta=-73.656455 -> V=1.0, theta=0.0
% INFO    : Bus 58307	: V=0.9838074, theta=-72.974414 -> V=1.0, theta=0.0
% INFO    : Bus 58308	: V=0.9675507, theta=-75.437402 -> V=1.0, theta=0.0
% INFO    : Bus 58309	: V=0.9868113, theta=-60.659635 -> V=1.0, theta=0.0
% INFO    : Bus 58310	: V=1.0151493, theta=-56.377273 -> V=1.0, theta=0.0
% INFO    : Bus 58311	: V=1.0176039, theta=-56.288048 -> V=1.0, theta=0.0
% INFO    : Bus 58312	: V=0.978055, theta=-71.403371 -> V=1.0, theta=0.0
% INFO    : Bus 58313	: V=0.9945543, theta=-70.770293 -> V=1.0, theta=0.0
% INFO    : Bus 58314	: V=0.9914319, theta=-71.561699 -> V=1.0, theta=0.0
% INFO    : Bus 58315	: V=0.9934443, theta=-71.116034 -> V=1.0, theta=0.0
% INFO    : Bus 58316	: V=0.9888063, theta=-70.940214 -> V=1.0, theta=0.0
% INFO    : Bus 58317	: V=0.989928, theta=-72.203925 -> V=1.0, theta=0.0
% INFO    : Bus 58318	: V=0.9952288, theta=-70.378034 -> V=1.0, theta=0.0
% INFO    : Bus 58319	: V=0.9933538, theta=-70.513869 -> V=1.0, theta=0.0
% INFO    : Bus 58320	: V=0.993696, theta=-70.504954 -> V=1.0, theta=0.0
% INFO    : Bus 58321	: V=0.9929563, theta=-70.560038 -> V=1.0, theta=0.0
% INFO    : Bus 58322	: V=0.992404, theta=-70.611358 -> V=1.0, theta=0.0
% INFO    : Bus 58323	: V=0.9924866, theta=-70.572512 -> V=1.0, theta=0.0
% INFO    : Bus 58324	: V=0.9957562, theta=-70.286705 -> V=1.0, theta=0.0
% INFO    : Bus 58325	: V=0.9963877, theta=-70.195799 -> V=1.0, theta=0.0
% INFO    : Bus 58326	: V=0.9969479, theta=-70.026828 -> V=1.0, theta=0.0
% INFO    : Bus 58327	: V=0.9980444, theta=-69.895486 -> V=1.0, theta=0.0
% INFO    : Bus 58328	: V=0.9974769, theta=-70.022611 -> V=1.0, theta=0.0
% INFO    : Bus 58329	: V=0.9970079, theta=-70.104745 -> V=1.0, theta=0.0
% INFO    : Bus 58330	: V=0.9972613, theta=-70.169765 -> V=1.0, theta=0.0
% INFO    : Bus 58331	: V=0.9991235, theta=-70.001418 -> V=1.0, theta=0.0
% INFO    : Bus 58332	: V=0.9968017, theta=-70.205833 -> V=1.0, theta=0.0
% INFO    : Bus 58333	: V=0.9958641, theta=-70.337664 -> V=1.0, theta=0.0
% INFO    : Bus 58334	: V=0.9943336, theta=-70.410041 -> V=1.0, theta=0.0
% INFO    : Bus 58335	: V=0.9947062, theta=-70.402522 -> V=1.0, theta=0.0
% INFO    : Bus 58336	: V=0.9972636, theta=-70.225727 -> V=1.0, theta=0.0
% INFO    : Bus 58337	: V=0.9961288, theta=-70.266508 -> V=1.0, theta=0.0
% INFO    : Bus 58338	: V=0.996517, theta=-70.285567 -> V=1.0, theta=0.0
% INFO    : Bus 58339	: V=0.9962969, theta=-70.263168 -> V=1.0, theta=0.0
% INFO    : Bus 58340	: V=0.9980548, theta=-70.063684 -> V=1.0, theta=0.0
% INFO    : Bus 58341	: V=0.9974258, theta=-70.088607 -> V=1.0, theta=0.0
% INFO    : Bus 58342	: V=0.9987585, theta=-69.886338 -> V=1.0, theta=0.0
% INFO    : Bus 58343	: V=1.0003504, theta=-69.712062 -> V=1.0, theta=0.0
% INFO    : Bus 58344	: V=0.9996186, theta=-69.716828 -> V=1.0, theta=0.0
% INFO    : Bus 58345	: V=1.0061803, theta=-68.927191 -> V=1.0, theta=0.0
% INFO    : Bus 58346	: V=1.0152947, theta=-68.224892 -> V=1.0, theta=0.0
% INFO    : Bus 58347	: V=1.0100364, theta=-68.448092 -> V=1.0, theta=0.0
% INFO    : Bus 58348	: V=0.9944099, theta=-70.214004 -> V=1.0, theta=0.0
% INFO    : Bus 58349	: V=1.0163161, theta=-68.156807 -> V=1.0, theta=0.0
% INFO    : Bus 58350	: V=1.0040368, theta=-69.237828 -> V=1.0, theta=0.0
% INFO    : Bus 58351	: V=0.9943806, theta=-68.83634 -> V=1.0, theta=0.0
% INFO    : Bus 58352	: V=1.0106404, theta=-68.10367 -> V=1.0, theta=0.0
% INFO    : Bus 58353	: V=1.005771, theta=-68.533812 -> V=1.0, theta=0.0
% INFO    : Bus 58354	: V=0.9916289, theta=-70.420634 -> V=1.0, theta=0.0
% INFO    : Bus 58355	: V=0.9926375, theta=-70.238949 -> V=1.0, theta=0.0
% INFO    : Bus 58356	: V=1.0028432, theta=-69.262061 -> V=1.0, theta=0.0
% INFO    : Bus 58357	: V=1.0043374, theta=-69.275112 -> V=1.0, theta=0.0
% INFO    : Bus 58358	: V=1.0063787, theta=-69.205346 -> V=1.0, theta=0.0
% INFO    : Bus 58359	: V=1.015153, theta=-68.18254 -> V=1.0, theta=0.0
% INFO    : Bus 58360	: V=1.007719, theta=-68.530686 -> V=1.0, theta=0.0
% INFO    : Bus 58361	: V=1.0047596, theta=-69.234769 -> V=1.0, theta=0.0
% INFO    : Bus 58362	: V=1.0021933, theta=-69.208849 -> V=1.0, theta=0.0
% INFO    : Bus 58363	: V=0.9927328, theta=-70.332728 -> V=1.0, theta=0.0
% INFO    : Bus 58364	: V=0.9919935, theta=-70.649156 -> V=1.0, theta=0.0
% INFO    : Bus 58365	: V=0.989164, theta=-70.949858 -> V=1.0, theta=0.0
% INFO    : Bus 58366	: V=0.9909354, theta=-70.753565 -> V=1.0, theta=0.0
% INFO    : Bus 58367	: V=0.9878822, theta=-71.030524 -> V=1.0, theta=0.0
% INFO    : Bus 58368	: V=0.9903749, theta=-69.952283 -> V=1.0, theta=0.0
% INFO    : Bus 58369	: V=0.9942076, theta=-70.450459 -> V=1.0, theta=0.0
% INFO    : Bus 58370	: V=1.0020247, theta=-68.859089 -> V=1.0, theta=0.0
% INFO    : Bus 58371	: V=1.005168, theta=-66.14316 -> V=1.0, theta=0.0
% INFO    : Bus 58372	: V=1.0010078, theta=-68.722029 -> V=1.0, theta=0.0
% INFO    : Bus 58373	: V=1.0133937, theta=-66.011536 -> V=1.0, theta=0.0
% INFO    : Bus 58374	: V=0.990198, theta=-70.128416 -> V=1.0, theta=0.0
% INFO    : Bus 58375	: V=0.9853668, theta=-71.554711 -> V=1.0, theta=0.0
% INFO    : Bus 58376	: V=0.9838619, theta=-71.846514 -> V=1.0, theta=0.0
% INFO    : Bus 58377	: V=0.9957297, theta=-70.214987 -> V=1.0, theta=0.0
% INFO    : Bus 58378	: V=0.999676, theta=-69.901145 -> V=1.0, theta=0.0
% INFO    : Bus 58379	: V=0.9692677, theta=-70.011967 -> V=1.0, theta=0.0
% INFO    : Bus 58380	: V=0.9934297, theta=-68.15816 -> V=1.0, theta=0.0
% INFO    : Bus 58381	: V=0.993927, theta=-67.324663 -> V=1.0, theta=0.0
% INFO    : Bus 58382	: V=0.9954534, theta=-67.599457 -> V=1.0, theta=0.0
% INFO    : Bus 58383	: V=0.9923867, theta=-68.653961 -> V=1.0, theta=0.0
% INFO    : Bus 58384	: V=0.9956277, theta=-68.688004 -> V=1.0, theta=0.0
% INFO    : Bus 58385	: V=0.9915179, theta=-67.15999 -> V=1.0, theta=0.0
% INFO    : Bus 58386	: V=0.9940323, theta=-66.877453 -> V=1.0, theta=0.0
% INFO    : Bus 58387	: V=0.9575228, theta=-69.956992 -> V=1.0, theta=0.0
% INFO    : Bus 58388	: V=0.9907288, theta=-66.682609 -> V=1.0, theta=0.0
% INFO    : Bus 58389	: V=0.9950442, theta=-65.549555 -> V=1.0, theta=0.0
% INFO    : Bus 58390	: V=0.9991001, theta=-55.427474 -> V=1.0, theta=0.0
% INFO    : Bus 58391	: V=0.9722503, theta=-58.589129 -> V=1.0, theta=0.0
% INFO    : Bus 58392	: V=0.9647486, theta=-66.197564 -> V=1.0, theta=0.0
% INFO    : Bus 58393	: V=0.9682748, theta=-65.977205 -> V=1.0, theta=0.0
% INFO    : Bus 58394	: V=0.9688621, theta=-65.736529 -> V=1.0, theta=0.0
% INFO    : Bus 58395	: V=0.96329, theta=-66.214765 -> V=1.0, theta=0.0
% INFO    : Bus 58396	: V=0.9699262, theta=-65.953404 -> V=1.0, theta=0.0
% INFO    : Bus 58397	: V=0.9703775, theta=-65.948615 -> V=1.0, theta=0.0
% INFO    : Bus 58398	: V=0.9792698, theta=-63.328843 -> V=1.0, theta=0.0
% INFO    : Bus 58399	: V=0.9693725, theta=-65.959696 -> V=1.0, theta=0.0
% INFO    : Bus 58400	: V=0.9802974, theta=-63.767465 -> V=1.0, theta=0.0
% INFO    : Bus 58401	: V=0.9865736, theta=-63.200462 -> V=1.0, theta=0.0
% INFO    : Bus 58402	: V=0.958576, theta=-66.735645 -> V=1.0, theta=0.0
% INFO    : Bus 58403	: V=0.9632179, theta=-66.213627 -> V=1.0, theta=0.0
% INFO    : Bus 58404	: V=0.9544719, theta=-67.052275 -> V=1.0, theta=0.0
% INFO    : Bus 58405	: V=0.9613995, theta=-66.522169 -> V=1.0, theta=0.0
% INFO    : Bus 58406	: V=0.9628016, theta=-66.453186 -> V=1.0, theta=0.0
% INFO    : Bus 58407	: V=0.960561, theta=-66.541375 -> V=1.0, theta=0.0
% INFO    : Bus 58408	: V=0.9647954, theta=-66.33841 -> V=1.0, theta=0.0
% INFO    : Bus 58409	: V=0.9811856, theta=-65.137439 -> V=1.0, theta=0.0
% INFO    : Bus 58410	: V=0.9666557, theta=-66.161945 -> V=1.0, theta=0.0
% INFO    : Bus 58411	: V=0.9596768, theta=-66.640718 -> V=1.0, theta=0.0
% INFO    : Bus 58412	: V=0.9826884, theta=-64.734544 -> V=1.0, theta=0.0
% INFO    : Bus 58413	: V=0.9873062, theta=-64.670546 -> V=1.0, theta=0.0
% INFO    : Bus 58414	: V=0.9827995, theta=-65.060045 -> V=1.0, theta=0.0
% INFO    : Bus 58415	: V=0.9717115, theta=-65.890864 -> V=1.0, theta=0.0
% INFO    : Bus 58416	: V=0.988427, theta=-64.285705 -> V=1.0, theta=0.0
% INFO    : Bus 58417	: V=0.9884705, theta=-63.741659 -> V=1.0, theta=0.0
% INFO    : Bus 58418	: V=0.9807865, theta=-63.322915 -> V=1.0, theta=0.0
% INFO    : Bus 58419	: V=0.9874931, theta=-63.391449 -> V=1.0, theta=0.0
% INFO    : Bus 58420	: V=0.9812836, theta=-63.432843 -> V=1.0, theta=0.0
% INFO    : Bus 58421	: V=0.9848976, theta=-63.236752 -> V=1.0, theta=0.0
% INFO    : Bus 58422	: V=1.003845, theta=-60.296005 -> V=1.0, theta=0.0
% INFO    : Bus 58423	: V=0.9890677, theta=-62.648062 -> V=1.0, theta=0.0
% INFO    : Bus 58424	: V=0.9877453, theta=-62.891504 -> V=1.0, theta=0.0
% INFO    : Bus 58425	: V=1.0020317, theta=-61.658956 -> V=1.0, theta=0.0
% INFO    : Bus 58426	: V=1.0032185, theta=-60.553131 -> V=1.0, theta=0.0
% INFO    : Bus 58427	: V=1.0053328, theta=-61.192799 -> V=1.0, theta=0.0
% INFO    : Bus 58428	: V=0.9851913, theta=-63.232666 -> V=1.0, theta=0.0
% INFO    : Bus 58429	: V=1.0048226, theta=-60.529079 -> V=1.0, theta=0.0
% INFO    : Bus 58430	: V=0.9920369, theta=-59.879403 -> V=1.0, theta=0.0
% INFO    : Bus 58431	: V=0.9888705, theta=-60.86381 -> V=1.0, theta=0.0
% INFO    : Bus 58432	: V=0.9987153, theta=-60.603471 -> V=1.0, theta=0.0
% INFO    : Bus 58433	: V=0.9932883, theta=-62.746416 -> V=1.0, theta=0.0
% INFO    : Bus 58434	: V=0.9954346, theta=-62.286934 -> V=1.0, theta=0.0
% INFO    : Bus 58435	: V=0.9762787, theta=-63.766344 -> V=1.0, theta=0.0
% INFO    : Bus 58436	: V=0.9722479, theta=-63.797854 -> V=1.0, theta=0.0
% INFO    : Bus 58437	: V=0.9968203, theta=-61.952961 -> V=1.0, theta=0.0
% INFO    : Bus 58438	: V=0.9727462, theta=-69.584948 -> V=1.0, theta=0.0
% INFO    : Bus 58439	: V=0.9893614, theta=-68.441506 -> V=1.0, theta=0.0
% INFO    : Bus 58440	: V=0.9776915, theta=-69.268924 -> V=1.0, theta=0.0
% INFO    : Bus 58441	: V=0.9928584, theta=-67.713658 -> V=1.0, theta=0.0
% INFO    : Bus 58442	: V=0.9529227, theta=-72.864351 -> V=1.0, theta=0.0
% INFO    : Bus 58443	: V=0.9536008, theta=-73.101999 -> V=1.0, theta=0.0
% INFO    : Bus 58444	: V=0.9783498, theta=-69.350135 -> V=1.0, theta=0.0
% INFO    : Bus 58445	: V=0.9560236, theta=-72.755916 -> V=1.0, theta=0.0
% INFO    : Bus 58446	: V=0.9937207, theta=-67.700908 -> V=1.0, theta=0.0
% INFO    : Bus 58447	: V=0.9801953, theta=-69.221255 -> V=1.0, theta=0.0
% INFO    : Bus 58448	: V=0.9791495, theta=-69.309177 -> V=1.0, theta=0.0
% INFO    : Bus 58449	: V=0.9854769, theta=-68.589124 -> V=1.0, theta=0.0
% INFO    : Bus 58450	: V=0.9701526, theta=-69.8008 -> V=1.0, theta=0.0
% INFO    : Bus 58451	: V=0.9702641, theta=-69.617514 -> V=1.0, theta=0.0
% INFO    : Bus 58452	: V=0.9672508, theta=-71.132616 -> V=1.0, theta=0.0
% INFO    : Bus 58453	: V=0.9629832, theta=-71.896438 -> V=1.0, theta=0.0
% INFO    : Bus 58454	: V=0.9549392, theta=-73.174604 -> V=1.0, theta=0.0
% INFO    : Bus 58455	: V=0.9596648, theta=-72.939277 -> V=1.0, theta=0.0
% INFO    : Bus 58456	: V=0.9652872, theta=-72.35696 -> V=1.0, theta=0.0
% INFO    : Bus 58457	: V=0.9608563, theta=-72.8301 -> V=1.0, theta=0.0
% INFO    : Bus 58458	: V=0.9622027, theta=-72.852386 -> V=1.0, theta=0.0
% INFO    : Bus 58459	: V=0.9694764, theta=-71.60045 -> V=1.0, theta=0.0
% INFO    : Bus 58460	: V=0.9612519, theta=-72.878987 -> V=1.0, theta=0.0
% INFO    : Bus 58461	: V=0.9612103, theta=-72.66311 -> V=1.0, theta=0.0
% INFO    : Bus 58462	: V=0.961313, theta=-72.901448 -> V=1.0, theta=0.0
% INFO    : Bus 58463	: V=0.961022, theta=-72.647565 -> V=1.0, theta=0.0
% INFO    : Bus 58464	: V=0.9586863, theta=-73.010083 -> V=1.0, theta=0.0
% INFO    : Bus 58465	: V=0.9599196, theta=-72.960225 -> V=1.0, theta=0.0
% INFO    : Bus 58466	: V=0.9560345, theta=-73.145224 -> V=1.0, theta=0.0
% INFO    : Bus 58467	: V=0.9645993, theta=-72.674602 -> V=1.0, theta=0.0
% INFO    : Bus 58468	: V=0.9570032, theta=-73.139921 -> V=1.0, theta=0.0
% INFO    : Bus 58469	: V=0.9564774, theta=-73.235679 -> V=1.0, theta=0.0
% INFO    : Bus 58470	: V=0.9566634, theta=-73.118884 -> V=1.0, theta=0.0
% INFO    : Bus 58471	: V=0.959449, theta=-73.133973 -> V=1.0, theta=0.0
% INFO    : Bus 58472	: V=0.9580001, theta=-73.006806 -> V=1.0, theta=0.0
% INFO    : Bus 58473	: V=0.9583361, theta=-73.145193 -> V=1.0, theta=0.0
% INFO    : Bus 58474	: V=0.9636388, theta=-72.397019 -> V=1.0, theta=0.0
% INFO    : Bus 58475	: V=0.9620676, theta=-72.407163 -> V=1.0, theta=0.0
% INFO    : Bus 58476	: V=0.964481, theta=-72.430119 -> V=1.0, theta=0.0
% INFO    : Bus 58477	: V=0.9657512, theta=-72.351609 -> V=1.0, theta=0.0
% INFO    : Bus 58478	: V=0.9646167, theta=-72.381916 -> V=1.0, theta=0.0
% INFO    : Bus 58479	: V=0.9629003, theta=-72.426027 -> V=1.0, theta=0.0
% INFO    : Bus 58480	: V=0.9725752, theta=-71.874248 -> V=1.0, theta=0.0
% INFO    : Bus 58481	: V=0.9983614, theta=-68.654488 -> V=1.0, theta=0.0
% INFO    : Bus 58482	: V=0.9660061, theta=-72.169123 -> V=1.0, theta=0.0
% INFO    : Bus 58483	: V=0.9637222, theta=-72.410138 -> V=1.0, theta=0.0
% INFO    : Bus 58484	: V=0.9660985, theta=-71.92623 -> V=1.0, theta=0.0
% INFO    : Bus 58485	: V=0.9684347, theta=-71.920309 -> V=1.0, theta=0.0
% INFO    : Bus 58486	: V=0.9700819, theta=-71.868947 -> V=1.0, theta=0.0
% INFO    : Bus 58487	: V=0.9690795, theta=-72.102746 -> V=1.0, theta=0.0
% INFO    : Bus 58488	: V=0.9746325, theta=-71.511494 -> V=1.0, theta=0.0
% INFO    : Bus 58489	: V=0.997999, theta=-68.688394 -> V=1.0, theta=0.0
% INFO    : Bus 58490	: V=0.9672663, theta=-71.904399 -> V=1.0, theta=0.0
% INFO    : Bus 58491	: V=0.9755085, theta=-70.758208 -> V=1.0, theta=0.0
% INFO    : Bus 58492	: V=0.9563047, theta=-73.010892 -> V=1.0, theta=0.0
% INFO    : Bus 58493	: V=0.9619644, theta=-72.551474 -> V=1.0, theta=0.0
% INFO    : Bus 58494	: V=0.9681465, theta=-71.772659 -> V=1.0, theta=0.0
% INFO    : Bus 58495	: V=0.9748682, theta=-71.202807 -> V=1.0, theta=0.0
% INFO    : Bus 58496	: V=0.9683772, theta=-71.753952 -> V=1.0, theta=0.0
% INFO    : Bus 58497	: V=0.9625958, theta=-72.025041 -> V=1.0, theta=0.0
% INFO    : Bus 58498	: V=0.9754971, theta=-71.083596 -> V=1.0, theta=0.0
% INFO    : Bus 58499	: V=0.9629311, theta=-72.071763 -> V=1.0, theta=0.0
% INFO    : Bus 58500	: V=0.9732262, theta=-69.972982 -> V=1.0, theta=0.0
% INFO    : Bus 58501	: V=0.9635371, theta=-71.909168 -> V=1.0, theta=0.0
% INFO    : Bus 58502	: V=0.9651714, theta=-71.545341 -> V=1.0, theta=0.0
% INFO    : Bus 58503	: V=0.9610061, theta=-72.038234 -> V=1.0, theta=0.0
% INFO    : Bus 58504	: V=0.9632436, theta=-71.886435 -> V=1.0, theta=0.0
% INFO    : Bus 58505	: V=0.9776413, theta=-70.510709 -> V=1.0, theta=0.0
% INFO    : Bus 58506	: V=0.9754181, theta=-70.822306 -> V=1.0, theta=0.0
% INFO    : Bus 58507	: V=0.9872032, theta=-69.373408 -> V=1.0, theta=0.0
% INFO    : Bus 58508	: V=0.9800965, theta=-70.268776 -> V=1.0, theta=0.0
% INFO    : Bus 58509	: V=0.978499, theta=-70.410112 -> V=1.0, theta=0.0
% INFO    : Bus 58510	: V=0.9631625, theta=-71.900199 -> V=1.0, theta=0.0
% INFO    : Bus 58511	: V=0.9638489, theta=-71.894651 -> V=1.0, theta=0.0
% INFO    : Bus 58512	: V=0.9629296, theta=-71.940571 -> V=1.0, theta=0.0
% INFO    : Bus 58513	: V=0.9548025, theta=-72.124305 -> V=1.0, theta=0.0
% INFO    : Bus 58514	: V=0.9768085, theta=-69.713382 -> V=1.0, theta=0.0
% INFO    : Bus 58515	: V=0.9932894, theta=-67.768961 -> V=1.0, theta=0.0
% INFO    : Bus 58516	: V=0.9940401, theta=-68.111274 -> V=1.0, theta=0.0
% INFO    : Bus 58517	: V=0.9650506, theta=-71.972386 -> V=1.0, theta=0.0
% INFO    : Bus 58518	: V=0.9778183, theta=-70.565457 -> V=1.0, theta=0.0
% INFO    : Bus 58519	: V=0.9741381, theta=-70.957127 -> V=1.0, theta=0.0
% INFO    : Bus 58520	: V=0.9772424, theta=-70.776701 -> V=1.0, theta=0.0
% INFO    : Bus 58521	: V=0.9745339, theta=-70.892609 -> V=1.0, theta=0.0
% INFO    : Bus 58522	: V=0.9946542, theta=-68.366532 -> V=1.0, theta=0.0
% INFO    : Bus 58523	: V=0.9638743, theta=-72.02931 -> V=1.0, theta=0.0
% INFO    : Bus 58524	: V=0.9767098, theta=-70.358903 -> V=1.0, theta=0.0
% INFO    : Bus 58525	: V=0.9711486, theta=-70.285956 -> V=1.0, theta=0.0
% INFO    : Bus 58526	: V=0.9866842, theta=-68.637619 -> V=1.0, theta=0.0
% INFO    : Bus 58527	: V=0.9782444, theta=-70.717227 -> V=1.0, theta=0.0
% INFO    : Bus 58528	: V=0.9776323, theta=-70.904503 -> V=1.0, theta=0.0
% INFO    : Bus 58529	: V=0.9829455, theta=-70.466094 -> V=1.0, theta=0.0
% INFO    : Bus 58530	: V=0.9922687, theta=-69.946589 -> V=1.0, theta=0.0
% INFO    : Bus 58531	: V=0.9808891, theta=-69.274896 -> V=1.0, theta=0.0
% INFO    : Bus 58532	: V=0.9944421, theta=-68.488953 -> V=1.0, theta=0.0
% INFO    : Bus 58533	: V=0.9934771, theta=-68.322722 -> V=1.0, theta=0.0
% INFO    : Bus 58534	: V=1.0017083, theta=-68.424352 -> V=1.0, theta=0.0
% INFO    : Bus 58535	: V=0.9967883, theta=-68.450638 -> V=1.0, theta=0.0
% INFO    : Bus 58536	: V=0.9605559, theta=-70.863085 -> V=1.0, theta=0.0
% INFO    : Bus 58537	: V=0.9888264, theta=-68.616832 -> V=1.0, theta=0.0
% INFO    : Bus 58538	: V=0.9505355, theta=-61.880446 -> V=1.0, theta=0.0
% INFO    : Bus 58539	: V=0.9507601, theta=-61.802268 -> V=1.0, theta=0.0
% INFO    : Bus 58540	: V=0.9615794, theta=-60.025425 -> V=1.0, theta=0.0
% INFO    : Bus 58541	: V=0.9703217, theta=-71.364128 -> V=1.0, theta=0.0
% INFO    : Bus 58542	: V=0.9790496, theta=-70.260381 -> V=1.0, theta=0.0
% INFO    : Bus 58543	: V=0.9824359, theta=-69.325955 -> V=1.0, theta=0.0
% INFO    : Bus 58544	: V=0.9726859, theta=-69.631686 -> V=1.0, theta=0.0
% INFO    : Bus 58545	: V=0.9913522, theta=-66.025196 -> V=1.0, theta=0.0
% INFO    : Bus 58546	: V=1.0082248, theta=-65.033842 -> V=1.0, theta=0.0
% INFO    : Bus 58547	: V=0.9702539, theta=-69.001919 -> V=1.0, theta=0.0
% INFO    : Bus 58548	: V=0.9919026, theta=-67.495594 -> V=1.0, theta=0.0
% INFO    : Bus 58549	: V=0.9733606, theta=-69.493597 -> V=1.0, theta=0.0
% INFO    : Bus 58550	: V=0.9769755, theta=-71.34106 -> V=1.0, theta=0.0
% INFO    : Bus 58551	: V=0.9769878, theta=-71.604082 -> V=1.0, theta=0.0
% INFO    : Bus 58552	: V=0.9966107, theta=-59.242963 -> V=1.0, theta=0.0
% INFO    : Bus 58553	: V=1.0105249, theta=-58.033238 -> V=1.0, theta=0.0
% INFO    : Bus 58554	: V=0.9948322, theta=-60.9773 -> V=1.0, theta=0.0
% INFO    : Bus 58555	: V=1.004715, theta=-60.529021 -> V=1.0, theta=0.0
% INFO    : Bus 58556	: V=0.9850248, theta=-63.414752 -> V=1.0, theta=0.0
% INFO    : Bus 58557	: V=0.9835888, theta=-61.683701 -> V=1.0, theta=0.0
% INFO    : Bus 58558	: V=0.9884245, theta=-61.390473 -> V=1.0, theta=0.0
% INFO    : Bus 58559	: V=0.9907807, theta=-60.912228 -> V=1.0, theta=0.0
% INFO    : Bus 58560	: V=0.9866047, theta=-62.898578 -> V=1.0, theta=0.0
% INFO    : Bus 58561	: V=0.9855729, theta=-63.217237 -> V=1.0, theta=0.0
% INFO    : Bus 58562	: V=1.0047036, theta=-56.314765 -> V=1.0, theta=0.0
% INFO    : Bus 58563	: V=1.0144364, theta=-55.684854 -> V=1.0, theta=0.0
% INFO    : Bus 58564	: V=0.9755538, theta=-59.782355 -> V=1.0, theta=0.0
% INFO    : Bus 58565	: V=1.0198911, theta=-56.488825 -> V=1.0, theta=0.0
% INFO    : Bus 58566	: V=0.9971893, theta=-59.279069 -> V=1.0, theta=0.0
% INFO    : Bus 58567	: V=1.0198424, theta=-57.021113 -> V=1.0, theta=0.0
% INFO    : Bus 58568	: V=0.9701102, theta=-73.984169 -> V=1.0, theta=0.0
% INFO    : Bus 58569	: V=0.9716372, theta=-73.914582 -> V=1.0, theta=0.0
% INFO    : Bus 58570	: V=0.9792599, theta=-72.971241 -> V=1.0, theta=0.0
% INFO    : Bus 58571	: V=0.9979046, theta=-69.487886 -> V=1.0, theta=0.0
% INFO    : Bus 58572	: V=0.9654538, theta=-72.578297 -> V=1.0, theta=0.0
% INFO    : Bus 58573	: V=0.989094, theta=-70.277616 -> V=1.0, theta=0.0
% INFO    : Bus 58574	: V=0.9780389, theta=-71.293709 -> V=1.0, theta=0.0
% INFO    : Bus 75433	: V=1.0170113, theta=-62.857269 -> V=1.0, theta=0.0
% INFO    : Bus 75434	: V=1.0113998, theta=-64.75701 -> V=1.0, theta=0.0
% INFO    : Bus 75435	: V=1.0108534, theta=-64.961061 -> V=1.0, theta=0.0
% INFO    : Bus 75436	: V=1.0010432, theta=-65.948593 -> V=1.0, theta=0.0
% INFO    : Bus 75437	: V=1.0173329, theta=-62.11113 -> V=1.0, theta=0.0
% INFO    : Bus 75438	: V=1.0143085, theta=-62.863062 -> V=1.0, theta=0.0
% INFO    : Bus 75439	: V=1.0160683, theta=-63.748718 -> V=1.0, theta=0.0
% INFO    : Bus 75440	: V=1.012843, theta=-63.976564 -> V=1.0, theta=0.0
% INFO    : Bus 75441	: V=1.0128714, theta=-71.126211 -> V=1.0, theta=0.0
% INFO    : Bus 75442	: V=1.0175925, theta=-62.078943 -> V=1.0, theta=0.0
% INFO    : Bus 75443	: V=1.0166414, theta=-62.1919 -> V=1.0, theta=0.0
% INFO    : Bus 75444	: V=0.993077, theta=-68.699791 -> V=1.0, theta=0.0
% INFO    : Bus 75445	: V=0.9914421, theta=-68.791533 -> V=1.0, theta=0.0
% INFO    : Bus 75446	: V=0.9732854, theta=-69.416553 -> V=1.0, theta=0.0
% INFO    : Bus 75447	: V=0.9878719, theta=-68.212036 -> V=1.0, theta=0.0
% INFO    : Bus 75448	: V=1.0093417, theta=-65.740046 -> V=1.0, theta=0.0
% INFO    : Bus 75449	: V=1.0126017, theta=-65.150291 -> V=1.0, theta=0.0
% INFO    : Bus 75450	: V=1.0080075, theta=-63.655091 -> V=1.0, theta=0.0
% INFO    : Bus 75451	: V=1.0191289, theta=-63.50401 -> V=1.0, theta=0.0
% INFO    : Bus 75452	: V=1.0150761, theta=-63.938834 -> V=1.0, theta=0.0
% INFO    : Bus 75453	: V=0.9926795, theta=-73.477178 -> V=1.0, theta=0.0
% INFO    : Bus 75454	: V=1.0122746, theta=-64.003626 -> V=1.0, theta=0.0
% INFO    : Bus 75455	: V=0.9942734, theta=-67.891901 -> V=1.0, theta=0.0
% INFO    : Bus 75456	: V=0.9820193, theta=-71.53867 -> V=1.0, theta=0.0
% INFO    : Bus 75457	: V=0.9714772, theta=-72.307638 -> V=1.0, theta=0.0
% INFO    : Bus 75458	: V=0.975648, theta=-72.086345 -> V=1.0, theta=0.0
% INFO    : Bus 75459	: V=0.9800834, theta=-71.548938 -> V=1.0, theta=0.0
% INFO    : Bus 75460	: V=0.9879075, theta=-66.851185 -> V=1.0, theta=0.0
% INFO    : Bus 75461	: V=1.0112455, theta=-64.867462 -> V=1.0, theta=0.0
% INFO    : Bus 75462	: V=0.9898394, theta=-72.132368 -> V=1.0, theta=0.0
% INFO    : Bus 75463	: V=0.9815206, theta=-65.808706 -> V=1.0, theta=0.0
% INFO    : Bus 75464	: V=0.9671239, theta=-72.947122 -> V=1.0, theta=0.0
% INFO    : Bus 75465	: V=0.9801544, theta=-65.852726 -> V=1.0, theta=0.0
% INFO    : Bus 75466	: V=1.0042109, theta=-75.11355 -> V=1.0, theta=0.0
% INFO    : Bus 75467	: V=1.0038062, theta=-75.1566 -> V=1.0, theta=0.0
% INFO    : Bus 75468	: V=1.013878, theta=-70.247864 -> V=1.0, theta=0.0
% INFO    : Bus 75469	: V=1.0051582, theta=-71.817948 -> V=1.0, theta=0.0
% INFO    : Bus 75470	: V=1.0027772, theta=-72.221392 -> V=1.0, theta=0.0
% INFO    : Bus 75471	: V=1.0093944, theta=-69.650405 -> V=1.0, theta=0.0
% INFO    : Bus 75472	: V=1.0004245, theta=-70.986435 -> V=1.0, theta=0.0
% INFO    : Bus 75473	: V=0.9975517, theta=-71.210658 -> V=1.0, theta=0.0
% INFO    : Bus 75474	: V=1.0094259, theta=-73.12003 -> V=1.0, theta=0.0
% INFO    : Bus 75475	: V=1.015295, theta=-75.027555 -> V=1.0, theta=0.0
% INFO    : Bus 75476	: V=1.0116409, theta=-75.395566 -> V=1.0, theta=0.0
% INFO    : Bus 75477	: V=1.012957, theta=-74.646754 -> V=1.0, theta=0.0
% INFO    : Bus 75478	: V=1.0119454, theta=-74.806398 -> V=1.0, theta=0.0
% INFO    : Bus 75479	: V=1.0030983, theta=-77.882468 -> V=1.0, theta=0.0
% INFO    : Bus 75480	: V=1.0016677, theta=-78.10627 -> V=1.0, theta=0.0
% INFO    : Bus 75481	: V=1.0094485, theta=-77.373427 -> V=1.0, theta=0.0
% INFO    : Bus 75482	: V=1.0051606, theta=-77.871084 -> V=1.0, theta=0.0
% INFO    : Bus 75483	: V=1.0095765, theta=-76.986102 -> V=1.0, theta=0.0
% INFO    : Bus 75484	: V=1.0002104, theta=-78.069014 -> V=1.0, theta=0.0
% INFO    : Bus 75485	: V=0.993694, theta=-78.872579 -> V=1.0, theta=0.0
% INFO    : Bus 75486	: V=1.0090063, theta=-74.732331 -> V=1.0, theta=0.0
% INFO    : Bus 75487	: V=1.007792, theta=-74.951774 -> V=1.0, theta=0.0
% INFO    : Bus 75488	: V=1.0056312, theta=-72.271435 -> V=1.0, theta=0.0
% INFO    : Bus 75489	: V=1.0029463, theta=-72.71225 -> V=1.0, theta=0.0
% INFO    : Bus 75490	: V=0.9995552, theta=-74.177549 -> V=1.0, theta=0.0
% INFO    : Bus 75491	: V=1.0127347, theta=-76.239071 -> V=1.0, theta=0.0
% INFO    : Bus 75492	: V=0.9994509, theta=-73.829955 -> V=1.0, theta=0.0
% INFO    : Bus 75493	: V=1.0186018, theta=-74.606251 -> V=1.0, theta=0.0
% INFO    : Bus 75494	: V=1.0168884, theta=-74.890323 -> V=1.0, theta=0.0
% INFO    : Bus 75495	: V=1.0120136, theta=-75.194624 -> V=1.0, theta=0.0
% INFO    : Bus 75496	: V=1.02, theta=-70.539752 -> V=1.0, theta=0.0
% INFO    : Bus 75497	: V=1.0127788, theta=-77.206703 -> V=1.0, theta=0.0
% INFO    : Bus 75498	: V=0.9938661, theta=-78.813005 -> V=1.0, theta=0.0
% INFO    : Bus 75499	: V=1.0117566, theta=-73.696446 -> V=1.0, theta=0.0
% INFO    : Bus 75500	: V=1.0045317, theta=-73.065868 -> V=1.0, theta=0.0
% INFO    : Bus 75501	: V=0.9649103, theta=-79.613152 -> V=1.0, theta=0.0
% INFO    : Bus 75502	: V=0.9913692, theta=-79.179498 -> V=1.0, theta=0.0
% INFO    : Bus 75503	: V=0.9881999, theta=-77.838239 -> V=1.0, theta=0.0
% INFO    : Bus 75504	: V=0.9922398, theta=-70.129771 -> V=1.0, theta=0.0
% INFO    : Bus 75505	: V=1.0015057, theta=-76.175522 -> V=1.0, theta=0.0
% INFO    : Bus 75506	: V=1.0088315, theta=-76.565318 -> V=1.0, theta=0.0
% INFO    : Bus 75507	: V=0.9674618, theta=-80.767822 -> V=1.0, theta=0.0
% INFO    : Bus 75508	: V=1.004738, theta=-77.698573 -> V=1.0, theta=0.0
% INFO    : Bus 75509	: V=0.9881241, theta=-70.811522 -> V=1.0, theta=0.0
% INFO    : Bus 75510	: V=0.9983602, theta=-73.964871 -> V=1.0, theta=0.0
% INFO    : Bus 75511	: V=1.02, theta=-78.453337 -> V=1.0, theta=0.0
% INFO    : Bus 75512	: V=1.0166416, theta=-79.005052 -> V=1.0, theta=0.0
% INFO    : Bus 75513	: V=1.0050302, theta=-78.413961 -> V=1.0, theta=0.0
% INFO    : Bus 75514	: V=1.02, theta=-73.265179 -> V=1.0, theta=0.0
% INFO    : Bus 75515	: V=1.0054237, theta=-79.413922 -> V=1.0, theta=0.0
% INFO    : Bus 75516	: V=1.0041652, theta=-79.709814 -> V=1.0, theta=0.0
% INFO    : Bus 75517	: V=1.02, theta=-77.178641 -> V=1.0, theta=0.0
% INFO    : Bus 75518	: V=1.02, theta=-76.615648 -> V=1.0, theta=0.0
% INFO    : Bus 75519	: V=1.0205449, theta=-78.446722 -> V=1.0, theta=0.0
% INFO    : Bus 75520	: V=1.0174937, theta=-78.507894 -> V=1.0, theta=0.0
% INFO    : Bus 75521	: V=1.0086205, theta=-77.655537 -> V=1.0, theta=0.0
% INFO    : Bus 75522	: V=1.0047349, theta=-78.211077 -> V=1.0, theta=0.0
% INFO    : Bus 75523	: V=0.9824736, theta=-82.260705 -> V=1.0, theta=0.0
% INFO    : Bus 75524	: V=1.0146454, theta=-76.732787 -> V=1.0, theta=0.0
% INFO    : Bus 75525	: V=1.0145416, theta=-75.965951 -> V=1.0, theta=0.0
% INFO    : Bus 75526	: V=0.9974521, theta=-79.896489 -> V=1.0, theta=0.0
% INFO    : Bus 75527	: V=0.999302, theta=-79.13118 -> V=1.0, theta=0.0
% INFO    : Bus 75528	: V=1.0106085, theta=-80.167273 -> V=1.0, theta=0.0
% INFO    : Bus 75529	: V=0.9851343, theta=-81.135134 -> V=1.0, theta=0.0
% INFO    : Bus 75530	: V=1.0184938, theta=-82.391861 -> V=1.0, theta=0.0
% INFO    : Bus 75531	: V=1.0048235, theta=-79.45195 -> V=1.0, theta=0.0
% INFO    : Bus 75532	: V=1.0202469, theta=-78.4726 -> V=1.0, theta=0.0
% INFO    : Bus 75533	: V=1.0176187, theta=-78.490758 -> V=1.0, theta=0.0
% INFO    : Bus 75534	: V=1.02, theta=-82.151042 -> V=1.0, theta=0.0
% INFO    : Bus 75535	: V=1.0100999, theta=-75.351638 -> V=1.0, theta=0.0
% INFO    : Bus 75536	: V=1.0091478, theta=-75.515649 -> V=1.0, theta=0.0
% INFO    : Bus 75537	: V=1.0157536, theta=-75.482285 -> V=1.0, theta=0.0
% INFO    : Bus 75538	: V=1.0149002, theta=-75.577201 -> V=1.0, theta=0.0
% INFO    : Bus 75539	: V=1.0026277, theta=-76.876706 -> V=1.0, theta=0.0
% INFO    : Bus 75540	: V=1.0020682, theta=-76.955578 -> V=1.0, theta=0.0
% INFO    : Bus 75541	: V=1.0147468, theta=-75.360719 -> V=1.0, theta=0.0
% INFO    : Bus 75542	: V=1.0126911, theta=-75.819149 -> V=1.0, theta=0.0
% INFO    : Bus 75543	: V=1.003574, theta=-77.203487 -> V=1.0, theta=0.0
% INFO    : Bus 75544	: V=1.0002378, theta=-77.633911 -> V=1.0, theta=0.0
% INFO    : Bus 75545	: V=1.0164118, theta=-75.985291 -> V=1.0, theta=0.0
% INFO    : Bus 75546	: V=1.0172473, theta=-76.079012 -> V=1.0, theta=0.0
% INFO    : Bus 75547	: V=1.0085772, theta=-75.46928 -> V=1.0, theta=0.0
% INFO    : Bus 75548	: V=0.9991355, theta=-75.505156 -> V=1.0, theta=0.0
% INFO    : Bus 75549	: V=1.0119372, theta=-76.433676 -> V=1.0, theta=0.0
% INFO    : Bus 75550	: V=1.0199197, theta=-73.644254 -> V=1.0, theta=0.0
% INFO    : Bus 75551	: V=1.0132701, theta=-74.410884 -> V=1.0, theta=0.0
% INFO    : Bus 75552	: V=1.0143624, theta=-74.205242 -> V=1.0, theta=0.0
% INFO    : Bus 75553	: V=1.011692, theta=-76.290925 -> V=1.0, theta=0.0
% INFO    : Bus 75554	: V=1.02, theta=-74.205457 -> V=1.0, theta=0.0
% INFO    : Bus 75555	: V=1.0129158, theta=-68.758811 -> V=1.0, theta=0.0
% INFO    : Bus 75556	: V=0.9832235, theta=-76.772071 -> V=1.0, theta=0.0
% INFO    : Bus 75557	: V=1.0045406, theta=-73.158645 -> V=1.0, theta=0.0
% INFO    : Bus 75558	: V=0.9758467, theta=-66.412542 -> V=1.0, theta=0.0
% INFO    : Bus 75559	: V=0.9771104, theta=-65.933172 -> V=1.0, theta=0.0
% INFO    : Bus 75560	: V=0.9778179, theta=-65.724668 -> V=1.0, theta=0.0
% INFO    : Bus 75561	: V=0.977864, theta=-65.780496 -> V=1.0, theta=0.0
% INFO    : Bus 75562	: V=0.9796108, theta=-65.882808 -> V=1.0, theta=0.0
% INFO    : Bus 75563	: V=0.980363, theta=-65.551121 -> V=1.0, theta=0.0
% INFO    : Bus 75564	: V=0.9811935, theta=-65.477976 -> V=1.0, theta=0.0
% INFO    : Bus 75565	: V=0.9859602, theta=-65.006346 -> V=1.0, theta=0.0
% INFO    : Bus 75566	: V=0.987098, theta=-64.897141 -> V=1.0, theta=0.0
% INFO    : Bus 75567	: V=0.983334, theta=-65.069758 -> V=1.0, theta=0.0
% INFO    : Bus 75568	: V=0.9848731, theta=-65.059606 -> V=1.0, theta=0.0
% INFO    : Bus 75569	: V=0.9848411, theta=-65.108833 -> V=1.0, theta=0.0
% INFO    : Bus 75570	: V=0.9905742, theta=-64.84234 -> V=1.0, theta=0.0
% INFO    : Bus 75571	: V=0.9920973, theta=-64.625667 -> V=1.0, theta=0.0
% INFO    : Bus 75572	: V=0.9913239, theta=-64.799692 -> V=1.0, theta=0.0
% INFO    : Bus 75573	: V=1.0006927, theta=-63.699378 -> V=1.0, theta=0.0
% INFO    : Bus 75574	: V=1.0042625, theta=-63.66491 -> V=1.0, theta=0.0
% INFO    : Bus 75575	: V=1.0104835, theta=-63.044046 -> V=1.0, theta=0.0
% INFO    : Bus 75576	: V=1.0077732, theta=-63.386838 -> V=1.0, theta=0.0
% INFO    : Bus 75577	: V=1.006456, theta=-63.655886 -> V=1.0, theta=0.0
% INFO    : Bus 75578	: V=1.0171973, theta=-62.021538 -> V=1.0, theta=0.0
% INFO    : Bus 75579	: V=1.015508, theta=-62.609814 -> V=1.0, theta=0.0
% INFO    : Bus 75580	: V=1.0132697, theta=-62.939999 -> V=1.0, theta=0.0
% INFO    : Bus 75581	: V=1.012151, theta=-63.062243 -> V=1.0, theta=0.0
% INFO    : Bus 75582	: V=1.0126787, theta=-62.900435 -> V=1.0, theta=0.0
% INFO    : Bus 75583	: V=1.0048666, theta=-63.753297 -> V=1.0, theta=0.0
% INFO    : Bus 75584	: V=1.0065237, theta=-63.729189 -> V=1.0, theta=0.0
% INFO    : Bus 75585	: V=1.0082296, theta=-63.457382 -> V=1.0, theta=0.0
% INFO    : Bus 75586	: V=1.0079978, theta=-63.471052 -> V=1.0, theta=0.0
% INFO    : Bus 75587	: V=1.0050986, theta=-64.179926 -> V=1.0, theta=0.0
% INFO    : Bus 75588	: V=1.0035317, theta=-64.218718 -> V=1.0, theta=0.0
% INFO    : Bus 75589	: V=1.0052179, theta=-64.204347 -> V=1.0, theta=0.0
% INFO    : Bus 75590	: V=1.0066729, theta=-64.137996 -> V=1.0, theta=0.0
% INFO    : Bus 75591	: V=1.0070352, theta=-63.946803 -> V=1.0, theta=0.0
% INFO    : Bus 75592	: V=1.0078196, theta=-63.881712 -> V=1.0, theta=0.0
% INFO    : Bus 75593	: V=1.0084807, theta=-63.865394 -> V=1.0, theta=0.0
% INFO    : Bus 75594	: V=1.0136749, theta=-63.976694 -> V=1.0, theta=0.0
% INFO    : Bus 75595	: V=0.9974742, theta=-65.386772 -> V=1.0, theta=0.0
% INFO    : Bus 75596	: V=0.995673, theta=-65.665857 -> V=1.0, theta=0.0
% INFO    : Bus 75597	: V=0.9964019, theta=-65.87921 -> V=1.0, theta=0.0
% INFO    : Bus 75598	: V=1.0074425, theta=-64.521968 -> V=1.0, theta=0.0
% INFO    : Bus 75599	: V=0.99489, theta=-65.821444 -> V=1.0, theta=0.0
% INFO    : Bus 75600	: V=0.9975555, theta=-65.538293 -> V=1.0, theta=0.0
% INFO    : Bus 75601	: V=0.9749574, theta=-67.801402 -> V=1.0, theta=0.0
% INFO    : Bus 75602	: V=0.9703054, theta=-68.417948 -> V=1.0, theta=0.0
% INFO    : Bus 75603	: V=0.9852968, theta=-66.649075 -> V=1.0, theta=0.0
% INFO    : Bus 75604	: V=0.9771712, theta=-67.263835 -> V=1.0, theta=0.0
% INFO    : Bus 75605	: V=0.9753225, theta=-66.998374 -> V=1.0, theta=0.0
% INFO    : Bus 75606	: V=0.9698253, theta=-68.478273 -> V=1.0, theta=0.0
% INFO    : Bus 75607	: V=0.9780482, theta=-66.338467 -> V=1.0, theta=0.0
% INFO    : Bus 75608	: V=1.0037947, theta=-63.877589 -> V=1.0, theta=0.0
% INFO    : Bus 75609	: V=0.9737222, theta=-71.050865 -> V=1.0, theta=0.0
% INFO    : Bus 75610	: V=0.9748949, theta=-70.93445 -> V=1.0, theta=0.0
% INFO    : Bus 75611	: V=0.9689205, theta=-72.078878 -> V=1.0, theta=0.0
% INFO    : Bus 75612	: V=0.9768709, theta=-70.999412 -> V=1.0, theta=0.0
% INFO    : Bus 75613	: V=0.9720696, theta=-71.481424 -> V=1.0, theta=0.0
% INFO    : Bus 75614	: V=0.9673109, theta=-71.904862 -> V=1.0, theta=0.0
% INFO    : Bus 75615	: V=0.9700768, theta=-71.727499 -> V=1.0, theta=0.0
% INFO    : Bus 75616	: V=0.9691557, theta=-72.175327 -> V=1.0, theta=0.0
% INFO    : Bus 75617	: V=0.9719343, theta=-71.314541 -> V=1.0, theta=0.0
% INFO    : Bus 75618	: V=0.9736046, theta=-71.36038 -> V=1.0, theta=0.0
% INFO    : Bus 75619	: V=0.9709898, theta=-71.486545 -> V=1.0, theta=0.0
% INFO    : Bus 75620	: V=0.9700498, theta=-71.73343 -> V=1.0, theta=0.0
% INFO    : Bus 75621	: V=0.968999, theta=-71.6698 -> V=1.0, theta=0.0
% INFO    : Bus 75622	: V=0.9741292, theta=-70.48462 -> V=1.0, theta=0.0
% INFO    : Bus 75623	: V=0.9758849, theta=-70.286397 -> V=1.0, theta=0.0
% INFO    : Bus 75624	: V=0.9699371, theta=-71.456721 -> V=1.0, theta=0.0
% INFO    : Bus 75625	: V=0.9698366, theta=-72.056885 -> V=1.0, theta=0.0
% INFO    : Bus 75626	: V=0.980094, theta=-70.863089 -> V=1.0, theta=0.0
% INFO    : Bus 75627	: V=0.9725126, theta=-71.82721 -> V=1.0, theta=0.0
% INFO    : Bus 75628	: V=0.9663234, theta=-73.072532 -> V=1.0, theta=0.0
% INFO    : Bus 75629	: V=0.9705216, theta=-74.835969 -> V=1.0, theta=0.0
% INFO    : Bus 75630	: V=0.9789322, theta=-73.752201 -> V=1.0, theta=0.0
% INFO    : Bus 75631	: V=0.9754548, theta=-73.603846 -> V=1.0, theta=0.0
% INFO    : Bus 75632	: V=0.9864707, theta=-73.994693 -> V=1.0, theta=0.0
% INFO    : Bus 75633	: V=0.9879605, theta=-74.759801 -> V=1.0, theta=0.0
% INFO    : Bus 75634	: V=0.9958789, theta=-73.749933 -> V=1.0, theta=0.0
% INFO    : Bus 75635	: V=0.9949827, theta=-73.695452 -> V=1.0, theta=0.0
% INFO    : Bus 75636	: V=0.9661014, theta=-74.445441 -> V=1.0, theta=0.0
% INFO    : Bus 75637	: V=0.9689009, theta=-70.799049 -> V=1.0, theta=0.0
% INFO    : Bus 75638	: V=0.9845946, theta=-70.865875 -> V=1.0, theta=0.0
% INFO    : Bus 75639	: V=0.9795269, theta=-71.419869 -> V=1.0, theta=0.0
% INFO    : Bus 75640	: V=0.9738933, theta=-72.129418 -> V=1.0, theta=0.0
% INFO    : Bus 75641	: V=0.9723915, theta=-71.369559 -> V=1.0, theta=0.0
% INFO    : Bus 75642	: V=0.9757509, theta=-71.015807 -> V=1.0, theta=0.0
% INFO    : Bus 75643	: V=0.9719831, theta=-71.8386 -> V=1.0, theta=0.0
% INFO    : Bus 75644	: V=0.9703425, theta=-72.22156 -> V=1.0, theta=0.0
% INFO    : Bus 75645	: V=0.9728423, theta=-72.327961 -> V=1.0, theta=0.0
% INFO    : Bus 75646	: V=0.9766936, theta=-71.939686 -> V=1.0, theta=0.0
% INFO    : Bus 75647	: V=0.9694729, theta=-72.727117 -> V=1.0, theta=0.0
% INFO    : Bus 75648	: V=0.9710074, theta=-72.627984 -> V=1.0, theta=0.0
% INFO    : Bus 75649	: V=0.9708781, theta=-72.432873 -> V=1.0, theta=0.0
% INFO    : Bus 75650	: V=0.9722725, theta=-72.297052 -> V=1.0, theta=0.0
% INFO    : Bus 75651	: V=0.9713585, theta=-72.303191 -> V=1.0, theta=0.0
% INFO    : Bus 75652	: V=0.9683292, theta=-72.517057 -> V=1.0, theta=0.0
% INFO    : Bus 75653	: V=0.9660922, theta=-73.145025 -> V=1.0, theta=0.0
% INFO    : Bus 75654	: V=0.9677354, theta=-72.533159 -> V=1.0, theta=0.0
% INFO    : Bus 75655	: V=0.9672411, theta=-72.605449 -> V=1.0, theta=0.0
% INFO    : Bus 75656	: V=0.9695654, theta=-72.356987 -> V=1.0, theta=0.0
% INFO    : Bus 75657	: V=0.9718872, theta=-72.338006 -> V=1.0, theta=0.0
% INFO    : Bus 75658	: V=0.9719733, theta=-72.106896 -> V=1.0, theta=0.0
% INFO    : Bus 75659	: V=0.9774163, theta=-71.613538 -> V=1.0, theta=0.0
% INFO    : Bus 75660	: V=0.9737856, theta=-71.770595 -> V=1.0, theta=0.0
% INFO    : Bus 75661	: V=0.9643939, theta=-72.703972 -> V=1.0, theta=0.0
% INFO    : Bus 75662	: V=0.9625631, theta=-72.676623 -> V=1.0, theta=0.0
% INFO    : Bus 75663	: V=0.9653201, theta=-72.477965 -> V=1.0, theta=0.0
% INFO    : Bus 75664	: V=0.970908, theta=-72.002325 -> V=1.0, theta=0.0
% INFO    : Bus 75665	: V=0.9741856, theta=-71.058903 -> V=1.0, theta=0.0
% INFO    : Bus 75666	: V=0.9737645, theta=-71.045279 -> V=1.0, theta=0.0
% INFO    : Bus 75667	: V=0.9705995, theta=-71.114491 -> V=1.0, theta=0.0
% INFO    : Bus 75668	: V=0.9869379, theta=-73.613944 -> V=1.0, theta=0.0
% INFO    : Bus 75669	: V=0.9677443, theta=-72.504546 -> V=1.0, theta=0.0
% INFO    : Bus 75670	: V=0.9810415, theta=-68.863203 -> V=1.0, theta=0.0
% INFO    : Bus 75671	: V=0.9678008, theta=-73.633193 -> V=1.0, theta=0.0
% INFO    : Bus 75672	: V=0.9638862, theta=-76.163614 -> V=1.0, theta=0.0
% INFO    : Bus 75673	: V=0.9624841, theta=-70.694535 -> V=1.0, theta=0.0
% INFO    : Bus 75674	: V=0.9635942, theta=-71.678836 -> V=1.0, theta=0.0
% INFO    : Bus 75675	: V=0.9749874, theta=-70.257811 -> V=1.0, theta=0.0
% INFO    : Bus 75676	: V=0.9828607, theta=-69.376481 -> V=1.0, theta=0.0
% INFO    : Bus 75677	: V=0.9808291, theta=-70.310478 -> V=1.0, theta=0.0
% INFO    : Bus 75678	: V=0.97182, theta=-70.846358 -> V=1.0, theta=0.0
% INFO    : Bus 75679	: V=0.9646549, theta=-71.302493 -> V=1.0, theta=0.0
% INFO    : Bus 75680	: V=0.9850618, theta=-68.351335 -> V=1.0, theta=0.0
% INFO    : Bus 75681	: V=0.9905394, theta=-68.129159 -> V=1.0, theta=0.0
% INFO    : Bus 75682	: V=0.9869735, theta=-67.272597 -> V=1.0, theta=0.0
% INFO    : Bus 75683	: V=0.9861533, theta=-67.783336 -> V=1.0, theta=0.0
% INFO    : Bus 75684	: V=0.9901985, theta=-66.709263 -> V=1.0, theta=0.0
% INFO    : Bus 75685	: V=0.9856783, theta=-67.138877 -> V=1.0, theta=0.0
% INFO    : Bus 75686	: V=0.9768327, theta=-69.584988 -> V=1.0, theta=0.0
% INFO    : Bus 75687	: V=0.995478, theta=-66.308994 -> V=1.0, theta=0.0
% INFO    : Bus 75688	: V=0.9905088, theta=-66.450353 -> V=1.0, theta=0.0
% INFO    : Bus 75689	: V=0.9894702, theta=-66.734561 -> V=1.0, theta=0.0
% INFO    : Bus 75690	: V=0.9901428, theta=-66.691527 -> V=1.0, theta=0.0
% INFO    : Bus 75691	: V=0.9948625, theta=-66.415364 -> V=1.0, theta=0.0
% INFO    : Bus 75692	: V=0.9924014, theta=-66.701119 -> V=1.0, theta=0.0
% INFO    : Bus 75693	: V=0.9909038, theta=-66.926933 -> V=1.0, theta=0.0
% INFO    : Bus 75694	: V=0.9912589, theta=-66.997684 -> V=1.0, theta=0.0
% INFO    : Bus 75695	: V=0.9924261, theta=-66.950167 -> V=1.0, theta=0.0
% INFO    : Bus 75696	: V=0.9878846, theta=-67.354176 -> V=1.0, theta=0.0
% INFO    : Bus 75697	: V=0.9876836, theta=-67.356724 -> V=1.0, theta=0.0
% INFO    : Bus 75698	: V=1.0006849, theta=-66.010575 -> V=1.0, theta=0.0
% INFO    : Bus 75699	: V=0.9968095, theta=-66.501041 -> V=1.0, theta=0.0
% INFO    : Bus 75700	: V=1.0091109, theta=-64.616099 -> V=1.0, theta=0.0
% INFO    : Bus 75701	: V=1.0046206, theta=-65.116802 -> V=1.0, theta=0.0
% INFO    : Bus 75702	: V=0.9928297, theta=-66.695374 -> V=1.0, theta=0.0
% INFO    : Bus 75703	: V=0.9962984, theta=-66.223741 -> V=1.0, theta=0.0
% INFO    : Bus 75704	: V=0.9983082, theta=-66.007841 -> V=1.0, theta=0.0
% INFO    : Bus 75705	: V=0.9909401, theta=-67.145557 -> V=1.0, theta=0.0
% INFO    : Bus 75706	: V=0.9904636, theta=-67.195611 -> V=1.0, theta=0.0
% INFO    : Bus 75707	: V=0.9895881, theta=-67.536468 -> V=1.0, theta=0.0
% INFO    : Bus 75708	: V=0.9813892, theta=-68.740745 -> V=1.0, theta=0.0
% INFO    : Bus 75709	: V=0.9875361, theta=-67.84581 -> V=1.0, theta=0.0
% INFO    : Bus 75710	: V=0.9859037, theta=-67.991031 -> V=1.0, theta=0.0
% INFO    : Bus 75711	: V=0.9893419, theta=-67.311991 -> V=1.0, theta=0.0
% INFO    : Bus 75712	: V=0.9785472, theta=-70.111743 -> V=1.0, theta=0.0
% INFO    : Bus 75713	: V=0.9811554, theta=-69.369162 -> V=1.0, theta=0.0
% INFO    : Bus 75714	: V=0.9841383, theta=-69.296939 -> V=1.0, theta=0.0
% INFO    : Bus 75715	: V=0.9836381, theta=-69.453116 -> V=1.0, theta=0.0
% INFO    : Bus 75716	: V=0.9896351, theta=-68.839181 -> V=1.0, theta=0.0
% INFO    : Bus 75717	: V=0.9845904, theta=-69.498329 -> V=1.0, theta=0.0
% INFO    : Bus 75718	: V=0.9880372, theta=-68.879555 -> V=1.0, theta=0.0
% INFO    : Bus 75719	: V=0.9853657, theta=-67.745108 -> V=1.0, theta=0.0
% INFO    : Bus 75720	: V=0.9877445, theta=-67.333114 -> V=1.0, theta=0.0
% INFO    : Bus 75721	: V=0.9843843, theta=-67.790477 -> V=1.0, theta=0.0
% INFO    : Bus 75722	: V=0.9842945, theta=-69.307091 -> V=1.0, theta=0.0
% INFO    : Bus 75723	: V=0.972837, theta=-70.003239 -> V=1.0, theta=0.0
% INFO    : Bus 75724	: V=0.9841387, theta=-68.585156 -> V=1.0, theta=0.0
% INFO    : Bus 75725	: V=0.967575, theta=-69.742437 -> V=1.0, theta=0.0
% INFO    : Bus 75726	: V=0.9770827, theta=-68.410554 -> V=1.0, theta=0.0
% INFO    : Bus 75727	: V=0.980832, theta=-67.809868 -> V=1.0, theta=0.0
% INFO    : Bus 75728	: V=0.9775576, theta=-68.348985 -> V=1.0, theta=0.0
% INFO    : Bus 75729	: V=0.9708386, theta=-69.66023 -> V=1.0, theta=0.0
% INFO    : Bus 75730	: V=0.9692741, theta=-69.890807 -> V=1.0, theta=0.0
% INFO    : Bus 75731	: V=0.9756769, theta=-68.879965 -> V=1.0, theta=0.0
% INFO    : Bus 75732	: V=0.9555598, theta=-71.407823 -> V=1.0, theta=0.0
% INFO    : Bus 75733	: V=0.967407, theta=-69.929146 -> V=1.0, theta=0.0
% INFO    : Bus 75734	: V=0.9650934, theta=-70.221414 -> V=1.0, theta=0.0
% INFO    : Bus 75735	: V=0.9684897, theta=-70.037519 -> V=1.0, theta=0.0
% INFO    : Bus 75736	: V=0.9904817, theta=-66.975253 -> V=1.0, theta=0.0
% INFO    : Bus 75737	: V=0.9907323, theta=-66.975119 -> V=1.0, theta=0.0
% INFO    : Bus 75738	: V=0.9929527, theta=-66.672911 -> V=1.0, theta=0.0
% INFO    : Bus 75739	: V=1.0072518, theta=-65.239623 -> V=1.0, theta=0.0
% INFO    : Bus 75740	: V=1.0008365, theta=-66.274743 -> V=1.0, theta=0.0
% INFO    : Bus 75741	: V=0.9778366, theta=-69.619859 -> V=1.0, theta=0.0
% INFO    : Bus 75742	: V=0.98513, theta=-68.748138 -> V=1.0, theta=0.0
% INFO    : Bus 75743	: V=1.0020376, theta=-66.878034 -> V=1.0, theta=0.0
% INFO    : Bus 75744	: V=1.0102359, theta=-64.261184 -> V=1.0, theta=0.0
% INFO    : Bus 75745	: V=1.0085327, theta=-64.514851 -> V=1.0, theta=0.0
% INFO    : Bus 75746	: V=1.003651, theta=-65.302536 -> V=1.0, theta=0.0
% INFO    : Bus 75747	: V=0.9953425, theta=-66.068548 -> V=1.0, theta=0.0
% INFO    : Bus 75748	: V=0.9923762, theta=-67.253804 -> V=1.0, theta=0.0
% INFO    : Bus 75749	: V=0.9998122, theta=-65.75309 -> V=1.0, theta=0.0
% INFO    : Bus 75750	: V=0.9843189, theta=-69.741063 -> V=1.0, theta=0.0
% INFO    : Bus 75751	: V=0.9847926, theta=-69.752052 -> V=1.0, theta=0.0
% INFO    : Bus 75752	: V=0.9888159, theta=-67.853873 -> V=1.0, theta=0.0
% INFO    : Bus 75753	: V=1.0008304, theta=-65.892967 -> V=1.0, theta=0.0
% INFO    : Bus 75754	: V=1.0042007, theta=-65.765195 -> V=1.0, theta=0.0
% INFO    : Bus 75755	: V=1.0100164, theta=-65.073238 -> V=1.0, theta=0.0
% INFO    : Bus 75756	: V=1.0098831, theta=-64.959273 -> V=1.0, theta=0.0
% INFO    : Bus 75757	: V=0.9689553, theta=-70.735969 -> V=1.0, theta=0.0
% INFO    : Bus 75758	: V=0.9806296, theta=-71.555986 -> V=1.0, theta=0.0
% INFO    : Bus 75759	: V=0.9707177, theta=-73.127084 -> V=1.0, theta=0.0
% INFO    : Bus 75760	: V=0.9769411, theta=-70.699904 -> V=1.0, theta=0.0
% INFO    : Bus 75761	: V=0.980219, theta=-70.27201 -> V=1.0, theta=0.0
% INFO    : Bus 75762	: V=0.9884804, theta=-71.89126 -> V=1.0, theta=0.0
% INFO    : Bus 75763	: V=0.9979698, theta=-71.978731 -> V=1.0, theta=0.0
% INFO    : Bus 75764	: V=1.0033081, theta=-72.597311 -> V=1.0, theta=0.0
% INFO    : Bus 75765	: V=0.9991768, theta=-72.1322 -> V=1.0, theta=0.0
% INFO    : Bus 75766	: V=0.9903686, theta=-71.526127 -> V=1.0, theta=0.0
% INFO    : Bus 75767	: V=0.9773163, theta=-73.098365 -> V=1.0, theta=0.0
% INFO    : Bus 75768	: V=0.9906974, theta=-79.309145 -> V=1.0, theta=0.0
% INFO    : Bus 75769	: V=0.9982987, theta=-78.495622 -> V=1.0, theta=0.0
% INFO    : Bus 75770	: V=0.9929336, theta=-79.200326 -> V=1.0, theta=0.0
% INFO    : Bus 75771	: V=0.98942, theta=-79.416458 -> V=1.0, theta=0.0
% INFO    : Bus 75772	: V=0.9876927, theta=-79.534697 -> V=1.0, theta=0.0
% INFO    : Bus 75773	: V=0.9858763, theta=-79.573354 -> V=1.0, theta=0.0
% INFO    : Bus 75774	: V=0.9815423, theta=-80.041369 -> V=1.0, theta=0.0
% INFO    : Bus 75775	: V=0.9823106, theta=-79.912018 -> V=1.0, theta=0.0
% INFO    : Bus 75776	: V=0.9834145, theta=-80.034709 -> V=1.0, theta=0.0
% INFO    : Bus 75777	: V=0.9911438, theta=-79.824061 -> V=1.0, theta=0.0
% INFO    : Bus 75778	: V=1.0124691, theta=-82.013527 -> V=1.0, theta=0.0
% INFO    : Bus 75779	: V=1.0133593, theta=-81.656016 -> V=1.0, theta=0.0
% INFO    : Bus 75780	: V=1.0076066, theta=-81.666304 -> V=1.0, theta=0.0
% INFO    : Bus 75781	: V=0.9886639, theta=-80.576316 -> V=1.0, theta=0.0
% INFO    : Bus 75782	: V=1.0063127, theta=-80.207607 -> V=1.0, theta=0.0
% INFO    : Bus 75783	: V=0.9973671, theta=-79.031636 -> V=1.0, theta=0.0
% INFO    : Bus 75784	: V=0.9967981, theta=-79.097845 -> V=1.0, theta=0.0
% INFO    : Bus 75785	: V=0.9933365, theta=-79.441253 -> V=1.0, theta=0.0
% INFO    : Bus 75786	: V=1.0078095, theta=-77.69304 -> V=1.0, theta=0.0
% INFO    : Bus 75787	: V=0.9905185, theta=-79.691883 -> V=1.0, theta=0.0
% INFO    : Bus 75788	: V=0.993907, theta=-79.390571 -> V=1.0, theta=0.0
% INFO    : Bus 75789	: V=1.0043878, theta=-78.405157 -> V=1.0, theta=0.0
% INFO    : Bus 75790	: V=1.0003767, theta=-78.870189 -> V=1.0, theta=0.0
% INFO    : Bus 75791	: V=0.998147, theta=-79.004032 -> V=1.0, theta=0.0
% INFO    : Bus 75792	: V=0.9962082, theta=-79.18896 -> V=1.0, theta=0.0
% INFO    : Bus 75793	: V=0.9912914, theta=-79.425472 -> V=1.0, theta=0.0
% INFO    : Bus 75794	: V=0.9935274, theta=-79.300392 -> V=1.0, theta=0.0
% INFO    : Bus 75795	: V=0.9919322, theta=-79.630662 -> V=1.0, theta=0.0
% INFO    : Bus 75796	: V=0.9952939, theta=-79.08414 -> V=1.0, theta=0.0
% INFO    : Bus 75797	: V=0.979562, theta=-80.209036 -> V=1.0, theta=0.0
% INFO    : Bus 75798	: V=0.9970716, theta=-79.118529 -> V=1.0, theta=0.0
% INFO    : Bus 75799	: V=0.9906279, theta=-79.858997 -> V=1.0, theta=0.0
% INFO    : Bus 75800	: V=0.9875807, theta=-79.87966 -> V=1.0, theta=0.0
% INFO    : Bus 75801	: V=0.9939242, theta=-78.995524 -> V=1.0, theta=0.0
% INFO    : Bus 75802	: V=0.9824024, theta=-80.189875 -> V=1.0, theta=0.0
% INFO    : Bus 75803	: V=1.0029769, theta=-78.3898 -> V=1.0, theta=0.0
% INFO    : Bus 75804	: V=1.0040094, theta=-78.496959 -> V=1.0, theta=0.0
% INFO    : Bus 75805	: V=1.0079556, theta=-79.072867 -> V=1.0, theta=0.0
% INFO    : Bus 75806	: V=1.0003749, theta=-80.568873 -> V=1.0, theta=0.0
% INFO    : Bus 75807	: V=0.9766969, theta=-81.925276 -> V=1.0, theta=0.0
% INFO    : Bus 75808	: V=0.9696638, theta=-82.945351 -> V=1.0, theta=0.0
% INFO    : Bus 75809	: V=0.964999, theta=-82.794252 -> V=1.0, theta=0.0
% INFO    : Bus 75810	: V=0.9576585, theta=-83.770287 -> V=1.0, theta=0.0
% INFO    : Bus 75811	: V=0.9751351, theta=-82.574568 -> V=1.0, theta=0.0
% INFO    : Bus 75812	: V=0.9675506, theta=-82.950499 -> V=1.0, theta=0.0
% INFO    : Bus 75813	: V=0.966942, theta=-82.93076 -> V=1.0, theta=0.0
% INFO    : Bus 75814	: V=0.9688608, theta=-82.936294 -> V=1.0, theta=0.0
% INFO    : Bus 75815	: V=0.9653018, theta=-83.004231 -> V=1.0, theta=0.0
% INFO    : Bus 75816	: V=0.9649791, theta=-83.014555 -> V=1.0, theta=0.0
% INFO    : Bus 75817	: V=0.9663955, theta=-82.583784 -> V=1.0, theta=0.0
% INFO    : Bus 75818	: V=0.9562146, theta=-84.141052 -> V=1.0, theta=0.0
% INFO    : Bus 75819	: V=0.9955083, theta=-77.948334 -> V=1.0, theta=0.0
% INFO    : Bus 75820	: V=1.0097966, theta=-76.369526 -> V=1.0, theta=0.0
% INFO    : Bus 75821	: V=1.0185215, theta=-75.426102 -> V=1.0, theta=0.0
% INFO    : Bus 75822	: V=1.0155959, theta=-75.883631 -> V=1.0, theta=0.0
% INFO    : Bus 75823	: V=0.9900286, theta=-79.449674 -> V=1.0, theta=0.0
% INFO    : Bus 75824	: V=0.9907998, theta=-79.150176 -> V=1.0, theta=0.0
% INFO    : Bus 75825	: V=0.9955168, theta=-80.519095 -> V=1.0, theta=0.0
% INFO    : Bus 75826	: V=1.0010754, theta=-79.781314 -> V=1.0, theta=0.0
% INFO    : Bus 75827	: V=0.9913982, theta=-81.004735 -> V=1.0, theta=0.0
% INFO    : Bus 75828	: V=0.9967585, theta=-80.520784 -> V=1.0, theta=0.0
% INFO    : Bus 75829	: V=0.9960324, theta=-80.505612 -> V=1.0, theta=0.0
% INFO    : Bus 75830	: V=0.9911049, theta=-80.933661 -> V=1.0, theta=0.0
% INFO    : Bus 75831	: V=0.9846629, theta=-81.250973 -> V=1.0, theta=0.0
% INFO    : Bus 75832	: V=0.9676811, theta=-82.613409 -> V=1.0, theta=0.0
% INFO    : Bus 75833	: V=0.9807267, theta=-80.843338 -> V=1.0, theta=0.0
% INFO    : Bus 75834	: V=1.0035418, theta=-79.208984 -> V=1.0, theta=0.0
% INFO    : Bus 75835	: V=1.0106796, theta=-79.236888 -> V=1.0, theta=0.0
% INFO    : Bus 75836	: V=1.0138463, theta=-77.839631 -> V=1.0, theta=0.0
% INFO    : Bus 75837	: V=0.9913099, theta=-80.766314 -> V=1.0, theta=0.0
% INFO    : Bus 75838	: V=0.9717771, theta=-82.017993 -> V=1.0, theta=0.0
% INFO    : Bus 75839	: V=0.9774593, theta=-81.821003 -> V=1.0, theta=0.0
% INFO    : Bus 75840	: V=0.9945681, theta=-79.825677 -> V=1.0, theta=0.0
% INFO    : Bus 75841	: V=0.9850087, theta=-80.286256 -> V=1.0, theta=0.0
% INFO    : Bus 75842	: V=0.9670802, theta=-82.871367 -> V=1.0, theta=0.0
% INFO    : Bus 75843	: V=0.9710352, theta=-82.686933 -> V=1.0, theta=0.0
% INFO    : Bus 75844	: V=0.9825788, theta=-81.70066 -> V=1.0, theta=0.0
% INFO    : Bus 75845	: V=0.9748889, theta=-82.534611 -> V=1.0, theta=0.0
% INFO    : Bus 75846	: V=0.9706266, theta=-82.405721 -> V=1.0, theta=0.0
% INFO    : Bus 75847	: V=1.0100578, theta=-79.191856 -> V=1.0, theta=0.0
% INFO    : Bus 75848	: V=1.0091416, theta=-79.476542 -> V=1.0, theta=0.0
% INFO    : Bus 75849	: V=0.9761432, theta=-81.627464 -> V=1.0, theta=0.0
% INFO    : Bus 75850	: V=0.970918, theta=-82.302828 -> V=1.0, theta=0.0
% INFO    : Bus 75851	: V=1.0134415, theta=-82.142424 -> V=1.0, theta=0.0
% INFO    : Bus 75852	: V=0.995517, theta=-83.657874 -> V=1.0, theta=0.0
% INFO    : Bus 75853	: V=0.9965018, theta=-83.238208 -> V=1.0, theta=0.0
% INFO    : Bus 75854	: V=0.9828074, theta=-79.838677 -> V=1.0, theta=0.0
% INFO    : Bus 75855	: V=0.9811415, theta=-79.673365 -> V=1.0, theta=0.0
% INFO    : Bus 75856	: V=0.9716221, theta=-80.781183 -> V=1.0, theta=0.0
% INFO    : Bus 75857	: V=0.9808363, theta=-79.885336 -> V=1.0, theta=0.0
% INFO    : Bus 75858	: V=0.9783866, theta=-80.018259 -> V=1.0, theta=0.0
% INFO    : Bus 75859	: V=0.9791588, theta=-79.599865 -> V=1.0, theta=0.0
% INFO    : Bus 75860	: V=0.9684785, theta=-79.916929 -> V=1.0, theta=0.0
% INFO    : Bus 75861	: V=0.9753988, theta=-79.309191 -> V=1.0, theta=0.0
% INFO    : Bus 75862	: V=0.9804123, theta=-79.289866 -> V=1.0, theta=0.0
% INFO    : Bus 75863	: V=0.9952417, theta=-77.219822 -> V=1.0, theta=0.0
% INFO    : Bus 75864	: V=0.9691694, theta=-78.306319 -> V=1.0, theta=0.0
% INFO    : Bus 75865	: V=0.9737591, theta=-78.247875 -> V=1.0, theta=0.0
% INFO    : Bus 75866	: V=0.9793149, theta=-77.289112 -> V=1.0, theta=0.0
% INFO    : Bus 75867	: V=0.9850746, theta=-76.945784 -> V=1.0, theta=0.0
% INFO    : Bus 75868	: V=0.9829328, theta=-76.938744 -> V=1.0, theta=0.0
% INFO    : Bus 75869	: V=1.003439, theta=-75.135152 -> V=1.0, theta=0.0
% INFO    : Bus 75870	: V=0.9960999, theta=-76.198614 -> V=1.0, theta=0.0
% INFO    : Bus 75871	: V=0.9981037, theta=-76.155418 -> V=1.0, theta=0.0
% INFO    : Bus 75872	: V=0.9677483, theta=-78.393932 -> V=1.0, theta=0.0
% INFO    : Bus 75873	: V=0.9779736, theta=-77.351239 -> V=1.0, theta=0.0
% INFO    : Bus 75874	: V=0.978867, theta=-77.337449 -> V=1.0, theta=0.0
% INFO    : Bus 75875	: V=0.9739881, theta=-77.688173 -> V=1.0, theta=0.0
% INFO    : Bus 75876	: V=0.9941304, theta=-75.839472 -> V=1.0, theta=0.0
% INFO    : Bus 75877	: V=0.98676, theta=-76.855851 -> V=1.0, theta=0.0
% INFO    : Bus 75878	: V=0.9839379, theta=-70.295009 -> V=1.0, theta=0.0
% INFO    : Bus 75879	: V=0.9920165, theta=-70.080321 -> V=1.0, theta=0.0
% INFO    : Bus 75880	: V=0.9907988, theta=-70.2238 -> V=1.0, theta=0.0
% INFO    : Bus 75881	: V=0.9696951, theta=-74.498686 -> V=1.0, theta=0.0
% INFO    : Bus 75882	: V=0.9783496, theta=-72.737689 -> V=1.0, theta=0.0
% INFO    : Bus 75883	: V=0.9837234, theta=-71.765742 -> V=1.0, theta=0.0
% INFO    : Bus 75884	: V=0.9765387, theta=-72.915339 -> V=1.0, theta=0.0
% INFO    : Bus 75885	: V=0.9851489, theta=-71.74285 -> V=1.0, theta=0.0
% INFO    : Bus 75886	: V=0.9886248, theta=-77.858081 -> V=1.0, theta=0.0
% INFO    : Bus 75887	: V=0.9849937, theta=-77.890553 -> V=1.0, theta=0.0
% INFO    : Bus 75888	: V=0.9771452, theta=-78.237736 -> V=1.0, theta=0.0
% INFO    : Bus 75889	: V=0.9862883, theta=-77.897666 -> V=1.0, theta=0.0
% INFO    : Bus 75890	: V=0.9851767, theta=-78.029251 -> V=1.0, theta=0.0
% INFO    : Bus 75891	: V=0.9920396, theta=-77.676486 -> V=1.0, theta=0.0
% INFO    : Bus 75892	: V=0.9938324, theta=-78.016363 -> V=1.0, theta=0.0
% INFO    : Bus 75893	: V=0.9875831, theta=-77.980883 -> V=1.0, theta=0.0
% INFO    : Bus 75894	: V=1.0010721, theta=-76.60277 -> V=1.0, theta=0.0
% INFO    : Bus 75895	: V=0.9983816, theta=-77.059166 -> V=1.0, theta=0.0
% INFO    : Bus 75896	: V=0.9976336, theta=-77.615453 -> V=1.0, theta=0.0
% INFO    : Bus 75897	: V=1.0081525, theta=-76.897788 -> V=1.0, theta=0.0
% INFO    : Bus 75898	: V=0.9924957, theta=-76.616989 -> V=1.0, theta=0.0
% INFO    : Bus 75899	: V=0.9831095, theta=-77.73355 -> V=1.0, theta=0.0
% INFO    : Bus 75900	: V=0.9896604, theta=-77.138983 -> V=1.0, theta=0.0
% INFO    : Bus 75901	: V=0.9893199, theta=-77.658104 -> V=1.0, theta=0.0
% INFO    : Bus 75902	: V=0.9855104, theta=-78.052196 -> V=1.0, theta=0.0
% INFO    : Bus 75903	: V=0.989043, theta=-78.309608 -> V=1.0, theta=0.0
% INFO    : Bus 75904	: V=0.9984796, theta=-75.604343 -> V=1.0, theta=0.0
% INFO    : Bus 75905	: V=0.984515, theta=-77.434162 -> V=1.0, theta=0.0
% INFO    : Bus 75906	: V=0.9910353, theta=-76.228998 -> V=1.0, theta=0.0
% INFO    : Bus 75907	: V=0.9872308, theta=-76.855014 -> V=1.0, theta=0.0
% INFO    : Bus 75908	: V=1.0043122, theta=-75.117995 -> V=1.0, theta=0.0
% INFO    : Bus 75909	: V=0.9967457, theta=-76.167094 -> V=1.0, theta=0.0
% INFO    : Bus 75910	: V=0.9927775, theta=-76.549776 -> V=1.0, theta=0.0
% INFO    : Bus 75911	: V=0.9942625, theta=-76.073251 -> V=1.0, theta=0.0
% INFO    : Bus 75912	: V=0.9836592, theta=-77.398278 -> V=1.0, theta=0.0
% INFO    : Bus 75913	: V=0.978606, theta=-77.760158 -> V=1.0, theta=0.0
% INFO    : Bus 75914	: V=0.9797751, theta=-77.534418 -> V=1.0, theta=0.0
% INFO    : Bus 75915	: V=0.9811362, theta=-77.395455 -> V=1.0, theta=0.0
% INFO    : Bus 75916	: V=0.984827, theta=-77.028789 -> V=1.0, theta=0.0
% INFO    : Bus 75917	: V=0.9828473, theta=-77.319568 -> V=1.0, theta=0.0
% INFO    : Bus 75918	: V=0.9618028, theta=-79.106552 -> V=1.0, theta=0.0
% INFO    : Bus 75919	: V=0.9679843, theta=-80.977253 -> V=1.0, theta=0.0
% INFO    : Bus 75920	: V=0.9636873, theta=-81.101598 -> V=1.0, theta=0.0
% INFO    : Bus 75921	: V=0.9708113, theta=-81.067115 -> V=1.0, theta=0.0
% INFO    : Bus 75922	: V=0.9887745, theta=-79.356759 -> V=1.0, theta=0.0
% INFO    : Bus 75923	: V=0.9884844, theta=-79.391017 -> V=1.0, theta=0.0
% INFO    : Bus 75924	: V=0.9800571, theta=-80.080045 -> V=1.0, theta=0.0
% INFO    : Bus 75925	: V=0.9836487, theta=-79.844336 -> V=1.0, theta=0.0
% INFO    : Bus 75926	: V=0.9801337, theta=-80.039222 -> V=1.0, theta=0.0
% INFO    : Bus 75927	: V=0.9666813, theta=-80.773887 -> V=1.0, theta=0.0
% INFO    : Bus 75928	: V=0.9668122, theta=-80.86418 -> V=1.0, theta=0.0
% INFO    : Bus 75929	: V=0.9719259, theta=-80.134933 -> V=1.0, theta=0.0
% INFO    : Bus 75930	: V=0.9728387, theta=-80.020198 -> V=1.0, theta=0.0
% INFO    : Bus 75931	: V=0.9778823, theta=-78.761054 -> V=1.0, theta=0.0
% INFO    : Bus 75932	: V=0.9719834, theta=-80.026819 -> V=1.0, theta=0.0
% INFO    : Bus 75933	: V=0.9703538, theta=-80.114628 -> V=1.0, theta=0.0
% INFO    : Bus 75934	: V=0.9623043, theta=-80.496108 -> V=1.0, theta=0.0
% INFO    : Bus 75935	: V=0.9623557, theta=-80.458499 -> V=1.0, theta=0.0
% INFO    : Bus 75936	: V=0.9941086, theta=-77.74613 -> V=1.0, theta=0.0
% INFO    : Bus 75937	: V=0.9909756, theta=-78.119006 -> V=1.0, theta=0.0
% INFO    : Bus 75938	: V=0.977895, theta=-78.591245 -> V=1.0, theta=0.0
% INFO    : Bus 75939	: V=0.9740444, theta=-78.981192 -> V=1.0, theta=0.0
% INFO    : Bus 75940	: V=0.977611, theta=-78.588022 -> V=1.0, theta=0.0
% INFO    : Bus 75941	: V=0.9758707, theta=-78.605696 -> V=1.0, theta=0.0
% INFO    : Bus 75942	: V=0.976553, theta=-78.600647 -> V=1.0, theta=0.0
% INFO    : Bus 75943	: V=0.9736092, theta=-78.994317 -> V=1.0, theta=0.0
% INFO    : Bus 75944	: V=0.9782419, theta=-78.550561 -> V=1.0, theta=0.0
% INFO    : Bus 75945	: V=0.9734723, theta=-79.013437 -> V=1.0, theta=0.0
% INFO    : Bus 75946	: V=0.9699019, theta=-79.135053 -> V=1.0, theta=0.0
% INFO    : Bus 75947	: V=0.9740328, theta=-78.800495 -> V=1.0, theta=0.0
% INFO    : Bus 75948	: V=0.9870757, theta=-77.510966 -> V=1.0, theta=0.0
% INFO    : Bus 75949	: V=0.9803119, theta=-78.531244 -> V=1.0, theta=0.0
% INFO    : Bus 75950	: V=0.973213, theta=-79.09511 -> V=1.0, theta=0.0
% INFO    : Bus 75951	: V=0.9850539, theta=-77.51537 -> V=1.0, theta=0.0
% INFO    : Bus 75952	: V=0.9810842, theta=-78.230851 -> V=1.0, theta=0.0
% INFO    : Bus 75953	: V=0.9825528, theta=-78.083265 -> V=1.0, theta=0.0
% INFO    : Bus 75954	: V=0.9868686, theta=-77.838762 -> V=1.0, theta=0.0
% INFO    : Bus 75955	: V=0.9875746, theta=-77.511148 -> V=1.0, theta=0.0
% INFO    : Bus 75956	: V=0.9854718, theta=-77.661411 -> V=1.0, theta=0.0
% INFO    : Bus 75957	: V=0.9803543, theta=-78.321941 -> V=1.0, theta=0.0
% INFO    : Bus 75958	: V=0.9898023, theta=-77.542295 -> V=1.0, theta=0.0
% INFO    : Bus 75959	: V=0.9946448, theta=-77.176263 -> V=1.0, theta=0.0
% INFO    : Bus 75960	: V=0.9885712, theta=-78.048113 -> V=1.0, theta=0.0
% INFO    : Bus 75961	: V=0.9970262, theta=-77.123204 -> V=1.0, theta=0.0
% INFO    : Bus 75962	: V=0.9915196, theta=-77.747771 -> V=1.0, theta=0.0
% INFO    : Bus 75963	: V=0.9998712, theta=-72.707537 -> V=1.0, theta=0.0
% INFO    : Bus 75964	: V=0.9910922, theta=-73.953789 -> V=1.0, theta=0.0
% INFO    : Bus 75965	: V=1.0034074, theta=-73.177046 -> V=1.0, theta=0.0
% INFO    : Bus 75966	: V=1.0013918, theta=-73.110365 -> V=1.0, theta=0.0
% INFO    : Bus 75967	: V=0.9996319, theta=-74.208779 -> V=1.0, theta=0.0
% INFO    : Bus 75968	: V=1.0002901, theta=-73.065106 -> V=1.0, theta=0.0
% INFO    : Bus 75969	: V=1.0090102, theta=-71.67313 -> V=1.0, theta=0.0
% INFO    : Bus 75970	: V=0.9964, theta=-73.429624 -> V=1.0, theta=0.0
% INFO    : Bus 75971	: V=0.9971431, theta=-73.406716 -> V=1.0, theta=0.0
% INFO    : Bus 75972	: V=0.9998567, theta=-72.905373 -> V=1.0, theta=0.0
% INFO    : Bus 75973	: V=1.0030776, theta=-72.516962 -> V=1.0, theta=0.0
% INFO    : Bus 75974	: V=1.003994, theta=-72.346036 -> V=1.0, theta=0.0
% INFO    : Bus 75975	: V=1.0024628, theta=-72.530969 -> V=1.0, theta=0.0
% INFO    : Bus 75976	: V=0.9802466, theta=-74.627478 -> V=1.0, theta=0.0
% INFO    : Bus 75977	: V=0.9957046, theta=-73.470602 -> V=1.0, theta=0.0
% INFO    : Bus 75978	: V=1.0150068, theta=-70.985214 -> V=1.0, theta=0.0
% INFO    : Bus 75979	: V=0.9961479, theta=-73.311134 -> V=1.0, theta=0.0
% INFO    : Bus 75980	: V=0.996618, theta=-72.723908 -> V=1.0, theta=0.0
% INFO    : Bus 75981	: V=1.0091654, theta=-71.582658 -> V=1.0, theta=0.0
% INFO    : Bus 75982	: V=1.0062435, theta=-72.003838 -> V=1.0, theta=0.0
% INFO    : Bus 75983	: V=0.9972236, theta=-73.917127 -> V=1.0, theta=0.0
% INFO    : Bus 75984	: V=0.9885053, theta=-74.004532 -> V=1.0, theta=0.0
% INFO    : Bus 75985	: V=0.9898717, theta=-73.738819 -> V=1.0, theta=0.0
% INFO    : Bus 75986	: V=0.9869226, theta=-74.186721 -> V=1.0, theta=0.0
% INFO    : Bus 75987	: V=0.9869412, theta=-73.914282 -> V=1.0, theta=0.0
% INFO    : Bus 75988	: V=0.9703317, theta=-75.413489 -> V=1.0, theta=0.0
% INFO    : Bus 75989	: V=0.9745219, theta=-75.20568 -> V=1.0, theta=0.0
% INFO    : Bus 75990	: V=0.9899224, theta=-74.339173 -> V=1.0, theta=0.0
% INFO    : Bus 75991	: V=1.0076945, theta=-73.123588 -> V=1.0, theta=0.0
% INFO    : Bus 75992	: V=0.9873539, theta=-73.650314 -> V=1.0, theta=0.0
% INFO    : Bus 75993	: V=0.9762408, theta=-74.994888 -> V=1.0, theta=0.0
% INFO    : Bus 75994	: V=0.9806078, theta=-74.181894 -> V=1.0, theta=0.0
% INFO    : Bus 75995	: V=0.976233, theta=-74.680954 -> V=1.0, theta=0.0
% INFO    : Bus 75996	: V=0.98403, theta=-73.628279 -> V=1.0, theta=0.0
% INFO    : Bus 75997	: V=0.984492, theta=-73.6927 -> V=1.0, theta=0.0
% INFO    : Bus 75998	: V=0.9953259, theta=-73.929268 -> V=1.0, theta=0.0
% INFO    : Bus 75999	: V=0.9817212, theta=-74.752279 -> V=1.0, theta=0.0
% INFO    : Bus 76000	: V=0.9849897, theta=-74.713982 -> V=1.0, theta=0.0
% INFO    : Bus 76001	: V=0.982251, theta=-75.360713 -> V=1.0, theta=0.0
% INFO    : Bus 76002	: V=0.9625933, theta=-79.556273 -> V=1.0, theta=0.0
% INFO    : Bus 76003	: V=0.9618159, theta=-79.610415 -> V=1.0, theta=0.0
% INFO    : Bus 76004	: V=0.9683831, theta=-79.17846 -> V=1.0, theta=0.0
% INFO    : Bus 76005	: V=0.9677562, theta=-79.494649 -> V=1.0, theta=0.0
% INFO    : Bus 76006	: V=0.972553, theta=-79.298767 -> V=1.0, theta=0.0
% INFO    : Bus 76007	: V=0.9669473, theta=-80.079373 -> V=1.0, theta=0.0
% INFO    : Bus 76008	: V=0.9629128, theta=-80.18278 -> V=1.0, theta=0.0
% INFO    : Bus 76009	: V=0.9599044, theta=-79.983758 -> V=1.0, theta=0.0
% INFO    : Bus 76010	: V=0.9627863, theta=-79.570616 -> V=1.0, theta=0.0
% INFO    : Bus 76011	: V=0.9940435, theta=-75.493903 -> V=1.0, theta=0.0
% INFO    : Bus 76012	: V=0.9967247, theta=-76.64533 -> V=1.0, theta=0.0
% INFO    : Bus 76013	: V=0.9715816, theta=-78.471847 -> V=1.0, theta=0.0
% INFO    : Bus 76014	: V=0.9881571, theta=-76.562723 -> V=1.0, theta=0.0
% INFO    : Bus 76015	: V=0.9821906, theta=-77.222265 -> V=1.0, theta=0.0
% INFO    : Bus 76016	: V=0.9683902, theta=-78.823827 -> V=1.0, theta=0.0
% INFO    : Bus 76017	: V=0.9768696, theta=-77.594799 -> V=1.0, theta=0.0
% INFO    : Bus 76018	: V=0.9815631, theta=-77.168763 -> V=1.0, theta=0.0
% INFO    : Bus 76019	: V=0.9699087, theta=-78.781862 -> V=1.0, theta=0.0
% INFO    : Bus 76020	: V=0.9719047, theta=-78.32803 -> V=1.0, theta=0.0
% INFO    : Bus 76021	: V=0.9670116, theta=-79.07875 -> V=1.0, theta=0.0
% INFO    : Bus 76022	: V=0.9670644, theta=-79.941834 -> V=1.0, theta=0.0
% INFO    : Bus 76023	: V=0.990665, theta=-78.518125 -> V=1.0, theta=0.0
% INFO    : Bus 76024	: V=0.9815569, theta=-79.729718 -> V=1.0, theta=0.0
% INFO    : Bus 76025	: V=0.9793432, theta=-79.524536 -> V=1.0, theta=0.0
% INFO    : Bus 76026	: V=0.9679383, theta=-81.075925 -> V=1.0, theta=0.0
% INFO    : Bus 76027	: V=0.9706556, theta=-80.130426 -> V=1.0, theta=0.0
% INFO    : Bus 76028	: V=0.9720132, theta=-80.396925 -> V=1.0, theta=0.0
% INFO    : Bus 76029	: V=0.9713231, theta=-80.405053 -> V=1.0, theta=0.0
% INFO    : Bus 76030	: V=0.9867578, theta=-78.809291 -> V=1.0, theta=0.0
% INFO    : Bus 76031	: V=0.9749175, theta=-80.192892 -> V=1.0, theta=0.0
% INFO    : Bus 76032	: V=0.9742557, theta=-80.328425 -> V=1.0, theta=0.0
% INFO    : Bus 76033	: V=0.9826285, theta=-79.589466 -> V=1.0, theta=0.0
% INFO    : Bus 76034	: V=0.9815031, theta=-79.937519 -> V=1.0, theta=0.0
% INFO    : Bus 76035	: V=0.9858774, theta=-79.328997 -> V=1.0, theta=0.0
% INFO    : Bus 76036	: V=0.9869065, theta=-79.35643 -> V=1.0, theta=0.0
% INFO    : Bus 76037	: V=0.9811768, theta=-79.629216 -> V=1.0, theta=0.0
% INFO    : Bus 76038	: V=0.9846618, theta=-79.448779 -> V=1.0, theta=0.0
% INFO    : Bus 76039	: V=0.9858751, theta=-79.300042 -> V=1.0, theta=0.0
% INFO    : Bus 76040	: V=1.0002709, theta=-78.019979 -> V=1.0, theta=0.0
% INFO    : Bus 76041	: V=1.0007032, theta=-77.991439 -> V=1.0, theta=0.0
% INFO    : Bus 76042	: V=0.9789595, theta=-80.442343 -> V=1.0, theta=0.0
% INFO    : Bus 76043	: V=0.9888284, theta=-79.36561 -> V=1.0, theta=0.0
% INFO    : Bus 76044	: V=1.0097063, theta=-77.065362 -> V=1.0, theta=0.0
% INFO    : Bus 76045	: V=1.0011329, theta=-78.058103 -> V=1.0, theta=0.0
% INFO    : Bus 76046	: V=0.9917899, theta=-79.058635 -> V=1.0, theta=0.0
% INFO    : Bus 76047	: V=1.0013304, theta=-77.964899 -> V=1.0, theta=0.0
% INFO    : Bus 76048	: V=0.993269, theta=-78.755107 -> V=1.0, theta=0.0
% INFO    : Bus 76049	: V=0.9924362, theta=-78.786541 -> V=1.0, theta=0.0
% INFO    : Bus 76050	: V=0.993543, theta=-78.745357 -> V=1.0, theta=0.0
% INFO    : Bus 76051	: V=0.9938717, theta=-78.729316 -> V=1.0, theta=0.0
% INFO    : Bus 76052	: V=0.9878646, theta=-79.340667 -> V=1.0, theta=0.0
% INFO    : Bus 76053	: V=0.9997509, theta=-78.063102 -> V=1.0, theta=0.0
% INFO    : Bus 76054	: V=0.9943948, theta=-78.742473 -> V=1.0, theta=0.0
% INFO    : Bus 76055	: V=0.9941036, theta=-78.762925 -> V=1.0, theta=0.0
% INFO    : Bus 76056	: V=0.998137, theta=-78.17009 -> V=1.0, theta=0.0
% INFO    : Bus 76057	: V=0.9935398, theta=-78.801002 -> V=1.0, theta=0.0
% INFO    : Bus 76058	: V=1.0048289, theta=-77.696659 -> V=1.0, theta=0.0
% INFO    : Bus 76059	: V=0.99319, theta=-78.688811 -> V=1.0, theta=0.0
% INFO    : Bus 76060	: V=0.9972736, theta=-78.222263 -> V=1.0, theta=0.0
% INFO    : Bus 76061	: V=0.9898813, theta=-79.07253 -> V=1.0, theta=0.0
% INFO    : Bus 76062	: V=0.9851579, theta=-79.481036 -> V=1.0, theta=0.0
% INFO    : Bus 76063	: V=0.9863571, theta=-79.420023 -> V=1.0, theta=0.0
% INFO    : Bus 76064	: V=0.9875457, theta=-79.252355 -> V=1.0, theta=0.0
% INFO    : Bus 76065	: V=0.9974456, theta=-78.085992 -> V=1.0, theta=0.0
% INFO    : Bus 76066	: V=0.9914552, theta=-78.869658 -> V=1.0, theta=0.0
% INFO    : Bus 76067	: V=0.9744638, theta=-79.895699 -> V=1.0, theta=0.0
% INFO    : Bus 76068	: V=0.9784972, theta=-79.832278 -> V=1.0, theta=0.0
% INFO    : Bus 76069	: V=0.9806449, theta=-79.761577 -> V=1.0, theta=0.0
% INFO    : Bus 76070	: V=0.9885049, theta=-79.027972 -> V=1.0, theta=0.0
% INFO    : Bus 76071	: V=0.9829408, theta=-79.348487 -> V=1.0, theta=0.0
% INFO    : Bus 76072	: V=0.9628235, theta=-81.017413 -> V=1.0, theta=0.0
% INFO    : Bus 76073	: V=0.9690275, theta=-80.299897 -> V=1.0, theta=0.0
% INFO    : Bus 76074	: V=0.9738301, theta=-79.729221 -> V=1.0, theta=0.0
% INFO    : Bus 76075	: V=0.9573196, theta=-81.086824 -> V=1.0, theta=0.0
% INFO    : Bus 76076	: V=0.9612442, theta=-80.817834 -> V=1.0, theta=0.0
% INFO    : Bus 76077	: V=0.9767328, theta=-79.432227 -> V=1.0, theta=0.0
% INFO    : Bus 76078	: V=0.973964, theta=-78.932855 -> V=1.0, theta=0.0
% INFO    : Bus 76079	: V=0.9716389, theta=-78.99136 -> V=1.0, theta=0.0
% INFO    : Bus 76080	: V=0.9716713, theta=-79.51632 -> V=1.0, theta=0.0
% INFO    : Bus 76081	: V=0.9663086, theta=-79.102158 -> V=1.0, theta=0.0
% INFO    : Bus 76082	: V=0.9626212, theta=-79.701335 -> V=1.0, theta=0.0
% INFO    : Bus 76083	: V=0.9647446, theta=-79.347789 -> V=1.0, theta=0.0
% INFO    : Bus 76084	: V=0.9708303, theta=-80.217396 -> V=1.0, theta=0.0
% INFO    : Bus 76085	: V=0.991367, theta=-78.138346 -> V=1.0, theta=0.0
% INFO    : Bus 76086	: V=0.9852042, theta=-78.977714 -> V=1.0, theta=0.0
% INFO    : Bus 76087	: V=0.9796686, theta=-79.381407 -> V=1.0, theta=0.0
% INFO    : Bus 76088	: V=0.9777805, theta=-79.483573 -> V=1.0, theta=0.0
% INFO    : Bus 76089	: V=0.9834576, theta=-79.279042 -> V=1.0, theta=0.0
% INFO    : Bus 76090	: V=0.9827323, theta=-79.324725 -> V=1.0, theta=0.0
% INFO    : Bus 76091	: V=0.9885826, theta=-79.103216 -> V=1.0, theta=0.0
% INFO    : Bus 76092	: V=0.9820128, theta=-79.436118 -> V=1.0, theta=0.0
% INFO    : Bus 76093	: V=0.9780111, theta=-79.544932 -> V=1.0, theta=0.0
% INFO    : Bus 76094	: V=0.9762971, theta=-79.671212 -> V=1.0, theta=0.0
% INFO    : Bus 76095	: V=0.9716077, theta=-79.84072 -> V=1.0, theta=0.0
% INFO    : Bus 76096	: V=0.9813147, theta=-78.700274 -> V=1.0, theta=0.0
% INFO    : Bus 76097	: V=0.9822364, theta=-78.034594 -> V=1.0, theta=0.0
% INFO    : Bus 76098	: V=0.9855039, theta=-78.29329 -> V=1.0, theta=0.0
% INFO    : Bus 76099	: V=0.9840075, theta=-78.197187 -> V=1.0, theta=0.0
% INFO    : Bus 76100	: V=0.965841, theta=-80.412764 -> V=1.0, theta=0.0
% INFO    : Bus 76101	: V=0.9868507, theta=-77.157584 -> V=1.0, theta=0.0
% INFO    : Bus 76102	: V=0.9853942, theta=-77.972357 -> V=1.0, theta=0.0
% INFO    : Bus 76103	: V=0.9642154, theta=-78.710856 -> V=1.0, theta=0.0
% INFO    : Bus 76104	: V=0.9630635, theta=-78.404186 -> V=1.0, theta=0.0
% INFO    : Bus 76105	: V=0.9835415, theta=-79.623409 -> V=1.0, theta=0.0
% INFO    : Bus 76106	: V=0.975306, theta=-79.668589 -> V=1.0, theta=0.0
% INFO    : Bus 76107	: V=0.9787779, theta=-79.17621 -> V=1.0, theta=0.0
% INFO    : Bus 76108	: V=0.9792101, theta=-79.341881 -> V=1.0, theta=0.0
% INFO    : Bus 76109	: V=0.9770702, theta=-79.236392 -> V=1.0, theta=0.0
% INFO    : Bus 76110	: V=0.9965111, theta=-77.1981 -> V=1.0, theta=0.0
% INFO    : Bus 76111	: V=1.0088205, theta=-75.821369 -> V=1.0, theta=0.0
% INFO    : Bus 76112	: V=1.0086105, theta=-75.838485 -> V=1.0, theta=0.0
% INFO    : Bus 76113	: V=0.9847105, theta=-78.163413 -> V=1.0, theta=0.0
% INFO    : Bus 76114	: V=0.9783486, theta=-79.393531 -> V=1.0, theta=0.0
% INFO    : Bus 76115	: V=0.9739265, theta=-79.887795 -> V=1.0, theta=0.0
% INFO    : Bus 76116	: V=0.9804499, theta=-79.312068 -> V=1.0, theta=0.0
% INFO    : Bus 76117	: V=0.9942803, theta=-77.727333 -> V=1.0, theta=0.0
% INFO    : Bus 76118	: V=0.98808, theta=-78.551608 -> V=1.0, theta=0.0
% INFO    : Bus 76119	: V=0.9783006, theta=-79.121351 -> V=1.0, theta=0.0
% INFO    : Bus 76120	: V=0.9839969, theta=-78.297306 -> V=1.0, theta=0.0
% INFO    : Bus 76121	: V=0.9950224, theta=-77.760872 -> V=1.0, theta=0.0
% INFO    : Bus 76122	: V=0.9867008, theta=-78.832734 -> V=1.0, theta=0.0
% INFO    : Bus 76123	: V=0.9927858, theta=-78.720799 -> V=1.0, theta=0.0
% INFO    : Bus 76124	: V=0.9936819, theta=-78.648676 -> V=1.0, theta=0.0
% INFO    : Bus 76125	: V=0.9927437, theta=-78.727701 -> V=1.0, theta=0.0
% INFO    : Bus 76126	: V=1.0053678, theta=-77.660231 -> V=1.0, theta=0.0
% INFO    : Bus 76127	: V=1.0001604, theta=-78.256485 -> V=1.0, theta=0.0
% INFO    : Bus 76128	: V=0.9956674, theta=-78.473965 -> V=1.0, theta=0.0
% INFO    : Bus 76129	: V=0.9935613, theta=-78.635894 -> V=1.0, theta=0.0
% INFO    : Bus 76130	: V=0.9955723, theta=-78.58512 -> V=1.0, theta=0.0
% INFO    : Bus 76131	: V=0.9910769, theta=-78.709719 -> V=1.0, theta=0.0
% INFO    : Bus 76132	: V=0.9948154, theta=-78.301361 -> V=1.0, theta=0.0
% INFO    : Bus 76133	: V=0.982882, theta=-79.573632 -> V=1.0, theta=0.0
% INFO    : Bus 76134	: V=0.9809443, theta=-79.252815 -> V=1.0, theta=0.0
% INFO    : Bus 76135	: V=0.9864552, theta=-79.031518 -> V=1.0, theta=0.0
% INFO    : Bus 76136	: V=0.989651, theta=-77.446248 -> V=1.0, theta=0.0
% INFO    : Bus 76137	: V=0.9993176, theta=-76.697339 -> V=1.0, theta=0.0
% INFO    : Bus 76138	: V=1.0004453, theta=-76.602056 -> V=1.0, theta=0.0
% INFO    : Bus 76139	: V=1.0022517, theta=-75.774308 -> V=1.0, theta=0.0
% INFO    : Bus 76140	: V=0.9820532, theta=-79.091555 -> V=1.0, theta=0.0
% INFO    : Bus 76141	: V=0.9815032, theta=-79.077006 -> V=1.0, theta=0.0
% INFO    : Bus 76142	: V=0.9774657, theta=-79.309484 -> V=1.0, theta=0.0
% INFO    : Bus 76143	: V=0.9859613, theta=-79.253656 -> V=1.0, theta=0.0
% INFO    : Bus 76144	: V=0.9744042, theta=-79.534062 -> V=1.0, theta=0.0
% INFO    : Bus 76145	: V=0.9713214, theta=-80.236334 -> V=1.0, theta=0.0
% INFO    : Bus 76146	: V=0.9757225, theta=-79.573741 -> V=1.0, theta=0.0
% INFO    : Bus 76147	: V=0.9811196, theta=-79.30301 -> V=1.0, theta=0.0
% INFO    : Bus 76148	: V=0.9766767, theta=-79.392669 -> V=1.0, theta=0.0
% INFO    : Bus 76149	: V=0.976126, theta=-79.262514 -> V=1.0, theta=0.0
% INFO    : Bus 76150	: V=0.9826628, theta=-78.412907 -> V=1.0, theta=0.0
% INFO    : Bus 76151	: V=0.9810751, theta=-78.271766 -> V=1.0, theta=0.0
% INFO    : Bus 76152	: V=0.9949358, theta=-77.299483 -> V=1.0, theta=0.0
% INFO    : Bus 76153	: V=0.9890364, theta=-77.972017 -> V=1.0, theta=0.0
% INFO    : Bus 76154	: V=0.9755273, theta=-79.380796 -> V=1.0, theta=0.0
% INFO    : Bus 76155	: V=0.9759294, theta=-79.38754 -> V=1.0, theta=0.0
% INFO    : Bus 76156	: V=0.9767256, theta=-79.380599 -> V=1.0, theta=0.0
% INFO    : Bus 76157	: V=0.9715667, theta=-79.493259 -> V=1.0, theta=0.0
% INFO    : Bus 76158	: V=0.9738973, theta=-79.207465 -> V=1.0, theta=0.0
% INFO    : Bus 76159	: V=0.9752563, theta=-79.358494 -> V=1.0, theta=0.0
% INFO    : Bus 76160	: V=0.9859172, theta=-78.345484 -> V=1.0, theta=0.0
% INFO    : Bus 76161	: V=0.9751319, theta=-79.307976 -> V=1.0, theta=0.0
% INFO    : Bus 76162	: V=0.9725044, theta=-79.35705 -> V=1.0, theta=0.0
% INFO    : Bus 76163	: V=0.9742489, theta=-78.842028 -> V=1.0, theta=0.0
% INFO    : Bus 76164	: V=0.9756623, theta=-78.825755 -> V=1.0, theta=0.0
% INFO    : Bus 76165	: V=0.9806212, theta=-78.367831 -> V=1.0, theta=0.0
% INFO    : Bus 76166	: V=0.9753517, theta=-78.778452 -> V=1.0, theta=0.0
% INFO    : Bus 76167	: V=0.9838169, theta=-78.23306 -> V=1.0, theta=0.0
% INFO    : Bus 76168	: V=0.980756, theta=-78.374226 -> V=1.0, theta=0.0
% INFO    : Bus 76169	: V=0.9807679, theta=-78.373453 -> V=1.0, theta=0.0
% INFO    : Bus 76170	: V=0.9969742, theta=-76.691731 -> V=1.0, theta=0.0
% INFO    : Bus 76171	: V=0.9926154, theta=-77.125797 -> V=1.0, theta=0.0
% INFO    : Bus 76172	: V=0.9910533, theta=-77.073126 -> V=1.0, theta=0.0
% INFO    : Bus 76173	: V=0.9936876, theta=-76.669305 -> V=1.0, theta=0.0
% INFO    : Bus 76174	: V=0.9970822, theta=-76.942537 -> V=1.0, theta=0.0
% INFO    : Bus 76175	: V=0.9997232, theta=-76.408743 -> V=1.0, theta=0.0
% INFO    : Bus 76176	: V=0.9879259, theta=-77.536745 -> V=1.0, theta=0.0
% INFO    : Bus 76177	: V=0.9916902, theta=-77.011455 -> V=1.0, theta=0.0
% INFO    : Bus 76178	: V=0.990658, theta=-77.680028 -> V=1.0, theta=0.0
% INFO    : Bus 76179	: V=0.9925103, theta=-76.49752 -> V=1.0, theta=0.0
% INFO    : Bus 76180	: V=0.9972457, theta=-76.256528 -> V=1.0, theta=0.0
% INFO    : Bus 76181	: V=0.9946062, theta=-76.297368 -> V=1.0, theta=0.0
% INFO    : Bus 76182	: V=0.9913614, theta=-76.482018 -> V=1.0, theta=0.0
% INFO    : Bus 76183	: V=0.9790862, theta=-79.599869 -> V=1.0, theta=0.0
% INFO    : Bus 76184	: V=0.980427, theta=-79.676692 -> V=1.0, theta=0.0
% INFO    : Bus 76185	: V=0.9879146, theta=-78.979598 -> V=1.0, theta=0.0
% INFO    : Bus 76186	: V=0.9834184, theta=-79.611683 -> V=1.0, theta=0.0
% INFO    : Bus 76187	: V=0.9817469, theta=-79.643998 -> V=1.0, theta=0.0
% INFO    : Bus 76188	: V=0.9848688, theta=-79.497587 -> V=1.0, theta=0.0
% INFO    : Bus 76189	: V=0.9816616, theta=-79.625713 -> V=1.0, theta=0.0
% INFO    : Bus 76190	: V=0.9863329, theta=-79.372656 -> V=1.0, theta=0.0
% INFO    : Bus 76191	: V=0.9916928, theta=-79.027029 -> V=1.0, theta=0.0
% INFO    : Bus 76192	: V=0.9906175, theta=-79.135781 -> V=1.0, theta=0.0
% INFO    : Bus 76193	: V=0.9928364, theta=-78.936585 -> V=1.0, theta=0.0
% INFO    : Bus 76194	: V=0.9889339, theta=-79.300578 -> V=1.0, theta=0.0
% INFO    : Bus 76195	: V=0.9992956, theta=-78.124543 -> V=1.0, theta=0.0
% INFO    : Bus 76196	: V=0.9940748, theta=-78.794801 -> V=1.0, theta=0.0
% INFO    : Bus 76197	: V=0.9932165, theta=-78.870779 -> V=1.0, theta=0.0
% INFO    : Bus 76198	: V=0.9897231, theta=-79.134504 -> V=1.0, theta=0.0
% INFO    : Bus 76199	: V=0.9890722, theta=-79.206527 -> V=1.0, theta=0.0
% INFO    : Bus 76200	: V=0.9887025, theta=-79.253704 -> V=1.0, theta=0.0
% INFO    : Bus 76201	: V=0.991441, theta=-79.094284 -> V=1.0, theta=0.0
% INFO    : Bus 76202	: V=0.9818983, theta=-79.570412 -> V=1.0, theta=0.0
% INFO    : Bus 76203	: V=0.9841847, theta=-79.558965 -> V=1.0, theta=0.0
% INFO    : Bus 76204	: V=0.9832295, theta=-79.890582 -> V=1.0, theta=0.0
% INFO    : Bus 76205	: V=0.9901435, theta=-78.931807 -> V=1.0, theta=0.0
% INFO    : Bus 76206	: V=0.9915422, theta=-78.81586 -> V=1.0, theta=0.0
% INFO    : Bus 76207	: V=0.9863021, theta=-79.360811 -> V=1.0, theta=0.0
% INFO    : Bus 76208	: V=0.9873825, theta=-79.330828 -> V=1.0, theta=0.0
% INFO    : Bus 76209	: V=0.9856565, theta=-79.376608 -> V=1.0, theta=0.0
% INFO    : Bus 76210	: V=0.9879898, theta=-79.217584 -> V=1.0, theta=0.0
% INFO    : Bus 76211	: V=0.9881328, theta=-79.021248 -> V=1.0, theta=0.0
% INFO    : Bus 76212	: V=0.9848437, theta=-79.311284 -> V=1.0, theta=0.0
% INFO    : Bus 76213	: V=0.9815788, theta=-79.33015 -> V=1.0, theta=0.0
% INFO    : Bus 76214	: V=0.981801, theta=-79.295085 -> V=1.0, theta=0.0
% INFO    : Bus 76215	: V=0.9815273, theta=-79.290567 -> V=1.0, theta=0.0
% INFO    : Bus 76216	: V=0.983114, theta=-79.360698 -> V=1.0, theta=0.0
% INFO    : Bus 76217	: V=0.9822567, theta=-79.609544 -> V=1.0, theta=0.0
% INFO    : Bus 76218	: V=0.9717089, theta=-79.999832 -> V=1.0, theta=0.0
% INFO    : Bus 76219	: V=0.9815509, theta=-79.311632 -> V=1.0, theta=0.0
% INFO    : Bus 76220	: V=0.9808961, theta=-79.375724 -> V=1.0, theta=0.0
% INFO    : Bus 76221	: V=0.9841852, theta=-79.271668 -> V=1.0, theta=0.0
% INFO    : Bus 76222	: V=0.9911447, theta=-79.132167 -> V=1.0, theta=0.0
% INFO    : Bus 76223	: V=0.9871572, theta=-79.65911 -> V=1.0, theta=0.0
% INFO    : Bus 76224	: V=0.9892937, theta=-79.361987 -> V=1.0, theta=0.0
% INFO    : Bus 76225	: V=0.9984644, theta=-78.28128 -> V=1.0, theta=0.0
% INFO    : Bus 76226	: V=0.9901701, theta=-79.251832 -> V=1.0, theta=0.0
% INFO    : Bus 76227	: V=0.972932, theta=-77.055697 -> V=1.0, theta=0.0
% INFO    : Bus 76228	: V=0.9828194, theta=-74.714561 -> V=1.0, theta=0.0
% INFO    : Bus 76229	: V=0.959967, theta=-78.075462 -> V=1.0, theta=0.0
% INFO    : Bus 76230	: V=0.9762431, theta=-76.605812 -> V=1.0, theta=0.0
% INFO    : Bus 76231	: V=0.9855568, theta=-75.756025 -> V=1.0, theta=0.0
% INFO    : Bus 76232	: V=0.9811348, theta=-76.291936 -> V=1.0, theta=0.0
% INFO    : Bus 76233	: V=0.9688038, theta=-77.289574 -> V=1.0, theta=0.0
% INFO    : Bus 76234	: V=0.9632618, theta=-78.601894 -> V=1.0, theta=0.0
% INFO    : Bus 76235	: V=0.9574781, theta=-78.638444 -> V=1.0, theta=0.0
% INFO    : Bus 76236	: V=0.959562, theta=-78.692512 -> V=1.0, theta=0.0
% INFO    : Bus 76237	: V=0.9656915, theta=-78.027243 -> V=1.0, theta=0.0
% INFO    : Bus 76238	: V=0.9627746, theta=-78.220332 -> V=1.0, theta=0.0
% INFO    : Bus 76239	: V=0.9621656, theta=-78.198022 -> V=1.0, theta=0.0
% INFO    : Bus 76240	: V=0.9639613, theta=-78.325069 -> V=1.0, theta=0.0
% INFO    : Bus 76241	: V=0.9640264, theta=-78.6292 -> V=1.0, theta=0.0
% INFO    : Bus 76242	: V=0.9809291, theta=-75.788716 -> V=1.0, theta=0.0
% INFO    : Bus 76243	: V=0.9715191, theta=-77.335879 -> V=1.0, theta=0.0
% INFO    : Bus 76244	: V=0.9770562, theta=-76.705447 -> V=1.0, theta=0.0
% INFO    : Bus 76245	: V=0.9787028, theta=-76.574411 -> V=1.0, theta=0.0
% INFO    : Bus 76246	: V=0.9732927, theta=-77.161946 -> V=1.0, theta=0.0
% INFO    : Bus 76247	: V=0.9720872, theta=-76.996287 -> V=1.0, theta=0.0
% INFO    : Bus 76248	: V=0.9746126, theta=-76.835817 -> V=1.0, theta=0.0
% INFO    : Bus 76249	: V=0.9734185, theta=-76.912486 -> V=1.0, theta=0.0
% INFO    : Bus 76250	: V=0.9763326, theta=-76.835381 -> V=1.0, theta=0.0
% INFO    : Bus 76251	: V=0.9796545, theta=-76.497233 -> V=1.0, theta=0.0
% INFO    : Bus 76252	: V=0.9877584, theta=-75.597525 -> V=1.0, theta=0.0
% INFO    : Bus 76253	: V=0.9829408, theta=-76.241815 -> V=1.0, theta=0.0
% INFO    : Bus 76254	: V=0.9744179, theta=-77.100214 -> V=1.0, theta=0.0
% INFO    : Bus 76255	: V=0.9724999, theta=-76.920406 -> V=1.0, theta=0.0
% INFO    : Bus 76256	: V=0.9745652, theta=-76.9018 -> V=1.0, theta=0.0
% INFO    : Bus 76257	: V=0.977474, theta=-76.56287 -> V=1.0, theta=0.0
% INFO    : Bus 76258	: V=0.977174, theta=-76.470934 -> V=1.0, theta=0.0
% INFO    : Bus 76259	: V=0.9730799, theta=-77.03924 -> V=1.0, theta=0.0
% INFO    : Bus 76260	: V=0.9694869, theta=-77.481886 -> V=1.0, theta=0.0
% INFO    : Bus 76261	: V=0.980241, theta=-76.646129 -> V=1.0, theta=0.0
% INFO    : Bus 76262	: V=0.9858497, theta=-76.494977 -> V=1.0, theta=0.0
% INFO    : Bus 76263	: V=0.9873513, theta=-76.495962 -> V=1.0, theta=0.0
% INFO    : Bus 76264	: V=0.9827413, theta=-76.42292 -> V=1.0, theta=0.0
% INFO    : Bus 76265	: V=0.9819631, theta=-76.45902 -> V=1.0, theta=0.0
% INFO    : Bus 76266	: V=0.9813678, theta=-76.458084 -> V=1.0, theta=0.0
% INFO    : Bus 76267	: V=0.9796091, theta=-77.094761 -> V=1.0, theta=0.0
% INFO    : Bus 76268	: V=0.9853034, theta=-77.134414 -> V=1.0, theta=0.0
% INFO    : Bus 76269	: V=0.9868668, theta=-76.775187 -> V=1.0, theta=0.0
% INFO    : Bus 76270	: V=0.9851828, theta=-76.405217 -> V=1.0, theta=0.0
% INFO    : Bus 76271	: V=1.000932, theta=-75.455227 -> V=1.0, theta=0.0
% INFO    : Bus 76272	: V=1.015368, theta=-74.773843 -> V=1.0, theta=0.0
% INFO    : Bus 76273	: V=1.005441, theta=-75.411031 -> V=1.0, theta=0.0
% INFO    : Bus 76274	: V=1.0086224, theta=-74.274068 -> V=1.0, theta=0.0
% INFO    : Bus 76275	: V=1.006824, theta=-74.654962 -> V=1.0, theta=0.0
% INFO    : Bus 76276	: V=0.9961919, theta=-75.254885 -> V=1.0, theta=0.0
% INFO    : Bus 76277	: V=0.9964397, theta=-75.103725 -> V=1.0, theta=0.0
% INFO    : Bus 76278	: V=0.9985101, theta=-74.608097 -> V=1.0, theta=0.0
% INFO    : Bus 76279	: V=0.9984408, theta=-74.351215 -> V=1.0, theta=0.0
% INFO    : Bus 76280	: V=0.9898551, theta=-74.496725 -> V=1.0, theta=0.0
% INFO    : Bus 76281	: V=0.9849643, theta=-75.341623 -> V=1.0, theta=0.0
% INFO    : Bus 76282	: V=0.9864375, theta=-76.816233 -> V=1.0, theta=0.0
% INFO    : Bus 76283	: V=0.9850689, theta=-76.534547 -> V=1.0, theta=0.0
% INFO    : Bus 76284	: V=0.9688931, theta=-79.968552 -> V=1.0, theta=0.0
% INFO    : Bus 76285	: V=0.9661864, theta=-80.366539 -> V=1.0, theta=0.0
% INFO    : Bus 76286	: V=0.9645293, theta=-81.631995 -> V=1.0, theta=0.0
% INFO    : Bus 76287	: V=0.9567308, theta=-82.494825 -> V=1.0, theta=0.0
% INFO    : Bus 76288	: V=0.9589797, theta=-81.881385 -> V=1.0, theta=0.0
% INFO    : Bus 76289	: V=0.9713808, theta=-76.76826 -> V=1.0, theta=0.0
% INFO    : Bus 76290	: V=0.9706559, theta=-76.405287 -> V=1.0, theta=0.0
% INFO    : Bus 76291	: V=0.9901106, theta=-74.172401 -> V=1.0, theta=0.0
% INFO    : Bus 76292	: V=0.9787436, theta=-79.102561 -> V=1.0, theta=0.0
% INFO    : Bus 76293	: V=0.9867228, theta=-78.854154 -> V=1.0, theta=0.0
% INFO    : Bus 76294	: V=1.0008298, theta=-77.520516 -> V=1.0, theta=0.0
% INFO    : Bus 76295	: V=0.9661578, theta=-79.954415 -> V=1.0, theta=0.0
% INFO    : Bus 76296	: V=0.9629659, theta=-82.38526 -> V=1.0, theta=0.0
% INFO    : Bus 76297	: V=0.9949432, theta=-77.150772 -> V=1.0, theta=0.0
% INFO    : Bus 76298	: V=0.994302, theta=-76.597955 -> V=1.0, theta=0.0
% INFO    : Bus 76299	: V=1.013726, theta=-74.379602 -> V=1.0, theta=0.0
% INFO    : Bus 76300	: V=1.010309, theta=-75.037882 -> V=1.0, theta=0.0
% INFO    : Bus 76301	: V=1.0109582, theta=-74.571204 -> V=1.0, theta=0.0
% INFO    : Bus 76302	: V=1.0035853, theta=-75.449019 -> V=1.0, theta=0.0
% INFO    : Bus 76303	: V=0.9941295, theta=-76.477631 -> V=1.0, theta=0.0
% INFO    : Bus 76304	: V=0.976131, theta=-79.698167 -> V=1.0, theta=0.0
% INFO    : Bus 76305	: V=0.9886521, theta=-78.316451 -> V=1.0, theta=0.0
% INFO    : Bus 76306	: V=0.9827747, theta=-78.841383 -> V=1.0, theta=0.0
% INFO    : Bus 76307	: V=0.9865297, theta=-78.428275 -> V=1.0, theta=0.0
% INFO    : Bus 76308	: V=0.983633, theta=-78.766281 -> V=1.0, theta=0.0
% INFO    : Bus 76309	: V=0.9961508, theta=-77.519327 -> V=1.0, theta=0.0
% INFO    : Bus 76310	: V=0.9916933, theta=-78.140185 -> V=1.0, theta=0.0
% INFO    : Bus 76311	: V=0.9740834, theta=-79.776403 -> V=1.0, theta=0.0
% INFO    : Bus 76312	: V=0.9847586, theta=-78.683766 -> V=1.0, theta=0.0
% INFO    : Bus 76313	: V=0.9716635, theta=-79.090189 -> V=1.0, theta=0.0
% INFO    : Bus 76314	: V=0.9700241, theta=-79.344088 -> V=1.0, theta=0.0
% INFO    : Bus 76315	: V=0.9662518, theta=-79.652796 -> V=1.0, theta=0.0
% INFO    : Bus 76316	: V=0.960006, theta=-80.047833 -> V=1.0, theta=0.0
% INFO    : Bus 76317	: V=0.9758703, theta=-78.845505 -> V=1.0, theta=0.0
% INFO    : Bus 76318	: V=0.9665317, theta=-79.693916 -> V=1.0, theta=0.0
% INFO    : Bus 76319	: V=0.9895596, theta=-77.503698 -> V=1.0, theta=0.0
% INFO    : Bus 76320	: V=0.9848038, theta=-78.264335 -> V=1.0, theta=0.0
% INFO    : Bus 76321	: V=0.9641093, theta=-79.260143 -> V=1.0, theta=0.0
% INFO    : Bus 76322	: V=0.9643481, theta=-78.792562 -> V=1.0, theta=0.0
% INFO    : Bus 76323	: V=0.9719217, theta=-79.248821 -> V=1.0, theta=0.0
% INFO    : Bus 76324	: V=0.973866, theta=-79.768044 -> V=1.0, theta=0.0
% INFO    : Bus 76325	: V=0.9782619, theta=-79.570687 -> V=1.0, theta=0.0
% INFO    : Bus 76326	: V=0.9789007, theta=-79.728936 -> V=1.0, theta=0.0
% INFO    : Bus 76327	: V=0.9901605, theta=-78.585537 -> V=1.0, theta=0.0
% INFO    : Bus 76328	: V=0.9839221, theta=-79.082768 -> V=1.0, theta=0.0
% INFO    : Bus 76329	: V=0.9828501, theta=-79.119757 -> V=1.0, theta=0.0
% INFO    : Bus 76330	: V=0.9826606, theta=-78.74264 -> V=1.0, theta=0.0
% INFO    : Bus 76331	: V=0.9777439, theta=-79.380288 -> V=1.0, theta=0.0
% INFO    : Bus 76332	: V=0.9980406, theta=-77.696411 -> V=1.0, theta=0.0
% INFO    : Bus 76333	: V=0.9926162, theta=-78.278826 -> V=1.0, theta=0.0
% INFO    : Bus 76334	: V=0.9799245, theta=-78.472239 -> V=1.0, theta=0.0
% INFO    : Bus 76335	: V=0.9821345, theta=-78.508243 -> V=1.0, theta=0.0
% INFO    : Bus 76336	: V=0.9878551, theta=-78.225647 -> V=1.0, theta=0.0
% INFO    : Bus 76337	: V=0.9912371, theta=-77.695894 -> V=1.0, theta=0.0
% INFO    : Bus 76338	: V=0.9828443, theta=-78.453796 -> V=1.0, theta=0.0
% INFO    : Bus 76339	: V=0.9841284, theta=-78.377175 -> V=1.0, theta=0.0
% INFO    : Bus 76340	: V=0.9887799, theta=-77.656523 -> V=1.0, theta=0.0
% INFO    : Bus 76341	: V=0.9889399, theta=-77.647479 -> V=1.0, theta=0.0
% INFO    : Bus 76342	: V=0.9897135, theta=-77.313038 -> V=1.0, theta=0.0
% INFO    : Bus 76343	: V=0.9902157, theta=-77.670622 -> V=1.0, theta=0.0
% INFO    : Bus 76344	: V=0.9961549, theta=-77.00614 -> V=1.0, theta=0.0
% INFO    : Bus 76345	: V=1.0064693, theta=-76.263742 -> V=1.0, theta=0.0
% INFO    : Bus 76346	: V=1.01318, theta=-75.651746 -> V=1.0, theta=0.0
% INFO    : Bus 76347	: V=1.0043758, theta=-76.315901 -> V=1.0, theta=0.0
% INFO    : Bus 76348	: V=0.970157, theta=-79.140819 -> V=1.0, theta=0.0
% INFO    : Bus 76349	: V=0.9704244, theta=-79.314241 -> V=1.0, theta=0.0
% INFO    : Bus 76350	: V=0.9640155, theta=-79.514076 -> V=1.0, theta=0.0
% INFO    : Bus 76351	: V=0.9641826, theta=-79.941644 -> V=1.0, theta=0.0
% INFO    : Bus 76352	: V=0.9707666, theta=-78.971933 -> V=1.0, theta=0.0
% INFO    : Bus 76353	: V=0.9788844, theta=-78.586426 -> V=1.0, theta=0.0
% INFO    : Bus 76354	: V=0.9958873, theta=-77.012129 -> V=1.0, theta=0.0
% INFO    : Bus 76355	: V=0.9994824, theta=-76.682411 -> V=1.0, theta=0.0
% INFO    : Bus 76356	: V=1.0071919, theta=-75.912295 -> V=1.0, theta=0.0
% INFO    : Bus 76357	: V=0.9913617, theta=-77.54133 -> V=1.0, theta=0.0
% INFO    : Bus 76358	: V=0.996702, theta=-77.103144 -> V=1.0, theta=0.0
% INFO    : Bus 76359	: V=0.9915107, theta=-77.72135 -> V=1.0, theta=0.0
% INFO    : Bus 76360	: V=0.9863727, theta=-78.330553 -> V=1.0, theta=0.0
% INFO    : Bus 76361	: V=0.9812778, theta=-78.814905 -> V=1.0, theta=0.0
% INFO    : Bus 76362	: V=0.9793467, theta=-78.840674 -> V=1.0, theta=0.0
% INFO    : Bus 76363	: V=0.9712253, theta=-79.967769 -> V=1.0, theta=0.0
% INFO    : Bus 76364	: V=0.976937, theta=-78.98906 -> V=1.0, theta=0.0
% INFO    : Bus 76365	: V=0.9764132, theta=-79.030561 -> V=1.0, theta=0.0
% INFO    : Bus 76366	: V=0.9882267, theta=-77.823558 -> V=1.0, theta=0.0
% INFO    : Bus 76367	: V=0.9794284, theta=-78.873298 -> V=1.0, theta=0.0
% INFO    : Bus 76368	: V=0.971727, theta=-78.006612 -> V=1.0, theta=0.0
% INFO    : Bus 76369	: V=0.9940946, theta=-76.100398 -> V=1.0, theta=0.0
% INFO    : Bus 76370	: V=1.0079285, theta=-74.722757 -> V=1.0, theta=0.0
% INFO    : Bus 76371	: V=1.0057549, theta=-74.993743 -> V=1.0, theta=0.0
% INFO    : Bus 76372	: V=1.0092206, theta=-74.640612 -> V=1.0, theta=0.0
% INFO    : Bus 76373	: V=1.0065017, theta=-74.957666 -> V=1.0, theta=0.0
% INFO    : Bus 76374	: V=0.9901338, theta=-76.21773 -> V=1.0, theta=0.0
% INFO    : Bus 76375	: V=0.9857209, theta=-75.483886 -> V=1.0, theta=0.0
% INFO    : Bus 76376	: V=0.9949713, theta=-76.343639 -> V=1.0, theta=0.0
% INFO    : Bus 76377	: V=0.9944814, theta=-76.120999 -> V=1.0, theta=0.0
% INFO    : Bus 76378	: V=0.9936934, theta=-76.195165 -> V=1.0, theta=0.0
% INFO    : Bus 76379	: V=0.9868083, theta=-75.76813 -> V=1.0, theta=0.0
% INFO    : Bus 76380	: V=0.9896179, theta=-76.14081 -> V=1.0, theta=0.0
% INFO    : Bus 76381	: V=0.9878698, theta=-76.222625 -> V=1.0, theta=0.0
% INFO    : Bus 76382	: V=0.9874079, theta=-75.327982 -> V=1.0, theta=0.0
% INFO    : Bus 76383	: V=0.9813449, theta=-74.816983 -> V=1.0, theta=0.0
% INFO    : Bus 76384	: V=0.9773523, theta=-75.145229 -> V=1.0, theta=0.0
% INFO    : Bus 76385	: V=1.0008051, theta=-75.374272 -> V=1.0, theta=0.0
% INFO    : Bus 76386	: V=1.0004102, theta=-76.564704 -> V=1.0, theta=0.0
% INFO    : Bus 76387	: V=1.0038275, theta=-76.483508 -> V=1.0, theta=0.0
% INFO    : Bus 76388	: V=1.0047054, theta=-76.418969 -> V=1.0, theta=0.0
% INFO    : Bus 76389	: V=1.0005906, theta=-76.824706 -> V=1.0, theta=0.0
% INFO    : Bus 76390	: V=1.004099, theta=-76.715936 -> V=1.0, theta=0.0
% INFO    : Bus 76391	: V=0.9995864, theta=-77.006513 -> V=1.0, theta=0.0
% INFO    : Bus 76392	: V=1.0097888, theta=-76.386285 -> V=1.0, theta=0.0
% INFO    : Bus 76393	: V=1.0076425, theta=-76.590359 -> V=1.0, theta=0.0
% INFO    : Bus 76394	: V=0.9936069, theta=-77.971458 -> V=1.0, theta=0.0
% INFO    : Bus 76395	: V=0.9977214, theta=-75.797498 -> V=1.0, theta=0.0
% INFO    : Bus 76396	: V=0.9979969, theta=-76.802796 -> V=1.0, theta=0.0
% INFO    : Bus 76397	: V=0.9937888, theta=-76.942007 -> V=1.0, theta=0.0
% INFO    : Bus 76398	: V=1.0065867, theta=-75.916744 -> V=1.0, theta=0.0
% INFO    : Bus 76399	: V=1.0051378, theta=-76.384819 -> V=1.0, theta=0.0
% INFO    : Bus 76400	: V=1.0118652, theta=-75.518905 -> V=1.0, theta=0.0
% INFO    : Bus 76401	: V=1.0035216, theta=-76.154829 -> V=1.0, theta=0.0
% INFO    : Bus 76402	: V=1.000648, theta=-75.866983 -> V=1.0, theta=0.0
% INFO    : Bus 76403	: V=1.0028147, theta=-75.602942 -> V=1.0, theta=0.0
% INFO    : Bus 76404	: V=1.0012867, theta=-76.640475 -> V=1.0, theta=0.0
% INFO    : Bus 76405	: V=1.002348, theta=-76.272341 -> V=1.0, theta=0.0
% INFO    : Bus 76406	: V=1.0054951, theta=-75.748034 -> V=1.0, theta=0.0
% INFO    : Bus 76407	: V=1.0040226, theta=-76.723146 -> V=1.0, theta=0.0
% INFO    : Bus 76408	: V=1.0048973, theta=-76.698244 -> V=1.0, theta=0.0
% INFO    : Bus 76409	: V=0.9999351, theta=-75.933149 -> V=1.0, theta=0.0
% INFO    : Bus 76410	: V=0.9807129, theta=-74.831883 -> V=1.0, theta=0.0
% INFO    : Bus 76411	: V=0.9783346, theta=-73.94647 -> V=1.0, theta=0.0
% INFO    : Bus 76412	: V=0.9831211, theta=-70.985192 -> V=1.0, theta=0.0
% INFO    : Bus 76413	: V=0.9880772, theta=-68.004917 -> V=1.0, theta=0.0
% INFO    : Bus 76414	: V=0.9801967, theta=-68.918324 -> V=1.0, theta=0.0
% INFO    : Bus 76415	: V=0.9761489, theta=-71.868005 -> V=1.0, theta=0.0
% INFO    : Bus 76416	: V=0.9786356, theta=-71.023216 -> V=1.0, theta=0.0
% INFO    : Bus 76417	: V=0.9774562, theta=-71.49163 -> V=1.0, theta=0.0
% INFO    : Bus 76418	: V=0.9750898, theta=-72.570846 -> V=1.0, theta=0.0
% INFO    : Bus 76419	: V=0.979057, theta=-73.197358 -> V=1.0, theta=0.0
% INFO    : Bus 76420	: V=0.9812961, theta=-73.916956 -> V=1.0, theta=0.0
% INFO    : Bus 76421	: V=0.980046, theta=-72.1714 -> V=1.0, theta=0.0
% INFO    : Bus 76422	: V=0.9730118, theta=-72.915236 -> V=1.0, theta=0.0
% INFO    : Bus 76423	: V=0.9699713, theta=-72.548857 -> V=1.0, theta=0.0
% INFO    : Bus 76424	: V=0.9792962, theta=-72.75016 -> V=1.0, theta=0.0
% INFO    : Bus 76425	: V=0.9686343, theta=-79.971024 -> V=1.0, theta=0.0
% INFO    : Bus 76426	: V=0.9914425, theta=-71.157996 -> V=1.0, theta=0.0
% INFO    : Bus 76427	: V=0.9943109, theta=-72.714492 -> V=1.0, theta=0.0
% INFO    : Bus 76428	: V=1.007054, theta=-70.853475 -> V=1.0, theta=0.0
% INFO    : Bus 76429	: V=1.0005757, theta=-71.600267 -> V=1.0, theta=0.0
% INFO    : Bus 76430	: V=0.9894266, theta=-72.580957 -> V=1.0, theta=0.0
% INFO    : Bus 76431	: V=0.9862333, theta=-72.547343 -> V=1.0, theta=0.0
% INFO    : Bus 76432	: V=0.9888254, theta=-71.611781 -> V=1.0, theta=0.0
% INFO    : Bus 76433	: V=0.9881816, theta=-72.332849 -> V=1.0, theta=0.0
% INFO    : Bus 76434	: V=0.9695914, theta=-79.959709 -> V=1.0, theta=0.0
% INFO    : Bus 76435	: V=0.973683, theta=-75.020028 -> V=1.0, theta=0.0
% INFO    : Bus 76436	: V=0.9814414, theta=-73.642345 -> V=1.0, theta=0.0
% INFO    : Bus 76437	: V=0.9664817, theta=-78.602077 -> V=1.0, theta=0.0
% INFO    : Bus 76438	: V=0.9717432, theta=-77.719531 -> V=1.0, theta=0.0
% INFO    : Bus 76439	: V=0.9596721, theta=-80.416107 -> V=1.0, theta=0.0
% INFO    : Bus 76440	: V=0.9595852, theta=-80.130318 -> V=1.0, theta=0.0
% INFO    : Bus 76441	: V=0.9895333, theta=-70.543231 -> V=1.0, theta=0.0
% INFO    : Bus 76442	: V=1.0024835, theta=-68.439019 -> V=1.0, theta=0.0
% INFO    : Bus 76443	: V=0.9968678, theta=-69.194178 -> V=1.0, theta=0.0
% INFO    : Bus 76444	: V=0.9854988, theta=-70.494066 -> V=1.0, theta=0.0
% INFO    : Bus 76445	: V=0.9784513, theta=-71.302514 -> V=1.0, theta=0.0
% INFO    : Bus 76446	: V=0.9768507, theta=-78.652792 -> V=1.0, theta=0.0
% INFO    : Bus 76447	: V=0.9751765, theta=-76.604303 -> V=1.0, theta=0.0
% INFO    : Bus 76448	: V=0.9746569, theta=-76.894439 -> V=1.0, theta=0.0
% INFO    : Bus 76449	: V=0.9953814, theta=-74.0828 -> V=1.0, theta=0.0
% INFO    : Bus 76450	: V=0.9945494, theta=-74.151449 -> V=1.0, theta=0.0
% INFO    : Bus 76451	: V=1.0006738, theta=-73.344183 -> V=1.0, theta=0.0
% INFO    : Bus 76452	: V=0.9677528, theta=-78.915606 -> V=1.0, theta=0.0
% INFO    : Bus 76453	: V=1.0087773, theta=-60.9446 -> V=1.0, theta=0.0
% INFO    : Bus 76454	: V=1.0141728, theta=-60.068615 -> V=1.0, theta=0.0
% INFO    : Bus 76455	: V=1.0087296, theta=-60.94941 -> V=1.0, theta=0.0
% INFO    : Bus 76456	: V=1.0169392, theta=-51.056646 -> V=1.0, theta=0.0
% INFO    : Bus 76457	: V=0.9921517, theta=-64.01882 -> V=1.0, theta=0.0
% INFO    : Bus 76458	: V=1.0158614, theta=-51.129055 -> V=1.0, theta=0.0
% INFO    : Bus 76459	: V=1.0157217, theta=-51.144919 -> V=1.0, theta=0.0
% INFO    : Bus 76460	: V=1.0103218, theta=-68.485395 -> V=1.0, theta=0.0
% INFO    : Bus 76461	: V=1.0087539, theta=-68.53497 -> V=1.0, theta=0.0
% INFO    : Bus 76462	: V=1.0169817, theta=-50.51664 -> V=1.0, theta=0.0
% INFO    : Bus 76463	: V=1.011935, theta=-60.496288 -> V=1.0, theta=0.0
% INFO    : Bus 76464	: V=1.005268, theta=-61.474913 -> V=1.0, theta=0.0
% INFO    : Bus 76465	: V=1.0045674, theta=-61.535328 -> V=1.0, theta=0.0
% INFO    : Bus 76466	: V=1.0105893, theta=-60.439214 -> V=1.0, theta=0.0
% INFO    : Bus 76467	: V=0.9962565, theta=-62.292364 -> V=1.0, theta=0.0
% INFO    : Bus 76468	: V=0.9897332, theta=-63.195213 -> V=1.0, theta=0.0
% INFO    : Bus 76469	: V=1.0141534, theta=-63.796701 -> V=1.0, theta=0.0
% INFO    : Bus 76470	: V=1.0015451, theta=-65.215705 -> V=1.0, theta=0.0
% INFO    : Bus 76471	: V=0.9992591, theta=-65.686851 -> V=1.0, theta=0.0
% INFO    : Bus 76472	: V=1.0106099, theta=-58.792347 -> V=1.0, theta=0.0
% INFO    : Bus 76473	: V=1.0041182, theta=-60.907418 -> V=1.0, theta=0.0
% INFO    : Bus 76474	: V=0.9988456, theta=-61.453841 -> V=1.0, theta=0.0
% INFO    : Bus 76475	: V=1.0057887, theta=-60.311735 -> V=1.0, theta=0.0
% INFO    : Bus 76476	: V=1.0023769, theta=-64.286879 -> V=1.0, theta=0.0
% INFO    : Bus 76477	: V=1.0079706, theta=-63.60099 -> V=1.0, theta=0.0
% INFO    : Bus 76478	: V=1.0057391, theta=-63.077333 -> V=1.0, theta=0.0
% INFO    : Bus 76479	: V=1.0000555, theta=-61.334282 -> V=1.0, theta=0.0
% INFO    : Bus 76480	: V=0.9947315, theta=-62.497765 -> V=1.0, theta=0.0
% INFO    : Bus 76481	: V=1.0007783, theta=-59.010286 -> V=1.0, theta=0.0
% INFO    : Bus 76482	: V=0.9967582, theta=-63.844769 -> V=1.0, theta=0.0
% INFO    : Bus 76483	: V=1.0007694, theta=-62.516685 -> V=1.0, theta=0.0
% INFO    : Bus 76484	: V=0.9961207, theta=-63.272536 -> V=1.0, theta=0.0
% INFO    : Bus 76485	: V=0.994154, theta=-62.919236 -> V=1.0, theta=0.0
% INFO    : Bus 76486	: V=0.9901339, theta=-63.965655 -> V=1.0, theta=0.0
% INFO    : Bus 76487	: V=0.9990921, theta=-66.493478 -> V=1.0, theta=0.0
% INFO    : Bus 76488	: V=0.9918683, theta=-63.965359 -> V=1.0, theta=0.0
% INFO    : Bus 76489	: V=0.9905146, theta=-64.276232 -> V=1.0, theta=0.0
% INFO    : Bus 76490	: V=0.9923598, theta=-64.018982 -> V=1.0, theta=0.0
% INFO    : Bus 76491	: V=1.0007195, theta=-62.523651 -> V=1.0, theta=0.0
% INFO    : Bus 76492	: V=0.9923248, theta=-63.92832 -> V=1.0, theta=0.0
% INFO    : Bus 76493	: V=1.0130082, theta=-51.549889 -> V=1.0, theta=0.0
% INFO    : Bus 76494	: V=1.0121799, theta=-51.659944 -> V=1.0, theta=0.0
% INFO    : Bus 76495	: V=1.0114823, theta=-68.993142 -> V=1.0, theta=0.0
% INFO    : Bus 76496	: V=1.0008403, theta=-62.608325 -> V=1.0, theta=0.0
% INFO    : Bus 76497	: V=0.9934479, theta=-63.833667 -> V=1.0, theta=0.0
% INFO    : Bus 76498	: V=1.0026949, theta=-69.155802 -> V=1.0, theta=0.0
% INFO    : Bus 76499	: V=1.0113987, theta=-68.543247 -> V=1.0, theta=0.0
% INFO    : Bus 76500	: V=0.9940581, theta=-64.001495 -> V=1.0, theta=0.0
% INFO    : Bus 76501	: V=1.010274, theta=-68.789556 -> V=1.0, theta=0.0
% INFO    : Bus 76502	: V=1.0071537, theta=-71.00751 -> V=1.0, theta=0.0
% INFO    : Bus 76503	: V=0.9965482, theta=-59.596213 -> V=1.0, theta=0.0
% INFO    : Bus 76504	: V=1.0088086, theta=-63.019016 -> V=1.0, theta=0.0
% INFO    : Bus 76505	: V=1.0146021, theta=-68.742181 -> V=1.0, theta=0.0
% INFO    : Bus 76506	: V=0.9948279, theta=-65.632971 -> V=1.0, theta=0.0
% INFO    : Bus 76507	: V=1.0113756, theta=-66.661971 -> V=1.0, theta=0.0
% INFO    : Bus 76508	: V=1.0157478, theta=-65.829614 -> V=1.0, theta=0.0
% INFO    : Bus 76509	: V=1.0139697, theta=-68.569676 -> V=1.0, theta=0.0
% INFO    : Bus 76510	: V=1.0077211, theta=-69.221233 -> V=1.0, theta=0.0
% INFO    : Bus 76511	: V=1.0149316, theta=-68.997074 -> V=1.0, theta=0.0
% INFO    : Bus 76512	: V=1.0057258, theta=-71.928271 -> V=1.0, theta=0.0
% INFO    : Bus 76513	: V=1.013903, theta=-58.829571 -> V=1.0, theta=0.0
% INFO    : Bus 76514	: V=1.0034673, theta=-62.186044 -> V=1.0, theta=0.0
% INFO    : Bus 76515	: V=0.9976237, theta=-63.583811 -> V=1.0, theta=0.0
% INFO    : Bus 76516	: V=0.9962361, theta=-63.331303 -> V=1.0, theta=0.0
% INFO    : Bus 76517	: V=1.0105544, theta=-60.434551 -> V=1.0, theta=0.0
% INFO    : Bus 76518	: V=0.9957402, theta=-62.351128 -> V=1.0, theta=0.0
% INFO    : Bus 76519	: V=0.9928149, theta=-63.007645 -> V=1.0, theta=0.0
% INFO    : Bus 76520	: V=1.0146435, theta=-65.489299 -> V=1.0, theta=0.0
% INFO    : Bus 76521	: V=0.9911079, theta=-70.456498 -> V=1.0, theta=0.0
% INFO    : Bus 76522	: V=0.9813995, theta=-61.9232 -> V=1.0, theta=0.0
% INFO    : Bus 76523	: V=0.9757751, theta=-63.15522 -> V=1.0, theta=0.0
% INFO    : Bus 76524	: V=0.9938063, theta=-64.761013 -> V=1.0, theta=0.0
% INFO    : Bus 76525	: V=1.0126747, theta=-51.771265 -> V=1.0, theta=0.0
% INFO    : Bus 76526	: V=1.0253649, theta=-64.837728 -> V=1.0, theta=0.0
% INFO    : Bus 76527	: V=1.0219583, theta=-64.997502 -> V=1.0, theta=0.0
% INFO    : Bus 76528	: V=1.0028681, theta=-59.168172 -> V=1.0, theta=0.0
% INFO    : Bus 76529	: V=1.0099237, theta=-68.995077 -> V=1.0, theta=0.0
% INFO    : Bus 76530	: V=1.0085385, theta=-72.720603 -> V=1.0, theta=0.0
% INFO    : Bus 76531	: V=1.0094671, theta=-73.071688 -> V=1.0, theta=0.0
% INFO    : Bus 76532	: V=1.0065085, theta=-62.623654 -> V=1.0, theta=0.0
% INFO    : Bus 76533	: V=1.0109335, theta=-59.358776 -> V=1.0, theta=0.0
% INFO    : Bus 76534	: V=1.0125875, theta=-59.243639 -> V=1.0, theta=0.0
% INFO    : Bus 76535	: V=1.0082077, theta=-63.625515 -> V=1.0, theta=0.0
% INFO    : Bus 76536	: V=1.0192717, theta=-58.038227 -> V=1.0, theta=0.0
% INFO    : Bus 76537	: V=1.0044186, theta=-60.388973 -> V=1.0, theta=0.0
% INFO    : Bus 76538	: V=1.02, theta=-57.977938 -> V=1.0, theta=0.0
% INFO    : Bus 76539	: V=0.9963622, theta=-62.666192 -> V=1.0, theta=0.0
% INFO    : Bus 76540	: V=1.018208, theta=-64.9811 -> V=1.0, theta=0.0
% INFO    : Bus 76541	: V=0.9802335, theta=-61.297481 -> V=1.0, theta=0.0
% INFO    : Bus 76542	: V=1.0096418, theta=-68.960198 -> V=1.0, theta=0.0
% INFO    : Bus 76543	: V=1.0121686, theta=-69.821507 -> V=1.0, theta=0.0
% INFO    : Bus 76544	: V=1.0035903, theta=-70.569629 -> V=1.0, theta=0.0
% INFO    : Bus 76545	: V=0.9826107, theta=-70.12133 -> V=1.0, theta=0.0
% INFO    : Bus 76546	: V=0.9881546, theta=-64.66667 -> V=1.0, theta=0.0
% INFO    : Bus 76547	: V=0.9878046, theta=-64.136919 -> V=1.0, theta=0.0
% INFO    : Bus 76548	: V=0.9828176, theta=-65.426116 -> V=1.0, theta=0.0
% INFO    : Bus 76549	: V=0.9930447, theta=-66.913302 -> V=1.0, theta=0.0
% INFO    : Bus 76550	: V=0.9955027, theta=-62.287076 -> V=1.0, theta=0.0
% INFO    : Bus 76551	: V=0.9842538, theta=-74.677035 -> V=1.0, theta=0.0
% INFO    : Bus 76552	: V=0.986475, theta=-63.38655 -> V=1.0, theta=0.0
% INFO    : Bus 76553	: V=0.9809434, theta=-64.458401 -> V=1.0, theta=0.0
% INFO    : Bus 76554	: V=0.9953242, theta=-69.777133 -> V=1.0, theta=0.0
% INFO    : Bus 76555	: V=0.9987657, theta=-58.309908 -> V=1.0, theta=0.0
% INFO    : Bus 76556	: V=1.0071443, theta=-69.736751 -> V=1.0, theta=0.0
% INFO    : Bus 76557	: V=1.0152788, theta=-59.30321 -> V=1.0, theta=0.0
% INFO    : Bus 76558	: V=0.9954488, theta=-64.894475 -> V=1.0, theta=0.0
% INFO    : Bus 76559	: V=0.9967485, theta=-68.03267 -> V=1.0, theta=0.0
% INFO    : Bus 76560	: V=1.016589, theta=-64.440817 -> V=1.0, theta=0.0
% INFO    : Bus 76561	: V=0.9877251, theta=-63.778125 -> V=1.0, theta=0.0
% INFO    : Bus 76562	: V=1.0195337, theta=-73.679135 -> V=1.0, theta=0.0
% INFO    : Bus 76563	: V=1.0183414, theta=-64.840761 -> V=1.0, theta=0.0
% INFO    : Bus 76564	: V=0.9984726, theta=-64.950095 -> V=1.0, theta=0.0
% INFO    : Bus 76565	: V=0.9919334, theta=-63.222855 -> V=1.0, theta=0.0
% INFO    : Bus 76566	: V=1.0166961, theta=-72.761735 -> V=1.0, theta=0.0
% INFO    : Bus 76567	: V=0.9812387, theta=-68.446319 -> V=1.0, theta=0.0
% INFO    : Bus 76568	: V=0.9737079, theta=-69.124396 -> V=1.0, theta=0.0
% INFO    : Bus 76569	: V=0.9730831, theta=-69.067815 -> V=1.0, theta=0.0
% INFO    : Bus 76570	: V=0.9784881, theta=-68.673051 -> V=1.0, theta=0.0
% INFO    : Bus 76571	: V=0.9851938, theta=-68.040546 -> V=1.0, theta=0.0
% INFO    : Bus 76572	: V=0.9700751, theta=-71.052873 -> V=1.0, theta=0.0
% INFO    : Bus 76573	: V=0.9646006, theta=-71.65815 -> V=1.0, theta=0.0
% INFO    : Bus 76574	: V=0.9716731, theta=-70.779594 -> V=1.0, theta=0.0
% INFO    : Bus 76575	: V=0.9627949, theta=-70.249622 -> V=1.0, theta=0.0
% INFO    : Bus 76576	: V=0.9660822, theta=-69.620855 -> V=1.0, theta=0.0
% INFO    : Bus 76577	: V=0.9855921, theta=-67.587858 -> V=1.0, theta=0.0
% INFO    : Bus 76578	: V=0.9893856, theta=-67.202274 -> V=1.0, theta=0.0
% INFO    : Bus 76579	: V=0.9891703, theta=-67.123368 -> V=1.0, theta=0.0
% INFO    : Bus 76580	: V=0.9857669, theta=-65.734352 -> V=1.0, theta=0.0
% INFO    : Bus 76581	: V=0.9745557, theta=-68.679448 -> V=1.0, theta=0.0
% INFO    : Bus 76582	: V=0.9887826, theta=-64.372622 -> V=1.0, theta=0.0
% INFO    : Bus 76583	: V=0.9840278, theta=-65.463249 -> V=1.0, theta=0.0
% INFO    : Bus 76584	: V=0.9826416, theta=-65.6555 -> V=1.0, theta=0.0
% INFO    : Bus 76585	: V=0.9758675, theta=-66.603672 -> V=1.0, theta=0.0
% INFO    : Bus 76586	: V=0.9755974, theta=-66.649295 -> V=1.0, theta=0.0
% INFO    : Bus 76587	: V=0.9801049, theta=-65.857529 -> V=1.0, theta=0.0
% INFO    : Bus 76588	: V=0.976865, theta=-66.331241 -> V=1.0, theta=0.0
% INFO    : Bus 76589	: V=0.9816741, theta=-65.800487 -> V=1.0, theta=0.0
% INFO    : Bus 76590	: V=0.9768297, theta=-66.429775 -> V=1.0, theta=0.0
% INFO    : Bus 76591	: V=0.9777347, theta=-66.254434 -> V=1.0, theta=0.0
% INFO    : Bus 76592	: V=0.9789244, theta=-65.933684 -> V=1.0, theta=0.0
% INFO    : Bus 76593	: V=0.9784702, theta=-66.162801 -> V=1.0, theta=0.0
% INFO    : Bus 76594	: V=0.977281, theta=-66.226697 -> V=1.0, theta=0.0
% INFO    : Bus 76595	: V=0.9778918, theta=-66.141246 -> V=1.0, theta=0.0
% INFO    : Bus 76596	: V=0.9781456, theta=-66.26336 -> V=1.0, theta=0.0
% INFO    : Bus 76597	: V=0.9802329, theta=-65.836886 -> V=1.0, theta=0.0
% INFO    : Bus 76598	: V=0.9784676, theta=-66.180011 -> V=1.0, theta=0.0
% INFO    : Bus 76599	: V=0.9783006, theta=-66.19507 -> V=1.0, theta=0.0
% INFO    : Bus 76600	: V=0.9745106, theta=-66.876569 -> V=1.0, theta=0.0
% INFO    : Bus 76601	: V=0.9784611, theta=-66.180149 -> V=1.0, theta=0.0
% INFO    : Bus 76602	: V=0.980442, theta=-65.662717 -> V=1.0, theta=0.0
% INFO    : Bus 76603	: V=0.980963, theta=-65.789434 -> V=1.0, theta=0.0
% INFO    : Bus 76604	: V=0.9804902, theta=-65.658534 -> V=1.0, theta=0.0
% INFO    : Bus 76605	: V=0.9759306, theta=-66.579651 -> V=1.0, theta=0.0
% INFO    : Bus 76606	: V=0.979369, theta=-65.96164 -> V=1.0, theta=0.0
% INFO    : Bus 76607	: V=0.9783439, theta=-66.186083 -> V=1.0, theta=0.0
% INFO    : Bus 76608	: V=0.9787952, theta=-66.032133 -> V=1.0, theta=0.0
% INFO    : Bus 76609	: V=0.9741172, theta=-66.912906 -> V=1.0, theta=0.0
% INFO    : Bus 76610	: V=0.9790888, theta=-65.956898 -> V=1.0, theta=0.0
% INFO    : Bus 76611	: V=0.9773647, theta=-66.15632 -> V=1.0, theta=0.0
% INFO    : Bus 76612	: V=0.9784931, theta=-65.96374 -> V=1.0, theta=0.0
% INFO    : Bus 76613	: V=0.9789105, theta=-65.918 -> V=1.0, theta=0.0
% INFO    : Bus 76614	: V=0.9793947, theta=-65.867107 -> V=1.0, theta=0.0
% INFO    : Bus 76615	: V=0.9794295, theta=-65.875897 -> V=1.0, theta=0.0
% INFO    : Bus 76616	: V=0.9790789, theta=-65.900813 -> V=1.0, theta=0.0
% INFO    : Bus 76617	: V=0.9807701, theta=-65.75443 -> V=1.0, theta=0.0
% INFO    : Bus 76618	: V=0.9806669, theta=-65.758666 -> V=1.0, theta=0.0
% INFO    : Bus 76619	: V=0.9787405, theta=-65.971123 -> V=1.0, theta=0.0
% INFO    : Bus 76620	: V=0.9786974, theta=-65.975588 -> V=1.0, theta=0.0
% INFO    : Bus 76621	: V=0.9805791, theta=-65.771551 -> V=1.0, theta=0.0
% INFO    : Bus 76622	: V=0.9801321, theta=-65.778016 -> V=1.0, theta=0.0
% INFO    : Bus 76623	: V=0.9771383, theta=-66.356555 -> V=1.0, theta=0.0
% INFO    : Bus 76624	: V=0.978119, theta=-66.231007 -> V=1.0, theta=0.0
% INFO    : Bus 76625	: V=0.9808805, theta=-65.702948 -> V=1.0, theta=0.0
% INFO    : Bus 76626	: V=0.9816559, theta=-65.546068 -> V=1.0, theta=0.0
% INFO    : Bus 76627	: V=0.9776194, theta=-66.265436 -> V=1.0, theta=0.0
% INFO    : Bus 76628	: V=0.9795112, theta=-65.892864 -> V=1.0, theta=0.0
% INFO    : Bus 76629	: V=0.9810738, theta=-65.566006 -> V=1.0, theta=0.0
% INFO    : Bus 76630	: V=0.9819021, theta=-65.446428 -> V=1.0, theta=0.0
% INFO    : Bus 76631	: V=0.9808239, theta=-65.589639 -> V=1.0, theta=0.0
% INFO    : Bus 76632	: V=0.9810288, theta=-65.578839 -> V=1.0, theta=0.0
% INFO    : Bus 76633	: V=0.9793565, theta=-65.796157 -> V=1.0, theta=0.0
% INFO    : Bus 76634	: V=0.9818157, theta=-65.344964 -> V=1.0, theta=0.0
% INFO    : Bus 76635	: V=0.9768031, theta=-66.271664 -> V=1.0, theta=0.0
% INFO    : Bus 76636	: V=0.9808743, theta=-65.582341 -> V=1.0, theta=0.0
% INFO    : Bus 76637	: V=0.9801295, theta=-65.64639 -> V=1.0, theta=0.0
% INFO    : Bus 76638	: V=0.9763483, theta=-66.342421 -> V=1.0, theta=0.0
% INFO    : Bus 76639	: V=0.9767556, theta=-66.314775 -> V=1.0, theta=0.0
% INFO    : Bus 76640	: V=0.9747532, theta=-66.697926 -> V=1.0, theta=0.0
% INFO    : Bus 76641	: V=0.9758061, theta=-66.466676 -> V=1.0, theta=0.0
% INFO    : Bus 76642	: V=0.976152, theta=-66.445113 -> V=1.0, theta=0.0
% INFO    : Bus 76643	: V=0.9819165, theta=-65.356868 -> V=1.0, theta=0.0
% INFO    : Bus 76644	: V=0.9785967, theta=-65.94034 -> V=1.0, theta=0.0
% INFO    : Bus 76645	: V=0.979964, theta=-65.658206 -> V=1.0, theta=0.0
% INFO    : Bus 76646	: V=0.9787058, theta=-65.92697 -> V=1.0, theta=0.0
% INFO    : Bus 76647	: V=0.9800692, theta=-65.655523 -> V=1.0, theta=0.0
% INFO    : Bus 76648	: V=0.9809726, theta=-65.464767 -> V=1.0, theta=0.0
% INFO    : Bus 76649	: V=0.9796253, theta=-65.720603 -> V=1.0, theta=0.0
% INFO    : Bus 76650	: V=0.9811756, theta=-65.451366 -> V=1.0, theta=0.0
% INFO    : Bus 76651	: V=0.97877, theta=-65.935711 -> V=1.0, theta=0.0
% INFO    : Bus 76652	: V=0.9815051, theta=-65.407112 -> V=1.0, theta=0.0
% INFO    : Bus 76653	: V=0.9811364, theta=-65.559115 -> V=1.0, theta=0.0
% INFO    : Bus 76654	: V=0.9849276, theta=-64.921396 -> V=1.0, theta=0.0
% INFO    : Bus 76655	: V=0.9845153, theta=-64.956758 -> V=1.0, theta=0.0
% INFO    : Bus 76656	: V=0.9553086, theta=-75.474923 -> V=1.0, theta=0.0
% INFO    : Bus 76657	: V=0.9559738, theta=-75.144432 -> V=1.0, theta=0.0
% INFO    : Bus 76658	: V=0.9587628, theta=-72.144005 -> V=1.0, theta=0.0
% INFO    : Bus 76659	: V=0.9587418, theta=-72.998795 -> V=1.0, theta=0.0
% INFO    : Bus 76660	: V=0.9556892, theta=-73.295175 -> V=1.0, theta=0.0
% INFO    : Bus 76661	: V=0.9538609, theta=-73.005837 -> V=1.0, theta=0.0
% INFO    : Bus 76662	: V=0.9498264, theta=-72.895388 -> V=1.0, theta=0.0
% INFO    : Bus 76663	: V=0.9477222, theta=-77.6174 -> V=1.0, theta=0.0
% INFO    : Bus 76664	: V=0.9499172, theta=-74.014 -> V=1.0, theta=0.0
% INFO    : Bus 76665	: V=0.9523877, theta=-75.683737 -> V=1.0, theta=0.0
% INFO    : Bus 76666	: V=0.949412, theta=-75.588689 -> V=1.0, theta=0.0
% INFO    : Bus 76667	: V=0.9759953, theta=-75.293123 -> V=1.0, theta=0.0
% INFO    : Bus 76668	: V=0.9761937, theta=-61.569577 -> V=1.0, theta=0.0
% INFO    : Bus 76669	: V=0.9733625, theta=-61.998462 -> V=1.0, theta=0.0
% INFO    : Bus 76670	: V=0.9715427, theta=-66.451015 -> V=1.0, theta=0.0
% INFO    : Bus 76671	: V=0.9664844, theta=-63.897047 -> V=1.0, theta=0.0
% INFO    : Bus 76672	: V=0.9714267, theta=-65.119931 -> V=1.0, theta=0.0
% INFO    : Bus 76673	: V=0.965606, theta=-71.469055 -> V=1.0, theta=0.0
% INFO    : Bus 76674	: V=1.0007323, theta=-67.622814 -> V=1.0, theta=0.0
% INFO    : Bus 76675	: V=0.9965558, theta=-67.890284 -> V=1.0, theta=0.0
% INFO    : Bus 76676	: V=0.9814955, theta=-69.794598 -> V=1.0, theta=0.0
% INFO    : Bus 76677	: V=0.9810887, theta=-69.413114 -> V=1.0, theta=0.0
% INFO    : Bus 76678	: V=0.9684342, theta=-71.040437 -> V=1.0, theta=0.0
% INFO    : Bus 76679	: V=0.9573439, theta=-76.079858 -> V=1.0, theta=0.0
% INFO    : Bus 76680	: V=0.956982, theta=-75.84718 -> V=1.0, theta=0.0
% INFO    : Bus 76681	: V=0.9598648, theta=-75.02153 -> V=1.0, theta=0.0
% INFO    : Bus 76682	: V=0.9583934, theta=-75.835837 -> V=1.0, theta=0.0
% INFO    : Bus 76683	: V=0.9755194, theta=-63.706405 -> V=1.0, theta=0.0
% INFO    : Bus 76684	: V=0.9878615, theta=-63.128399 -> V=1.0, theta=0.0
% INFO    : Bus 76685	: V=0.9830844, theta=-63.756092 -> V=1.0, theta=0.0
% INFO    : Bus 76686	: V=0.9767057, theta=-63.915868 -> V=1.0, theta=0.0
% INFO    : Bus 76687	: V=0.9826294, theta=-64.937923 -> V=1.0, theta=0.0
% INFO    : Bus 76688	: V=0.9723801, theta=-67.44637 -> V=1.0, theta=0.0
% INFO    : Bus 76689	: V=0.9745137, theta=-65.519795 -> V=1.0, theta=0.0
% INFO    : Bus 76690	: V=0.9927433, theta=-66.606468 -> V=1.0, theta=0.0
% INFO    : Bus 76691	: V=0.9932558, theta=-68.311189 -> V=1.0, theta=0.0
% INFO    : Bus 76692	: V=0.9856924, theta=-66.333 -> V=1.0, theta=0.0
% INFO    : Bus 76693	: V=0.9927285, theta=-65.88822 -> V=1.0, theta=0.0
% INFO    : Bus 76694	: V=0.9962241, theta=-64.731967 -> V=1.0, theta=0.0
% INFO    : Bus 76695	: V=0.988114, theta=-65.326024 -> V=1.0, theta=0.0
% INFO    : Bus 76696	: V=0.9793291, theta=-66.351908 -> V=1.0, theta=0.0
% INFO    : Bus 76697	: V=0.9711126, theta=-68.059919 -> V=1.0, theta=0.0
% INFO    : Bus 76698	: V=0.96481, theta=-70.551277 -> V=1.0, theta=0.0
% INFO    : Bus 76699	: V=0.959333, theta=-71.336707 -> V=1.0, theta=0.0
% INFO    : Bus 76700	: V=0.9715566, theta=-70.390787 -> V=1.0, theta=0.0
% INFO    : Bus 76701	: V=0.9852711, theta=-63.94347 -> V=1.0, theta=0.0
% INFO    : Bus 76702	: V=0.9976304, theta=-64.018224 -> V=1.0, theta=0.0
% INFO    : Bus 76703	: V=0.9955868, theta=-64.171598 -> V=1.0, theta=0.0
% INFO    : Bus 76704	: V=0.9805079, theta=-66.564725 -> V=1.0, theta=0.0
% INFO    : Bus 76705	: V=0.9725823, theta=-65.482674 -> V=1.0, theta=0.0
% INFO    : Bus 76706	: V=0.9894993, theta=-62.919153 -> V=1.0, theta=0.0
% INFO    : Bus 76707	: V=0.9831791, theta=-63.558015 -> V=1.0, theta=0.0
% INFO    : Bus 76708	: V=0.9674707, theta=-66.180452 -> V=1.0, theta=0.0
% INFO    : Bus 76709	: V=0.9648093, theta=-65.926297 -> V=1.0, theta=0.0
% INFO    : Bus 76710	: V=0.9622175, theta=-67.038971 -> V=1.0, theta=0.0
% INFO    : Bus 76711	: V=0.9774147, theta=-66.151432 -> V=1.0, theta=0.0
% INFO    : Bus 76712	: V=0.9675332, theta=-65.74847 -> V=1.0, theta=0.0
% INFO    : Bus 76713	: V=0.9668383, theta=-66.459616 -> V=1.0, theta=0.0
% INFO    : Bus 76714	: V=0.9702904, theta=-66.427763 -> V=1.0, theta=0.0
% INFO    : Bus 76715	: V=0.9768108, theta=-64.891959 -> V=1.0, theta=0.0
% INFO    : Bus 76716	: V=0.9653528, theta=-66.731966 -> V=1.0, theta=0.0
% INFO    : Bus 76717	: V=0.9856065, theta=-63.49469 -> V=1.0, theta=0.0
% INFO    : Bus 76718	: V=0.9656542, theta=-65.677295 -> V=1.0, theta=0.0
% INFO    : Bus 76719	: V=0.9680595, theta=-64.98234 -> V=1.0, theta=0.0
% INFO    : Bus 76720	: V=0.9781393, theta=-64.662886 -> V=1.0, theta=0.0
% INFO    : Bus 76721	: V=0.9970205, theta=-74.840099 -> V=1.0, theta=0.0
% INFO    : Bus 76722	: V=0.9994141, theta=-74.164364 -> V=1.0, theta=0.0
% INFO    : Bus 76723	: V=0.9994605, theta=-73.097299 -> V=1.0, theta=0.0
% INFO    : Bus 76724	: V=1.0016346, theta=-73.276253 -> V=1.0, theta=0.0
% INFO    : Bus 76725	: V=1.0061931, theta=-73.974588 -> V=1.0, theta=0.0
% INFO    : Bus 76726	: V=1.0035794, theta=-74.271701 -> V=1.0, theta=0.0
% INFO    : Bus 76727	: V=1.0100414, theta=-74.415731 -> V=1.0, theta=0.0
% INFO    : Bus 76728	: V=1.007288, theta=-74.428127 -> V=1.0, theta=0.0
% INFO    : Bus 76729	: V=0.9978852, theta=-71.521534 -> V=1.0, theta=0.0
% INFO    : Bus 76730	: V=1.0026063, theta=-73.003432 -> V=1.0, theta=0.0
% INFO    : Bus 76731	: V=1.0033597, theta=-73.718238 -> V=1.0, theta=0.0
% INFO    : Bus 76732	: V=1.0022934, theta=-73.385606 -> V=1.0, theta=0.0
% INFO    : Bus 76733	: V=1.0021926, theta=-74.035354 -> V=1.0, theta=0.0
% INFO    : Bus 76734	: V=1.0016135, theta=-73.3225 -> V=1.0, theta=0.0
% INFO    : Bus 76735	: V=1.0026272, theta=-71.824954 -> V=1.0, theta=0.0
% INFO    : Bus 76736	: V=1.002598, theta=-72.51314 -> V=1.0, theta=0.0
% INFO    : Bus 76737	: V=1.0010067, theta=-72.679363 -> V=1.0, theta=0.0
% INFO    : Bus 76738	: V=1.0018354, theta=-73.338143 -> V=1.0, theta=0.0
% INFO    : Bus 76739	: V=1.0015281, theta=-73.341575 -> V=1.0, theta=0.0
% INFO    : Bus 76740	: V=0.999508, theta=-73.549965 -> V=1.0, theta=0.0
% INFO    : Bus 76741	: V=1.0003469, theta=-73.528357 -> V=1.0, theta=0.0
% INFO    : Bus 76742	: V=0.9956078, theta=-73.456397 -> V=1.0, theta=0.0
% INFO    : Bus 76743	: V=0.9966604, theta=-73.802319 -> V=1.0, theta=0.0
% INFO    : Bus 76744	: V=1.0001779, theta=-72.412027 -> V=1.0, theta=0.0
% INFO    : Bus 76745	: V=1.0010701, theta=-72.931394 -> V=1.0, theta=0.0
% INFO    : Bus 76746	: V=0.9945249, theta=-72.351939 -> V=1.0, theta=0.0
% INFO    : Bus 76747	: V=0.990237, theta=-71.643198 -> V=1.0, theta=0.0
% INFO    : Bus 76748	: V=1.0018796, theta=-71.771933 -> V=1.0, theta=0.0
% INFO    : Bus 76749	: V=0.994189, theta=-70.326838 -> V=1.0, theta=0.0
% INFO    : Bus 76750	: V=0.9908495, theta=-71.348738 -> V=1.0, theta=0.0
% INFO    : Bus 76751	: V=0.9844379, theta=-70.133326 -> V=1.0, theta=0.0
% INFO    : Bus 76752	: V=0.9988444, theta=-73.878791 -> V=1.0, theta=0.0
% INFO    : Bus 76753	: V=1.0013474, theta=-74.301288 -> V=1.0, theta=0.0
% INFO    : Bus 76754	: V=1.006879, theta=-73.9603 -> V=1.0, theta=0.0
% INFO    : Bus 76755	: V=0.9827271, theta=-67.021171 -> V=1.0, theta=0.0
% INFO    : Bus 76756	: V=0.9842897, theta=-70.439639 -> V=1.0, theta=0.0
% INFO    : Bus 76757	: V=0.9570539, theta=-71.542554 -> V=1.0, theta=0.0
% INFO    : Bus 76758	: V=0.9618256, theta=-71.550649 -> V=1.0, theta=0.0
% INFO    : Bus 76759	: V=0.964419, theta=-70.985052 -> V=1.0, theta=0.0
% INFO    : Bus 76760	: V=0.9830616, theta=-71.474363 -> V=1.0, theta=0.0
% INFO    : Bus 76761	: V=0.9873816, theta=-71.013153 -> V=1.0, theta=0.0
% INFO    : Bus 76762	: V=0.9937788, theta=-70.183007 -> V=1.0, theta=0.0
% INFO    : Bus 76763	: V=0.9940476, theta=-70.187433 -> V=1.0, theta=0.0
% INFO    : Bus 76764	: V=0.9821153, theta=-70.228507 -> V=1.0, theta=0.0
% INFO    : Bus 76765	: V=0.99032, theta=-70.30932 -> V=1.0, theta=0.0
% INFO    : Bus 76766	: V=0.9815553, theta=-64.079777 -> V=1.0, theta=0.0
% INFO    : Bus 76767	: V=1.0021224, theta=-64.506309 -> V=1.0, theta=0.0
% INFO    : Bus 76768	: V=0.9844425, theta=-65.704919 -> V=1.0, theta=0.0
% INFO    : Bus 76769	: V=0.9618084, theta=-66.64913 -> V=1.0, theta=0.0
% INFO    : Bus 76770	: V=0.9621545, theta=-66.802324 -> V=1.0, theta=0.0
% INFO    : Bus 76771	: V=0.9660525, theta=-68.007672 -> V=1.0, theta=0.0
% INFO    : Bus 76772	: V=0.9617085, theta=-67.263192 -> V=1.0, theta=0.0
% INFO    : Bus 76773	: V=0.9788889, theta=-65.149642 -> V=1.0, theta=0.0
% INFO    : Bus 76774	: V=0.9788038, theta=-63.143758 -> V=1.0, theta=0.0
% INFO    : Bus 76775	: V=0.9897365, theta=-64.30816 -> V=1.0, theta=0.0
% INFO    : Bus 76776	: V=0.9868931, theta=-63.734216 -> V=1.0, theta=0.0
% INFO    : Bus 76777	: V=0.9867693, theta=-64.941102 -> V=1.0, theta=0.0
% INFO    : Bus 76778	: V=0.9907584, theta=-64.23543 -> V=1.0, theta=0.0
% INFO    : Bus 76779	: V=0.9895491, theta=-63.33065 -> V=1.0, theta=0.0
% INFO    : Bus 76780	: V=0.9893283, theta=-63.380711 -> V=1.0, theta=0.0
% INFO    : Bus 76781	: V=0.9909397, theta=-64.292042 -> V=1.0, theta=0.0
% INFO    : Bus 76782	: V=0.9835298, theta=-64.35696 -> V=1.0, theta=0.0
% INFO    : Bus 76783	: V=0.9899688, theta=-64.175365 -> V=1.0, theta=0.0
% INFO    : Bus 76784	: V=0.9901074, theta=-64.183405 -> V=1.0, theta=0.0
% INFO    : Bus 76785	: V=0.988542, theta=-64.259836 -> V=1.0, theta=0.0
% INFO    : Bus 76786	: V=0.9881807, theta=-64.249679 -> V=1.0, theta=0.0
% INFO    : Bus 76787	: V=0.9834577, theta=-64.283389 -> V=1.0, theta=0.0
% INFO    : Bus 76788	: V=0.9834804, theta=-64.341431 -> V=1.0, theta=0.0
% INFO    : Bus 76789	: V=0.9840649, theta=-64.283685 -> V=1.0, theta=0.0
% INFO    : Bus 76790	: V=0.9866703, theta=-63.749114 -> V=1.0, theta=0.0
% INFO    : Bus 76791	: V=0.9840967, theta=-64.243279 -> V=1.0, theta=0.0
% INFO    : Bus 76792	: V=0.986506, theta=-63.762162 -> V=1.0, theta=0.0
% INFO    : Bus 76793	: V=0.983388, theta=-64.387421 -> V=1.0, theta=0.0
% INFO    : Bus 76794	: V=0.9833717, theta=-64.429391 -> V=1.0, theta=0.0
% INFO    : Bus 76795	: V=0.9841493, theta=-64.244125 -> V=1.0, theta=0.0
% INFO    : Bus 76796	: V=0.9809614, theta=-64.980989 -> V=1.0, theta=0.0
% INFO    : Bus 76797	: V=0.9901029, theta=-63.942701 -> V=1.0, theta=0.0
% INFO    : Bus 76798	: V=0.9903794, theta=-64.126631 -> V=1.0, theta=0.0
% INFO    : Bus 76799	: V=0.9880729, theta=-64.114148 -> V=1.0, theta=0.0
% INFO    : Bus 76800	: V=0.9864517, theta=-64.388284 -> V=1.0, theta=0.0
% INFO    : Bus 76801	: V=0.9864647, theta=-64.494165 -> V=1.0, theta=0.0
% INFO    : Bus 76802	: V=0.9825393, theta=-64.12704 -> V=1.0, theta=0.0
% INFO    : Bus 76803	: V=0.9879569, theta=-64.233885 -> V=1.0, theta=0.0
% INFO    : Bus 76804	: V=0.9832033, theta=-64.315761 -> V=1.0, theta=0.0
% INFO    : Bus 76805	: V=0.9897683, theta=-64.206415 -> V=1.0, theta=0.0
% INFO    : Bus 76806	: V=0.9810048, theta=-64.799 -> V=1.0, theta=0.0
% INFO    : Bus 76807	: V=0.9813237, theta=-64.377245 -> V=1.0, theta=0.0
% INFO    : Bus 76808	: V=0.9922166, theta=-64.232319 -> V=1.0, theta=0.0
% INFO    : Bus 76809	: V=0.9923299, theta=-64.057055 -> V=1.0, theta=0.0
% INFO    : Bus 76810	: V=0.9923603, theta=-64.047091 -> V=1.0, theta=0.0
% INFO    : Bus 76811	: V=0.9901358, theta=-64.176983 -> V=1.0, theta=0.0
% INFO    : Bus 76812	: V=0.9895793, theta=-64.233264 -> V=1.0, theta=0.0
% INFO    : Bus 76813	: V=0.9892948, theta=-64.276478 -> V=1.0, theta=0.0
% INFO    : Bus 76814	: V=0.9911763, theta=-64.091451 -> V=1.0, theta=0.0
% INFO    : Bus 76815	: V=0.9892999, theta=-64.278088 -> V=1.0, theta=0.0
% INFO    : Bus 76816	: V=0.9843539, theta=-64.13409 -> V=1.0, theta=0.0
% INFO    : Bus 76817	: V=0.9835753, theta=-65.39592 -> V=1.0, theta=0.0
% INFO    : Bus 76818	: V=0.9806254, theta=-65.29758 -> V=1.0, theta=0.0
% INFO    : Bus 76819	: V=0.9900793, theta=-64.241771 -> V=1.0, theta=0.0
% INFO    : Bus 76820	: V=0.9805612, theta=-65.214737 -> V=1.0, theta=0.0
% INFO    : Bus 76821	: V=0.9909851, theta=-64.6946 -> V=1.0, theta=0.0
% INFO    : Bus 76822	: V=0.9925147, theta=-64.317865 -> V=1.0, theta=0.0
% INFO    : Bus 76823	: V=0.9828261, theta=-65.469203 -> V=1.0, theta=0.0
% INFO    : Bus 76824	: V=0.9841982, theta=-65.164274 -> V=1.0, theta=0.0
% INFO    : Bus 76825	: V=0.982012, theta=-65.510313 -> V=1.0, theta=0.0
% INFO    : Bus 76826	: V=0.9793505, theta=-65.705039 -> V=1.0, theta=0.0
% INFO    : Bus 76827	: V=0.9792871, theta=-65.711006 -> V=1.0, theta=0.0
% INFO    : Bus 76828	: V=0.9799091, theta=-65.143083 -> V=1.0, theta=0.0
% INFO    : Bus 76829	: V=0.9815857, theta=-65.532634 -> V=1.0, theta=0.0
% INFO    : Bus 76830	: V=0.9806662, theta=-65.603293 -> V=1.0, theta=0.0
% INFO    : Bus 76831	: V=0.9812629, theta=-64.382717 -> V=1.0, theta=0.0
% INFO    : Bus 76832	: V=0.9810662, theta=-65.568298 -> V=1.0, theta=0.0
% INFO    : Bus 76833	: V=0.9796665, theta=-65.221347 -> V=1.0, theta=0.0
% INFO    : Bus 76834	: V=0.9790389, theta=-65.268436 -> V=1.0, theta=0.0
% INFO    : Bus 76835	: V=0.9878823, theta=-64.861383 -> V=1.0, theta=0.0
% INFO    : Bus 76836	: V=0.9723612, theta=-66.395722 -> V=1.0, theta=0.0
% INFO    : Bus 76837	: V=0.9770871, theta=-66.138635 -> V=1.0, theta=0.0
% INFO    : Bus 76838	: V=0.9776833, theta=-66.097994 -> V=1.0, theta=0.0
% INFO    : Bus 76839	: V=0.9795355, theta=-65.937077 -> V=1.0, theta=0.0
% INFO    : Bus 76840	: V=0.9788499, theta=-65.984854 -> V=1.0, theta=0.0
% INFO    : Bus 76841	: V=0.9781519, theta=-65.801983 -> V=1.0, theta=0.0
% INFO    : Bus 76842	: V=0.9761839, theta=-66.263365 -> V=1.0, theta=0.0
% INFO    : Bus 76843	: V=0.9718448, theta=-66.45076 -> V=1.0, theta=0.0
% INFO    : Bus 76844	: V=0.9762085, theta=-66.239568 -> V=1.0, theta=0.0
% INFO    : Bus 76845	: V=0.9713785, theta=-66.471226 -> V=1.0, theta=0.0
% INFO    : Bus 76846	: V=0.9753835, theta=-66.544291 -> V=1.0, theta=0.0
% INFO    : Bus 76847	: V=0.9756727, theta=-66.511597 -> V=1.0, theta=0.0
% INFO    : Bus 76848	: V=0.9803591, theta=-65.635632 -> V=1.0, theta=0.0
% INFO    : Bus 76849	: V=0.981386, theta=-65.443139 -> V=1.0, theta=0.0
% INFO    : Bus 76850	: V=0.9750019, theta=-66.608328 -> V=1.0, theta=0.0
% INFO    : Bus 76851	: V=0.9755335, theta=-66.526622 -> V=1.0, theta=0.0
% INFO    : Bus 76852	: V=0.979065, theta=-65.934214 -> V=1.0, theta=0.0
% INFO    : Bus 76853	: V=0.9794255, theta=-65.924763 -> V=1.0, theta=0.0
% INFO    : Bus 76854	: V=0.9731416, theta=-66.344971 -> V=1.0, theta=0.0
% INFO    : Bus 76855	: V=0.9789834, theta=-66.0629 -> V=1.0, theta=0.0
% INFO    : Bus 76856	: V=0.9784262, theta=-65.431993 -> V=1.0, theta=0.0
% INFO    : Bus 76857	: V=0.9768178, theta=-66.398168 -> V=1.0, theta=0.0
% INFO    : Bus 76858	: V=0.9786865, theta=-65.970726 -> V=1.0, theta=0.0
% INFO    : Bus 76859	: V=0.9785883, theta=-66.099077 -> V=1.0, theta=0.0
% INFO    : Bus 76860	: V=0.9784597, theta=-66.12326 -> V=1.0, theta=0.0
% INFO    : Bus 76861	: V=0.9807423, theta=-65.723998 -> V=1.0, theta=0.0
% INFO    : Bus 76862	: V=0.9852494, theta=-64.863781 -> V=1.0, theta=0.0
% INFO    : Bus 76863	: V=0.9831637, theta=-65.446984 -> V=1.0, theta=0.0
% INFO    : Bus 76864	: V=0.9742035, theta=-66.134053 -> V=1.0, theta=0.0
% INFO    : Bus 76865	: V=0.9792178, theta=-65.404253 -> V=1.0, theta=0.0
% INFO    : Bus 76866	: V=0.9767502, theta=-65.85736 -> V=1.0, theta=0.0
% INFO    : Bus 76867	: V=0.9800342, theta=-65.29457 -> V=1.0, theta=0.0
% INFO    : Bus 76868	: V=0.9848778, theta=-64.589727 -> V=1.0, theta=0.0
% INFO    : Bus 76869	: V=0.9840455, theta=-65.175459 -> V=1.0, theta=0.0
% INFO    : Bus 76870	: V=0.9788918, theta=-66.072315 -> V=1.0, theta=0.0
% INFO    : Bus 76871	: V=0.980484, theta=-65.333267 -> V=1.0, theta=0.0
% INFO    : Bus 76872	: V=0.9807342, theta=-65.312516 -> V=1.0, theta=0.0
% INFO    : Bus 76873	: V=0.9842293, theta=-65.162404 -> V=1.0, theta=0.0
% INFO    : Bus 76874	: V=0.9761583, theta=-66.165513 -> V=1.0, theta=0.0
% INFO    : Bus 76875	: V=0.9779948, theta=-65.736705 -> V=1.0, theta=0.0
% INFO    : Bus 76876	: V=0.9819099, theta=-65.553779 -> V=1.0, theta=0.0
% INFO    : Bus 76877	: V=0.9825289, theta=-65.512216 -> V=1.0, theta=0.0
% INFO    : Bus 76878	: V=0.98287, theta=-65.428729 -> V=1.0, theta=0.0
% INFO    : Bus 76879	: V=0.9896276, theta=-64.512511 -> V=1.0, theta=0.0
% INFO    : Bus 76880	: V=0.9822912, theta=-65.457122 -> V=1.0, theta=0.0
% INFO    : Bus 76881	: V=0.9848658, theta=-65.10633 -> V=1.0, theta=0.0
% INFO    : Bus 76882	: V=0.9912033, theta=-64.385664 -> V=1.0, theta=0.0
% INFO    : Bus 76883	: V=0.9941276, theta=-64.019955 -> V=1.0, theta=0.0
% INFO    : Bus 76884	: V=0.991939, theta=-64.380292 -> V=1.0, theta=0.0
% INFO    : Bus 76885	: V=0.9911076, theta=-64.432127 -> V=1.0, theta=0.0
% INFO    : Bus 76886	: V=0.9824033, theta=-65.626954 -> V=1.0, theta=0.0
% INFO    : Bus 76887	: V=0.9844743, theta=-65.194335 -> V=1.0, theta=0.0
% INFO    : Bus 76888	: V=0.9711179, theta=-66.684657 -> V=1.0, theta=0.0
% INFO    : Bus 76889	: V=0.9822044, theta=-65.63528 -> V=1.0, theta=0.0
% INFO    : Bus 76890	: V=0.9703803, theta=-66.72368 -> V=1.0, theta=0.0
% INFO    : Bus 76891	: V=0.9845656, theta=-65.191816 -> V=1.0, theta=0.0
% INFO    : Bus 76892	: V=0.9825855, theta=-65.574484 -> V=1.0, theta=0.0
% INFO    : Bus 76893	: V=0.9704493, theta=-66.789808 -> V=1.0, theta=0.0
% INFO    : Bus 76894	: V=0.9711215, theta=-66.734387 -> V=1.0, theta=0.0
% INFO    : Bus 76895	: V=0.9704352, theta=-66.854079 -> V=1.0, theta=0.0
% INFO    : Bus 76896	: V=0.9718651, theta=-66.602467 -> V=1.0, theta=0.0
% INFO    : Bus 76897	: V=0.9733581, theta=-66.419862 -> V=1.0, theta=0.0
% INFO    : Bus 76898	: V=0.9857864, theta=-64.593635 -> V=1.0, theta=0.0
% INFO    : Bus 76899	: V=0.9746783, theta=-66.417419 -> V=1.0, theta=0.0
% INFO    : Bus 76900	: V=0.9748265, theta=-66.315634 -> V=1.0, theta=0.0
% INFO    : Bus 76901	: V=0.9739239, theta=-66.361095 -> V=1.0, theta=0.0
% INFO    : Bus 76902	: V=0.9778681, theta=-65.759813 -> V=1.0, theta=0.0
% INFO    : Bus 76903	: V=0.9741123, theta=-66.475223 -> V=1.0, theta=0.0
% INFO    : Bus 76904	: V=0.972605, theta=-66.686921 -> V=1.0, theta=0.0
% INFO    : Bus 76905	: V=0.9743884, theta=-66.461166 -> V=1.0, theta=0.0
% INFO    : Bus 76906	: V=0.9743595, theta=-66.65008 -> V=1.0, theta=0.0
% INFO    : Bus 76907	: V=0.9725234, theta=-66.740185 -> V=1.0, theta=0.0
% INFO    : Bus 76908	: V=0.972626, theta=-66.88265 -> V=1.0, theta=0.0
% INFO    : Bus 76909	: V=0.9718747, theta=-66.71338 -> V=1.0, theta=0.0
% INFO    : Bus 76910	: V=0.9723268, theta=-66.739307 -> V=1.0, theta=0.0
% INFO    : Bus 76911	: V=0.9710755, theta=-66.86551 -> V=1.0, theta=0.0
% INFO    : Bus 76912	: V=0.9700551, theta=-67.101108 -> V=1.0, theta=0.0
% INFO    : Bus 76913	: V=0.9743765, theta=-66.696378 -> V=1.0, theta=0.0
% INFO    : Bus 76914	: V=0.9728538, theta=-66.834494 -> V=1.0, theta=0.0
% INFO    : Bus 76915	: V=0.9742861, theta=-66.669624 -> V=1.0, theta=0.0
% INFO    : Bus 76916	: V=0.9725184, theta=-66.792662 -> V=1.0, theta=0.0
% INFO    : Bus 76917	: V=0.9770114, theta=-66.176776 -> V=1.0, theta=0.0
% INFO    : Bus 76918	: V=0.9740171, theta=-66.720556 -> V=1.0, theta=0.0
% INFO    : Bus 76919	: V=0.9728085, theta=-66.953377 -> V=1.0, theta=0.0
% INFO    : Bus 76920	: V=0.974177, theta=-66.705653 -> V=1.0, theta=0.0
% INFO    : Bus 76921	: V=0.9853418, theta=-65.080371 -> V=1.0, theta=0.0
% INFO    : Bus 76922	: V=1.0062252, theta=-60.139291 -> V=1.0, theta=0.0
% INFO    : Bus 76923	: V=0.9744878, theta=-70.231345 -> V=1.0, theta=0.0
% INFO    : Bus 76924	: V=0.9735474, theta=-71.255714 -> V=1.0, theta=0.0
% INFO    : Bus 76925	: V=0.9773678, theta=-61.838935 -> V=1.0, theta=0.0
% INFO    : Bus 76926	: V=0.9738217, theta=-62.946561 -> V=1.0, theta=0.0
% INFO    : Bus 76927	: V=0.9753099, theta=-63.093371 -> V=1.0, theta=0.0
% INFO    : Bus 76928	: V=0.9967089, theta=-69.72395 -> V=1.0, theta=0.0
% INFO    : Bus 76929	: V=0.9955396, theta=-69.394096 -> V=1.0, theta=0.0
% INFO    : Bus 76930	: V=0.9968744, theta=-69.585926 -> V=1.0, theta=0.0
% INFO    : Bus 76931	: V=0.9931616, theta=-69.662093 -> V=1.0, theta=0.0
% INFO    : Bus 76932	: V=0.985746, theta=-69.617855 -> V=1.0, theta=0.0
% INFO    : Bus 76933	: V=0.9890071, theta=-68.864098 -> V=1.0, theta=0.0
% INFO    : Bus 76934	: V=0.9951929, theta=-69.129922 -> V=1.0, theta=0.0
% INFO    : Bus 76935	: V=0.989275, theta=-69.342593 -> V=1.0, theta=0.0
% INFO    : Bus 76936	: V=0.9949754, theta=-69.065833 -> V=1.0, theta=0.0
% INFO    : Bus 76937	: V=0.9960848, theta=-69.488476 -> V=1.0, theta=0.0
% INFO    : Bus 76938	: V=0.9853132, theta=-69.880045 -> V=1.0, theta=0.0
% INFO    : Bus 76939	: V=0.9928286, theta=-67.560224 -> V=1.0, theta=0.0
% INFO    : Bus 76940	: V=0.9978949, theta=-68.764794 -> V=1.0, theta=0.0
% INFO    : Bus 76941	: V=0.9923584, theta=-68.931174 -> V=1.0, theta=0.0
% INFO    : Bus 76942	: V=1.0003515, theta=-65.387994 -> V=1.0, theta=0.0
% INFO    : Bus 76943	: V=1.0040721, theta=-64.957272 -> V=1.0, theta=0.0
% INFO    : Bus 76944	: V=0.9963366, theta=-66.787464 -> V=1.0, theta=0.0
% INFO    : Bus 76945	: V=0.9932154, theta=-68.202359 -> V=1.0, theta=0.0
% INFO    : Bus 76946	: V=0.9869082, theta=-67.53092 -> V=1.0, theta=0.0
% INFO    : Bus 76947	: V=0.9881627, theta=-68.010209 -> V=1.0, theta=0.0
% INFO    : Bus 76948	: V=0.9894131, theta=-68.176674 -> V=1.0, theta=0.0
% INFO    : Bus 76949	: V=0.9836669, theta=-68.486958 -> V=1.0, theta=0.0
% INFO    : Bus 76950	: V=0.9842577, theta=-68.882321 -> V=1.0, theta=0.0
% INFO    : Bus 76951	: V=0.9913119, theta=-67.187947 -> V=1.0, theta=0.0
% INFO    : Bus 76952	: V=0.9881646, theta=-68.203785 -> V=1.0, theta=0.0
% INFO    : Bus 76953	: V=0.9814216, theta=-68.994391 -> V=1.0, theta=0.0
% INFO    : Bus 76954	: V=0.9824895, theta=-70.181485 -> V=1.0, theta=0.0
% INFO    : Bus 76955	: V=0.984573, theta=-70.073129 -> V=1.0, theta=0.0
% INFO    : Bus 76956	: V=0.9848466, theta=-69.3253 -> V=1.0, theta=0.0
% INFO    : Bus 76957	: V=0.9850331, theta=-69.442833 -> V=1.0, theta=0.0
% INFO    : Bus 76958	: V=0.9554707, theta=-71.690265 -> V=1.0, theta=0.0
% INFO    : Bus 76959	: V=0.980465, theta=-66.469223 -> V=1.0, theta=0.0
% INFO    : Bus 76960	: V=0.9778762, theta=-66.617629 -> V=1.0, theta=0.0
% INFO    : Bus 76961	: V=0.9912815, theta=-64.774625 -> V=1.0, theta=0.0
% INFO    : Bus 76962	: V=0.9764714, theta=-66.728677 -> V=1.0, theta=0.0
% INFO    : Bus 76963	: V=0.9881297, theta=-66.031274 -> V=1.0, theta=0.0
% INFO    : Bus 76964	: V=0.9912505, theta=-65.186567 -> V=1.0, theta=0.0
% INFO    : Bus 76965	: V=0.983609, theta=-65.995683 -> V=1.0, theta=0.0
% INFO    : Bus 76966	: V=0.9925943, theta=-65.354927 -> V=1.0, theta=0.0
% INFO    : Bus 76967	: V=0.9772052, theta=-66.580014 -> V=1.0, theta=0.0
% INFO    : Bus 76968	: V=0.9809042, theta=-66.173318 -> V=1.0, theta=0.0
% INFO    : Bus 76969	: V=0.9822258, theta=-66.012571 -> V=1.0, theta=0.0
% INFO    : Bus 76970	: V=0.9871306, theta=-65.585111 -> V=1.0, theta=0.0
% INFO    : Bus 76971	: V=0.980067, theta=-66.007632 -> V=1.0, theta=0.0
% INFO    : Bus 76972	: V=0.9789578, theta=-66.161816 -> V=1.0, theta=0.0
% INFO    : Bus 76973	: V=0.9797743, theta=-65.976927 -> V=1.0, theta=0.0
% INFO    : Bus 76974	: V=0.9785962, theta=-66.522732 -> V=1.0, theta=0.0
% INFO    : Bus 76975	: V=0.9827341, theta=-66.046209 -> V=1.0, theta=0.0
% INFO    : Bus 76976	: V=0.9818977, theta=-66.415006 -> V=1.0, theta=0.0
% INFO    : Bus 76977	: V=0.9823179, theta=-66.061607 -> V=1.0, theta=0.0
% INFO    : Bus 76978	: V=0.9843469, theta=-65.736316 -> V=1.0, theta=0.0
% INFO    : Bus 76979	: V=0.986662, theta=-65.078782 -> V=1.0, theta=0.0
% INFO    : Bus 76980	: V=0.9939637, theta=-63.858708 -> V=1.0, theta=0.0
% INFO    : Bus 76981	: V=1.0021006, theta=-62.853862 -> V=1.0, theta=0.0
% INFO    : Bus 76982	: V=0.9876749, theta=-65.168003 -> V=1.0, theta=0.0
% INFO    : Bus 76983	: V=0.986691, theta=-65.250523 -> V=1.0, theta=0.0
% INFO    : Bus 76984	: V=0.9906361, theta=-64.18532 -> V=1.0, theta=0.0
% INFO    : Bus 76985	: V=0.988159, theta=-64.565185 -> V=1.0, theta=0.0
% INFO    : Bus 76986	: V=0.9832429, theta=-64.877959 -> V=1.0, theta=0.0
% INFO    : Bus 76987	: V=0.9820561, theta=-65.179612 -> V=1.0, theta=0.0
% INFO    : Bus 76988	: V=0.9856741, theta=-66.173663 -> V=1.0, theta=0.0
% INFO    : Bus 76989	: V=0.9796768, theta=-66.726226 -> V=1.0, theta=0.0
% INFO    : Bus 76990	: V=0.9863847, theta=-65.996049 -> V=1.0, theta=0.0
% INFO    : Bus 76991	: V=0.9778952, theta=-67.143375 -> V=1.0, theta=0.0
% INFO    : Bus 76992	: V=0.9815351, theta=-66.588874 -> V=1.0, theta=0.0
% INFO    : Bus 76993	: V=0.9896262, theta=-65.616398 -> V=1.0, theta=0.0
% INFO    : Bus 76994	: V=0.9874156, theta=-66.111066 -> V=1.0, theta=0.0
% INFO    : Bus 76995	: V=0.9859924, theta=-66.108453 -> V=1.0, theta=0.0
% INFO    : Bus 76996	: V=0.9860724, theta=-66.232296 -> V=1.0, theta=0.0
% INFO    : Bus 76997	: V=0.9968792, theta=-64.662149 -> V=1.0, theta=0.0
% INFO    : Bus 76998	: V=0.9795316, theta=-65.700264 -> V=1.0, theta=0.0
% INFO    : Bus 76999	: V=0.9933762, theta=-65.384185 -> V=1.0, theta=0.0
% INFO    : Bus 77000	: V=0.9971071, theta=-64.488168 -> V=1.0, theta=0.0
% INFO    : Bus 77001	: V=0.9860377, theta=-64.651203 -> V=1.0, theta=0.0
% INFO    : Bus 77002	: V=0.9902199, theta=-64.471654 -> V=1.0, theta=0.0
% INFO    : Bus 77003	: V=0.9909658, theta=-64.145106 -> V=1.0, theta=0.0
% INFO    : Bus 77004	: V=0.9844381, theta=-64.352102 -> V=1.0, theta=0.0
% INFO    : Bus 77005	: V=0.9849242, theta=-63.194368 -> V=1.0, theta=0.0
% INFO    : Bus 77006	: V=0.9867742, theta=-64.488134 -> V=1.0, theta=0.0
% INFO    : Bus 77007	: V=0.9879355, theta=-64.114098 -> V=1.0, theta=0.0
% INFO    : Bus 77008	: V=0.9842416, theta=-63.679827 -> V=1.0, theta=0.0
% INFO    : Bus 77009	: V=0.9872206, theta=-63.741722 -> V=1.0, theta=0.0
% INFO    : Bus 77010	: V=0.9843118, theta=-64.442709 -> V=1.0, theta=0.0
% INFO    : Bus 77011	: V=0.9848974, theta=-63.160831 -> V=1.0, theta=0.0
% INFO    : Bus 77012	: V=0.986482, theta=-63.851273 -> V=1.0, theta=0.0
% INFO    : Bus 77013	: V=0.9851416, theta=-64.658945 -> V=1.0, theta=0.0
% INFO    : Bus 77014	: V=0.9790336, theta=-65.138844 -> V=1.0, theta=0.0
% INFO    : Bus 77015	: V=0.9899641, theta=-64.16449 -> V=1.0, theta=0.0
% INFO    : Bus 77016	: V=0.9921002, theta=-64.2226 -> V=1.0, theta=0.0
% INFO    : Bus 77017	: V=0.9907415, theta=-64.384649 -> V=1.0, theta=0.0
% INFO    : Bus 77018	: V=0.9945501, theta=-64.065389 -> V=1.0, theta=0.0
% INFO    : Bus 77019	: V=0.9906506, theta=-63.93159 -> V=1.0, theta=0.0
% INFO    : Bus 77020	: V=0.9885275, theta=-64.158254 -> V=1.0, theta=0.0
% INFO    : Bus 77021	: V=0.996534, theta=-63.941604 -> V=1.0, theta=0.0
% INFO    : Bus 77022	: V=0.9892341, theta=-64.508724 -> V=1.0, theta=0.0
% INFO    : Bus 77023	: V=0.9941185, theta=-64.101726 -> V=1.0, theta=0.0
% INFO    : Bus 77024	: V=0.9948685, theta=-64.057592 -> V=1.0, theta=0.0
% INFO    : Bus 77025	: V=0.9905884, theta=-64.364361 -> V=1.0, theta=0.0
% INFO    : Bus 77026	: V=0.9895228, theta=-64.47853 -> V=1.0, theta=0.0
% INFO    : Bus 77027	: V=0.993716, theta=-64.121653 -> V=1.0, theta=0.0
% INFO    : Bus 77028	: V=0.9949096, theta=-63.526296 -> V=1.0, theta=0.0
% INFO    : Bus 77029	: V=0.9957184, theta=-63.300656 -> V=1.0, theta=0.0
% INFO    : Bus 77030	: V=0.995013, theta=-63.509477 -> V=1.0, theta=0.0
% INFO    : Bus 77031	: V=0.9923056, theta=-64.278427 -> V=1.0, theta=0.0
% INFO    : Bus 77032	: V=1.0011326, theta=-62.130262 -> V=1.0, theta=0.0
% INFO    : Bus 77033	: V=0.9986637, theta=-63.180949 -> V=1.0, theta=0.0
% INFO    : Bus 77034	: V=0.9969387, theta=-63.553071 -> V=1.0, theta=0.0
% INFO    : Bus 77035	: V=0.9893202, theta=-64.530594 -> V=1.0, theta=0.0
% INFO    : Bus 77036	: V=0.9886753, theta=-64.604982 -> V=1.0, theta=0.0
% INFO    : Bus 77037	: V=0.9972789, theta=-63.300612 -> V=1.0, theta=0.0
% INFO    : Bus 77038	: V=0.9931945, theta=-64.197538 -> V=1.0, theta=0.0
% INFO    : Bus 77039	: V=0.9896134, theta=-64.57333 -> V=1.0, theta=0.0
% INFO    : Bus 77040	: V=0.9854758, theta=-65.148041 -> V=1.0, theta=0.0
% INFO    : Bus 77041	: V=0.9938253, theta=-63.650752 -> V=1.0, theta=0.0
% INFO    : Bus 77042	: V=0.992868, theta=-63.749115 -> V=1.0, theta=0.0
% INFO    : Bus 77043	: V=0.9870827, theta=-64.872432 -> V=1.0, theta=0.0
% INFO    : Bus 77044	: V=0.9869732, theta=-64.882404 -> V=1.0, theta=0.0
% INFO    : Bus 77045	: V=0.9875614, theta=-64.918578 -> V=1.0, theta=0.0
% INFO    : Bus 77046	: V=0.9880318, theta=-64.757045 -> V=1.0, theta=0.0
% INFO    : Bus 77047	: V=0.9859769, theta=-65.00347 -> V=1.0, theta=0.0
% INFO    : Bus 77048	: V=0.9851459, theta=-65.142201 -> V=1.0, theta=0.0
% INFO    : Bus 77049	: V=0.9858784, theta=-65.014508 -> V=1.0, theta=0.0
% INFO    : Bus 77050	: V=0.9877909, theta=-64.782824 -> V=1.0, theta=0.0
% INFO    : Bus 77051	: V=0.9848474, theta=-65.135298 -> V=1.0, theta=0.0
% INFO    : Bus 77052	: V=0.9853207, theta=-65.022444 -> V=1.0, theta=0.0
% INFO    : Bus 77053	: V=0.9987133, theta=-62.579523 -> V=1.0, theta=0.0
% INFO    : Bus 77054	: V=0.9922702, theta=-63.947431 -> V=1.0, theta=0.0
% INFO    : Bus 77055	: V=0.9872498, theta=-64.897403 -> V=1.0, theta=0.0
% INFO    : Bus 77056	: V=0.9918407, theta=-63.990908 -> V=1.0, theta=0.0
% INFO    : Bus 77057	: V=0.98784, theta=-64.801783 -> V=1.0, theta=0.0
% INFO    : Bus 77058	: V=0.9868727, theta=-64.89799 -> V=1.0, theta=0.0
% INFO    : Bus 77059	: V=0.9829817, theta=-65.305841 -> V=1.0, theta=0.0
% INFO    : Bus 77060	: V=0.985087, theta=-65.382858 -> V=1.0, theta=0.0
% INFO    : Bus 77061	: V=0.9867632, theta=-64.918828 -> V=1.0, theta=0.0
% INFO    : Bus 77062	: V=0.9873938, theta=-64.847129 -> V=1.0, theta=0.0
% INFO    : Bus 77063	: V=0.984021, theta=-65.156865 -> V=1.0, theta=0.0
% INFO    : Bus 77064	: V=0.9867182, theta=-64.908937 -> V=1.0, theta=0.0
% INFO    : Bus 77065	: V=0.984804, theta=-65.087767 -> V=1.0, theta=0.0
% INFO    : Bus 77066	: V=0.9800743, theta=-66.00094 -> V=1.0, theta=0.0
% INFO    : Bus 77067	: V=0.9839588, theta=-65.116081 -> V=1.0, theta=0.0
% INFO    : Bus 77068	: V=0.9823622, theta=-65.580359 -> V=1.0, theta=0.0
% INFO    : Bus 77069	: V=0.9826709, theta=-65.229558 -> V=1.0, theta=0.0
% INFO    : Bus 77070	: V=0.9845452, theta=-65.12625 -> V=1.0, theta=0.0
% INFO    : Bus 77071	: V=0.9849321, theta=-65.143657 -> V=1.0, theta=0.0
% INFO    : Bus 77072	: V=0.9836046, theta=-65.177833 -> V=1.0, theta=0.0
% INFO    : Bus 77073	: V=0.9827928, theta=-65.273856 -> V=1.0, theta=0.0
% INFO    : Bus 77074	: V=0.9847119, theta=-65.160284 -> V=1.0, theta=0.0
% INFO    : Bus 77075	: V=0.9817495, theta=-65.331529 -> V=1.0, theta=0.0
% INFO    : Bus 77076	: V=0.9830184, theta=-65.399426 -> V=1.0, theta=0.0
% INFO    : Bus 77077	: V=0.983476, theta=-65.306063 -> V=1.0, theta=0.0
% INFO    : Bus 77078	: V=0.9831008, theta=-65.394904 -> V=1.0, theta=0.0
% INFO    : Bus 77079	: V=0.9797506, theta=-65.718749 -> V=1.0, theta=0.0
% INFO    : Bus 77080	: V=0.9890792, theta=-64.451508 -> V=1.0, theta=0.0
% INFO    : Bus 77081	: V=0.9823663, theta=-65.578089 -> V=1.0, theta=0.0
% INFO    : Bus 77082	: V=0.983843, theta=-65.459547 -> V=1.0, theta=0.0
% INFO    : Bus 77083	: V=0.9814383, theta=-65.660046 -> V=1.0, theta=0.0
% INFO    : Bus 77084	: V=0.9854327, theta=-65.12314 -> V=1.0, theta=0.0
% INFO    : Bus 77085	: V=0.9816967, theta=-65.647964 -> V=1.0, theta=0.0
% INFO    : Bus 77086	: V=0.9840691, theta=-65.428134 -> V=1.0, theta=0.0
% INFO    : Bus 77087	: V=0.9855737, theta=-65.10784 -> V=1.0, theta=0.0
% INFO    : Bus 77088	: V=0.9840866, theta=-65.17046 -> V=1.0, theta=0.0
% INFO    : Bus 77089	: V=0.9829086, theta=-65.519256 -> V=1.0, theta=0.0
% INFO    : Bus 77090	: V=0.9801503, theta=-65.865007 -> V=1.0, theta=0.0
% INFO    : Bus 77091	: V=0.9838216, theta=-65.272113 -> V=1.0, theta=0.0
% INFO    : Bus 77092	: V=0.9819058, theta=-65.624852 -> V=1.0, theta=0.0
% INFO    : Bus 77093	: V=0.9801555, theta=-66.040972 -> V=1.0, theta=0.0
% INFO    : Bus 77094	: V=0.9935744, theta=-63.197793 -> V=1.0, theta=0.0
% INFO    : Bus 77095	: V=0.9865539, theta=-64.707477 -> V=1.0, theta=0.0
% INFO    : Bus 77096	: V=0.9817525, theta=-65.721001 -> V=1.0, theta=0.0
% INFO    : Bus 77097	: V=0.9760053, theta=-66.77608 -> V=1.0, theta=0.0
% INFO    : Bus 77098	: V=0.9852785, theta=-64.846404 -> V=1.0, theta=0.0
% INFO    : Bus 77099	: V=0.9850339, theta=-64.906018 -> V=1.0, theta=0.0
% INFO    : Bus 77100	: V=0.9779795, theta=-66.263854 -> V=1.0, theta=0.0
% INFO    : Bus 77101	: V=0.979179, theta=-65.899209 -> V=1.0, theta=0.0
% INFO    : Bus 77102	: V=0.9792832, theta=-65.885516 -> V=1.0, theta=0.0
% INFO    : Bus 77103	: V=1.0158519, theta=-73.318125 -> V=1.0, theta=0.0
% INFO    : Bus 77104	: V=1.0137645, theta=-73.502899 -> V=1.0, theta=0.0
% INFO    : Bus 77105	: V=1.0142473, theta=-73.635481 -> V=1.0, theta=0.0
% INFO    : Bus 77106	: V=1.018516, theta=-73.68411 -> V=1.0, theta=0.0
% INFO    : Bus 77107	: V=1.0101243, theta=-74.217482 -> V=1.0, theta=0.0
% INFO    : Bus 77108	: V=1.0092859, theta=-73.780987 -> V=1.0, theta=0.0
% INFO    : Bus 77109	: V=0.9709134, theta=-72.501721 -> V=1.0, theta=0.0
% INFO    : Bus 77110	: V=0.9984292, theta=-70.822383 -> V=1.0, theta=0.0
% INFO    : Bus 77111	: V=0.9895686, theta=-70.673303 -> V=1.0, theta=0.0
% INFO    : Bus 77112	: V=1.0002247, theta=-72.184537 -> V=1.0, theta=0.0
% INFO    : Bus 77113	: V=0.9654327, theta=-66.324377 -> V=1.0, theta=0.0
% INFO    : Bus 77114	: V=0.9668134, theta=-65.728634 -> V=1.0, theta=0.0
% INFO    : Bus 77115	: V=0.9675063, theta=-65.453754 -> V=1.0, theta=0.0
% INFO    : Bus 77116	: V=0.9683752, theta=-65.37695 -> V=1.0, theta=0.0
% INFO    : Bus 77117	: V=0.9667854, theta=-65.880279 -> V=1.0, theta=0.0
% INFO    : Bus 77118	: V=0.9667045, theta=-65.541124 -> V=1.0, theta=0.0
% INFO    : Bus 77119	: V=0.9726946, theta=-63.767786 -> V=1.0, theta=0.0
% INFO    : Bus 77120	: V=0.9717457, theta=-64.09849 -> V=1.0, theta=0.0
% INFO    : Bus 77121	: V=0.9716214, theta=-64.524567 -> V=1.0, theta=0.0
% INFO    : Bus 77122	: V=0.9683651, theta=-65.319956 -> V=1.0, theta=0.0
% INFO    : Bus 77123	: V=0.9780383, theta=-61.463582 -> V=1.0, theta=0.0
% INFO    : Bus 77124	: V=0.9693861, theta=-65.034054 -> V=1.0, theta=0.0
% INFO    : Bus 77125	: V=0.9681302, theta=-65.220698 -> V=1.0, theta=0.0
% INFO    : Bus 77126	: V=0.9619265, theta=-66.033105 -> V=1.0, theta=0.0
% INFO    : Bus 77127	: V=0.9715382, theta=-64.102265 -> V=1.0, theta=0.0
% INFO    : Bus 77128	: V=0.9685396, theta=-65.357242 -> V=1.0, theta=0.0
% INFO    : Bus 77129	: V=0.9804345, theta=-61.093149 -> V=1.0, theta=0.0
% INFO    : Bus 77130	: V=0.9740828, theta=-63.67083 -> V=1.0, theta=0.0
% INFO    : Bus 77131	: V=0.9736138, theta=-64.414283 -> V=1.0, theta=0.0
% INFO    : Bus 77132	: V=0.966495, theta=-66.374766 -> V=1.0, theta=0.0
% INFO    : Bus 77133	: V=0.9743554, theta=-64.587081 -> V=1.0, theta=0.0
% INFO    : Bus 77134	: V=0.9757658, theta=-61.215409 -> V=1.0, theta=0.0
% INFO    : Bus 77135	: V=0.9739026, theta=-61.865354 -> V=1.0, theta=0.0
% INFO    : Bus 77136	: V=0.9796205, theta=-60.975537 -> V=1.0, theta=0.0
% INFO    : Bus 77137	: V=0.9742288, theta=-61.92145 -> V=1.0, theta=0.0
% INFO    : Bus 77138	: V=0.9818335, theta=-60.883614 -> V=1.0, theta=0.0
% INFO    : Bus 77139	: V=0.9823395, theta=-60.856857 -> V=1.0, theta=0.0
% INFO    : Bus 77140	: V=0.9732055, theta=-62.248699 -> V=1.0, theta=0.0
% INFO    : Bus 77141	: V=0.9744909, theta=-61.927925 -> V=1.0, theta=0.0
% INFO    : Bus 77142	: V=0.9765694, theta=-61.542193 -> V=1.0, theta=0.0
% INFO    : Bus 77143	: V=0.9721386, theta=-62.50544 -> V=1.0, theta=0.0
% INFO    : Bus 77144	: V=0.9751732, theta=-61.618607 -> V=1.0, theta=0.0
% INFO    : Bus 77145	: V=0.9759675, theta=-61.62266 -> V=1.0, theta=0.0
% INFO    : Bus 77146	: V=0.9735868, theta=-62.323227 -> V=1.0, theta=0.0
% INFO    : Bus 77147	: V=0.9737952, theta=-62.412257 -> V=1.0, theta=0.0
% INFO    : Bus 77148	: V=0.9733287, theta=-60.842189 -> V=1.0, theta=0.0
% INFO    : Bus 77149	: V=0.9778059, theta=-60.207809 -> V=1.0, theta=0.0
% INFO    : Bus 77150	: V=0.97496, theta=-61.122987 -> V=1.0, theta=0.0
% INFO    : Bus 77151	: V=0.9771361, theta=-60.497597 -> V=1.0, theta=0.0
% INFO    : Bus 77152	: V=0.9742449, theta=-62.025906 -> V=1.0, theta=0.0
% INFO    : Bus 77153	: V=0.9775886, theta=-62.422731 -> V=1.0, theta=0.0
% INFO    : Bus 77154	: V=0.9765109, theta=-62.136949 -> V=1.0, theta=0.0
% INFO    : Bus 77155	: V=0.9721327, theta=-61.782678 -> V=1.0, theta=0.0
% INFO    : Bus 77156	: V=0.9788487, theta=-60.97262 -> V=1.0, theta=0.0
% INFO    : Bus 77157	: V=0.9845885, theta=-60.247906 -> V=1.0, theta=0.0
% INFO    : Bus 77158	: V=0.9802509, theta=-61.140676 -> V=1.0, theta=0.0
% INFO    : Bus 77159	: V=0.9763233, theta=-61.228758 -> V=1.0, theta=0.0
% INFO    : Bus 77160	: V=0.9729036, theta=-62.061618 -> V=1.0, theta=0.0
% INFO    : Bus 77161	: V=0.9927761, theta=-57.702543 -> V=1.0, theta=0.0
% INFO    : Bus 77162	: V=0.9878673, theta=-59.458638 -> V=1.0, theta=0.0
% INFO    : Bus 77163	: V=0.9857066, theta=-59.986093 -> V=1.0, theta=0.0
% INFO    : Bus 77164	: V=0.9705384, theta=-64.831973 -> V=1.0, theta=0.0
% INFO    : Bus 77165	: V=0.9814152, theta=-62.83901 -> V=1.0, theta=0.0
% INFO    : Bus 77166	: V=0.9709392, theta=-63.100708 -> V=1.0, theta=0.0
% INFO    : Bus 77167	: V=0.970553, theta=-64.714391 -> V=1.0, theta=0.0
% INFO    : Bus 77168	: V=0.9734844, theta=-68.303632 -> V=1.0, theta=0.0
% INFO    : Bus 77169	: V=0.9796656, theta=-66.229423 -> V=1.0, theta=0.0
% INFO    : Bus 77170	: V=0.9685947, theta=-67.604379 -> V=1.0, theta=0.0
% INFO    : Bus 77171	: V=0.9778871, theta=-63.903474 -> V=1.0, theta=0.0
% INFO    : Bus 77172	: V=0.9815814, theta=-63.719485 -> V=1.0, theta=0.0
% INFO    : Bus 77173	: V=0.9710869, theta=-65.270681 -> V=1.0, theta=0.0
% INFO    : Bus 77174	: V=0.9626365, theta=-67.343625 -> V=1.0, theta=0.0
% INFO    : Bus 77175	: V=0.9758648, theta=-64.430702 -> V=1.0, theta=0.0
% INFO    : Bus 77176	: V=0.9640958, theta=-65.366459 -> V=1.0, theta=0.0
% INFO    : Bus 77177	: V=0.9715642, theta=-65.116701 -> V=1.0, theta=0.0
% INFO    : Bus 77178	: V=0.9660193, theta=-67.441797 -> V=1.0, theta=0.0
% INFO    : Bus 77179	: V=0.9858561, theta=-63.279365 -> V=1.0, theta=0.0
% INFO    : Bus 77180	: V=0.9766101, theta=-64.210645 -> V=1.0, theta=0.0
% INFO    : Bus 77181	: V=0.97762, theta=-64.064832 -> V=1.0, theta=0.0
% INFO    : Bus 77182	: V=0.9788541, theta=-63.95097 -> V=1.0, theta=0.0
% INFO    : Bus 77183	: V=0.9819991, theta=-63.746138 -> V=1.0, theta=0.0
% INFO    : Bus 77184	: V=0.9851334, theta=-63.0708 -> V=1.0, theta=0.0
% INFO    : Bus 77185	: V=0.9732091, theta=-64.406414 -> V=1.0, theta=0.0
% INFO    : Bus 77186	: V=0.9721125, theta=-64.627202 -> V=1.0, theta=0.0
% INFO    : Bus 77187	: V=0.9791753, theta=-63.556552 -> V=1.0, theta=0.0
% INFO    : Bus 77188	: V=0.9733734, theta=-64.953309 -> V=1.0, theta=0.0
% INFO    : Bus 77189	: V=0.9799442, theta=-71.651743 -> V=1.0, theta=0.0
% INFO    : Bus 77190	: V=0.9895763, theta=-58.539066 -> V=1.0, theta=0.0
% INFO    : Bus 77191	: V=0.9974432, theta=-56.067716 -> V=1.0, theta=0.0
% INFO    : Bus 77192	: V=0.9841748, theta=-58.908688 -> V=1.0, theta=0.0
% INFO    : Bus 77193	: V=0.9824003, theta=-58.849218 -> V=1.0, theta=0.0
% INFO    : Bus 77194	: V=0.9909961, theta=-56.787609 -> V=1.0, theta=0.0
% INFO    : Bus 77195	: V=0.9929194, theta=-56.607849 -> V=1.0, theta=0.0
% INFO    : Bus 77196	: V=1.0096112, theta=-52.951019 -> V=1.0, theta=0.0
% INFO    : Bus 77197	: V=1.0149997, theta=-51.532948 -> V=1.0, theta=0.0
% INFO    : Bus 77198	: V=1.0143058, theta=-51.623567 -> V=1.0, theta=0.0
% INFO    : Bus 77199	: V=1.01366, theta=-51.656294 -> V=1.0, theta=0.0
% INFO    : Bus 77200	: V=1.0167683, theta=-51.33076 -> V=1.0, theta=0.0
% INFO    : Bus 77201	: V=0.9671078, theta=-66.181876 -> V=1.0, theta=0.0
% INFO    : Bus 77202	: V=0.9576247, theta=-67.003124 -> V=1.0, theta=0.0
% INFO    : Bus 77203	: V=0.9531554, theta=-67.997492 -> V=1.0, theta=0.0
% INFO    : Bus 77204	: V=0.9637863, theta=-67.012998 -> V=1.0, theta=0.0
% INFO    : Bus 77205	: V=0.9682467, theta=-65.531012 -> V=1.0, theta=0.0
% INFO    : Bus 77206	: V=0.9649655, theta=-65.774672 -> V=1.0, theta=0.0
% INFO    : Bus 77207	: V=0.9665818, theta=-66.1608 -> V=1.0, theta=0.0
% INFO    : Bus 77208	: V=0.9661449, theta=-66.823624 -> V=1.0, theta=0.0
% INFO    : Bus 77209	: V=0.9575702, theta=-68.442352 -> V=1.0, theta=0.0
% INFO    : Bus 77210	: V=0.9764831, theta=-66.321149 -> V=1.0, theta=0.0
% INFO    : Bus 77211	: V=0.9750252, theta=-66.637531 -> V=1.0, theta=0.0
% INFO    : Bus 77212	: V=0.9762008, theta=-66.557705 -> V=1.0, theta=0.0
% INFO    : Bus 77213	: V=0.9898161, theta=-64.361165 -> V=1.0, theta=0.0
% INFO    : Bus 77214	: V=0.9897532, theta=-64.3682 -> V=1.0, theta=0.0
% INFO    : Bus 77215	: V=0.987852, theta=-64.713137 -> V=1.0, theta=0.0
% INFO    : Bus 77216	: V=0.9738951, theta=-66.757227 -> V=1.0, theta=0.0
% INFO    : Bus 77217	: V=0.9904117, theta=-64.302866 -> V=1.0, theta=0.0
% INFO    : Bus 77218	: V=0.9925374, theta=-63.856577 -> V=1.0, theta=0.0
% INFO    : Bus 77219	: V=0.9905697, theta=-64.285336 -> V=1.0, theta=0.0
% INFO    : Bus 77220	: V=0.9900901, theta=-64.333064 -> V=1.0, theta=0.0
% INFO    : Bus 77221	: V=0.9898088, theta=-64.347079 -> V=1.0, theta=0.0
% INFO    : Bus 77222	: V=0.9910933, theta=-64.266012 -> V=1.0, theta=0.0
% INFO    : Bus 77223	: V=0.9747114, theta=-66.815378 -> V=1.0, theta=0.0
% INFO    : Bus 77224	: V=0.9929571, theta=-63.908648 -> V=1.0, theta=0.0
% INFO    : Bus 77225	: V=0.9955479, theta=-63.454163 -> V=1.0, theta=0.0
% INFO    : Bus 77226	: V=0.9896454, theta=-64.529014 -> V=1.0, theta=0.0
% INFO    : Bus 77227	: V=0.9759912, theta=-66.621515 -> V=1.0, theta=0.0
% INFO    : Bus 77228	: V=0.9910694, theta=-64.267163 -> V=1.0, theta=0.0
% INFO    : Bus 77229	: V=0.9931745, theta=-63.846875 -> V=1.0, theta=0.0
% INFO    : Bus 77230	: V=0.976074, theta=-66.692327 -> V=1.0, theta=0.0
% INFO    : Bus 77231	: V=0.9936788, theta=-63.799307 -> V=1.0, theta=0.0
% INFO    : Bus 77232	: V=0.9933477, theta=-63.834725 -> V=1.0, theta=0.0
% INFO    : Bus 77233	: V=0.9930817, theta=-63.851597 -> V=1.0, theta=0.0
% INFO    : Bus 77234	: V=0.9904983, theta=-64.395259 -> V=1.0, theta=0.0
% INFO    : Bus 77235	: V=0.9889905, theta=-64.683155 -> V=1.0, theta=0.0
% INFO    : Bus 77236	: V=0.9929238, theta=-63.869972 -> V=1.0, theta=0.0
% INFO    : Bus 77237	: V=0.9917405, theta=-64.120271 -> V=1.0, theta=0.0
% INFO    : Bus 77238	: V=0.9854472, theta=-65.15945 -> V=1.0, theta=0.0
% INFO    : Bus 77239	: V=0.9853064, theta=-65.177164 -> V=1.0, theta=0.0
% INFO    : Bus 77240	: V=0.9845385, theta=-65.223174 -> V=1.0, theta=0.0
% INFO    : Bus 77241	: V=0.9849626, theta=-65.121352 -> V=1.0, theta=0.0
% INFO    : Bus 77242	: V=0.9823272, theta=-65.604125 -> V=1.0, theta=0.0
% INFO    : Bus 77243	: V=0.9766231, theta=-66.692419 -> V=1.0, theta=0.0
% INFO    : Bus 77244	: V=0.9770321, theta=-66.616682 -> V=1.0, theta=0.0
% INFO    : Bus 77245	: V=0.9808991, theta=-65.903984 -> V=1.0, theta=0.0
% INFO    : Bus 77246	: V=0.9809018, theta=-65.906441 -> V=1.0, theta=0.0
% INFO    : Bus 77247	: V=0.9795468, theta=-66.311137 -> V=1.0, theta=0.0
% INFO    : Bus 77248	: V=0.9849212, theta=-65.124226 -> V=1.0, theta=0.0
% INFO    : Bus 77249	: V=0.9769666, theta=-66.668697 -> V=1.0, theta=0.0
% INFO    : Bus 77250	: V=0.9849612, theta=-65.121262 -> V=1.0, theta=0.0
% INFO    : Bus 77251	: V=0.9853653, theta=-65.139904 -> V=1.0, theta=0.0
% INFO    : Bus 77252	: V=0.9848775, theta=-65.186479 -> V=1.0, theta=0.0
% INFO    : Bus 77253	: V=0.9846708, theta=-65.203777 -> V=1.0, theta=0.0
% INFO    : Bus 77254	: V=0.9880794, theta=-64.586846 -> V=1.0, theta=0.0
% INFO    : Bus 77255	: V=0.9855976, theta=-65.107716 -> V=1.0, theta=0.0
% INFO    : Bus 77256	: V=0.9852555, theta=-65.106933 -> V=1.0, theta=0.0
% INFO    : Bus 77257	: V=0.9851964, theta=-65.113323 -> V=1.0, theta=0.0
% INFO    : Bus 77258	: V=0.9833676, theta=-65.561556 -> V=1.0, theta=0.0
% INFO    : Bus 77259	: V=0.9832554, theta=-65.578682 -> V=1.0, theta=0.0
% INFO    : Bus 77260	: V=0.9829323, theta=-65.621786 -> V=1.0, theta=0.0
% INFO    : Bus 77261	: V=0.9853127, theta=-65.142614 -> V=1.0, theta=0.0
% INFO    : Bus 77262	: V=0.9853861, theta=-65.135607 -> V=1.0, theta=0.0
% INFO    : Bus 77263	: V=0.9855413, theta=-65.122639 -> V=1.0, theta=0.0
% INFO    : Bus 77264	: V=0.9855763, theta=-65.118176 -> V=1.0, theta=0.0
% INFO    : Bus 77265	: V=0.9756807, theta=-66.951086 -> V=1.0, theta=0.0
% INFO    : Bus 77266	: V=0.9907467, theta=-64.226957 -> V=1.0, theta=0.0
% INFO    : Bus 77267	: V=0.9890039, theta=-64.466908 -> V=1.0, theta=0.0
% INFO    : Bus 77268	: V=0.9780932, theta=-67.001465 -> V=1.0, theta=0.0
% INFO    : Bus 77269	: V=0.9878831, theta=-64.73975 -> V=1.0, theta=0.0
% INFO    : Bus 77270	: V=0.9855974, theta=-65.193299 -> V=1.0, theta=0.0
% INFO    : Bus 77271	: V=0.9778312, theta=-66.902335 -> V=1.0, theta=0.0
% INFO    : Bus 77272	: V=0.9878671, theta=-64.74097 -> V=1.0, theta=0.0
% INFO    : Bus 77273	: V=0.9878135, theta=-64.616183 -> V=1.0, theta=0.0
% INFO    : Bus 77274	: V=0.9855842, theta=-65.108135 -> V=1.0, theta=0.0
% INFO    : Bus 77275	: V=0.977272, theta=-66.784886 -> V=1.0, theta=0.0
% INFO    : Bus 77276	: V=0.9858205, theta=-65.102387 -> V=1.0, theta=0.0
% INFO    : Bus 77277	: V=0.9866992, theta=-64.730503 -> V=1.0, theta=0.0
% INFO    : Bus 77278	: V=0.9829448, theta=-65.622001 -> V=1.0, theta=0.0
% INFO    : Bus 77279	: V=0.9794463, theta=-66.38446 -> V=1.0, theta=0.0
% INFO    : Bus 77280	: V=0.9830057, theta=-65.612273 -> V=1.0, theta=0.0
% INFO    : Bus 77281	: V=0.982801, theta=-65.634233 -> V=1.0, theta=0.0
% INFO    : Bus 77282	: V=0.9841004, theta=-65.321616 -> V=1.0, theta=0.0
% INFO    : Bus 77283	: V=0.9793416, theta=-66.383761 -> V=1.0, theta=0.0
% INFO    : Bus 77284	: V=0.9839425, theta=-65.333645 -> V=1.0, theta=0.0
% INFO    : Bus 77285	: V=0.9759051, theta=-66.866313 -> V=1.0, theta=0.0
% INFO    : Bus 77286	: V=0.9816877, theta=-65.759342 -> V=1.0, theta=0.0
% INFO    : Bus 77287	: V=0.9824069, theta=-65.676763 -> V=1.0, theta=0.0
% INFO    : Bus 77288	: V=0.9836166, theta=-65.380792 -> V=1.0, theta=0.0
% INFO    : Bus 77289	: V=0.9836248, theta=-65.377676 -> V=1.0, theta=0.0
% INFO    : Bus 77290	: V=0.9851806, theta=-65.11425 -> V=1.0, theta=0.0
% INFO    : Bus 77291	: V=0.9850054, theta=-65.127463 -> V=1.0, theta=0.0
% INFO    : Bus 77292	: V=0.9851364, theta=-65.11575 -> V=1.0, theta=0.0
% INFO    : Bus 77293	: V=0.983213, theta=-65.41938 -> V=1.0, theta=0.0
% INFO    : Bus 77294	: V=0.9848293, theta=-65.135601 -> V=1.0, theta=0.0
% INFO    : Bus 77295	: V=0.9846502, theta=-65.153133 -> V=1.0, theta=0.0
% INFO    : Bus 77296	: V=0.9849186, theta=-65.120834 -> V=1.0, theta=0.0
% INFO    : Bus 77297	: V=0.9757065, theta=-66.87254 -> V=1.0, theta=0.0
% INFO    : Bus 77298	: V=0.9815438, theta=-65.638253 -> V=1.0, theta=0.0
% INFO    : Bus 77299	: V=0.9804286, theta=-65.746346 -> V=1.0, theta=0.0
% INFO    : Bus 77300	: V=0.9803501, theta=-65.75592 -> V=1.0, theta=0.0
% INFO    : Bus 77301	: V=0.9760908, theta=-66.508948 -> V=1.0, theta=0.0
% INFO    : Bus 77302	: V=0.9782188, theta=-66.133921 -> V=1.0, theta=0.0
% INFO    : Bus 77303	: V=0.9758482, theta=-66.822852 -> V=1.0, theta=0.0
% INFO    : Bus 77304	: V=0.9803343, theta=-65.776209 -> V=1.0, theta=0.0
% INFO    : Bus 77305	: V=0.9766006, theta=-66.73929 -> V=1.0, theta=0.0
% INFO    : Bus 77306	: V=0.9759029, theta=-66.835888 -> V=1.0, theta=0.0
% INFO    : Bus 77307	: V=0.9828348, theta=-65.340081 -> V=1.0, theta=0.0
% INFO    : Bus 77308	: V=0.9797166, theta=-65.939043 -> V=1.0, theta=0.0
% INFO    : Bus 77309	: V=0.9782548, theta=-66.202287 -> V=1.0, theta=0.0
% INFO    : Bus 77310	: V=0.9790151, theta=-65.917811 -> V=1.0, theta=0.0
% INFO    : Bus 77311	: V=0.9778983, theta=-66.247048 -> V=1.0, theta=0.0
% INFO    : Bus 77312	: V=0.9792492, theta=-66.88464 -> V=1.0, theta=0.0
% INFO    : Bus 77313	: V=0.9821825, theta=-65.553457 -> V=1.0, theta=0.0
% INFO    : Bus 77314	: V=0.9824636, theta=-65.508932 -> V=1.0, theta=0.0
% INFO    : Bus 77315	: V=0.98176, theta=-65.592906 -> V=1.0, theta=0.0
% INFO    : Bus 77316	: V=0.9790004, theta=-66.669415 -> V=1.0, theta=0.0
% INFO    : Bus 77317	: V=0.9814223, theta=-65.835082 -> V=1.0, theta=0.0
% INFO    : Bus 77318	: V=0.9788382, theta=-66.339631 -> V=1.0, theta=0.0
% INFO    : Bus 77319	: V=0.9814539, theta=-65.667605 -> V=1.0, theta=0.0
% INFO    : Bus 77320	: V=0.9787047, theta=-66.380312 -> V=1.0, theta=0.0
% INFO    : Bus 77321	: V=0.9814144, theta=-65.799724 -> V=1.0, theta=0.0
% INFO    : Bus 77322	: V=0.9812774, theta=-65.808716 -> V=1.0, theta=0.0
% INFO    : Bus 77323	: V=0.9762935, theta=-67.012899 -> V=1.0, theta=0.0
% INFO    : Bus 77324	: V=0.9789931, theta=-66.335354 -> V=1.0, theta=0.0
% INFO    : Bus 77325	: V=0.9787632, theta=-66.302803 -> V=1.0, theta=0.0
% INFO    : Bus 77326	: V=0.981203, theta=-65.705756 -> V=1.0, theta=0.0
% INFO    : Bus 77327	: V=0.981436, theta=-65.797849 -> V=1.0, theta=0.0
% INFO    : Bus 77328	: V=0.981739, theta=-65.78666 -> V=1.0, theta=0.0
% INFO    : Bus 77329	: V=0.9784989, theta=-66.368086 -> V=1.0, theta=0.0
% INFO    : Bus 77330	: V=0.9780881, theta=-66.418342 -> V=1.0, theta=0.0
% INFO    : Bus 77331	: V=0.9770598, theta=-66.57803 -> V=1.0, theta=0.0
% INFO    : Bus 77332	: V=0.978156, theta=-66.469769 -> V=1.0, theta=0.0
% INFO    : Bus 77333	: V=0.976874, theta=-66.718342 -> V=1.0, theta=0.0
% INFO    : Bus 77334	: V=0.9776538, theta=-66.624544 -> V=1.0, theta=0.0
% INFO    : Bus 77335	: V=0.9856567, theta=-65.159453 -> V=1.0, theta=0.0
% INFO    : Bus 77336	: V=0.9885071, theta=-64.66909 -> V=1.0, theta=0.0
% INFO    : Bus 77337	: V=0.9775595, theta=-66.633881 -> V=1.0, theta=0.0
% INFO    : Bus 77338	: V=0.9753347, theta=-66.880588 -> V=1.0, theta=0.0
% INFO    : Bus 77339	: V=0.974987, theta=-66.822062 -> V=1.0, theta=0.0
% INFO    : Bus 77340	: V=0.9786492, theta=-66.483409 -> V=1.0, theta=0.0
% INFO    : Bus 77341	: V=0.9760567, theta=-66.800697 -> V=1.0, theta=0.0
% INFO    : Bus 77342	: V=0.970284, theta=-67.146444 -> V=1.0, theta=0.0
% INFO    : Bus 77343	: V=0.9845376, theta=-65.327696 -> V=1.0, theta=0.0
% INFO    : Bus 77344	: V=0.9786872, theta=-66.313537 -> V=1.0, theta=0.0
% INFO    : Bus 77345	: V=0.9860975, theta=-66.139954 -> V=1.0, theta=0.0
% INFO    : Bus 77346	: V=0.9783731, theta=-66.436948 -> V=1.0, theta=0.0
% INFO    : Bus 77347	: V=0.9823479, theta=-65.634605 -> V=1.0, theta=0.0
% INFO    : Bus 77348	: V=0.9827578, theta=-66.357222 -> V=1.0, theta=0.0
% INFO    : Bus 77349	: V=0.9830052, theta=-66.547415 -> V=1.0, theta=0.0
% INFO    : Bus 77350	: V=0.9773677, theta=-66.546981 -> V=1.0, theta=0.0
% INFO    : Bus 77351	: V=0.9926625, theta=-65.744077 -> V=1.0, theta=0.0
% INFO    : Bus 77352	: V=0.9831397, theta=-66.640672 -> V=1.0, theta=0.0
% INFO    : Bus 77353	: V=0.9774393, theta=-66.57505 -> V=1.0, theta=0.0
% INFO    : Bus 77354	: V=0.9771978, theta=-66.651637 -> V=1.0, theta=0.0
% INFO    : Bus 77355	: V=0.9764398, theta=-66.728555 -> V=1.0, theta=0.0
% INFO    : Bus 77356	: V=0.9762329, theta=-66.80699 -> V=1.0, theta=0.0
% INFO    : Bus 77357	: V=0.9758342, theta=-66.820685 -> V=1.0, theta=0.0
% INFO    : Bus 77358	: V=0.976726, theta=-66.679958 -> V=1.0, theta=0.0
% INFO    : Bus 77359	: V=0.9976903, theta=-66.685806 -> V=1.0, theta=0.0
% INFO    : Bus 77360	: V=0.9701833, theta=-72.823184 -> V=1.0, theta=0.0
% INFO    : Bus 77361	: V=0.9805267, theta=-69.355001 -> V=1.0, theta=0.0
% INFO    : Bus 77362	: V=0.9828693, theta=-68.159667 -> V=1.0, theta=0.0
% INFO    : Bus 77363	: V=0.9904567, theta=-67.244346 -> V=1.0, theta=0.0
% INFO    : Bus 77364	: V=0.9866388, theta=-62.903671 -> V=1.0, theta=0.0
% INFO    : Bus 77365	: V=0.9865605, theta=-62.897812 -> V=1.0, theta=0.0
% INFO    : Bus 77366	: V=0.9883342, theta=-63.002934 -> V=1.0, theta=0.0
% INFO    : Bus 77367	: V=0.9893266, theta=-62.796712 -> V=1.0, theta=0.0
% INFO    : Bus 77368	: V=0.9892292, theta=-62.810305 -> V=1.0, theta=0.0
% INFO    : Bus 77369	: V=0.987862, theta=-62.606139 -> V=1.0, theta=0.0
% INFO    : Bus 77370	: V=0.9892084, theta=-62.244149 -> V=1.0, theta=0.0
% INFO    : Bus 77371	: V=0.9890827, theta=-62.910089 -> V=1.0, theta=0.0
% INFO    : Bus 77372	: V=0.9887127, theta=-62.501157 -> V=1.0, theta=0.0
% INFO    : Bus 77373	: V=0.989611, theta=-62.782938 -> V=1.0, theta=0.0
% INFO    : Bus 77374	: V=0.9887135, theta=-62.521501 -> V=1.0, theta=0.0
% INFO    : Bus 77375	: V=0.9894788, theta=-62.374218 -> V=1.0, theta=0.0
% INFO    : Bus 77376	: V=0.98801, theta=-62.400963 -> V=1.0, theta=0.0
% INFO    : Bus 77377	: V=0.9922998, theta=-61.682593 -> V=1.0, theta=0.0
% INFO    : Bus 77378	: V=0.9926928, theta=-61.647012 -> V=1.0, theta=0.0
% INFO    : Bus 77379	: V=0.9908953, theta=-61.764598 -> V=1.0, theta=0.0
% INFO    : Bus 77380	: V=0.9908744, theta=-62.122554 -> V=1.0, theta=0.0
% INFO    : Bus 77381	: V=0.9932217, theta=-61.822304 -> V=1.0, theta=0.0
% INFO    : Bus 77382	: V=0.988058, theta=-61.872869 -> V=1.0, theta=0.0
% INFO    : Bus 77383	: V=0.992345, theta=-61.932422 -> V=1.0, theta=0.0
% INFO    : Bus 77384	: V=0.9866882, theta=-62.447762 -> V=1.0, theta=0.0
% INFO    : Bus 77385	: V=0.9920767, theta=-61.907324 -> V=1.0, theta=0.0
% INFO    : Bus 77386	: V=0.9907629, theta=-61.588877 -> V=1.0, theta=0.0
% INFO    : Bus 77387	: V=0.9931789, theta=-61.69984 -> V=1.0, theta=0.0
% INFO    : Bus 77388	: V=0.9922838, theta=-61.825293 -> V=1.0, theta=0.0
% INFO    : Bus 77389	: V=0.9910879, theta=-61.891894 -> V=1.0, theta=0.0
% INFO    : Bus 77390	: V=1.0011576, theta=-60.784348 -> V=1.0, theta=0.0
% INFO    : Bus 77391	: V=0.9943303, theta=-61.707131 -> V=1.0, theta=0.0
% INFO    : Bus 77392	: V=0.9921251, theta=-61.793729 -> V=1.0, theta=0.0
% INFO    : Bus 77393	: V=0.9928984, theta=-61.707444 -> V=1.0, theta=0.0
% INFO    : Bus 77394	: V=1.0071867, theta=-61.05809 -> V=1.0, theta=0.0
% INFO    : Bus 77395	: V=1.0127081, theta=-60.32939 -> V=1.0, theta=0.0
% INFO    : Bus 77396	: V=1.0056861, theta=-61.310227 -> V=1.0, theta=0.0
% INFO    : Bus 77397	: V=0.9963784, theta=-62.020273 -> V=1.0, theta=0.0
% INFO    : Bus 77398	: V=0.9959652, theta=-62.515393 -> V=1.0, theta=0.0
% INFO    : Bus 77399	: V=0.9968491, theta=-62.439282 -> V=1.0, theta=0.0
% INFO    : Bus 77400	: V=0.9929852, theta=-62.592636 -> V=1.0, theta=0.0
% INFO    : Bus 77401	: V=0.9958168, theta=-62.602024 -> V=1.0, theta=0.0
% INFO    : Bus 77402	: V=0.9906654, theta=-63.19539 -> V=1.0, theta=0.0
% INFO    : Bus 77403	: V=0.9788448, theta=-63.902141 -> V=1.0, theta=0.0
% INFO    : Bus 77404	: V=0.9797928, theta=-63.91201 -> V=1.0, theta=0.0
% INFO    : Bus 77405	: V=0.9774096, theta=-64.024632 -> V=1.0, theta=0.0
% INFO    : Bus 77406	: V=0.986656, theta=-63.299881 -> V=1.0, theta=0.0
% INFO    : Bus 77407	: V=0.9753878, theta=-64.261573 -> V=1.0, theta=0.0
% INFO    : Bus 77408	: V=0.9747798, theta=-64.320421 -> V=1.0, theta=0.0
% INFO    : Bus 77409	: V=0.9717833, theta=-65.769411 -> V=1.0, theta=0.0
% INFO    : Bus 77410	: V=0.9933038, theta=-62.83021 -> V=1.0, theta=0.0
% INFO    : Bus 77411	: V=0.9989852, theta=-62.228954 -> V=1.0, theta=0.0
% INFO    : Bus 77412	: V=0.9932745, theta=-63.001504 -> V=1.0, theta=0.0
% INFO    : Bus 77413	: V=1.0118752, theta=-66.041009 -> V=1.0, theta=0.0
% INFO    : Bus 77414	: V=1.007804, theta=-67.649986 -> V=1.0, theta=0.0
% INFO    : Bus 77415	: V=0.9809669, theta=-70.064372 -> V=1.0, theta=0.0
% INFO    : Bus 77416	: V=0.9878275, theta=-69.281816 -> V=1.0, theta=0.0
% INFO    : Bus 77417	: V=0.9866902, theta=-71.187313 -> V=1.0, theta=0.0
% INFO    : Bus 77418	: V=0.9848674, theta=-71.083037 -> V=1.0, theta=0.0
% INFO    : Bus 77419	: V=0.9812738, theta=-71.059603 -> V=1.0, theta=0.0
% INFO    : Bus 77420	: V=0.9751418, theta=-71.670914 -> V=1.0, theta=0.0
% INFO    : Bus 77421	: V=0.9738847, theta=-71.143401 -> V=1.0, theta=0.0
% INFO    : Bus 77422	: V=0.9730429, theta=-70.872925 -> V=1.0, theta=0.0
% INFO    : Bus 77423	: V=0.9714993, theta=-70.115918 -> V=1.0, theta=0.0
% INFO    : Bus 77424	: V=0.969316, theta=-69.308147 -> V=1.0, theta=0.0
% INFO    : Bus 77425	: V=0.9703228, theta=-69.963912 -> V=1.0, theta=0.0
% INFO    : Bus 77426	: V=0.9826932, theta=-67.968312 -> V=1.0, theta=0.0
% INFO    : Bus 77427	: V=0.9774563, theta=-69.179074 -> V=1.0, theta=0.0
% INFO    : Bus 77428	: V=0.9630042, theta=-70.898722 -> V=1.0, theta=0.0
% INFO    : Bus 77429	: V=0.9666715, theta=-70.574423 -> V=1.0, theta=0.0
% INFO    : Bus 77430	: V=0.9713733, theta=-65.991489 -> V=1.0, theta=0.0
% INFO    : Bus 77431	: V=0.9675025, theta=-68.233033 -> V=1.0, theta=0.0
% INFO    : Bus 77432	: V=0.9755955, theta=-64.761742 -> V=1.0, theta=0.0
% INFO    : Bus 77433	: V=0.9996451, theta=-70.332983 -> V=1.0, theta=0.0
% INFO    : Bus 77434	: V=0.9853222, theta=-72.03904 -> V=1.0, theta=0.0
% INFO    : Bus 77435	: V=0.9745917, theta=-72.988077 -> V=1.0, theta=0.0
% INFO    : Bus 77436	: V=0.9723632, theta=-66.646561 -> V=1.0, theta=0.0
% INFO    : Bus 77437	: V=0.970166, theta=-66.314605 -> V=1.0, theta=0.0
% INFO    : Bus 77438	: V=0.9888648, theta=-73.033794 -> V=1.0, theta=0.0
% INFO    : Bus 77439	: V=0.9915418, theta=-72.823914 -> V=1.0, theta=0.0
% INFO    : Bus 77440	: V=0.9896258, theta=-72.478429 -> V=1.0, theta=0.0
% INFO    : Bus 77441	: V=0.9706258, theta=-75.785343 -> V=1.0, theta=0.0
% INFO    : Bus 77442	: V=0.9878118, theta=-62.256465 -> V=1.0, theta=0.0
% INFO    : Bus 77443	: V=0.9946762, theta=-61.488847 -> V=1.0, theta=0.0
% INFO    : Bus 77444	: V=0.9901557, theta=-61.627549 -> V=1.0, theta=0.0
% INFO    : Bus 77445	: V=0.9993409, theta=-60.681283 -> V=1.0, theta=0.0
% INFO    : Bus 77446	: V=0.9955683, theta=-61.118317 -> V=1.0, theta=0.0
% INFO    : Bus 77447	: V=0.9895743, theta=-62.113148 -> V=1.0, theta=0.0
% INFO    : Bus 77448	: V=0.9867623, theta=-62.556891 -> V=1.0, theta=0.0
% INFO    : Bus 77449	: V=0.9853511, theta=-62.364223 -> V=1.0, theta=0.0
% INFO    : Bus 77450	: V=0.996202, theta=-61.955364 -> V=1.0, theta=0.0
% INFO    : Bus 77451	: V=0.9923875, theta=-62.341643 -> V=1.0, theta=0.0
% INFO    : Bus 77452	: V=0.9859811, theta=-63.981523 -> V=1.0, theta=0.0
% INFO    : Bus 77453	: V=0.9935778, theta=-62.654778 -> V=1.0, theta=0.0
% INFO    : Bus 77454	: V=0.9899859, theta=-62.312854 -> V=1.0, theta=0.0
% INFO    : Bus 77455	: V=0.9900818, theta=-62.652343 -> V=1.0, theta=0.0
% INFO    : Bus 77456	: V=0.9888421, theta=-62.067024 -> V=1.0, theta=0.0
% INFO    : Bus 77457	: V=0.9894832, theta=-61.995093 -> V=1.0, theta=0.0
% INFO    : Bus 77458	: V=0.9832851, theta=-62.765933 -> V=1.0, theta=0.0
% INFO    : Bus 77459	: V=0.9834354, theta=-63.409104 -> V=1.0, theta=0.0
% INFO    : Bus 77460	: V=0.9829922, theta=-64.432421 -> V=1.0, theta=0.0
% INFO    : Bus 77461	: V=0.98587, theta=-63.595577 -> V=1.0, theta=0.0
% INFO    : Bus 77462	: V=0.9826751, theta=-64.25948 -> V=1.0, theta=0.0
% INFO    : Bus 77463	: V=0.9826911, theta=-64.075951 -> V=1.0, theta=0.0
% INFO    : Bus 77464	: V=0.97984, theta=-62.414555 -> V=1.0, theta=0.0
% INFO    : Bus 77465	: V=0.9971865, theta=-60.958273 -> V=1.0, theta=0.0
% INFO    : Bus 77466	: V=0.9956801, theta=-61.277791 -> V=1.0, theta=0.0
% INFO    : Bus 77467	: V=0.985049, theta=-61.807401 -> V=1.0, theta=0.0
% INFO    : Bus 77468	: V=0.9912055, theta=-61.885306 -> V=1.0, theta=0.0
% INFO    : Bus 77469	: V=0.9930722, theta=-61.375237 -> V=1.0, theta=0.0
% INFO    : Bus 77470	: V=0.9948107, theta=-61.532402 -> V=1.0, theta=0.0
% INFO    : Bus 77471	: V=0.9910093, theta=-61.801872 -> V=1.0, theta=0.0
% INFO    : Bus 77472	: V=0.9849176, theta=-62.151733 -> V=1.0, theta=0.0
% INFO    : Bus 77473	: V=0.9819562, theta=-62.768461 -> V=1.0, theta=0.0
% INFO    : Bus 77474	: V=0.9840401, theta=-62.512128 -> V=1.0, theta=0.0
% INFO    : Bus 77475	: V=0.9754814, theta=-63.582013 -> V=1.0, theta=0.0
% INFO    : Bus 77476	: V=0.9769571, theta=-63.331938 -> V=1.0, theta=0.0
% INFO    : Bus 77477	: V=0.988473, theta=-61.729133 -> V=1.0, theta=0.0
% INFO    : Bus 77478	: V=0.9812822, theta=-62.658061 -> V=1.0, theta=0.0
% INFO    : Bus 77479	: V=0.9827369, theta=-60.857594 -> V=1.0, theta=0.0
% INFO    : Bus 77480	: V=0.9927336, theta=-59.692913 -> V=1.0, theta=0.0
% INFO    : Bus 77481	: V=0.9865428, theta=-60.060025 -> V=1.0, theta=0.0
% INFO    : Bus 77482	: V=0.9922427, theta=-59.498883 -> V=1.0, theta=0.0
% INFO    : Bus 77483	: V=0.987911, theta=-61.079684 -> V=1.0, theta=0.0
% INFO    : Bus 77484	: V=0.9932213, theta=-60.752812 -> V=1.0, theta=0.0
% INFO    : Bus 77485	: V=1.0006269, theta=-59.923552 -> V=1.0, theta=0.0
% INFO    : Bus 77486	: V=1.0172583, theta=-58.256811 -> V=1.0, theta=0.0
% INFO    : Bus 77487	: V=1.011578, theta=-58.841511 -> V=1.0, theta=0.0
% INFO    : Bus 77488	: V=0.9864943, theta=-61.317223 -> V=1.0, theta=0.0
% INFO    : Bus 77489	: V=1.0039723, theta=-59.21873 -> V=1.0, theta=0.0
% INFO    : Bus 77490	: V=0.9902621, theta=-59.739312 -> V=1.0, theta=0.0
% INFO    : Bus 77491	: V=0.994475, theta=-59.361512 -> V=1.0, theta=0.0
% INFO    : Bus 77492	: V=0.9938683, theta=-59.417042 -> V=1.0, theta=0.0
% INFO    : Bus 77493	: V=0.9947707, theta=-59.453635 -> V=1.0, theta=0.0
% INFO    : Bus 77494	: V=0.9964306, theta=-59.98944 -> V=1.0, theta=0.0
% INFO    : Bus 77495	: V=0.9928788, theta=-60.322058 -> V=1.0, theta=0.0
% INFO    : Bus 77496	: V=0.9760176, theta=-65.875248 -> V=1.0, theta=0.0
% INFO    : Bus 77497	: V=0.9812657, theta=-64.896441 -> V=1.0, theta=0.0
% INFO    : Bus 77498	: V=0.984036, theta=-64.167106 -> V=1.0, theta=0.0
% INFO    : Bus 77499	: V=0.9839676, theta=-64.416202 -> V=1.0, theta=0.0
% INFO    : Bus 77500	: V=0.9742149, theta=-66.343315 -> V=1.0, theta=0.0
% INFO    : Bus 77501	: V=0.9738173, theta=-66.245999 -> V=1.0, theta=0.0
% INFO    : Bus 77502	: V=0.9698627, theta=-66.458438 -> V=1.0, theta=0.0
% INFO    : Bus 77503	: V=0.9633367, theta=-72.42608 -> V=1.0, theta=0.0
% INFO    : Bus 77504	: V=0.9619677, theta=-72.993007 -> V=1.0, theta=0.0
% INFO    : Bus 77505	: V=0.9539163, theta=-76.72471 -> V=1.0, theta=0.0
% INFO    : Bus 77506	: V=0.9886818, theta=-70.980703 -> V=1.0, theta=0.0
% INFO    : Bus 77507	: V=0.9935056, theta=-70.95122 -> V=1.0, theta=0.0
% INFO    : Bus 77508	: V=1.0088953, theta=-70.135828 -> V=1.0, theta=0.0
% INFO    : Bus 77509	: V=0.9752435, theta=-70.474098 -> V=1.0, theta=0.0
% INFO    : Bus 77510	: V=0.9698407, theta=-70.172746 -> V=1.0, theta=0.0
% INFO    : Bus 77511	: V=0.9773656, theta=-65.507176 -> V=1.0, theta=0.0
% INFO    : Bus 77512	: V=0.9721144, theta=-65.983778 -> V=1.0, theta=0.0
% INFO    : Bus 77513	: V=0.971887, theta=-65.372325 -> V=1.0, theta=0.0
% INFO    : Bus 77514	: V=0.9668094, theta=-66.543558 -> V=1.0, theta=0.0
% INFO    : Bus 77515	: V=0.9654997, theta=-66.732068 -> V=1.0, theta=0.0
% INFO    : Bus 77516	: V=0.9634588, theta=-66.655011 -> V=1.0, theta=0.0
% INFO    : Bus 77517	: V=0.9681526, theta=-65.418956 -> V=1.0, theta=0.0
% INFO    : Bus 77518	: V=0.9734582, theta=-65.119685 -> V=1.0, theta=0.0
% INFO    : Bus 77519	: V=0.9709952, theta=-66.021019 -> V=1.0, theta=0.0
% INFO    : Bus 77520	: V=0.9693059, theta=-65.374582 -> V=1.0, theta=0.0
% INFO    : Bus 77521	: V=0.9793411, theta=-64.260632 -> V=1.0, theta=0.0
% INFO    : Bus 77522	: V=0.9927822, theta=-69.490258 -> V=1.0, theta=0.0
% INFO    : Bus 77523	: V=0.997646, theta=-68.132454 -> V=1.0, theta=0.0
% INFO    : Bus 77524	: V=0.9906455, theta=-69.497194 -> V=1.0, theta=0.0
% INFO    : Bus 77525	: V=0.9940008, theta=-69.680662 -> V=1.0, theta=0.0
% INFO    : Bus 77526	: V=0.9824648, theta=-70.237626 -> V=1.0, theta=0.0
% INFO    : Bus 77527	: V=0.9843436, theta=-66.445906 -> V=1.0, theta=0.0
% INFO    : Bus 77528	: V=1.0038142, theta=-63.712005 -> V=1.0, theta=0.0
% INFO    : Bus 77529	: V=0.9835698, theta=-66.08889 -> V=1.0, theta=0.0
% INFO    : Bus 77530	: V=0.9978388, theta=-61.915816 -> V=1.0, theta=0.0
% INFO    : Bus 77531	: V=0.9797935, theta=-65.915025 -> V=1.0, theta=0.0
% INFO    : Bus 77532	: V=0.9781223, theta=-65.670259 -> V=1.0, theta=0.0
% INFO    : Bus 77533	: V=0.9830405, theta=-63.482324 -> V=1.0, theta=0.0
% INFO    : Bus 77534	: V=0.9823497, theta=-63.590456 -> V=1.0, theta=0.0
% INFO    : Bus 77535	: V=0.9873911, theta=-64.40005 -> V=1.0, theta=0.0
% INFO    : Bus 77536	: V=0.9881842, theta=-64.209497 -> V=1.0, theta=0.0
% INFO    : Bus 77537	: V=0.9893928, theta=-64.072756 -> V=1.0, theta=0.0
% INFO    : Bus 77538	: V=0.9890038, theta=-64.11131 -> V=1.0, theta=0.0
% INFO    : Bus 77539	: V=0.9882651, theta=-64.280023 -> V=1.0, theta=0.0
% INFO    : Bus 77540	: V=0.9899354, theta=-63.931019 -> V=1.0, theta=0.0
% INFO    : Bus 77541	: V=0.9945155, theta=-62.968654 -> V=1.0, theta=0.0
% INFO    : Bus 77542	: V=0.9907024, theta=-63.799812 -> V=1.0, theta=0.0
% INFO    : Bus 77543	: V=0.9838881, theta=-65.05003 -> V=1.0, theta=0.0
% INFO    : Bus 77544	: V=0.9827687, theta=-65.292766 -> V=1.0, theta=0.0
% INFO    : Bus 77545	: V=0.9873364, theta=-64.454926 -> V=1.0, theta=0.0
% INFO    : Bus 77546	: V=0.987074, theta=-64.474769 -> V=1.0, theta=0.0
% INFO    : Bus 77547	: V=0.9918058, theta=-63.519826 -> V=1.0, theta=0.0
% INFO    : Bus 77548	: V=0.9941832, theta=-63.026494 -> V=1.0, theta=0.0
% INFO    : Bus 77549	: V=0.9886235, theta=-63.797652 -> V=1.0, theta=0.0
% INFO    : Bus 77550	: V=0.9836013, theta=-64.906625 -> V=1.0, theta=0.0
% INFO    : Bus 77551	: V=0.9836755, theta=-65.022378 -> V=1.0, theta=0.0
% INFO    : Bus 77552	: V=0.9841989, theta=-64.884124 -> V=1.0, theta=0.0
% INFO    : Bus 77553	: V=0.9822283, theta=-65.316297 -> V=1.0, theta=0.0
% INFO    : Bus 77554	: V=0.983693, theta=-65.054781 -> V=1.0, theta=0.0
% INFO    : Bus 77555	: V=0.9910398, theta=-63.580451 -> V=1.0, theta=0.0
% INFO    : Bus 77556	: V=0.9843875, theta=-64.803696 -> V=1.0, theta=0.0
% INFO    : Bus 77557	: V=0.9815146, theta=-65.396392 -> V=1.0, theta=0.0
% INFO    : Bus 77558	: V=0.9820661, theta=-65.375772 -> V=1.0, theta=0.0
% INFO    : Bus 77559	: V=0.9787717, theta=-65.900645 -> V=1.0, theta=0.0
% INFO    : Bus 77560	: V=0.9815879, theta=-65.394678 -> V=1.0, theta=0.0
% INFO    : Bus 77561	: V=0.9835406, theta=-65.06386 -> V=1.0, theta=0.0
% INFO    : Bus 77562	: V=0.9816476, theta=-65.365179 -> V=1.0, theta=0.0
% INFO    : Bus 77563	: V=0.9826098, theta=-65.198351 -> V=1.0, theta=0.0
% INFO    : Bus 77564	: V=0.9822385, theta=-65.210123 -> V=1.0, theta=0.0
% INFO    : Bus 77565	: V=0.9786727, theta=-65.684956 -> V=1.0, theta=0.0
% INFO    : Bus 77566	: V=0.9758596, theta=-65.974668 -> V=1.0, theta=0.0
% INFO    : Bus 77567	: V=0.97739, theta=-65.836527 -> V=1.0, theta=0.0
% INFO    : Bus 77568	: V=0.9794208, theta=-65.568535 -> V=1.0, theta=0.0
% INFO    : Bus 77569	: V=0.9763748, theta=-65.937204 -> V=1.0, theta=0.0
% INFO    : Bus 77570	: V=0.9790283, theta=-65.628571 -> V=1.0, theta=0.0
% INFO    : Bus 77571	: V=0.9770719, theta=-65.813817 -> V=1.0, theta=0.0
% INFO    : Bus 77572	: V=0.978176, theta=-65.376817 -> V=1.0, theta=0.0
% INFO    : Bus 77573	: V=0.9786812, theta=-65.978961 -> V=1.0, theta=0.0
% INFO    : Bus 77574	: V=0.9802147, theta=-65.194965 -> V=1.0, theta=0.0
% INFO    : Bus 77575	: V=0.9815148, theta=-65.096928 -> V=1.0, theta=0.0
% INFO    : Bus 77576	: V=0.9780439, theta=-65.69976 -> V=1.0, theta=0.0
% INFO    : Bus 77577	: V=0.9817262, theta=-64.993466 -> V=1.0, theta=0.0
% INFO    : Bus 77578	: V=0.9800368, theta=-65.229964 -> V=1.0, theta=0.0
% INFO    : Bus 77579	: V=0.9819474, theta=-64.98192 -> V=1.0, theta=0.0
% INFO    : Bus 77580	: V=0.9796452, theta=-65.367265 -> V=1.0, theta=0.0
% INFO    : Bus 77581	: V=0.9803221, theta=-65.291967 -> V=1.0, theta=0.0
% INFO    : Bus 77582	: V=0.9817583, theta=-65.082239 -> V=1.0, theta=0.0
% INFO    : Bus 77583	: V=0.9918532, theta=-63.673752 -> V=1.0, theta=0.0
% INFO    : Bus 77584	: V=0.9874623, theta=-64.371582 -> V=1.0, theta=0.0
% INFO    : Bus 77585	: V=0.9863491, theta=-64.47959 -> V=1.0, theta=0.0
% INFO    : Bus 77586	: V=0.9843975, theta=-64.628857 -> V=1.0, theta=0.0
% INFO    : Bus 77587	: V=0.9835383, theta=-64.735336 -> V=1.0, theta=0.0
% INFO    : Bus 77588	: V=0.9817787, theta=-65.077377 -> V=1.0, theta=0.0
% INFO    : Bus 77589	: V=0.9851933, theta=-64.355126 -> V=1.0, theta=0.0
% INFO    : Bus 77590	: V=0.9861481, theta=-64.265138 -> V=1.0, theta=0.0
% INFO    : Bus 77591	: V=0.9868452, theta=-64.166544 -> V=1.0, theta=0.0
% INFO    : Bus 77592	: V=0.986318, theta=-63.760222 -> V=1.0, theta=0.0
% INFO    : Bus 77593	: V=0.994732, theta=-62.847347 -> V=1.0, theta=0.0
% INFO    : Bus 77594	: V=0.9904034, theta=-63.199821 -> V=1.0, theta=0.0
% INFO    : Bus 77595	: V=0.9809524, theta=-64.932722 -> V=1.0, theta=0.0
% INFO    : Bus 77596	: V=0.976863, theta=-65.542946 -> V=1.0, theta=0.0
% INFO    : Bus 77597	: V=0.9737656, theta=-66.477586 -> V=1.0, theta=0.0
% INFO    : Bus 77598	: V=0.9723269, theta=-65.839353 -> V=1.0, theta=0.0
% INFO    : Bus 77599	: V=0.9832226, theta=-63.749601 -> V=1.0, theta=0.0
% INFO    : Bus 77600	: V=0.9887563, theta=-63.072622 -> V=1.0, theta=0.0
% INFO    : Bus 77601	: V=0.9950241, theta=-62.406915 -> V=1.0, theta=0.0
% INFO    : Bus 77602	: V=0.9983427, theta=-62.086305 -> V=1.0, theta=0.0
% INFO    : Bus 77603	: V=0.9994735, theta=-62.023113 -> V=1.0, theta=0.0
% INFO    : Bus 77604	: V=0.9854427, theta=-63.568467 -> V=1.0, theta=0.0
% INFO    : Bus 77605	: V=0.9810764, theta=-63.875784 -> V=1.0, theta=0.0
% INFO    : Bus 77606	: V=0.9792415, theta=-63.83309 -> V=1.0, theta=0.0
% INFO    : Bus 77607	: V=0.9811176, theta=-65.123107 -> V=1.0, theta=0.0
% INFO    : Bus 77608	: V=0.988471, theta=-69.744006 -> V=1.0, theta=0.0
% INFO    : Bus 77609	: V=1.0007562, theta=-69.215483 -> V=1.0, theta=0.0
% INFO    : Bus 77610	: V=0.9975385, theta=-70.528982 -> V=1.0, theta=0.0
% INFO    : Bus 77611	: V=1.0199441, theta=-52.38337 -> V=1.0, theta=0.0
% INFO    : Bus 77612	: V=1.01926, theta=-54.11207 -> V=1.0, theta=0.0
% INFO    : Bus 77613	: V=1.0169506, theta=-53.849642 -> V=1.0, theta=0.0
% INFO    : Bus 77614	: V=1.0169359, theta=-54.265254 -> V=1.0, theta=0.0
% INFO    : Bus 77615	: V=1.0179449, theta=-53.198342 -> V=1.0, theta=0.0
% INFO    : Bus 77616	: V=1.0170592, theta=-53.750545 -> V=1.0, theta=0.0
% INFO    : Bus 77617	: V=1.0150851, theta=-54.626122 -> V=1.0, theta=0.0
% INFO    : Bus 77618	: V=1.0139823, theta=-54.497376 -> V=1.0, theta=0.0
% INFO    : Bus 77619	: V=1.0044872, theta=-61.366679 -> V=1.0, theta=0.0
% INFO    : Bus 77620	: V=0.9988023, theta=-61.993542 -> V=1.0, theta=0.0
% INFO    : Bus 77621	: V=0.9984962, theta=-62.018153 -> V=1.0, theta=0.0
% INFO    : Bus 77622	: V=1.0058357, theta=-59.957741 -> V=1.0, theta=0.0
% INFO    : Bus 77623	: V=1.0097755, theta=-56.475627 -> V=1.0, theta=0.0
% INFO    : Bus 77624	: V=1.0118428, theta=-58.107624 -> V=1.0, theta=0.0
% INFO    : Bus 77625	: V=1.0109084, theta=-57.700429 -> V=1.0, theta=0.0
% INFO    : Bus 77626	: V=1.0142131, theta=-59.326543 -> V=1.0, theta=0.0
% INFO    : Bus 77627	: V=1.0113173, theta=-59.701143 -> V=1.0, theta=0.0
% INFO    : Bus 77628	: V=1.0093869, theta=-59.732804 -> V=1.0, theta=0.0
% INFO    : Bus 77629	: V=1.0107441, theta=-58.871643 -> V=1.0, theta=0.0
% INFO    : Bus 77630	: V=1.007601, theta=-59.119766 -> V=1.0, theta=0.0
% INFO    : Bus 77631	: V=1.0144744, theta=-58.450798 -> V=1.0, theta=0.0
% INFO    : Bus 77632	: V=1.0071672, theta=-59.122225 -> V=1.0, theta=0.0
% INFO    : Bus 77633	: V=1.0140725, theta=-52.108451 -> V=1.0, theta=0.0
% INFO    : Bus 77634	: V=1.0008778, theta=-55.152499 -> V=1.0, theta=0.0
% INFO    : Bus 77635	: V=1.0012293, theta=-63.145536 -> V=1.0, theta=0.0
% INFO    : Bus 77636	: V=1.0049841, theta=-62.783875 -> V=1.0, theta=0.0
% INFO    : Bus 77637	: V=1.0119277, theta=-59.310778 -> V=1.0, theta=0.0
% INFO    : Bus 77638	: V=1.0072446, theta=-59.71645 -> V=1.0, theta=0.0
% INFO    : Bus 77639	: V=1.0121296, theta=-53.951942 -> V=1.0, theta=0.0
% INFO    : Bus 77640	: V=1.0014514, theta=-60.659222 -> V=1.0, theta=0.0
% INFO    : Bus 77641	: V=1.0049096, theta=-60.291854 -> V=1.0, theta=0.0
% INFO    : Bus 77642	: V=1.0184894, theta=-56.33149 -> V=1.0, theta=0.0
% INFO    : Bus 77643	: V=1.0167005, theta=-56.379976 -> V=1.0, theta=0.0
% INFO    : Bus 77644	: V=1.0048368, theta=-56.853191 -> V=1.0, theta=0.0
% INFO    : Bus 77645	: V=0.9973894, theta=-61.121292 -> V=1.0, theta=0.0
% INFO    : Bus 77646	: V=1.0013517, theta=-61.443621 -> V=1.0, theta=0.0
% INFO    : Bus 77647	: V=1.0019796, theta=-61.497667 -> V=1.0, theta=0.0
% INFO    : Bus 77648	: V=1.0058138, theta=-53.135946 -> V=1.0, theta=0.0
% INFO    : Bus 77649	: V=1.0159408, theta=-58.75846 -> V=1.0, theta=0.0
% INFO    : Bus 77650	: V=1.0079671, theta=-59.806801 -> V=1.0, theta=0.0
% INFO    : Bus 77651	: V=1.0073706, theta=-60.037117 -> V=1.0, theta=0.0
% INFO    : Bus 77652	: V=1.0036347, theta=-59.541051 -> V=1.0, theta=0.0
% INFO    : Bus 77653	: V=1.0117717, theta=-58.816387 -> V=1.0, theta=0.0
% INFO    : Bus 77654	: V=1.0014458, theta=-59.58058 -> V=1.0, theta=0.0
% INFO    : Bus 77655	: V=0.9988179, theta=-60.289062 -> V=1.0, theta=0.0
% INFO    : Bus 77656	: V=1.014485, theta=-54.385231 -> V=1.0, theta=0.0
% INFO    : Bus 77657	: V=0.9995875, theta=-61.253054 -> V=1.0, theta=0.0
% INFO    : Bus 77658	: V=1.0145908, theta=-54.700345 -> V=1.0, theta=0.0
% INFO    : Bus 77659	: V=1.0124103, theta=-54.779545 -> V=1.0, theta=0.0
% INFO    : Bus 77660	: V=1.0066379, theta=-58.783485 -> V=1.0, theta=0.0
% INFO    : Bus 77661	: V=0.9928935, theta=-61.259858 -> V=1.0, theta=0.0
% INFO    : Bus 77662	: V=1.0090115, theta=-58.868374 -> V=1.0, theta=0.0
% INFO    : Bus 77663	: V=1.02, theta=-53.061994 -> V=1.0, theta=0.0
% INFO    : Bus 77664	: V=0.9987716, theta=-60.264393 -> V=1.0, theta=0.0
% INFO    : Bus 77665	: V=1.0166733, theta=-56.216853 -> V=1.0, theta=0.0
% INFO    : Bus 77666	: V=1.0137764, theta=-56.597475 -> V=1.0, theta=0.0
% INFO    : Bus 77667	: V=1.0079996, theta=-60.127558 -> V=1.0, theta=0.0
% INFO    : Bus 77668	: V=0.9954972, theta=-60.744207 -> V=1.0, theta=0.0
% INFO    : Bus 77669	: V=1.0192987, theta=-56.650816 -> V=1.0, theta=0.0
% INFO    : Bus 77670	: V=1.0160625, theta=-57.547715 -> V=1.0, theta=0.0
% INFO    : Bus 77671	: V=1.0135128, theta=-58.170089 -> V=1.0, theta=0.0
% INFO    : Bus 77672	: V=1.012375, theta=-58.625671 -> V=1.0, theta=0.0
% INFO    : Bus 77673	: V=1.0194773, theta=-57.348932 -> V=1.0, theta=0.0
% INFO    : Bus 77674	: V=1.0184222, theta=-57.496461 -> V=1.0, theta=0.0
% INFO    : Bus 77675	: V=1.0071384, theta=-57.182652 -> V=1.0, theta=0.0
% INFO    : Bus 77676	: V=1.006032, theta=-57.374214 -> V=1.0, theta=0.0
% INFO    : Bus 77677	: V=1.0113965, theta=-55.757191 -> V=1.0, theta=0.0
% INFO    : Bus 77678	: V=1.0080032, theta=-56.492745 -> V=1.0, theta=0.0
% INFO    : Bus 77679	: V=1.0180242, theta=-56.742368 -> V=1.0, theta=0.0
% INFO    : Bus 77680	: V=1.013941, theta=-57.892423 -> V=1.0, theta=0.0
% INFO    : Bus 77681	: V=1.0073008, theta=-59.046913 -> V=1.0, theta=0.0
% INFO    : Bus 77682	: V=1.0068296, theta=-59.295041 -> V=1.0, theta=0.0
% INFO    : Bus 77683	: V=0.9971552, theta=-60.903556 -> V=1.0, theta=0.0
% INFO    : Bus 77684	: V=1.0004288, theta=-60.569082 -> V=1.0, theta=0.0
% INFO    : Bus 77685	: V=1.0152366, theta=-57.897476 -> V=1.0, theta=0.0
% INFO    : Bus 77686	: V=1.014507, theta=-58.049723 -> V=1.0, theta=0.0
% INFO    : Bus 77687	: V=1.0178429, theta=-52.762336 -> V=1.0, theta=0.0
% INFO    : Bus 77688	: V=1.0191066, theta=-52.989874 -> V=1.0, theta=0.0
% INFO    : Bus 77689	: V=1.0155877, theta=-53.839605 -> V=1.0, theta=0.0
% INFO    : Bus 77690	: V=1.0137532, theta=-54.182522 -> V=1.0, theta=0.0
% INFO    : Bus 77691	: V=0.9950676, theta=-59.287264 -> V=1.0, theta=0.0
% INFO    : Bus 77692	: V=1.0048556, theta=-62.568727 -> V=1.0, theta=0.0
% INFO    : Bus 77693	: V=1.0104042, theta=-61.889487 -> V=1.0, theta=0.0
% INFO    : Bus 77694	: V=1.0102709, theta=-59.445701 -> V=1.0, theta=0.0
% INFO    : Bus 77695	: V=1.0067677, theta=-62.097541 -> V=1.0, theta=0.0
% INFO    : Bus 77696	: V=1.0092677, theta=-62.060943 -> V=1.0, theta=0.0
% INFO    : Bus 77697	: V=0.9965733, theta=-61.330733 -> V=1.0, theta=0.0
% INFO    : Bus 77698	: V=1.0159018, theta=-58.679641 -> V=1.0, theta=0.0
% INFO    : Bus 77699	: V=1.0112716, theta=-59.30344 -> V=1.0, theta=0.0
% INFO    : Bus 77700	: V=1.0066177, theta=-59.762602 -> V=1.0, theta=0.0
% INFO    : Bus 77701	: V=1.0147229, theta=-57.182962 -> V=1.0, theta=0.0
% INFO    : Bus 77702	: V=1.0185113, theta=-57.580277 -> V=1.0, theta=0.0
% INFO    : Bus 77703	: V=1.015052, theta=-58.03354 -> V=1.0, theta=0.0
% INFO    : Bus 77704	: V=0.9978572, theta=-60.863104 -> V=1.0, theta=0.0
% INFO    : Bus 77705	: V=0.9946281, theta=-61.368613 -> V=1.0, theta=0.0
% INFO    : Bus 77706	: V=1.0132681, theta=-57.071263 -> V=1.0, theta=0.0
% INFO    : Bus 77707	: V=1.0067974, theta=-58.029657 -> V=1.0, theta=0.0
% INFO    : Bus 77708	: V=1.0167637, theta=-58.050935 -> V=1.0, theta=0.0
% INFO    : Bus 77709	: V=1.0121067, theta=-54.474561 -> V=1.0, theta=0.0
% INFO    : Bus 77710	: V=1.0148657, theta=-64.76287 -> V=1.0, theta=0.0
% INFO    : Bus 77711	: V=0.9949929, theta=-61.541607 -> V=1.0, theta=0.0
% INFO    : Bus 77712	: V=0.999524, theta=-62.626279 -> V=1.0, theta=0.0
% INFO    : Bus 77713	: V=1.0092197, theta=-56.395664 -> V=1.0, theta=0.0
% INFO    : Bus 77714	: V=1.0120037, theta=-56.104784 -> V=1.0, theta=0.0
% INFO    : Bus 77715	: V=1.0089429, theta=-60.186073 -> V=1.0, theta=0.0
% INFO    : Bus 77716	: V=1.0123092, theta=-59.812257 -> V=1.0, theta=0.0
% INFO    : Bus 77717	: V=1.0089028, theta=-62.917249 -> V=1.0, theta=0.0
% INFO    : Bus 77718	: V=1.001717, theta=-64.12854 -> V=1.0, theta=0.0
% INFO    : Bus 77719	: V=1.0011889, theta=-64.286663 -> V=1.0, theta=0.0
% INFO    : Bus 77720	: V=1.02, theta=-55.687573 -> V=1.0, theta=0.0
% INFO    : Bus 77721	: V=0.9663946, theta=-78.307818 -> V=1.0, theta=0.0
% INFO    : Bus 77722	: V=0.9957535, theta=-59.303295 -> V=1.0, theta=0.0
% INFO    : Bus 77723	: V=1.0081136, theta=-68.061526 -> V=1.0, theta=0.0
% INFO    : Bus 77724	: V=1.02, theta=-57.630075 -> V=1.0, theta=0.0
% INFO    : Bus 77725	: V=1.02, theta=-60.701937 -> V=1.0, theta=0.0
% INFO    : Bus 77726	: V=1.0109778, theta=-58.175469 -> V=1.0, theta=0.0
% INFO    : Bus 77727	: V=1.0135062, theta=-58.056433 -> V=1.0, theta=0.0
% INFO    : Bus 77728	: V=0.9949015, theta=-60.314141 -> V=1.0, theta=0.0
% INFO    : Bus 77729	: V=0.9821541, theta=-61.200427 -> V=1.0, theta=0.0
% INFO    : Bus 77730	: V=0.9811058, theta=-61.563051 -> V=1.0, theta=0.0
% INFO    : Bus 77731	: V=0.988224, theta=-63.356857 -> V=1.0, theta=0.0
% INFO    : Bus 77732	: V=0.9816517, theta=-63.736537 -> V=1.0, theta=0.0
% INFO    : Bus 77733	: V=1.02, theta=-56.865423 -> V=1.0, theta=0.0
% INFO    : Bus 77734	: V=1.0165402, theta=-67.822135 -> V=1.0, theta=0.0
% INFO    : Bus 77735	: V=0.9699611, theta=-73.377208 -> V=1.0, theta=0.0
% INFO    : Bus 77736	: V=0.9734485, theta=-70.872814 -> V=1.0, theta=0.0
% INFO    : Bus 77737	: V=1.006334, theta=-71.42831 -> V=1.0, theta=0.0
% INFO    : Bus 77738	: V=0.997356, theta=-68.518561 -> V=1.0, theta=0.0
% INFO    : Bus 77739	: V=0.9901523, theta=-60.7357 -> V=1.0, theta=0.0
% INFO    : Bus 77740	: V=0.982034, theta=-62.059746 -> V=1.0, theta=0.0
% INFO    : Bus 77741	: V=1.0190304, theta=-61.988665 -> V=1.0, theta=0.0
% INFO    : Bus 77742	: V=0.9651466, theta=-69.027194 -> V=1.0, theta=0.0
% INFO    : Bus 77743	: V=0.9913523, theta=-63.427192 -> V=1.0, theta=0.0
% INFO    : Bus 77744	: V=0.995927, theta=-61.133129 -> V=1.0, theta=0.0
% INFO    : Bus 77745	: V=1.0156892, theta=-55.664048 -> V=1.0, theta=0.0
% INFO    : Bus 77746	: V=0.9897822, theta=-60.182185 -> V=1.0, theta=0.0
% INFO    : Bus 77747	: V=1.0069546, theta=-57.688598 -> V=1.0, theta=0.0
% INFO    : Bus 77748	: V=0.9839077, theta=-66.444272 -> V=1.0, theta=0.0
% INFO    : Bus 77749	: V=0.9952155, theta=-61.779623 -> V=1.0, theta=0.0
% INFO    : Bus 77750	: V=0.9985767, theta=-63.498412 -> V=1.0, theta=0.0
% INFO    : Bus 77751	: V=0.9925086, theta=-61.537563 -> V=1.0, theta=0.0
% INFO    : Bus 77752	: V=0.9984404, theta=-59.790239 -> V=1.0, theta=0.0
% INFO    : Bus 77753	: V=1.02, theta=-57.023001 -> V=1.0, theta=0.0
% INFO    : Bus 77754	: V=0.9768234, theta=-63.751259 -> V=1.0, theta=0.0
% INFO    : Bus 77755	: V=1.0192109, theta=-56.943871 -> V=1.0, theta=0.0
% INFO    : Bus 77756	: V=0.9764787, theta=-65.951428 -> V=1.0, theta=0.0
% INFO    : Bus 77757	: V=1.0011371, theta=-59.221993 -> V=1.0, theta=0.0
% INFO    : Bus 77758	: V=1.0002086, theta=-59.384006 -> V=1.0, theta=0.0
% INFO    : Bus 77759	: V=0.9931783, theta=-68.58679 -> V=1.0, theta=0.0
% INFO    : Bus 77760	: V=1.0060989, theta=-57.756938 -> V=1.0, theta=0.0
% INFO    : Bus 77761	: V=1.0057652, theta=-59.130163 -> V=1.0, theta=0.0
% INFO    : Bus 77762	: V=1.013759, theta=-71.368812 -> V=1.0, theta=0.0
% INFO    : Bus 77763	: V=0.9934794, theta=-61.934614 -> V=1.0, theta=0.0
% INFO    : Bus 77764	: V=0.9968764, theta=-59.075986 -> V=1.0, theta=0.0
% INFO    : Bus 77765	: V=0.9761444, theta=-64.98116 -> V=1.0, theta=0.0
% INFO    : Bus 77766	: V=0.9655379, theta=-69.650335 -> V=1.0, theta=0.0
% INFO    : Bus 77767	: V=1.0169325, theta=-58.455229 -> V=1.0, theta=0.0
% INFO    : Bus 77768	: V=1.019093, theta=-58.18022 -> V=1.0, theta=0.0
% INFO    : Bus 77769	: V=1.0171889, theta=-58.291775 -> V=1.0, theta=0.0
% INFO    : Bus 77770	: V=0.9879981, theta=-63.795491 -> V=1.0, theta=0.0
% INFO    : Bus 77771	: V=1.006261, theta=-60.377178 -> V=1.0, theta=0.0
% INFO    : Bus 77772	: V=1.0083588, theta=-61.787054 -> V=1.0, theta=0.0
% INFO    : Bus 77773	: V=0.9761352, theta=-62.508292 -> V=1.0, theta=0.0
% INFO    : Bus 77774	: V=1.004889, theta=-59.067879 -> V=1.0, theta=0.0
% INFO    : Bus 77775	: V=0.9966038, theta=-53.54782 -> V=1.0, theta=0.0
% INFO    : Bus 77776	: V=0.9992762, theta=-53.495734 -> V=1.0, theta=0.0
% INFO    : Bus 77777	: V=0.9980266, theta=-53.470929 -> V=1.0, theta=0.0
% INFO    : Bus 77778	: V=0.9983733, theta=-53.73542 -> V=1.0, theta=0.0
% INFO    : Bus 77779	: V=0.9662881, theta=-57.665939 -> V=1.0, theta=0.0
% INFO    : Bus 77780	: V=0.9791027, theta=-56.202768 -> V=1.0, theta=0.0
% INFO    : Bus 77781	: V=0.9877215, theta=-55.001782 -> V=1.0, theta=0.0
% INFO    : Bus 77782	: V=0.9883889, theta=-54.431567 -> V=1.0, theta=0.0
% INFO    : Bus 77783	: V=0.9952324, theta=-53.925216 -> V=1.0, theta=0.0
% INFO    : Bus 77784	: V=0.9989709, theta=-53.607143 -> V=1.0, theta=0.0
% INFO    : Bus 77785	: V=1.0058602, theta=-53.553238 -> V=1.0, theta=0.0
% INFO    : Bus 77786	: V=0.9967069, theta=-53.676497 -> V=1.0, theta=0.0
% INFO    : Bus 77787	: V=0.9955498, theta=-53.73727 -> V=1.0, theta=0.0
% INFO    : Bus 77788	: V=1.0094008, theta=-52.465805 -> V=1.0, theta=0.0
% INFO    : Bus 77789	: V=1.0046227, theta=-52.80136 -> V=1.0, theta=0.0
% INFO    : Bus 77790	: V=1.0054669, theta=-52.932529 -> V=1.0, theta=0.0
% INFO    : Bus 77791	: V=0.9883345, theta=-64.618166 -> V=1.0, theta=0.0
% INFO    : Bus 77792	: V=0.98881, theta=-64.577036 -> V=1.0, theta=0.0
% INFO    : Bus 77793	: V=0.9915204, theta=-64.248257 -> V=1.0, theta=0.0
% INFO    : Bus 77794	: V=0.9916819, theta=-64.218288 -> V=1.0, theta=0.0
% INFO    : Bus 77795	: V=0.9923417, theta=-64.41409 -> V=1.0, theta=0.0
% INFO    : Bus 77796	: V=0.9922256, theta=-63.488988 -> V=1.0, theta=0.0
% INFO    : Bus 77797	: V=0.9932161, theta=-64.005137 -> V=1.0, theta=0.0
% INFO    : Bus 77798	: V=0.9858548, theta=-64.797344 -> V=1.0, theta=0.0
% INFO    : Bus 77799	: V=0.9875071, theta=-64.709704 -> V=1.0, theta=0.0
% INFO    : Bus 77800	: V=0.9865833, theta=-63.247963 -> V=1.0, theta=0.0
% INFO    : Bus 77801	: V=0.9878708, theta=-63.728827 -> V=1.0, theta=0.0
% INFO    : Bus 77802	: V=0.9866835, theta=-64.510867 -> V=1.0, theta=0.0
% INFO    : Bus 77803	: V=0.9885363, theta=-64.778124 -> V=1.0, theta=0.0
% INFO    : Bus 77804	: V=0.9905761, theta=-64.501486 -> V=1.0, theta=0.0
% INFO    : Bus 77805	: V=0.9906301, theta=-63.454269 -> V=1.0, theta=0.0
% INFO    : Bus 77806	: V=0.9892511, theta=-64.088371 -> V=1.0, theta=0.0
% INFO    : Bus 77807	: V=0.9951591, theta=-63.983325 -> V=1.0, theta=0.0
% INFO    : Bus 77808	: V=0.9948682, theta=-63.977461 -> V=1.0, theta=0.0
% INFO    : Bus 77809	: V=0.9954171, theta=-64.035068 -> V=1.0, theta=0.0
% INFO    : Bus 77810	: V=0.98992, theta=-64.311472 -> V=1.0, theta=0.0
% INFO    : Bus 77811	: V=0.9940117, theta=-63.827899 -> V=1.0, theta=0.0
% INFO    : Bus 77812	: V=0.9940582, theta=-63.815066 -> V=1.0, theta=0.0
% INFO    : Bus 77813	: V=0.9944591, theta=-63.983089 -> V=1.0, theta=0.0
% INFO    : Bus 77814	: V=0.9816866, theta=-65.322865 -> V=1.0, theta=0.0
% INFO    : Bus 77815	: V=0.9975119, theta=-63.521362 -> V=1.0, theta=0.0
% INFO    : Bus 77816	: V=0.9929998, theta=-63.954076 -> V=1.0, theta=0.0
% INFO    : Bus 77817	: V=0.9973669, theta=-63.421445 -> V=1.0, theta=0.0
% INFO    : Bus 77818	: V=0.9828383, theta=-62.782857 -> V=1.0, theta=0.0
% INFO    : Bus 77819	: V=0.9930065, theta=-63.94364 -> V=1.0, theta=0.0
% INFO    : Bus 77820	: V=0.9986312, theta=-63.287283 -> V=1.0, theta=0.0
% INFO    : Bus 77821	: V=0.9994838, theta=-63.245172 -> V=1.0, theta=0.0
% INFO    : Bus 77822	: V=0.993009, theta=-63.567057 -> V=1.0, theta=0.0
% INFO    : Bus 77823	: V=0.9793544, theta=-64.97332 -> V=1.0, theta=0.0
% INFO    : Bus 77824	: V=0.9877673, theta=-64.56683 -> V=1.0, theta=0.0
% INFO    : Bus 77825	: V=0.9882936, theta=-64.273028 -> V=1.0, theta=0.0
% INFO    : Bus 77826	: V=0.9830458, theta=-65.116091 -> V=1.0, theta=0.0
% INFO    : Bus 77827	: V=0.9813476, theta=-64.682904 -> V=1.0, theta=0.0
% INFO    : Bus 77828	: V=0.978836, theta=-65.026445 -> V=1.0, theta=0.0
% INFO    : Bus 77829	: V=0.996037, theta=-63.929173 -> V=1.0, theta=0.0
% INFO    : Bus 77830	: V=0.9975122, theta=-63.567652 -> V=1.0, theta=0.0
% INFO    : Bus 77831	: V=0.9832911, theta=-64.560959 -> V=1.0, theta=0.0
% INFO    : Bus 77832	: V=0.9912319, theta=-64.260673 -> V=1.0, theta=0.0
% INFO    : Bus 77833	: V=0.9894841, theta=-64.29512 -> V=1.0, theta=0.0
% INFO    : Bus 77834	: V=0.9871332, theta=-62.98588 -> V=1.0, theta=0.0
% INFO    : Bus 77835	: V=0.9928865, theta=-63.918629 -> V=1.0, theta=0.0
% INFO    : Bus 77836	: V=0.991289, theta=-64.307037 -> V=1.0, theta=0.0
% INFO    : Bus 77837	: V=0.9886568, theta=-63.664973 -> V=1.0, theta=0.0
% INFO    : Bus 77838	: V=0.986375, theta=-64.522231 -> V=1.0, theta=0.0
% INFO    : Bus 77839	: V=0.9837803, theta=-65.023712 -> V=1.0, theta=0.0
% INFO    : Bus 77840	: V=0.9845025, theta=-64.399631 -> V=1.0, theta=0.0
% INFO    : Bus 77841	: V=0.9747399, theta=-62.628196 -> V=1.0, theta=0.0
% INFO    : Bus 77842	: V=0.9764274, theta=-62.542199 -> V=1.0, theta=0.0
% INFO    : Bus 77843	: V=0.9802626, theta=-62.251373 -> V=1.0, theta=0.0
% INFO    : Bus 77844	: V=0.9816554, theta=-62.213954 -> V=1.0, theta=0.0
% INFO    : Bus 77845	: V=1.0006878, theta=-60.562696 -> V=1.0, theta=0.0
% INFO    : Bus 77846	: V=1.0028536, theta=-60.56368 -> V=1.0, theta=0.0
% INFO    : Bus 77847	: V=0.9986658, theta=-61.210038 -> V=1.0, theta=0.0
% INFO    : Bus 77848	: V=1.0001366, theta=-60.71585 -> V=1.0, theta=0.0
% INFO    : Bus 77849	: V=1.0035369, theta=-60.249445 -> V=1.0, theta=0.0
% INFO    : Bus 77850	: V=1.0023469, theta=-60.338616 -> V=1.0, theta=0.0
% INFO    : Bus 77851	: V=0.9880502, theta=-61.181729 -> V=1.0, theta=0.0
% INFO    : Bus 77852	: V=0.9978457, theta=-60.401 -> V=1.0, theta=0.0
% INFO    : Bus 77853	: V=0.9859979, theta=-61.751506 -> V=1.0, theta=0.0
% INFO    : Bus 77854	: V=0.9848638, theta=-61.826263 -> V=1.0, theta=0.0
% INFO    : Bus 77855	: V=0.9837849, theta=-61.815259 -> V=1.0, theta=0.0
% INFO    : Bus 77856	: V=0.963394, theta=-61.928298 -> V=1.0, theta=0.0
% INFO    : Bus 77857	: V=0.9585502, theta=-61.97088 -> V=1.0, theta=0.0
% INFO    : Bus 77858	: V=0.9573463, theta=-61.7256 -> V=1.0, theta=0.0
% INFO    : Bus 77859	: V=0.9922904, theta=-60.869371 -> V=1.0, theta=0.0
% INFO    : Bus 77860	: V=0.9684153, theta=-62.393141 -> V=1.0, theta=0.0
% INFO    : Bus 77861	: V=0.9805319, theta=-61.046966 -> V=1.0, theta=0.0
% INFO    : Bus 77862	: V=0.9799314, theta=-60.945687 -> V=1.0, theta=0.0
% INFO    : Bus 77863	: V=0.9846219, theta=-61.589291 -> V=1.0, theta=0.0
% INFO    : Bus 77864	: V=0.9798482, theta=-61.766186 -> V=1.0, theta=0.0
% INFO    : Bus 77865	: V=0.9839877, theta=-61.048902 -> V=1.0, theta=0.0
% INFO    : Bus 77866	: V=0.9839496, theta=-61.255891 -> V=1.0, theta=0.0
% INFO    : Bus 77867	: V=0.9863409, theta=-60.936389 -> V=1.0, theta=0.0
% INFO    : Bus 77868	: V=0.9867078, theta=-60.891418 -> V=1.0, theta=0.0
% INFO    : Bus 77869	: V=0.9710773, theta=-62.704557 -> V=1.0, theta=0.0
% INFO    : Bus 77870	: V=0.9803395, theta=-62.055237 -> V=1.0, theta=0.0
% INFO    : Bus 77871	: V=0.9802673, theta=-62.053519 -> V=1.0, theta=0.0
% INFO    : Bus 77872	: V=0.9686953, theta=-62.466543 -> V=1.0, theta=0.0
% INFO    : Bus 77873	: V=0.9683998, theta=-62.344409 -> V=1.0, theta=0.0
% INFO    : Bus 77874	: V=0.96337, theta=-62.275537 -> V=1.0, theta=0.0
% INFO    : Bus 77875	: V=0.964825, theta=-61.349561 -> V=1.0, theta=0.0
% INFO    : Bus 77876	: V=0.9623735, theta=-62.000971 -> V=1.0, theta=0.0
% INFO    : Bus 77877	: V=0.9794566, theta=-61.114842 -> V=1.0, theta=0.0
% INFO    : Bus 77878	: V=0.9803785, theta=-61.661975 -> V=1.0, theta=0.0
% INFO    : Bus 77879	: V=0.9884636, theta=-60.334425 -> V=1.0, theta=0.0
% INFO    : Bus 77880	: V=0.974632, theta=-61.471243 -> V=1.0, theta=0.0
% INFO    : Bus 77881	: V=0.9767757, theta=-61.246537 -> V=1.0, theta=0.0
% INFO    : Bus 77882	: V=0.9689397, theta=-61.340256 -> V=1.0, theta=0.0
% INFO    : Bus 77883	: V=0.987525, theta=-60.355435 -> V=1.0, theta=0.0
% INFO    : Bus 77884	: V=0.9681989, theta=-61.292787 -> V=1.0, theta=0.0
% INFO    : Bus 77885	: V=0.962293, theta=-61.303511 -> V=1.0, theta=0.0
% INFO    : Bus 77886	: V=0.9681647, theta=-60.81323 -> V=1.0, theta=0.0
% INFO    : Bus 77887	: V=0.9683889, theta=-60.810396 -> V=1.0, theta=0.0
% INFO    : Bus 77888	: V=0.9706289, theta=-60.99104 -> V=1.0, theta=0.0
% INFO    : Bus 77889	: V=0.968112, theta=-60.976296 -> V=1.0, theta=0.0
% INFO    : Bus 77890	: V=0.9574366, theta=-60.465946 -> V=1.0, theta=0.0
% INFO    : Bus 77891	: V=0.9613302, theta=-61.40943 -> V=1.0, theta=0.0
% INFO    : Bus 77892	: V=0.96439, theta=-59.935948 -> V=1.0, theta=0.0
% INFO    : Bus 77893	: V=0.9619639, theta=-60.894567 -> V=1.0, theta=0.0
% INFO    : Bus 77894	: V=0.9633085, theta=-58.940846 -> V=1.0, theta=0.0
% INFO    : Bus 77895	: V=0.9817713, theta=-61.399599 -> V=1.0, theta=0.0
% INFO    : Bus 77896	: V=0.984909, theta=-61.716222 -> V=1.0, theta=0.0
% INFO    : Bus 77897	: V=0.9855435, theta=-61.556411 -> V=1.0, theta=0.0
% INFO    : Bus 77898	: V=0.9715827, theta=-62.699413 -> V=1.0, theta=0.0
% INFO    : Bus 77899	: V=0.9818592, theta=-61.017539 -> V=1.0, theta=0.0
% INFO    : Bus 77900	: V=0.9849665, theta=-61.193841 -> V=1.0, theta=0.0
% INFO    : Bus 77901	: V=0.9786439, theta=-61.094627 -> V=1.0, theta=0.0
% INFO    : Bus 77902	: V=0.9830027, theta=-61.055648 -> V=1.0, theta=0.0
% INFO    : Bus 77903	: V=0.9878036, theta=-60.353465 -> V=1.0, theta=0.0
% INFO    : Bus 77904	: V=1.0045129, theta=-53.391704 -> V=1.0, theta=0.0
% INFO    : Bus 77905	: V=0.9939478, theta=-54.476662 -> V=1.0, theta=0.0
% INFO    : Bus 77906	: V=1.0023671, theta=-54.046698 -> V=1.0, theta=0.0
% INFO    : Bus 77907	: V=0.9969665, theta=-55.248178 -> V=1.0, theta=0.0
% INFO    : Bus 77908	: V=1.0085564, theta=-54.76242 -> V=1.0, theta=0.0
% INFO    : Bus 77909	: V=1.0041703, theta=-54.986525 -> V=1.0, theta=0.0
% INFO    : Bus 77910	: V=1.005746, theta=-54.804299 -> V=1.0, theta=0.0
% INFO    : Bus 77911	: V=1.0038486, theta=-55.011516 -> V=1.0, theta=0.0
% INFO    : Bus 77912	: V=1.0062557, theta=-54.749029 -> V=1.0, theta=0.0
% INFO    : Bus 77913	: V=1.0058329, theta=-54.807765 -> V=1.0, theta=0.0
% INFO    : Bus 77914	: V=0.9999827, theta=-55.079652 -> V=1.0, theta=0.0
% INFO    : Bus 77915	: V=0.9879148, theta=-56.07653 -> V=1.0, theta=0.0
% INFO    : Bus 77916	: V=0.9913135, theta=-55.802444 -> V=1.0, theta=0.0
% INFO    : Bus 77917	: V=0.9921933, theta=-55.897313 -> V=1.0, theta=0.0
% INFO    : Bus 77918	: V=0.9908561, theta=-56.22673 -> V=1.0, theta=0.0
% INFO    : Bus 77919	: V=0.9838907, theta=-56.383697 -> V=1.0, theta=0.0
% INFO    : Bus 77920	: V=0.9990799, theta=-55.130992 -> V=1.0, theta=0.0
% INFO    : Bus 77921	: V=0.9831245, theta=-62.381302 -> V=1.0, theta=0.0
% INFO    : Bus 77922	: V=0.9842121, theta=-62.220769 -> V=1.0, theta=0.0
% INFO    : Bus 77923	: V=0.985445, theta=-62.007954 -> V=1.0, theta=0.0
% INFO    : Bus 77924	: V=0.9852333, theta=-62.143565 -> V=1.0, theta=0.0
% INFO    : Bus 77925	: V=0.9832777, theta=-62.22445 -> V=1.0, theta=0.0
% INFO    : Bus 77926	: V=0.9774407, theta=-62.536201 -> V=1.0, theta=0.0
% INFO    : Bus 77927	: V=0.9831429, theta=-62.213219 -> V=1.0, theta=0.0
% INFO    : Bus 77928	: V=0.9883437, theta=-61.760447 -> V=1.0, theta=0.0
% INFO    : Bus 77929	: V=0.9881828, theta=-61.7739 -> V=1.0, theta=0.0
% INFO    : Bus 77930	: V=0.9873682, theta=-61.81351 -> V=1.0, theta=0.0
% INFO    : Bus 77931	: V=0.9881936, theta=-61.641107 -> V=1.0, theta=0.0
% INFO    : Bus 77932	: V=0.9926286, theta=-61.470245 -> V=1.0, theta=0.0
% INFO    : Bus 77933	: V=0.9900625, theta=-61.621003 -> V=1.0, theta=0.0
% INFO    : Bus 77934	: V=0.990639, theta=-61.591035 -> V=1.0, theta=0.0
% INFO    : Bus 77935	: V=0.9894396, theta=-61.77313 -> V=1.0, theta=0.0
% INFO    : Bus 77936	: V=0.9885681, theta=-61.857042 -> V=1.0, theta=0.0
% INFO    : Bus 77937	: V=0.9951133, theta=-61.34952 -> V=1.0, theta=0.0
% INFO    : Bus 77938	: V=0.9950696, theta=-61.398969 -> V=1.0, theta=0.0
% INFO    : Bus 77939	: V=0.9942142, theta=-61.464416 -> V=1.0, theta=0.0
% INFO    : Bus 77940	: V=0.9881343, theta=-61.943283 -> V=1.0, theta=0.0
% INFO    : Bus 77941	: V=0.9913991, theta=-61.659697 -> V=1.0, theta=0.0
% INFO    : Bus 77942	: V=0.9881186, theta=-61.780018 -> V=1.0, theta=0.0
% INFO    : Bus 77943	: V=0.9851405, theta=-62.195462 -> V=1.0, theta=0.0
% INFO    : Bus 77944	: V=0.9837758, theta=-62.380905 -> V=1.0, theta=0.0
% INFO    : Bus 77945	: V=0.981581, theta=-62.400753 -> V=1.0, theta=0.0
% INFO    : Bus 77946	: V=0.9815393, theta=-62.351636 -> V=1.0, theta=0.0
% INFO    : Bus 77947	: V=0.9798716, theta=-62.425007 -> V=1.0, theta=0.0
% INFO    : Bus 77948	: V=0.987273, theta=-61.615628 -> V=1.0, theta=0.0
% INFO    : Bus 77949	: V=0.9879782, theta=-61.642838 -> V=1.0, theta=0.0
% INFO    : Bus 77950	: V=0.9869758, theta=-61.643667 -> V=1.0, theta=0.0
% INFO    : Bus 77951	: V=0.9880725, theta=-61.639885 -> V=1.0, theta=0.0
% INFO    : Bus 77952	: V=0.9815642, theta=-62.146258 -> V=1.0, theta=0.0
% INFO    : Bus 77953	: V=0.9869272, theta=-61.732544 -> V=1.0, theta=0.0
% INFO    : Bus 77954	: V=0.9866314, theta=-61.839675 -> V=1.0, theta=0.0
% INFO    : Bus 77955	: V=0.9878692, theta=-63.174211 -> V=1.0, theta=0.0
% INFO    : Bus 77956	: V=0.9864104, theta=-63.002478 -> V=1.0, theta=0.0
% INFO    : Bus 77957	: V=0.9838636, theta=-62.894722 -> V=1.0, theta=0.0
% INFO    : Bus 77958	: V=0.9826549, theta=-62.863084 -> V=1.0, theta=0.0
% INFO    : Bus 77959	: V=0.983249, theta=-62.874645 -> V=1.0, theta=0.0
% INFO    : Bus 77960	: V=0.982138, theta=-62.722083 -> V=1.0, theta=0.0
% INFO    : Bus 77961	: V=0.9825139, theta=-62.706309 -> V=1.0, theta=0.0
% INFO    : Bus 77962	: V=0.9814606, theta=-62.717185 -> V=1.0, theta=0.0
% INFO    : Bus 77963	: V=0.9896974, theta=-63.225368 -> V=1.0, theta=0.0
% INFO    : Bus 77964	: V=0.986307, theta=-63.035823 -> V=1.0, theta=0.0
% INFO    : Bus 77965	: V=0.9818164, theta=-62.88597 -> V=1.0, theta=0.0
% INFO    : Bus 77966	: V=0.9783401, theta=-62.644471 -> V=1.0, theta=0.0
% INFO    : Bus 77967	: V=0.9787281, theta=-62.645364 -> V=1.0, theta=0.0
% INFO    : Bus 77968	: V=0.9777934, theta=-62.584873 -> V=1.0, theta=0.0
% INFO    : Bus 77969	: V=0.978592, theta=-62.507069 -> V=1.0, theta=0.0
% INFO    : Bus 77970	: V=0.9800433, theta=-62.408234 -> V=1.0, theta=0.0
% INFO    : Bus 77971	: V=0.9797531, theta=-62.405124 -> V=1.0, theta=0.0
% INFO    : Bus 77972	: V=0.9799811, theta=-62.11968 -> V=1.0, theta=0.0
% INFO    : Bus 77973	: V=0.9819249, theta=-62.117377 -> V=1.0, theta=0.0
% INFO    : Bus 77974	: V=0.9782076, theta=-62.624022 -> V=1.0, theta=0.0
% INFO    : Bus 77975	: V=0.9787926, theta=-62.5432 -> V=1.0, theta=0.0
% INFO    : Bus 77976	: V=0.9795928, theta=-62.769325 -> V=1.0, theta=0.0
% INFO    : Bus 77977	: V=0.983333, theta=-62.838808 -> V=1.0, theta=0.0
% INFO    : Bus 77978	: V=1.001319, theta=-61.041133 -> V=1.0, theta=0.0
% INFO    : Bus 77979	: V=0.9898963, theta=-62.510335 -> V=1.0, theta=0.0
% INFO    : Bus 77980	: V=0.9892921, theta=-62.618014 -> V=1.0, theta=0.0
% INFO    : Bus 77981	: V=0.9824246, theta=-62.881048 -> V=1.0, theta=0.0
% INFO    : Bus 77982	: V=0.9827839, theta=-62.643988 -> V=1.0, theta=0.0
% INFO    : Bus 77983	: V=0.9904501, theta=-62.198077 -> V=1.0, theta=0.0
% INFO    : Bus 77984	: V=0.9885586, theta=-62.402736 -> V=1.0, theta=0.0
% INFO    : Bus 77985	: V=0.9849798, theta=-62.199391 -> V=1.0, theta=0.0
% INFO    : Bus 77986	: V=0.9879594, theta=-61.779711 -> V=1.0, theta=0.0
% INFO    : Bus 77987	: V=1.0068627, theta=-60.222198 -> V=1.0, theta=0.0
% INFO    : Bus 77988	: V=1.0015731, theta=-60.737681 -> V=1.0, theta=0.0
% INFO    : Bus 77989	: V=0.9880215, theta=-60.117699 -> V=1.0, theta=0.0
% INFO    : Bus 77990	: V=0.9952777, theta=-59.609846 -> V=1.0, theta=0.0
% INFO    : Bus 77991	: V=0.9928774, theta=-59.688643 -> V=1.0, theta=0.0
% INFO    : Bus 77992	: V=1.0011113, theta=-59.035243 -> V=1.0, theta=0.0
% INFO    : Bus 77993	: V=0.9731915, theta=-60.280183 -> V=1.0, theta=0.0
% INFO    : Bus 77994	: V=0.986125, theta=-60.123534 -> V=1.0, theta=0.0
% INFO    : Bus 77995	: V=0.9866882, theta=-60.392684 -> V=1.0, theta=0.0
% INFO    : Bus 77996	: V=0.9776137, theta=-60.049932 -> V=1.0, theta=0.0
% INFO    : Bus 77997	: V=0.9770382, theta=-60.141439 -> V=1.0, theta=0.0
% INFO    : Bus 77998	: V=0.9832841, theta=-59.955281 -> V=1.0, theta=0.0
% INFO    : Bus 77999	: V=0.9697579, theta=-60.070765 -> V=1.0, theta=0.0
% INFO    : Bus 78000	: V=0.9640664, theta=-60.322289 -> V=1.0, theta=0.0
% INFO    : Bus 78001	: V=0.9731234, theta=-59.361781 -> V=1.0, theta=0.0
% INFO    : Bus 78002	: V=0.9739648, theta=-59.919838 -> V=1.0, theta=0.0
% INFO    : Bus 78003	: V=0.9753393, theta=-58.361289 -> V=1.0, theta=0.0
% INFO    : Bus 78004	: V=0.9726009, theta=-58.676221 -> V=1.0, theta=0.0
% INFO    : Bus 78005	: V=0.9669639, theta=-59.416449 -> V=1.0, theta=0.0
% INFO    : Bus 78006	: V=0.9855366, theta=-56.739052 -> V=1.0, theta=0.0
% INFO    : Bus 78007	: V=1.0016574, theta=-57.694072 -> V=1.0, theta=0.0
% INFO    : Bus 78008	: V=1.0011646, theta=-57.707218 -> V=1.0, theta=0.0
% INFO    : Bus 78009	: V=0.9921436, theta=-63.56 -> V=1.0, theta=0.0
% INFO    : Bus 78010	: V=0.9917737, theta=-62.735289 -> V=1.0, theta=0.0
% INFO    : Bus 78011	: V=0.9953827, theta=-62.154982 -> V=1.0, theta=0.0
% INFO    : Bus 78012	: V=1.0001215, theta=-61.668392 -> V=1.0, theta=0.0
% INFO    : Bus 78013	: V=0.998777, theta=-61.7874 -> V=1.0, theta=0.0
% INFO    : Bus 78014	: V=0.997306, theta=-61.971321 -> V=1.0, theta=0.0
% INFO    : Bus 78015	: V=0.9971939, theta=-61.818964 -> V=1.0, theta=0.0
% INFO    : Bus 78016	: V=1.0002346, theta=-61.637705 -> V=1.0, theta=0.0
% INFO    : Bus 78017	: V=0.9990439, theta=-61.827146 -> V=1.0, theta=0.0
% INFO    : Bus 78018	: V=0.9933002, theta=-62.268746 -> V=1.0, theta=0.0
% INFO    : Bus 78019	: V=0.9933471, theta=-62.286866 -> V=1.0, theta=0.0
% INFO    : Bus 78020	: V=0.9930211, theta=-62.273351 -> V=1.0, theta=0.0
% INFO    : Bus 78021	: V=0.9911168, theta=-62.232254 -> V=1.0, theta=0.0
% INFO    : Bus 78022	: V=0.99965, theta=-61.705936 -> V=1.0, theta=0.0
% INFO    : Bus 78023	: V=0.9915489, theta=-62.227161 -> V=1.0, theta=0.0
% INFO    : Bus 78024	: V=0.9906591, theta=-62.194054 -> V=1.0, theta=0.0
% INFO    : Bus 78025	: V=0.9926404, theta=-62.108338 -> V=1.0, theta=0.0
% INFO    : Bus 78026	: V=0.9910494, theta=-62.168753 -> V=1.0, theta=0.0
% INFO    : Bus 78027	: V=0.9929407, theta=-62.06712 -> V=1.0, theta=0.0
% INFO    : Bus 78028	: V=0.9880975, theta=-62.365892 -> V=1.0, theta=0.0
% INFO    : Bus 78029	: V=0.9910056, theta=-63.059913 -> V=1.0, theta=0.0
% INFO    : Bus 78030	: V=0.9973015, theta=-62.591829 -> V=1.0, theta=0.0
% INFO    : Bus 78031	: V=0.9929258, theta=-62.370522 -> V=1.0, theta=0.0
% INFO    : Bus 78032	: V=0.9902158, theta=-62.853155 -> V=1.0, theta=0.0
% INFO    : Bus 78033	: V=0.992689, theta=-62.015397 -> V=1.0, theta=0.0
% INFO    : Bus 78034	: V=0.9912538, theta=-62.06192 -> V=1.0, theta=0.0
% INFO    : Bus 78035	: V=0.9933812, theta=-61.919014 -> V=1.0, theta=0.0
% INFO    : Bus 78036	: V=0.9983521, theta=-61.464204 -> V=1.0, theta=0.0
% INFO    : Bus 78037	: V=0.9972779, theta=-61.555653 -> V=1.0, theta=0.0
% INFO    : Bus 78038	: V=0.992093, theta=-61.773343 -> V=1.0, theta=0.0
% INFO    : Bus 78039	: V=0.9945997, theta=-61.67366 -> V=1.0, theta=0.0
% INFO    : Bus 78040	: V=0.9963479, theta=-61.609245 -> V=1.0, theta=0.0
% INFO    : Bus 78041	: V=0.9861427, theta=-62.143213 -> V=1.0, theta=0.0
% INFO    : Bus 78042	: V=0.9879194, theta=-62.150369 -> V=1.0, theta=0.0
% INFO    : Bus 78043	: V=0.9906528, theta=-61.904889 -> V=1.0, theta=0.0
% INFO    : Bus 78044	: V=0.9916112, theta=-61.760913 -> V=1.0, theta=0.0
% INFO    : Bus 78045	: V=0.9909495, theta=-63.844021 -> V=1.0, theta=0.0
% INFO    : Bus 78046	: V=0.9914453, theta=-64.206635 -> V=1.0, theta=0.0
% INFO    : Bus 78047	: V=0.9906901, theta=-63.846116 -> V=1.0, theta=0.0
% INFO    : Bus 78048	: V=0.9904973, theta=-63.794166 -> V=1.0, theta=0.0
% INFO    : Bus 78049	: V=0.9951829, theta=-63.049527 -> V=1.0, theta=0.0
% INFO    : Bus 78050	: V=0.9908417, theta=-63.830412 -> V=1.0, theta=0.0
% INFO    : Bus 78051	: V=0.9918106, theta=-63.945094 -> V=1.0, theta=0.0
% INFO    : Bus 78052	: V=0.9911217, theta=-63.774819 -> V=1.0, theta=0.0
% INFO    : Bus 78053	: V=0.9913589, theta=-63.717559 -> V=1.0, theta=0.0
% INFO    : Bus 78054	: V=0.9919676, theta=-63.826845 -> V=1.0, theta=0.0
% INFO    : Bus 78055	: V=0.9921023, theta=-63.711848 -> V=1.0, theta=0.0
% INFO    : Bus 78056	: V=0.9921468, theta=-63.710716 -> V=1.0, theta=0.0
% INFO    : Bus 78057	: V=0.990193, theta=-64.246469 -> V=1.0, theta=0.0
% INFO    : Bus 78058	: V=0.9915475, theta=-64.003823 -> V=1.0, theta=0.0
% INFO    : Bus 78059	: V=0.9922268, theta=-63.896697 -> V=1.0, theta=0.0
% INFO    : Bus 78060	: V=0.9918134, theta=-63.934028 -> V=1.0, theta=0.0
% INFO    : Bus 78061	: V=0.994714, theta=-63.05525 -> V=1.0, theta=0.0
% INFO    : Bus 78062	: V=0.9938118, theta=-63.24146 -> V=1.0, theta=0.0
% INFO    : Bus 78063	: V=0.9915949, theta=-62.79202 -> V=1.0, theta=0.0
% INFO    : Bus 78064	: V=0.9947801, theta=-63.043644 -> V=1.0, theta=0.0
% INFO    : Bus 78065	: V=0.9911306, theta=-63.947046 -> V=1.0, theta=0.0
% INFO    : Bus 78066	: V=0.9915736, theta=-62.821853 -> V=1.0, theta=0.0
% INFO    : Bus 78067	: V=0.9923742, theta=-63.4283 -> V=1.0, theta=0.0
% INFO    : Bus 78068	: V=0.9906731, theta=-63.850115 -> V=1.0, theta=0.0
% INFO    : Bus 78069	: V=0.9920745, theta=-60.935312 -> V=1.0, theta=0.0
% INFO    : Bus 78070	: V=0.9907171, theta=-60.921049 -> V=1.0, theta=0.0
% INFO    : Bus 78071	: V=0.9918053, theta=-60.842883 -> V=1.0, theta=0.0
% INFO    : Bus 78072	: V=0.9790717, theta=-61.999746 -> V=1.0, theta=0.0
% INFO    : Bus 78073	: V=0.9801737, theta=-61.936402 -> V=1.0, theta=0.0
% INFO    : Bus 78074	: V=0.9762896, theta=-61.988849 -> V=1.0, theta=0.0
% INFO    : Bus 78075	: V=0.9810148, theta=-62.154747 -> V=1.0, theta=0.0
% INFO    : Bus 78076	: V=0.9767886, theta=-62.555215 -> V=1.0, theta=0.0
% INFO    : Bus 78077	: V=1.0017514, theta=-60.465489 -> V=1.0, theta=0.0
% INFO    : Bus 78078	: V=0.9993844, theta=-60.564419 -> V=1.0, theta=0.0
% INFO    : Bus 78079	: V=0.9970314, theta=-60.693726 -> V=1.0, theta=0.0
% INFO    : Bus 78080	: V=0.9937156, theta=-60.845179 -> V=1.0, theta=0.0
% INFO    : Bus 78081	: V=0.992476, theta=-61.315197 -> V=1.0, theta=0.0
% INFO    : Bus 78082	: V=0.9907967, theta=-61.344431 -> V=1.0, theta=0.0
% INFO    : Bus 78083	: V=0.9900226, theta=-61.415115 -> V=1.0, theta=0.0
% INFO    : Bus 78084	: V=0.9936392, theta=-60.834512 -> V=1.0, theta=0.0
% INFO    : Bus 78085	: V=0.9864044, theta=-61.508138 -> V=1.0, theta=0.0
% INFO    : Bus 78086	: V=0.9957332, theta=-60.719975 -> V=1.0, theta=0.0
% INFO    : Bus 78087	: V=0.9939853, theta=-60.82509 -> V=1.0, theta=0.0
% INFO    : Bus 78088	: V=0.9930514, theta=-60.852 -> V=1.0, theta=0.0
% INFO    : Bus 78089	: V=0.9919172, theta=-60.45297 -> V=1.0, theta=0.0
% INFO    : Bus 78090	: V=1.0064797, theta=-59.516083 -> V=1.0, theta=0.0
% INFO    : Bus 78091	: V=0.9930796, theta=-60.799067 -> V=1.0, theta=0.0
% INFO    : Bus 78092	: V=0.9911826, theta=-61.01429 -> V=1.0, theta=0.0
% INFO    : Bus 78093	: V=0.982899, theta=-61.66314 -> V=1.0, theta=0.0
% INFO    : Bus 78094	: V=0.9838095, theta=-61.944027 -> V=1.0, theta=0.0
% INFO    : Bus 78095	: V=0.9841561, theta=-61.990133 -> V=1.0, theta=0.0
% INFO    : Bus 78096	: V=0.9827983, theta=-62.081491 -> V=1.0, theta=0.0
% INFO    : Bus 78097	: V=0.9819477, theta=-62.210711 -> V=1.0, theta=0.0
% INFO    : Bus 78098	: V=0.9764921, theta=-62.020562 -> V=1.0, theta=0.0
% INFO    : Bus 78099	: V=0.978162, theta=-62.000348 -> V=1.0, theta=0.0
% INFO    : Bus 78100	: V=0.9812826, theta=-61.719512 -> V=1.0, theta=0.0
% INFO    : Bus 78101	: V=0.9937827, theta=-60.278814 -> V=1.0, theta=0.0
% INFO    : Bus 78102	: V=0.9924939, theta=-60.321729 -> V=1.0, theta=0.0
% INFO    : Bus 78103	: V=0.9814301, theta=-61.594927 -> V=1.0, theta=0.0
% INFO    : Bus 78104	: V=1.003932, theta=-59.802023 -> V=1.0, theta=0.0
% INFO    : Bus 78105	: V=0.9919929, theta=-60.687306 -> V=1.0, theta=0.0
% INFO    : Bus 78106	: V=0.9889265, theta=-60.846091 -> V=1.0, theta=0.0
% INFO    : Bus 78107	: V=0.9753284, theta=-61.747041 -> V=1.0, theta=0.0
% INFO    : Bus 78108	: V=0.9879357, theta=-60.955149 -> V=1.0, theta=0.0
% INFO    : Bus 78109	: V=0.9929909, theta=-60.211767 -> V=1.0, theta=0.0
% INFO    : Bus 78110	: V=0.990541, theta=-60.76481 -> V=1.0, theta=0.0
% INFO    : Bus 78111	: V=0.9948158, theta=-60.274665 -> V=1.0, theta=0.0
% INFO    : Bus 78112	: V=0.9916883, theta=-60.34511 -> V=1.0, theta=0.0
% INFO    : Bus 78113	: V=0.9884943, theta=-60.685961 -> V=1.0, theta=0.0
% INFO    : Bus 78114	: V=0.9928068, theta=-60.209229 -> V=1.0, theta=0.0
% INFO    : Bus 78115	: V=0.9973921, theta=-60.100116 -> V=1.0, theta=0.0
% INFO    : Bus 78116	: V=0.9986947, theta=-60.022205 -> V=1.0, theta=0.0
% INFO    : Bus 78117	: V=1.0001504, theta=-59.980907 -> V=1.0, theta=0.0
% INFO    : Bus 78118	: V=0.9929772, theta=-60.321056 -> V=1.0, theta=0.0
% INFO    : Bus 78119	: V=0.9927223, theta=-60.378202 -> V=1.0, theta=0.0
% INFO    : Bus 78120	: V=0.9961554, theta=-60.155448 -> V=1.0, theta=0.0
% INFO    : Bus 78121	: V=0.9944019, theta=-60.469633 -> V=1.0, theta=0.0
% INFO    : Bus 78122	: V=0.9963204, theta=-60.339963 -> V=1.0, theta=0.0
% INFO    : Bus 78123	: V=0.9948997, theta=-60.530658 -> V=1.0, theta=0.0
% INFO    : Bus 78124	: V=0.9956417, theta=-60.466821 -> V=1.0, theta=0.0
% INFO    : Bus 78125	: V=0.9973346, theta=-60.303246 -> V=1.0, theta=0.0
% INFO    : Bus 78126	: V=1.0027891, theta=-59.853935 -> V=1.0, theta=0.0
% INFO    : Bus 78127	: V=1.0011741, theta=-60.130769 -> V=1.0, theta=0.0
% INFO    : Bus 78128	: V=0.9990077, theta=-60.687275 -> V=1.0, theta=0.0
% INFO    : Bus 78129	: V=0.9961121, theta=-60.578207 -> V=1.0, theta=0.0
% INFO    : Bus 78130	: V=1.0025388, theta=-60.321878 -> V=1.0, theta=0.0
% INFO    : Bus 78131	: V=1.006446, theta=-59.514036 -> V=1.0, theta=0.0
% INFO    : Bus 78132	: V=1.0090623, theta=-59.404121 -> V=1.0, theta=0.0
% INFO    : Bus 78133	: V=1.0078731, theta=-59.512284 -> V=1.0, theta=0.0
% INFO    : Bus 78134	: V=1.0063335, theta=-59.517196 -> V=1.0, theta=0.0
% INFO    : Bus 78135	: V=1.0062631, theta=-59.481923 -> V=1.0, theta=0.0
% INFO    : Bus 78136	: V=1.006369, theta=-59.479483 -> V=1.0, theta=0.0
% INFO    : Bus 78137	: V=0.9851182, theta=-60.859895 -> V=1.0, theta=0.0
% INFO    : Bus 78138	: V=0.9909087, theta=-60.247244 -> V=1.0, theta=0.0
% INFO    : Bus 78139	: V=0.9877364, theta=-60.694538 -> V=1.0, theta=0.0
% INFO    : Bus 78140	: V=0.9863355, theta=-60.747266 -> V=1.0, theta=0.0
% INFO    : Bus 78141	: V=0.9941238, theta=-60.136314 -> V=1.0, theta=0.0
% INFO    : Bus 78142	: V=0.987023, theta=-60.735308 -> V=1.0, theta=0.0
% INFO    : Bus 78143	: V=0.9822769, theta=-61.182715 -> V=1.0, theta=0.0
% INFO    : Bus 78144	: V=0.9864819, theta=-60.873423 -> V=1.0, theta=0.0
% INFO    : Bus 78145	: V=0.9806158, theta=-61.175411 -> V=1.0, theta=0.0
% INFO    : Bus 78146	: V=0.9887941, theta=-60.466804 -> V=1.0, theta=0.0
% INFO    : Bus 78147	: V=0.9844059, theta=-60.927382 -> V=1.0, theta=0.0
% INFO    : Bus 78148	: V=0.9896126, theta=-60.472654 -> V=1.0, theta=0.0
% INFO    : Bus 78149	: V=0.9979409, theta=-59.928968 -> V=1.0, theta=0.0
% INFO    : Bus 78150	: V=1.0038774, theta=-59.528412 -> V=1.0, theta=0.0
% INFO    : Bus 78151	: V=1.0032263, theta=-59.512193 -> V=1.0, theta=0.0
% INFO    : Bus 78152	: V=0.9977523, theta=-59.55305 -> V=1.0, theta=0.0
% INFO    : Bus 78153	: V=0.9973303, theta=-59.732329 -> V=1.0, theta=0.0
% INFO    : Bus 78154	: V=0.9955948, theta=-59.77479 -> V=1.0, theta=0.0
% INFO    : Bus 78155	: V=0.9900768, theta=-60.387172 -> V=1.0, theta=0.0
% INFO    : Bus 78156	: V=0.9904929, theta=-60.340185 -> V=1.0, theta=0.0
% INFO    : Bus 78157	: V=0.9890062, theta=-60.484464 -> V=1.0, theta=0.0
% INFO    : Bus 78158	: V=0.9848415, theta=-60.831173 -> V=1.0, theta=0.0
% INFO    : Bus 78159	: V=0.9788671, theta=-61.63279 -> V=1.0, theta=0.0
% INFO    : Bus 78160	: V=0.9858444, theta=-60.914688 -> V=1.0, theta=0.0
% INFO    : Bus 78161	: V=0.9858934, theta=-60.925587 -> V=1.0, theta=0.0
% INFO    : Bus 78162	: V=0.9850101, theta=-61.045239 -> V=1.0, theta=0.0
% INFO    : Bus 78163	: V=0.9874292, theta=-60.947118 -> V=1.0, theta=0.0
% INFO    : Bus 78164	: V=0.987807, theta=-60.924962 -> V=1.0, theta=0.0
% INFO    : Bus 78165	: V=1.006238, theta=-59.162773 -> V=1.0, theta=0.0
% INFO    : Bus 78166	: V=1.0021106, theta=-59.526314 -> V=1.0, theta=0.0
% INFO    : Bus 78167	: V=0.9881815, theta=-60.765946 -> V=1.0, theta=0.0
% INFO    : Bus 78168	: V=1.0066841, theta=-59.310924 -> V=1.0, theta=0.0
% INFO    : Bus 78169	: V=1.0067582, theta=-59.203618 -> V=1.0, theta=0.0
% INFO    : Bus 78170	: V=0.9976963, theta=-60.398856 -> V=1.0, theta=0.0
% INFO    : Bus 78171	: V=1.0127137, theta=-59.448429 -> V=1.0, theta=0.0
% INFO    : Bus 78172	: V=0.9735783, theta=-60.689537 -> V=1.0, theta=0.0
% INFO    : Bus 78173	: V=0.9823012, theta=-60.409845 -> V=1.0, theta=0.0
% INFO    : Bus 78174	: V=0.9768351, theta=-60.689884 -> V=1.0, theta=0.0
% INFO    : Bus 78175	: V=0.9860727, theta=-60.232362 -> V=1.0, theta=0.0
% INFO    : Bus 78176	: V=0.9860811, theta=-60.216567 -> V=1.0, theta=0.0
% INFO    : Bus 78177	: V=0.9839245, theta=-60.216968 -> V=1.0, theta=0.0
% INFO    : Bus 78178	: V=0.9794153, theta=-60.235345 -> V=1.0, theta=0.0
% INFO    : Bus 78179	: V=0.9761625, theta=-60.374315 -> V=1.0, theta=0.0
% INFO    : Bus 78180	: V=0.9814036, theta=-59.49285 -> V=1.0, theta=0.0
% INFO    : Bus 78181	: V=0.9668533, theta=-60.397372 -> V=1.0, theta=0.0
% INFO    : Bus 78182	: V=0.9683752, theta=-60.232761 -> V=1.0, theta=0.0
% INFO    : Bus 78183	: V=0.9769692, theta=-59.48718 -> V=1.0, theta=0.0
% INFO    : Bus 78184	: V=0.9783772, theta=-59.554145 -> V=1.0, theta=0.0
% INFO    : Bus 78185	: V=0.977774, theta=-59.44502 -> V=1.0, theta=0.0
% INFO    : Bus 78186	: V=0.981075, theta=-59.486982 -> V=1.0, theta=0.0
% INFO    : Bus 78187	: V=0.9782083, theta=-59.071828 -> V=1.0, theta=0.0
% INFO    : Bus 78188	: V=0.9795966, theta=-59.14249 -> V=1.0, theta=0.0
% INFO    : Bus 78189	: V=0.983768, theta=-59.218487 -> V=1.0, theta=0.0
% INFO    : Bus 78190	: V=0.9806258, theta=-58.887476 -> V=1.0, theta=0.0
% INFO    : Bus 78191	: V=0.9806149, theta=-58.8277 -> V=1.0, theta=0.0
% INFO    : Bus 78192	: V=0.9822956, theta=-58.655579 -> V=1.0, theta=0.0
% INFO    : Bus 78193	: V=0.9855461, theta=-58.556981 -> V=1.0, theta=0.0
% INFO    : Bus 78194	: V=0.988683, theta=-58.516855 -> V=1.0, theta=0.0
% INFO    : Bus 78195	: V=0.9914065, theta=-58.314687 -> V=1.0, theta=0.0
% INFO    : Bus 78196	: V=0.9863209, theta=-58.227231 -> V=1.0, theta=0.0
% INFO    : Bus 78197	: V=0.9853057, theta=-58.510628 -> V=1.0, theta=0.0
% INFO    : Bus 78198	: V=0.9867567, theta=-58.147316 -> V=1.0, theta=0.0
% INFO    : Bus 78199	: V=0.9844547, theta=-60.2307 -> V=1.0, theta=0.0
% INFO    : Bus 78200	: V=0.9805208, theta=-59.58461 -> V=1.0, theta=0.0
% INFO    : Bus 78201	: V=0.9853381, theta=-60.432083 -> V=1.0, theta=0.0
% INFO    : Bus 78202	: V=0.981564, theta=-60.485106 -> V=1.0, theta=0.0
% INFO    : Bus 78203	: V=0.9853205, theta=-60.379185 -> V=1.0, theta=0.0
% INFO    : Bus 78204	: V=0.9835028, theta=-60.478449 -> V=1.0, theta=0.0
% INFO    : Bus 78205	: V=0.9821253, theta=-60.205954 -> V=1.0, theta=0.0
% INFO    : Bus 78206	: V=0.9803763, theta=-60.189416 -> V=1.0, theta=0.0
% INFO    : Bus 78207	: V=0.9843436, theta=-59.468648 -> V=1.0, theta=0.0
% INFO    : Bus 78208	: V=0.9822757, theta=-59.957257 -> V=1.0, theta=0.0
% INFO    : Bus 78209	: V=0.9879281, theta=-59.142833 -> V=1.0, theta=0.0
% INFO    : Bus 78210	: V=0.9844098, theta=-59.453558 -> V=1.0, theta=0.0
% INFO    : Bus 78211	: V=0.9866676, theta=-59.16374 -> V=1.0, theta=0.0
% INFO    : Bus 78212	: V=0.9819082, theta=-59.47373 -> V=1.0, theta=0.0
% INFO    : Bus 78213	: V=0.9771632, theta=-60.24581 -> V=1.0, theta=0.0
% INFO    : Bus 78214	: V=0.9841462, theta=-63.75001 -> V=1.0, theta=0.0
% INFO    : Bus 78215	: V=0.9824274, theta=-64.080904 -> V=1.0, theta=0.0
% INFO    : Bus 78216	: V=0.9814446, theta=-63.158151 -> V=1.0, theta=0.0
% INFO    : Bus 78217	: V=0.9825029, theta=-63.595369 -> V=1.0, theta=0.0
% INFO    : Bus 78218	: V=0.9768624, theta=-62.838049 -> V=1.0, theta=0.0
% INFO    : Bus 78219	: V=0.981173, theta=-63.3378 -> V=1.0, theta=0.0
% INFO    : Bus 78220	: V=0.9803576, theta=-63.401636 -> V=1.0, theta=0.0
% INFO    : Bus 78221	: V=0.9784576, theta=-62.693844 -> V=1.0, theta=0.0
% INFO    : Bus 78222	: V=0.978257, theta=-62.713575 -> V=1.0, theta=0.0
% INFO    : Bus 78223	: V=0.9835004, theta=-62.176006 -> V=1.0, theta=0.0
% INFO    : Bus 78224	: V=0.9811484, theta=-62.273574 -> V=1.0, theta=0.0
% INFO    : Bus 78225	: V=0.9718302, theta=-62.968652 -> V=1.0, theta=0.0
% INFO    : Bus 78226	: V=0.9777661, theta=-62.590903 -> V=1.0, theta=0.0
% INFO    : Bus 78227	: V=0.9792837, theta=-62.568854 -> V=1.0, theta=0.0
% INFO    : Bus 78228	: V=0.979399, theta=-62.530576 -> V=1.0, theta=0.0
% INFO    : Bus 78229	: V=0.9768617, theta=-62.679485 -> V=1.0, theta=0.0
% INFO    : Bus 78230	: V=0.9778618, theta=-62.015371 -> V=1.0, theta=0.0
% INFO    : Bus 78231	: V=0.9760932, theta=-62.745763 -> V=1.0, theta=0.0
% INFO    : Bus 78232	: V=0.9753854, theta=-64.250516 -> V=1.0, theta=0.0
% INFO    : Bus 78233	: V=0.9766973, theta=-63.183898 -> V=1.0, theta=0.0
% INFO    : Bus 78234	: V=0.9789379, theta=-62.471032 -> V=1.0, theta=0.0
% INFO    : Bus 78235	: V=0.982642, theta=-62.195483 -> V=1.0, theta=0.0
% INFO    : Bus 78236	: V=0.9799402, theta=-62.447449 -> V=1.0, theta=0.0
% INFO    : Bus 78237	: V=0.9846321, theta=-62.011018 -> V=1.0, theta=0.0
% INFO    : Bus 78238	: V=0.9803667, theta=-62.606019 -> V=1.0, theta=0.0
% INFO    : Bus 78239	: V=0.9826585, theta=-62.314547 -> V=1.0, theta=0.0
% INFO    : Bus 78240	: V=0.9786875, theta=-62.343162 -> V=1.0, theta=0.0
% INFO    : Bus 78241	: V=0.9796151, theta=-62.442595 -> V=1.0, theta=0.0
% INFO    : Bus 78242	: V=0.9794616, theta=-62.452688 -> V=1.0, theta=0.0
% INFO    : Bus 78243	: V=0.980331, theta=-62.272103 -> V=1.0, theta=0.0
% INFO    : Bus 78244	: V=0.9964143, theta=-60.796013 -> V=1.0, theta=0.0
% INFO    : Bus 78245	: V=0.9970776, theta=-60.807984 -> V=1.0, theta=0.0
% INFO    : Bus 78246	: V=0.9934926, theta=-60.744965 -> V=1.0, theta=0.0
% INFO    : Bus 78247	: V=0.9871379, theta=-61.127962 -> V=1.0, theta=0.0
% INFO    : Bus 78248	: V=0.9795509, theta=-62.433657 -> V=1.0, theta=0.0
% INFO    : Bus 78249	: V=0.9908047, theta=-57.852003 -> V=1.0, theta=0.0
% INFO    : Bus 78250	: V=0.9897691, theta=-57.971124 -> V=1.0, theta=0.0
% INFO    : Bus 78251	: V=0.9964692, theta=-57.332872 -> V=1.0, theta=0.0
% INFO    : Bus 78252	: V=0.9928811, theta=-57.925952 -> V=1.0, theta=0.0
% INFO    : Bus 78253	: V=0.9942856, theta=-57.874122 -> V=1.0, theta=0.0
% INFO    : Bus 78254	: V=1.0019688, theta=-57.12478 -> V=1.0, theta=0.0
% INFO    : Bus 78255	: V=0.9993226, theta=-57.199226 -> V=1.0, theta=0.0
% INFO    : Bus 78256	: V=1.0022249, theta=-56.868765 -> V=1.0, theta=0.0
% INFO    : Bus 78257	: V=1.0008849, theta=-56.889227 -> V=1.0, theta=0.0
% INFO    : Bus 78258	: V=0.9923111, theta=-58.821529 -> V=1.0, theta=0.0
% INFO    : Bus 78259	: V=0.9937401, theta=-57.70928 -> V=1.0, theta=0.0
% INFO    : Bus 78260	: V=0.9850272, theta=-58.598171 -> V=1.0, theta=0.0
% INFO    : Bus 78261	: V=0.9904383, theta=-58.936675 -> V=1.0, theta=0.0
% INFO    : Bus 78262	: V=0.9827755, theta=-60.392114 -> V=1.0, theta=0.0
% INFO    : Bus 78263	: V=0.9858041, theta=-59.682507 -> V=1.0, theta=0.0
% INFO    : Bus 78264	: V=0.9843761, theta=-60.65322 -> V=1.0, theta=0.0
% INFO    : Bus 78265	: V=0.989382, theta=-58.314657 -> V=1.0, theta=0.0
% INFO    : Bus 78266	: V=0.9852394, theta=-58.15713 -> V=1.0, theta=0.0
% INFO    : Bus 78267	: V=0.9979508, theta=-57.812648 -> V=1.0, theta=0.0
% INFO    : Bus 78268	: V=1.0024334, theta=-56.692307 -> V=1.0, theta=0.0
% INFO    : Bus 78269	: V=1.0023636, theta=-56.849001 -> V=1.0, theta=0.0
% INFO    : Bus 78270	: V=1.0017902, theta=-56.757919 -> V=1.0, theta=0.0
% INFO    : Bus 78271	: V=0.9935262, theta=-57.133147 -> V=1.0, theta=0.0
% INFO    : Bus 78272	: V=0.9971368, theta=-56.811046 -> V=1.0, theta=0.0
% INFO    : Bus 78273	: V=0.9971728, theta=-57.049213 -> V=1.0, theta=0.0
% INFO    : Bus 78274	: V=0.9957306, theta=-56.847155 -> V=1.0, theta=0.0
% INFO    : Bus 78275	: V=1.0001006, theta=-56.530893 -> V=1.0, theta=0.0
% INFO    : Bus 78276	: V=1.0009235, theta=-56.354196 -> V=1.0, theta=0.0
% INFO    : Bus 78277	: V=1.0015946, theta=-56.383235 -> V=1.0, theta=0.0
% INFO    : Bus 78278	: V=1.0036178, theta=-56.158495 -> V=1.0, theta=0.0
% INFO    : Bus 78279	: V=1.0023226, theta=-56.179777 -> V=1.0, theta=0.0
% INFO    : Bus 78280	: V=0.9965073, theta=-57.714502 -> V=1.0, theta=0.0
% INFO    : Bus 78281	: V=0.9987389, theta=-56.55154 -> V=1.0, theta=0.0
% INFO    : Bus 78282	: V=1.0103788, theta=-55.38795 -> V=1.0, theta=0.0
% INFO    : Bus 78283	: V=1.0152414, theta=-54.626323 -> V=1.0, theta=0.0
% INFO    : Bus 78284	: V=1.0157146, theta=-54.50992 -> V=1.0, theta=0.0
% INFO    : Bus 78285	: V=0.9931059, theta=-54.724895 -> V=1.0, theta=0.0
% INFO    : Bus 78286	: V=0.9902835, theta=-63.602743 -> V=1.0, theta=0.0
% INFO    : Bus 78287	: V=0.9897112, theta=-63.484117 -> V=1.0, theta=0.0
% INFO    : Bus 78288	: V=0.986363, theta=-63.191637 -> V=1.0, theta=0.0
% INFO    : Bus 78289	: V=0.9896204, theta=-63.571849 -> V=1.0, theta=0.0
% INFO    : Bus 78290	: V=0.9913112, theta=-63.768882 -> V=1.0, theta=0.0
% INFO    : Bus 78291	: V=0.9904491, theta=-63.770784 -> V=1.0, theta=0.0
% INFO    : Bus 78292	: V=0.9875876, theta=-64.235152 -> V=1.0, theta=0.0
% INFO    : Bus 78293	: V=0.9902412, theta=-63.745328 -> V=1.0, theta=0.0
% INFO    : Bus 78294	: V=0.9901258, theta=-63.675589 -> V=1.0, theta=0.0
% INFO    : Bus 78295	: V=0.9887579, theta=-63.60586 -> V=1.0, theta=0.0
% INFO    : Bus 78296	: V=0.9889019, theta=-64.14296 -> V=1.0, theta=0.0
% INFO    : Bus 78297	: V=0.9881844, theta=-64.235653 -> V=1.0, theta=0.0
% INFO    : Bus 78298	: V=0.9913509, theta=-63.601066 -> V=1.0, theta=0.0
% INFO    : Bus 78299	: V=0.9907277, theta=-63.737713 -> V=1.0, theta=0.0
% INFO    : Bus 78300	: V=0.9897014, theta=-64.090789 -> V=1.0, theta=0.0
% INFO    : Bus 78301	: V=0.9891184, theta=-64.119262 -> V=1.0, theta=0.0
% INFO    : Bus 78302	: V=0.9826242, theta=-64.237425 -> V=1.0, theta=0.0
% INFO    : Bus 78303	: V=0.9798564, theta=-64.95852 -> V=1.0, theta=0.0
% INFO    : Bus 78304	: V=0.9989975, theta=-62.408006 -> V=1.0, theta=0.0
% INFO    : Bus 78305	: V=0.9927316, theta=-63.423071 -> V=1.0, theta=0.0
% INFO    : Bus 78306	: V=0.9907668, theta=-63.729867 -> V=1.0, theta=0.0
% INFO    : Bus 78307	: V=0.9830596, theta=-64.650458 -> V=1.0, theta=0.0
% INFO    : Bus 78308	: V=0.9888364, theta=-63.885683 -> V=1.0, theta=0.0
% INFO    : Bus 78309	: V=0.9842111, theta=-63.953547 -> V=1.0, theta=0.0
% INFO    : Bus 78310	: V=0.9842888, theta=-64.040399 -> V=1.0, theta=0.0
% INFO    : Bus 78311	: V=0.974283, theta=-65.694145 -> V=1.0, theta=0.0
% INFO    : Bus 78312	: V=0.99496, theta=-63.170433 -> V=1.0, theta=0.0
% INFO    : Bus 78313	: V=0.9930263, theta=-63.342402 -> V=1.0, theta=0.0
% INFO    : Bus 78314	: V=0.9964558, theta=-57.189837 -> V=1.0, theta=0.0
% INFO    : Bus 78315	: V=0.9923842, theta=-57.156879 -> V=1.0, theta=0.0
% INFO    : Bus 78316	: V=1.0099444, theta=-54.915903 -> V=1.0, theta=0.0
% INFO    : Bus 78317	: V=1.0075177, theta=-55.693029 -> V=1.0, theta=0.0
% INFO    : Bus 78318	: V=1.0086292, theta=-55.219513 -> V=1.0, theta=0.0
% INFO    : Bus 78319	: V=1.0096855, theta=-55.067798 -> V=1.0, theta=0.0
% INFO    : Bus 78320	: V=0.9709645, theta=-62.470367 -> V=1.0, theta=0.0
% INFO    : Bus 78321	: V=0.9716321, theta=-62.450091 -> V=1.0, theta=0.0
% INFO    : Bus 78322	: V=0.9742816, theta=-62.333693 -> V=1.0, theta=0.0
% INFO    : Bus 78323	: V=0.9720311, theta=-62.414774 -> V=1.0, theta=0.0
% INFO    : Bus 78324	: V=0.9746429, theta=-62.193778 -> V=1.0, theta=0.0
% INFO    : Bus 78325	: V=0.9775528, theta=-61.874864 -> V=1.0, theta=0.0
% INFO    : Bus 78326	: V=0.9785398, theta=-62.016595 -> V=1.0, theta=0.0
% INFO    : Bus 78327	: V=0.9819594, theta=-61.745636 -> V=1.0, theta=0.0
% INFO    : Bus 78328	: V=0.9830483, theta=-61.088382 -> V=1.0, theta=0.0
% INFO    : Bus 78329	: V=0.9686538, theta=-62.585911 -> V=1.0, theta=0.0
% INFO    : Bus 78330	: V=0.9686636, theta=-62.737019 -> V=1.0, theta=0.0
% INFO    : Bus 78331	: V=0.9746649, theta=-62.225652 -> V=1.0, theta=0.0
% INFO    : Bus 78332	: V=0.9729875, theta=-62.373086 -> V=1.0, theta=0.0
% INFO    : Bus 78333	: V=0.974758, theta=-61.925989 -> V=1.0, theta=0.0
% INFO    : Bus 78334	: V=0.9718718, theta=-62.395509 -> V=1.0, theta=0.0
% INFO    : Bus 78335	: V=0.9721677, theta=-62.378824 -> V=1.0, theta=0.0
% INFO    : Bus 78336	: V=0.9781645, theta=-62.0135 -> V=1.0, theta=0.0
% INFO    : Bus 78337	: V=0.9757432, theta=-62.137993 -> V=1.0, theta=0.0
% INFO    : Bus 78338	: V=0.9680392, theta=-67.548605 -> V=1.0, theta=0.0
% INFO    : Bus 78339	: V=0.9717297, theta=-66.36352 -> V=1.0, theta=0.0
% INFO    : Bus 78340	: V=0.9679204, theta=-67.529713 -> V=1.0, theta=0.0
% INFO    : Bus 78341	: V=0.9660845, theta=-67.447927 -> V=1.0, theta=0.0
% INFO    : Bus 78342	: V=0.9670462, theta=-66.247675 -> V=1.0, theta=0.0
% INFO    : Bus 78343	: V=0.9708326, theta=-66.265827 -> V=1.0, theta=0.0
% INFO    : Bus 78344	: V=0.9747008, theta=-65.253538 -> V=1.0, theta=0.0
% INFO    : Bus 78345	: V=0.9745977, theta=-64.267674 -> V=1.0, theta=0.0
% INFO    : Bus 78346	: V=0.9707463, theta=-65.610667 -> V=1.0, theta=0.0
% INFO    : Bus 78347	: V=0.9704583, theta=-65.215884 -> V=1.0, theta=0.0
% INFO    : Bus 78348	: V=0.9860574, theta=-62.320391 -> V=1.0, theta=0.0
% INFO    : Bus 78349	: V=0.9894042, theta=-61.545936 -> V=1.0, theta=0.0
% INFO    : Bus 78350	: V=0.9820387, theta=-62.749083 -> V=1.0, theta=0.0
% INFO    : Bus 78351	: V=0.9802325, theta=-62.624628 -> V=1.0, theta=0.0
% INFO    : Bus 78352	: V=0.9954341, theta=-61.296156 -> V=1.0, theta=0.0
% INFO    : Bus 78353	: V=0.9920945, theta=-61.214121 -> V=1.0, theta=0.0
% INFO    : Bus 78354	: V=0.9920536, theta=-61.337845 -> V=1.0, theta=0.0
% INFO    : Bus 78355	: V=0.9913404, theta=-61.414653 -> V=1.0, theta=0.0
% INFO    : Bus 78356	: V=0.9924741, theta=-61.281969 -> V=1.0, theta=0.0
% INFO    : Bus 78357	: V=0.989035, theta=-61.40758 -> V=1.0, theta=0.0
% INFO    : Bus 78358	: V=0.9860703, theta=-61.789054 -> V=1.0, theta=0.0
% INFO    : Bus 78359	: V=0.9888943, theta=-61.513493 -> V=1.0, theta=0.0
% INFO    : Bus 78360	: V=0.9794519, theta=-62.402031 -> V=1.0, theta=0.0
% INFO    : Bus 78361	: V=0.9808763, theta=-62.1138 -> V=1.0, theta=0.0
% INFO    : Bus 78362	: V=0.9816295, theta=-61.974884 -> V=1.0, theta=0.0
% INFO    : Bus 78363	: V=0.9854585, theta=-62.826727 -> V=1.0, theta=0.0
% INFO    : Bus 78364	: V=0.9915678, theta=-61.321744 -> V=1.0, theta=0.0
% INFO    : Bus 78365	: V=0.9882201, theta=-61.41772 -> V=1.0, theta=0.0
% INFO    : Bus 78366	: V=0.9962949, theta=-60.795829 -> V=1.0, theta=0.0
% INFO    : Bus 78367	: V=0.9898194, theta=-61.123575 -> V=1.0, theta=0.0
% INFO    : Bus 78368	: V=0.9925462, theta=-61.187805 -> V=1.0, theta=0.0
% INFO    : Bus 78369	: V=0.999031, theta=-60.631502 -> V=1.0, theta=0.0
% INFO    : Bus 78370	: V=1.0008413, theta=-60.373108 -> V=1.0, theta=0.0
% INFO    : Bus 78371	: V=1.0026936, theta=-60.340777 -> V=1.0, theta=0.0
% INFO    : Bus 78372	: V=0.9919465, theta=-60.877992 -> V=1.0, theta=0.0
% INFO    : Bus 78373	: V=0.997455, theta=-60.377906 -> V=1.0, theta=0.0
% INFO    : Bus 78374	: V=0.99529, theta=-60.527941 -> V=1.0, theta=0.0
% INFO    : Bus 78375	: V=0.9843246, theta=-61.541281 -> V=1.0, theta=0.0
% INFO    : Bus 78376	: V=0.9834337, theta=-61.680501 -> V=1.0, theta=0.0
% INFO    : Bus 78377	: V=0.9803897, theta=-62.04155 -> V=1.0, theta=0.0
% INFO    : Bus 78378	: V=0.9781967, theta=-62.225246 -> V=1.0, theta=0.0
% INFO    : Bus 78379	: V=0.9764654, theta=-62.259681 -> V=1.0, theta=0.0
% INFO    : Bus 78380	: V=0.9781156, theta=-62.144469 -> V=1.0, theta=0.0
% INFO    : Bus 78381	: V=0.97824, theta=-61.866796 -> V=1.0, theta=0.0
% INFO    : Bus 78382	: V=0.9795752, theta=-62.068907 -> V=1.0, theta=0.0
% INFO    : Bus 78383	: V=0.9795061, theta=-62.048125 -> V=1.0, theta=0.0
% INFO    : Bus 78384	: V=0.9836145, theta=-61.590092 -> V=1.0, theta=0.0
% INFO    : Bus 78385	: V=0.9875452, theta=-61.237133 -> V=1.0, theta=0.0
% INFO    : Bus 78386	: V=0.9828825, theta=-61.445158 -> V=1.0, theta=0.0
% INFO    : Bus 78387	: V=0.9826255, theta=-61.649449 -> V=1.0, theta=0.0
% INFO    : Bus 78388	: V=0.981976, theta=-61.441701 -> V=1.0, theta=0.0
% INFO    : Bus 78389	: V=0.9881631, theta=-61.174978 -> V=1.0, theta=0.0
% INFO    : Bus 78390	: V=0.9882113, theta=-61.163663 -> V=1.0, theta=0.0
% INFO    : Bus 78391	: V=0.9948295, theta=-61.352836 -> V=1.0, theta=0.0
% INFO    : Bus 78392	: V=0.9966723, theta=-61.430901 -> V=1.0, theta=0.0
% INFO    : Bus 78393	: V=0.998582, theta=-61.271381 -> V=1.0, theta=0.0
% INFO    : Bus 78394	: V=0.9707885, theta=-65.463977 -> V=1.0, theta=0.0
% INFO    : Bus 78395	: V=0.9890692, theta=-63.292004 -> V=1.0, theta=0.0
% INFO    : Bus 78396	: V=0.9984697, theta=-60.654992 -> V=1.0, theta=0.0
% INFO    : Bus 78397	: V=0.9985452, theta=-60.543307 -> V=1.0, theta=0.0
% INFO    : Bus 78398	: V=1.0012351, theta=-60.084018 -> V=1.0, theta=0.0
% INFO    : Bus 78399	: V=1.0098484, theta=-59.272895 -> V=1.0, theta=0.0
% INFO    : Bus 78400	: V=1.0155208, theta=-58.726238 -> V=1.0, theta=0.0
% INFO    : Bus 78401	: V=1.0078477, theta=-59.938974 -> V=1.0, theta=0.0
% INFO    : Bus 78402	: V=1.0018481, theta=-59.945707 -> V=1.0, theta=0.0
% INFO    : Bus 78403	: V=1.0097637, theta=-59.282615 -> V=1.0, theta=0.0
% INFO    : Bus 78404	: V=0.9979677, theta=-60.57085 -> V=1.0, theta=0.0
% INFO    : Bus 78405	: V=1.0002718, theta=-60.920174 -> V=1.0, theta=0.0
% INFO    : Bus 78406	: V=0.9988507, theta=-61.020804 -> V=1.0, theta=0.0
% INFO    : Bus 78407	: V=0.9880829, theta=-61.023643 -> V=1.0, theta=0.0
% INFO    : Bus 78408	: V=0.9912519, theta=-60.474333 -> V=1.0, theta=0.0
% INFO    : Bus 78409	: V=0.9904725, theta=-60.398451 -> V=1.0, theta=0.0
% INFO    : Bus 78410	: V=0.9891348, theta=-59.47435 -> V=1.0, theta=0.0
% INFO    : Bus 78411	: V=0.9791, theta=-60.25385 -> V=1.0, theta=0.0
% INFO    : Bus 78412	: V=0.9915729, theta=-59.603784 -> V=1.0, theta=0.0
% INFO    : Bus 78413	: V=0.9890498, theta=-59.39225 -> V=1.0, theta=0.0
% INFO    : Bus 78414	: V=0.9784393, theta=-61.762053 -> V=1.0, theta=0.0
% INFO    : Bus 78415	: V=0.9815147, theta=-61.249556 -> V=1.0, theta=0.0
% INFO    : Bus 78416	: V=0.989311, theta=-59.997443 -> V=1.0, theta=0.0
% INFO    : Bus 78417	: V=0.9819954, theta=-61.296321 -> V=1.0, theta=0.0
% INFO    : Bus 78418	: V=0.9664345, theta=-63.70409 -> V=1.0, theta=0.0
% INFO    : Bus 78419	: V=0.9672566, theta=-63.667663 -> V=1.0, theta=0.0
% INFO    : Bus 78420	: V=0.9677579, theta=-63.636626 -> V=1.0, theta=0.0
% INFO    : Bus 78421	: V=0.9668339, theta=-63.654044 -> V=1.0, theta=0.0
% INFO    : Bus 78422	: V=0.9686368, theta=-63.543566 -> V=1.0, theta=0.0
% INFO    : Bus 78423	: V=0.9645706, theta=-63.873385 -> V=1.0, theta=0.0
% INFO    : Bus 78424	: V=0.9686655, theta=-63.447849 -> V=1.0, theta=0.0
% INFO    : Bus 78425	: V=0.969296, theta=-63.42905 -> V=1.0, theta=0.0
% INFO    : Bus 78426	: V=0.9686912, theta=-63.468554 -> V=1.0, theta=0.0
% INFO    : Bus 78427	: V=0.960826, theta=-64.202439 -> V=1.0, theta=0.0
% INFO    : Bus 78428	: V=0.9608022, theta=-64.498193 -> V=1.0, theta=0.0
% INFO    : Bus 78429	: V=0.9622722, theta=-64.230639 -> V=1.0, theta=0.0
% INFO    : Bus 78430	: V=0.9656619, theta=-63.909975 -> V=1.0, theta=0.0
% INFO    : Bus 78431	: V=0.9644251, theta=-63.699684 -> V=1.0, theta=0.0
% INFO    : Bus 78432	: V=0.9748586, theta=-62.318164 -> V=1.0, theta=0.0
% INFO    : Bus 78433	: V=0.9650425, theta=-63.419333 -> V=1.0, theta=0.0
% INFO    : Bus 78434	: V=0.9769874, theta=-62.057076 -> V=1.0, theta=0.0
% INFO    : Bus 78435	: V=0.9743533, theta=-62.834235 -> V=1.0, theta=0.0
% INFO    : Bus 78436	: V=0.9736506, theta=-62.874784 -> V=1.0, theta=0.0
% INFO    : Bus 78437	: V=0.9769933, theta=-62.047773 -> V=1.0, theta=0.0
% INFO    : Bus 78438	: V=0.9768588, theta=-62.024537 -> V=1.0, theta=0.0
% INFO    : Bus 78439	: V=0.9760322, theta=-62.105457 -> V=1.0, theta=0.0
% INFO    : Bus 78440	: V=0.9775564, theta=-61.993717 -> V=1.0, theta=0.0
% INFO    : Bus 78441	: V=0.9667143, theta=-63.79667 -> V=1.0, theta=0.0
% INFO    : Bus 78442	: V=0.9930738, theta=-61.191733 -> V=1.0, theta=0.0
% INFO    : Bus 78443	: V=0.9912051, theta=-61.563692 -> V=1.0, theta=0.0
% INFO    : Bus 78444	: V=0.983556, theta=-62.610151 -> V=1.0, theta=0.0
% INFO    : Bus 78445	: V=0.9905003, theta=-61.829302 -> V=1.0, theta=0.0
% INFO    : Bus 78446	: V=0.9714602, theta=-63.340129 -> V=1.0, theta=0.0
% INFO    : Bus 78447	: V=0.9806799, theta=-61.753001 -> V=1.0, theta=0.0
% INFO    : Bus 78448	: V=0.9708201, theta=-62.899774 -> V=1.0, theta=0.0
% INFO    : Bus 78449	: V=0.9658613, theta=-63.773013 -> V=1.0, theta=0.0
% INFO    : Bus 78450	: V=0.9673713, theta=-64.344285 -> V=1.0, theta=0.0
% INFO    : Bus 78451	: V=1.0069231, theta=-59.695969 -> V=1.0, theta=0.0
% INFO    : Bus 78452	: V=0.9973988, theta=-61.06343 -> V=1.0, theta=0.0
% INFO    : Bus 78453	: V=0.9870957, theta=-61.80693 -> V=1.0, theta=0.0
% INFO    : Bus 78454	: V=0.9826856, theta=-62.376181 -> V=1.0, theta=0.0
% INFO    : Bus 78455	: V=0.9815697, theta=-61.850148 -> V=1.0, theta=0.0
% INFO    : Bus 78456	: V=0.9814133, theta=-62.150785 -> V=1.0, theta=0.0
% INFO    : Bus 78457	: V=0.9716034, theta=-62.834242 -> V=1.0, theta=0.0
% INFO    : Bus 78458	: V=0.9774257, theta=-62.40848 -> V=1.0, theta=0.0
% INFO    : Bus 78459	: V=0.9716997, theta=-63.069377 -> V=1.0, theta=0.0
% INFO    : Bus 78460	: V=0.9762936, theta=-62.096952 -> V=1.0, theta=0.0
% INFO    : Bus 78461	: V=0.9656017, theta=-63.980332 -> V=1.0, theta=0.0
% INFO    : Bus 78462	: V=0.9680229, theta=-63.366853 -> V=1.0, theta=0.0
% INFO    : Bus 78463	: V=0.9720757, theta=-62.869016 -> V=1.0, theta=0.0
% INFO    : Bus 78464	: V=0.9722629, theta=-62.736201 -> V=1.0, theta=0.0
% INFO    : Bus 78465	: V=0.9700228, theta=-63.386519 -> V=1.0, theta=0.0
% INFO    : Bus 78466	: V=0.9804325, theta=-61.402578 -> V=1.0, theta=0.0
% INFO    : Bus 78467	: V=0.9802932, theta=-61.430316 -> V=1.0, theta=0.0
% INFO    : Bus 78468	: V=0.9861527, theta=-60.59646 -> V=1.0, theta=0.0
% INFO    : Bus 78469	: V=0.9840972, theta=-61.129956 -> V=1.0, theta=0.0
% INFO    : Bus 78470	: V=0.9787144, theta=-61.907301 -> V=1.0, theta=0.0
% INFO    : Bus 78471	: V=0.9930626, theta=-59.327924 -> V=1.0, theta=0.0
% INFO    : Bus 78472	: V=0.9873601, theta=-60.296533 -> V=1.0, theta=0.0
% INFO    : Bus 78473	: V=0.9841885, theta=-60.953389 -> V=1.0, theta=0.0
% INFO    : Bus 78474	: V=0.9742288, theta=-60.13995 -> V=1.0, theta=0.0
% INFO    : Bus 78475	: V=0.9647706, theta=-62.66435 -> V=1.0, theta=0.0
% INFO    : Bus 78476	: V=0.9608639, theta=-62.661833 -> V=1.0, theta=0.0
% INFO    : Bus 78477	: V=1.0037566, theta=-57.35605 -> V=1.0, theta=0.0
% INFO    : Bus 78478	: V=0.9846363, theta=-60.727889 -> V=1.0, theta=0.0
% INFO    : Bus 78479	: V=0.9839387, theta=-60.852911 -> V=1.0, theta=0.0
% INFO    : Bus 78480	: V=0.9641824, theta=-63.260883 -> V=1.0, theta=0.0
% INFO    : Bus 78481	: V=0.9613921, theta=-63.566577 -> V=1.0, theta=0.0
% INFO    : Bus 78482	: V=0.9581271, theta=-63.826076 -> V=1.0, theta=0.0
% INFO    : Bus 78483	: V=0.9651642, theta=-62.370991 -> V=1.0, theta=0.0
% INFO    : Bus 78484	: V=0.968296, theta=-62.718647 -> V=1.0, theta=0.0
% INFO    : Bus 78485	: V=0.9628573, theta=-63.340656 -> V=1.0, theta=0.0
% INFO    : Bus 78486	: V=0.970974, theta=-62.66769 -> V=1.0, theta=0.0
% INFO    : Bus 78487	: V=0.9663023, theta=-63.006549 -> V=1.0, theta=0.0
% INFO    : Bus 78488	: V=0.9721041, theta=-62.048108 -> V=1.0, theta=0.0
% INFO    : Bus 78489	: V=0.9640279, theta=-63.286322 -> V=1.0, theta=0.0
% INFO    : Bus 78490	: V=0.9653719, theta=-63.232812 -> V=1.0, theta=0.0
% INFO    : Bus 78491	: V=0.9692429, theta=-62.930786 -> V=1.0, theta=0.0
% INFO    : Bus 78492	: V=0.9671695, theta=-63.802941 -> V=1.0, theta=0.0
% INFO    : Bus 78493	: V=0.978473, theta=-61.274329 -> V=1.0, theta=0.0
% INFO    : Bus 78494	: V=0.9769196, theta=-62.110725 -> V=1.0, theta=0.0
% INFO    : Bus 78495	: V=0.9711746, theta=-62.932047 -> V=1.0, theta=0.0
% INFO    : Bus 78496	: V=0.9776245, theta=-61.821283 -> V=1.0, theta=0.0
% INFO    : Bus 78497	: V=0.9746423, theta=-61.945767 -> V=1.0, theta=0.0
% INFO    : Bus 78498	: V=0.9792905, theta=-61.579549 -> V=1.0, theta=0.0
% INFO    : Bus 78499	: V=0.9951669, theta=-59.17777 -> V=1.0, theta=0.0
% INFO    : Bus 78500	: V=0.9726129, theta=-62.065491 -> V=1.0, theta=0.0
% INFO    : Bus 78501	: V=0.9739148, theta=-61.875169 -> V=1.0, theta=0.0
% INFO    : Bus 78502	: V=0.9704791, theta=-63.194102 -> V=1.0, theta=0.0
% INFO    : Bus 78503	: V=0.9664683, theta=-64.235815 -> V=1.0, theta=0.0
% INFO    : Bus 78504	: V=0.9672445, theta=-63.975839 -> V=1.0, theta=0.0
% INFO    : Bus 78505	: V=0.9655754, theta=-64.334033 -> V=1.0, theta=0.0
% INFO    : Bus 78506	: V=0.9723069, theta=-63.600366 -> V=1.0, theta=0.0
% INFO    : Bus 78507	: V=0.9646241, theta=-64.655423 -> V=1.0, theta=0.0
% INFO    : Bus 78508	: V=0.9740454, theta=-63.702902 -> V=1.0, theta=0.0
% INFO    : Bus 78509	: V=0.9748148, theta=-63.728363 -> V=1.0, theta=0.0
% INFO    : Bus 78510	: V=0.9811238, theta=-62.866957 -> V=1.0, theta=0.0
% INFO    : Bus 78511	: V=0.976719, theta=-63.691255 -> V=1.0, theta=0.0
% INFO    : Bus 78512	: V=0.9657291, theta=-63.627201 -> V=1.0, theta=0.0
% INFO    : Bus 78513	: V=0.9673296, theta=-63.141975 -> V=1.0, theta=0.0
% INFO    : Bus 78514	: V=0.9734786, theta=-62.419723 -> V=1.0, theta=0.0
% INFO    : Bus 78515	: V=0.9749649, theta=-62.373133 -> V=1.0, theta=0.0
% INFO    : Bus 78516	: V=0.9952558, theta=-58.614554 -> V=1.0, theta=0.0
% INFO    : Bus 78517	: V=0.9920518, theta=-59.655336 -> V=1.0, theta=0.0
% INFO    : Bus 78518	: V=0.9669282, theta=-63.713627 -> V=1.0, theta=0.0
% INFO    : Bus 78519	: V=1.0104775, theta=-65.975208 -> V=1.0, theta=0.0
% INFO    : Bus 78520	: V=1.0065002, theta=-61.720175 -> V=1.0, theta=0.0
% INFO    : Bus 78521	: V=1.0056981, theta=-61.369576 -> V=1.0, theta=0.0
% INFO    : Bus 78522	: V=0.9885382, theta=-62.935009 -> V=1.0, theta=0.0
% INFO    : Bus 78523	: V=0.9968464, theta=-60.727151 -> V=1.0, theta=0.0
% INFO    : Bus 78524	: V=1.0142163, theta=-58.426667 -> V=1.0, theta=0.0
% INFO    : Bus 78525	: V=1.0156391, theta=-58.298881 -> V=1.0, theta=0.0
% INFO    : Bus 78526	: V=1.0148021, theta=-58.089739 -> V=1.0, theta=0.0
% INFO    : Bus 78527	: V=1.0126689, theta=-58.540057 -> V=1.0, theta=0.0
% INFO    : Bus 78528	: V=0.989634, theta=-62.327514 -> V=1.0, theta=0.0
% INFO    : Bus 78529	: V=0.9727206, theta=-61.379246 -> V=1.0, theta=0.0
% INFO    : Bus 78530	: V=0.9768297, theta=-61.993839 -> V=1.0, theta=0.0
% INFO    : Bus 78531	: V=0.9818155, theta=-61.535691 -> V=1.0, theta=0.0
% INFO    : Bus 78532	: V=0.9829109, theta=-61.106613 -> V=1.0, theta=0.0
% INFO    : Bus 78533	: V=0.9914046, theta=-60.046964 -> V=1.0, theta=0.0
% INFO    : Bus 78534	: V=0.9981665, theta=-58.672319 -> V=1.0, theta=0.0
% INFO    : Bus 78535	: V=1.0020348, theta=-57.726562 -> V=1.0, theta=0.0
% INFO    : Bus 78536	: V=0.9986301, theta=-58.653341 -> V=1.0, theta=0.0
% INFO    : Bus 78537	: V=0.9939012, theta=-59.673015 -> V=1.0, theta=0.0
% INFO    : Bus 78538	: V=0.9929265, theta=-59.881875 -> V=1.0, theta=0.0
% INFO    : Bus 78539	: V=0.9871231, theta=-60.298448 -> V=1.0, theta=0.0
% INFO    : Bus 78540	: V=0.9901605, theta=-60.01319 -> V=1.0, theta=0.0
% INFO    : Bus 78541	: V=0.9841423, theta=-60.960107 -> V=1.0, theta=0.0
% INFO    : Bus 78542	: V=0.9913991, theta=-59.609137 -> V=1.0, theta=0.0
% INFO    : Bus 78543	: V=0.99584, theta=-58.83924 -> V=1.0, theta=0.0
% INFO    : Bus 78544	: V=0.9971379, theta=-58.81596 -> V=1.0, theta=0.0
% INFO    : Bus 78545	: V=0.9969619, theta=-58.795257 -> V=1.0, theta=0.0
% INFO    : Bus 78546	: V=0.9917511, theta=-59.568796 -> V=1.0, theta=0.0
% INFO    : Bus 78547	: V=0.9723756, theta=-64.092637 -> V=1.0, theta=0.0
% INFO    : Bus 78548	: V=0.9904288, theta=-60.128146 -> V=1.0, theta=0.0
% INFO    : Bus 78549	: V=1.0034839, theta=-57.620411 -> V=1.0, theta=0.0
% INFO    : Bus 78550	: V=1.0011913, theta=-58.349218 -> V=1.0, theta=0.0
% INFO    : Bus 78551	: V=0.9899195, theta=-60.171123 -> V=1.0, theta=0.0
% INFO    : Bus 78552	: V=0.9959975, theta=-58.97007 -> V=1.0, theta=0.0
% INFO    : Bus 78553	: V=0.9894899, theta=-61.43951 -> V=1.0, theta=0.0
% INFO    : Bus 78554	: V=0.9910837, theta=-60.925985 -> V=1.0, theta=0.0
% INFO    : Bus 78555	: V=0.9926279, theta=-63.886595 -> V=1.0, theta=0.0
% INFO    : Bus 78556	: V=0.9927272, theta=-63.827335 -> V=1.0, theta=0.0
% INFO    : Bus 78557	: V=0.9932439, theta=-63.833523 -> V=1.0, theta=0.0
% INFO    : Bus 78558	: V=0.9930919, theta=-63.96803 -> V=1.0, theta=0.0
% INFO    : Bus 78559	: V=0.9950701, theta=-63.800169 -> V=1.0, theta=0.0
% INFO    : Bus 78560	: V=0.9988525, theta=-62.989732 -> V=1.0, theta=0.0
% INFO    : Bus 78561	: V=0.9928484, theta=-63.760805 -> V=1.0, theta=0.0
% INFO    : Bus 78562	: V=0.998782, theta=-63.069674 -> V=1.0, theta=0.0
% INFO    : Bus 78563	: V=0.9996062, theta=-63.194414 -> V=1.0, theta=0.0
% INFO    : Bus 78564	: V=0.9917163, theta=-64.250255 -> V=1.0, theta=0.0
% INFO    : Bus 78565	: V=0.9999552, theta=-62.794453 -> V=1.0, theta=0.0
% INFO    : Bus 78566	: V=0.9993838, theta=-62.872788 -> V=1.0, theta=0.0
% INFO    : Bus 78567	: V=0.9904791, theta=-64.231476 -> V=1.0, theta=0.0
% INFO    : Bus 78568	: V=0.9920616, theta=-64.020111 -> V=1.0, theta=0.0
% INFO    : Bus 78569	: V=0.9918824, theta=-64.380814 -> V=1.0, theta=0.0
% INFO    : Bus 78570	: V=0.9822937, theta=-66.635365 -> V=1.0, theta=0.0
% INFO    : Bus 78571	: V=0.9635821, theta=-64.97047 -> V=1.0, theta=0.0
% INFO    : Bus 78572	: V=0.9919149, theta=-63.994278 -> V=1.0, theta=0.0
% INFO    : Bus 78573	: V=0.9927419, theta=-63.994047 -> V=1.0, theta=0.0
% INFO    : Bus 78574	: V=0.9948434, theta=-63.696106 -> V=1.0, theta=0.0
% INFO    : Bus 78575	: V=0.98235, theta=-65.782216 -> V=1.0, theta=0.0
% INFO    : Bus 78576	: V=0.9958688, theta=-63.637245 -> V=1.0, theta=0.0
% INFO    : Bus 78577	: V=0.9938758, theta=-63.721203 -> V=1.0, theta=0.0
% INFO    : Bus 78578	: V=0.990825, theta=-64.130034 -> V=1.0, theta=0.0
% INFO    : Bus 78579	: V=0.9961995, theta=-63.411555 -> V=1.0, theta=0.0
% INFO    : Bus 78580	: V=0.9796325, theta=-64.999533 -> V=1.0, theta=0.0
% INFO    : Bus 78581	: V=0.9859804, theta=-64.076761 -> V=1.0, theta=0.0
% INFO    : Bus 78582	: V=0.9898491, theta=-63.863592 -> V=1.0, theta=0.0
% INFO    : Bus 78583	: V=1.0042422, theta=-62.197869 -> V=1.0, theta=0.0
% INFO    : Bus 78584	: V=0.9874607, theta=-64.308118 -> V=1.0, theta=0.0
% INFO    : Bus 78585	: V=0.9833503, theta=-65.078408 -> V=1.0, theta=0.0
% INFO    : Bus 78586	: V=0.9875557, theta=-64.33172 -> V=1.0, theta=0.0
% INFO    : Bus 78587	: V=0.988016, theta=-64.056125 -> V=1.0, theta=0.0
% INFO    : Bus 78588	: V=0.963173, theta=-67.789711 -> V=1.0, theta=0.0
% INFO    : Bus 78589	: V=0.9758615, theta=-65.547497 -> V=1.0, theta=0.0
% INFO    : Bus 78590	: V=0.9862078, theta=-63.699991 -> V=1.0, theta=0.0
% INFO    : Bus 78591	: V=0.9914039, theta=-62.560796 -> V=1.0, theta=0.0
% INFO    : Bus 78592	: V=0.9941004, theta=-62.08501 -> V=1.0, theta=0.0
% INFO    : Bus 78593	: V=0.9812853, theta=-64.649842 -> V=1.0, theta=0.0
% INFO    : Bus 78594	: V=0.9837941, theta=-64.343388 -> V=1.0, theta=0.0
% INFO    : Bus 78595	: V=0.9834345, theta=-64.20971 -> V=1.0, theta=0.0
% INFO    : Bus 78596	: V=0.9846133, theta=-64.05469 -> V=1.0, theta=0.0
% INFO    : Bus 78597	: V=0.9811484, theta=-64.685101 -> V=1.0, theta=0.0
% INFO    : Bus 78598	: V=0.9801173, theta=-64.578827 -> V=1.0, theta=0.0
% INFO    : Bus 78599	: V=0.9770144, theta=-64.873139 -> V=1.0, theta=0.0
% INFO    : Bus 78600	: V=0.9785596, theta=-64.869374 -> V=1.0, theta=0.0
% INFO    : Bus 78601	: V=0.9497791, theta=-77.665026 -> V=1.0, theta=0.0
% INFO    : Bus 78602	: V=0.9621659, theta=-79.169467 -> V=1.0, theta=0.0
% INFO    : Bus 78603	: V=1.0039649, theta=-66.197677 -> V=1.0, theta=0.0
% INFO    : Bus 78604	: V=0.9922894, theta=-67.929302 -> V=1.0, theta=0.0
% INFO    : Bus 78605	: V=0.9811372, theta=-70.264683 -> V=1.0, theta=0.0
% INFO    : Bus 78606	: V=0.9771276, theta=-71.317435 -> V=1.0, theta=0.0
% INFO    : Bus 78607	: V=0.9864679, theta=-62.850218 -> V=1.0, theta=0.0
% INFO    : Bus 78608	: V=1.0021861, theta=-60.705151 -> V=1.0, theta=0.0
% INFO    : Bus 78609	: V=0.9972885, theta=-61.457668 -> V=1.0, theta=0.0
% INFO    : Bus 78610	: V=0.9865689, theta=-62.800419 -> V=1.0, theta=0.0
% INFO    : Bus 78611	: V=1.0024821, theta=-60.651938 -> V=1.0, theta=0.0
% INFO    : Bus 78612	: V=0.9969632, theta=-61.490258 -> V=1.0, theta=0.0
% INFO    : Bus 78613	: V=1.001837, theta=-60.650798 -> V=1.0, theta=0.0
% INFO    : Bus 78614	: V=1.0038071, theta=-60.374698 -> V=1.0, theta=0.0
% INFO    : Bus 78615	: V=0.9909261, theta=-62.08683 -> V=1.0, theta=0.0
% INFO    : Bus 78616	: V=1.0011174, theta=-60.768579 -> V=1.0, theta=0.0
% INFO    : Bus 78617	: V=0.9869702, theta=-62.565499 -> V=1.0, theta=0.0
% INFO    : Bus 78618	: V=0.9695236, theta=-64.501333 -> V=1.0, theta=0.0
% INFO    : Bus 78619	: V=0.9681795, theta=-64.743973 -> V=1.0, theta=0.0
% INFO    : Bus 78620	: V=0.9731284, theta=-64.097056 -> V=1.0, theta=0.0
% INFO    : Bus 78621	: V=0.9806936, theta=-63.118539 -> V=1.0, theta=0.0
% INFO    : Bus 78622	: V=0.9768864, theta=-63.979951 -> V=1.0, theta=0.0
% INFO    : Bus 78623	: V=0.9843221, theta=-62.732498 -> V=1.0, theta=0.0
% INFO    : Bus 78624	: V=0.9714766, theta=-64.287297 -> V=1.0, theta=0.0
% INFO    : Bus 78625	: V=0.984931, theta=-62.707395 -> V=1.0, theta=0.0
% INFO    : Bus 78626	: V=0.9944083, theta=-61.759216 -> V=1.0, theta=0.0
% INFO    : Bus 78627	: V=0.9933782, theta=-62.218333 -> V=1.0, theta=0.0
% INFO    : Bus 78628	: V=0.9877098, theta=-62.980926 -> V=1.0, theta=0.0
% INFO    : Bus 78629	: V=0.9971193, theta=-61.78487 -> V=1.0, theta=0.0
% INFO    : Bus 78630	: V=0.9775095, theta=-62.982319 -> V=1.0, theta=0.0
% INFO    : Bus 78631	: V=0.9741767, theta=-63.589828 -> V=1.0, theta=0.0
% INFO    : Bus 78632	: V=0.9759328, theta=-63.478549 -> V=1.0, theta=0.0
% INFO    : Bus 78633	: V=0.9765792, theta=-63.694172 -> V=1.0, theta=0.0
% INFO    : Bus 78634	: V=0.9740314, theta=-64.315217 -> V=1.0, theta=0.0
% INFO    : Bus 78635	: V=0.9729409, theta=-64.134145 -> V=1.0, theta=0.0
% INFO    : Bus 78636	: V=0.9779532, theta=-63.428155 -> V=1.0, theta=0.0
% INFO    : Bus 78637	: V=0.9762984, theta=-63.741152 -> V=1.0, theta=0.0
% INFO    : Bus 78638	: V=0.9826215, theta=-62.79686 -> V=1.0, theta=0.0
% INFO    : Bus 78639	: V=0.9903404, theta=-61.491433 -> V=1.0, theta=0.0
% INFO    : Bus 78640	: V=0.9905934, theta=-61.970349 -> V=1.0, theta=0.0
% INFO    : Bus 78641	: V=0.9927478, theta=-61.837461 -> V=1.0, theta=0.0
% INFO    : Bus 78642	: V=1.0016593, theta=-60.732558 -> V=1.0, theta=0.0
% INFO    : Bus 78643	: V=0.9870734, theta=-62.643374 -> V=1.0, theta=0.0
% INFO    : Bus 78644	: V=0.9868574, theta=-63.113638 -> V=1.0, theta=0.0
% INFO    : Bus 78645	: V=1.0035169, theta=-60.398734 -> V=1.0, theta=0.0
% INFO    : Bus 78646	: V=1.0055484, theta=-60.131227 -> V=1.0, theta=0.0
% INFO    : Bus 78647	: V=0.9641647, theta=-65.921399 -> V=1.0, theta=0.0
% INFO    : Bus 78648	: V=0.9685043, theta=-65.833171 -> V=1.0, theta=0.0
% INFO    : Bus 78649	: V=0.9633567, theta=-66.156283 -> V=1.0, theta=0.0
% INFO    : Bus 78650	: V=0.9645603, theta=-65.769306 -> V=1.0, theta=0.0
% INFO    : Bus 78651	: V=0.9767557, theta=-67.15056 -> V=1.0, theta=0.0
% INFO    : Bus 78652	: V=0.9697507, theta=-67.052533 -> V=1.0, theta=0.0
% INFO    : Bus 78653	: V=0.9628463, theta=-66.868219 -> V=1.0, theta=0.0
% INFO    : Bus 78654	: V=0.9667518, theta=-67.369061 -> V=1.0, theta=0.0
% INFO    : Bus 78655	: V=0.9613207, theta=-66.606756 -> V=1.0, theta=0.0
% INFO    : Bus 78656	: V=0.9646963, theta=-66.126732 -> V=1.0, theta=0.0
% INFO    : Bus 78657	: V=0.9716134, theta=-65.755807 -> V=1.0, theta=0.0
% INFO    : Bus 78658	: V=0.9764631, theta=-63.566499 -> V=1.0, theta=0.0
% INFO    : Bus 78659	: V=0.9668443, theta=-65.060998 -> V=1.0, theta=0.0
% INFO    : Bus 78660	: V=0.9738591, theta=-62.605314 -> V=1.0, theta=0.0
% INFO    : Bus 78661	: V=0.9757437, theta=-62.442476 -> V=1.0, theta=0.0
% INFO    : Bus 78662	: V=0.9781496, theta=-61.987551 -> V=1.0, theta=0.0
% INFO    : Bus 78663	: V=0.9738565, theta=-63.265646 -> V=1.0, theta=0.0
% INFO    : Bus 78664	: V=0.997954, theta=-60.643345 -> V=1.0, theta=0.0
% INFO    : Bus 78665	: V=0.9922973, theta=-61.806723 -> V=1.0, theta=0.0
% INFO    : Bus 78666	: V=1.0041164, theta=-60.043423 -> V=1.0, theta=0.0
% INFO    : Bus 78667	: V=0.9964829, theta=-61.31164 -> V=1.0, theta=0.0
% INFO    : Bus 78668	: V=0.9871681, theta=-62.089687 -> V=1.0, theta=0.0
% INFO    : Bus 78669	: V=1.0003499, theta=-60.193188 -> V=1.0, theta=0.0
% INFO    : Bus 78670	: V=1.0013997, theta=-60.057919 -> V=1.0, theta=0.0
% INFO    : Bus 78671	: V=1.008641, theta=-60.31835 -> V=1.0, theta=0.0
% INFO    : Bus 78672	: V=1.0082322, theta=-60.101889 -> V=1.0, theta=0.0
% INFO    : Bus 78673	: V=1.00696, theta=-60.249517 -> V=1.0, theta=0.0
% INFO    : Bus 78674	: V=0.9928082, theta=-63.070902 -> V=1.0, theta=0.0
% INFO    : Bus 78675	: V=0.9982456, theta=-61.824322 -> V=1.0, theta=0.0
% INFO    : Bus 78676	: V=0.9995632, theta=-61.088846 -> V=1.0, theta=0.0
% INFO    : Bus 78677	: V=1.0040781, theta=-59.735261 -> V=1.0, theta=0.0
% INFO    : Bus 78678	: V=1.0059531, theta=-59.611221 -> V=1.0, theta=0.0
% INFO    : Bus 78679	: V=0.9910846, theta=-61.635858 -> V=1.0, theta=0.0
% INFO    : Bus 78680	: V=0.9449023, theta=-76.774289 -> V=1.0, theta=0.0
% INFO    : Bus 78681	: V=0.9862746, theta=-62.599323 -> V=1.0, theta=0.0
% INFO    : Bus 78682	: V=0.992919, theta=-62.007118 -> V=1.0, theta=0.0
% INFO    : Bus 78683	: V=0.9969547, theta=-61.920536 -> V=1.0, theta=0.0
% INFO    : Bus 78684	: V=0.9981501, theta=-61.63086 -> V=1.0, theta=0.0
% INFO    : Bus 78685	: V=0.9614174, theta=-69.026092 -> V=1.0, theta=0.0
% INFO    : Bus 78686	: V=0.9733214, theta=-67.28847 -> V=1.0, theta=0.0
% INFO    : Bus 78687	: V=0.9737425, theta=-67.238579 -> V=1.0, theta=0.0
% INFO    : Bus 78688	: V=0.9660748, theta=-68.277981 -> V=1.0, theta=0.0
% INFO    : Bus 78689	: V=0.9610104, theta=-68.664372 -> V=1.0, theta=0.0
% INFO    : Bus 78690	: V=0.9589538, theta=-69.160829 -> V=1.0, theta=0.0
% INFO    : Bus 78691	: V=0.959346, theta=-69.14287 -> V=1.0, theta=0.0
% INFO    : Bus 78692	: V=0.9609992, theta=-68.678431 -> V=1.0, theta=0.0
% INFO    : Bus 78693	: V=0.9569125, theta=-69.254309 -> V=1.0, theta=0.0
% INFO    : Bus 78694	: V=0.9562984, theta=-69.281496 -> V=1.0, theta=0.0
% INFO    : Bus 78695	: V=0.9833777, theta=-62.376424 -> V=1.0, theta=0.0
% INFO    : Bus 78696	: V=0.9884097, theta=-61.984678 -> V=1.0, theta=0.0
% INFO    : Bus 78697	: V=0.9958061, theta=-61.728476 -> V=1.0, theta=0.0
% INFO    : Bus 78698	: V=0.9924633, theta=-62.311257 -> V=1.0, theta=0.0
% INFO    : Bus 78699	: V=0.9920369, theta=-62.107652 -> V=1.0, theta=0.0
% INFO    : Bus 78700	: V=1.0082463, theta=-60.606273 -> V=1.0, theta=0.0
% INFO    : Bus 78701	: V=1.0031733, theta=-61.709586 -> V=1.0, theta=0.0
% INFO    : Bus 78702	: V=0.9920378, theta=-61.250006 -> V=1.0, theta=0.0
% INFO    : Bus 78703	: V=0.9893777, theta=-61.853523 -> V=1.0, theta=0.0
% INFO    : Bus 78704	: V=0.984769, theta=-61.897459 -> V=1.0, theta=0.0
% INFO    : Bus 78705	: V=0.9767782, theta=-62.872334 -> V=1.0, theta=0.0
% INFO    : Bus 78706	: V=0.9819593, theta=-62.341347 -> V=1.0, theta=0.0
% INFO    : Bus 78707	: V=0.9808353, theta=-62.017938 -> V=1.0, theta=0.0
% INFO    : Bus 78708	: V=0.9850595, theta=-61.53698 -> V=1.0, theta=0.0
% INFO    : Bus 78709	: V=0.9874667, theta=-61.152115 -> V=1.0, theta=0.0
% INFO    : Bus 78710	: V=0.9866433, theta=-61.220977 -> V=1.0, theta=0.0
% INFO    : Bus 78711	: V=0.9856235, theta=-61.435152 -> V=1.0, theta=0.0
% INFO    : Bus 78712	: V=0.9827888, theta=-62.218558 -> V=1.0, theta=0.0
% INFO    : Bus 78713	: V=0.9810006, theta=-60.717293 -> V=1.0, theta=0.0
% INFO    : Bus 78714	: V=0.9810448, theta=-60.973776 -> V=1.0, theta=0.0
% INFO    : Bus 78715	: V=0.9717431, theta=-63.435033 -> V=1.0, theta=0.0
% INFO    : Bus 78716	: V=0.9544447, theta=-66.117131 -> V=1.0, theta=0.0
% INFO    : Bus 78717	: V=0.9669786, theta=-64.072884 -> V=1.0, theta=0.0
% INFO    : Bus 78718	: V=0.973494, theta=-63.410901 -> V=1.0, theta=0.0
% INFO    : Bus 78719	: V=0.9765408, theta=-63.379841 -> V=1.0, theta=0.0
% INFO    : Bus 78720	: V=0.9764159, theta=-63.80926 -> V=1.0, theta=0.0
% INFO    : Bus 78721	: V=0.9595443, theta=-65.46758 -> V=1.0, theta=0.0
% INFO    : Bus 78722	: V=0.9665614, theta=-63.637343 -> V=1.0, theta=0.0
% INFO    : Bus 78723	: V=0.9651732, theta=-63.734473 -> V=1.0, theta=0.0
% INFO    : Bus 78724	: V=0.9690537, theta=-63.141359 -> V=1.0, theta=0.0
% INFO    : Bus 78725	: V=0.9765795, theta=-60.300568 -> V=1.0, theta=0.0
% INFO    : Bus 78726	: V=0.9848684, theta=-59.437446 -> V=1.0, theta=0.0
% INFO    : Bus 78727	: V=0.9845584, theta=-59.594453 -> V=1.0, theta=0.0
% INFO    : Bus 78728	: V=0.9704542, theta=-62.789335 -> V=1.0, theta=0.0
% INFO    : Bus 78729	: V=0.9781534, theta=-60.64814 -> V=1.0, theta=0.0
% INFO    : Bus 78730	: V=0.9860853, theta=-59.29308 -> V=1.0, theta=0.0
% INFO    : Bus 78731	: V=0.9647606, theta=-64.64918 -> V=1.0, theta=0.0
% INFO    : Bus 78732	: V=0.9690792, theta=-62.765743 -> V=1.0, theta=0.0
% INFO    : Bus 78733	: V=0.9726272, theta=-62.534065 -> V=1.0, theta=0.0
% INFO    : Bus 78734	: V=0.9841071, theta=-70.654245 -> V=1.0, theta=0.0
% INFO    : Bus 78735	: V=0.9853523, theta=-69.015506 -> V=1.0, theta=0.0
% INFO    : Bus 78736	: V=0.9902952, theta=-68.469847 -> V=1.0, theta=0.0
% INFO    : Bus 78737	: V=1.0001391, theta=-67.162438 -> V=1.0, theta=0.0
% INFO    : Bus 78738	: V=1.0043858, theta=-63.135956 -> V=1.0, theta=0.0
% INFO    : Bus 78739	: V=1.0075607, theta=-62.041554 -> V=1.0, theta=0.0
% INFO    : Bus 78740	: V=1.0041101, theta=-63.135934 -> V=1.0, theta=0.0
% INFO    : Bus 78741	: V=0.9866836, theta=-67.165393 -> V=1.0, theta=0.0
% INFO    : Bus 78742	: V=0.9896386, theta=-65.871628 -> V=1.0, theta=0.0
% INFO    : Bus 78743	: V=0.9887259, theta=-63.975605 -> V=1.0, theta=0.0
% INFO    : Bus 78744	: V=0.9401138, theta=-76.574057 -> V=1.0, theta=0.0
% INFO    : Bus 78745	: V=0.9571803, theta=-72.229742 -> V=1.0, theta=0.0
% INFO    : Bus 78746	: V=0.9463794, theta=-74.602554 -> V=1.0, theta=0.0
% INFO    : Bus 78747	: V=0.9478443, theta=-74.240701 -> V=1.0, theta=0.0
% INFO    : Bus 78748	: V=0.9649829, theta=-67.653363 -> V=1.0, theta=0.0
% INFO    : Bus 78749	: V=0.9707662, theta=-65.051168 -> V=1.0, theta=0.0
% INFO    : Bus 78750	: V=0.9686474, theta=-67.750395 -> V=1.0, theta=0.0
% INFO    : Bus 78751	: V=0.9633614, theta=-69.039315 -> V=1.0, theta=0.0
% INFO    : Bus 78752	: V=0.9631003, theta=-69.110347 -> V=1.0, theta=0.0
% INFO    : Bus 78753	: V=0.9431604, theta=-72.741206 -> V=1.0, theta=0.0
% INFO    : Bus 78754	: V=0.9424764, theta=-73.039534 -> V=1.0, theta=0.0
% INFO    : Bus 78755	: V=0.9604258, theta=-74.700712 -> V=1.0, theta=0.0
% INFO    : Bus 78756	: V=0.9446815, theta=-74.505157 -> V=1.0, theta=0.0
% INFO    : Bus 78757	: V=0.9405093, theta=-73.426542 -> V=1.0, theta=0.0
% INFO    : Bus 78758	: V=0.9766112, theta=-63.808656 -> V=1.0, theta=0.0
% INFO    : Bus 78759	: V=0.9757784, theta=-63.781083 -> V=1.0, theta=0.0
% INFO    : Bus 78760	: V=0.9807, theta=-63.304965 -> V=1.0, theta=0.0
% INFO    : Bus 78761	: V=0.9854849, theta=-62.826279 -> V=1.0, theta=0.0
% INFO    : Bus 78762	: V=0.9823323, theta=-63.156703 -> V=1.0, theta=0.0
% INFO    : Bus 78763	: V=0.9828164, theta=-62.977452 -> V=1.0, theta=0.0
% INFO    : Bus 78764	: V=0.9851871, theta=-62.649737 -> V=1.0, theta=0.0
% INFO    : Bus 78765	: V=0.9852154, theta=-62.83899 -> V=1.0, theta=0.0
% INFO    : Bus 78766	: V=1.0070166, theta=-59.432334 -> V=1.0, theta=0.0
% INFO    : Bus 78767	: V=1.0028343, theta=-60.348775 -> V=1.0, theta=0.0
% INFO    : Bus 78768	: V=0.9973943, theta=-61.321031 -> V=1.0, theta=0.0
% INFO    : Bus 78769	: V=0.9966508, theta=-61.568504 -> V=1.0, theta=0.0
% INFO    : Bus 78770	: V=0.9911573, theta=-61.964054 -> V=1.0, theta=0.0
% INFO    : Bus 78771	: V=0.9955314, theta=-61.454148 -> V=1.0, theta=0.0
% INFO    : Bus 78772	: V=0.9925829, theta=-61.985386 -> V=1.0, theta=0.0
% INFO    : Bus 78773	: V=0.9889445, theta=-62.306676 -> V=1.0, theta=0.0
% INFO    : Bus 78774	: V=0.9907002, theta=-62.067194 -> V=1.0, theta=0.0
% INFO    : Bus 78775	: V=0.9966129, theta=-61.303244 -> V=1.0, theta=0.0
% INFO    : Bus 78776	: V=0.9941293, theta=-61.69446 -> V=1.0, theta=0.0
% INFO    : Bus 78777	: V=0.9980068, theta=-60.246903 -> V=1.0, theta=0.0
% INFO    : Bus 78778	: V=0.9975267, theta=-60.284043 -> V=1.0, theta=0.0
% INFO    : Bus 78779	: V=0.9977375, theta=-60.712308 -> V=1.0, theta=0.0
% INFO    : Bus 78780	: V=0.9901015, theta=-61.06768 -> V=1.0, theta=0.0
% INFO    : Bus 78781	: V=0.9787699, theta=-63.597973 -> V=1.0, theta=0.0
% INFO    : Bus 78782	: V=0.9761983, theta=-64.020837 -> V=1.0, theta=0.0
% INFO    : Bus 78783	: V=0.9739847, theta=-64.181485 -> V=1.0, theta=0.0
% INFO    : Bus 78784	: V=0.9687309, theta=-64.748327 -> V=1.0, theta=0.0
% INFO    : Bus 78785	: V=0.9770839, theta=-63.969123 -> V=1.0, theta=0.0
% INFO    : Bus 78786	: V=0.9758261, theta=-63.986747 -> V=1.0, theta=0.0
% INFO    : Bus 78787	: V=0.9642252, theta=-65.592268 -> V=1.0, theta=0.0
% INFO    : Bus 78788	: V=0.9652837, theta=-65.137844 -> V=1.0, theta=0.0
% INFO    : Bus 78789	: V=0.9655307, theta=-65.375185 -> V=1.0, theta=0.0
% INFO    : Bus 78790	: V=0.9520637, theta=-66.758225 -> V=1.0, theta=0.0
% INFO    : Bus 78791	: V=0.9667206, theta=-65.248456 -> V=1.0, theta=0.0
% INFO    : Bus 78792	: V=0.9648306, theta=-65.19874 -> V=1.0, theta=0.0
% INFO    : Bus 78793	: V=0.9713047, theta=-65.021434 -> V=1.0, theta=0.0
% INFO    : Bus 78794	: V=0.9762254, theta=-63.970542 -> V=1.0, theta=0.0
% INFO    : Bus 78795	: V=0.9720043, theta=-64.299603 -> V=1.0, theta=0.0
% INFO    : Bus 78796	: V=0.9701157, theta=-65.006905 -> V=1.0, theta=0.0
% INFO    : Bus 78797	: V=0.9753663, theta=-64.098621 -> V=1.0, theta=0.0
% INFO    : Bus 78798	: V=0.96593, theta=-65.456434 -> V=1.0, theta=0.0
% INFO    : Bus 78799	: V=0.9763551, theta=-64.606216 -> V=1.0, theta=0.0
% INFO    : Bus 78800	: V=0.9717299, theta=-65.017136 -> V=1.0, theta=0.0
% INFO    : Bus 78801	: V=0.9645391, theta=-64.92406 -> V=1.0, theta=0.0
% INFO    : Bus 78802	: V=0.9597646, theta=-69.173943 -> V=1.0, theta=0.0
% INFO    : Bus 78803	: V=0.9502526, theta=-68.997373 -> V=1.0, theta=0.0
% INFO    : Bus 78804	: V=0.9923277, theta=-61.375751 -> V=1.0, theta=0.0
% INFO    : Bus 78805	: V=0.9913899, theta=-61.449776 -> V=1.0, theta=0.0
% INFO    : Bus 78806	: V=0.9866345, theta=-62.019437 -> V=1.0, theta=0.0
% INFO    : Bus 78807	: V=0.991138, theta=-61.485907 -> V=1.0, theta=0.0
% INFO    : Bus 78808	: V=0.9944151, theta=-60.793657 -> V=1.0, theta=0.0
% INFO    : Bus 78809	: V=0.9891159, theta=-61.521338 -> V=1.0, theta=0.0
% INFO    : Bus 78810	: V=0.9894301, theta=-61.529997 -> V=1.0, theta=0.0
% INFO    : Bus 78811	: V=0.9949781, theta=-60.725534 -> V=1.0, theta=0.0
% INFO    : Bus 78812	: V=0.99344, theta=-61.233174 -> V=1.0, theta=0.0
% INFO    : Bus 78813	: V=0.9952383, theta=-60.761491 -> V=1.0, theta=0.0
% INFO    : Bus 78814	: V=0.9979874, theta=-60.419141 -> V=1.0, theta=0.0
% INFO    : Bus 78815	: V=1.0087389, theta=-58.72582 -> V=1.0, theta=0.0
% INFO    : Bus 78816	: V=1.0100022, theta=-58.635632 -> V=1.0, theta=0.0
% INFO    : Bus 78817	: V=1.0046082, theta=-59.474735 -> V=1.0, theta=0.0
% INFO    : Bus 78818	: V=1.0005865, theta=-60.077485 -> V=1.0, theta=0.0
% INFO    : Bus 78819	: V=1.0033993, theta=-59.568338 -> V=1.0, theta=0.0
% INFO    : Bus 78820	: V=0.9960161, theta=-60.664141 -> V=1.0, theta=0.0
% INFO    : Bus 78821	: V=1.0152832, theta=-57.961883 -> V=1.0, theta=0.0
% INFO    : Bus 78822	: V=1.0129893, theta=-58.231846 -> V=1.0, theta=0.0
% INFO    : Bus 78823	: V=0.9987416, theta=-60.234633 -> V=1.0, theta=0.0
% INFO    : Bus 78824	: V=1.0069781, theta=-59.041774 -> V=1.0, theta=0.0
% INFO    : Bus 78825	: V=0.9999762, theta=-60.04602 -> V=1.0, theta=0.0
% INFO    : Bus 78826	: V=1.0088789, theta=-58.777674 -> V=1.0, theta=0.0
% INFO    : Bus 78827	: V=1.0102666, theta=-58.686176 -> V=1.0, theta=0.0
% INFO    : Bus 78828	: V=0.9999866, theta=-60.137065 -> V=1.0, theta=0.0
% INFO    : Bus 78829	: V=1.0137298, theta=-58.184452 -> V=1.0, theta=0.0
% INFO    : Bus 78830	: V=1.0116011, theta=-58.551649 -> V=1.0, theta=0.0
% INFO    : Bus 78831	: V=1.0168913, theta=-57.794465 -> V=1.0, theta=0.0
% INFO    : Bus 78832	: V=1.0115735, theta=-58.529886 -> V=1.0, theta=0.0
% INFO    : Bus 78833	: V=1.0103587, theta=-58.77391 -> V=1.0, theta=0.0
% INFO    : Bus 78834	: V=1.0177864, theta=-57.628078 -> V=1.0, theta=0.0
% INFO    : Bus 78835	: V=1.0143647, theta=-58.071612 -> V=1.0, theta=0.0
% INFO    : Bus 78836	: V=1.0118388, theta=-58.338482 -> V=1.0, theta=0.0
% INFO    : Bus 78837	: V=1.0107519, theta=-58.574528 -> V=1.0, theta=0.0
% INFO    : Bus 78838	: V=1.0142919, theta=-58.123759 -> V=1.0, theta=0.0
% INFO    : Bus 78839	: V=1.0177833, theta=-57.519758 -> V=1.0, theta=0.0
% INFO    : Bus 78840	: V=1.0160096, theta=-57.754244 -> V=1.0, theta=0.0
% INFO    : Bus 78841	: V=1.0142435, theta=-58.068552 -> V=1.0, theta=0.0
% INFO    : Bus 78842	: V=1.017601, theta=-57.376375 -> V=1.0, theta=0.0
% INFO    : Bus 78843	: V=1.0164034, theta=-57.620006 -> V=1.0, theta=0.0
% INFO    : Bus 78844	: V=1.0132642, theta=-57.704411 -> V=1.0, theta=0.0
% INFO    : Bus 78845	: V=1.0127475, theta=-58.181108 -> V=1.0, theta=0.0
% INFO    : Bus 78846	: V=1.0113902, theta=-58.378953 -> V=1.0, theta=0.0
% INFO    : Bus 78847	: V=1.0128022, theta=-57.690854 -> V=1.0, theta=0.0
% INFO    : Bus 78848	: V=1.00931, theta=-58.417185 -> V=1.0, theta=0.0
% INFO    : Bus 78849	: V=1.0055695, theta=-59.079993 -> V=1.0, theta=0.0
% INFO    : Bus 78850	: V=1.0176679, theta=-57.143393 -> V=1.0, theta=0.0
% INFO    : Bus 78851	: V=1.0132152, theta=-58.010882 -> V=1.0, theta=0.0
% INFO    : Bus 78852	: V=1.0109943, theta=-58.335286 -> V=1.0, theta=0.0
% INFO    : Bus 78853	: V=1.0084904, theta=-58.58985 -> V=1.0, theta=0.0
% INFO    : Bus 78854	: V=1.0032843, theta=-59.412746 -> V=1.0, theta=0.0
% INFO    : Bus 78855	: V=1.0025237, theta=-59.504446 -> V=1.0, theta=0.0
% INFO    : Bus 78856	: V=1.0022683, theta=-59.919969 -> V=1.0, theta=0.0
% INFO    : Bus 78857	: V=0.9968639, theta=-60.137469 -> V=1.0, theta=0.0
% INFO    : Bus 78858	: V=1.0025864, theta=-58.990068 -> V=1.0, theta=0.0
% INFO    : Bus 78859	: V=0.9905204, theta=-60.864986 -> V=1.0, theta=0.0
% INFO    : Bus 78860	: V=0.9992881, theta=-59.236102 -> V=1.0, theta=0.0
% INFO    : Bus 78861	: V=1.0080703, theta=-58.753141 -> V=1.0, theta=0.0
% INFO    : Bus 78862	: V=0.9961298, theta=-60.564173 -> V=1.0, theta=0.0
% INFO    : Bus 78863	: V=1.003664, theta=-59.519767 -> V=1.0, theta=0.0
% INFO    : Bus 78864	: V=0.9947988, theta=-60.487554 -> V=1.0, theta=0.0
% INFO    : Bus 78865	: V=0.9991883, theta=-60.183732 -> V=1.0, theta=0.0
% INFO    : Bus 78866	: V=0.9861164, theta=-61.953492 -> V=1.0, theta=0.0
% INFO    : Bus 78867	: V=0.9844721, theta=-61.702745 -> V=1.0, theta=0.0
% INFO    : Bus 78868	: V=0.9929879, theta=-60.653985 -> V=1.0, theta=0.0
% INFO    : Bus 78869	: V=0.9818059, theta=-62.527875 -> V=1.0, theta=0.0
% INFO    : Bus 78870	: V=0.982895, theta=-62.359576 -> V=1.0, theta=0.0
% INFO    : Bus 78871	: V=0.9878114, theta=-61.680807 -> V=1.0, theta=0.0
% INFO    : Bus 78872	: V=0.9840954, theta=-62.249901 -> V=1.0, theta=0.0
% INFO    : Bus 78873	: V=0.9877986, theta=-61.62607 -> V=1.0, theta=0.0
% INFO    : Bus 78874	: V=0.984444, theta=-62.114842 -> V=1.0, theta=0.0
% INFO    : Bus 78875	: V=0.9809939, theta=-62.341171 -> V=1.0, theta=0.0
% INFO    : Bus 78876	: V=0.9951087, theta=-60.008721 -> V=1.0, theta=0.0
% INFO    : Bus 78877	: V=1.0052703, theta=-59.39018 -> V=1.0, theta=0.0
% INFO    : Bus 78878	: V=1.011957, theta=-58.545437 -> V=1.0, theta=0.0
% INFO    : Bus 78879	: V=0.9945794, theta=-61.133596 -> V=1.0, theta=0.0
% INFO    : Bus 78880	: V=0.9684703, theta=-70.604241 -> V=1.0, theta=0.0
% INFO    : Bus 78881	: V=0.9692831, theta=-72.254145 -> V=1.0, theta=0.0
% INFO    : Bus 78882	: V=0.9786389, theta=-68.464076 -> V=1.0, theta=0.0
% INFO    : Bus 78883	: V=0.956733, theta=-76.656766 -> V=1.0, theta=0.0
% INFO    : Bus 78884	: V=0.9509873, theta=-73.493515 -> V=1.0, theta=0.0
% INFO    : Bus 78885	: V=0.9630623, theta=-71.084519 -> V=1.0, theta=0.0
% INFO    : Bus 78886	: V=0.9725094, theta=-69.384052 -> V=1.0, theta=0.0
% INFO    : Bus 78887	: V=0.9711001, theta=-69.645857 -> V=1.0, theta=0.0
% INFO    : Bus 78888	: V=0.9583026, theta=-72.408327 -> V=1.0, theta=0.0
% INFO    : Bus 78889	: V=0.9510731, theta=-73.279409 -> V=1.0, theta=0.0
% INFO    : Bus 78890	: V=0.9475451, theta=-73.891254 -> V=1.0, theta=0.0
% INFO    : Bus 78891	: V=0.9481257, theta=-72.254818 -> V=1.0, theta=0.0
% INFO    : Bus 78892	: V=0.9590926, theta=-72.24349 -> V=1.0, theta=0.0
% INFO    : Bus 78893	: V=0.9530247, theta=-72.890817 -> V=1.0, theta=0.0
% INFO    : Bus 78894	: V=0.956207, theta=-73.413268 -> V=1.0, theta=0.0
% INFO    : Bus 78895	: V=0.9428572, theta=-74.755611 -> V=1.0, theta=0.0
% INFO    : Bus 78896	: V=0.9623116, theta=-72.288921 -> V=1.0, theta=0.0
% INFO    : Bus 78897	: V=0.9543424, theta=-74.580575 -> V=1.0, theta=0.0
% INFO    : Bus 78898	: V=0.9450229, theta=-76.034034 -> V=1.0, theta=0.0
% INFO    : Bus 78899	: V=0.9540964, theta=-74.072929 -> V=1.0, theta=0.0
% INFO    : Bus 78900	: V=0.9429598, theta=-72.915814 -> V=1.0, theta=0.0
% INFO    : Bus 78901	: V=0.9685562, theta=-61.229821 -> V=1.0, theta=0.0
% INFO    : Bus 78902	: V=0.9775132, theta=-59.933661 -> V=1.0, theta=0.0
% INFO    : Bus 78903	: V=0.9687986, theta=-61.100907 -> V=1.0, theta=0.0
% INFO    : Bus 78904	: V=0.9922026, theta=-57.845027 -> V=1.0, theta=0.0
% INFO    : Bus 78905	: V=0.9986796, theta=-56.592315 -> V=1.0, theta=0.0
% INFO    : Bus 78906	: V=0.9975505, theta=-57.020231 -> V=1.0, theta=0.0
% INFO    : Bus 78907	: V=0.9923201, theta=-57.948357 -> V=1.0, theta=0.0
% INFO    : Bus 78908	: V=0.9832519, theta=-58.958826 -> V=1.0, theta=0.0
% INFO    : Bus 78909	: V=0.9880299, theta=-57.999668 -> V=1.0, theta=0.0
% INFO    : Bus 78910	: V=1.0008312, theta=-57.755297 -> V=1.0, theta=0.0
% INFO    : Bus 78911	: V=0.9975439, theta=-57.714752 -> V=1.0, theta=0.0
% INFO    : Bus 78912	: V=0.9939071, theta=-71.047829 -> V=1.0, theta=0.0
% INFO    : Bus 78913	: V=0.9963364, theta=-71.506514 -> V=1.0, theta=0.0
% INFO    : Bus 78914	: V=0.9970937, theta=-59.502279 -> V=1.0, theta=0.0
% INFO    : Bus 78915	: V=1.0092291, theta=-57.474166 -> V=1.0, theta=0.0
% INFO    : Bus 78916	: V=1.0031171, theta=-58.671238 -> V=1.0, theta=0.0
% INFO    : Bus 78917	: V=0.9980034, theta=-59.491835 -> V=1.0, theta=0.0
% INFO    : Bus 78918	: V=0.9967646, theta=-59.776216 -> V=1.0, theta=0.0
% INFO    : Bus 78919	: V=0.9854965, theta=-60.288678 -> V=1.0, theta=0.0
% INFO    : Bus 78920	: V=0.988395, theta=-60.053211 -> V=1.0, theta=0.0
% INFO    : Bus 78921	: V=0.979196, theta=-60.487788 -> V=1.0, theta=0.0
% INFO    : Bus 78922	: V=0.9649742, theta=-61.91585 -> V=1.0, theta=0.0
% INFO    : Bus 78923	: V=0.980674, theta=-60.343617 -> V=1.0, theta=0.0
% INFO    : Bus 78924	: V=1.0150016, theta=-53.259063 -> V=1.0, theta=0.0
% INFO    : Bus 78925	: V=0.9939919, theta=-54.449159 -> V=1.0, theta=0.0
% INFO    : Bus 78926	: V=0.9844754, theta=-63.205108 -> V=1.0, theta=0.0
% INFO    : Bus 78927	: V=0.9884851, theta=-62.675637 -> V=1.0, theta=0.0
% INFO    : Bus 78928	: V=0.9845867, theta=-64.074618 -> V=1.0, theta=0.0
% INFO    : Bus 78929	: V=0.9905214, theta=-61.700367 -> V=1.0, theta=0.0
% INFO    : Bus 78930	: V=1.0037066, theta=-61.325251 -> V=1.0, theta=0.0
% INFO    : Bus 78931	: V=0.9999914, theta=-61.612421 -> V=1.0, theta=0.0
% INFO    : Bus 78932	: V=1.0013481, theta=-60.617044 -> V=1.0, theta=0.0
% INFO    : Bus 78933	: V=1.0037957, theta=-60.195718 -> V=1.0, theta=0.0
% INFO    : Bus 78934	: V=1.0147801, theta=-58.042327 -> V=1.0, theta=0.0
% INFO    : Bus 78935	: V=1.0119332, theta=-58.624669 -> V=1.0, theta=0.0
% INFO    : Bus 78936	: V=1.0116829, theta=-58.583796 -> V=1.0, theta=0.0
% INFO    : Bus 78937	: V=1.013516, theta=-58.171389 -> V=1.0, theta=0.0
% INFO    : Bus 78938	: V=0.987314, theta=-67.254496 -> V=1.0, theta=0.0
% INFO    : Bus 78939	: V=0.9793938, theta=-68.284045 -> V=1.0, theta=0.0
% INFO    : Bus 78940	: V=0.9841166, theta=-65.894259 -> V=1.0, theta=0.0
% INFO    : Bus 78941	: V=1.0147309, theta=-59.984477 -> V=1.0, theta=0.0
% INFO    : Bus 78942	: V=1.0113594, theta=-60.737755 -> V=1.0, theta=0.0
% INFO    : Bus 78943	: V=1.0105906, theta=-61.00847 -> V=1.0, theta=0.0
% INFO    : Bus 78944	: V=0.9532625, theta=-69.499992 -> V=1.0, theta=0.0
% INFO    : Bus 78945	: V=0.9907118, theta=-62.885779 -> V=1.0, theta=0.0
% INFO    : Bus 78946	: V=0.9501216, theta=-71.93743 -> V=1.0, theta=0.0
% INFO    : Bus 78947	: V=0.949182, theta=-71.991573 -> V=1.0, theta=0.0
% INFO    : Bus 78948	: V=0.9494936, theta=-72.109899 -> V=1.0, theta=0.0
% INFO    : Bus 78949	: V=0.9518466, theta=-71.805291 -> V=1.0, theta=0.0
% INFO    : Bus 78950	: V=0.9548789, theta=-71.343732 -> V=1.0, theta=0.0
% INFO    : Bus 78951	: V=0.9542105, theta=-71.367975 -> V=1.0, theta=0.0
% INFO    : Bus 78952	: V=0.9557256, theta=-71.087029 -> V=1.0, theta=0.0
% INFO    : Bus 78953	: V=0.9561763, theta=-70.922301 -> V=1.0, theta=0.0
% INFO    : Bus 78954	: V=0.9524646, theta=-72.074224 -> V=1.0, theta=0.0
% INFO    : Bus 78955	: V=0.9826331, theta=-67.644359 -> V=1.0, theta=0.0
% INFO    : Bus 78956	: V=0.9728976, theta=-68.88841 -> V=1.0, theta=0.0
% INFO    : Bus 78957	: V=0.9679123, theta=-70.152023 -> V=1.0, theta=0.0
% INFO    : Bus 78958	: V=0.9716263, theta=-68.928765 -> V=1.0, theta=0.0
% INFO    : Bus 78959	: V=0.9671083, theta=-70.196943 -> V=1.0, theta=0.0
% INFO    : Bus 78960	: V=0.9613179, theta=-70.049626 -> V=1.0, theta=0.0
% INFO    : Bus 78961	: V=0.9573405, theta=-70.785391 -> V=1.0, theta=0.0
% INFO    : Bus 78962	: V=0.9533016, theta=-71.342099 -> V=1.0, theta=0.0
% INFO    : Bus 78963	: V=0.9518546, theta=-71.317049 -> V=1.0, theta=0.0
% INFO    : Bus 78964	: V=0.9525197, theta=-71.372981 -> V=1.0, theta=0.0
% INFO    : Bus 78965	: V=0.9783842, theta=-62.396535 -> V=1.0, theta=0.0
% INFO    : Bus 78966	: V=0.977359, theta=-62.593141 -> V=1.0, theta=0.0
% INFO    : Bus 78967	: V=0.9774214, theta=-62.522115 -> V=1.0, theta=0.0
% INFO    : Bus 78968	: V=0.9783406, theta=-62.272103 -> V=1.0, theta=0.0
% INFO    : Bus 78969	: V=0.9587327, theta=-65.540969 -> V=1.0, theta=0.0
% INFO    : Bus 78970	: V=0.9829002, theta=-62.391413 -> V=1.0, theta=0.0
% INFO    : Bus 78971	: V=0.9716436, theta=-63.695309 -> V=1.0, theta=0.0
% INFO    : Bus 78972	: V=0.976173, theta=-62.585173 -> V=1.0, theta=0.0
% INFO    : Bus 78973	: V=0.9762705, theta=-62.682988 -> V=1.0, theta=0.0
% INFO    : Bus 78974	: V=0.9748678, theta=-62.85358 -> V=1.0, theta=0.0
% INFO    : Bus 78975	: V=0.9607001, theta=-65.414176 -> V=1.0, theta=0.0
% INFO    : Bus 78976	: V=0.9795738, theta=-62.366916 -> V=1.0, theta=0.0
% INFO    : Bus 78977	: V=0.9732473, theta=-63.022603 -> V=1.0, theta=0.0
% INFO    : Bus 78978	: V=0.9634313, theta=-64.956026 -> V=1.0, theta=0.0
% INFO    : Bus 78979	: V=0.975367, theta=-62.737199 -> V=1.0, theta=0.0
% INFO    : Bus 78980	: V=0.9634619, theta=-65.01327 -> V=1.0, theta=0.0
% INFO    : Bus 78981	: V=0.9812305, theta=-62.151753 -> V=1.0, theta=0.0
% INFO    : Bus 78982	: V=0.982521, theta=-62.045338 -> V=1.0, theta=0.0
% INFO    : Bus 78983	: V=0.9535773, theta=-66.295796 -> V=1.0, theta=0.0
% INFO    : Bus 78984	: V=0.9539636, theta=-66.331348 -> V=1.0, theta=0.0
% INFO    : Bus 78985	: V=0.9593243, theta=-66.581893 -> V=1.0, theta=0.0
% INFO    : Bus 78986	: V=0.9515147, theta=-67.161209 -> V=1.0, theta=0.0
% INFO    : Bus 78987	: V=0.9587744, theta=-66.42615 -> V=1.0, theta=0.0
% INFO    : Bus 78988	: V=0.9832225, theta=-64.760949 -> V=1.0, theta=0.0
% INFO    : Bus 78989	: V=0.965148, theta=-66.24656 -> V=1.0, theta=0.0
% INFO    : Bus 78990	: V=0.9617436, theta=-65.600996 -> V=1.0, theta=0.0
% INFO    : Bus 78991	: V=0.9618314, theta=-65.612108 -> V=1.0, theta=0.0
% INFO    : Bus 78992	: V=0.9628118, theta=-65.691226 -> V=1.0, theta=0.0
% INFO    : Bus 78993	: V=0.953348, theta=-67.107731 -> V=1.0, theta=0.0
% INFO    : Bus 78994	: V=0.9756998, theta=-62.668577 -> V=1.0, theta=0.0
% INFO    : Bus 78995	: V=0.9786887, theta=-62.356434 -> V=1.0, theta=0.0
% INFO    : Bus 78996	: V=0.9821017, theta=-61.816158 -> V=1.0, theta=0.0
% INFO    : Bus 78997	: V=0.9779715, theta=-62.435837 -> V=1.0, theta=0.0
% INFO    : Bus 78998	: V=0.9842802, theta=-61.370159 -> V=1.0, theta=0.0
% INFO    : Bus 78999	: V=0.9805226, theta=-62.175191 -> V=1.0, theta=0.0
% INFO    : Bus 79000	: V=0.9842787, theta=-61.602062 -> V=1.0, theta=0.0
% INFO    : Bus 79001	: V=0.9917509, theta=-60.389714 -> V=1.0, theta=0.0
% INFO    : Bus 79002	: V=0.9819296, theta=-62.170105 -> V=1.0, theta=0.0
% INFO    : Bus 79003	: V=0.9812745, theta=-59.578289 -> V=1.0, theta=0.0
% INFO    : Bus 79004	: V=0.9852363, theta=-61.526502 -> V=1.0, theta=0.0
% INFO    : Bus 79005	: V=0.9823242, theta=-61.521093 -> V=1.0, theta=0.0
% INFO    : Bus 79006	: V=0.9954539, theta=-58.391133 -> V=1.0, theta=0.0
% INFO    : Bus 79007	: V=0.9623068, theta=-64.305282 -> V=1.0, theta=0.0
% INFO    : Bus 79008	: V=0.9616908, theta=-63.829315 -> V=1.0, theta=0.0
% INFO    : Bus 79009	: V=0.9563738, theta=-66.181172 -> V=1.0, theta=0.0
% INFO    : Bus 79010	: V=0.9548742, theta=-66.047437 -> V=1.0, theta=0.0
% INFO    : Bus 79011	: V=0.9647513, theta=-64.331244 -> V=1.0, theta=0.0
% INFO    : Bus 79012	: V=0.9750416, theta=-62.227421 -> V=1.0, theta=0.0
% INFO    : Bus 79013	: V=0.976414, theta=-62.087756 -> V=1.0, theta=0.0
% INFO    : Bus 79014	: V=0.9647572, theta=-64.704744 -> V=1.0, theta=0.0
% INFO    : Bus 79015	: V=0.9850902, theta=-64.701326 -> V=1.0, theta=0.0
% INFO    : Bus 79016	: V=0.9870589, theta=-64.703405 -> V=1.0, theta=0.0
% INFO    : Bus 79017	: V=0.9904081, theta=-64.581666 -> V=1.0, theta=0.0
% INFO    : Bus 79018	: V=0.9878107, theta=-64.761517 -> V=1.0, theta=0.0
% INFO    : Bus 79019	: V=0.9793808, theta=-65.70064 -> V=1.0, theta=0.0
% INFO    : Bus 79020	: V=0.9849739, theta=-64.887754 -> V=1.0, theta=0.0
% INFO    : Bus 79021	: V=0.9941411, theta=-62.79568 -> V=1.0, theta=0.0
% INFO    : Bus 79022	: V=0.9912628, theta=-63.266996 -> V=1.0, theta=0.0
% INFO    : Bus 79023	: V=0.9775376, theta=-64.936073 -> V=1.0, theta=0.0
% INFO    : Bus 79024	: V=0.9952206, theta=-64.091248 -> V=1.0, theta=0.0
% INFO    : Bus 79025	: V=0.9840017, theta=-65.057038 -> V=1.0, theta=0.0
% INFO    : Bus 79026	: V=0.9882678, theta=-64.617596 -> V=1.0, theta=0.0
% INFO    : Bus 79027	: V=0.9872963, theta=-64.829041 -> V=1.0, theta=0.0
% INFO    : Bus 79028	: V=0.9651762, theta=-65.84833 -> V=1.0, theta=0.0
% INFO    : Bus 79029	: V=0.985134, theta=-63.75517 -> V=1.0, theta=0.0
% INFO    : Bus 79030	: V=0.988707, theta=-63.283019 -> V=1.0, theta=0.0
% INFO    : Bus 79031	: V=0.9883349, theta=-63.296267 -> V=1.0, theta=0.0
% INFO    : Bus 79032	: V=0.988897, theta=-63.232236 -> V=1.0, theta=0.0
% INFO    : Bus 79033	: V=0.9888651, theta=-63.070274 -> V=1.0, theta=0.0
% INFO    : Bus 79034	: V=0.9884894, theta=-63.327987 -> V=1.0, theta=0.0
% INFO    : Bus 79035	: V=0.9888929, theta=-63.238267 -> V=1.0, theta=0.0
% INFO    : Bus 79036	: V=0.9923009, theta=-63.604623 -> V=1.0, theta=0.0
% INFO    : Bus 79037	: V=0.9970537, theta=-62.207382 -> V=1.0, theta=0.0
% INFO    : Bus 79038	: V=0.9923396, theta=-63.107453 -> V=1.0, theta=0.0
% INFO    : Bus 79039	: V=0.9944424, theta=-62.875422 -> V=1.0, theta=0.0
% INFO    : Bus 79040	: V=0.9951705, theta=-62.430488 -> V=1.0, theta=0.0
% INFO    : Bus 79041	: V=0.987902, theta=-63.35118 -> V=1.0, theta=0.0
% INFO    : Bus 79042	: V=0.9952264, theta=-62.27263 -> V=1.0, theta=0.0
% INFO    : Bus 79043	: V=1.0010596, theta=-61.530726 -> V=1.0, theta=0.0
% INFO    : Bus 79044	: V=1.0163106, theta=-58.500552 -> V=1.0, theta=0.0
% INFO    : Bus 79045	: V=1.0113967, theta=-59.694197 -> V=1.0, theta=0.0
% INFO    : Bus 79046	: V=1.0048958, theta=-61.032115 -> V=1.0, theta=0.0
% INFO    : Bus 79047	: V=1.0038749, theta=-61.235815 -> V=1.0, theta=0.0
% INFO    : Bus 79048	: V=0.9852141, theta=-63.910101 -> V=1.0, theta=0.0
% INFO    : Bus 79049	: V=0.9827047, theta=-64.078388 -> V=1.0, theta=0.0
% INFO    : Bus 79050	: V=0.9899786, theta=-62.913272 -> V=1.0, theta=0.0
% INFO    : Bus 79051	: V=0.9841061, theta=-63.507068 -> V=1.0, theta=0.0
% INFO    : Bus 79052	: V=0.9914018, theta=-62.806139 -> V=1.0, theta=0.0
% INFO    : Bus 79053	: V=0.9738213, theta=-65.13824 -> V=1.0, theta=0.0
% INFO    : Bus 79054	: V=0.973268, theta=-65.208767 -> V=1.0, theta=0.0
% INFO    : Bus 79055	: V=0.9661614, theta=-67.273274 -> V=1.0, theta=0.0
% INFO    : Bus 79056	: V=0.9730972, theta=-66.044439 -> V=1.0, theta=0.0
% INFO    : Bus 79057	: V=0.9594762, theta=-69.398922 -> V=1.0, theta=0.0
% INFO    : Bus 79058	: V=0.9599795, theta=-69.23205 -> V=1.0, theta=0.0
% INFO    : Bus 79059	: V=0.9627869, theta=-68.767952 -> V=1.0, theta=0.0
% INFO    : Bus 79060	: V=0.962313, theta=-68.684273 -> V=1.0, theta=0.0
% INFO    : Bus 79061	: V=0.9607185, theta=-68.518479 -> V=1.0, theta=0.0
% INFO    : Bus 79062	: V=0.9648518, theta=-67.607085 -> V=1.0, theta=0.0
% INFO    : Bus 79063	: V=0.9645187, theta=-67.937403 -> V=1.0, theta=0.0
% INFO    : Bus 79064	: V=0.9634428, theta=-67.852596 -> V=1.0, theta=0.0
% INFO    : Bus 79065	: V=0.9633382, theta=-67.860092 -> V=1.0, theta=0.0
% INFO    : Bus 79066	: V=0.9649042, theta=-67.498964 -> V=1.0, theta=0.0
% INFO    : Bus 79067	: V=0.9658003, theta=-67.454372 -> V=1.0, theta=0.0
% INFO    : Bus 79068	: V=0.9732703, theta=-65.147089 -> V=1.0, theta=0.0
% INFO    : Bus 79069	: V=0.9724471, theta=-66.743115 -> V=1.0, theta=0.0
% INFO    : Bus 79070	: V=0.9741502, theta=-65.875254 -> V=1.0, theta=0.0
% INFO    : Bus 79071	: V=0.9730656, theta=-65.220559 -> V=1.0, theta=0.0
% INFO    : Bus 79072	: V=0.9753985, theta=-64.972289 -> V=1.0, theta=0.0
% INFO    : Bus 79073	: V=0.9773027, theta=-64.593841 -> V=1.0, theta=0.0
% INFO    : Bus 79074	: V=0.9755812, theta=-64.930175 -> V=1.0, theta=0.0
% INFO    : Bus 79075	: V=0.9931792, theta=-60.952579 -> V=1.0, theta=0.0
% INFO    : Bus 79076	: V=0.993651, theta=-61.365459 -> V=1.0, theta=0.0
% INFO    : Bus 79077	: V=1.0182238, theta=-56.290002 -> V=1.0, theta=0.0
% INFO    : Bus 79078	: V=1.0169892, theta=-56.479844 -> V=1.0, theta=0.0
% INFO    : Bus 79079	: V=1.0179849, theta=-56.548631 -> V=1.0, theta=0.0
% INFO    : Bus 79080	: V=1.0156512, theta=-57.196683 -> V=1.0, theta=0.0
% INFO    : Bus 79081	: V=1.0065817, theta=-58.89745 -> V=1.0, theta=0.0
% INFO    : Bus 79082	: V=1.0180576, theta=-56.773868 -> V=1.0, theta=0.0
% INFO    : Bus 79083	: V=1.0179727, theta=-56.979946 -> V=1.0, theta=0.0
% INFO    : Bus 79084	: V=1.0112689, theta=-58.228529 -> V=1.0, theta=0.0
% INFO    : Bus 79085	: V=1.0124748, theta=-57.969242 -> V=1.0, theta=0.0
% INFO    : Bus 79086	: V=1.0124663, theta=-58.111168 -> V=1.0, theta=0.0
% INFO    : Bus 79087	: V=0.9747584, theta=-64.889926 -> V=1.0, theta=0.0
% INFO    : Bus 79088	: V=1.0178876, theta=-56.670521 -> V=1.0, theta=0.0
% INFO    : Bus 79089	: V=1.0153803, theta=-57.356928 -> V=1.0, theta=0.0
% INFO    : Bus 79090	: V=0.9730213, theta=-70.541058 -> V=1.0, theta=0.0
% INFO    : Bus 79091	: V=0.9635154, theta=-71.89869 -> V=1.0, theta=0.0
% INFO    : Bus 79092	: V=0.9790916, theta=-69.377284 -> V=1.0, theta=0.0
% INFO    : Bus 79093	: V=0.9777427, theta=-69.88994 -> V=1.0, theta=0.0
% INFO    : Bus 79094	: V=0.9709066, theta=-70.949161 -> V=1.0, theta=0.0
% INFO    : Bus 79095	: V=0.9623184, theta=-70.70619 -> V=1.0, theta=0.0
% INFO    : Bus 79096	: V=0.9671966, theta=-70.968706 -> V=1.0, theta=0.0
% INFO    : Bus 79097	: V=0.9674314, theta=-70.970459 -> V=1.0, theta=0.0
% INFO    : Bus 79098	: V=0.9850757, theta=-75.482071 -> V=1.0, theta=0.0
% INFO    : Bus 79099	: V=0.945232, theta=-80.331453 -> V=1.0, theta=0.0
% INFO    : Bus 79100	: V=0.9790056, theta=-75.351998 -> V=1.0, theta=0.0
% INFO    : Bus 79101	: V=0.9551446, theta=-66.358624 -> V=1.0, theta=0.0
% INFO    : Bus 79102	: V=0.951389, theta=-73.180241 -> V=1.0, theta=0.0
% INFO    : Bus 79103	: V=0.9491231, theta=-71.310696 -> V=1.0, theta=0.0
% INFO    : Bus 79104	: V=0.958695, theta=-67.999171 -> V=1.0, theta=0.0
% INFO    : Bus 79105	: V=0.9631089, theta=-68.134137 -> V=1.0, theta=0.0
% INFO    : Bus 79106	: V=0.9419221, theta=-71.638239 -> V=1.0, theta=0.0
% INFO    : Bus 79107	: V=0.944828, theta=-69.648953 -> V=1.0, theta=0.0
% INFO    : Bus 79108	: V=0.9600981, theta=-67.163344 -> V=1.0, theta=0.0
% INFO    : Bus 79109	: V=0.9855944, theta=-63.873583 -> V=1.0, theta=0.0
% INFO    : Bus 79110	: V=0.9585092, theta=-69.088798 -> V=1.0, theta=0.0
% INFO    : Bus 79111	: V=0.9576859, theta=-69.080083 -> V=1.0, theta=0.0
% INFO    : Bus 79112	: V=0.9644506, theta=-67.313737 -> V=1.0, theta=0.0
% INFO    : Bus 79113	: V=0.9628757, theta=-68.06419 -> V=1.0, theta=0.0
% INFO    : Bus 79114	: V=0.9597671, theta=-68.218463 -> V=1.0, theta=0.0
% INFO    : Bus 79115	: V=0.9622965, theta=-68.212871 -> V=1.0, theta=0.0
% INFO    : Bus 79116	: V=0.9717562, theta=-64.815514 -> V=1.0, theta=0.0
% INFO    : Bus 79117	: V=0.9666362, theta=-66.601684 -> V=1.0, theta=0.0
% INFO    : Bus 79118	: V=0.9649108, theta=-66.363857 -> V=1.0, theta=0.0
% INFO    : Bus 79119	: V=0.9663572, theta=-66.206009 -> V=1.0, theta=0.0
% INFO    : Bus 79120	: V=0.9698444, theta=-65.9452 -> V=1.0, theta=0.0
% INFO    : Bus 79121	: V=0.9860414, theta=-62.938642 -> V=1.0, theta=0.0
% INFO    : Bus 79122	: V=0.9899284, theta=-62.621847 -> V=1.0, theta=0.0
% INFO    : Bus 79123	: V=0.9802482, theta=-63.579761 -> V=1.0, theta=0.0
% INFO    : Bus 79124	: V=0.9834177, theta=-63.177056 -> V=1.0, theta=0.0
% INFO    : Bus 79125	: V=0.9634627, theta=-67.616058 -> V=1.0, theta=0.0
% INFO    : Bus 79126	: V=0.9652131, theta=-64.826411 -> V=1.0, theta=0.0
% INFO    : Bus 79127	: V=0.9633158, theta=-65.259779 -> V=1.0, theta=0.0
% INFO    : Bus 79128	: V=0.9652574, theta=-64.695592 -> V=1.0, theta=0.0
% INFO    : Bus 79129	: V=0.9707556, theta=-64.427221 -> V=1.0, theta=0.0
% INFO    : Bus 79130	: V=0.9811249, theta=-63.479011 -> V=1.0, theta=0.0
% INFO    : Bus 79131	: V=1.0093207, theta=-59.484836 -> V=1.0, theta=0.0
% INFO    : Bus 79132	: V=1.0014054, theta=-60.811377 -> V=1.0, theta=0.0
% INFO    : Bus 79133	: V=0.9909217, theta=-62.423889 -> V=1.0, theta=0.0
% INFO    : Bus 79134	: V=0.9914777, theta=-62.337682 -> V=1.0, theta=0.0
% INFO    : Bus 79135	: V=0.9801603, theta=-63.599849 -> V=1.0, theta=0.0
% INFO    : Bus 79136	: V=0.9987453, theta=-61.777172 -> V=1.0, theta=0.0
% INFO    : Bus 79137	: V=0.9981314, theta=-61.803397 -> V=1.0, theta=0.0
% INFO    : Bus 79138	: V=0.9758268, theta=-63.986803 -> V=1.0, theta=0.0
% INFO    : Bus 79139	: V=0.989892, theta=-62.845543 -> V=1.0, theta=0.0
% INFO    : Bus 79140	: V=0.9673478, theta=-64.881776 -> V=1.0, theta=0.0
% INFO    : Bus 79141	: V=0.9626011, theta=-65.159437 -> V=1.0, theta=0.0
% INFO    : Bus 79142	: V=0.9644575, theta=-65.088505 -> V=1.0, theta=0.0
% INFO    : Bus 79143	: V=0.9637056, theta=-65.139876 -> V=1.0, theta=0.0
% INFO    : Bus 79144	: V=0.9648723, theta=-64.911752 -> V=1.0, theta=0.0
% INFO    : Bus 79145	: V=0.9626848, theta=-65.225256 -> V=1.0, theta=0.0
% INFO    : Bus 79146	: V=0.9642151, theta=-65.093894 -> V=1.0, theta=0.0
% INFO    : Bus 79147	: V=0.962854, theta=-65.066952 -> V=1.0, theta=0.0
% INFO    : Bus 79148	: V=0.9619277, theta=-65.193282 -> V=1.0, theta=0.0
% INFO    : Bus 79149	: V=0.9608496, theta=-65.2664 -> V=1.0, theta=0.0
% INFO    : Bus 79150	: V=0.9659062, theta=-64.923096 -> V=1.0, theta=0.0
% INFO    : Bus 79151	: V=0.9719238, theta=-64.21886 -> V=1.0, theta=0.0
% INFO    : Bus 79152	: V=0.9735026, theta=-63.983409 -> V=1.0, theta=0.0
% INFO    : Bus 79153	: V=0.9758343, theta=-63.863149 -> V=1.0, theta=0.0
% INFO    : Bus 79154	: V=0.9810734, theta=-63.200279 -> V=1.0, theta=0.0
% INFO    : Bus 79155	: V=0.9774116, theta=-63.662632 -> V=1.0, theta=0.0
% INFO    : Bus 79156	: V=0.9801655, theta=-63.217866 -> V=1.0, theta=0.0
% INFO    : Bus 79157	: V=0.9796628, theta=-63.218673 -> V=1.0, theta=0.0
% INFO    : Bus 79158	: V=0.9767834, theta=-63.760519 -> V=1.0, theta=0.0
% INFO    : Bus 79159	: V=0.9766171, theta=-63.770394 -> V=1.0, theta=0.0
% INFO    : Bus 79160	: V=0.9764949, theta=-63.78583 -> V=1.0, theta=0.0
% INFO    : Bus 79161	: V=0.9785234, theta=-63.191522 -> V=1.0, theta=0.0
% INFO    : Bus 79162	: V=0.9783438, theta=-63.078614 -> V=1.0, theta=0.0
% INFO    : Bus 79163	: V=0.9799089, theta=-62.83103 -> V=1.0, theta=0.0
% INFO    : Bus 79164	: V=0.9823054, theta=-62.538033 -> V=1.0, theta=0.0
% INFO    : Bus 79165	: V=0.9819875, theta=-62.553785 -> V=1.0, theta=0.0
% INFO    : Bus 79166	: V=0.9816424, theta=-62.582562 -> V=1.0, theta=0.0
% INFO    : Bus 79167	: V=0.9975121, theta=-60.624841 -> V=1.0, theta=0.0
% INFO    : Bus 79168	: V=0.987013, theta=-62.278425 -> V=1.0, theta=0.0
% INFO    : Bus 79169	: V=0.9835847, theta=-62.875699 -> V=1.0, theta=0.0
% INFO    : Bus 79170	: V=0.9794679, theta=-63.292929 -> V=1.0, theta=0.0
% INFO    : Bus 79171	: V=0.9789491, theta=-63.20027 -> V=1.0, theta=0.0
% INFO    : Bus 79172	: V=0.9749046, theta=-64.003026 -> V=1.0, theta=0.0
% INFO    : Bus 79173	: V=0.9839735, theta=-62.901909 -> V=1.0, theta=0.0
% INFO    : Bus 79174	: V=0.994216, theta=-62.040908 -> V=1.0, theta=0.0
% INFO    : Bus 79175	: V=0.9985066, theta=-61.243839 -> V=1.0, theta=0.0
% INFO    : Bus 79176	: V=0.9943453, theta=-62.093711 -> V=1.0, theta=0.0
% INFO    : Bus 79177	: V=1.0108879, theta=-59.838715 -> V=1.0, theta=0.0
% INFO    : Bus 79178	: V=1.0076562, theta=-60.610243 -> V=1.0, theta=0.0
% INFO    : Bus 79179	: V=0.9966775, theta=-61.621004 -> V=1.0, theta=0.0
% INFO    : Bus 79180	: V=1.0009584, theta=-61.509653 -> V=1.0, theta=0.0
% INFO    : Bus 79181	: V=1.0050084, theta=-60.416808 -> V=1.0, theta=0.0
% INFO    : Bus 79182	: V=1.0031444, theta=-61.088625 -> V=1.0, theta=0.0
% INFO    : Bus 79183	: V=1.0059031, theta=-60.278946 -> V=1.0, theta=0.0
% INFO    : Bus 79184	: V=1.0027045, theta=-61.110067 -> V=1.0, theta=0.0
% INFO    : Bus 79185	: V=1.000073, theta=-61.048371 -> V=1.0, theta=0.0
% INFO    : Bus 79186	: V=0.9983277, theta=-61.510448 -> V=1.0, theta=0.0
% INFO    : Bus 79187	: V=0.9990526, theta=-61.417627 -> V=1.0, theta=0.0
% INFO    : Bus 79188	: V=0.9906213, theta=-62.206423 -> V=1.0, theta=0.0
% INFO    : Bus 79189	: V=1.0036203, theta=-60.638344 -> V=1.0, theta=0.0
% INFO    : Bus 79190	: V=0.9847387, theta=-63.822875 -> V=1.0, theta=0.0
% INFO    : Bus 79191	: V=0.9885321, theta=-63.53251 -> V=1.0, theta=0.0
% INFO    : Bus 79192	: V=0.9917854, theta=-63.112427 -> V=1.0, theta=0.0
% INFO    : Bus 79193	: V=1.0131549, theta=-59.185876 -> V=1.0, theta=0.0
% INFO    : Bus 79194	: V=1.011709, theta=-59.381556 -> V=1.0, theta=0.0
% INFO    : Bus 79195	: V=1.0130363, theta=-59.205284 -> V=1.0, theta=0.0
% INFO    : Bus 79196	: V=1.0119881, theta=-59.573656 -> V=1.0, theta=0.0
% INFO    : Bus 79197	: V=1.0142753, theta=-58.928844 -> V=1.0, theta=0.0
% INFO    : Bus 79198	: V=1.0134435, theta=-59.080843 -> V=1.0, theta=0.0
% INFO    : Bus 79199	: V=1.0118839, theta=-59.825274 -> V=1.0, theta=0.0
% INFO    : Bus 79200	: V=0.996649, theta=-62.664133 -> V=1.0, theta=0.0
% INFO    : Bus 79201	: V=0.9950596, theta=-63.014432 -> V=1.0, theta=0.0
% INFO    : Bus 79202	: V=0.9915134, theta=-63.44472 -> V=1.0, theta=0.0
% INFO    : Bus 79203	: V=0.9719774, theta=-64.289615 -> V=1.0, theta=0.0
% INFO    : Bus 79204	: V=0.9880129, theta=-62.512588 -> V=1.0, theta=0.0
% INFO    : Bus 79205	: V=0.9634735, theta=-71.062911 -> V=1.0, theta=0.0
% INFO    : Bus 79206	: V=0.9961015, theta=-62.027617 -> V=1.0, theta=0.0
% INFO    : Bus 79207	: V=0.9920285, theta=-62.98528 -> V=1.0, theta=0.0
% INFO    : Bus 79208	: V=0.9869373, theta=-63.401122 -> V=1.0, theta=0.0
% INFO    : Bus 79209	: V=0.9901715, theta=-63.238563 -> V=1.0, theta=0.0
% INFO    : Bus 79210	: V=0.9980467, theta=-61.405253 -> V=1.0, theta=0.0
% INFO    : Bus 79211	: V=1.0044284, theta=-60.880812 -> V=1.0, theta=0.0
% INFO    : Bus 79212	: V=0.9962111, theta=-61.908817 -> V=1.0, theta=0.0
% INFO    : Bus 79213	: V=0.9945723, theta=-62.150011 -> V=1.0, theta=0.0
% INFO    : Bus 79214	: V=0.9948323, theta=-62.211827 -> V=1.0, theta=0.0
% INFO    : Bus 79215	: V=0.984974, theta=-64.137506 -> V=1.0, theta=0.0
% INFO    : Bus 79216	: V=0.9960478, theta=-62.832206 -> V=1.0, theta=0.0
% INFO    : Bus 79217	: V=0.9955512, theta=-62.739778 -> V=1.0, theta=0.0
% INFO    : Bus 79218	: V=0.9933763, theta=-62.321546 -> V=1.0, theta=0.0
% INFO    : Bus 79219	: V=0.9945663, theta=-62.66474 -> V=1.0, theta=0.0
% INFO    : Bus 79220	: V=0.996375, theta=-61.961567 -> V=1.0, theta=0.0
% INFO    : Bus 79221	: V=0.9979013, theta=-61.736395 -> V=1.0, theta=0.0
% INFO    : Bus 79222	: V=1.0025475, theta=-61.196426 -> V=1.0, theta=0.0
% INFO    : Bus 79223	: V=0.9999637, theta=-61.351077 -> V=1.0, theta=0.0
% INFO    : Bus 79224	: V=0.998777, theta=-61.670731 -> V=1.0, theta=0.0
% INFO    : Bus 79225	: V=1.0082876, theta=-60.128724 -> V=1.0, theta=0.0
% INFO    : Bus 79226	: V=0.9914316, theta=-62.882757 -> V=1.0, theta=0.0
% INFO    : Bus 79227	: V=0.9880215, theta=-63.489078 -> V=1.0, theta=0.0
% INFO    : Bus 79228	: V=0.9919306, theta=-62.766758 -> V=1.0, theta=0.0
% INFO    : Bus 79229	: V=0.994955, theta=-61.915296 -> V=1.0, theta=0.0
% INFO    : Bus 79230	: V=0.9595104, theta=-71.309376 -> V=1.0, theta=0.0
% INFO    : Bus 79231	: V=0.9648975, theta=-71.410783 -> V=1.0, theta=0.0
% INFO    : Bus 79232	: V=0.9740052, theta=-69.293402 -> V=1.0, theta=0.0
% INFO    : Bus 79233	: V=0.9675749, theta=-69.247689 -> V=1.0, theta=0.0
% INFO    : Bus 79234	: V=0.9787814, theta=-68.854976 -> V=1.0, theta=0.0
% INFO    : Bus 79235	: V=0.9746522, theta=-68.978996 -> V=1.0, theta=0.0
% INFO    : Bus 79236	: V=0.9914523, theta=-69.882689 -> V=1.0, theta=0.0
% INFO    : Bus 79237	: V=0.9567805, theta=-68.372458 -> V=1.0, theta=0.0
% INFO    : Bus 79238	: V=0.9549558, theta=-67.437345 -> V=1.0, theta=0.0
% INFO    : Bus 79239	: V=0.984698, theta=-63.395244 -> V=1.0, theta=0.0
% INFO    : Bus 79240	: V=1.0026914, theta=-60.34844 -> V=1.0, theta=0.0
% INFO    : Bus 79241	: V=0.9844683, theta=-63.299994 -> V=1.0, theta=0.0
% INFO    : Bus 79242	: V=0.9898253, theta=-61.950421 -> V=1.0, theta=0.0
% INFO    : Bus 79243	: V=0.9892999, theta=-62.255989 -> V=1.0, theta=0.0
% INFO    : Bus 79244	: V=0.9906437, theta=-61.849112 -> V=1.0, theta=0.0
% INFO    : Bus 79245	: V=0.9919954, theta=-61.982003 -> V=1.0, theta=0.0
% INFO    : Bus 79246	: V=0.9894489, theta=-62.233284 -> V=1.0, theta=0.0
% INFO    : Bus 79247	: V=0.9898096, theta=-62.209649 -> V=1.0, theta=0.0
% INFO    : Bus 79248	: V=0.9960517, theta=-61.067202 -> V=1.0, theta=0.0
% INFO    : Bus 79249	: V=0.9907572, theta=-61.849084 -> V=1.0, theta=0.0
% INFO    : Bus 79250	: V=0.9900403, theta=-61.886166 -> V=1.0, theta=0.0
% INFO    : Bus 79251	: V=0.9878011, theta=-61.590895 -> V=1.0, theta=0.0
% INFO    : Bus 79252	: V=0.9962049, theta=-61.044138 -> V=1.0, theta=0.0
% INFO    : Bus 79253	: V=0.9875875, theta=-62.418247 -> V=1.0, theta=0.0
% INFO    : Bus 79254	: V=0.9897538, theta=-62.138082 -> V=1.0, theta=0.0
% INFO    : Bus 79255	: V=0.9888135, theta=-61.521471 -> V=1.0, theta=0.0
% INFO    : Bus 79256	: V=0.9874243, theta=-61.590971 -> V=1.0, theta=0.0
% INFO    : Bus 79257	: V=0.9836312, theta=-61.598819 -> V=1.0, theta=0.0
% INFO    : Bus 79258	: V=0.9908768, theta=-61.240847 -> V=1.0, theta=0.0
% INFO    : Bus 79259	: V=1.0140765, theta=-58.115315 -> V=1.0, theta=0.0
% INFO    : Bus 79260	: V=1.0127123, theta=-58.339492 -> V=1.0, theta=0.0
% INFO    : Bus 79261	: V=1.0020815, theta=-59.822044 -> V=1.0, theta=0.0
% INFO    : Bus 79262	: V=0.9991577, theta=-60.301154 -> V=1.0, theta=0.0
% INFO    : Bus 79263	: V=0.9951943, theta=-60.934088 -> V=1.0, theta=0.0
% INFO    : Bus 79264	: V=0.9953664, theta=-60.915034 -> V=1.0, theta=0.0
% INFO    : Bus 79265	: V=0.9951085, theta=-60.952454 -> V=1.0, theta=0.0
% INFO    : Bus 79266	: V=0.9948105, theta=-60.9868 -> V=1.0, theta=0.0
% INFO    : Bus 79267	: V=0.9941682, theta=-61.174672 -> V=1.0, theta=0.0
% INFO    : Bus 79268	: V=0.9915312, theta=-61.498841 -> V=1.0, theta=0.0
% INFO    : Bus 79269	: V=0.9939069, theta=-61.188071 -> V=1.0, theta=0.0
% INFO    : Bus 79270	: V=0.9906228, theta=-61.773216 -> V=1.0, theta=0.0
% INFO    : Bus 79271	: V=0.991209, theta=-61.549446 -> V=1.0, theta=0.0
% INFO    : Bus 79272	: V=0.9927304, theta=-61.696861 -> V=1.0, theta=0.0
% INFO    : Bus 79273	: V=0.9940577, theta=-61.602184 -> V=1.0, theta=0.0
% INFO    : Bus 79274	: V=0.9893022, theta=-61.886545 -> V=1.0, theta=0.0
% INFO    : Bus 79275	: V=0.986288, theta=-62.018271 -> V=1.0, theta=0.0
% INFO    : Bus 79276	: V=0.986743, theta=-62.050172 -> V=1.0, theta=0.0
% INFO    : Bus 79277	: V=0.9867648, theta=-62.182156 -> V=1.0, theta=0.0
% INFO    : Bus 79278	: V=0.9911811, theta=-61.752181 -> V=1.0, theta=0.0
% INFO    : Bus 79279	: V=0.9890143, theta=-61.997173 -> V=1.0, theta=0.0
% INFO    : Bus 79280	: V=0.9862096, theta=-62.209728 -> V=1.0, theta=0.0
% INFO    : Bus 79281	: V=0.9848628, theta=-62.79 -> V=1.0, theta=0.0
% INFO    : Bus 79282	: V=0.9840206, theta=-62.766834 -> V=1.0, theta=0.0
% INFO    : Bus 79283	: V=0.9844266, theta=-62.779717 -> V=1.0, theta=0.0
% INFO    : Bus 79284	: V=0.9841828, theta=-62.818259 -> V=1.0, theta=0.0
% INFO    : Bus 79285	: V=0.9840645, theta=-62.808915 -> V=1.0, theta=0.0
% INFO    : Bus 79286	: V=0.9840992, theta=-62.69969 -> V=1.0, theta=0.0
% INFO    : Bus 79287	: V=0.9820096, theta=-62.949134 -> V=1.0, theta=0.0
% INFO    : Bus 79288	: V=0.9860509, theta=-62.229369 -> V=1.0, theta=0.0
% INFO    : Bus 79289	: V=0.9814678, theta=-62.684849 -> V=1.0, theta=0.0
% INFO    : Bus 79290	: V=0.9825508, theta=-62.915795 -> V=1.0, theta=0.0
% INFO    : Bus 79291	: V=0.980621, theta=-62.99172 -> V=1.0, theta=0.0
% INFO    : Bus 79292	: V=0.9782851, theta=-63.231448 -> V=1.0, theta=0.0
% INFO    : Bus 79293	: V=0.9778342, theta=-63.281149 -> V=1.0, theta=0.0
% INFO    : Bus 79294	: V=0.9801571, theta=-62.713914 -> V=1.0, theta=0.0
% INFO    : Bus 79295	: V=0.9827345, theta=-62.595098 -> V=1.0, theta=0.0
% INFO    : Bus 79296	: V=0.986325, theta=-62.158275 -> V=1.0, theta=0.0
% INFO    : Bus 79297	: V=0.9827186, theta=-62.223789 -> V=1.0, theta=0.0
% INFO    : Bus 79298	: V=0.9836382, theta=-62.412223 -> V=1.0, theta=0.0
% INFO    : Bus 79299	: V=0.9784266, theta=-63.066079 -> V=1.0, theta=0.0
% INFO    : Bus 79300	: V=0.9806487, theta=-62.697826 -> V=1.0, theta=0.0
% INFO    : Bus 79301	: V=0.9829841, theta=-62.60777 -> V=1.0, theta=0.0
% INFO    : Bus 79302	: V=0.9768886, theta=-63.456249 -> V=1.0, theta=0.0
% INFO    : Bus 79303	: V=0.9756608, theta=-63.592719 -> V=1.0, theta=0.0
% INFO    : Bus 79304	: V=0.9745578, theta=-63.723855 -> V=1.0, theta=0.0
% INFO    : Bus 79305	: V=0.977876, theta=-63.200684 -> V=1.0, theta=0.0
% INFO    : Bus 79306	: V=0.975773, theta=-63.51999 -> V=1.0, theta=0.0
% INFO    : Bus 79307	: V=0.9745142, theta=-63.71461 -> V=1.0, theta=0.0
% INFO    : Bus 79308	: V=0.9753572, theta=-63.644288 -> V=1.0, theta=0.0
% INFO    : Bus 79309	: V=0.974468, theta=-63.724859 -> V=1.0, theta=0.0
% INFO    : Bus 79310	: V=0.9701093, theta=-64.283137 -> V=1.0, theta=0.0
% INFO    : Bus 79311	: V=0.9722725, theta=-64.002664 -> V=1.0, theta=0.0
% INFO    : Bus 79312	: V=0.9647231, theta=-64.884122 -> V=1.0, theta=0.0
% INFO    : Bus 79313	: V=0.9658703, theta=-64.763029 -> V=1.0, theta=0.0
% INFO    : Bus 79314	: V=0.9663074, theta=-64.696258 -> V=1.0, theta=0.0
% INFO    : Bus 79315	: V=0.9618023, theta=-65.250242 -> V=1.0, theta=0.0
% INFO    : Bus 79316	: V=0.9627001, theta=-65.082091 -> V=1.0, theta=0.0
% INFO    : Bus 79317	: V=0.9694261, theta=-64.441499 -> V=1.0, theta=0.0
% INFO    : Bus 79318	: V=0.9712505, theta=-64.314326 -> V=1.0, theta=0.0
% INFO    : Bus 79319	: V=0.9718591, theta=-64.270606 -> V=1.0, theta=0.0
% INFO    : Bus 79320	: V=0.9684933, theta=-64.621282 -> V=1.0, theta=0.0
% INFO    : Bus 79321	: V=0.9762662, theta=-63.602392 -> V=1.0, theta=0.0
% INFO    : Bus 79322	: V=0.9799642, theta=-62.905827 -> V=1.0, theta=0.0
% INFO    : Bus 79323	: V=0.9746345, theta=-63.427579 -> V=1.0, theta=0.0
% INFO    : Bus 79324	: V=0.9741072, theta=-63.875308 -> V=1.0, theta=0.0
% INFO    : Bus 79325	: V=0.9755312, theta=-63.692529 -> V=1.0, theta=0.0
% INFO    : Bus 79326	: V=0.9739668, theta=-63.882624 -> V=1.0, theta=0.0
% INFO    : Bus 79327	: V=0.9687434, theta=-64.519802 -> V=1.0, theta=0.0
% INFO    : Bus 79328	: V=0.9698959, theta=-64.404482 -> V=1.0, theta=0.0
% INFO    : Bus 79329	: V=0.9693104, theta=-64.513247 -> V=1.0, theta=0.0
% INFO    : Bus 79330	: V=0.9727329, theta=-63.890834 -> V=1.0, theta=0.0
% INFO    : Bus 79331	: V=0.974492, theta=-63.676967 -> V=1.0, theta=0.0
% INFO    : Bus 79332	: V=0.9739583, theta=-63.8016 -> V=1.0, theta=0.0
% INFO    : Bus 79333	: V=0.9752613, theta=-63.547214 -> V=1.0, theta=0.0
% INFO    : Bus 79334	: V=0.9734306, theta=-63.871054 -> V=1.0, theta=0.0
% INFO    : Bus 79335	: V=0.9704, theta=-64.322998 -> V=1.0, theta=0.0
% INFO    : Bus 79336	: V=0.9675068, theta=-64.62355 -> V=1.0, theta=0.0
% INFO    : Bus 79337	: V=0.9706331, theta=-64.255973 -> V=1.0, theta=0.0
% INFO    : Bus 79338	: V=0.9675695, theta=-64.817209 -> V=1.0, theta=0.0
% INFO    : Bus 79339	: V=0.975429, theta=-63.883172 -> V=1.0, theta=0.0
% INFO    : Bus 79340	: V=0.9799754, theta=-63.484655 -> V=1.0, theta=0.0
% INFO    : Bus 79341	: V=0.9981902, theta=-60.950924 -> V=1.0, theta=0.0
% INFO    : Bus 79342	: V=0.9937388, theta=-61.597668 -> V=1.0, theta=0.0
% INFO    : Bus 79343	: V=0.9865282, theta=-62.758392 -> V=1.0, theta=0.0
% INFO    : Bus 79344	: V=0.996951, theta=-60.469405 -> V=1.0, theta=0.0
% INFO    : Bus 79345	: V=0.9905782, theta=-61.690917 -> V=1.0, theta=0.0
% INFO    : Bus 79346	: V=0.9899584, theta=-61.984387 -> V=1.0, theta=0.0
% INFO    : Bus 79347	: V=0.9730338, theta=-63.941745 -> V=1.0, theta=0.0
% INFO    : Bus 79348	: V=0.9796011, theta=-62.892456 -> V=1.0, theta=0.0
% INFO    : Bus 79349	: V=0.9843256, theta=-62.446993 -> V=1.0, theta=0.0
% INFO    : Bus 79350	: V=0.9840851, theta=-62.543024 -> V=1.0, theta=0.0
% INFO    : Bus 79351	: V=0.9647747, theta=-65.198065 -> V=1.0, theta=0.0
% INFO    : Bus 79352	: V=0.97053, theta=-64.300582 -> V=1.0, theta=0.0
% INFO    : Bus 79353	: V=0.9806776, theta=-63.278341 -> V=1.0, theta=0.0
% INFO    : Bus 79354	: V=0.977496, theta=-63.707831 -> V=1.0, theta=0.0
% INFO    : Bus 79355	: V=0.9863561, theta=-61.522376 -> V=1.0, theta=0.0
% INFO    : Bus 79356	: V=1.0131605, theta=-58.247793 -> V=1.0, theta=0.0
% INFO    : Bus 79357	: V=1.0058055, theta=-59.297439 -> V=1.0, theta=0.0
% INFO    : Bus 79358	: V=0.9650073, theta=-68.949399 -> V=1.0, theta=0.0
% INFO    : Bus 79359	: V=0.9653885, theta=-69.431012 -> V=1.0, theta=0.0
% INFO    : Bus 79360	: V=0.9642467, theta=-68.800827 -> V=1.0, theta=0.0
% INFO    : Bus 79361	: V=0.9607533, theta=-69.590482 -> V=1.0, theta=0.0
% INFO    : Bus 79362	: V=0.9652152, theta=-68.792305 -> V=1.0, theta=0.0
% INFO    : Bus 79363	: V=0.964433, theta=-68.240061 -> V=1.0, theta=0.0
% INFO    : Bus 79364	: V=0.9639711, theta=-68.072366 -> V=1.0, theta=0.0
% INFO    : Bus 79365	: V=0.9456728, theta=-81.392525 -> V=1.0, theta=0.0
% INFO    : Bus 79366	: V=1.0074735, theta=-60.748361 -> V=1.0, theta=0.0
% INFO    : Bus 79367	: V=1.0140618, theta=-59.357484 -> V=1.0, theta=0.0
% INFO    : Bus 79368	: V=1.0185634, theta=-60.340314 -> V=1.0, theta=0.0
% INFO    : Bus 79369	: V=0.9632622, theta=-69.174937 -> V=1.0, theta=0.0
% INFO    : Bus 79370	: V=0.9855403, theta=-64.760452 -> V=1.0, theta=0.0
% INFO    : Bus 79371	: V=0.9980653, theta=-63.370362 -> V=1.0, theta=0.0
% INFO    : Bus 79372	: V=0.9974278, theta=-62.06256 -> V=1.0, theta=0.0
% INFO    : Bus 79373	: V=0.9837364, theta=-64.712461 -> V=1.0, theta=0.0
% INFO    : Bus 79374	: V=0.9715444, theta=-66.350008 -> V=1.0, theta=0.0
% INFO    : Bus 79375	: V=0.9770919, theta=-66.529365 -> V=1.0, theta=0.0
% INFO    : Bus 79376	: V=0.9596621, theta=-70.035542 -> V=1.0, theta=0.0
% INFO    : Bus 79377	: V=0.9838729, theta=-69.31332 -> V=1.0, theta=0.0
% INFO    : Bus 79378	: V=0.9720644, theta=-61.335554 -> V=1.0, theta=0.0
% INFO    : Bus 79379	: V=0.9725154, theta=-61.368068 -> V=1.0, theta=0.0
% INFO    : Bus 79380	: V=1.0031737, theta=-58.391523 -> V=1.0, theta=0.0
% INFO    : Bus 79381	: V=1.0034085, theta=-58.346383 -> V=1.0, theta=0.0
% INFO    : Bus 79382	: V=0.9722452, theta=-69.822149 -> V=1.0, theta=0.0
% INFO    : Bus 79383	: V=0.9507967, theta=-73.624279 -> V=1.0, theta=0.0
% INFO    : Bus 79384	: V=0.9548136, theta=-74.572316 -> V=1.0, theta=0.0
% INFO    : Bus 79385	: V=0.9466997, theta=-81.450642 -> V=1.0, theta=0.0
% INFO    : Bus 79386	: V=0.9488477, theta=-79.777981 -> V=1.0, theta=0.0
% INFO    : Bus 79387	: V=0.9469425, theta=-80.858181 -> V=1.0, theta=0.0
% INFO    : Bus 79388	: V=0.9667784, theta=-70.413863 -> V=1.0, theta=0.0
% INFO    : Bus 79389	: V=0.9685202, theta=-70.798939 -> V=1.0, theta=0.0
% INFO    : Bus 79390	: V=0.9721782, theta=-70.594161 -> V=1.0, theta=0.0
% INFO    : Bus 79391	: V=0.9840333, theta=-71.601043 -> V=1.0, theta=0.0
% INFO    : Bus 79392	: V=0.9841135, theta=-71.203758 -> V=1.0, theta=0.0
% INFO    : Bus 79393	: V=0.9918439, theta=-70.356573 -> V=1.0, theta=0.0
% INFO    : Bus 79394	: V=0.996296, theta=-69.535719 -> V=1.0, theta=0.0
% INFO    : Bus 79395	: V=0.9938191, theta=-70.021774 -> V=1.0, theta=0.0
% INFO    : Bus 79396	: V=0.9956366, theta=-69.228984 -> V=1.0, theta=0.0
% INFO    : Bus 79397	: V=0.9997428, theta=-68.979326 -> V=1.0, theta=0.0
% INFO    : Bus 79398	: V=0.9653752, theta=-75.105091 -> V=1.0, theta=0.0
% INFO    : Bus 79399	: V=0.9857761, theta=-74.282839 -> V=1.0, theta=0.0
% INFO    : Bus 79400	: V=1.0008679, theta=-72.216095 -> V=1.0, theta=0.0
% INFO    : Bus 79401	: V=0.9994518, theta=-72.260602 -> V=1.0, theta=0.0
% INFO    : Bus 79402	: V=0.9680923, theta=-61.147822 -> V=1.0, theta=0.0
% INFO    : Bus 79403	: V=0.9717974, theta=-59.542668 -> V=1.0, theta=0.0
% INFO    : Bus 79404	: V=0.9795367, theta=-59.996218 -> V=1.0, theta=0.0
% INFO    : Bus 79405	: V=0.975051, theta=-57.495148 -> V=1.0, theta=0.0
% INFO    : Bus 79406	: V=0.9786679, theta=-57.694774 -> V=1.0, theta=0.0
% INFO    : Bus 79407	: V=0.977926, theta=-57.632355 -> V=1.0, theta=0.0
% INFO    : Bus 79408	: V=0.9763797, theta=-58.079529 -> V=1.0, theta=0.0
% INFO    : Bus 79409	: V=0.9958354, theta=-55.74737 -> V=1.0, theta=0.0
% INFO    : Bus 79410	: V=0.9830936, theta=-60.200061 -> V=1.0, theta=0.0
% INFO    : Bus 79411	: V=0.9821808, theta=-60.240277 -> V=1.0, theta=0.0
% INFO    : Bus 79412	: V=0.989356, theta=-59.481585 -> V=1.0, theta=0.0
% INFO    : Bus 79413	: V=0.985611, theta=-59.82239 -> V=1.0, theta=0.0
% INFO    : Bus 79414	: V=0.9765294, theta=-60.058802 -> V=1.0, theta=0.0
% INFO    : Bus 79415	: V=0.97634, theta=-59.826042 -> V=1.0, theta=0.0
% INFO    : Bus 79416	: V=0.9644352, theta=-70.348792 -> V=1.0, theta=0.0
% INFO    : Bus 79417	: V=0.9649992, theta=-69.951829 -> V=1.0, theta=0.0
% INFO    : Bus 79418	: V=0.9647462, theta=-69.610319 -> V=1.0, theta=0.0
% INFO    : Bus 79419	: V=0.9920092, theta=-61.569468 -> V=1.0, theta=0.0
% INFO    : Bus 79420	: V=0.9919124, theta=-61.608683 -> V=1.0, theta=0.0
% INFO    : Bus 79421	: V=0.9887657, theta=-61.804711 -> V=1.0, theta=0.0
% INFO    : Bus 79422	: V=0.994146, theta=-60.838132 -> V=1.0, theta=0.0
% INFO    : Bus 79423	: V=1.004918, theta=-59.655331 -> V=1.0, theta=0.0
% INFO    : Bus 79424	: V=1.0033431, theta=-60.080911 -> V=1.0, theta=0.0
% INFO    : Bus 79425	: V=0.9897962, theta=-61.716563 -> V=1.0, theta=0.0
% INFO    : Bus 79426	: V=0.9630044, theta=-64.260282 -> V=1.0, theta=0.0
% INFO    : Bus 79427	: V=0.9513215, theta=-64.488739 -> V=1.0, theta=0.0
% INFO    : Bus 79428	: V=0.9554902, theta=-63.992382 -> V=1.0, theta=0.0
% INFO    : Bus 79429	: V=0.958618, theta=-63.589937 -> V=1.0, theta=0.0
% INFO    : Bus 79430	: V=0.9649671, theta=-62.968288 -> V=1.0, theta=0.0
% INFO    : Bus 79431	: V=0.9603302, theta=-63.40734 -> V=1.0, theta=0.0
% INFO    : Bus 79432	: V=0.9520594, theta=-64.540575 -> V=1.0, theta=0.0
% INFO    : Bus 79433	: V=0.9527079, theta=-63.827788 -> V=1.0, theta=0.0
% INFO    : Bus 79434	: V=0.9627867, theta=-62.678538 -> V=1.0, theta=0.0
% INFO    : Bus 79435	: V=0.9539108, theta=-63.53134 -> V=1.0, theta=0.0
% INFO    : Bus 79436	: V=0.9445052, theta=-64.205937 -> V=1.0, theta=0.0
% INFO    : Bus 79437	: V=0.9534637, theta=-63.407765 -> V=1.0, theta=0.0
% INFO    : Bus 79438	: V=0.9537998, theta=-64.034992 -> V=1.0, theta=0.0
% INFO    : Bus 79439	: V=0.9657803, theta=-62.840876 -> V=1.0, theta=0.0
% INFO    : Bus 79440	: V=0.9764041, theta=-68.826077 -> V=1.0, theta=0.0
% INFO    : Bus 79441	: V=0.9594444, theta=-71.695601 -> V=1.0, theta=0.0
% INFO    : Bus 79442	: V=0.9643764, theta=-71.37301 -> V=1.0, theta=0.0
% INFO    : Bus 79443	: V=0.9775774, theta=-62.505506 -> V=1.0, theta=0.0
% INFO    : Bus 79444	: V=0.9764403, theta=-62.58542 -> V=1.0, theta=0.0
% INFO    : Bus 79445	: V=0.9757217, theta=-62.70172 -> V=1.0, theta=0.0
% INFO    : Bus 79446	: V=0.97529, theta=-62.69997 -> V=1.0, theta=0.0
% INFO    : Bus 79447	: V=0.9756235, theta=-62.693633 -> V=1.0, theta=0.0
% INFO    : Bus 79448	: V=0.980517, theta=-62.251446 -> V=1.0, theta=0.0
% INFO    : Bus 79449	: V=0.9802164, theta=-62.219082 -> V=1.0, theta=0.0
% INFO    : Bus 79450	: V=0.9755919, theta=-63.923366 -> V=1.0, theta=0.0
% INFO    : Bus 79451	: V=0.9781147, theta=-62.491037 -> V=1.0, theta=0.0
% INFO    : Bus 79452	: V=0.9803163, theta=-62.731947 -> V=1.0, theta=0.0
% INFO    : Bus 79453	: V=0.9833534, theta=-62.729586 -> V=1.0, theta=0.0
% INFO    : Bus 79454	: V=0.9873746, theta=-61.364174 -> V=1.0, theta=0.0
% INFO    : Bus 79455	: V=0.9824833, theta=-62.258898 -> V=1.0, theta=0.0
% INFO    : Bus 79456	: V=0.977333, theta=-62.650457 -> V=1.0, theta=0.0
% INFO    : Bus 79457	: V=0.9681803, theta=-63.304827 -> V=1.0, theta=0.0
% INFO    : Bus 79458	: V=0.9793634, theta=-61.232426 -> V=1.0, theta=0.0
% INFO    : Bus 79459	: V=0.9789965, theta=-61.323288 -> V=1.0, theta=0.0
% INFO    : Bus 79460	: V=0.9746475, theta=-61.620251 -> V=1.0, theta=0.0
% INFO    : Bus 79461	: V=0.9699022, theta=-63.200671 -> V=1.0, theta=0.0
% INFO    : Bus 79462	: V=0.9701166, theta=-62.655547 -> V=1.0, theta=0.0
% INFO    : Bus 79463	: V=0.9744303, theta=-62.628794 -> V=1.0, theta=0.0
% INFO    : Bus 79464	: V=0.9790725, theta=-62.437099 -> V=1.0, theta=0.0
% INFO    : Bus 79465	: V=0.9801779, theta=-62.350521 -> V=1.0, theta=0.0
% INFO    : Bus 79466	: V=0.994126, theta=-58.766787 -> V=1.0, theta=0.0
% INFO    : Bus 79467	: V=1.0113964, theta=-52.912978 -> V=1.0, theta=0.0
% INFO    : Bus 79468	: V=1.0188348, theta=-55.965409 -> V=1.0, theta=0.0
% INFO    : Bus 79469	: V=1.0164049, theta=-56.150474 -> V=1.0, theta=0.0
% INFO    : Bus 79470	: V=0.9896604, theta=-56.504674 -> V=1.0, theta=0.0
% INFO    : Bus 79471	: V=1.015868, theta=-44.139645 -> V=1.0, theta=0.0
% INFO    : Bus 79472	: V=1.0135767, theta=-56.410281 -> V=1.0, theta=0.0
% INFO    : Bus 79473	: V=1.0176065, theta=-52.221699 -> V=1.0, theta=0.0
% INFO    : Bus 79474	: V=1.0194117, theta=-52.100283 -> V=1.0, theta=0.0
% INFO    : Bus 79475	: V=1.0041777, theta=-53.92479 -> V=1.0, theta=0.0
% INFO    : Bus 79476	: V=1.0184068, theta=-48.076823 -> V=1.0, theta=0.0
% INFO    : Bus 79477	: V=1.0186099, theta=-48.004378 -> V=1.0, theta=0.0
% INFO    : Bus 79478	: V=1.0036029, theta=-54.306057 -> V=1.0, theta=0.0
% INFO    : Bus 79479	: V=1.011533, theta=-48.657234 -> V=1.0, theta=0.0
% INFO    : Bus 79480	: V=1.0080293, theta=-49.139251 -> V=1.0, theta=0.0
% INFO    : Bus 79481	: V=1.0072944, theta=-49.224002 -> V=1.0, theta=0.0
% INFO    : Bus 79482	: V=1.0156809, theta=-46.484115 -> V=1.0, theta=0.0
% INFO    : Bus 79483	: V=1.0133105, theta=-46.827785 -> V=1.0, theta=0.0
% INFO    : Bus 79484	: V=1.0127136, theta=-46.955525 -> V=1.0, theta=0.0
% INFO    : Bus 79485	: V=1.0179137, theta=-52.871662 -> V=1.0, theta=0.0
% INFO    : Bus 79486	: V=1.02, theta=-52.715106 -> V=1.0, theta=0.0
% INFO    : Bus 79487	: V=0.9911611, theta=-54.981087 -> V=1.0, theta=0.0
% INFO    : Bus 79488	: V=0.9892128, theta=-55.04718 -> V=1.0, theta=0.0
% INFO    : Bus 79489	: V=0.9885039, theta=-55.173985 -> V=1.0, theta=0.0
% INFO    : Bus 79490	: V=0.9982364, theta=-56.778693 -> V=1.0, theta=0.0
% INFO    : Bus 79491	: V=0.9981792, theta=-56.092193 -> V=1.0, theta=0.0
% INFO    : Bus 79492	: V=1.0052064, theta=-56.699022 -> V=1.0, theta=0.0
% INFO    : Bus 79493	: V=1.0042004, theta=-56.92329 -> V=1.0, theta=0.0
% INFO    : Bus 79494	: V=1.0146744, theta=-48.516406 -> V=1.0, theta=0.0
% INFO    : Bus 79495	: V=0.9808379, theta=-57.726386 -> V=1.0, theta=0.0
% INFO    : Bus 79496	: V=0.9969813, theta=-55.154034 -> V=1.0, theta=0.0
% INFO    : Bus 79497	: V=0.9970442, theta=-55.311865 -> V=1.0, theta=0.0
% INFO    : Bus 79498	: V=0.9961684, theta=-55.795449 -> V=1.0, theta=0.0
% INFO    : Bus 79499	: V=0.9773523, theta=-57.346845 -> V=1.0, theta=0.0
% INFO    : Bus 79500	: V=0.9869549, theta=-56.682022 -> V=1.0, theta=0.0
% INFO    : Bus 79501	: V=1.0071622, theta=-48.667527 -> V=1.0, theta=0.0
% INFO    : Bus 79502	: V=1.0137357, theta=-48.528877 -> V=1.0, theta=0.0
% INFO    : Bus 79503	: V=1.02, theta=-50.933216 -> V=1.0, theta=0.0
% INFO    : Bus 79504	: V=0.9880914, theta=-55.236939 -> V=1.0, theta=0.0
% INFO    : Bus 79505	: V=0.9814981, theta=-57.058354 -> V=1.0, theta=0.0
% INFO    : Bus 79506	: V=1.0060775, theta=-55.694924 -> V=1.0, theta=0.0
% INFO    : Bus 79507	: V=1.0044204, theta=-55.923428 -> V=1.0, theta=0.0
% INFO    : Bus 79508	: V=1.006349, theta=-51.171518 -> V=1.0, theta=0.0
% INFO    : Bus 79509	: V=1.02, theta=-52.111582 -> V=1.0, theta=0.0
% INFO    : Bus 79510	: V=0.9557618, theta=-56.482134 -> V=1.0, theta=0.0
% INFO    : Bus 79511	: V=0.9849233, theta=-56.64728 -> V=1.0, theta=0.0
% INFO    : Bus 79512	: V=0.9830154, theta=-57.039693 -> V=1.0, theta=0.0
% INFO    : Bus 79513	: V=1.0205408, theta=-51.246775 -> V=1.0, theta=0.0
% INFO    : Bus 79514	: V=1.0017189, theta=-42.475568 -> V=1.0, theta=0.0
% INFO    : Bus 79515	: V=0.9999187, theta=-42.72569 -> V=1.0, theta=0.0
% INFO    : Bus 79516	: V=1.0111836, theta=-36.575034 -> V=1.0, theta=0.0
% INFO    : Bus 79517	: V=1.0081208, theta=-37.183147 -> V=1.0, theta=0.0
% INFO    : Bus 79518	: V=1.0158012, theta=-24.277163 -> V=1.0, theta=0.0
% INFO    : Bus 79519	: V=1.0150701, theta=-24.382654 -> V=1.0, theta=0.0
% INFO    : Bus 79520	: V=0.9996247, theta=-38.478666 -> V=1.0, theta=0.0
% INFO    : Bus 79521	: V=0.9952845, theta=-39.329298 -> V=1.0, theta=0.0
% INFO    : Bus 79522	: V=0.9947661, theta=-39.492338 -> V=1.0, theta=0.0
% INFO    : Bus 79523	: V=1.0162227, theta=-37.294868 -> V=1.0, theta=0.0
% INFO    : Bus 79524	: V=1.0168015, theta=-36.631024 -> V=1.0, theta=0.0
% INFO    : Bus 79525	: V=1.0154342, theta=-36.716302 -> V=1.0, theta=0.0
% INFO    : Bus 79526	: V=1.0132407, theta=-34.635471 -> V=1.0, theta=0.0
% INFO    : Bus 79527	: V=1.0122444, theta=-39.725374 -> V=1.0, theta=0.0
% INFO    : Bus 79528	: V=1.0117704, theta=-39.86031 -> V=1.0, theta=0.0
% INFO    : Bus 79529	: V=1.0070153, theta=-42.035512 -> V=1.0, theta=0.0
% INFO    : Bus 79530	: V=1.0091922, theta=-41.978542 -> V=1.0, theta=0.0
% INFO    : Bus 79531	: V=1.0081466, theta=-35.799512 -> V=1.0, theta=0.0
% INFO    : Bus 79532	: V=1.0072076, theta=-36.69774 -> V=1.0, theta=0.0
% INFO    : Bus 79533	: V=1.0074216, theta=-36.620368 -> V=1.0, theta=0.0
% INFO    : Bus 79534	: V=1.0082148, theta=-27.316714 -> V=1.0, theta=0.0
% INFO    : Bus 79535	: V=1.0058556, theta=-27.949679 -> V=1.0, theta=0.0
% INFO    : Bus 79536	: V=1.0051813, theta=-28.103263 -> V=1.0, theta=0.0
% INFO    : Bus 79537	: V=1.0061096, theta=-38.705042 -> V=1.0, theta=0.0
% INFO    : Bus 79538	: V=1.005312, theta=-38.868276 -> V=1.0, theta=0.0
% INFO    : Bus 79539	: V=1.0073199, theta=-37.207591 -> V=1.0, theta=0.0
% INFO    : Bus 79540	: V=1.02, theta=-35.905052 -> V=1.0, theta=0.0
% INFO    : Bus 79541	: V=1.019558, theta=-36.086035 -> V=1.0, theta=0.0
% INFO    : Bus 79542	: V=1.004372, theta=-36.374082 -> V=1.0, theta=0.0
% INFO    : Bus 79543	: V=1.0072759, theta=-36.026625 -> V=1.0, theta=0.0
% INFO    : Bus 79544	: V=1.0140761, theta=-37.02168 -> V=1.0, theta=0.0
% INFO    : Bus 79545	: V=1.0094702, theta=-24.631838 -> V=1.0, theta=0.0
% INFO    : Bus 79546	: V=1.0134303, theta=-37.87755 -> V=1.0, theta=0.0
% INFO    : Bus 79547	: V=1.0119369, theta=-37.96269 -> V=1.0, theta=0.0
% INFO    : Bus 79548	: V=1.0136643, theta=-39.469811 -> V=1.0, theta=0.0
% INFO    : Bus 79549	: V=0.972927, theta=-45.072814 -> V=1.0, theta=0.0
% INFO    : Bus 79550	: V=1.02, theta=-33.822346 -> V=1.0, theta=0.0
% INFO    : Bus 79551	: V=1.0160048, theta=-34.438858 -> V=1.0, theta=0.0
% INFO    : Bus 79552	: V=1.0151497, theta=-34.625579 -> V=1.0, theta=0.0
% INFO    : Bus 79553	: V=0.9632755, theta=-41.434524 -> V=1.0, theta=0.0
% INFO    : Bus 79554	: V=1.02, theta=-23.684959 -> V=1.0, theta=0.0
% INFO    : Bus 79555	: V=1.007666, theta=-35.60735 -> V=1.0, theta=0.0
% INFO    : Bus 79556	: V=1.0180572, theta=-38.864161 -> V=1.0, theta=0.0
% INFO    : Bus 79557	: V=0.9739393, theta=-37.787971 -> V=1.0, theta=0.0
% INFO    : Bus 79558	: V=1.02, theta=-29.874509 -> V=1.0, theta=0.0
% INFO    : Bus 79559	: V=1.0043612, theta=-38.726803 -> V=1.0, theta=0.0
% INFO    : Bus 79560	: V=0.9975591, theta=-40.62785 -> V=1.0, theta=0.0
% INFO    : Bus 79561	: V=1.0066167, theta=-39.949625 -> V=1.0, theta=0.0
% INFO    : Bus 79562	: V=1.0018907, theta=-40.613399 -> V=1.0, theta=0.0
% INFO    : Bus 79563	: V=0.999913, theta=-40.840878 -> V=1.0, theta=0.0
% INFO    : Bus 79564	: V=1.0114552, theta=-38.63569 -> V=1.0, theta=0.0
% INFO    : Bus 79565	: V=1.0075798, theta=-39.118926 -> V=1.0, theta=0.0
% INFO    : Bus 79566	: V=1.0075056, theta=-39.210516 -> V=1.0, theta=0.0
% INFO    : Bus 79567	: V=1.0153682, theta=-39.266831 -> V=1.0, theta=0.0
% INFO    : Bus 79568	: V=1.0047095, theta=-45.26597 -> V=1.0, theta=0.0
% INFO    : Bus 79569	: V=0.9952023, theta=-41.085677 -> V=1.0, theta=0.0
% INFO    : Bus 79570	: V=0.9750512, theta=-38.877951 -> V=1.0, theta=0.0
% INFO    : Bus 79571	: V=0.9995703, theta=-37.04415 -> V=1.0, theta=0.0
% INFO    : Bus 79572	: V=0.9965381, theta=-43.152363 -> V=1.0, theta=0.0
% INFO    : Bus 79573	: V=0.9583317, theta=-46.902478 -> V=1.0, theta=0.0
% INFO    : Bus 79574	: V=1.0205651, theta=-37.103278 -> V=1.0, theta=0.0
% INFO    : Bus 79575	: V=0.9802929, theta=-43.29832 -> V=1.0, theta=0.0
% INFO    : Bus 79576	: V=1.0159605, theta=-36.366803 -> V=1.0, theta=0.0
% INFO    : Bus 79577	: V=1.0169375, theta=-42.261487 -> V=1.0, theta=0.0
% INFO    : Bus 79578	: V=1.0170051, theta=-42.314916 -> V=1.0, theta=0.0
% INFO    : Bus 79579	: V=1.006132, theta=-47.036508 -> V=1.0, theta=0.0
% INFO    : Bus 79580	: V=1.0061935, theta=-47.212822 -> V=1.0, theta=0.0
% INFO    : Bus 79581	: V=1.0095469, theta=-38.461099 -> V=1.0, theta=0.0
% INFO    : Bus 79582	: V=1.0178513, theta=-38.005497 -> V=1.0, theta=0.0
% INFO    : Bus 79583	: V=1.0178029, theta=-38.022238 -> V=1.0, theta=0.0
% INFO    : Bus 79584	: V=1.0179936, theta=-37.470385 -> V=1.0, theta=0.0
% INFO    : Bus 79585	: V=1.0187798, theta=-37.368043 -> V=1.0, theta=0.0
% INFO    : Bus 79586	: V=1.0170649, theta=-44.584811 -> V=1.0, theta=0.0
% INFO    : Bus 79587	: V=1.0054457, theta=-43.412378 -> V=1.0, theta=0.0
% INFO    : Bus 79588	: V=0.9926777, theta=-44.986915 -> V=1.0, theta=0.0
% INFO    : Bus 79589	: V=0.9882136, theta=-45.480185 -> V=1.0, theta=0.0
% INFO    : Bus 79590	: V=1.01234, theta=-40.193015 -> V=1.0, theta=0.0
% INFO    : Bus 79591	: V=1.0179871, theta=-40.07584 -> V=1.0, theta=0.0
% INFO    : Bus 79592	: V=1.0183621, theta=-39.873955 -> V=1.0, theta=0.0
% INFO    : Bus 79593	: V=1.0159655, theta=-42.449163 -> V=1.0, theta=0.0
% INFO    : Bus 79594	: V=1.0137768, theta=-43.296532 -> V=1.0, theta=0.0
% INFO    : Bus 79595	: V=1.0134348, theta=-43.436132 -> V=1.0, theta=0.0
% INFO    : Bus 79596	: V=1.0123977, theta=-45.752331 -> V=1.0, theta=0.0
% INFO    : Bus 79597	: V=1.0102214, theta=-46.250392 -> V=1.0, theta=0.0
% INFO    : Bus 79598	: V=1.0096192, theta=-46.251712 -> V=1.0, theta=0.0
% INFO    : Bus 79599	: V=1.0105088, theta=-46.272982 -> V=1.0, theta=0.0
% INFO    : Bus 79600	: V=1.0103531, theta=-46.331476 -> V=1.0, theta=0.0
% INFO    : Bus 79601	: V=0.9999886, theta=-41.062846 -> V=1.0, theta=0.0
% INFO    : Bus 79602	: V=0.9929241, theta=-42.036346 -> V=1.0, theta=0.0
% INFO    : Bus 79603	: V=0.9899317, theta=-42.55956 -> V=1.0, theta=0.0
% INFO    : Bus 79604	: V=1.0152348, theta=-40.659834 -> V=1.0, theta=0.0
% INFO    : Bus 79605	: V=0.9895386, theta=-42.284732 -> V=1.0, theta=0.0
% INFO    : Bus 79606	: V=0.9906265, theta=-42.283502 -> V=1.0, theta=0.0
% INFO    : Bus 79607	: V=1.0163438, theta=-40.7393 -> V=1.0, theta=0.0
% INFO    : Bus 79608	: V=1.0135628, theta=-38.848401 -> V=1.0, theta=0.0
% INFO    : Bus 79609	: V=1.0126981, theta=-39.060874 -> V=1.0, theta=0.0
% INFO    : Bus 79610	: V=1.0135364, theta=-39.69339 -> V=1.0, theta=0.0
% INFO    : Bus 79611	: V=1.0077647, theta=-40.591582 -> V=1.0, theta=0.0
% INFO    : Bus 79612	: V=1.0057857, theta=-40.948743 -> V=1.0, theta=0.0
% INFO    : Bus 79613	: V=1.0094971, theta=-41.621852 -> V=1.0, theta=0.0
% INFO    : Bus 79614	: V=0.9960616, theta=-47.379989 -> V=1.0, theta=0.0
% INFO    : Bus 79615	: V=0.9924291, theta=-47.775122 -> V=1.0, theta=0.0
% INFO    : Bus 79616	: V=1.0021322, theta=-41.623274 -> V=1.0, theta=0.0
% INFO    : Bus 79617	: V=1.02, theta=-42.12498 -> V=1.0, theta=0.0
% INFO    : Bus 79618	: V=1.0046323, theta=-40.996742 -> V=1.0, theta=0.0
% INFO    : Bus 79619	: V=1.02, theta=-37.512263 -> V=1.0, theta=0.0
% INFO    : Bus 79620	: V=1.0189865, theta=-37.980883 -> V=1.0, theta=0.0
% INFO    : Bus 79621	: V=1.0177191, theta=-42.454301 -> V=1.0, theta=0.0
% INFO    : Bus 79622	: V=0.9709744, theta=-49.708919 -> V=1.0, theta=0.0
% INFO    : Bus 79623	: V=1.0152091, theta=-38.504671 -> V=1.0, theta=0.0
% INFO    : Bus 79624	: V=1.0124221, theta=-41.332758 -> V=1.0, theta=0.0
% INFO    : Bus 79625	: V=1.0046327, theta=-41.530586 -> V=1.0, theta=0.0
% INFO    : Bus 79626	: V=1.0164905, theta=-38.556397 -> V=1.0, theta=0.0
% INFO    : Bus 79627	: V=1.0032968, theta=-44.084018 -> V=1.0, theta=0.0
% INFO    : Bus 79628	: V=1.0164008, theta=-43.543589 -> V=1.0, theta=0.0
% INFO    : Bus 79629	: V=1.0150047, theta=-38.537939 -> V=1.0, theta=0.0
% INFO    : Bus 79630	: V=1.0076486, theta=-44.744674 -> V=1.0, theta=0.0
% INFO    : Bus 79631	: V=1.0062018, theta=-45.092666 -> V=1.0, theta=0.0
% INFO    : Bus 79632	: V=1.0180828, theta=-38.307993 -> V=1.0, theta=0.0
% INFO    : Bus 79633	: V=1.0147191, theta=-38.265076 -> V=1.0, theta=0.0
% INFO    : Bus 79634	: V=1.0158984, theta=-38.096219 -> V=1.0, theta=0.0
% INFO    : Bus 79635	: V=0.9566495, theta=-50.904983 -> V=1.0, theta=0.0
% INFO    : Bus 79636	: V=0.9907929, theta=-48.315689 -> V=1.0, theta=0.0
% INFO    : Bus 79637	: V=0.970837, theta=-49.622412 -> V=1.0, theta=0.0
% INFO    : Bus 79638	: V=1.0032465, theta=-43.557618 -> V=1.0, theta=0.0
% INFO    : Bus 79639	: V=1.0021856, theta=-43.733292 -> V=1.0, theta=0.0
% INFO    : Bus 79640	: V=1.0162967, theta=-36.5931 -> V=1.0, theta=0.0
% INFO    : Bus 79641	: V=1.0132476, theta=-36.006325 -> V=1.0, theta=0.0
% INFO    : Bus 79642	: V=1.0122548, theta=-38.528579 -> V=1.0, theta=0.0
% INFO    : Bus 79643	: V=1.0144378, theta=-38.424675 -> V=1.0, theta=0.0
% INFO    : Bus 79644	: V=1.0185329, theta=-47.267176 -> V=1.0, theta=0.0
% INFO    : Bus 79645	: V=1.017019, theta=-47.584537 -> V=1.0, theta=0.0
% INFO    : Bus 79646	: V=1.0198773, theta=-41.864834 -> V=1.0, theta=0.0
% INFO    : Bus 79647	: V=1.0176598, theta=-41.924768 -> V=1.0, theta=0.0
% INFO    : Bus 79648	: V=1.0194267, theta=-50.650651 -> V=1.0, theta=0.0
% INFO    : Bus 79649	: V=1.0190203, theta=-50.566924 -> V=1.0, theta=0.0
% INFO    : Bus 79650	: V=1.0185963, theta=-49.664796 -> V=1.0, theta=0.0
% INFO    : Bus 79651	: V=1.018875, theta=-49.466146 -> V=1.0, theta=0.0
% INFO    : Bus 79652	: V=1.0174648, theta=-45.607657 -> V=1.0, theta=0.0
% INFO    : Bus 79653	: V=1.0172674, theta=-45.436741 -> V=1.0, theta=0.0
% INFO    : Bus 79654	: V=1.02, theta=-40.302916 -> V=1.0, theta=0.0
% INFO    : Bus 79655	: V=1.0181772, theta=-40.571534 -> V=1.0, theta=0.0
% INFO    : Bus 79656	: V=1.0126891, theta=-41.680106 -> V=1.0, theta=0.0
% INFO    : Bus 79657	: V=1.0126829, theta=-41.571548 -> V=1.0, theta=0.0
% INFO    : Bus 79658	: V=1.0177877, theta=-35.752077 -> V=1.0, theta=0.0
% INFO    : Bus 79659	: V=1.0176777, theta=-35.511788 -> V=1.0, theta=0.0
% INFO    : Bus 79660	: V=1.0086335, theta=-43.479796 -> V=1.0, theta=0.0
% INFO    : Bus 79661	: V=1.0183786, theta=-48.795859 -> V=1.0, theta=0.0
% INFO    : Bus 79662	: V=1.0161287, theta=-48.98274 -> V=1.0, theta=0.0
% INFO    : Bus 79663	: V=1.0153007, theta=-49.146246 -> V=1.0, theta=0.0
% INFO    : Bus 79664	: V=1.0123357, theta=-31.979358 -> V=1.0, theta=0.0
% INFO    : Bus 79665	: V=1.0135917, theta=-31.817244 -> V=1.0, theta=0.0
% INFO    : Bus 79666	: V=1.02, theta=-49.296791 -> V=1.0, theta=0.0
% INFO    : Bus 79667	: V=1.0189238, theta=-50.91652 -> V=1.0, theta=0.0
% INFO    : Bus 79668	: V=1.0100352, theta=-51.818545 -> V=1.0, theta=0.0
% INFO    : Bus 79669	: V=1.0102277, theta=-50.00957 -> V=1.0, theta=0.0
% INFO    : Bus 79670	: V=1.013964, theta=-32.264068 -> V=1.0, theta=0.0
% INFO    : Bus 79671	: V=0.9909893, theta=-45.366659 -> V=1.0, theta=0.0
% INFO    : Bus 79672	: V=1.0152594, theta=-45.408132 -> V=1.0, theta=0.0
% INFO    : Bus 79673	: V=1.02, theta=-49.904226 -> V=1.0, theta=0.0
% INFO    : Bus 79674	: V=1.02, theta=-44.554688 -> V=1.0, theta=0.0
% INFO    : Bus 79675	: V=1.0160372, theta=-38.925932 -> V=1.0, theta=0.0
% INFO    : Bus 79676	: V=0.9982933, theta=-54.404259 -> V=1.0, theta=0.0
% INFO    : Bus 79677	: V=0.9999485, theta=-54.184842 -> V=1.0, theta=0.0
% INFO    : Bus 79678	: V=1.0101526, theta=-53.009601 -> V=1.0, theta=0.0
% INFO    : Bus 79679	: V=1.0046354, theta=-52.992127 -> V=1.0, theta=0.0
% INFO    : Bus 79680	: V=1.0111193, theta=-52.797348 -> V=1.0, theta=0.0
% INFO    : Bus 79681	: V=1.0151538, theta=-52.275259 -> V=1.0, theta=0.0
% INFO    : Bus 79682	: V=1.0074336, theta=-52.582176 -> V=1.0, theta=0.0
% INFO    : Bus 79683	: V=1.0066124, theta=-57.249523 -> V=1.0, theta=0.0
% INFO    : Bus 79684	: V=1.0134328, theta=-56.400782 -> V=1.0, theta=0.0
% INFO    : Bus 79685	: V=1.0034717, theta=-57.375705 -> V=1.0, theta=0.0
% INFO    : Bus 79686	: V=1.016665, theta=-56.088245 -> V=1.0, theta=0.0
% INFO    : Bus 79687	: V=1.011348, theta=-56.615863 -> V=1.0, theta=0.0
% INFO    : Bus 79688	: V=1.0087749, theta=-56.952876 -> V=1.0, theta=0.0
% INFO    : Bus 79689	: V=1.0076837, theta=-57.221722 -> V=1.0, theta=0.0
% INFO    : Bus 79690	: V=1.0121689, theta=-56.689864 -> V=1.0, theta=0.0
% INFO    : Bus 79691	: V=1.0078123, theta=-57.311035 -> V=1.0, theta=0.0
% INFO    : Bus 79692	: V=1.0013835, theta=-57.708488 -> V=1.0, theta=0.0
% INFO    : Bus 79693	: V=1.0025212, theta=-57.937832 -> V=1.0, theta=0.0
% INFO    : Bus 79694	: V=0.9966038, theta=-58.497146 -> V=1.0, theta=0.0
% INFO    : Bus 79695	: V=0.9812603, theta=-59.314007 -> V=1.0, theta=0.0
% INFO    : Bus 79696	: V=0.999451, theta=-57.651157 -> V=1.0, theta=0.0
% INFO    : Bus 79697	: V=0.9875272, theta=-58.160108 -> V=1.0, theta=0.0
% INFO    : Bus 79698	: V=1.0094287, theta=-56.497123 -> V=1.0, theta=0.0
% INFO    : Bus 79699	: V=1.0077378, theta=-56.799613 -> V=1.0, theta=0.0
% INFO    : Bus 79700	: V=0.9940039, theta=-57.856562 -> V=1.0, theta=0.0
% INFO    : Bus 79701	: V=0.9946559, theta=-57.93072 -> V=1.0, theta=0.0
% INFO    : Bus 79702	: V=0.988471, theta=-58.20049 -> V=1.0, theta=0.0
% INFO    : Bus 79703	: V=0.9863717, theta=-58.063502 -> V=1.0, theta=0.0
% INFO    : Bus 79704	: V=0.9807543, theta=-58.364445 -> V=1.0, theta=0.0
% INFO    : Bus 79705	: V=0.9813824, theta=-58.354002 -> V=1.0, theta=0.0
% INFO    : Bus 79706	: V=0.979561, theta=-58.299623 -> V=1.0, theta=0.0
% INFO    : Bus 79707	: V=0.9902279, theta=-57.118426 -> V=1.0, theta=0.0
% INFO    : Bus 79708	: V=0.9822988, theta=-57.923118 -> V=1.0, theta=0.0
% INFO    : Bus 79709	: V=0.9838485, theta=-57.403663 -> V=1.0, theta=0.0
% INFO    : Bus 79710	: V=0.9941907, theta=-57.19055 -> V=1.0, theta=0.0
% INFO    : Bus 79711	: V=1.0049836, theta=-56.500527 -> V=1.0, theta=0.0
% INFO    : Bus 79712	: V=0.9880664, theta=-57.800087 -> V=1.0, theta=0.0
% INFO    : Bus 79713	: V=0.9838364, theta=-57.430465 -> V=1.0, theta=0.0
% INFO    : Bus 79714	: V=0.9878455, theta=-57.012813 -> V=1.0, theta=0.0
% INFO    : Bus 79715	: V=0.9905818, theta=-57.073882 -> V=1.0, theta=0.0
% INFO    : Bus 79716	: V=0.9875841, theta=-56.464307 -> V=1.0, theta=0.0
% INFO    : Bus 79717	: V=0.9781123, theta=-56.884228 -> V=1.0, theta=0.0
% INFO    : Bus 79718	: V=0.9787647, theta=-56.669239 -> V=1.0, theta=0.0
% INFO    : Bus 79719	: V=0.9993298, theta=-49.581686 -> V=1.0, theta=0.0
% INFO    : Bus 79720	: V=0.9981935, theta=-49.301082 -> V=1.0, theta=0.0
% INFO    : Bus 79721	: V=0.9914409, theta=-49.979214 -> V=1.0, theta=0.0
% INFO    : Bus 79722	: V=0.9938391, theta=-49.587384 -> V=1.0, theta=0.0
% INFO    : Bus 79723	: V=0.9988595, theta=-47.271017 -> V=1.0, theta=0.0
% INFO    : Bus 79724	: V=1.0053196, theta=-45.614997 -> V=1.0, theta=0.0
% INFO    : Bus 79725	: V=1.0039288, theta=-45.362637 -> V=1.0, theta=0.0
% INFO    : Bus 79726	: V=1.0016217, theta=-46.858247 -> V=1.0, theta=0.0
% INFO    : Bus 79727	: V=0.9938794, theta=-45.882357 -> V=1.0, theta=0.0
% INFO    : Bus 79728	: V=1.0058384, theta=-45.173244 -> V=1.0, theta=0.0
% INFO    : Bus 79729	: V=0.9981132, theta=-45.555357 -> V=1.0, theta=0.0
% INFO    : Bus 79730	: V=0.9943461, theta=-46.704333 -> V=1.0, theta=0.0
% INFO    : Bus 79731	: V=0.9970164, theta=-48.59361 -> V=1.0, theta=0.0
% INFO    : Bus 79732	: V=0.9506302, theta=-56.397116 -> V=1.0, theta=0.0
% INFO    : Bus 79733	: V=0.9494347, theta=-56.623768 -> V=1.0, theta=0.0
% INFO    : Bus 79734	: V=0.9479717, theta=-56.730843 -> V=1.0, theta=0.0
% INFO    : Bus 79735	: V=0.9462651, theta=-57.017012 -> V=1.0, theta=0.0
% INFO    : Bus 79736	: V=0.9480182, theta=-56.958918 -> V=1.0, theta=0.0
% INFO    : Bus 79737	: V=0.9484654, theta=-56.88459 -> V=1.0, theta=0.0
% INFO    : Bus 79738	: V=0.9487255, theta=-56.901624 -> V=1.0, theta=0.0
% INFO    : Bus 79739	: V=0.9528838, theta=-56.386945 -> V=1.0, theta=0.0
% INFO    : Bus 79740	: V=0.9514106, theta=-56.328121 -> V=1.0, theta=0.0
% INFO    : Bus 79741	: V=0.9505266, theta=-56.254733 -> V=1.0, theta=0.0
% INFO    : Bus 79742	: V=0.9604465, theta=-55.108181 -> V=1.0, theta=0.0
% INFO    : Bus 79743	: V=0.960392, theta=-55.214237 -> V=1.0, theta=0.0
% INFO    : Bus 79744	: V=0.954512, theta=-55.771784 -> V=1.0, theta=0.0
% INFO    : Bus 79745	: V=0.9512817, theta=-56.064992 -> V=1.0, theta=0.0
% INFO    : Bus 79746	: V=0.9534599, theta=-55.824513 -> V=1.0, theta=0.0
% INFO    : Bus 79747	: V=0.9531209, theta=-55.865543 -> V=1.0, theta=0.0
% INFO    : Bus 79748	: V=0.9535838, theta=-55.851612 -> V=1.0, theta=0.0
% INFO    : Bus 79749	: V=0.9559423, theta=-55.428265 -> V=1.0, theta=0.0
% INFO    : Bus 79750	: V=0.9638451, theta=-54.751488 -> V=1.0, theta=0.0
% INFO    : Bus 79751	: V=0.9618789, theta=-55.058426 -> V=1.0, theta=0.0
% INFO    : Bus 79752	: V=0.9581544, theta=-55.3262 -> V=1.0, theta=0.0
% INFO    : Bus 79753	: V=0.953754, theta=-55.798867 -> V=1.0, theta=0.0
% INFO    : Bus 79754	: V=0.9576256, theta=-55.218843 -> V=1.0, theta=0.0
% INFO    : Bus 79755	: V=0.954731, theta=-55.703183 -> V=1.0, theta=0.0
% INFO    : Bus 79756	: V=0.96407, theta=-54.439985 -> V=1.0, theta=0.0
% INFO    : Bus 79757	: V=0.9572524, theta=-55.34381 -> V=1.0, theta=0.0
% INFO    : Bus 79758	: V=0.9496746, theta=-55.782448 -> V=1.0, theta=0.0
% INFO    : Bus 79759	: V=0.9536388, theta=-55.543851 -> V=1.0, theta=0.0
% INFO    : Bus 79760	: V=0.9516334, theta=-55.752387 -> V=1.0, theta=0.0
% INFO    : Bus 79761	: V=0.9513418, theta=-55.786987 -> V=1.0, theta=0.0
% INFO    : Bus 79762	: V=0.9528037, theta=-55.428569 -> V=1.0, theta=0.0
% INFO    : Bus 79763	: V=0.956572, theta=-54.954197 -> V=1.0, theta=0.0
% INFO    : Bus 79764	: V=0.9569485, theta=-54.960652 -> V=1.0, theta=0.0
% INFO    : Bus 79765	: V=0.9560765, theta=-54.990923 -> V=1.0, theta=0.0
% INFO    : Bus 79766	: V=0.9555628, theta=-55.011993 -> V=1.0, theta=0.0
% INFO    : Bus 79767	: V=0.9560117, theta=-55.009436 -> V=1.0, theta=0.0
% INFO    : Bus 79768	: V=0.9556882, theta=-55.114798 -> V=1.0, theta=0.0
% INFO    : Bus 79769	: V=0.953163, theta=-55.441611 -> V=1.0, theta=0.0
% INFO    : Bus 79770	: V=0.9513294, theta=-55.746355 -> V=1.0, theta=0.0
% INFO    : Bus 79771	: V=0.9517684, theta=-55.668412 -> V=1.0, theta=0.0
% INFO    : Bus 79772	: V=0.9525334, theta=-55.719561 -> V=1.0, theta=0.0
% INFO    : Bus 79773	: V=0.9535007, theta=-55.627575 -> V=1.0, theta=0.0
% INFO    : Bus 79774	: V=0.9526713, theta=-55.735048 -> V=1.0, theta=0.0
% INFO    : Bus 79775	: V=0.9523486, theta=-55.863177 -> V=1.0, theta=0.0
% INFO    : Bus 79776	: V=0.9526994, theta=-55.717088 -> V=1.0, theta=0.0
% INFO    : Bus 79777	: V=0.9527489, theta=-55.703819 -> V=1.0, theta=0.0
% INFO    : Bus 79778	: V=0.9574336, theta=-55.498201 -> V=1.0, theta=0.0
% INFO    : Bus 79779	: V=0.951406, theta=-56.316896 -> V=1.0, theta=0.0
% INFO    : Bus 79780	: V=0.9543268, theta=-55.929819 -> V=1.0, theta=0.0
% INFO    : Bus 79781	: V=0.9606326, theta=-55.456032 -> V=1.0, theta=0.0
% INFO    : Bus 79782	: V=0.9587828, theta=-55.775009 -> V=1.0, theta=0.0
% INFO    : Bus 79783	: V=0.9541426, theta=-56.302965 -> V=1.0, theta=0.0
% INFO    : Bus 79784	: V=0.9520066, theta=-56.357453 -> V=1.0, theta=0.0
% INFO    : Bus 79785	: V=0.9534671, theta=-56.409711 -> V=1.0, theta=0.0
% INFO    : Bus 79786	: V=0.9524918, theta=-56.329269 -> V=1.0, theta=0.0
% INFO    : Bus 79787	: V=0.9543429, theta=-56.278171 -> V=1.0, theta=0.0
% INFO    : Bus 79788	: V=0.9567962, theta=-54.853123 -> V=1.0, theta=0.0
% INFO    : Bus 79789	: V=0.9581323, theta=-54.72379 -> V=1.0, theta=0.0
% INFO    : Bus 79790	: V=0.9502062, theta=-55.722179 -> V=1.0, theta=0.0
% INFO    : Bus 79791	: V=0.9654945, theta=-54.57983 -> V=1.0, theta=0.0
% INFO    : Bus 79792	: V=0.9586621, theta=-55.287641 -> V=1.0, theta=0.0
% INFO    : Bus 79793	: V=0.9537173, theta=-55.348622 -> V=1.0, theta=0.0
% INFO    : Bus 79794	: V=0.9465183, theta=-57.136168 -> V=1.0, theta=0.0
% INFO    : Bus 79795	: V=0.9556344, theta=-54.997313 -> V=1.0, theta=0.0
% INFO    : Bus 79796	: V=0.9528535, theta=-55.498034 -> V=1.0, theta=0.0
% INFO    : Bus 79797	: V=0.9680198, theta=-54.234838 -> V=1.0, theta=0.0
% INFO    : Bus 79798	: V=0.9596352, theta=-55.068267 -> V=1.0, theta=0.0
% INFO    : Bus 79799	: V=0.9548102, theta=-55.564382 -> V=1.0, theta=0.0
% INFO    : Bus 79800	: V=0.9693393, theta=-54.432408 -> V=1.0, theta=0.0
% INFO    : Bus 79801	: V=0.9589535, theta=-55.047982 -> V=1.0, theta=0.0
% INFO    : Bus 79802	: V=0.9565023, theta=-55.750226 -> V=1.0, theta=0.0
% INFO    : Bus 79803	: V=1.0101363, theta=-54.993685 -> V=1.0, theta=0.0
% INFO    : Bus 79804	: V=1.0164335, theta=-53.132628 -> V=1.0, theta=0.0
% INFO    : Bus 79805	: V=1.0093016, theta=-53.910743 -> V=1.0, theta=0.0
% INFO    : Bus 79806	: V=1.0143851, theta=-53.308567 -> V=1.0, theta=0.0
% INFO    : Bus 79807	: V=1.0137286, theta=-53.486728 -> V=1.0, theta=0.0
% INFO    : Bus 79808	: V=1.0108029, theta=-53.635492 -> V=1.0, theta=0.0
% INFO    : Bus 79809	: V=1.0166613, theta=-53.04781 -> V=1.0, theta=0.0
% INFO    : Bus 79810	: V=1.0140902, theta=-53.556855 -> V=1.0, theta=0.0
% INFO    : Bus 79811	: V=1.0020734, theta=-53.739665 -> V=1.0, theta=0.0
% INFO    : Bus 79812	: V=0.9910625, theta=-53.417608 -> V=1.0, theta=0.0
% INFO    : Bus 79813	: V=0.9848265, theta=-54.228907 -> V=1.0, theta=0.0
% INFO    : Bus 79814	: V=0.9885059, theta=-52.125 -> V=1.0, theta=0.0
% INFO    : Bus 79815	: V=0.9521573, theta=-56.705657 -> V=1.0, theta=0.0
% INFO    : Bus 79816	: V=0.9602233, theta=-56.208472 -> V=1.0, theta=0.0
% INFO    : Bus 79817	: V=0.9825991, theta=-54.801718 -> V=1.0, theta=0.0
% INFO    : Bus 79818	: V=0.985063, theta=-54.331201 -> V=1.0, theta=0.0
% INFO    : Bus 79819	: V=0.9888911, theta=-54.664404 -> V=1.0, theta=0.0
% INFO    : Bus 79820	: V=0.9883659, theta=-54.485701 -> V=1.0, theta=0.0
% INFO    : Bus 79821	: V=0.9854585, theta=-54.517896 -> V=1.0, theta=0.0
% INFO    : Bus 79822	: V=0.9858594, theta=-54.495803 -> V=1.0, theta=0.0
% INFO    : Bus 79823	: V=0.9905666, theta=-53.662322 -> V=1.0, theta=0.0
% INFO    : Bus 79824	: V=0.9954394, theta=-53.465112 -> V=1.0, theta=0.0
% INFO    : Bus 79825	: V=0.9922863, theta=-53.613835 -> V=1.0, theta=0.0
% INFO    : Bus 79826	: V=0.9820926, theta=-56.161137 -> V=1.0, theta=0.0
% INFO    : Bus 79827	: V=0.9858107, theta=-56.08279 -> V=1.0, theta=0.0
% INFO    : Bus 79828	: V=0.9716194, theta=-56.809922 -> V=1.0, theta=0.0
% INFO    : Bus 79829	: V=0.9673525, theta=-57.038131 -> V=1.0, theta=0.0
% INFO    : Bus 79830	: V=0.96585, theta=-57.206385 -> V=1.0, theta=0.0
% INFO    : Bus 79831	: V=0.9710195, theta=-56.580509 -> V=1.0, theta=0.0
% INFO    : Bus 79832	: V=0.9859933, theta=-54.783075 -> V=1.0, theta=0.0
% INFO    : Bus 79833	: V=0.9846937, theta=-55.032254 -> V=1.0, theta=0.0
% INFO    : Bus 79834	: V=0.9844166, theta=-55.183932 -> V=1.0, theta=0.0
% INFO    : Bus 79835	: V=0.9800809, theta=-56.059611 -> V=1.0, theta=0.0
% INFO    : Bus 79836	: V=0.9755362, theta=-56.451456 -> V=1.0, theta=0.0
% INFO    : Bus 79837	: V=0.9635281, theta=-57.227468 -> V=1.0, theta=0.0
% INFO    : Bus 79838	: V=0.9633052, theta=-57.222755 -> V=1.0, theta=0.0
% INFO    : Bus 79839	: V=0.9653576, theta=-57.261025 -> V=1.0, theta=0.0
% INFO    : Bus 79840	: V=0.9631652, theta=-57.327083 -> V=1.0, theta=0.0
% INFO    : Bus 79841	: V=0.9576674, theta=-57.546246 -> V=1.0, theta=0.0
% INFO    : Bus 79842	: V=0.9627363, theta=-57.075812 -> V=1.0, theta=0.0
% INFO    : Bus 79843	: V=0.9560195, theta=-57.085442 -> V=1.0, theta=0.0
% INFO    : Bus 79844	: V=0.9798541, theta=-56.95012 -> V=1.0, theta=0.0
% INFO    : Bus 79845	: V=0.9669304, theta=-57.554777 -> V=1.0, theta=0.0
% INFO    : Bus 79846	: V=0.9676697, theta=-57.324443 -> V=1.0, theta=0.0
% INFO    : Bus 79847	: V=0.9665389, theta=-57.327438 -> V=1.0, theta=0.0
% INFO    : Bus 79848	: V=0.9650866, theta=-57.31705 -> V=1.0, theta=0.0
% INFO    : Bus 79849	: V=0.9746395, theta=-57.190403 -> V=1.0, theta=0.0
% INFO    : Bus 79850	: V=0.9635273, theta=-57.840986 -> V=1.0, theta=0.0
% INFO    : Bus 79851	: V=0.9637372, theta=-56.818582 -> V=1.0, theta=0.0
% INFO    : Bus 79852	: V=0.9560161, theta=-58.731257 -> V=1.0, theta=0.0
% INFO    : Bus 79853	: V=0.9543977, theta=-58.871464 -> V=1.0, theta=0.0
% INFO    : Bus 79854	: V=0.9547062, theta=-59.071353 -> V=1.0, theta=0.0
% INFO    : Bus 79855	: V=0.9543543, theta=-58.986317 -> V=1.0, theta=0.0
% INFO    : Bus 79856	: V=0.9549651, theta=-59.265218 -> V=1.0, theta=0.0
% INFO    : Bus 79857	: V=0.9543146, theta=-59.178128 -> V=1.0, theta=0.0
% INFO    : Bus 79858	: V=0.9527967, theta=-59.307846 -> V=1.0, theta=0.0
% INFO    : Bus 79859	: V=0.9541455, theta=-59.363353 -> V=1.0, theta=0.0
% INFO    : Bus 79860	: V=0.9546136, theta=-59.323402 -> V=1.0, theta=0.0
% INFO    : Bus 79861	: V=0.9543498, theta=-59.377615 -> V=1.0, theta=0.0
% INFO    : Bus 79862	: V=0.9538885, theta=-59.380696 -> V=1.0, theta=0.0
% INFO    : Bus 79863	: V=0.9519006, theta=-59.83339 -> V=1.0, theta=0.0
% INFO    : Bus 79864	: V=0.9545484, theta=-59.439931 -> V=1.0, theta=0.0
% INFO    : Bus 79865	: V=0.9648812, theta=-58.494722 -> V=1.0, theta=0.0
% INFO    : Bus 79866	: V=0.9609371, theta=-59.028674 -> V=1.0, theta=0.0
% INFO    : Bus 79867	: V=0.9567684, theta=-59.349591 -> V=1.0, theta=0.0
% INFO    : Bus 79868	: V=0.9561627, theta=-59.183716 -> V=1.0, theta=0.0
% INFO    : Bus 79869	: V=0.9557554, theta=-59.783431 -> V=1.0, theta=0.0
% INFO    : Bus 79870	: V=0.9557636, theta=-59.877834 -> V=1.0, theta=0.0
% INFO    : Bus 79871	: V=0.9576323, theta=-59.705963 -> V=1.0, theta=0.0
% INFO    : Bus 79872	: V=0.9801181, theta=-59.259802 -> V=1.0, theta=0.0
% INFO    : Bus 79873	: V=0.9581427, theta=-59.74623 -> V=1.0, theta=0.0
% INFO    : Bus 79874	: V=0.9615116, theta=-59.68923 -> V=1.0, theta=0.0
% INFO    : Bus 79875	: V=0.9565381, theta=-59.853865 -> V=1.0, theta=0.0
% INFO    : Bus 79876	: V=0.9872431, theta=-57.243947 -> V=1.0, theta=0.0
% INFO    : Bus 79877	: V=0.9806041, theta=-57.658349 -> V=1.0, theta=0.0
% INFO    : Bus 79878	: V=0.9825412, theta=-57.605824 -> V=1.0, theta=0.0
% INFO    : Bus 79879	: V=0.9814912, theta=-57.661608 -> V=1.0, theta=0.0
% INFO    : Bus 79880	: V=0.9807739, theta=-57.688495 -> V=1.0, theta=0.0
% INFO    : Bus 79881	: V=0.9766185, theta=-57.771689 -> V=1.0, theta=0.0
% INFO    : Bus 79882	: V=0.9804313, theta=-57.730578 -> V=1.0, theta=0.0
% INFO    : Bus 79883	: V=0.9789377, theta=-57.718609 -> V=1.0, theta=0.0
% INFO    : Bus 79884	: V=0.9899416, theta=-56.259393 -> V=1.0, theta=0.0
% INFO    : Bus 79885	: V=0.9970076, theta=-55.684952 -> V=1.0, theta=0.0
% INFO    : Bus 79886	: V=0.9960962, theta=-55.598292 -> V=1.0, theta=0.0
% INFO    : Bus 79887	: V=0.9910733, theta=-56.1193 -> V=1.0, theta=0.0
% INFO    : Bus 79888	: V=0.9907742, theta=-56.182775 -> V=1.0, theta=0.0
% INFO    : Bus 79889	: V=0.99213, theta=-55.97631 -> V=1.0, theta=0.0
% INFO    : Bus 79890	: V=1.0016108, theta=-54.919167 -> V=1.0, theta=0.0
% INFO    : Bus 79891	: V=1.0023933, theta=-54.765722 -> V=1.0, theta=0.0
% INFO    : Bus 79892	: V=1.0008359, theta=-55.237057 -> V=1.0, theta=0.0
% INFO    : Bus 79893	: V=0.9639523, theta=-58.056992 -> V=1.0, theta=0.0
% INFO    : Bus 79894	: V=0.9758193, theta=-57.136393 -> V=1.0, theta=0.0
% INFO    : Bus 79895	: V=0.9598774, theta=-58.368946 -> V=1.0, theta=0.0
% INFO    : Bus 79896	: V=0.9625536, theta=-58.129995 -> V=1.0, theta=0.0
% INFO    : Bus 79897	: V=0.9596788, theta=-58.616966 -> V=1.0, theta=0.0
% INFO    : Bus 79898	: V=0.9823008, theta=-57.355074 -> V=1.0, theta=0.0
% INFO    : Bus 79899	: V=0.9844058, theta=-57.214469 -> V=1.0, theta=0.0
% INFO    : Bus 79900	: V=0.9778657, theta=-57.524899 -> V=1.0, theta=0.0
% INFO    : Bus 79901	: V=0.9796702, theta=-57.487083 -> V=1.0, theta=0.0
% INFO    : Bus 79902	: V=0.991868, theta=-56.38341 -> V=1.0, theta=0.0
% INFO    : Bus 79903	: V=0.9920073, theta=-56.382247 -> V=1.0, theta=0.0
% INFO    : Bus 79904	: V=0.9958717, theta=-56.008503 -> V=1.0, theta=0.0
% INFO    : Bus 79905	: V=0.9950196, theta=-56.211819 -> V=1.0, theta=0.0
% INFO    : Bus 79906	: V=0.983981, theta=-57.358099 -> V=1.0, theta=0.0
% INFO    : Bus 79907	: V=0.9968269, theta=-55.957674 -> V=1.0, theta=0.0
% INFO    : Bus 79908	: V=0.9951709, theta=-56.317715 -> V=1.0, theta=0.0
% INFO    : Bus 79909	: V=0.9876635, theta=-57.024178 -> V=1.0, theta=0.0
% INFO    : Bus 79910	: V=1.0068947, theta=-54.967029 -> V=1.0, theta=0.0
% INFO    : Bus 79911	: V=1.0047318, theta=-55.113851 -> V=1.0, theta=0.0
% INFO    : Bus 79912	: V=0.9880867, theta=-56.365822 -> V=1.0, theta=0.0
% INFO    : Bus 79913	: V=0.9954604, theta=-55.984802 -> V=1.0, theta=0.0
% INFO    : Bus 79914	: V=0.9574155, theta=-59.752326 -> V=1.0, theta=0.0
% INFO    : Bus 79915	: V=0.956931, theta=-59.696039 -> V=1.0, theta=0.0
% INFO    : Bus 79916	: V=0.9615329, theta=-58.851894 -> V=1.0, theta=0.0
% INFO    : Bus 79917	: V=0.9652565, theta=-58.612016 -> V=1.0, theta=0.0
% INFO    : Bus 79918	: V=0.9651841, theta=-58.619377 -> V=1.0, theta=0.0
% INFO    : Bus 79919	: V=0.9664994, theta=-58.586834 -> V=1.0, theta=0.0
% INFO    : Bus 79920	: V=0.966508, theta=-58.619658 -> V=1.0, theta=0.0
% INFO    : Bus 79921	: V=0.9683346, theta=-58.589596 -> V=1.0, theta=0.0
% INFO    : Bus 79922	: V=0.9698674, theta=-58.383686 -> V=1.0, theta=0.0
% INFO    : Bus 79923	: V=0.9709907, theta=-58.263358 -> V=1.0, theta=0.0
% INFO    : Bus 79924	: V=0.9900082, theta=-56.241928 -> V=1.0, theta=0.0
% INFO    : Bus 79925	: V=0.9868245, theta=-51.88615 -> V=1.0, theta=0.0
% INFO    : Bus 79926	: V=0.9895655, theta=-51.783175 -> V=1.0, theta=0.0
% INFO    : Bus 79927	: V=0.9976629, theta=-50.490041 -> V=1.0, theta=0.0
% INFO    : Bus 79928	: V=1.0007859, theta=-50.70685 -> V=1.0, theta=0.0
% INFO    : Bus 79929	: V=1.0099076, theta=-49.181428 -> V=1.0, theta=0.0
% INFO    : Bus 79930	: V=1.0071628, theta=-49.221224 -> V=1.0, theta=0.0
% INFO    : Bus 79931	: V=1.0132663, theta=-48.700341 -> V=1.0, theta=0.0
% INFO    : Bus 79932	: V=0.9922183, theta=-50.970742 -> V=1.0, theta=0.0
% INFO    : Bus 79933	: V=0.9570285, theta=-59.136248 -> V=1.0, theta=0.0
% INFO    : Bus 79934	: V=0.9749064, theta=-60.238592 -> V=1.0, theta=0.0
% INFO    : Bus 79935	: V=0.9732119, theta=-59.89564 -> V=1.0, theta=0.0
% INFO    : Bus 79936	: V=0.9723974, theta=-59.655757 -> V=1.0, theta=0.0
% INFO    : Bus 79937	: V=0.9761446, theta=-59.004409 -> V=1.0, theta=0.0
% INFO    : Bus 79938	: V=0.9772117, theta=-59.175598 -> V=1.0, theta=0.0
% INFO    : Bus 79939	: V=0.9700513, theta=-59.660201 -> V=1.0, theta=0.0
% INFO    : Bus 79940	: V=0.9681429, theta=-59.617469 -> V=1.0, theta=0.0
% INFO    : Bus 79941	: V=0.9686935, theta=-59.751015 -> V=1.0, theta=0.0
% INFO    : Bus 79942	: V=0.9702302, theta=-59.80197 -> V=1.0, theta=0.0
% INFO    : Bus 79943	: V=0.9750985, theta=-58.761363 -> V=1.0, theta=0.0
% INFO    : Bus 79944	: V=0.9800264, theta=-57.327816 -> V=1.0, theta=0.0
% INFO    : Bus 79945	: V=0.974334, theta=-57.669138 -> V=1.0, theta=0.0
% INFO    : Bus 79946	: V=0.9657857, theta=-59.097115 -> V=1.0, theta=0.0
% INFO    : Bus 79947	: V=0.9821857, theta=-57.199763 -> V=1.0, theta=0.0
% INFO    : Bus 79948	: V=0.9962298, theta=-56.748462 -> V=1.0, theta=0.0
% INFO    : Bus 79949	: V=0.9969731, theta=-56.908093 -> V=1.0, theta=0.0
% INFO    : Bus 79950	: V=1.0007286, theta=-56.779364 -> V=1.0, theta=0.0
% INFO    : Bus 79951	: V=1.0008635, theta=-56.818554 -> V=1.0, theta=0.0
% INFO    : Bus 79952	: V=1.0014231, theta=-56.708954 -> V=1.0, theta=0.0
% INFO    : Bus 79953	: V=0.9984219, theta=-56.963252 -> V=1.0, theta=0.0
% INFO    : Bus 79954	: V=0.9837004, theta=-58.291792 -> V=1.0, theta=0.0
% INFO    : Bus 79955	: V=0.9872292, theta=-58.135973 -> V=1.0, theta=0.0
% INFO    : Bus 79956	: V=0.9882745, theta=-57.839623 -> V=1.0, theta=0.0
% INFO    : Bus 79957	: V=1.010196, theta=-56.043624 -> V=1.0, theta=0.0
% INFO    : Bus 79958	: V=1.0054963, theta=-56.586569 -> V=1.0, theta=0.0
% INFO    : Bus 79959	: V=1.0033496, theta=-56.898371 -> V=1.0, theta=0.0
% INFO    : Bus 79960	: V=0.9962334, theta=-49.012442 -> V=1.0, theta=0.0
% INFO    : Bus 79961	: V=0.9965296, theta=-48.988614 -> V=1.0, theta=0.0
% INFO    : Bus 79962	: V=0.9947315, theta=-48.85047 -> V=1.0, theta=0.0
% INFO    : Bus 79963	: V=0.9993077, theta=-49.29899 -> V=1.0, theta=0.0
% INFO    : Bus 79964	: V=0.9836749, theta=-51.011842 -> V=1.0, theta=0.0
% INFO    : Bus 79965	: V=0.9881887, theta=-50.033954 -> V=1.0, theta=0.0
% INFO    : Bus 79966	: V=0.9885455, theta=-50.802275 -> V=1.0, theta=0.0
% INFO    : Bus 79967	: V=1.0005173, theta=-48.82353 -> V=1.0, theta=0.0
% INFO    : Bus 79968	: V=0.9986964, theta=-49.118919 -> V=1.0, theta=0.0
% INFO    : Bus 79969	: V=1.004294, theta=-47.306996 -> V=1.0, theta=0.0
% INFO    : Bus 79970	: V=0.9976055, theta=-49.295811 -> V=1.0, theta=0.0
% INFO    : Bus 79971	: V=0.9815307, theta=-50.76176 -> V=1.0, theta=0.0
% INFO    : Bus 79972	: V=1.006151, theta=-49.810654 -> V=1.0, theta=0.0
% INFO    : Bus 79973	: V=1.0149031, theta=-48.9365 -> V=1.0, theta=0.0
% INFO    : Bus 79974	: V=1.0186944, theta=-48.745103 -> V=1.0, theta=0.0
% INFO    : Bus 79975	: V=1.0168112, theta=-48.934176 -> V=1.0, theta=0.0
% INFO    : Bus 79976	: V=1.0103139, theta=-49.232492 -> V=1.0, theta=0.0
% INFO    : Bus 79977	: V=1.0128143, theta=-48.537841 -> V=1.0, theta=0.0
% INFO    : Bus 79978	: V=0.9770613, theta=-57.992999 -> V=1.0, theta=0.0
% INFO    : Bus 79979	: V=0.9739879, theta=-57.649949 -> V=1.0, theta=0.0
% INFO    : Bus 79980	: V=0.9736888, theta=-57.780199 -> V=1.0, theta=0.0
% INFO    : Bus 79981	: V=0.9747146, theta=-57.85083 -> V=1.0, theta=0.0
% INFO    : Bus 79982	: V=0.9856553, theta=-56.571279 -> V=1.0, theta=0.0
% INFO    : Bus 79983	: V=0.9776683, theta=-57.617058 -> V=1.0, theta=0.0
% INFO    : Bus 79984	: V=0.9736179, theta=-57.933836 -> V=1.0, theta=0.0
% INFO    : Bus 79985	: V=0.9796887, theta=-57.452949 -> V=1.0, theta=0.0
% INFO    : Bus 79986	: V=0.9852552, theta=-56.904602 -> V=1.0, theta=0.0
% INFO    : Bus 79987	: V=0.9853742, theta=-56.921257 -> V=1.0, theta=0.0
% INFO    : Bus 79988	: V=0.9765639, theta=-57.288312 -> V=1.0, theta=0.0
% INFO    : Bus 79989	: V=0.9888155, theta=-56.318936 -> V=1.0, theta=0.0
% INFO    : Bus 79990	: V=0.987203, theta=-56.688544 -> V=1.0, theta=0.0
% INFO    : Bus 79991	: V=0.9811895, theta=-56.818704 -> V=1.0, theta=0.0
% INFO    : Bus 79992	: V=0.9904951, theta=-55.771173 -> V=1.0, theta=0.0
% INFO    : Bus 79993	: V=0.9893326, theta=-56.104024 -> V=1.0, theta=0.0
% INFO    : Bus 79994	: V=0.9819984, theta=-56.88454 -> V=1.0, theta=0.0
% INFO    : Bus 79995	: V=0.9788804, theta=-57.491068 -> V=1.0, theta=0.0
% INFO    : Bus 79996	: V=0.9821163, theta=-57.919892 -> V=1.0, theta=0.0
% INFO    : Bus 79997	: V=0.978079, theta=-58.784979 -> V=1.0, theta=0.0
% INFO    : Bus 79998	: V=0.9901398, theta=-56.401127 -> V=1.0, theta=0.0
% INFO    : Bus 79999	: V=0.9862682, theta=-56.847365 -> V=1.0, theta=0.0
% INFO    : Bus 80000	: V=0.9841067, theta=-57.170365 -> V=1.0, theta=0.0
% INFO    : Bus 80001	: V=0.9901317, theta=-55.849743 -> V=1.0, theta=0.0
% INFO    : Bus 80002	: V=1.020598, theta=-51.411525 -> V=1.0, theta=0.0
% INFO    : Bus 80003	: V=1.0204607, theta=-51.019692 -> V=1.0, theta=0.0
% INFO    : Bus 80004	: V=1.0200347, theta=-51.04769 -> V=1.0, theta=0.0
% INFO    : Bus 80005	: V=1.0179043, theta=-49.756 -> V=1.0, theta=0.0
% INFO    : Bus 80006	: V=0.9790166, theta=-58.107805 -> V=1.0, theta=0.0
% INFO    : Bus 80007	: V=0.985495, theta=-57.881114 -> V=1.0, theta=0.0
% INFO    : Bus 80008	: V=0.9849625, theta=-57.918168 -> V=1.0, theta=0.0
% INFO    : Bus 80009	: V=0.9915474, theta=-57.174202 -> V=1.0, theta=0.0
% INFO    : Bus 80010	: V=1.0069856, theta=-55.503433 -> V=1.0, theta=0.0
% INFO    : Bus 80011	: V=0.9955501, theta=-56.883202 -> V=1.0, theta=0.0
% INFO    : Bus 80012	: V=0.9862811, theta=-57.906641 -> V=1.0, theta=0.0
% INFO    : Bus 80013	: V=0.9886238, theta=-57.824668 -> V=1.0, theta=0.0
% INFO    : Bus 80014	: V=0.9878219, theta=-57.92082 -> V=1.0, theta=0.0
% INFO    : Bus 80015	: V=0.9805076, theta=-58.359425 -> V=1.0, theta=0.0
% INFO    : Bus 80016	: V=0.9801305, theta=-58.544991 -> V=1.0, theta=0.0
% INFO    : Bus 80017	: V=0.9756476, theta=-58.536639 -> V=1.0, theta=0.0
% INFO    : Bus 80018	: V=0.9773779, theta=-58.568538 -> V=1.0, theta=0.0
% INFO    : Bus 80019	: V=0.9779387, theta=-58.552668 -> V=1.0, theta=0.0
% INFO    : Bus 80020	: V=0.9847397, theta=-58.106106 -> V=1.0, theta=0.0
% INFO    : Bus 80021	: V=0.9787463, theta=-58.464556 -> V=1.0, theta=0.0
% INFO    : Bus 80022	: V=0.9777706, theta=-58.499646 -> V=1.0, theta=0.0
% INFO    : Bus 80023	: V=0.9730264, theta=-59.082151 -> V=1.0, theta=0.0
% INFO    : Bus 80024	: V=0.9775874, theta=-58.931337 -> V=1.0, theta=0.0
% INFO    : Bus 80025	: V=0.9922165, theta=-57.529423 -> V=1.0, theta=0.0
% INFO    : Bus 80026	: V=0.9881299, theta=-57.916417 -> V=1.0, theta=0.0
% INFO    : Bus 80027	: V=0.9806254, theta=-58.040808 -> V=1.0, theta=0.0
% INFO    : Bus 80028	: V=0.9564937, theta=-58.80403 -> V=1.0, theta=0.0
% INFO    : Bus 80029	: V=0.9530415, theta=-59.325375 -> V=1.0, theta=0.0
% INFO    : Bus 80030	: V=0.9516167, theta=-59.276008 -> V=1.0, theta=0.0
% INFO    : Bus 80031	: V=0.9517741, theta=-59.353823 -> V=1.0, theta=0.0
% INFO    : Bus 80032	: V=0.9536343, theta=-59.01653 -> V=1.0, theta=0.0
% INFO    : Bus 80033	: V=0.9524221, theta=-59.360626 -> V=1.0, theta=0.0
% INFO    : Bus 80034	: V=0.9558645, theta=-59.076546 -> V=1.0, theta=0.0
% INFO    : Bus 80035	: V=0.9506992, theta=-58.439595 -> V=1.0, theta=0.0
% INFO    : Bus 80036	: V=0.9494095, theta=-59.087441 -> V=1.0, theta=0.0
% INFO    : Bus 80037	: V=0.9498419, theta=-58.721725 -> V=1.0, theta=0.0
% INFO    : Bus 80038	: V=0.9603276, theta=-58.100068 -> V=1.0, theta=0.0
% INFO    : Bus 80039	: V=0.9534111, theta=-58.990074 -> V=1.0, theta=0.0
% INFO    : Bus 80040	: V=0.9688801, theta=-56.579245 -> V=1.0, theta=0.0
% INFO    : Bus 80041	: V=0.9665889, theta=-56.861545 -> V=1.0, theta=0.0
% INFO    : Bus 80042	: V=0.9620786, theta=-56.935624 -> V=1.0, theta=0.0
% INFO    : Bus 80043	: V=0.9622206, theta=-56.998731 -> V=1.0, theta=0.0
% INFO    : Bus 80044	: V=0.9770588, theta=-56.299643 -> V=1.0, theta=0.0
% INFO    : Bus 80045	: V=0.9770676, theta=-55.95802 -> V=1.0, theta=0.0
% INFO    : Bus 80046	: V=0.9652871, theta=-56.818948 -> V=1.0, theta=0.0
% INFO    : Bus 80047	: V=0.9727052, theta=-56.91343 -> V=1.0, theta=0.0
% INFO    : Bus 80048	: V=0.9741071, theta=-56.183837 -> V=1.0, theta=0.0
% INFO    : Bus 80049	: V=0.9773864, theta=-55.818694 -> V=1.0, theta=0.0
% INFO    : Bus 80050	: V=0.9777908, theta=-55.805735 -> V=1.0, theta=0.0
% INFO    : Bus 80051	: V=0.9719621, theta=-56.638453 -> V=1.0, theta=0.0
% INFO    : Bus 80052	: V=0.9841956, theta=-54.98203 -> V=1.0, theta=0.0
% INFO    : Bus 80053	: V=0.9849884, theta=-55.043122 -> V=1.0, theta=0.0
% INFO    : Bus 80054	: V=0.9630111, theta=-56.480695 -> V=1.0, theta=0.0
% INFO    : Bus 80055	: V=0.9620869, theta=-56.36256 -> V=1.0, theta=0.0
% INFO    : Bus 80056	: V=0.962039, theta=-56.706638 -> V=1.0, theta=0.0
% INFO    : Bus 80057	: V=0.9657729, theta=-56.302567 -> V=1.0, theta=0.0
% INFO    : Bus 80058	: V=0.9729, theta=-55.806988 -> V=1.0, theta=0.0
% INFO    : Bus 80059	: V=0.9616747, theta=-56.948652 -> V=1.0, theta=0.0
% INFO    : Bus 80060	: V=0.9701186, theta=-56.258092 -> V=1.0, theta=0.0
% INFO    : Bus 80061	: V=0.9678182, theta=-56.670069 -> V=1.0, theta=0.0
% INFO    : Bus 80062	: V=0.9790361, theta=-54.982936 -> V=1.0, theta=0.0
% INFO    : Bus 80063	: V=0.9663107, theta=-56.704556 -> V=1.0, theta=0.0
% INFO    : Bus 80064	: V=0.9765399, theta=-55.746915 -> V=1.0, theta=0.0
% INFO    : Bus 80065	: V=0.9739095, theta=-56.146258 -> V=1.0, theta=0.0
% INFO    : Bus 80066	: V=0.9797346, theta=-55.017552 -> V=1.0, theta=0.0
% INFO    : Bus 80067	: V=0.9778214, theta=-55.48484 -> V=1.0, theta=0.0
% INFO    : Bus 80068	: V=0.9722502, theta=-56.347676 -> V=1.0, theta=0.0
% INFO    : Bus 80069	: V=0.9611716, theta=-56.883115 -> V=1.0, theta=0.0
% INFO    : Bus 80070	: V=0.9712051, theta=-56.42527 -> V=1.0, theta=0.0
% INFO    : Bus 80071	: V=0.9675618, theta=-56.281974 -> V=1.0, theta=0.0
% INFO    : Bus 80072	: V=0.970221, theta=-56.585096 -> V=1.0, theta=0.0
% INFO    : Bus 80073	: V=0.9704679, theta=-56.594967 -> V=1.0, theta=0.0
% INFO    : Bus 80074	: V=0.9543847, theta=-57.194592 -> V=1.0, theta=0.0
% INFO    : Bus 80075	: V=0.9675535, theta=-55.596323 -> V=1.0, theta=0.0
% INFO    : Bus 80076	: V=0.9581889, theta=-56.964045 -> V=1.0, theta=0.0
% INFO    : Bus 80077	: V=0.953699, theta=-56.917202 -> V=1.0, theta=0.0
% INFO    : Bus 80078	: V=0.9550981, theta=-56.935281 -> V=1.0, theta=0.0
% INFO    : Bus 80079	: V=0.9536096, theta=-57.009302 -> V=1.0, theta=0.0
% INFO    : Bus 80080	: V=0.9754393, theta=-55.04304 -> V=1.0, theta=0.0
% INFO    : Bus 80081	: V=0.9667086, theta=-56.082071 -> V=1.0, theta=0.0
% INFO    : Bus 80082	: V=0.9629088, theta=-56.66455 -> V=1.0, theta=0.0
% INFO    : Bus 80083	: V=0.9666491, theta=-55.54935 -> V=1.0, theta=0.0
% INFO    : Bus 80084	: V=0.9685946, theta=-55.501947 -> V=1.0, theta=0.0
% INFO    : Bus 80085	: V=0.9545064, theta=-57.454735 -> V=1.0, theta=0.0
% INFO    : Bus 80086	: V=0.9545352, theta=-57.551374 -> V=1.0, theta=0.0
% INFO    : Bus 80087	: V=0.9517238, theta=-57.780782 -> V=1.0, theta=0.0
% INFO    : Bus 80088	: V=0.9546794, theta=-57.425782 -> V=1.0, theta=0.0
% INFO    : Bus 80089	: V=0.9568825, theta=-57.076533 -> V=1.0, theta=0.0
% INFO    : Bus 80090	: V=0.9570886, theta=-57.090715 -> V=1.0, theta=0.0
% INFO    : Bus 80091	: V=0.9545097, theta=-57.361745 -> V=1.0, theta=0.0
% INFO    : Bus 80092	: V=0.9556636, theta=-56.805328 -> V=1.0, theta=0.0
% INFO    : Bus 80093	: V=0.955563, theta=-56.515069 -> V=1.0, theta=0.0
% INFO    : Bus 80094	: V=0.953316, theta=-56.530929 -> V=1.0, theta=0.0
% INFO    : Bus 80095	: V=0.9518509, theta=-56.583845 -> V=1.0, theta=0.0
% INFO    : Bus 80096	: V=0.955826, theta=-56.529507 -> V=1.0, theta=0.0
% INFO    : Bus 80097	: V=0.956146, theta=-56.546093 -> V=1.0, theta=0.0
% INFO    : Bus 80098	: V=0.956076, theta=-56.512306 -> V=1.0, theta=0.0
% INFO    : Bus 80099	: V=0.9615918, theta=-55.724907 -> V=1.0, theta=0.0
% INFO    : Bus 80100	: V=0.9576228, theta=-56.42036 -> V=1.0, theta=0.0
% INFO    : Bus 80101	: V=0.9565492, theta=-56.514268 -> V=1.0, theta=0.0
% INFO    : Bus 80102	: V=0.9488604, theta=-57.623809 -> V=1.0, theta=0.0
% INFO    : Bus 80103	: V=0.9586107, theta=-56.669274 -> V=1.0, theta=0.0
% INFO    : Bus 80104	: V=0.954105, theta=-57.068075 -> V=1.0, theta=0.0
% INFO    : Bus 80105	: V=0.9490466, theta=-57.573922 -> V=1.0, theta=0.0
% INFO    : Bus 80106	: V=0.9510551, theta=-57.536501 -> V=1.0, theta=0.0
% INFO    : Bus 80107	: V=0.9507963, theta=-57.527177 -> V=1.0, theta=0.0
% INFO    : Bus 80108	: V=0.9537261, theta=-57.154605 -> V=1.0, theta=0.0
% INFO    : Bus 80109	: V=0.953012, theta=-57.219645 -> V=1.0, theta=0.0
% INFO    : Bus 80110	: V=0.9530646, theta=-57.158996 -> V=1.0, theta=0.0
% INFO    : Bus 80111	: V=0.9539562, theta=-56.871445 -> V=1.0, theta=0.0
% INFO    : Bus 80112	: V=0.952689, theta=-57.053508 -> V=1.0, theta=0.0
% INFO    : Bus 80113	: V=0.9516507, theta=-56.973365 -> V=1.0, theta=0.0
% INFO    : Bus 80114	: V=0.9528059, theta=-56.828627 -> V=1.0, theta=0.0
% INFO    : Bus 80115	: V=0.9528875, theta=-56.908546 -> V=1.0, theta=0.0
% INFO    : Bus 80116	: V=0.9530848, theta=-56.892708 -> V=1.0, theta=0.0
% INFO    : Bus 80117	: V=0.9514052, theta=-56.857051 -> V=1.0, theta=0.0
% INFO    : Bus 80118	: V=0.9521117, theta=-56.631064 -> V=1.0, theta=0.0
% INFO    : Bus 80119	: V=0.9518219, theta=-56.680657 -> V=1.0, theta=0.0
% INFO    : Bus 80120	: V=0.9501012, theta=-56.971516 -> V=1.0, theta=0.0
% INFO    : Bus 80121	: V=0.9693768, theta=-54.694314 -> V=1.0, theta=0.0
% INFO    : Bus 80122	: V=0.961356, theta=-55.795078 -> V=1.0, theta=0.0
% INFO    : Bus 80123	: V=0.9599583, theta=-56.109201 -> V=1.0, theta=0.0
% INFO    : Bus 80124	: V=0.9528826, theta=-56.785411 -> V=1.0, theta=0.0
% INFO    : Bus 80125	: V=0.9487232, theta=-56.957845 -> V=1.0, theta=0.0
% INFO    : Bus 80126	: V=0.9501555, theta=-56.575066 -> V=1.0, theta=0.0
% INFO    : Bus 80127	: V=0.9521824, theta=-56.313328 -> V=1.0, theta=0.0
% INFO    : Bus 80128	: V=0.963582, theta=-56.804412 -> V=1.0, theta=0.0
% INFO    : Bus 80129	: V=0.9620294, theta=-56.885141 -> V=1.0, theta=0.0
% INFO    : Bus 80130	: V=0.9595502, theta=-57.038868 -> V=1.0, theta=0.0
% INFO    : Bus 80131	: V=0.9699927, theta=-56.009761 -> V=1.0, theta=0.0
% INFO    : Bus 80132	: V=0.9687696, theta=-56.175059 -> V=1.0, theta=0.0
% INFO    : Bus 80133	: V=0.9630093, theta=-56.73014 -> V=1.0, theta=0.0
% INFO    : Bus 80134	: V=0.9678945, theta=-56.227602 -> V=1.0, theta=0.0
% INFO    : Bus 80135	: V=0.9518047, theta=-56.827369 -> V=1.0, theta=0.0
% INFO    : Bus 80136	: V=0.9567135, theta=-56.150015 -> V=1.0, theta=0.0
% INFO    : Bus 80137	: V=0.9595707, theta=-55.661886 -> V=1.0, theta=0.0
% INFO    : Bus 80138	: V=0.9597024, theta=-55.754435 -> V=1.0, theta=0.0
% INFO    : Bus 80139	: V=0.9708738, theta=-53.505489 -> V=1.0, theta=0.0
% INFO    : Bus 80140	: V=0.9692856, theta=-53.568021 -> V=1.0, theta=0.0
% INFO    : Bus 80141	: V=0.9715959, theta=-53.179394 -> V=1.0, theta=0.0
% INFO    : Bus 80142	: V=0.9875732, theta=-51.347133 -> V=1.0, theta=0.0
% INFO    : Bus 80143	: V=0.9766021, theta=-52.643695 -> V=1.0, theta=0.0
% INFO    : Bus 80144	: V=0.9703688, theta=-53.460323 -> V=1.0, theta=0.0
% INFO    : Bus 80145	: V=0.966562, theta=-53.904487 -> V=1.0, theta=0.0
% INFO    : Bus 80146	: V=0.972346, theta=-53.087794 -> V=1.0, theta=0.0
% INFO    : Bus 80147	: V=0.9747379, theta=-52.762699 -> V=1.0, theta=0.0
% INFO    : Bus 80148	: V=0.9611818, theta=-54.117231 -> V=1.0, theta=0.0
% INFO    : Bus 80149	: V=0.9724464, theta=-52.997946 -> V=1.0, theta=0.0
% INFO    : Bus 80150	: V=0.9759994, theta=-52.403897 -> V=1.0, theta=0.0
% INFO    : Bus 80151	: V=0.971211, theta=-52.59204 -> V=1.0, theta=0.0
% INFO    : Bus 80152	: V=0.984298, theta=-51.129526 -> V=1.0, theta=0.0
% INFO    : Bus 80153	: V=0.984864, theta=-51.112146 -> V=1.0, theta=0.0
% INFO    : Bus 80154	: V=0.9650391, theta=-53.974701 -> V=1.0, theta=0.0
% INFO    : Bus 80155	: V=0.9770711, theta=-52.433928 -> V=1.0, theta=0.0
% INFO    : Bus 80156	: V=0.9649878, theta=-53.943597 -> V=1.0, theta=0.0
% INFO    : Bus 80157	: V=0.9662376, theta=-53.9351 -> V=1.0, theta=0.0
% INFO    : Bus 80158	: V=0.97294, theta=-52.576746 -> V=1.0, theta=0.0
% INFO    : Bus 80159	: V=0.9600568, theta=-54.648236 -> V=1.0, theta=0.0
% INFO    : Bus 80160	: V=0.9618323, theta=-54.590592 -> V=1.0, theta=0.0
% INFO    : Bus 80161	: V=0.95833, theta=-54.890116 -> V=1.0, theta=0.0
% INFO    : Bus 80162	: V=0.960099, theta=-54.775437 -> V=1.0, theta=0.0
% INFO    : Bus 80163	: V=0.9591449, theta=-54.803663 -> V=1.0, theta=0.0
% INFO    : Bus 80164	: V=0.9630887, theta=-54.100586 -> V=1.0, theta=0.0
% INFO    : Bus 80165	: V=0.9625245, theta=-54.372069 -> V=1.0, theta=0.0
% INFO    : Bus 80166	: V=0.9583195, theta=-54.851698 -> V=1.0, theta=0.0
% INFO    : Bus 80167	: V=0.9597956, theta=-54.72169 -> V=1.0, theta=0.0
% INFO    : Bus 80168	: V=0.968109, theta=-53.746292 -> V=1.0, theta=0.0
% INFO    : Bus 80169	: V=0.9647683, theta=-54.223793 -> V=1.0, theta=0.0
% INFO    : Bus 80170	: V=0.9598553, theta=-54.733548 -> V=1.0, theta=0.0
% INFO    : Bus 80171	: V=0.9576218, theta=-55.308807 -> V=1.0, theta=0.0
% INFO    : Bus 80172	: V=0.9572151, theta=-55.045339 -> V=1.0, theta=0.0
% INFO    : Bus 80173	: V=0.9589604, theta=-54.795219 -> V=1.0, theta=0.0
% INFO    : Bus 80174	: V=0.9538739, theta=-55.373394 -> V=1.0, theta=0.0
% INFO    : Bus 80175	: V=0.9567381, theta=-55.100165 -> V=1.0, theta=0.0
% INFO    : Bus 80176	: V=0.9512503, theta=-56.225753 -> V=1.0, theta=0.0
% INFO    : Bus 80177	: V=0.9518839, theta=-56.615373 -> V=1.0, theta=0.0
% INFO    : Bus 80178	: V=0.950106, theta=-56.530724 -> V=1.0, theta=0.0
% INFO    : Bus 80179	: V=0.9530354, theta=-55.909867 -> V=1.0, theta=0.0
% INFO    : Bus 80180	: V=0.9602274, theta=-55.98342 -> V=1.0, theta=0.0
% INFO    : Bus 80181	: V=0.9549797, theta=-56.572619 -> V=1.0, theta=0.0
% INFO    : Bus 80182	: V=0.9513611, theta=-57.296775 -> V=1.0, theta=0.0
% INFO    : Bus 80183	: V=0.9524786, theta=-56.756204 -> V=1.0, theta=0.0
% INFO    : Bus 80184	: V=0.9509908, theta=-56.779342 -> V=1.0, theta=0.0
% INFO    : Bus 80185	: V=0.9503948, theta=-56.76479 -> V=1.0, theta=0.0
% INFO    : Bus 80186	: V=0.9518183, theta=-56.651462 -> V=1.0, theta=0.0
% INFO    : Bus 80187	: V=0.970114, theta=-54.578401 -> V=1.0, theta=0.0
% INFO    : Bus 80188	: V=0.9602082, theta=-55.704393 -> V=1.0, theta=0.0
% INFO    : Bus 80189	: V=0.9542624, theta=-56.341763 -> V=1.0, theta=0.0
% INFO    : Bus 80190	: V=0.9541636, theta=-56.295369 -> V=1.0, theta=0.0
% INFO    : Bus 80191	: V=0.9552958, theta=-56.528937 -> V=1.0, theta=0.0
% INFO    : Bus 80192	: V=0.9552285, theta=-56.536988 -> V=1.0, theta=0.0
% INFO    : Bus 80193	: V=0.9513175, theta=-56.698177 -> V=1.0, theta=0.0
% INFO    : Bus 80194	: V=0.9523258, theta=-57.358112 -> V=1.0, theta=0.0
% INFO    : Bus 80195	: V=0.9648836, theta=-55.543374 -> V=1.0, theta=0.0
% INFO    : Bus 80196	: V=0.9575888, theta=-56.455607 -> V=1.0, theta=0.0
% INFO    : Bus 80197	: V=0.9525426, theta=-56.575314 -> V=1.0, theta=0.0
% INFO    : Bus 80198	: V=0.9577147, theta=-56.454087 -> V=1.0, theta=0.0
% INFO    : Bus 80199	: V=0.9772471, theta=-54.634301 -> V=1.0, theta=0.0
% INFO    : Bus 80200	: V=0.9722634, theta=-55.394898 -> V=1.0, theta=0.0
% INFO    : Bus 80201	: V=0.9706256, theta=-55.682619 -> V=1.0, theta=0.0
% INFO    : Bus 80202	: V=0.9579662, theta=-56.842152 -> V=1.0, theta=0.0
% INFO    : Bus 80203	: V=0.9801363, theta=-54.582873 -> V=1.0, theta=0.0
% INFO    : Bus 80204	: V=0.9892525, theta=-49.317124 -> V=1.0, theta=0.0
% INFO    : Bus 80205	: V=0.9962142, theta=-46.365624 -> V=1.0, theta=0.0
% INFO    : Bus 80206	: V=0.9995392, theta=-46.156045 -> V=1.0, theta=0.0
% INFO    : Bus 80207	: V=1.0017168, theta=-51.595671 -> V=1.0, theta=0.0
% INFO    : Bus 80208	: V=1.002651, theta=-51.086732 -> V=1.0, theta=0.0
% INFO    : Bus 80209	: V=0.9977896, theta=-51.405657 -> V=1.0, theta=0.0
% INFO    : Bus 80210	: V=0.9873019, theta=-57.950163 -> V=1.0, theta=0.0
% INFO    : Bus 80211	: V=0.9869162, theta=-57.902275 -> V=1.0, theta=0.0
% INFO    : Bus 80212	: V=0.9888693, theta=-57.747797 -> V=1.0, theta=0.0
% INFO    : Bus 80213	: V=0.9911599, theta=-57.522949 -> V=1.0, theta=0.0
% INFO    : Bus 80214	: V=0.9886363, theta=-57.903602 -> V=1.0, theta=0.0
% INFO    : Bus 80215	: V=1.0002088, theta=-56.604064 -> V=1.0, theta=0.0
% INFO    : Bus 80216	: V=0.9985876, theta=-56.564583 -> V=1.0, theta=0.0
% INFO    : Bus 80217	: V=0.9964419, theta=-56.934673 -> V=1.0, theta=0.0
% INFO    : Bus 80218	: V=0.9867254, theta=-58.041029 -> V=1.0, theta=0.0
% INFO    : Bus 80219	: V=0.9756019, theta=-58.872212 -> V=1.0, theta=0.0
% INFO    : Bus 80220	: V=0.9945515, theta=-55.793269 -> V=1.0, theta=0.0
% INFO    : Bus 80221	: V=0.9866238, theta=-47.673113 -> V=1.0, theta=0.0
% INFO    : Bus 80222	: V=0.9875929, theta=-47.541111 -> V=1.0, theta=0.0
% INFO    : Bus 80223	: V=0.9922815, theta=-47.453982 -> V=1.0, theta=0.0
% INFO    : Bus 80224	: V=0.9904558, theta=-48.541252 -> V=1.0, theta=0.0
% INFO    : Bus 80225	: V=1.0020738, theta=-47.830691 -> V=1.0, theta=0.0
% INFO    : Bus 80226	: V=1.003247, theta=-45.36149 -> V=1.0, theta=0.0
% INFO    : Bus 80227	: V=0.9746105, theta=-57.610142 -> V=1.0, theta=0.0
% INFO    : Bus 80228	: V=0.9716484, theta=-57.902473 -> V=1.0, theta=0.0
% INFO    : Bus 80229	: V=0.975458, theta=-57.653504 -> V=1.0, theta=0.0
% INFO    : Bus 80230	: V=0.9760895, theta=-57.568311 -> V=1.0, theta=0.0
% INFO    : Bus 80231	: V=0.9705779, theta=-57.978416 -> V=1.0, theta=0.0
% INFO    : Bus 80232	: V=0.970703, theta=-57.973955 -> V=1.0, theta=0.0
% INFO    : Bus 80233	: V=0.9712079, theta=-57.913604 -> V=1.0, theta=0.0
% INFO    : Bus 80234	: V=0.9713291, theta=-57.900165 -> V=1.0, theta=0.0
% INFO    : Bus 80235	: V=0.9700094, theta=-58.096394 -> V=1.0, theta=0.0
% INFO    : Bus 80236	: V=0.9741656, theta=-57.540001 -> V=1.0, theta=0.0
% INFO    : Bus 80237	: V=0.9704058, theta=-58.067028 -> V=1.0, theta=0.0
% INFO    : Bus 80238	: V=0.9704144, theta=-58.011447 -> V=1.0, theta=0.0
% INFO    : Bus 80239	: V=0.9768872, theta=-57.276201 -> V=1.0, theta=0.0
% INFO    : Bus 80240	: V=0.974734, theta=-57.755013 -> V=1.0, theta=0.0
% INFO    : Bus 80241	: V=0.9643371, theta=-58.541394 -> V=1.0, theta=0.0
% INFO    : Bus 80242	: V=0.9649314, theta=-58.488293 -> V=1.0, theta=0.0
% INFO    : Bus 80243	: V=0.9633365, theta=-58.610974 -> V=1.0, theta=0.0
% INFO    : Bus 80244	: V=0.9620551, theta=-58.722062 -> V=1.0, theta=0.0
% INFO    : Bus 80245	: V=0.9576768, theta=-59.07188 -> V=1.0, theta=0.0
% INFO    : Bus 80246	: V=0.9602985, theta=-58.869081 -> V=1.0, theta=0.0
% INFO    : Bus 80247	: V=0.9597, theta=-58.892092 -> V=1.0, theta=0.0
% INFO    : Bus 80248	: V=0.9684364, theta=-58.153314 -> V=1.0, theta=0.0
% INFO    : Bus 80249	: V=0.9705966, theta=-57.935831 -> V=1.0, theta=0.0
% INFO    : Bus 80250	: V=0.9702004, theta=-58.073785 -> V=1.0, theta=0.0
% INFO    : Bus 80251	: V=0.9705784, theta=-58.033018 -> V=1.0, theta=0.0
% INFO    : Bus 80252	: V=0.9680702, theta=-58.178578 -> V=1.0, theta=0.0
% INFO    : Bus 80253	: V=0.9691684, theta=-58.219242 -> V=1.0, theta=0.0
% INFO    : Bus 80254	: V=0.9644765, theta=-58.429986 -> V=1.0, theta=0.0
% INFO    : Bus 80255	: V=0.9596432, theta=-58.765651 -> V=1.0, theta=0.0
% INFO    : Bus 80256	: V=0.9833886, theta=-56.07981 -> V=1.0, theta=0.0
% INFO    : Bus 80257	: V=0.9743184, theta=-57.408596 -> V=1.0, theta=0.0
% INFO    : Bus 80258	: V=0.9719633, theta=-57.839935 -> V=1.0, theta=0.0
% INFO    : Bus 80259	: V=0.9812398, theta=-57.052751 -> V=1.0, theta=0.0
% INFO    : Bus 80260	: V=0.959747, theta=-58.716609 -> V=1.0, theta=0.0
% INFO    : Bus 80261	: V=0.9759282, theta=-57.157296 -> V=1.0, theta=0.0
% INFO    : Bus 80262	: V=0.9757582, theta=-57.173151 -> V=1.0, theta=0.0
% INFO    : Bus 80263	: V=0.9809464, theta=-56.345021 -> V=1.0, theta=0.0
% INFO    : Bus 80264	: V=0.9851643, theta=-56.230376 -> V=1.0, theta=0.0
% INFO    : Bus 80265	: V=0.9773032, theta=-57.615547 -> V=1.0, theta=0.0
% INFO    : Bus 80266	: V=0.9781251, theta=-57.424717 -> V=1.0, theta=0.0
% INFO    : Bus 80267	: V=0.9783578, theta=-57.411963 -> V=1.0, theta=0.0
% INFO    : Bus 80268	: V=0.9807639, theta=-57.069958 -> V=1.0, theta=0.0
% INFO    : Bus 80269	: V=0.9787941, theta=-57.397499 -> V=1.0, theta=0.0
% INFO    : Bus 80270	: V=0.9790942, theta=-57.416146 -> V=1.0, theta=0.0
% INFO    : Bus 80271	: V=0.987555, theta=-56.384393 -> V=1.0, theta=0.0
% INFO    : Bus 80272	: V=0.9930073, theta=-55.834234 -> V=1.0, theta=0.0
% INFO    : Bus 80273	: V=0.9916912, theta=-56.055945 -> V=1.0, theta=0.0
% INFO    : Bus 80274	: V=0.9760537, theta=-57.573772 -> V=1.0, theta=0.0
% INFO    : Bus 80275	: V=0.9782848, theta=-57.362766 -> V=1.0, theta=0.0
% INFO    : Bus 80276	: V=0.9734749, theta=-57.9707 -> V=1.0, theta=0.0
% INFO    : Bus 80277	: V=0.9746422, theta=-57.864734 -> V=1.0, theta=0.0
% INFO    : Bus 80278	: V=0.9667899, theta=-58.595041 -> V=1.0, theta=0.0
% INFO    : Bus 80279	: V=0.9703759, theta=-58.263838 -> V=1.0, theta=0.0
% INFO    : Bus 80280	: V=0.9705406, theta=-58.094746 -> V=1.0, theta=0.0
% INFO    : Bus 80281	: V=0.969905, theta=-58.105698 -> V=1.0, theta=0.0
% INFO    : Bus 80282	: V=0.9609084, theta=-58.84955 -> V=1.0, theta=0.0
% INFO    : Bus 80283	: V=0.9764689, theta=-57.45808 -> V=1.0, theta=0.0
% INFO    : Bus 80284	: V=0.9536133, theta=-46.317586 -> V=1.0, theta=0.0
% INFO    : Bus 80285	: V=0.9507936, theta=-46.128716 -> V=1.0, theta=0.0
% INFO    : Bus 80286	: V=0.9507222, theta=-46.065436 -> V=1.0, theta=0.0
% INFO    : Bus 80287	: V=0.9547738, theta=-45.96944 -> V=1.0, theta=0.0
% INFO    : Bus 80288	: V=0.9450402, theta=-46.672757 -> V=1.0, theta=0.0
% INFO    : Bus 80289	: V=0.9412546, theta=-46.490469 -> V=1.0, theta=0.0
% INFO    : Bus 80290	: V=0.9541325, theta=-45.572366 -> V=1.0, theta=0.0
% INFO    : Bus 80291	: V=0.9494993, theta=-45.434977 -> V=1.0, theta=0.0
% INFO    : Bus 80292	: V=0.9665267, theta=-44.395647 -> V=1.0, theta=0.0
% INFO    : Bus 80293	: V=0.9689177, theta=-44.24457 -> V=1.0, theta=0.0
% INFO    : Bus 80294	: V=0.9585079, theta=-45.117924 -> V=1.0, theta=0.0
% INFO    : Bus 80295	: V=0.9503525, theta=-46.629418 -> V=1.0, theta=0.0
% INFO    : Bus 80296	: V=0.9364313, theta=-46.426261 -> V=1.0, theta=0.0
% INFO    : Bus 80297	: V=0.9322233, theta=-46.413526 -> V=1.0, theta=0.0
% INFO    : Bus 80298	: V=0.9477894, theta=-48.265398 -> V=1.0, theta=0.0
% INFO    : Bus 80299	: V=0.9588972, theta=-49.804966 -> V=1.0, theta=0.0
% INFO    : Bus 80300	: V=0.9849432, theta=-39.362307 -> V=1.0, theta=0.0
% INFO    : Bus 80301	: V=0.9944376, theta=-38.939544 -> V=1.0, theta=0.0
% INFO    : Bus 80302	: V=0.9629714, theta=-48.873232 -> V=1.0, theta=0.0
% INFO    : Bus 80303	: V=0.9595351, theta=-49.430099 -> V=1.0, theta=0.0
% INFO    : Bus 80304	: V=0.9640611, theta=-48.546532 -> V=1.0, theta=0.0
% INFO    : Bus 80305	: V=0.995817, theta=-44.285665 -> V=1.0, theta=0.0
% INFO    : Bus 80306	: V=0.9950619, theta=-44.429798 -> V=1.0, theta=0.0
% INFO    : Bus 80307	: V=0.9895849, theta=-45.010816 -> V=1.0, theta=0.0
% INFO    : Bus 80308	: V=0.9881404, theta=-45.559999 -> V=1.0, theta=0.0
% INFO    : Bus 80309	: V=0.9671772, theta=-47.283287 -> V=1.0, theta=0.0
% INFO    : Bus 80310	: V=0.9464526, theta=-44.242353 -> V=1.0, theta=0.0
% INFO    : Bus 80311	: V=0.9579555, theta=-43.015052 -> V=1.0, theta=0.0
% INFO    : Bus 80312	: V=0.9477913, theta=-46.989886 -> V=1.0, theta=0.0
% INFO    : Bus 80313	: V=0.9532383, theta=-44.58346 -> V=1.0, theta=0.0
% INFO    : Bus 80314	: V=1.0032672, theta=-35.967467 -> V=1.0, theta=0.0
% INFO    : Bus 80315	: V=1.0032683, theta=-35.1249 -> V=1.0, theta=0.0
% INFO    : Bus 80316	: V=0.9807714, theta=-34.642098 -> V=1.0, theta=0.0
% INFO    : Bus 80317	: V=0.9840938, theta=-30.037385 -> V=1.0, theta=0.0
% INFO    : Bus 80318	: V=1.0012953, theta=-26.74583 -> V=1.0, theta=0.0
% INFO    : Bus 80319	: V=1.0187369, theta=-22.956991 -> V=1.0, theta=0.0
% INFO    : Bus 80320	: V=0.9834358, theta=-28.282519 -> V=1.0, theta=0.0
% INFO    : Bus 80321	: V=0.9927928, theta=-27.251432 -> V=1.0, theta=0.0
% INFO    : Bus 80322	: V=0.9548862, theta=-32.398721 -> V=1.0, theta=0.0
% INFO    : Bus 80323	: V=0.9671253, theta=-30.292367 -> V=1.0, theta=0.0
% INFO    : Bus 80324	: V=0.9481464, theta=-49.908372 -> V=1.0, theta=0.0
% INFO    : Bus 80325	: V=0.9517362, theta=-49.899513 -> V=1.0, theta=0.0
% INFO    : Bus 80326	: V=0.9456754, theta=-49.865927 -> V=1.0, theta=0.0
% INFO    : Bus 80327	: V=0.9402207, theta=-50.568046 -> V=1.0, theta=0.0
% INFO    : Bus 80328	: V=0.9522657, theta=-49.473603 -> V=1.0, theta=0.0
% INFO    : Bus 80329	: V=0.9593763, theta=-49.479621 -> V=1.0, theta=0.0
% INFO    : Bus 80330	: V=0.9643428, theta=-49.051659 -> V=1.0, theta=0.0
% INFO    : Bus 80331	: V=0.9516187, theta=-49.108152 -> V=1.0, theta=0.0
% INFO    : Bus 80332	: V=0.9513274, theta=-48.006047 -> V=1.0, theta=0.0
% INFO    : Bus 80333	: V=0.9490673, theta=-47.635808 -> V=1.0, theta=0.0
% INFO    : Bus 80334	: V=0.9635603, theta=-45.663829 -> V=1.0, theta=0.0
% INFO    : Bus 80335	: V=0.9452184, theta=-48.240951 -> V=1.0, theta=0.0
% INFO    : Bus 80336	: V=0.9881493, theta=-40.741216 -> V=1.0, theta=0.0
% INFO    : Bus 80337	: V=0.9807233, theta=-41.05447 -> V=1.0, theta=0.0
% INFO    : Bus 80338	: V=0.9855088, theta=-40.88141 -> V=1.0, theta=0.0
% INFO    : Bus 80339	: V=0.9855988, theta=-40.611566 -> V=1.0, theta=0.0
% INFO    : Bus 80340	: V=0.9829458, theta=-39.915273 -> V=1.0, theta=0.0
% INFO    : Bus 80341	: V=0.9707104, theta=-40.966946 -> V=1.0, theta=0.0
% INFO    : Bus 80342	: V=0.973142, theta=-41.748837 -> V=1.0, theta=0.0
% INFO    : Bus 80343	: V=0.9710836, theta=-41.827413 -> V=1.0, theta=0.0
% INFO    : Bus 80344	: V=0.9733578, theta=-41.688958 -> V=1.0, theta=0.0
% INFO    : Bus 80345	: V=0.971069, theta=-41.915429 -> V=1.0, theta=0.0
% INFO    : Bus 80346	: V=0.9794653, theta=-41.504145 -> V=1.0, theta=0.0
% INFO    : Bus 80347	: V=0.9771043, theta=-41.375301 -> V=1.0, theta=0.0
% INFO    : Bus 80348	: V=0.9750853, theta=-41.316732 -> V=1.0, theta=0.0
% INFO    : Bus 80349	: V=0.9681979, theta=-41.448242 -> V=1.0, theta=0.0
% INFO    : Bus 80350	: V=0.9507535, theta=-48.773368 -> V=1.0, theta=0.0
% INFO    : Bus 80351	: V=0.9383925, theta=-49.359713 -> V=1.0, theta=0.0
% INFO    : Bus 80352	: V=0.9465419, theta=-48.550376 -> V=1.0, theta=0.0
% INFO    : Bus 80353	: V=0.9733608, theta=-46.551173 -> V=1.0, theta=0.0
% INFO    : Bus 80354	: V=0.9533047, theta=-48.377689 -> V=1.0, theta=0.0
% INFO    : Bus 80355	: V=0.9504543, theta=-48.191692 -> V=1.0, theta=0.0
% INFO    : Bus 80356	: V=0.9509486, theta=-48.055514 -> V=1.0, theta=0.0
% INFO    : Bus 80357	: V=0.9418892, theta=-40.385514 -> V=1.0, theta=0.0
% INFO    : Bus 80358	: V=0.948374, theta=-39.683572 -> V=1.0, theta=0.0
% INFO    : Bus 80359	: V=0.9545056, theta=-38.585267 -> V=1.0, theta=0.0
% INFO    : Bus 80360	: V=0.9525715, theta=-38.115872 -> V=1.0, theta=0.0
% INFO    : Bus 80361	: V=0.9972521, theta=-40.899125 -> V=1.0, theta=0.0
% INFO    : Bus 80362	: V=0.9961987, theta=-41.047016 -> V=1.0, theta=0.0
% INFO    : Bus 80363	: V=0.979699, theta=-42.707395 -> V=1.0, theta=0.0
% INFO    : Bus 80364	: V=0.9832356, theta=-43.061712 -> V=1.0, theta=0.0
% INFO    : Bus 80365	: V=0.9719163, theta=-44.06549 -> V=1.0, theta=0.0
% INFO    : Bus 80366	: V=0.969152, theta=-44.527922 -> V=1.0, theta=0.0
% INFO    : Bus 80367	: V=0.967547, theta=-44.800893 -> V=1.0, theta=0.0
% INFO    : Bus 80368	: V=0.96837, theta=-44.785931 -> V=1.0, theta=0.0
% INFO    : Bus 80369	: V=0.9716391, theta=-44.723171 -> V=1.0, theta=0.0
% INFO    : Bus 80370	: V=0.9694353, theta=-44.777515 -> V=1.0, theta=0.0
% INFO    : Bus 80371	: V=0.9905587, theta=-41.453985 -> V=1.0, theta=0.0
% INFO    : Bus 80372	: V=0.9787282, theta=-43.067665 -> V=1.0, theta=0.0
% INFO    : Bus 80373	: V=0.9768501, theta=-43.623733 -> V=1.0, theta=0.0
% INFO    : Bus 80374	: V=0.9642569, theta=-44.284348 -> V=1.0, theta=0.0
% INFO    : Bus 80375	: V=0.9646578, theta=-44.250827 -> V=1.0, theta=0.0
% INFO    : Bus 80376	: V=0.9673019, theta=-43.498433 -> V=1.0, theta=0.0
% INFO    : Bus 80377	: V=0.9774558, theta=-41.457492 -> V=1.0, theta=0.0
% INFO    : Bus 80378	: V=0.9591094, theta=-43.563973 -> V=1.0, theta=0.0
% INFO    : Bus 80379	: V=0.9985004, theta=-39.360032 -> V=1.0, theta=0.0
% INFO    : Bus 80380	: V=0.9775145, theta=-41.787114 -> V=1.0, theta=0.0
% INFO    : Bus 80381	: V=0.9971821, theta=-38.84263 -> V=1.0, theta=0.0
% INFO    : Bus 80382	: V=0.9553466, theta=-45.183134 -> V=1.0, theta=0.0
% INFO    : Bus 80383	: V=0.9592524, theta=-44.790996 -> V=1.0, theta=0.0
% INFO    : Bus 80384	: V=0.9625612, theta=-41.070175 -> V=1.0, theta=0.0
% INFO    : Bus 80385	: V=0.9630076, theta=-41.090408 -> V=1.0, theta=0.0
% INFO    : Bus 80386	: V=0.9712611, theta=-41.879744 -> V=1.0, theta=0.0
% INFO    : Bus 80387	: V=0.9847374, theta=-41.135715 -> V=1.0, theta=0.0
% INFO    : Bus 80388	: V=1.0018994, theta=-39.450224 -> V=1.0, theta=0.0
% INFO    : Bus 80389	: V=0.9966008, theta=-39.919152 -> V=1.0, theta=0.0
% INFO    : Bus 80390	: V=0.9900292, theta=-31.285817 -> V=1.0, theta=0.0
% INFO    : Bus 80391	: V=0.9608925, theta=-35.952211 -> V=1.0, theta=0.0
% INFO    : Bus 80392	: V=0.9557817, theta=-35.862967 -> V=1.0, theta=0.0
% INFO    : Bus 80393	: V=0.9661712, theta=-38.748955 -> V=1.0, theta=0.0
% INFO    : Bus 80394	: V=0.9711942, theta=-39.553241 -> V=1.0, theta=0.0
% INFO    : Bus 80395	: V=0.9722017, theta=-39.28208 -> V=1.0, theta=0.0
% INFO    : Bus 80396	: V=0.9669392, theta=-38.691866 -> V=1.0, theta=0.0
% INFO    : Bus 80397	: V=0.9632558, theta=-38.865631 -> V=1.0, theta=0.0
% INFO    : Bus 80398	: V=0.9652016, theta=-38.802585 -> V=1.0, theta=0.0
% INFO    : Bus 80399	: V=0.9838017, theta=-33.870952 -> V=1.0, theta=0.0
% INFO    : Bus 80400	: V=0.9712161, theta=-36.565021 -> V=1.0, theta=0.0
% INFO    : Bus 80401	: V=0.9696723, theta=-36.850318 -> V=1.0, theta=0.0
% INFO    : Bus 80402	: V=0.962622, theta=-37.771664 -> V=1.0, theta=0.0
% INFO    : Bus 80403	: V=0.9666095, theta=-39.983782 -> V=1.0, theta=0.0
% INFO    : Bus 80404	: V=0.9732554, theta=-39.528607 -> V=1.0, theta=0.0
% INFO    : Bus 80405	: V=0.9651855, theta=-39.929 -> V=1.0, theta=0.0
% INFO    : Bus 80406	: V=0.9667956, theta=-39.82205 -> V=1.0, theta=0.0
% INFO    : Bus 80407	: V=0.9730053, theta=-39.518408 -> V=1.0, theta=0.0
% INFO    : Bus 80408	: V=0.9733878, theta=-39.494238 -> V=1.0, theta=0.0
% INFO    : Bus 80409	: V=0.9722664, theta=-39.402443 -> V=1.0, theta=0.0
% INFO    : Bus 80410	: V=0.9832059, theta=-38.474121 -> V=1.0, theta=0.0
% INFO    : Bus 80411	: V=0.9763723, theta=-39.291177 -> V=1.0, theta=0.0
% INFO    : Bus 80412	: V=0.9731646, theta=-39.473167 -> V=1.0, theta=0.0
% INFO    : Bus 80413	: V=0.9774422, theta=-38.589768 -> V=1.0, theta=0.0
% INFO    : Bus 80414	: V=0.9655663, theta=-39.74332 -> V=1.0, theta=0.0
% INFO    : Bus 80415	: V=0.9666225, theta=-39.719336 -> V=1.0, theta=0.0
% INFO    : Bus 80416	: V=0.9727163, theta=-39.513853 -> V=1.0, theta=0.0
% INFO    : Bus 80417	: V=0.968389, theta=-39.75467 -> V=1.0, theta=0.0
% INFO    : Bus 80418	: V=0.9672391, theta=-39.78819 -> V=1.0, theta=0.0
% INFO    : Bus 80419	: V=0.9993927, theta=-37.135663 -> V=1.0, theta=0.0
% INFO    : Bus 80420	: V=0.989844, theta=-38.348608 -> V=1.0, theta=0.0
% INFO    : Bus 80421	: V=0.9877375, theta=-38.702912 -> V=1.0, theta=0.0
% INFO    : Bus 80422	: V=0.9824824, theta=-38.966088 -> V=1.0, theta=0.0
% INFO    : Bus 80423	: V=0.9813251, theta=-39.069138 -> V=1.0, theta=0.0
% INFO    : Bus 80424	: V=0.9772627, theta=-39.287491 -> V=1.0, theta=0.0
% INFO    : Bus 80425	: V=0.9773681, theta=-39.436411 -> V=1.0, theta=0.0
% INFO    : Bus 80426	: V=0.9713945, theta=-39.729728 -> V=1.0, theta=0.0
% INFO    : Bus 80427	: V=0.9617022, theta=-45.512687 -> V=1.0, theta=0.0
% INFO    : Bus 80428	: V=0.9730334, theta=-45.74457 -> V=1.0, theta=0.0
% INFO    : Bus 80429	: V=0.9779259, theta=-47.816235 -> V=1.0, theta=0.0
% INFO    : Bus 80430	: V=0.9719054, theta=-44.860759 -> V=1.0, theta=0.0
% INFO    : Bus 80431	: V=0.9703227, theta=-44.665809 -> V=1.0, theta=0.0
% INFO    : Bus 80432	: V=0.96473, theta=-45.504764 -> V=1.0, theta=0.0
% INFO    : Bus 80433	: V=0.9688815, theta=-44.922046 -> V=1.0, theta=0.0
% INFO    : Bus 80434	: V=0.9640697, theta=-45.822068 -> V=1.0, theta=0.0
% INFO    : Bus 80435	: V=0.9653261, theta=-45.431283 -> V=1.0, theta=0.0
% INFO    : Bus 80436	: V=0.9882371, theta=-42.39002 -> V=1.0, theta=0.0
% INFO    : Bus 80437	: V=0.9887818, theta=-42.332213 -> V=1.0, theta=0.0
% INFO    : Bus 80438	: V=0.9892348, theta=-42.264144 -> V=1.0, theta=0.0
% INFO    : Bus 80439	: V=0.9893545, theta=-42.2732 -> V=1.0, theta=0.0
% INFO    : Bus 80440	: V=0.9937252, theta=-41.740003 -> V=1.0, theta=0.0
% INFO    : Bus 80441	: V=0.9934424, theta=-41.792131 -> V=1.0, theta=0.0
% INFO    : Bus 80442	: V=1.0001917, theta=-40.970347 -> V=1.0, theta=0.0
% INFO    : Bus 80443	: V=0.9972754, theta=-41.505169 -> V=1.0, theta=0.0
% INFO    : Bus 80444	: V=0.9795614, theta=-43.398436 -> V=1.0, theta=0.0
% INFO    : Bus 80445	: V=0.9896404, theta=-42.01745 -> V=1.0, theta=0.0
% INFO    : Bus 80446	: V=0.9872662, theta=-42.412591 -> V=1.0, theta=0.0
% INFO    : Bus 80447	: V=0.9791341, theta=-43.153949 -> V=1.0, theta=0.0
% INFO    : Bus 80448	: V=0.976684, theta=-43.704085 -> V=1.0, theta=0.0
% INFO    : Bus 80449	: V=0.9831647, theta=-43.033726 -> V=1.0, theta=0.0
% INFO    : Bus 80450	: V=0.9703008, theta=-37.797019 -> V=1.0, theta=0.0
% INFO    : Bus 80451	: V=0.9733539, theta=-35.822158 -> V=1.0, theta=0.0
% INFO    : Bus 80452	: V=0.9683257, theta=-36.440207 -> V=1.0, theta=0.0
% INFO    : Bus 80453	: V=0.9626496, theta=-43.011097 -> V=1.0, theta=0.0
% INFO    : Bus 80454	: V=0.9680235, theta=-42.453438 -> V=1.0, theta=0.0
% INFO    : Bus 80455	: V=0.9591438, theta=-43.197155 -> V=1.0, theta=0.0
% INFO    : Bus 80456	: V=0.9682064, theta=-42.457627 -> V=1.0, theta=0.0
% INFO    : Bus 80457	: V=0.9685219, theta=-42.46443 -> V=1.0, theta=0.0
% INFO    : Bus 80458	: V=0.9741544, theta=-41.623909 -> V=1.0, theta=0.0
% INFO    : Bus 80459	: V=0.9715045, theta=-42.23285 -> V=1.0, theta=0.0
% INFO    : Bus 80460	: V=0.9563209, theta=-43.394959 -> V=1.0, theta=0.0
% INFO    : Bus 80461	: V=0.9570987, theta=-43.493698 -> V=1.0, theta=0.0
% INFO    : Bus 80462	: V=0.9683466, theta=-42.533183 -> V=1.0, theta=0.0
% INFO    : Bus 80463	: V=0.9651605, theta=-42.70094 -> V=1.0, theta=0.0
% INFO    : Bus 80464	: V=0.9593685, theta=-43.072903 -> V=1.0, theta=0.0
% INFO    : Bus 80465	: V=0.9593572, theta=-43.31851 -> V=1.0, theta=0.0
% INFO    : Bus 80466	: V=0.9609774, theta=-42.999031 -> V=1.0, theta=0.0
% INFO    : Bus 80467	: V=0.9618003, theta=-42.955742 -> V=1.0, theta=0.0
% INFO    : Bus 80468	: V=0.9684067, theta=-42.436649 -> V=1.0, theta=0.0
% INFO    : Bus 80469	: V=0.9733387, theta=-41.790794 -> V=1.0, theta=0.0
% INFO    : Bus 80470	: V=0.9557402, theta=-43.800339 -> V=1.0, theta=0.0
% INFO    : Bus 80471	: V=0.9633128, theta=-42.791691 -> V=1.0, theta=0.0
% INFO    : Bus 80472	: V=0.9729525, theta=-41.928185 -> V=1.0, theta=0.0
% INFO    : Bus 80473	: V=0.9733467, theta=-41.985313 -> V=1.0, theta=0.0
% INFO    : Bus 80474	: V=0.9874924, theta=-40.047495 -> V=1.0, theta=0.0
% INFO    : Bus 80475	: V=0.9845787, theta=-40.553833 -> V=1.0, theta=0.0
% INFO    : Bus 80476	: V=0.9871832, theta=-40.054774 -> V=1.0, theta=0.0
% INFO    : Bus 80477	: V=0.9808666, theta=-41.051447 -> V=1.0, theta=0.0
% INFO    : Bus 80478	: V=0.980248, theta=-41.238412 -> V=1.0, theta=0.0
% INFO    : Bus 80479	: V=0.9502558, theta=-45.792488 -> V=1.0, theta=0.0
% INFO    : Bus 80480	: V=0.9482199, theta=-46.702429 -> V=1.0, theta=0.0
% INFO    : Bus 80481	: V=0.9493809, theta=-45.974147 -> V=1.0, theta=0.0
% INFO    : Bus 80482	: V=0.9506079, theta=-44.872671 -> V=1.0, theta=0.0
% INFO    : Bus 80483	: V=0.9754702, theta=-44.907973 -> V=1.0, theta=0.0
% INFO    : Bus 80484	: V=0.9758567, theta=-44.867866 -> V=1.0, theta=0.0
% INFO    : Bus 80485	: V=0.9687976, theta=-45.290769 -> V=1.0, theta=0.0
% INFO    : Bus 80486	: V=0.9698079, theta=-45.302659 -> V=1.0, theta=0.0
% INFO    : Bus 80487	: V=0.9699716, theta=-45.284055 -> V=1.0, theta=0.0
% INFO    : Bus 80488	: V=0.9748607, theta=-44.944082 -> V=1.0, theta=0.0
% INFO    : Bus 80489	: V=0.9871546, theta=-43.455932 -> V=1.0, theta=0.0
% INFO    : Bus 80490	: V=0.9937905, theta=-42.857628 -> V=1.0, theta=0.0
% INFO    : Bus 80491	: V=0.9839756, theta=-44.247757 -> V=1.0, theta=0.0
% INFO    : Bus 80492	: V=0.9840494, theta=-44.136841 -> V=1.0, theta=0.0
% INFO    : Bus 80493	: V=0.9676536, theta=-45.352763 -> V=1.0, theta=0.0
% INFO    : Bus 80494	: V=0.9672602, theta=-45.362172 -> V=1.0, theta=0.0
% INFO    : Bus 80495	: V=0.9690606, theta=-45.227485 -> V=1.0, theta=0.0
% INFO    : Bus 80496	: V=0.9784582, theta=-44.713389 -> V=1.0, theta=0.0
% INFO    : Bus 80497	: V=0.978205, theta=-44.846366 -> V=1.0, theta=0.0
% INFO    : Bus 80498	: V=0.9634137, theta=-46.606415 -> V=1.0, theta=0.0
% INFO    : Bus 80499	: V=0.9933978, theta=-42.922515 -> V=1.0, theta=0.0
% INFO    : Bus 80500	: V=0.9931558, theta=-42.992774 -> V=1.0, theta=0.0
% INFO    : Bus 80501	: V=0.9772777, theta=-44.857308 -> V=1.0, theta=0.0
% INFO    : Bus 80502	: V=0.9914501, theta=-43.436381 -> V=1.0, theta=0.0
% INFO    : Bus 80503	: V=0.9894541, theta=-43.827245 -> V=1.0, theta=0.0
% INFO    : Bus 80504	: V=0.9701455, theta=-45.214174 -> V=1.0, theta=0.0
% INFO    : Bus 80505	: V=0.979731, theta=-44.293416 -> V=1.0, theta=0.0
% INFO    : Bus 80506	: V=0.9794593, theta=-44.552647 -> V=1.0, theta=0.0
% INFO    : Bus 80507	: V=0.9777193, theta=-44.727641 -> V=1.0, theta=0.0
% INFO    : Bus 80508	: V=0.9766665, theta=-45.020821 -> V=1.0, theta=0.0
% INFO    : Bus 80509	: V=0.9719923, theta=-45.064518 -> V=1.0, theta=0.0
% INFO    : Bus 80510	: V=0.967866, theta=-45.151671 -> V=1.0, theta=0.0
% INFO    : Bus 80511	: V=0.9648695, theta=-45.359174 -> V=1.0, theta=0.0
% INFO    : Bus 80512	: V=0.9656116, theta=-45.451209 -> V=1.0, theta=0.0
% INFO    : Bus 80513	: V=0.9667882, theta=-45.2821 -> V=1.0, theta=0.0
% INFO    : Bus 80514	: V=0.9684375, theta=-44.929608 -> V=1.0, theta=0.0
% INFO    : Bus 80515	: V=0.961681, theta=-47.244853 -> V=1.0, theta=0.0
% INFO    : Bus 80516	: V=0.9667169, theta=-45.602014 -> V=1.0, theta=0.0
% INFO    : Bus 80517	: V=0.972232, theta=-42.303042 -> V=1.0, theta=0.0
% INFO    : Bus 80518	: V=0.9692024, theta=-42.386762 -> V=1.0, theta=0.0
% INFO    : Bus 80519	: V=0.9679894, theta=-42.622273 -> V=1.0, theta=0.0
% INFO    : Bus 80520	: V=0.970205, theta=-42.399104 -> V=1.0, theta=0.0
% INFO    : Bus 80521	: V=0.9622899, theta=-43.515042 -> V=1.0, theta=0.0
% INFO    : Bus 80522	: V=0.958987, theta=-43.415617 -> V=1.0, theta=0.0
% INFO    : Bus 80523	: V=0.9848666, theta=-39.847249 -> V=1.0, theta=0.0
% INFO    : Bus 80524	: V=0.986092, theta=-39.622908 -> V=1.0, theta=0.0
% INFO    : Bus 80525	: V=0.9852821, theta=-39.48505 -> V=1.0, theta=0.0
% INFO    : Bus 80526	: V=0.9720998, theta=-41.066637 -> V=1.0, theta=0.0
% INFO    : Bus 80527	: V=0.9817622, theta=-39.719325 -> V=1.0, theta=0.0
% INFO    : Bus 80528	: V=0.9882636, theta=-39.310576 -> V=1.0, theta=0.0
% INFO    : Bus 80529	: V=0.9796351, theta=-39.785077 -> V=1.0, theta=0.0
% INFO    : Bus 80530	: V=0.9896615, theta=-39.028012 -> V=1.0, theta=0.0
% INFO    : Bus 80531	: V=0.9867679, theta=-39.539843 -> V=1.0, theta=0.0
% INFO    : Bus 80532	: V=0.9764334, theta=-40.232063 -> V=1.0, theta=0.0
% INFO    : Bus 80533	: V=0.9890489, theta=-39.057822 -> V=1.0, theta=0.0
% INFO    : Bus 80534	: V=0.9989556, theta=-37.749839 -> V=1.0, theta=0.0
% INFO    : Bus 80535	: V=1.000043, theta=-37.766457 -> V=1.0, theta=0.0
% INFO    : Bus 80536	: V=0.9790787, theta=-39.926205 -> V=1.0, theta=0.0
% INFO    : Bus 80537	: V=0.9856097, theta=-39.332006 -> V=1.0, theta=0.0
% INFO    : Bus 80538	: V=0.9674998, theta=-40.358314 -> V=1.0, theta=0.0
% INFO    : Bus 80539	: V=0.9720964, theta=-43.057823 -> V=1.0, theta=0.0
% INFO    : Bus 80540	: V=1.0104973, theta=-38.057028 -> V=1.0, theta=0.0
% INFO    : Bus 80541	: V=0.9853456, theta=-40.644166 -> V=1.0, theta=0.0
% INFO    : Bus 80542	: V=0.9839483, theta=-41.04172 -> V=1.0, theta=0.0
% INFO    : Bus 80543	: V=0.9721125, theta=-42.090625 -> V=1.0, theta=0.0
% INFO    : Bus 80544	: V=0.9945312, theta=-39.696663 -> V=1.0, theta=0.0
% INFO    : Bus 80545	: V=0.9886639, theta=-40.490497 -> V=1.0, theta=0.0
% INFO    : Bus 80546	: V=0.9804558, theta=-41.728998 -> V=1.0, theta=0.0
% INFO    : Bus 80547	: V=0.982842, theta=-41.066899 -> V=1.0, theta=0.0
% INFO    : Bus 80548	: V=0.9540589, theta=-42.602034 -> V=1.0, theta=0.0
% INFO    : Bus 80549	: V=0.9512288, theta=-47.409223 -> V=1.0, theta=0.0
% INFO    : Bus 80550	: V=0.9572588, theta=-46.862429 -> V=1.0, theta=0.0
% INFO    : Bus 80551	: V=0.9523162, theta=-47.48324 -> V=1.0, theta=0.0
% INFO    : Bus 80552	: V=0.9619093, theta=-46.621173 -> V=1.0, theta=0.0
% INFO    : Bus 80553	: V=0.9538243, theta=-47.346681 -> V=1.0, theta=0.0
% INFO    : Bus 80554	: V=0.9529675, theta=-47.394961 -> V=1.0, theta=0.0
% INFO    : Bus 80555	: V=0.9532239, theta=-47.323295 -> V=1.0, theta=0.0
% INFO    : Bus 80556	: V=0.9581779, theta=-46.815508 -> V=1.0, theta=0.0
% INFO    : Bus 80557	: V=0.9552055, theta=-47.331624 -> V=1.0, theta=0.0
% INFO    : Bus 80558	: V=0.9617409, theta=-46.564527 -> V=1.0, theta=0.0
% INFO    : Bus 80559	: V=0.962007, theta=-46.599045 -> V=1.0, theta=0.0
% INFO    : Bus 80560	: V=0.9569678, theta=-47.24724 -> V=1.0, theta=0.0
% INFO    : Bus 80561	: V=0.9603488, theta=-46.604701 -> V=1.0, theta=0.0
% INFO    : Bus 80562	: V=0.9628792, theta=-46.480967 -> V=1.0, theta=0.0
% INFO    : Bus 80563	: V=0.9626749, theta=-46.577444 -> V=1.0, theta=0.0
% INFO    : Bus 80564	: V=0.9524991, theta=-47.514993 -> V=1.0, theta=0.0
% INFO    : Bus 80565	: V=0.9615637, theta=-46.641242 -> V=1.0, theta=0.0
% INFO    : Bus 80566	: V=0.9476437, theta=-47.816565 -> V=1.0, theta=0.0
% INFO    : Bus 80567	: V=0.948121, theta=-47.93078 -> V=1.0, theta=0.0
% INFO    : Bus 80568	: V=0.9472806, theta=-47.707225 -> V=1.0, theta=0.0
% INFO    : Bus 80569	: V=0.9485885, theta=-47.890933 -> V=1.0, theta=0.0
% INFO    : Bus 80570	: V=0.951714, theta=-47.190261 -> V=1.0, theta=0.0
% INFO    : Bus 80571	: V=0.9603321, theta=-46.273185 -> V=1.0, theta=0.0
% INFO    : Bus 80572	: V=0.9618104, theta=-46.05907 -> V=1.0, theta=0.0
% INFO    : Bus 80573	: V=0.9560768, theta=-46.450753 -> V=1.0, theta=0.0
% INFO    : Bus 80574	: V=0.9858823, theta=-44.243829 -> V=1.0, theta=0.0
% INFO    : Bus 80575	: V=0.9666234, theta=-45.761805 -> V=1.0, theta=0.0
% INFO    : Bus 80576	: V=0.9642488, theta=-46.13852 -> V=1.0, theta=0.0
% INFO    : Bus 80577	: V=0.9908813, theta=-43.478508 -> V=1.0, theta=0.0
% INFO    : Bus 80578	: V=0.9773519, theta=-44.827668 -> V=1.0, theta=0.0
% INFO    : Bus 80579	: V=0.973528, theta=-45.484048 -> V=1.0, theta=0.0
% INFO    : Bus 80580	: V=0.9623223, theta=-46.192714 -> V=1.0, theta=0.0
% INFO    : Bus 80581	: V=0.9767321, theta=-45.077752 -> V=1.0, theta=0.0
% INFO    : Bus 80582	: V=0.968313, theta=-45.855661 -> V=1.0, theta=0.0
% INFO    : Bus 80583	: V=0.9632765, theta=-46.57947 -> V=1.0, theta=0.0
% INFO    : Bus 80584	: V=0.9437203, theta=-48.079966 -> V=1.0, theta=0.0
% INFO    : Bus 80585	: V=0.9589529, theta=-47.031396 -> V=1.0, theta=0.0
% INFO    : Bus 80586	: V=0.9450491, theta=-48.4241 -> V=1.0, theta=0.0
% INFO    : Bus 80587	: V=0.9410742, theta=-48.461276 -> V=1.0, theta=0.0
% INFO    : Bus 80588	: V=1.0108555, theta=-39.488551 -> V=1.0, theta=0.0
% INFO    : Bus 80589	: V=1.015511, theta=-39.244394 -> V=1.0, theta=0.0
% INFO    : Bus 80590	: V=1.0147167, theta=-39.264305 -> V=1.0, theta=0.0
% INFO    : Bus 80591	: V=1.0140412, theta=-39.314739 -> V=1.0, theta=0.0
% INFO    : Bus 80592	: V=0.9551857, theta=-41.513267 -> V=1.0, theta=0.0
% INFO    : Bus 80593	: V=0.9624768, theta=-41.378622 -> V=1.0, theta=0.0
% INFO    : Bus 80594	: V=0.9655944, theta=-41.20483 -> V=1.0, theta=0.0
% INFO    : Bus 80595	: V=0.9732756, theta=-40.53454 -> V=1.0, theta=0.0
% INFO    : Bus 80596	: V=0.9678282, theta=-41.211762 -> V=1.0, theta=0.0
% INFO    : Bus 80597	: V=0.977011, theta=-40.759882 -> V=1.0, theta=0.0
% INFO    : Bus 80598	: V=0.9785102, theta=-39.936558 -> V=1.0, theta=0.0
% INFO    : Bus 80599	: V=0.9809429, theta=-39.426932 -> V=1.0, theta=0.0
% INFO    : Bus 80600	: V=0.9883472, theta=-45.976268 -> V=1.0, theta=0.0
% INFO    : Bus 80601	: V=0.9682458, theta=-48.217474 -> V=1.0, theta=0.0
% INFO    : Bus 80602	: V=0.9804829, theta=-44.915952 -> V=1.0, theta=0.0
% INFO    : Bus 80603	: V=0.9451153, theta=-49.069025 -> V=1.0, theta=0.0
% INFO    : Bus 80604	: V=0.9480798, theta=-48.705916 -> V=1.0, theta=0.0
% INFO    : Bus 80605	: V=0.9478994, theta=-48.708852 -> V=1.0, theta=0.0
% INFO    : Bus 80606	: V=0.9517429, theta=-47.665348 -> V=1.0, theta=0.0
% INFO    : Bus 80607	: V=0.9689795, theta=-43.902523 -> V=1.0, theta=0.0
% INFO    : Bus 80608	: V=0.9618766, theta=-44.395059 -> V=1.0, theta=0.0
% INFO    : Bus 80609	: V=0.9724129, theta=-39.512442 -> V=1.0, theta=0.0
% INFO    : Bus 80610	: V=0.9778039, theta=-38.598416 -> V=1.0, theta=0.0
% INFO    : Bus 80611	: V=0.9712091, theta=-44.154207 -> V=1.0, theta=0.0
% INFO    : Bus 80612	: V=0.9650244, theta=-45.2529 -> V=1.0, theta=0.0
% INFO    : Bus 80613	: V=0.9724471, theta=-44.124624 -> V=1.0, theta=0.0
% INFO    : Bus 80614	: V=0.9825118, theta=-42.727986 -> V=1.0, theta=0.0
% INFO    : Bus 80615	: V=0.9835601, theta=-42.703849 -> V=1.0, theta=0.0
% INFO    : Bus 80616	: V=0.9632208, theta=-45.861667 -> V=1.0, theta=0.0
% INFO    : Bus 80617	: V=0.9763707, theta=-42.765995 -> V=1.0, theta=0.0
% INFO    : Bus 80618	: V=0.9956379, theta=-40.397886 -> V=1.0, theta=0.0
% INFO    : Bus 80619	: V=0.9945324, theta=-40.684605 -> V=1.0, theta=0.0
% INFO    : Bus 80620	: V=0.983657, theta=-41.033853 -> V=1.0, theta=0.0
% INFO    : Bus 80621	: V=0.9881759, theta=-40.21671 -> V=1.0, theta=0.0
% INFO    : Bus 80622	: V=0.9833369, theta=-41.133035 -> V=1.0, theta=0.0
% INFO    : Bus 80623	: V=0.9784277, theta=-42.953998 -> V=1.0, theta=0.0
% INFO    : Bus 80624	: V=0.9797946, theta=-42.389228 -> V=1.0, theta=0.0
% INFO    : Bus 80625	: V=0.9652475, theta=-45.092146 -> V=1.0, theta=0.0
% INFO    : Bus 80626	: V=0.9736831, theta=-40.521875 -> V=1.0, theta=0.0
% INFO    : Bus 80627	: V=0.9760865, theta=-40.317874 -> V=1.0, theta=0.0
% INFO    : Bus 80628	: V=0.9586841, theta=-42.303494 -> V=1.0, theta=0.0
% INFO    : Bus 80629	: V=0.9561145, theta=-42.774217 -> V=1.0, theta=0.0
% INFO    : Bus 80630	: V=0.9567289, theta=-42.942095 -> V=1.0, theta=0.0
% INFO    : Bus 80631	: V=0.9630538, theta=-41.669256 -> V=1.0, theta=0.0
% INFO    : Bus 80632	: V=0.9625041, theta=-41.550164 -> V=1.0, theta=0.0
% INFO    : Bus 80633	: V=0.9648607, theta=-41.350523 -> V=1.0, theta=0.0
% INFO    : Bus 80634	: V=0.9487818, theta=-39.847526 -> V=1.0, theta=0.0
% INFO    : Bus 80635	: V=0.9715092, theta=-41.698866 -> V=1.0, theta=0.0
% INFO    : Bus 80636	: V=0.9723352, theta=-41.298064 -> V=1.0, theta=0.0
% INFO    : Bus 80637	: V=0.9750277, theta=-40.683713 -> V=1.0, theta=0.0
% INFO    : Bus 80638	: V=0.9949722, theta=-39.868912 -> V=1.0, theta=0.0
% INFO    : Bus 80639	: V=0.9988216, theta=-39.631905 -> V=1.0, theta=0.0
% INFO    : Bus 80640	: V=0.9967213, theta=-39.262007 -> V=1.0, theta=0.0
% INFO    : Bus 80641	: V=0.998887, theta=-39.072793 -> V=1.0, theta=0.0
% INFO    : Bus 80642	: V=0.9413592, theta=-42.373734 -> V=1.0, theta=0.0
% INFO    : Bus 80643	: V=0.950239, theta=-41.082933 -> V=1.0, theta=0.0
% INFO    : Bus 80644	: V=0.9474501, theta=-41.607138 -> V=1.0, theta=0.0
% INFO    : Bus 80645	: V=0.9506606, theta=-41.40926 -> V=1.0, theta=0.0
% INFO    : Bus 80646	: V=0.9463858, theta=-42.071935 -> V=1.0, theta=0.0
% INFO    : Bus 80647	: V=0.9580854, theta=-40.787416 -> V=1.0, theta=0.0
% INFO    : Bus 80648	: V=0.9614421, theta=-40.305533 -> V=1.0, theta=0.0
% INFO    : Bus 80649	: V=0.9609941, theta=-39.515997 -> V=1.0, theta=0.0
% INFO    : Bus 80650	: V=0.9637254, theta=-42.042432 -> V=1.0, theta=0.0
% INFO    : Bus 80651	: V=0.9758438, theta=-41.337361 -> V=1.0, theta=0.0
% INFO    : Bus 80652	: V=0.9850395, theta=-40.548569 -> V=1.0, theta=0.0
% INFO    : Bus 80653	: V=0.9587898, theta=-47.293825 -> V=1.0, theta=0.0
% INFO    : Bus 80654	: V=0.9506407, theta=-48.818509 -> V=1.0, theta=0.0
% INFO    : Bus 80655	: V=0.9649601, theta=-46.467543 -> V=1.0, theta=0.0
% INFO    : Bus 80656	: V=1.0018461, theta=-39.096793 -> V=1.0, theta=0.0
% INFO    : Bus 80657	: V=0.9814407, theta=-42.124273 -> V=1.0, theta=0.0
% INFO    : Bus 80658	: V=0.969595, theta=-43.593204 -> V=1.0, theta=0.0
% INFO    : Bus 80659	: V=0.975982, theta=-42.573843 -> V=1.0, theta=0.0
% INFO    : Bus 80660	: V=0.9778009, theta=-42.266753 -> V=1.0, theta=0.0
% INFO    : Bus 80661	: V=0.970879, theta=-48.360005 -> V=1.0, theta=0.0
% INFO    : Bus 80662	: V=0.983891, theta=-39.010017 -> V=1.0, theta=0.0
% INFO    : Bus 80663	: V=0.9792437, theta=-39.486975 -> V=1.0, theta=0.0
% INFO    : Bus 80664	: V=0.9799667, theta=-39.283926 -> V=1.0, theta=0.0
% INFO    : Bus 80665	: V=0.9760227, theta=-39.481409 -> V=1.0, theta=0.0
% INFO    : Bus 80666	: V=0.9787117, theta=-39.505157 -> V=1.0, theta=0.0
% INFO    : Bus 80667	: V=0.974491, theta=-39.5881 -> V=1.0, theta=0.0
% INFO    : Bus 80668	: V=0.9772741, theta=-39.366681 -> V=1.0, theta=0.0
% INFO    : Bus 80669	: V=0.9748352, theta=-39.513288 -> V=1.0, theta=0.0
% INFO    : Bus 80670	: V=0.9742611, theta=-39.305001 -> V=1.0, theta=0.0
% INFO    : Bus 80671	: V=0.9708549, theta=-39.81287 -> V=1.0, theta=0.0
% INFO    : Bus 80672	: V=0.9717177, theta=-39.663562 -> V=1.0, theta=0.0
% INFO    : Bus 80673	: V=0.9779797, theta=-39.308985 -> V=1.0, theta=0.0
% INFO    : Bus 80674	: V=0.9769352, theta=-39.49669 -> V=1.0, theta=0.0
% INFO    : Bus 80675	: V=0.9802255, theta=-38.850862 -> V=1.0, theta=0.0
% INFO    : Bus 80676	: V=0.9765547, theta=-39.170411 -> V=1.0, theta=0.0
% INFO    : Bus 80677	: V=0.9861047, theta=-38.007717 -> V=1.0, theta=0.0
% INFO    : Bus 80678	: V=0.9864539, theta=-38.313213 -> V=1.0, theta=0.0
% INFO    : Bus 80679	: V=0.9870167, theta=-38.131381 -> V=1.0, theta=0.0
% INFO    : Bus 80680	: V=0.9870683, theta=-38.013203 -> V=1.0, theta=0.0
% INFO    : Bus 80681	: V=0.9793877, theta=-39.126586 -> V=1.0, theta=0.0
% INFO    : Bus 80682	: V=0.9842367, theta=-38.815628 -> V=1.0, theta=0.0
% INFO    : Bus 80683	: V=0.9861256, theta=-38.555892 -> V=1.0, theta=0.0
% INFO    : Bus 80684	: V=0.9925109, theta=-37.756579 -> V=1.0, theta=0.0
% INFO    : Bus 80685	: V=0.989481, theta=-37.91736 -> V=1.0, theta=0.0
% INFO    : Bus 80686	: V=0.9852981, theta=-38.769806 -> V=1.0, theta=0.0
% INFO    : Bus 80687	: V=0.991721, theta=-38.194933 -> V=1.0, theta=0.0
% INFO    : Bus 80688	: V=0.9891756, theta=-38.557994 -> V=1.0, theta=0.0
% INFO    : Bus 80689	: V=1.0041709, theta=-36.888182 -> V=1.0, theta=0.0
% INFO    : Bus 80690	: V=0.998207, theta=-37.711025 -> V=1.0, theta=0.0
% INFO    : Bus 80691	: V=1.0038141, theta=-36.996013 -> V=1.0, theta=0.0
% INFO    : Bus 80692	: V=0.9965983, theta=-37.917325 -> V=1.0, theta=0.0
% INFO    : Bus 80693	: V=0.9957018, theta=-38.167043 -> V=1.0, theta=0.0
% INFO    : Bus 80694	: V=0.9908804, theta=-38.640204 -> V=1.0, theta=0.0
% INFO    : Bus 80695	: V=0.9935734, theta=-38.405179 -> V=1.0, theta=0.0
% INFO    : Bus 80696	: V=0.9940977, theta=-38.095636 -> V=1.0, theta=0.0
% INFO    : Bus 80697	: V=0.9832608, theta=-39.224619 -> V=1.0, theta=0.0
% INFO    : Bus 80698	: V=0.9809775, theta=-39.497191 -> V=1.0, theta=0.0
% INFO    : Bus 80699	: V=0.9788432, theta=-39.524336 -> V=1.0, theta=0.0
% INFO    : Bus 80700	: V=0.9850477, theta=-38.88128 -> V=1.0, theta=0.0
% INFO    : Bus 80701	: V=0.977828, theta=-39.601513 -> V=1.0, theta=0.0
% INFO    : Bus 80702	: V=0.9877198, theta=-38.993011 -> V=1.0, theta=0.0
% INFO    : Bus 80703	: V=0.9924278, theta=-38.71157 -> V=1.0, theta=0.0
% INFO    : Bus 80704	: V=0.9903806, theta=-39.091958 -> V=1.0, theta=0.0
% INFO    : Bus 80705	: V=0.9866996, theta=-39.210806 -> V=1.0, theta=0.0
% INFO    : Bus 80706	: V=0.9863993, theta=-39.579687 -> V=1.0, theta=0.0
% INFO    : Bus 80707	: V=0.9864162, theta=-39.554014 -> V=1.0, theta=0.0
% INFO    : Bus 80708	: V=0.9804542, theta=-39.706272 -> V=1.0, theta=0.0
% INFO    : Bus 80709	: V=0.9782578, theta=-39.925054 -> V=1.0, theta=0.0
% INFO    : Bus 80710	: V=0.9752028, theta=-39.935249 -> V=1.0, theta=0.0
% INFO    : Bus 80711	: V=0.9730884, theta=-40.380521 -> V=1.0, theta=0.0
% INFO    : Bus 80712	: V=0.9753808, theta=-39.148352 -> V=1.0, theta=0.0
% INFO    : Bus 80713	: V=0.9791829, theta=-38.761329 -> V=1.0, theta=0.0
% INFO    : Bus 80714	: V=0.9732349, theta=-39.320932 -> V=1.0, theta=0.0
% INFO    : Bus 80715	: V=0.9791712, theta=-38.522906 -> V=1.0, theta=0.0
% INFO    : Bus 80716	: V=0.9785724, theta=-38.531421 -> V=1.0, theta=0.0
% INFO    : Bus 80717	: V=0.9963959, theta=-36.986162 -> V=1.0, theta=0.0
% INFO    : Bus 80718	: V=0.9943639, theta=-37.454557 -> V=1.0, theta=0.0
% INFO    : Bus 80719	: V=0.9906867, theta=-37.708618 -> V=1.0, theta=0.0
% INFO    : Bus 80720	: V=0.9890973, theta=-37.750644 -> V=1.0, theta=0.0
% INFO    : Bus 80721	: V=0.9832337, theta=-37.864109 -> V=1.0, theta=0.0
% INFO    : Bus 80722	: V=0.9828531, theta=-37.792835 -> V=1.0, theta=0.0
% INFO    : Bus 80723	: V=0.997765, theta=-37.780822 -> V=1.0, theta=0.0
% INFO    : Bus 80724	: V=0.9960884, theta=-38.105383 -> V=1.0, theta=0.0
% INFO    : Bus 80725	: V=0.9921284, theta=-37.585879 -> V=1.0, theta=0.0
% INFO    : Bus 80726	: V=0.9955673, theta=-37.414883 -> V=1.0, theta=0.0
% INFO    : Bus 80727	: V=1.0022576, theta=-36.69815 -> V=1.0, theta=0.0
% INFO    : Bus 80728	: V=1.0003671, theta=-36.945511 -> V=1.0, theta=0.0
% INFO    : Bus 80729	: V=0.9858001, theta=-38.994408 -> V=1.0, theta=0.0
% INFO    : Bus 80730	: V=0.9940506, theta=-38.498868 -> V=1.0, theta=0.0
% INFO    : Bus 80731	: V=1.0006439, theta=-37.742643 -> V=1.0, theta=0.0
% INFO    : Bus 80732	: V=0.9950574, theta=-38.273496 -> V=1.0, theta=0.0
% INFO    : Bus 80733	: V=0.9918083, theta=-38.574752 -> V=1.0, theta=0.0
% INFO    : Bus 80734	: V=0.9934012, theta=-38.462761 -> V=1.0, theta=0.0
% INFO    : Bus 80735	: V=0.9977192, theta=-38.461742 -> V=1.0, theta=0.0
% INFO    : Bus 80736	: V=0.9953066, theta=-38.876472 -> V=1.0, theta=0.0
% INFO    : Bus 80737	: V=0.9985193, theta=-38.316739 -> V=1.0, theta=0.0
% INFO    : Bus 80738	: V=0.9923578, theta=-38.953766 -> V=1.0, theta=0.0
% INFO    : Bus 80739	: V=0.9942142, theta=-38.948181 -> V=1.0, theta=0.0
% INFO    : Bus 80740	: V=0.9922185, theta=-39.155215 -> V=1.0, theta=0.0
% INFO    : Bus 80741	: V=0.9930045, theta=-39.216992 -> V=1.0, theta=0.0
% INFO    : Bus 80742	: V=0.988219, theta=-38.64714 -> V=1.0, theta=0.0
% INFO    : Bus 80743	: V=1.0060654, theta=-35.958094 -> V=1.0, theta=0.0
% INFO    : Bus 80744	: V=1.0000774, theta=-36.976252 -> V=1.0, theta=0.0
% INFO    : Bus 80745	: V=0.9652613, theta=-46.88017 -> V=1.0, theta=0.0
% INFO    : Bus 80746	: V=0.9592933, theta=-48.094642 -> V=1.0, theta=0.0
% INFO    : Bus 80747	: V=0.9570093, theta=-43.772294 -> V=1.0, theta=0.0
% INFO    : Bus 80748	: V=0.9656201, theta=-43.109611 -> V=1.0, theta=0.0
% INFO    : Bus 80749	: V=0.9844495, theta=-41.337822 -> V=1.0, theta=0.0
% INFO    : Bus 80750	: V=0.9729452, theta=-41.261565 -> V=1.0, theta=0.0
% INFO    : Bus 80751	: V=0.9722481, theta=-41.248007 -> V=1.0, theta=0.0
% INFO    : Bus 80752	: V=0.9721111, theta=-41.293408 -> V=1.0, theta=0.0
% INFO    : Bus 80753	: V=0.9727755, theta=-40.618877 -> V=1.0, theta=0.0
% INFO    : Bus 80754	: V=0.9699527, theta=-40.80899 -> V=1.0, theta=0.0
% INFO    : Bus 80755	: V=0.973819, theta=-39.883544 -> V=1.0, theta=0.0
% INFO    : Bus 80756	: V=0.9530027, theta=-45.725177 -> V=1.0, theta=0.0
% INFO    : Bus 80757	: V=0.959711, theta=-45.060162 -> V=1.0, theta=0.0
% INFO    : Bus 80758	: V=0.9703821, theta=-44.273325 -> V=1.0, theta=0.0
% INFO    : Bus 80759	: V=0.957671, theta=-44.690103 -> V=1.0, theta=0.0
% INFO    : Bus 80760	: V=0.9557746, theta=-44.52994 -> V=1.0, theta=0.0
% INFO    : Bus 80761	: V=0.957397, theta=-43.81387 -> V=1.0, theta=0.0
% INFO    : Bus 80762	: V=0.9917257, theta=-29.325534 -> V=1.0, theta=0.0
% INFO    : Bus 80763	: V=0.9891404, theta=-28.877519 -> V=1.0, theta=0.0
% INFO    : Bus 80764	: V=0.9965603, theta=-28.456357 -> V=1.0, theta=0.0
% INFO    : Bus 80765	: V=0.9947677, theta=-28.60515 -> V=1.0, theta=0.0
% INFO    : Bus 80766	: V=1.0052847, theta=-27.229634 -> V=1.0, theta=0.0
% INFO    : Bus 80767	: V=0.9992474, theta=-28.106589 -> V=1.0, theta=0.0
% INFO    : Bus 80768	: V=0.9984283, theta=-28.197264 -> V=1.0, theta=0.0
% INFO    : Bus 80769	: V=0.9953404, theta=-28.609747 -> V=1.0, theta=0.0
% INFO    : Bus 80770	: V=0.9945408, theta=-28.611014 -> V=1.0, theta=0.0
% INFO    : Bus 80771	: V=0.9954642, theta=-28.570863 -> V=1.0, theta=0.0
% INFO    : Bus 80772	: V=0.9957094, theta=-28.585474 -> V=1.0, theta=0.0
% INFO    : Bus 80773	: V=0.9960467, theta=-28.559815 -> V=1.0, theta=0.0
% INFO    : Bus 80774	: V=1.0016783, theta=-28.863543 -> V=1.0, theta=0.0
% INFO    : Bus 80775	: V=1.000156, theta=-28.984229 -> V=1.0, theta=0.0
% INFO    : Bus 80776	: V=0.9889785, theta=-29.31538 -> V=1.0, theta=0.0
% INFO    : Bus 80777	: V=0.9888628, theta=-29.334015 -> V=1.0, theta=0.0
% INFO    : Bus 80778	: V=0.9897652, theta=-29.33028 -> V=1.0, theta=0.0
% INFO    : Bus 80779	: V=0.9859563, theta=-28.78897 -> V=1.0, theta=0.0
% INFO    : Bus 80780	: V=0.9948145, theta=-27.878708 -> V=1.0, theta=0.0
% INFO    : Bus 80781	: V=0.9896933, theta=-43.229834 -> V=1.0, theta=0.0
% INFO    : Bus 80782	: V=1.0028858, theta=-40.723769 -> V=1.0, theta=0.0
% INFO    : Bus 80783	: V=0.953484, theta=-37.637103 -> V=1.0, theta=0.0
% INFO    : Bus 80784	: V=0.958523, theta=-37.916804 -> V=1.0, theta=0.0
% INFO    : Bus 80785	: V=0.9535695, theta=-38.536896 -> V=1.0, theta=0.0
% INFO    : Bus 80786	: V=0.9663527, theta=-36.096852 -> V=1.0, theta=0.0
% INFO    : Bus 80787	: V=0.9688262, theta=-36.014633 -> V=1.0, theta=0.0
% INFO    : Bus 80788	: V=0.9575281, theta=-37.722351 -> V=1.0, theta=0.0
% INFO    : Bus 80789	: V=0.9597915, theta=-37.276429 -> V=1.0, theta=0.0
% INFO    : Bus 80790	: V=0.9550575, theta=-37.624471 -> V=1.0, theta=0.0
% INFO    : Bus 80791	: V=0.9703719, theta=-43.240222 -> V=1.0, theta=0.0
% INFO    : Bus 80792	: V=0.9586871, theta=-43.917487 -> V=1.0, theta=0.0
% INFO    : Bus 80793	: V=0.9577017, theta=-44.459868 -> V=1.0, theta=0.0
% INFO    : Bus 80794	: V=0.9300266, theta=-46.117967 -> V=1.0, theta=0.0
% INFO    : Bus 80795	: V=0.9537249, theta=-44.275317 -> V=1.0, theta=0.0
% INFO    : Bus 80796	: V=0.955051, theta=-44.221405 -> V=1.0, theta=0.0
% INFO    : Bus 80797	: V=0.9559982, theta=-44.132901 -> V=1.0, theta=0.0
% INFO    : Bus 80798	: V=0.9638457, theta=-44.775801 -> V=1.0, theta=0.0
% INFO    : Bus 80799	: V=0.9707808, theta=-43.93714 -> V=1.0, theta=0.0
% INFO    : Bus 80800	: V=0.9690105, theta=-44.175365 -> V=1.0, theta=0.0
% INFO    : Bus 80801	: V=0.9810936, theta=-31.582558 -> V=1.0, theta=0.0
% INFO    : Bus 80802	: V=0.9833312, theta=-32.483656 -> V=1.0, theta=0.0
% INFO    : Bus 80803	: V=0.9795388, theta=-32.805391 -> V=1.0, theta=0.0
% INFO    : Bus 80804	: V=0.9842076, theta=-32.206737 -> V=1.0, theta=0.0
% INFO    : Bus 80805	: V=0.9608002, theta=-45.140965 -> V=1.0, theta=0.0
% INFO    : Bus 80806	: V=1.0092601, theta=-38.494512 -> V=1.0, theta=0.0
% INFO    : Bus 80807	: V=1.0165215, theta=-36.913049 -> V=1.0, theta=0.0
% INFO    : Bus 80808	: V=1.0044033, theta=-38.790513 -> V=1.0, theta=0.0
% INFO    : Bus 80809	: V=0.9970538, theta=-39.737248 -> V=1.0, theta=0.0
% INFO    : Bus 80810	: V=0.9911078, theta=-41.350307 -> V=1.0, theta=0.0
% INFO    : Bus 80811	: V=0.9375805, theta=-46.244174 -> V=1.0, theta=0.0
% INFO    : Bus 80812	: V=0.9399918, theta=-45.575268 -> V=1.0, theta=0.0
% INFO    : Bus 80813	: V=0.9403879, theta=-45.76455 -> V=1.0, theta=0.0
% INFO    : Bus 80814	: V=0.9440582, theta=-45.854855 -> V=1.0, theta=0.0
% INFO    : Bus 80815	: V=0.953758, theta=-43.013249 -> V=1.0, theta=0.0
% INFO    : Bus 80816	: V=0.9450096, theta=-44.626542 -> V=1.0, theta=0.0
% INFO    : Bus 80817	: V=0.946545, theta=-45.333792 -> V=1.0, theta=0.0
% INFO    : Bus 80818	: V=0.9487136, theta=-44.314189 -> V=1.0, theta=0.0
% INFO    : Bus 80819	: V=0.945762, theta=-45.663751 -> V=1.0, theta=0.0
% INFO    : Bus 80820	: V=0.9640111, theta=-45.902899 -> V=1.0, theta=0.0
% INFO    : Bus 80821	: V=0.9462991, theta=-46.622489 -> V=1.0, theta=0.0
% INFO    : Bus 80822	: V=0.9452421, theta=-46.806934 -> V=1.0, theta=0.0
% INFO    : Bus 80823	: V=0.9438623, theta=-47.126941 -> V=1.0, theta=0.0
% INFO    : Bus 80824	: V=0.9492069, theta=-46.622142 -> V=1.0, theta=0.0
% INFO    : Bus 80825	: V=0.9333662, theta=-48.685544 -> V=1.0, theta=0.0
% INFO    : Bus 80826	: V=0.9373941, theta=-48.284079 -> V=1.0, theta=0.0
% INFO    : Bus 80827	: V=0.9425088, theta=-47.91933 -> V=1.0, theta=0.0
% INFO    : Bus 80828	: V=0.9424575, theta=-47.64339 -> V=1.0, theta=0.0
% INFO    : Bus 80829	: V=0.9502935, theta=-47.994621 -> V=1.0, theta=0.0
% INFO    : Bus 80830	: V=0.9484721, theta=-47.98719 -> V=1.0, theta=0.0
% INFO    : Bus 80831	: V=0.9999032, theta=-36.024806 -> V=1.0, theta=0.0
% INFO    : Bus 80832	: V=1.0125213, theta=-35.525062 -> V=1.0, theta=0.0
% INFO    : Bus 80833	: V=0.9960368, theta=-37.457102 -> V=1.0, theta=0.0
% INFO    : Bus 80834	: V=0.9691834, theta=-38.803777 -> V=1.0, theta=0.0
% INFO    : Bus 80835	: V=0.96816, theta=-39.407923 -> V=1.0, theta=0.0
% INFO    : Bus 80836	: V=0.9763758, theta=-38.016569 -> V=1.0, theta=0.0
% INFO    : Bus 80837	: V=0.9812146, theta=-37.575495 -> V=1.0, theta=0.0
% INFO    : Bus 80838	: V=0.9849892, theta=-36.784557 -> V=1.0, theta=0.0
% INFO    : Bus 80839	: V=0.9865629, theta=-36.743018 -> V=1.0, theta=0.0
% INFO    : Bus 80840	: V=0.9972959, theta=-36.527359 -> V=1.0, theta=0.0
% INFO    : Bus 80841	: V=0.9897941, theta=-34.900602 -> V=1.0, theta=0.0
% INFO    : Bus 80842	: V=0.991331, theta=-35.099507 -> V=1.0, theta=0.0
% INFO    : Bus 80843	: V=0.9962018, theta=-34.862697 -> V=1.0, theta=0.0
% INFO    : Bus 80844	: V=0.9886987, theta=-43.179349 -> V=1.0, theta=0.0
% INFO    : Bus 80845	: V=0.9907927, theta=-43.530364 -> V=1.0, theta=0.0
% INFO    : Bus 80846	: V=1.0022516, theta=-42.579112 -> V=1.0, theta=0.0
% INFO    : Bus 80847	: V=1.0035516, theta=-42.51182 -> V=1.0, theta=0.0
% INFO    : Bus 80848	: V=0.9941038, theta=-43.989363 -> V=1.0, theta=0.0
% INFO    : Bus 80849	: V=0.9921205, theta=-42.948088 -> V=1.0, theta=0.0
% INFO    : Bus 80850	: V=0.9927041, theta=-42.362311 -> V=1.0, theta=0.0
% INFO    : Bus 80851	: V=0.9936786, theta=-42.511216 -> V=1.0, theta=0.0
% INFO    : Bus 80852	: V=0.9938517, theta=-42.722604 -> V=1.0, theta=0.0
% INFO    : Bus 80853	: V=0.9957627, theta=-42.556371 -> V=1.0, theta=0.0
% INFO    : Bus 80854	: V=0.99996, theta=-40.713351 -> V=1.0, theta=0.0
% INFO    : Bus 80855	: V=1.0028042, theta=-40.378637 -> V=1.0, theta=0.0
% INFO    : Bus 80856	: V=0.9945499, theta=-41.362692 -> V=1.0, theta=0.0
% INFO    : Bus 80857	: V=0.9985573, theta=-40.899879 -> V=1.0, theta=0.0
% INFO    : Bus 80858	: V=1.0021691, theta=-40.174439 -> V=1.0, theta=0.0
% INFO    : Bus 80859	: V=0.9974129, theta=-40.718767 -> V=1.0, theta=0.0
% INFO    : Bus 80860	: V=1.0026126, theta=-40.190865 -> V=1.0, theta=0.0
% INFO    : Bus 80861	: V=1.0013241, theta=-40.420781 -> V=1.0, theta=0.0
% INFO    : Bus 80862	: V=1.0024293, theta=-40.487691 -> V=1.0, theta=0.0
% INFO    : Bus 80863	: V=0.9932587, theta=-40.235307 -> V=1.0, theta=0.0
% INFO    : Bus 80864	: V=0.9935754, theta=-40.293643 -> V=1.0, theta=0.0
% INFO    : Bus 80865	: V=1.0009639, theta=-41.078376 -> V=1.0, theta=0.0
% INFO    : Bus 80866	: V=0.9950641, theta=-41.86406 -> V=1.0, theta=0.0
% INFO    : Bus 80867	: V=0.9906767, theta=-42.327913 -> V=1.0, theta=0.0
% INFO    : Bus 80868	: V=0.9994099, theta=-40.680344 -> V=1.0, theta=0.0
% INFO    : Bus 80869	: V=0.9971551, theta=-40.897954 -> V=1.0, theta=0.0
% INFO    : Bus 80870	: V=0.9905586, theta=-40.672889 -> V=1.0, theta=0.0
% INFO    : Bus 80871	: V=1.0018395, theta=-39.876798 -> V=1.0, theta=0.0
% INFO    : Bus 80872	: V=0.9996331, theta=-40.143176 -> V=1.0, theta=0.0
% INFO    : Bus 80873	: V=0.9739638, theta=-38.903223 -> V=1.0, theta=0.0
% INFO    : Bus 80874	: V=0.9600494, theta=-38.7739 -> V=1.0, theta=0.0
% INFO    : Bus 80875	: V=0.9967649, theta=-35.998583 -> V=1.0, theta=0.0
% INFO    : Bus 80876	: V=1.0029488, theta=-35.168789 -> V=1.0, theta=0.0
% INFO    : Bus 80877	: V=1.0058151, theta=-34.541553 -> V=1.0, theta=0.0
% INFO    : Bus 80878	: V=0.9956245, theta=-35.585737 -> V=1.0, theta=0.0
% INFO    : Bus 80879	: V=0.9933533, theta=-36.029874 -> V=1.0, theta=0.0
% INFO    : Bus 80880	: V=0.968162, theta=-43.066271 -> V=1.0, theta=0.0
% INFO    : Bus 80881	: V=0.963491, theta=-42.94313 -> V=1.0, theta=0.0
% INFO    : Bus 80882	: V=0.9668546, theta=-41.42211 -> V=1.0, theta=0.0
% INFO    : Bus 80883	: V=0.9646537, theta=-42.728405 -> V=1.0, theta=0.0
% INFO    : Bus 80884	: V=0.9663703, theta=-42.246313 -> V=1.0, theta=0.0
% INFO    : Bus 80885	: V=0.9512199, theta=-48.586168 -> V=1.0, theta=0.0
% INFO    : Bus 80886	: V=0.9750455, theta=-46.015586 -> V=1.0, theta=0.0
% INFO    : Bus 80887	: V=0.9449916, theta=-51.83952 -> V=1.0, theta=0.0
% INFO    : Bus 80888	: V=0.9489993, theta=-51.510612 -> V=1.0, theta=0.0
% INFO    : Bus 80889	: V=0.9470612, theta=-51.491601 -> V=1.0, theta=0.0
% INFO    : Bus 80890	: V=0.9478806, theta=-50.141899 -> V=1.0, theta=0.0
% INFO    : Bus 80891	: V=0.9435953, theta=-49.962898 -> V=1.0, theta=0.0
% INFO    : Bus 80892	: V=0.9986311, theta=-40.530414 -> V=1.0, theta=0.0
% INFO    : Bus 80893	: V=0.996027, theta=-40.863505 -> V=1.0, theta=0.0
% INFO    : Bus 80894	: V=0.9520859, theta=-47.638948 -> V=1.0, theta=0.0
% INFO    : Bus 80895	: V=0.9547478, theta=-47.213366 -> V=1.0, theta=0.0
% INFO    : Bus 80896	: V=0.9662053, theta=-40.682264 -> V=1.0, theta=0.0
% INFO    : Bus 80897	: V=0.9801792, theta=-38.299615 -> V=1.0, theta=0.0
% INFO    : Bus 80898	: V=0.9870757, theta=-37.453794 -> V=1.0, theta=0.0
% INFO    : Bus 80899	: V=0.9839037, theta=-37.943594 -> V=1.0, theta=0.0
% INFO    : Bus 80900	: V=0.9703336, theta=-39.705007 -> V=1.0, theta=0.0
% INFO    : Bus 80901	: V=0.9746545, theta=-39.178507 -> V=1.0, theta=0.0
% INFO    : Bus 80902	: V=0.9747435, theta=-38.639842 -> V=1.0, theta=0.0
% INFO    : Bus 80903	: V=0.9785188, theta=-38.276859 -> V=1.0, theta=0.0
% INFO    : Bus 80904	: V=0.9997863, theta=-35.613815 -> V=1.0, theta=0.0
% INFO    : Bus 80905	: V=0.9941993, theta=-36.904638 -> V=1.0, theta=0.0
% INFO    : Bus 80906	: V=0.9936837, theta=-37.180831 -> V=1.0, theta=0.0
% INFO    : Bus 80907	: V=0.9846338, theta=-38.434748 -> V=1.0, theta=0.0
% INFO    : Bus 80908	: V=0.9848856, theta=-40.982929 -> V=1.0, theta=0.0
% INFO    : Bus 80909	: V=0.9835462, theta=-41.205356 -> V=1.0, theta=0.0
% INFO    : Bus 80910	: V=0.9810753, theta=-41.386936 -> V=1.0, theta=0.0
% INFO    : Bus 80911	: V=0.9533596, theta=-43.531164 -> V=1.0, theta=0.0
% INFO    : Bus 80912	: V=0.9542535, theta=-43.467971 -> V=1.0, theta=0.0
% INFO    : Bus 80913	: V=0.9544791, theta=-43.444036 -> V=1.0, theta=0.0
% INFO    : Bus 80914	: V=0.9540765, theta=-43.385344 -> V=1.0, theta=0.0
% INFO    : Bus 80915	: V=0.9552522, theta=-43.570194 -> V=1.0, theta=0.0
% INFO    : Bus 80916	: V=0.9578241, theta=-42.966308 -> V=1.0, theta=0.0
% INFO    : Bus 80917	: V=0.9530745, theta=-43.314269 -> V=1.0, theta=0.0
% INFO    : Bus 80918	: V=0.9560649, theta=-43.145491 -> V=1.0, theta=0.0
% INFO    : Bus 80919	: V=0.9578293, theta=-42.944745 -> V=1.0, theta=0.0
% INFO    : Bus 80920	: V=0.9571312, theta=-43.234209 -> V=1.0, theta=0.0
% INFO    : Bus 80921	: V=0.9544941, theta=-43.597494 -> V=1.0, theta=0.0
% INFO    : Bus 80922	: V=0.9578814, theta=-42.825242 -> V=1.0, theta=0.0
% INFO    : Bus 80923	: V=0.9541022, theta=-43.431761 -> V=1.0, theta=0.0
% INFO    : Bus 80924	: V=0.9670692, theta=-41.852044 -> V=1.0, theta=0.0
% INFO    : Bus 80925	: V=0.9644533, theta=-42.112572 -> V=1.0, theta=0.0
% INFO    : Bus 80926	: V=0.9663728, theta=-41.688789 -> V=1.0, theta=0.0
% INFO    : Bus 80927	: V=0.9771035, theta=-40.736302 -> V=1.0, theta=0.0
% INFO    : Bus 80928	: V=0.9672189, theta=-41.857109 -> V=1.0, theta=0.0
% INFO    : Bus 80929	: V=0.9649963, theta=-42.182443 -> V=1.0, theta=0.0
% INFO    : Bus 80930	: V=0.9733852, theta=-41.055855 -> V=1.0, theta=0.0
% INFO    : Bus 80931	: V=0.9703029, theta=-41.37973 -> V=1.0, theta=0.0
% INFO    : Bus 80932	: V=0.9745174, theta=-41.152636 -> V=1.0, theta=0.0
% INFO    : Bus 80933	: V=0.976587, theta=-41.075229 -> V=1.0, theta=0.0
% INFO    : Bus 80934	: V=0.9801729, theta=-40.727128 -> V=1.0, theta=0.0
% INFO    : Bus 80935	: V=0.9809352, theta=-40.662732 -> V=1.0, theta=0.0
% INFO    : Bus 80936	: V=0.9786356, theta=-41.257883 -> V=1.0, theta=0.0
% INFO    : Bus 80937	: V=0.9748084, theta=-41.609878 -> V=1.0, theta=0.0
% INFO    : Bus 80938	: V=0.960083, theta=-42.490483 -> V=1.0, theta=0.0
% INFO    : Bus 80939	: V=0.9664692, theta=-42.197986 -> V=1.0, theta=0.0
% INFO    : Bus 80940	: V=0.985184, theta=-40.189318 -> V=1.0, theta=0.0
% INFO    : Bus 80941	: V=0.9833862, theta=-40.49442 -> V=1.0, theta=0.0
% INFO    : Bus 80942	: V=0.9636798, theta=-42.520996 -> V=1.0, theta=0.0
% INFO    : Bus 80943	: V=0.9597346, theta=-42.683003 -> V=1.0, theta=0.0
% INFO    : Bus 80944	: V=0.9618606, theta=-42.671581 -> V=1.0, theta=0.0
% INFO    : Bus 80945	: V=0.9627406, theta=-42.584643 -> V=1.0, theta=0.0
% INFO    : Bus 80946	: V=0.9636894, theta=-42.55412 -> V=1.0, theta=0.0
% INFO    : Bus 80947	: V=0.9619542, theta=-42.717552 -> V=1.0, theta=0.0
% INFO    : Bus 80948	: V=0.9777821, theta=-41.1021 -> V=1.0, theta=0.0
% INFO    : Bus 80949	: V=0.9773065, theta=-41.537133 -> V=1.0, theta=0.0
% INFO    : Bus 80950	: V=0.971729, theta=-41.845188 -> V=1.0, theta=0.0
% INFO    : Bus 80951	: V=0.9674359, theta=-42.446064 -> V=1.0, theta=0.0
% INFO    : Bus 80952	: V=0.9660663, theta=-42.548765 -> V=1.0, theta=0.0
% INFO    : Bus 80953	: V=0.9842504, theta=-40.611661 -> V=1.0, theta=0.0
% INFO    : Bus 80954	: V=0.9779503, theta=-41.429019 -> V=1.0, theta=0.0
% INFO    : Bus 80955	: V=0.9693597, theta=-41.992125 -> V=1.0, theta=0.0
% INFO    : Bus 80956	: V=0.9790662, theta=-41.037998 -> V=1.0, theta=0.0
% INFO    : Bus 80957	: V=0.9652116, theta=-42.61515 -> V=1.0, theta=0.0
% INFO    : Bus 80958	: V=0.9705965, theta=-42.144944 -> V=1.0, theta=0.0
% INFO    : Bus 80959	: V=0.9587797, theta=-43.136163 -> V=1.0, theta=0.0
% INFO    : Bus 80960	: V=0.9597866, theta=-43.125655 -> V=1.0, theta=0.0
% INFO    : Bus 80961	: V=0.9589662, theta=-43.307513 -> V=1.0, theta=0.0
% INFO    : Bus 80962	: V=0.9556156, theta=-43.502961 -> V=1.0, theta=0.0
% INFO    : Bus 80963	: V=0.9571611, theta=-43.477423 -> V=1.0, theta=0.0
% INFO    : Bus 80964	: V=0.9568881, theta=-43.479335 -> V=1.0, theta=0.0
% INFO    : Bus 80965	: V=0.9563082, theta=-43.479186 -> V=1.0, theta=0.0
% INFO    : Bus 80966	: V=0.9645298, theta=-42.345776 -> V=1.0, theta=0.0
% INFO    : Bus 80967	: V=0.9635105, theta=-42.677919 -> V=1.0, theta=0.0
% INFO    : Bus 80968	: V=0.9570455, theta=-43.433133 -> V=1.0, theta=0.0
% INFO    : Bus 80969	: V=0.9597146, theta=-42.874271 -> V=1.0, theta=0.0
% INFO    : Bus 80970	: V=0.9601874, theta=-43.271686 -> V=1.0, theta=0.0
% INFO    : Bus 80971	: V=0.9553949, theta=-43.875271 -> V=1.0, theta=0.0
% INFO    : Bus 80972	: V=0.9547578, theta=-43.736101 -> V=1.0, theta=0.0
% INFO    : Bus 80973	: V=0.95365, theta=-43.324929 -> V=1.0, theta=0.0
% INFO    : Bus 80974	: V=0.9984408, theta=-40.246348 -> V=1.0, theta=0.0
% INFO    : Bus 80975	: V=0.9904826, theta=-40.967096 -> V=1.0, theta=0.0
% INFO    : Bus 80976	: V=0.9824007, theta=-46.325184 -> V=1.0, theta=0.0
% INFO    : Bus 80977	: V=0.9754043, theta=-47.181022 -> V=1.0, theta=0.0
% INFO    : Bus 80978	: V=0.9702769, theta=-47.721206 -> V=1.0, theta=0.0
% INFO    : Bus 80979	: V=0.9717018, theta=-47.533239 -> V=1.0, theta=0.0
% INFO    : Bus 80980	: V=0.9666873, theta=-48.038347 -> V=1.0, theta=0.0
% INFO    : Bus 80981	: V=0.9783382, theta=-39.988818 -> V=1.0, theta=0.0
% INFO    : Bus 80982	: V=0.9895186, theta=-37.37292 -> V=1.0, theta=0.0
% INFO    : Bus 80983	: V=0.9904939, theta=-37.275795 -> V=1.0, theta=0.0
% INFO    : Bus 80984	: V=0.982919, theta=-38.053118 -> V=1.0, theta=0.0
% INFO    : Bus 80985	: V=0.9842429, theta=-37.89771 -> V=1.0, theta=0.0
% INFO    : Bus 80986	: V=0.9884965, theta=-37.734966 -> V=1.0, theta=0.0
% INFO    : Bus 80987	: V=0.9477645, theta=-50.113196 -> V=1.0, theta=0.0
% INFO    : Bus 80988	: V=0.9453884, theta=-50.224762 -> V=1.0, theta=0.0
% INFO    : Bus 80989	: V=0.947069, theta=-50.003504 -> V=1.0, theta=0.0
% INFO    : Bus 80990	: V=0.9512685, theta=-49.584688 -> V=1.0, theta=0.0
% INFO    : Bus 80991	: V=0.9466937, theta=-49.783619 -> V=1.0, theta=0.0
% INFO    : Bus 80992	: V=0.9537754, theta=-44.098461 -> V=1.0, theta=0.0
% INFO    : Bus 80993	: V=0.9652798, theta=-42.354286 -> V=1.0, theta=0.0
% INFO    : Bus 80994	: V=0.9623491, theta=-42.728198 -> V=1.0, theta=0.0
% INFO    : Bus 80995	: V=0.967183, theta=-41.988152 -> V=1.0, theta=0.0
% INFO    : Bus 80996	: V=0.9492354, theta=-49.01327 -> V=1.0, theta=0.0
% INFO    : Bus 80997	: V=0.9554496, theta=-47.413124 -> V=1.0, theta=0.0
% INFO    : Bus 80998	: V=1.0038806, theta=-44.853868 -> V=1.0, theta=0.0
% INFO    : Bus 80999	: V=1.0035481, theta=-44.341413 -> V=1.0, theta=0.0
% INFO    : Bus 81000	: V=1.0000113, theta=-44.244035 -> V=1.0, theta=0.0
% INFO    : Bus 81001	: V=1.0022184, theta=-43.633627 -> V=1.0, theta=0.0
% INFO    : Bus 81002	: V=1.0123626, theta=-42.510531 -> V=1.0, theta=0.0
% INFO    : Bus 81003	: V=0.9972385, theta=-43.536021 -> V=1.0, theta=0.0
% INFO    : Bus 81004	: V=1.0071225, theta=-42.675143 -> V=1.0, theta=0.0
% INFO    : Bus 81005	: V=1.0019157, theta=-43.288362 -> V=1.0, theta=0.0
% INFO    : Bus 81006	: V=1.0009077, theta=-43.227786 -> V=1.0, theta=0.0
% INFO    : Bus 81007	: V=0.9946392, theta=-41.679621 -> V=1.0, theta=0.0
% INFO    : Bus 81008	: V=0.9806507, theta=-42.672508 -> V=1.0, theta=0.0
% INFO    : Bus 81009	: V=0.9816387, theta=-44.489155 -> V=1.0, theta=0.0
% INFO    : Bus 81010	: V=0.9870793, theta=-43.982469 -> V=1.0, theta=0.0
% INFO    : Bus 81011	: V=0.991493, theta=-43.31939 -> V=1.0, theta=0.0
% INFO    : Bus 81012	: V=0.9912768, theta=-43.431855 -> V=1.0, theta=0.0
% INFO    : Bus 81013	: V=0.9902461, theta=-43.520168 -> V=1.0, theta=0.0
% INFO    : Bus 81014	: V=0.9982675, theta=-42.491083 -> V=1.0, theta=0.0
% INFO    : Bus 81015	: V=0.9509392, theta=-56.241897 -> V=1.0, theta=0.0
% INFO    : Bus 81016	: V=0.9507351, theta=-56.033905 -> V=1.0, theta=0.0
% INFO    : Bus 81017	: V=0.952582, theta=-55.689704 -> V=1.0, theta=0.0
% INFO    : Bus 81018	: V=0.9518748, theta=-55.519849 -> V=1.0, theta=0.0
% INFO    : Bus 81019	: V=0.9537958, theta=-55.438991 -> V=1.0, theta=0.0
% INFO    : Bus 81020	: V=0.9530577, theta=-55.581386 -> V=1.0, theta=0.0
% INFO    : Bus 81021	: V=0.9519241, theta=-55.707267 -> V=1.0, theta=0.0
% INFO    : Bus 81022	: V=0.952433, theta=-55.661759 -> V=1.0, theta=0.0
% INFO    : Bus 81023	: V=0.9504882, theta=-55.915855 -> V=1.0, theta=0.0
% INFO    : Bus 81024	: V=0.9490889, theta=-56.170703 -> V=1.0, theta=0.0
% INFO    : Bus 81025	: V=0.9491736, theta=-56.086919 -> V=1.0, theta=0.0
% INFO    : Bus 81026	: V=0.9505977, theta=-55.878578 -> V=1.0, theta=0.0
% INFO    : Bus 81027	: V=0.9527378, theta=-55.653937 -> V=1.0, theta=0.0
% INFO    : Bus 81028	: V=0.9536453, theta=-55.459005 -> V=1.0, theta=0.0
% INFO    : Bus 81029	: V=0.9566594, theta=-55.137328 -> V=1.0, theta=0.0
% INFO    : Bus 81030	: V=0.9521113, theta=-55.689357 -> V=1.0, theta=0.0
% INFO    : Bus 81031	: V=0.9559778, theta=-55.068508 -> V=1.0, theta=0.0
% INFO    : Bus 81032	: V=0.9558766, theta=-55.116056 -> V=1.0, theta=0.0
% INFO    : Bus 81033	: V=0.9576641, theta=-55.048425 -> V=1.0, theta=0.0
% INFO    : Bus 81034	: V=0.9564679, theta=-54.916841 -> V=1.0, theta=0.0
% INFO    : Bus 81035	: V=0.9531562, theta=-55.497414 -> V=1.0, theta=0.0
% INFO    : Bus 81036	: V=0.9522811, theta=-55.58961 -> V=1.0, theta=0.0
% INFO    : Bus 81037	: V=0.9518778, theta=-55.632674 -> V=1.0, theta=0.0
% INFO    : Bus 81038	: V=0.9528145, theta=-55.53491 -> V=1.0, theta=0.0
% INFO    : Bus 81039	: V=0.9541937, theta=-55.338834 -> V=1.0, theta=0.0
% INFO    : Bus 81040	: V=1.015601, theta=-39.594805 -> V=1.0, theta=0.0
% INFO    : Bus 81041	: V=1.0029382, theta=-44.427575 -> V=1.0, theta=0.0
% INFO    : Bus 81042	: V=0.9982276, theta=-44.43767 -> V=1.0, theta=0.0
% INFO    : Bus 81043	: V=1.0122554, theta=-42.273174 -> V=1.0, theta=0.0
% INFO    : Bus 81044	: V=1.0136281, theta=-41.509506 -> V=1.0, theta=0.0
% INFO    : Bus 81045	: V=1.0129035, theta=-41.751432 -> V=1.0, theta=0.0
% INFO    : Bus 81046	: V=1.0077803, theta=-41.357761 -> V=1.0, theta=0.0
% INFO    : Bus 81047	: V=0.9770566, theta=-45.169637 -> V=1.0, theta=0.0
% INFO    : Bus 81048	: V=0.9860562, theta=-44.299813 -> V=1.0, theta=0.0
% INFO    : Bus 81049	: V=0.9900643, theta=-44.621807 -> V=1.0, theta=0.0
% INFO    : Bus 81050	: V=0.9612431, theta=-48.029944 -> V=1.0, theta=0.0
% INFO    : Bus 81051	: V=0.9974418, theta=-44.086543 -> V=1.0, theta=0.0
% INFO    : Bus 81052	: V=0.9612338, theta=-46.863447 -> V=1.0, theta=0.0
% INFO    : Bus 81053	: V=0.976331, theta=-46.979387 -> V=1.0, theta=0.0
% INFO    : Bus 81054	: V=0.9521276, theta=-49.164432 -> V=1.0, theta=0.0
% INFO    : Bus 81055	: V=0.948324, theta=-50.064348 -> V=1.0, theta=0.0
% INFO    : Bus 81056	: V=0.9477531, theta=-48.474122 -> V=1.0, theta=0.0
% INFO    : Bus 81057	: V=0.9485714, theta=-50.055214 -> V=1.0, theta=0.0
% INFO    : Bus 81058	: V=1.0140389, theta=-40.391104 -> V=1.0, theta=0.0
% INFO    : Bus 81059	: V=1.005724, theta=-41.2473 -> V=1.0, theta=0.0
% INFO    : Bus 81060	: V=0.988838, theta=-43.801388 -> V=1.0, theta=0.0
% INFO    : Bus 81061	: V=0.9780604, theta=-44.929065 -> V=1.0, theta=0.0
% INFO    : Bus 81062	: V=1.0077286, theta=-42.620666 -> V=1.0, theta=0.0
% INFO    : Bus 81063	: V=0.9589553, theta=-50.582141 -> V=1.0, theta=0.0
% INFO    : Bus 81064	: V=0.966809, theta=-49.958439 -> V=1.0, theta=0.0
% INFO    : Bus 81065	: V=1.0136237, theta=-38.997147 -> V=1.0, theta=0.0
% INFO    : Bus 81066	: V=1.0189175, theta=-38.575522 -> V=1.0, theta=0.0
% INFO    : Bus 81067	: V=1.0187104, theta=-37.888075 -> V=1.0, theta=0.0
% INFO    : Bus 81068	: V=1.0118266, theta=-38.542837 -> V=1.0, theta=0.0
% INFO    : Bus 81069	: V=1.0085526, theta=-39.44894 -> V=1.0, theta=0.0
% INFO    : Bus 81070	: V=0.996689, theta=-41.721762 -> V=1.0, theta=0.0
% INFO    : Bus 81071	: V=1.0114401, theta=-38.425476 -> V=1.0, theta=0.0
% INFO    : Bus 81072	: V=0.9969328, theta=-41.708552 -> V=1.0, theta=0.0
% INFO    : Bus 81073	: V=0.9970466, theta=-41.278614 -> V=1.0, theta=0.0
% INFO    : Bus 81074	: V=0.9975295, theta=-40.533341 -> V=1.0, theta=0.0
% INFO    : Bus 81075	: V=0.9964749, theta=-40.636372 -> V=1.0, theta=0.0
% INFO    : Bus 81076	: V=1.0032114, theta=-39.824472 -> V=1.0, theta=0.0
% INFO    : Bus 81077	: V=0.995061, theta=-41.756785 -> V=1.0, theta=0.0
% INFO    : Bus 81078	: V=0.9878791, theta=-42.095755 -> V=1.0, theta=0.0
% INFO    : Bus 81079	: V=0.9946982, theta=-41.193924 -> V=1.0, theta=0.0
% INFO    : Bus 81080	: V=0.9900667, theta=-41.847288 -> V=1.0, theta=0.0
% INFO    : Bus 81081	: V=0.9908558, theta=-41.218995 -> V=1.0, theta=0.0
% INFO    : Bus 81082	: V=0.9703957, theta=-43.219296 -> V=1.0, theta=0.0
% INFO    : Bus 81083	: V=0.9763178, theta=-43.440252 -> V=1.0, theta=0.0
% INFO    : Bus 81084	: V=0.9777893, theta=-43.330143 -> V=1.0, theta=0.0
% INFO    : Bus 81085	: V=0.9689255, theta=-43.484269 -> V=1.0, theta=0.0
% INFO    : Bus 81086	: V=0.9725449, theta=-43.606761 -> V=1.0, theta=0.0
% INFO    : Bus 81087	: V=0.9741569, theta=-42.909051 -> V=1.0, theta=0.0
% INFO    : Bus 81088	: V=0.9713804, theta=-43.21781 -> V=1.0, theta=0.0
% INFO    : Bus 81089	: V=0.9831239, theta=-55.81266 -> V=1.0, theta=0.0
% INFO    : Bus 81090	: V=1.0077682, theta=-45.983785 -> V=1.0, theta=0.0
% INFO    : Bus 81091	: V=1.0038421, theta=-46.43215 -> V=1.0, theta=0.0
% INFO    : Bus 81092	: V=1.00396, theta=-46.71621 -> V=1.0, theta=0.0
% INFO    : Bus 81093	: V=1.0050513, theta=-45.526605 -> V=1.0, theta=0.0
% INFO    : Bus 81094	: V=1.0159409, theta=-44.075497 -> V=1.0, theta=0.0
% INFO    : Bus 81095	: V=1.0151611, theta=-44.308402 -> V=1.0, theta=0.0
% INFO    : Bus 81096	: V=1.0082653, theta=-40.333905 -> V=1.0, theta=0.0
% INFO    : Bus 81097	: V=0.9741522, theta=-41.858458 -> V=1.0, theta=0.0
% INFO    : Bus 81098	: V=0.9720919, theta=-47.751706 -> V=1.0, theta=0.0
% INFO    : Bus 81099	: V=0.9663454, theta=-53.253589 -> V=1.0, theta=0.0
% INFO    : Bus 81100	: V=0.9689991, theta=-52.766431 -> V=1.0, theta=0.0
% INFO    : Bus 81101	: V=0.9683306, theta=-52.849792 -> V=1.0, theta=0.0
% INFO    : Bus 81102	: V=0.9591957, theta=-54.400403 -> V=1.0, theta=0.0
% INFO    : Bus 81103	: V=0.9607425, theta=-54.137835 -> V=1.0, theta=0.0
% INFO    : Bus 81104	: V=0.9571918, theta=-54.528543 -> V=1.0, theta=0.0
% INFO    : Bus 81105	: V=0.9607798, theta=-54.002609 -> V=1.0, theta=0.0
% INFO    : Bus 81106	: V=0.9610941, theta=-53.581533 -> V=1.0, theta=0.0
% INFO    : Bus 81107	: V=0.9648563, theta=-53.063357 -> V=1.0, theta=0.0
% INFO    : Bus 81108	: V=0.9608428, theta=-53.897795 -> V=1.0, theta=0.0
% INFO    : Bus 81109	: V=0.9630776, theta=-53.451203 -> V=1.0, theta=0.0
% INFO    : Bus 81110	: V=0.9652506, theta=-53.280847 -> V=1.0, theta=0.0
% INFO    : Bus 81111	: V=0.9676545, theta=-52.982975 -> V=1.0, theta=0.0
% INFO    : Bus 81112	: V=0.9685633, theta=-52.742929 -> V=1.0, theta=0.0
% INFO    : Bus 81113	: V=0.9754452, theta=-51.820237 -> V=1.0, theta=0.0
% INFO    : Bus 81114	: V=0.9738715, theta=-52.153239 -> V=1.0, theta=0.0
% INFO    : Bus 81115	: V=0.9593569, theta=-54.309586 -> V=1.0, theta=0.0
% INFO    : Bus 81116	: V=0.9611769, theta=-53.445192 -> V=1.0, theta=0.0
% INFO    : Bus 81117	: V=0.9619321, theta=-53.883593 -> V=1.0, theta=0.0
% INFO    : Bus 81118	: V=0.9623462, theta=-53.473622 -> V=1.0, theta=0.0
% INFO    : Bus 81119	: V=0.9581818, theta=-54.526247 -> V=1.0, theta=0.0
% INFO    : Bus 81120	: V=0.9681033, theta=-52.979639 -> V=1.0, theta=0.0
% INFO    : Bus 81121	: V=0.9682138, theta=-53.023288 -> V=1.0, theta=0.0
% INFO    : Bus 81122	: V=0.9688566, theta=-52.943341 -> V=1.0, theta=0.0
% INFO    : Bus 81123	: V=0.9675308, theta=-53.312355 -> V=1.0, theta=0.0
% INFO    : Bus 81124	: V=0.9697777, theta=-52.852885 -> V=1.0, theta=0.0
% INFO    : Bus 81125	: V=0.9659101, theta=-53.440945 -> V=1.0, theta=0.0
% INFO    : Bus 81126	: V=0.9620019, theta=-53.880851 -> V=1.0, theta=0.0
% INFO    : Bus 81127	: V=0.9631656, theta=-53.831739 -> V=1.0, theta=0.0
% INFO    : Bus 81128	: V=0.9698879, theta=-52.838778 -> V=1.0, theta=0.0
% INFO    : Bus 81129	: V=0.970243, theta=-52.911102 -> V=1.0, theta=0.0
% INFO    : Bus 81130	: V=0.9812326, theta=-50.993241 -> V=1.0, theta=0.0
% INFO    : Bus 81131	: V=0.9771484, theta=-51.640905 -> V=1.0, theta=0.0
% INFO    : Bus 81132	: V=0.97529, theta=-52.007389 -> V=1.0, theta=0.0
% INFO    : Bus 81133	: V=0.9604015, theta=-53.730953 -> V=1.0, theta=0.0
% INFO    : Bus 81134	: V=0.9538061, theta=-55.030238 -> V=1.0, theta=0.0
% INFO    : Bus 81135	: V=0.9528395, theta=-55.264 -> V=1.0, theta=0.0
% INFO    : Bus 81136	: V=0.9535355, theta=-55.001419 -> V=1.0, theta=0.0
% INFO    : Bus 81137	: V=0.959697, theta=-54.805013 -> V=1.0, theta=0.0
% INFO    : Bus 81138	: V=0.9588059, theta=-54.975872 -> V=1.0, theta=0.0
% INFO    : Bus 81139	: V=0.9554374, theta=-54.913731 -> V=1.0, theta=0.0
% INFO    : Bus 81140	: V=0.958067, theta=-54.521982 -> V=1.0, theta=0.0
% INFO    : Bus 81141	: V=0.9573354, theta=-54.672322 -> V=1.0, theta=0.0
% INFO    : Bus 81142	: V=0.9580015, theta=-54.967035 -> V=1.0, theta=0.0
% INFO    : Bus 81143	: V=0.9530604, theta=-55.806963 -> V=1.0, theta=0.0
% INFO    : Bus 81144	: V=0.9505214, theta=-55.8255 -> V=1.0, theta=0.0
% INFO    : Bus 81145	: V=0.9525389, theta=-55.74679 -> V=1.0, theta=0.0
% INFO    : Bus 81146	: V=0.9528923, theta=-55.655379 -> V=1.0, theta=0.0
% INFO    : Bus 81147	: V=0.9523666, theta=-55.332209 -> V=1.0, theta=0.0
% INFO    : Bus 81148	: V=0.9492749, theta=-55.732458 -> V=1.0, theta=0.0
% INFO    : Bus 81149	: V=0.9488738, theta=-55.631342 -> V=1.0, theta=0.0
% INFO    : Bus 81150	: V=0.9529331, theta=-55.445589 -> V=1.0, theta=0.0
% INFO    : Bus 81151	: V=0.9484917, theta=-56.473154 -> V=1.0, theta=0.0
% INFO    : Bus 81152	: V=0.9486914, theta=-56.23534 -> V=1.0, theta=0.0
% INFO    : Bus 81153	: V=0.9495794, theta=-55.9412 -> V=1.0, theta=0.0
% INFO    : Bus 81154	: V=0.950625, theta=-55.853428 -> V=1.0, theta=0.0
% INFO    : Bus 81155	: V=0.9481459, theta=-56.414182 -> V=1.0, theta=0.0
% INFO    : Bus 81156	: V=0.9560754, theta=-55.961396 -> V=1.0, theta=0.0
% INFO    : Bus 81157	: V=0.9608174, theta=-55.4561 -> V=1.0, theta=0.0
% INFO    : Bus 81158	: V=0.9556339, theta=-56.072728 -> V=1.0, theta=0.0
% INFO    : Bus 81159	: V=0.9602202, theta=-55.578133 -> V=1.0, theta=0.0
% INFO    : Bus 81160	: V=0.9587329, theta=-55.679596 -> V=1.0, theta=0.0
% INFO    : Bus 81161	: V=0.9587429, theta=-55.681118 -> V=1.0, theta=0.0
% INFO    : Bus 81162	: V=0.9559267, theta=-55.864695 -> V=1.0, theta=0.0
% INFO    : Bus 81163	: V=0.9536425, theta=-55.581717 -> V=1.0, theta=0.0
% INFO    : Bus 81164	: V=0.952894, theta=-56.268329 -> V=1.0, theta=0.0
% INFO    : Bus 81165	: V=0.9559493, theta=-55.821556 -> V=1.0, theta=0.0
% INFO    : Bus 81166	: V=0.9533941, theta=-56.224303 -> V=1.0, theta=0.0
% INFO    : Bus 81167	: V=0.9743492, theta=-54.48226 -> V=1.0, theta=0.0
% INFO    : Bus 81168	: V=0.9659194, theta=-54.851526 -> V=1.0, theta=0.0
% INFO    : Bus 81169	: V=0.9605754, theta=-55.528623 -> V=1.0, theta=0.0
% INFO    : Bus 81170	: V=0.9577645, theta=-55.455246 -> V=1.0, theta=0.0
% INFO    : Bus 81171	: V=0.9584213, theta=-55.347222 -> V=1.0, theta=0.0
% INFO    : Bus 81172	: V=0.9711201, theta=-53.985076 -> V=1.0, theta=0.0
% INFO    : Bus 81173	: V=0.970365, theta=-54.159447 -> V=1.0, theta=0.0
% INFO    : Bus 81174	: V=0.9533762, theta=-55.266034 -> V=1.0, theta=0.0
% INFO    : Bus 81175	: V=0.9663683, theta=-53.969479 -> V=1.0, theta=0.0
% INFO    : Bus 81176	: V=0.9677928, theta=-53.826332 -> V=1.0, theta=0.0
% INFO    : Bus 81177	: V=0.9690467, theta=-53.756308 -> V=1.0, theta=0.0
% INFO    : Bus 81178	: V=0.9691034, theta=-53.601416 -> V=1.0, theta=0.0
% INFO    : Bus 81179	: V=0.9688063, theta=-53.591546 -> V=1.0, theta=0.0
% INFO    : Bus 81180	: V=0.9696405, theta=-53.440499 -> V=1.0, theta=0.0
% INFO    : Bus 81181	: V=0.9691877, theta=-53.479034 -> V=1.0, theta=0.0
% INFO    : Bus 81182	: V=0.9570573, theta=-55.233823 -> V=1.0, theta=0.0
% INFO    : Bus 81183	: V=0.9540812, theta=-55.277942 -> V=1.0, theta=0.0
% INFO    : Bus 81184	: V=0.9549725, theta=-55.248616 -> V=1.0, theta=0.0
% INFO    : Bus 81185	: V=0.9786094, theta=-51.332707 -> V=1.0, theta=0.0
% INFO    : Bus 81186	: V=0.9755681, theta=-51.581759 -> V=1.0, theta=0.0
% INFO    : Bus 81187	: V=0.9724589, theta=-52.230924 -> V=1.0, theta=0.0
% INFO    : Bus 81188	: V=0.9711517, theta=-52.151629 -> V=1.0, theta=0.0
% INFO    : Bus 81189	: V=0.9836148, theta=-50.409216 -> V=1.0, theta=0.0
% INFO    : Bus 81190	: V=0.9920292, theta=-49.620057 -> V=1.0, theta=0.0
% INFO    : Bus 81191	: V=0.9521044, theta=-50.302487 -> V=1.0, theta=0.0
% INFO    : Bus 81192	: V=1.0124783, theta=-41.064698 -> V=1.0, theta=0.0
% INFO    : Bus 81193	: V=1.0104287, theta=-41.048856 -> V=1.0, theta=0.0
% INFO    : Bus 81194	: V=1.0177801, theta=-39.7099 -> V=1.0, theta=0.0
% INFO    : Bus 81195	: V=0.9916983, theta=-44.151279 -> V=1.0, theta=0.0
% INFO    : Bus 81196	: V=0.9862919, theta=-44.886227 -> V=1.0, theta=0.0
% INFO    : Bus 81197	: V=0.9849954, theta=-45.219747 -> V=1.0, theta=0.0
% INFO    : Bus 81198	: V=1.0055683, theta=-41.841393 -> V=1.0, theta=0.0
% INFO    : Bus 81199	: V=1.0035556, theta=-42.157723 -> V=1.0, theta=0.0
% INFO    : Bus 81200	: V=1.004326, theta=-53.035277 -> V=1.0, theta=0.0
% INFO    : Bus 81201	: V=1.0049591, theta=-53.075338 -> V=1.0, theta=0.0
% INFO    : Bus 81202	: V=0.9979791, theta=-53.520672 -> V=1.0, theta=0.0
% INFO    : Bus 81203	: V=0.9904028, theta=-54.408424 -> V=1.0, theta=0.0
% INFO    : Bus 81204	: V=0.9971228, theta=-54.025259 -> V=1.0, theta=0.0
% INFO    : Bus 81205	: V=0.9929107, theta=-54.52753 -> V=1.0, theta=0.0
% INFO    : Bus 81206	: V=0.9945189, theta=-54.537127 -> V=1.0, theta=0.0
% INFO    : Bus 81207	: V=0.9859967, theta=-55.61642 -> V=1.0, theta=0.0
% INFO    : Bus 81208	: V=1.0038638, theta=-46.893707 -> V=1.0, theta=0.0
% INFO    : Bus 81209	: V=0.9861978, theta=-43.313227 -> V=1.0, theta=0.0
% INFO    : Bus 81210	: V=0.9949629, theta=-42.140674 -> V=1.0, theta=0.0
% INFO    : Bus 81211	: V=1.0033244, theta=-41.064409 -> V=1.0, theta=0.0
% INFO    : Bus 81212	: V=1.0044333, theta=-41.230959 -> V=1.0, theta=0.0
% INFO    : Bus 81213	: V=0.9777606, theta=-43.763365 -> V=1.0, theta=0.0
% INFO    : Bus 81214	: V=0.997234, theta=-42.666723 -> V=1.0, theta=0.0
% INFO    : Bus 81215	: V=0.966338, theta=-49.613637 -> V=1.0, theta=0.0
% INFO    : Bus 81216	: V=1.009942, theta=-44.110999 -> V=1.0, theta=0.0
% INFO    : Bus 81217	: V=1.0077233, theta=-44.564228 -> V=1.0, theta=0.0
% INFO    : Bus 81218	: V=1.0109342, theta=-43.390964 -> V=1.0, theta=0.0
% INFO    : Bus 81219	: V=0.9951355, theta=-41.068407 -> V=1.0, theta=0.0
% INFO    : Bus 81220	: V=1.0176604, theta=-37.098548 -> V=1.0, theta=0.0
% INFO    : Bus 81221	: V=1.0174289, theta=-37.647414 -> V=1.0, theta=0.0
% INFO    : Bus 81222	: V=1.0101015, theta=-39.02742 -> V=1.0, theta=0.0
% INFO    : Bus 81223	: V=1.011777, theta=-39.145612 -> V=1.0, theta=0.0
% INFO    : Bus 81224	: V=1.0098612, theta=-41.674277 -> V=1.0, theta=0.0
% INFO    : Bus 81225	: V=0.9950847, theta=-42.902957 -> V=1.0, theta=0.0
% INFO    : Bus 81226	: V=1.0034081, theta=-41.77207 -> V=1.0, theta=0.0
% INFO    : Bus 81227	: V=1.0043126, theta=-41.677852 -> V=1.0, theta=0.0
% INFO    : Bus 81228	: V=0.9904087, theta=-42.925475 -> V=1.0, theta=0.0
% INFO    : Bus 81229	: V=0.9902339, theta=-42.858929 -> V=1.0, theta=0.0
% INFO    : Bus 81230	: V=0.9881721, theta=-42.991081 -> V=1.0, theta=0.0
% INFO    : Bus 81231	: V=0.9906873, theta=-42.639386 -> V=1.0, theta=0.0
% INFO    : Bus 81232	: V=0.9787441, theta=-43.70847 -> V=1.0, theta=0.0
% INFO    : Bus 81233	: V=0.9751975, theta=-43.549441 -> V=1.0, theta=0.0
% INFO    : Bus 81234	: V=0.9733006, theta=-44.199849 -> V=1.0, theta=0.0
% INFO    : Bus 81235	: V=0.9816253, theta=-43.512127 -> V=1.0, theta=0.0
% INFO    : Bus 81236	: V=0.9803493, theta=-43.5702 -> V=1.0, theta=0.0
% INFO    : Bus 81237	: V=0.9840786, theta=-43.444214 -> V=1.0, theta=0.0
% INFO    : Bus 81238	: V=0.9801882, theta=-43.555717 -> V=1.0, theta=0.0
% INFO    : Bus 81239	: V=0.9796093, theta=-43.70829 -> V=1.0, theta=0.0
% INFO    : Bus 81240	: V=0.979251, theta=-43.733891 -> V=1.0, theta=0.0
% INFO    : Bus 81241	: V=0.9804126, theta=-43.666115 -> V=1.0, theta=0.0
% INFO    : Bus 81242	: V=0.9822932, theta=-43.481096 -> V=1.0, theta=0.0
% INFO    : Bus 81243	: V=0.9820238, theta=-43.532263 -> V=1.0, theta=0.0
% INFO    : Bus 81244	: V=0.9857648, theta=-43.254435 -> V=1.0, theta=0.0
% INFO    : Bus 81245	: V=0.9791542, theta=-43.811843 -> V=1.0, theta=0.0
% INFO    : Bus 81246	: V=0.9923732, theta=-42.620501 -> V=1.0, theta=0.0
% INFO    : Bus 81247	: V=0.9923512, theta=-42.6161 -> V=1.0, theta=0.0
% INFO    : Bus 81248	: V=0.990779, theta=-42.779325 -> V=1.0, theta=0.0
% INFO    : Bus 81249	: V=0.993182, theta=-42.491093 -> V=1.0, theta=0.0
% INFO    : Bus 81250	: V=0.988416, theta=-43.042541 -> V=1.0, theta=0.0
% INFO    : Bus 81251	: V=0.9890399, theta=-42.866487 -> V=1.0, theta=0.0
% INFO    : Bus 81252	: V=0.9913504, theta=-42.772069 -> V=1.0, theta=0.0
% INFO    : Bus 81253	: V=0.9946466, theta=-42.232108 -> V=1.0, theta=0.0
% INFO    : Bus 81254	: V=0.9936473, theta=-42.320188 -> V=1.0, theta=0.0
% INFO    : Bus 81255	: V=0.9942103, theta=-42.259961 -> V=1.0, theta=0.0
% INFO    : Bus 81256	: V=0.9953522, theta=-42.154534 -> V=1.0, theta=0.0
% INFO    : Bus 81257	: V=1.0018607, theta=-41.381397 -> V=1.0, theta=0.0
% INFO    : Bus 81258	: V=0.9865143, theta=-42.803717 -> V=1.0, theta=0.0
% INFO    : Bus 81259	: V=1.0028266, theta=-41.344594 -> V=1.0, theta=0.0
% INFO    : Bus 81260	: V=1.0029142, theta=-41.368734 -> V=1.0, theta=0.0
% INFO    : Bus 81261	: V=0.9927532, theta=-42.567652 -> V=1.0, theta=0.0
% INFO    : Bus 81262	: V=1.0034802, theta=-41.093176 -> V=1.0, theta=0.0
% INFO    : Bus 81263	: V=1.0051883, theta=-40.622554 -> V=1.0, theta=0.0
% INFO    : Bus 81264	: V=0.9772561, theta=-45.509113 -> V=1.0, theta=0.0
% INFO    : Bus 81265	: V=0.9827998, theta=-44.831466 -> V=1.0, theta=0.0
% INFO    : Bus 81266	: V=0.9942809, theta=-43.158288 -> V=1.0, theta=0.0
% INFO    : Bus 81267	: V=0.9920899, theta=-43.693194 -> V=1.0, theta=0.0
% INFO    : Bus 81268	: V=0.9813078, theta=-45.286288 -> V=1.0, theta=0.0
% INFO    : Bus 81269	: V=0.9806088, theta=-45.198997 -> V=1.0, theta=0.0
% INFO    : Bus 81270	: V=1.0051315, theta=-43.106068 -> V=1.0, theta=0.0
% INFO    : Bus 81271	: V=0.9981449, theta=-40.659726 -> V=1.0, theta=0.0
% INFO    : Bus 81272	: V=0.9935302, theta=-40.760968 -> V=1.0, theta=0.0
% INFO    : Bus 81273	: V=0.9948052, theta=-40.898041 -> V=1.0, theta=0.0
% INFO    : Bus 81274	: V=1.0161246, theta=-38.090614 -> V=1.0, theta=0.0
% INFO    : Bus 81275	: V=1.0092189, theta=-39.580446 -> V=1.0, theta=0.0
% INFO    : Bus 81276	: V=1.0069108, theta=-40.151997 -> V=1.0, theta=0.0
% INFO    : Bus 81277	: V=0.9844227, theta=-45.068691 -> V=1.0, theta=0.0
% INFO    : Bus 81278	: V=1.005701, theta=-47.14049 -> V=1.0, theta=0.0
% INFO    : Bus 81279	: V=1.0097188, theta=-45.798996 -> V=1.0, theta=0.0
% INFO    : Bus 81280	: V=0.9937104, theta=-43.733425 -> V=1.0, theta=0.0
% INFO    : Bus 81281	: V=1.0001283, theta=-42.710597 -> V=1.0, theta=0.0
% INFO    : Bus 81282	: V=0.9740412, theta=-46.214085 -> V=1.0, theta=0.0
% INFO    : Bus 81283	: V=0.9783405, theta=-45.029073 -> V=1.0, theta=0.0
% INFO    : Bus 81284	: V=0.9430849, theta=-51.050906 -> V=1.0, theta=0.0
% INFO    : Bus 81285	: V=0.9933435, theta=-55.005953 -> V=1.0, theta=0.0
% INFO    : Bus 81286	: V=0.9917641, theta=-55.505804 -> V=1.0, theta=0.0
% INFO    : Bus 81287	: V=0.9811322, theta=-54.861565 -> V=1.0, theta=0.0
% INFO    : Bus 81288	: V=0.974268, theta=-55.687707 -> V=1.0, theta=0.0
% INFO    : Bus 81289	: V=0.9777795, theta=-54.964939 -> V=1.0, theta=0.0
% INFO    : Bus 81290	: V=0.9688476, theta=-55.504929 -> V=1.0, theta=0.0
% INFO    : Bus 81291	: V=0.9862019, theta=-54.873502 -> V=1.0, theta=0.0
% INFO    : Bus 81292	: V=0.9822055, theta=-55.415302 -> V=1.0, theta=0.0
% INFO    : Bus 81293	: V=0.9690529, theta=-55.5094 -> V=1.0, theta=0.0
% INFO    : Bus 81294	: V=0.9727457, theta=-55.306235 -> V=1.0, theta=0.0
% INFO    : Bus 81295	: V=0.9780921, theta=-54.829039 -> V=1.0, theta=0.0
% INFO    : Bus 81296	: V=0.9744595, theta=-55.403814 -> V=1.0, theta=0.0
% INFO    : Bus 81297	: V=0.9743492, theta=-55.31323 -> V=1.0, theta=0.0
% INFO    : Bus 81298	: V=0.9752934, theta=-55.3002 -> V=1.0, theta=0.0
% INFO    : Bus 81299	: V=0.9789483, theta=-54.776976 -> V=1.0, theta=0.0
% INFO    : Bus 81300	: V=0.9756587, theta=-55.212019 -> V=1.0, theta=0.0
% INFO    : Bus 81301	: V=0.9788107, theta=-54.747649 -> V=1.0, theta=0.0
% INFO    : Bus 81302	: V=0.9671836, theta=-55.593416 -> V=1.0, theta=0.0
% INFO    : Bus 81303	: V=0.9663562, theta=-55.12948 -> V=1.0, theta=0.0
% INFO    : Bus 81304	: V=0.9629846, theta=-55.796534 -> V=1.0, theta=0.0
% INFO    : Bus 81305	: V=0.9582275, theta=-56.429765 -> V=1.0, theta=0.0
% INFO    : Bus 81306	: V=0.9555416, theta=-56.505207 -> V=1.0, theta=0.0
% INFO    : Bus 81307	: V=0.9572595, theta=-56.286669 -> V=1.0, theta=0.0
% INFO    : Bus 81308	: V=0.9653625, theta=-54.450466 -> V=1.0, theta=0.0
% INFO    : Bus 81309	: V=0.9646583, theta=-54.559922 -> V=1.0, theta=0.0
% INFO    : Bus 81310	: V=0.9692433, theta=-54.1513 -> V=1.0, theta=0.0
% INFO    : Bus 81311	: V=0.9609932, theta=-55.355001 -> V=1.0, theta=0.0
% INFO    : Bus 81312	: V=0.9638076, theta=-55.280138 -> V=1.0, theta=0.0
% INFO    : Bus 81313	: V=1.0106404, theta=-42.049945 -> V=1.0, theta=0.0
% INFO    : Bus 81314	: V=1.016279, theta=-42.465312 -> V=1.0, theta=0.0
% INFO    : Bus 81315	: V=1.0161586, theta=-42.451551 -> V=1.0, theta=0.0
% INFO    : Bus 81316	: V=1.0171818, theta=-41.903552 -> V=1.0, theta=0.0
% INFO    : Bus 81317	: V=0.9876165, theta=-47.577068 -> V=1.0, theta=0.0
% INFO    : Bus 81318	: V=0.9895515, theta=-43.004577 -> V=1.0, theta=0.0
% INFO    : Bus 81319	: V=1.0093317, theta=-38.967692 -> V=1.0, theta=0.0
% INFO    : Bus 81320	: V=1.0073442, theta=-39.259549 -> V=1.0, theta=0.0
% INFO    : Bus 81321	: V=0.9813307, theta=-44.436388 -> V=1.0, theta=0.0
% INFO    : Bus 81322	: V=0.9627697, theta=-49.892169 -> V=1.0, theta=0.0
% INFO    : Bus 81323	: V=0.9626517, theta=-50.000702 -> V=1.0, theta=0.0
% INFO    : Bus 81324	: V=0.9613867, theta=-49.947113 -> V=1.0, theta=0.0
% INFO    : Bus 81325	: V=0.9658421, theta=-49.357392 -> V=1.0, theta=0.0
% INFO    : Bus 81326	: V=0.9642843, theta=-49.682069 -> V=1.0, theta=0.0
% INFO    : Bus 81327	: V=0.9565428, theta=-50.489044 -> V=1.0, theta=0.0
% INFO    : Bus 81328	: V=0.9623613, theta=-50.37693 -> V=1.0, theta=0.0
% INFO    : Bus 81329	: V=0.9568313, theta=-50.654711 -> V=1.0, theta=0.0
% INFO    : Bus 81330	: V=0.9915929, theta=-43.340642 -> V=1.0, theta=0.0
% INFO    : Bus 81331	: V=1.0004871, theta=-42.940676 -> V=1.0, theta=0.0
% INFO    : Bus 81332	: V=0.9915312, theta=-43.704263 -> V=1.0, theta=0.0
% INFO    : Bus 81333	: V=0.98931, theta=-44.096778 -> V=1.0, theta=0.0
% INFO    : Bus 81334	: V=0.977679, theta=-43.363136 -> V=1.0, theta=0.0
% INFO    : Bus 81335	: V=0.9900805, theta=-42.125828 -> V=1.0, theta=0.0
% INFO    : Bus 81336	: V=1.0147544, theta=-43.427381 -> V=1.0, theta=0.0
% INFO    : Bus 81337	: V=1.018312, theta=-42.716367 -> V=1.0, theta=0.0
% INFO    : Bus 81338	: V=1.0166692, theta=-42.84153 -> V=1.0, theta=0.0
% INFO    : Bus 81339	: V=1.0146258, theta=-43.316534 -> V=1.0, theta=0.0
% INFO    : Bus 81340	: V=0.9856698, theta=-48.227822 -> V=1.0, theta=0.0
% INFO    : Bus 81341	: V=0.9474839, theta=-50.45654 -> V=1.0, theta=0.0
% INFO    : Bus 81342	: V=0.9965072, theta=-43.00098 -> V=1.0, theta=0.0
% INFO    : Bus 81343	: V=0.986266, theta=-42.579013 -> V=1.0, theta=0.0
% INFO    : Bus 81344	: V=0.9784914, theta=-43.082243 -> V=1.0, theta=0.0
% INFO    : Bus 81345	: V=0.9793651, theta=-43.812996 -> V=1.0, theta=0.0
% INFO    : Bus 81346	: V=0.9716729, theta=-43.502653 -> V=1.0, theta=0.0
% INFO    : Bus 81347	: V=0.9691587, theta=-44.166682 -> V=1.0, theta=0.0
% INFO    : Bus 81348	: V=0.9775447, theta=-43.480885 -> V=1.0, theta=0.0
% INFO    : Bus 81349	: V=0.996197, theta=-42.237422 -> V=1.0, theta=0.0
% INFO    : Bus 81350	: V=1.000569, theta=-41.427335 -> V=1.0, theta=0.0
% INFO    : Bus 81351	: V=1.0002888, theta=-41.278056 -> V=1.0, theta=0.0
% INFO    : Bus 81352	: V=0.9998219, theta=-41.369734 -> V=1.0, theta=0.0
% INFO    : Bus 81353	: V=1.0079334, theta=-40.184244 -> V=1.0, theta=0.0
% INFO    : Bus 81354	: V=0.9927486, theta=-39.831511 -> V=1.0, theta=0.0
% INFO    : Bus 81355	: V=0.9798445, theta=-50.958305 -> V=1.0, theta=0.0
% INFO    : Bus 81356	: V=0.9830111, theta=-50.687606 -> V=1.0, theta=0.0
% INFO    : Bus 81357	: V=0.9971149, theta=-48.46969 -> V=1.0, theta=0.0
% INFO    : Bus 81358	: V=0.9904018, theta=-49.438282 -> V=1.0, theta=0.0
% INFO    : Bus 81359	: V=0.9830356, theta=-50.434288 -> V=1.0, theta=0.0
% INFO    : Bus 81360	: V=0.9879231, theta=-50.092712 -> V=1.0, theta=0.0
% INFO    : Bus 81361	: V=0.9874779, theta=-50.134806 -> V=1.0, theta=0.0
% INFO    : Bus 81362	: V=0.9847894, theta=-50.458701 -> V=1.0, theta=0.0
% INFO    : Bus 81363	: V=0.9894258, theta=-49.886721 -> V=1.0, theta=0.0
% INFO    : Bus 81364	: V=0.9970607, theta=-48.647379 -> V=1.0, theta=0.0
% INFO    : Bus 81365	: V=0.9954293, theta=-48.949326 -> V=1.0, theta=0.0
% INFO    : Bus 81366	: V=0.9957771, theta=-48.705094 -> V=1.0, theta=0.0
% INFO    : Bus 81367	: V=1.0038316, theta=-47.273428 -> V=1.0, theta=0.0
% INFO    : Bus 81368	: V=0.9800226, theta=-50.909544 -> V=1.0, theta=0.0
% INFO    : Bus 81369	: V=0.9775709, theta=-51.120988 -> V=1.0, theta=0.0
% INFO    : Bus 81370	: V=0.9793129, theta=-50.771069 -> V=1.0, theta=0.0
% INFO    : Bus 81371	: V=0.9841536, theta=-51.069391 -> V=1.0, theta=0.0
% INFO    : Bus 81372	: V=0.9849478, theta=-50.866859 -> V=1.0, theta=0.0
% INFO    : Bus 81373	: V=0.978686, theta=-51.133876 -> V=1.0, theta=0.0
% INFO    : Bus 81374	: V=0.9774063, theta=-51.976335 -> V=1.0, theta=0.0
% INFO    : Bus 81375	: V=0.9764689, theta=-52.091419 -> V=1.0, theta=0.0
% INFO    : Bus 81376	: V=0.9786327, theta=-51.698043 -> V=1.0, theta=0.0
% INFO    : Bus 81377	: V=0.9878857, theta=-50.498286 -> V=1.0, theta=0.0
% INFO    : Bus 81378	: V=0.9845361, theta=-50.978531 -> V=1.0, theta=0.0
% INFO    : Bus 81379	: V=0.9830701, theta=-51.215928 -> V=1.0, theta=0.0
% INFO    : Bus 81380	: V=0.9821711, theta=-51.347348 -> V=1.0, theta=0.0
% INFO    : Bus 81381	: V=0.9826581, theta=-51.211236 -> V=1.0, theta=0.0
% INFO    : Bus 81382	: V=0.9871831, theta=-50.496177 -> V=1.0, theta=0.0
% INFO    : Bus 81383	: V=0.9799281, theta=-51.479179 -> V=1.0, theta=0.0
% INFO    : Bus 81384	: V=0.9767231, theta=-52.291843 -> V=1.0, theta=0.0
% INFO    : Bus 81385	: V=0.9759484, theta=-52.217296 -> V=1.0, theta=0.0
% INFO    : Bus 81386	: V=0.9641103, theta=-50.56862 -> V=1.0, theta=0.0
% INFO    : Bus 81387	: V=0.968696, theta=-49.936697 -> V=1.0, theta=0.0
% INFO    : Bus 81388	: V=0.9748757, theta=-47.58679 -> V=1.0, theta=0.0
% INFO    : Bus 81389	: V=0.9496782, theta=-50.635276 -> V=1.0, theta=0.0
% INFO    : Bus 81390	: V=0.9490188, theta=-50.748221 -> V=1.0, theta=0.0
% INFO    : Bus 81391	: V=0.946302, theta=-51.016773 -> V=1.0, theta=0.0
% INFO    : Bus 81392	: V=0.9941101, theta=-46.689431 -> V=1.0, theta=0.0
% INFO    : Bus 81393	: V=0.9934584, theta=-47.156089 -> V=1.0, theta=0.0
% INFO    : Bus 81394	: V=0.9910394, theta=-49.894328 -> V=1.0, theta=0.0
% INFO    : Bus 81395	: V=0.998551, theta=-46.502156 -> V=1.0, theta=0.0
% INFO    : Bus 81396	: V=0.9976434, theta=-46.448862 -> V=1.0, theta=0.0
% INFO    : Bus 81397	: V=0.9864008, theta=-45.735357 -> V=1.0, theta=0.0
% INFO    : Bus 81398	: V=1.0108826, theta=-43.247776 -> V=1.0, theta=0.0
% INFO    : Bus 81399	: V=0.9589626, theta=-50.267332 -> V=1.0, theta=0.0
% INFO    : Bus 81400	: V=0.978719, theta=-47.275053 -> V=1.0, theta=0.0
% INFO    : Bus 81401	: V=0.9936759, theta=-45.756284 -> V=1.0, theta=0.0
% INFO    : Bus 81402	: V=0.9710941, theta=-47.740505 -> V=1.0, theta=0.0
% INFO    : Bus 81403	: V=0.9994885, theta=-44.628643 -> V=1.0, theta=0.0
% INFO    : Bus 81404	: V=0.9585934, theta=-47.676136 -> V=1.0, theta=0.0
% INFO    : Bus 81405	: V=0.9971806, theta=-52.861696 -> V=1.0, theta=0.0
% INFO    : Bus 81406	: V=0.9894838, theta=-52.975391 -> V=1.0, theta=0.0
% INFO    : Bus 81407	: V=1.0037127, theta=-52.160306 -> V=1.0, theta=0.0
% INFO    : Bus 81408	: V=0.9990928, theta=-52.239605 -> V=1.0, theta=0.0
% INFO    : Bus 81409	: V=0.9966427, theta=-52.494272 -> V=1.0, theta=0.0
% INFO    : Bus 81410	: V=0.9877642, theta=-50.641236 -> V=1.0, theta=0.0
% INFO    : Bus 81411	: V=0.9556802, theta=-50.349603 -> V=1.0, theta=0.0
% INFO    : Bus 81412	: V=0.955503, theta=-50.287662 -> V=1.0, theta=0.0
% INFO    : Bus 81413	: V=0.963879, theta=-49.486459 -> V=1.0, theta=0.0
% INFO    : Bus 81414	: V=0.9554189, theta=-50.300388 -> V=1.0, theta=0.0
% INFO    : Bus 81415	: V=0.9940359, theta=-41.782524 -> V=1.0, theta=0.0
% INFO    : Bus 81416	: V=0.9929678, theta=-41.511728 -> V=1.0, theta=0.0
% INFO    : Bus 81417	: V=1.0024344, theta=-41.515814 -> V=1.0, theta=0.0
% INFO    : Bus 81418	: V=1.0027667, theta=-45.159375 -> V=1.0, theta=0.0
% INFO    : Bus 81419	: V=1.0017886, theta=-45.239544 -> V=1.0, theta=0.0
% INFO    : Bus 81420	: V=1.0128488, theta=-44.356052 -> V=1.0, theta=0.0
% INFO    : Bus 81421	: V=1.000375, theta=-45.279528 -> V=1.0, theta=0.0
% INFO    : Bus 81422	: V=0.9964198, theta=-46.023962 -> V=1.0, theta=0.0
% INFO    : Bus 81423	: V=1.0041607, theta=-45.190302 -> V=1.0, theta=0.0
% INFO    : Bus 81424	: V=1.0134794, theta=-44.096534 -> V=1.0, theta=0.0
% INFO    : Bus 81425	: V=1.0123729, theta=-44.190572 -> V=1.0, theta=0.0
% INFO    : Bus 81426	: V=1.0109408, theta=-44.25749 -> V=1.0, theta=0.0
% INFO    : Bus 81427	: V=1.0087294, theta=-44.573451 -> V=1.0, theta=0.0
% INFO    : Bus 81428	: V=1.0050177, theta=-44.973686 -> V=1.0, theta=0.0
% INFO    : Bus 81429	: V=1.0051195, theta=-44.574609 -> V=1.0, theta=0.0
% INFO    : Bus 81430	: V=1.0050992, theta=-46.372679 -> V=1.0, theta=0.0
% INFO    : Bus 81431	: V=1.0088333, theta=-45.29947 -> V=1.0, theta=0.0
% INFO    : Bus 81432	: V=1.0048365, theta=-46.802487 -> V=1.0, theta=0.0
% INFO    : Bus 81433	: V=1.0054383, theta=-46.156634 -> V=1.0, theta=0.0
% INFO    : Bus 81434	: V=0.9975962, theta=-46.981203 -> V=1.0, theta=0.0
% INFO    : Bus 81435	: V=1.0021821, theta=-47.163265 -> V=1.0, theta=0.0
% INFO    : Bus 81436	: V=1.0004855, theta=-47.06284 -> V=1.0, theta=0.0
% INFO    : Bus 81437	: V=1.0044654, theta=-46.517026 -> V=1.0, theta=0.0
% INFO    : Bus 81438	: V=1.003288, theta=-46.684062 -> V=1.0, theta=0.0
% INFO    : Bus 81439	: V=0.9956539, theta=-47.034624 -> V=1.0, theta=0.0
% INFO    : Bus 81440	: V=1.0065914, theta=-45.348422 -> V=1.0, theta=0.0
% INFO    : Bus 81441	: V=1.0057907, theta=-45.545444 -> V=1.0, theta=0.0
% INFO    : Bus 81442	: V=1.0044871, theta=-45.519712 -> V=1.0, theta=0.0
% INFO    : Bus 81443	: V=0.9984803, theta=-40.385741 -> V=1.0, theta=0.0
% INFO    : Bus 81444	: V=0.9919299, theta=-40.98041 -> V=1.0, theta=0.0
% INFO    : Bus 81445	: V=0.9436625, theta=-51.286633 -> V=1.0, theta=0.0
% INFO    : Bus 81446	: V=0.9475366, theta=-50.50323 -> V=1.0, theta=0.0
% INFO    : Bus 81447	: V=0.9856866, theta=-53.688774 -> V=1.0, theta=0.0
% INFO    : Bus 81448	: V=0.9830548, theta=-53.377706 -> V=1.0, theta=0.0
% INFO    : Bus 81449	: V=1.0001609, theta=-44.891178 -> V=1.0, theta=0.0
% INFO    : Bus 81450	: V=0.9894632, theta=-46.512039 -> V=1.0, theta=0.0
% INFO    : Bus 81451	: V=0.973777, theta=-48.642597 -> V=1.0, theta=0.0
% INFO    : Bus 81452	: V=1.0084679, theta=-43.874964 -> V=1.0, theta=0.0
% INFO    : Bus 81453	: V=0.983905, theta=-47.917735 -> V=1.0, theta=0.0
% INFO    : Bus 81454	: V=0.9922627, theta=-47.045998 -> V=1.0, theta=0.0
% INFO    : Bus 81455	: V=1.0082428, theta=-46.070906 -> V=1.0, theta=0.0
% INFO    : Bus 81456	: V=1.0087497, theta=-46.307077 -> V=1.0, theta=0.0
% INFO    : Bus 81457	: V=1.0040008, theta=-41.228254 -> V=1.0, theta=0.0
% INFO    : Bus 81458	: V=1.0001011, theta=-41.978168 -> V=1.0, theta=0.0
% INFO    : Bus 81459	: V=0.9963865, theta=-42.716341 -> V=1.0, theta=0.0
% INFO    : Bus 81460	: V=0.9586627, theta=-48.940314 -> V=1.0, theta=0.0
% INFO    : Bus 81461	: V=0.9884977, theta=-44.005779 -> V=1.0, theta=0.0
% INFO    : Bus 81462	: V=0.9681904, theta=-50.261723 -> V=1.0, theta=0.0
% INFO    : Bus 81463	: V=0.997648, theta=-46.260567 -> V=1.0, theta=0.0
% INFO    : Bus 81464	: V=0.9762207, theta=-49.072931 -> V=1.0, theta=0.0
% INFO    : Bus 81465	: V=1.0027239, theta=-40.849587 -> V=1.0, theta=0.0
% INFO    : Bus 81466	: V=1.0081904, theta=-40.485804 -> V=1.0, theta=0.0
% INFO    : Bus 81467	: V=1.0099809, theta=-40.544439 -> V=1.0, theta=0.0
% INFO    : Bus 81468	: V=0.9915264, theta=-41.630602 -> V=1.0, theta=0.0
% INFO    : Bus 81469	: V=0.996157, theta=-41.007129 -> V=1.0, theta=0.0
% INFO    : Bus 81470	: V=0.9896893, theta=-41.262419 -> V=1.0, theta=0.0
% INFO    : Bus 81471	: V=0.9604717, theta=-54.461439 -> V=1.0, theta=0.0
% INFO    : Bus 81472	: V=0.9580055, theta=-54.928463 -> V=1.0, theta=0.0
% INFO    : Bus 81473	: V=0.9579046, theta=-54.922065 -> V=1.0, theta=0.0
% INFO    : Bus 81474	: V=0.9580075, theta=-54.897564 -> V=1.0, theta=0.0
% INFO    : Bus 81475	: V=0.9641556, theta=-53.870765 -> V=1.0, theta=0.0
% INFO    : Bus 81476	: V=0.9611934, theta=-54.34867 -> V=1.0, theta=0.0
% INFO    : Bus 81477	: V=0.961574, theta=-54.22707 -> V=1.0, theta=0.0
% INFO    : Bus 81478	: V=0.9726305, theta=-52.653419 -> V=1.0, theta=0.0
% INFO    : Bus 81479	: V=0.9649499, theta=-53.70376 -> V=1.0, theta=0.0
% INFO    : Bus 81480	: V=0.9613716, theta=-54.280963 -> V=1.0, theta=0.0
% INFO    : Bus 81481	: V=0.9604631, theta=-54.331175 -> V=1.0, theta=0.0
% INFO    : Bus 81482	: V=0.9576014, theta=-54.545481 -> V=1.0, theta=0.0
% INFO    : Bus 81483	: V=0.9568441, theta=-54.555347 -> V=1.0, theta=0.0
% INFO    : Bus 81484	: V=0.9559017, theta=-54.943465 -> V=1.0, theta=0.0
% INFO    : Bus 81485	: V=0.9539039, theta=-55.342302 -> V=1.0, theta=0.0
% INFO    : Bus 81486	: V=0.9548157, theta=-54.907619 -> V=1.0, theta=0.0
% INFO    : Bus 81487	: V=0.9564372, theta=-54.694857 -> V=1.0, theta=0.0
% INFO    : Bus 81488	: V=1.0065864, theta=-41.280688 -> V=1.0, theta=0.0
% INFO    : Bus 81489	: V=0.9986841, theta=-42.747681 -> V=1.0, theta=0.0
% INFO    : Bus 81490	: V=0.9974654, theta=-43.035659 -> V=1.0, theta=0.0
% INFO    : Bus 81491	: V=1.0000272, theta=-45.427821 -> V=1.0, theta=0.0
% INFO    : Bus 81492	: V=0.997512, theta=-45.809914 -> V=1.0, theta=0.0
% INFO    : Bus 81493	: V=1.0065071, theta=-42.696781 -> V=1.0, theta=0.0
% INFO    : Bus 81494	: V=1.0093656, theta=-42.693894 -> V=1.0, theta=0.0
% INFO    : Bus 81495	: V=1.016201, theta=-41.455849 -> V=1.0, theta=0.0
% INFO    : Bus 81496	: V=1.0121674, theta=-42.146494 -> V=1.0, theta=0.0
% INFO    : Bus 81497	: V=1.0097984, theta=-42.500235 -> V=1.0, theta=0.0
% INFO    : Bus 81498	: V=0.9825992, theta=-42.970207 -> V=1.0, theta=0.0
% INFO    : Bus 81499	: V=0.9773133, theta=-43.757691 -> V=1.0, theta=0.0
% INFO    : Bus 81500	: V=0.9854774, theta=-43.101078 -> V=1.0, theta=0.0
% INFO    : Bus 81501	: V=0.9859759, theta=-42.996598 -> V=1.0, theta=0.0
% INFO    : Bus 81502	: V=0.9834944, theta=-43.240479 -> V=1.0, theta=0.0
% INFO    : Bus 81503	: V=0.9883302, theta=-42.53532 -> V=1.0, theta=0.0
% INFO    : Bus 81504	: V=0.9829824, theta=-43.432517 -> V=1.0, theta=0.0
% INFO    : Bus 81505	: V=0.9794504, theta=-43.520206 -> V=1.0, theta=0.0
% INFO    : Bus 81506	: V=0.9776913, theta=-43.799193 -> V=1.0, theta=0.0
% INFO    : Bus 81507	: V=0.9654542, theta=-44.841656 -> V=1.0, theta=0.0
% INFO    : Bus 81508	: V=0.973696, theta=-44.114136 -> V=1.0, theta=0.0
% INFO    : Bus 81509	: V=0.9636409, theta=-44.26389 -> V=1.0, theta=0.0
% INFO    : Bus 81510	: V=0.9816705, theta=-43.109895 -> V=1.0, theta=0.0
% INFO    : Bus 81511	: V=0.9727953, theta=-43.811711 -> V=1.0, theta=0.0
% INFO    : Bus 81512	: V=0.9687934, theta=-43.735876 -> V=1.0, theta=0.0
% INFO    : Bus 81513	: V=0.9743532, theta=-43.524716 -> V=1.0, theta=0.0
% INFO    : Bus 81514	: V=1.0047363, theta=-39.053049 -> V=1.0, theta=0.0
% INFO    : Bus 81515	: V=1.0026636, theta=-39.70905 -> V=1.0, theta=0.0
% INFO    : Bus 81516	: V=0.9940859, theta=-40.703347 -> V=1.0, theta=0.0
% INFO    : Bus 81517	: V=0.9983023, theta=-44.456749 -> V=1.0, theta=0.0
% INFO    : Bus 81518	: V=0.9686314, theta=-43.565891 -> V=1.0, theta=0.0
% INFO    : Bus 81519	: V=0.9708579, theta=-43.458791 -> V=1.0, theta=0.0
% INFO    : Bus 81520	: V=0.9680579, theta=-43.526761 -> V=1.0, theta=0.0
% INFO    : Bus 81521	: V=0.9693654, theta=-43.606337 -> V=1.0, theta=0.0
% INFO    : Bus 81522	: V=0.9697181, theta=-43.605887 -> V=1.0, theta=0.0
% INFO    : Bus 81523	: V=0.9731981, theta=-42.93952 -> V=1.0, theta=0.0
% INFO    : Bus 81524	: V=0.9989537, theta=-40.843259 -> V=1.0, theta=0.0
% INFO    : Bus 81525	: V=0.952372, theta=-55.291557 -> V=1.0, theta=0.0
% INFO    : Bus 81526	: V=0.9526305, theta=-55.379845 -> V=1.0, theta=0.0
% INFO    : Bus 81527	: V=0.9618668, theta=-54.155754 -> V=1.0, theta=0.0
% INFO    : Bus 81528	: V=0.958636, theta=-54.427846 -> V=1.0, theta=0.0
% INFO    : Bus 81529	: V=0.9495451, theta=-55.921681 -> V=1.0, theta=0.0
% INFO    : Bus 81530	: V=0.9521354, theta=-55.601033 -> V=1.0, theta=0.0
% INFO    : Bus 81531	: V=1.0036594, theta=-45.558463 -> V=1.0, theta=0.0
% INFO    : Bus 81532	: V=1.0098532, theta=-44.768691 -> V=1.0, theta=0.0
% INFO    : Bus 81533	: V=1.0095428, theta=-44.734372 -> V=1.0, theta=0.0
% INFO    : Bus 81534	: V=1.0052047, theta=-45.337136 -> V=1.0, theta=0.0
% INFO    : Bus 81535	: V=0.9815484, theta=-47.677591 -> V=1.0, theta=0.0
% INFO    : Bus 81536	: V=0.9786331, theta=-48.380282 -> V=1.0, theta=0.0
% INFO    : Bus 81537	: V=0.9821968, theta=-42.850122 -> V=1.0, theta=0.0
% INFO    : Bus 81538	: V=0.9852442, theta=-42.155029 -> V=1.0, theta=0.0
% INFO    : Bus 81539	: V=0.9851753, theta=-42.32014 -> V=1.0, theta=0.0
% INFO    : Bus 81540	: V=0.9988211, theta=-40.763468 -> V=1.0, theta=0.0
% INFO    : Bus 81541	: V=0.9910966, theta=-41.809993 -> V=1.0, theta=0.0
% INFO    : Bus 81542	: V=0.9864912, theta=-42.540789 -> V=1.0, theta=0.0
% INFO    : Bus 81543	: V=0.9835865, theta=-42.821986 -> V=1.0, theta=0.0
% INFO    : Bus 81544	: V=0.9831189, theta=-42.885023 -> V=1.0, theta=0.0
% INFO    : Bus 81545	: V=0.9795606, theta=-43.021984 -> V=1.0, theta=0.0
% INFO    : Bus 81546	: V=0.981817, theta=-42.982982 -> V=1.0, theta=0.0
% INFO    : Bus 81547	: V=0.9826574, theta=-42.860604 -> V=1.0, theta=0.0
% INFO    : Bus 81548	: V=0.9912291, theta=-46.473424 -> V=1.0, theta=0.0
% INFO    : Bus 81549	: V=0.9941578, theta=-46.316896 -> V=1.0, theta=0.0
% INFO    : Bus 81550	: V=0.9979071, theta=-45.722816 -> V=1.0, theta=0.0
% INFO    : Bus 81551	: V=0.9965321, theta=-46.062914 -> V=1.0, theta=0.0
% INFO    : Bus 81552	: V=0.9946448, theta=-46.678181 -> V=1.0, theta=0.0
% INFO    : Bus 81553	: V=1.0139303, theta=-38.363858 -> V=1.0, theta=0.0
% INFO    : Bus 81554	: V=0.9868471, theta=-43.823467 -> V=1.0, theta=0.0
% INFO    : Bus 81555	: V=0.9891041, theta=-43.579684 -> V=1.0, theta=0.0
% INFO    : Bus 81556	: V=0.9840364, theta=-44.268657 -> V=1.0, theta=0.0
% INFO    : Bus 81557	: V=0.9799785, theta=-44.583039 -> V=1.0, theta=0.0
% INFO    : Bus 81558	: V=0.9813821, theta=-44.535263 -> V=1.0, theta=0.0
% INFO    : Bus 81559	: V=0.9946342, theta=-42.797578 -> V=1.0, theta=0.0
% INFO    : Bus 81560	: V=0.989561, theta=-43.591423 -> V=1.0, theta=0.0
% INFO    : Bus 81561	: V=0.9857485, theta=-44.127194 -> V=1.0, theta=0.0
% INFO    : Bus 81562	: V=0.9787031, theta=-44.854641 -> V=1.0, theta=0.0
% INFO    : Bus 81563	: V=0.9916631, theta=-43.278756 -> V=1.0, theta=0.0
% INFO    : Bus 81564	: V=0.9875345, theta=-43.837835 -> V=1.0, theta=0.0
% INFO    : Bus 81565	: V=0.9733878, theta=-52.445519 -> V=1.0, theta=0.0
% INFO    : Bus 81566	: V=0.9791594, theta=-51.740763 -> V=1.0, theta=0.0
% INFO    : Bus 81567	: V=0.9733994, theta=-52.302774 -> V=1.0, theta=0.0
% INFO    : Bus 81568	: V=0.9757315, theta=-51.729962 -> V=1.0, theta=0.0
% INFO    : Bus 81569	: V=0.9714642, theta=-52.674591 -> V=1.0, theta=0.0
% INFO    : Bus 81570	: V=0.9743823, theta=-45.588142 -> V=1.0, theta=0.0
% INFO    : Bus 81571	: V=0.9884568, theta=-42.02398 -> V=1.0, theta=0.0
% INFO    : Bus 81572	: V=0.9909968, theta=-41.77914 -> V=1.0, theta=0.0
% INFO    : Bus 81573	: V=0.9944523, theta=-41.455759 -> V=1.0, theta=0.0
% INFO    : Bus 81574	: V=0.9898545, theta=-41.837667 -> V=1.0, theta=0.0
% INFO    : Bus 81575	: V=0.9903458, theta=-41.39968 -> V=1.0, theta=0.0
% INFO    : Bus 81576	: V=0.9919317, theta=-41.614723 -> V=1.0, theta=0.0
% INFO    : Bus 81577	: V=1.0034439, theta=-40.596338 -> V=1.0, theta=0.0
% INFO    : Bus 81578	: V=1.0037532, theta=-40.704826 -> V=1.0, theta=0.0
% INFO    : Bus 81579	: V=0.9960689, theta=-41.104231 -> V=1.0, theta=0.0
% INFO    : Bus 81580	: V=1.0027714, theta=-40.685118 -> V=1.0, theta=0.0
% INFO    : Bus 81581	: V=0.9954122, theta=-41.20633 -> V=1.0, theta=0.0
% INFO    : Bus 81582	: V=0.9984486, theta=-41.151184 -> V=1.0, theta=0.0
% INFO    : Bus 81583	: V=0.998265, theta=-41.355808 -> V=1.0, theta=0.0
% INFO    : Bus 81584	: V=1.0008482, theta=-40.910458 -> V=1.0, theta=0.0
% INFO    : Bus 81585	: V=1.0052157, theta=-40.531246 -> V=1.0, theta=0.0
% INFO    : Bus 81586	: V=0.9995745, theta=-40.859759 -> V=1.0, theta=0.0
% INFO    : Bus 81587	: V=1.0017846, theta=-40.61233 -> V=1.0, theta=0.0
% INFO    : Bus 81588	: V=0.9775882, theta=-43.713172 -> V=1.0, theta=0.0
% INFO    : Bus 81589	: V=0.9721189, theta=-44.022591 -> V=1.0, theta=0.0
% INFO    : Bus 81590	: V=0.9786092, theta=-43.662855 -> V=1.0, theta=0.0
% INFO    : Bus 81591	: V=0.9848382, theta=-42.708492 -> V=1.0, theta=0.0
% INFO    : Bus 81592	: V=0.986007, theta=-43.029426 -> V=1.0, theta=0.0
% INFO    : Bus 81593	: V=0.975037, theta=-43.869152 -> V=1.0, theta=0.0
% INFO    : Bus 81594	: V=0.9691009, theta=-44.276449 -> V=1.0, theta=0.0
% INFO    : Bus 81595	: V=0.9708032, theta=-44.22111 -> V=1.0, theta=0.0
% INFO    : Bus 81596	: V=0.9686175, theta=-44.17541 -> V=1.0, theta=0.0
% INFO    : Bus 81597	: V=0.9702849, theta=-44.233228 -> V=1.0, theta=0.0
% INFO    : Bus 81598	: V=0.9896333, theta=-42.26549 -> V=1.0, theta=0.0
% INFO    : Bus 81599	: V=0.9861438, theta=-42.925851 -> V=1.0, theta=0.0
% INFO    : Bus 81600	: V=0.9730284, theta=-44.084896 -> V=1.0, theta=0.0
% INFO    : Bus 81601	: V=0.9693409, theta=-44.145409 -> V=1.0, theta=0.0
% INFO    : Bus 81602	: V=0.9669708, theta=-44.284919 -> V=1.0, theta=0.0
% INFO    : Bus 81603	: V=0.9709886, theta=-44.263223 -> V=1.0, theta=0.0
% INFO    : Bus 81604	: V=0.9712478, theta=-44.232464 -> V=1.0, theta=0.0
% INFO    : Bus 81605	: V=0.9942233, theta=-41.548242 -> V=1.0, theta=0.0
% INFO    : Bus 81606	: V=0.9848493, theta=-42.752434 -> V=1.0, theta=0.0
% INFO    : Bus 81607	: V=0.9740296, theta=-44.09188 -> V=1.0, theta=0.0
% INFO    : Bus 81608	: V=0.9890557, theta=-44.11779 -> V=1.0, theta=0.0
% INFO    : Bus 81609	: V=0.9874206, theta=-44.157074 -> V=1.0, theta=0.0
% INFO    : Bus 81610	: V=0.980878, theta=-41.146172 -> V=1.0, theta=0.0
% INFO    : Bus 81611	: V=0.9794654, theta=-41.395055 -> V=1.0, theta=0.0
% INFO    : Bus 81612	: V=0.9887444, theta=-42.09914 -> V=1.0, theta=0.0
% INFO    : Bus 81613	: V=0.9799012, theta=-43.382473 -> V=1.0, theta=0.0
% INFO    : Bus 81614	: V=0.9770887, theta=-43.40666 -> V=1.0, theta=0.0
% INFO    : Bus 81615	: V=0.9753492, theta=-43.536166 -> V=1.0, theta=0.0
% INFO    : Bus 81616	: V=0.9787474, theta=-43.347933 -> V=1.0, theta=0.0
% INFO    : Bus 81617	: V=0.9808401, theta=-43.200475 -> V=1.0, theta=0.0
% INFO    : Bus 81618	: V=0.9682055, theta=-49.830657 -> V=1.0, theta=0.0
% INFO    : Bus 81619	: V=0.9623552, theta=-50.574641 -> V=1.0, theta=0.0
% INFO    : Bus 81620	: V=0.9880652, theta=-43.077864 -> V=1.0, theta=0.0
% INFO    : Bus 81621	: V=0.9925852, theta=-42.411437 -> V=1.0, theta=0.0
% INFO    : Bus 81622	: V=0.9932817, theta=-42.370041 -> V=1.0, theta=0.0
% INFO    : Bus 81623	: V=0.9973576, theta=-41.816462 -> V=1.0, theta=0.0
% INFO    : Bus 81624	: V=0.9991477, theta=-41.665519 -> V=1.0, theta=0.0
% INFO    : Bus 81625	: V=0.9955004, theta=-42.027219 -> V=1.0, theta=0.0
% INFO    : Bus 81626	: V=0.998608, theta=-41.735901 -> V=1.0, theta=0.0
% INFO    : Bus 81627	: V=0.9998092, theta=-41.65065 -> V=1.0, theta=0.0
% INFO    : Bus 81628	: V=0.9976587, theta=-41.877043 -> V=1.0, theta=0.0
% INFO    : Bus 81629	: V=0.9989412, theta=-41.878136 -> V=1.0, theta=0.0
% INFO    : Bus 81630	: V=0.9965732, theta=-41.974957 -> V=1.0, theta=0.0
% INFO    : Bus 81631	: V=0.9949739, theta=-42.128201 -> V=1.0, theta=0.0
% INFO    : Bus 81632	: V=0.9945478, theta=-42.157261 -> V=1.0, theta=0.0
% INFO    : Bus 81633	: V=0.9941745, theta=-42.211773 -> V=1.0, theta=0.0
% INFO    : Bus 81634	: V=0.9958937, theta=-42.054449 -> V=1.0, theta=0.0
% INFO    : Bus 81635	: V=0.9974883, theta=-41.937567 -> V=1.0, theta=0.0
% INFO    : Bus 81636	: V=0.9959741, theta=-42.027369 -> V=1.0, theta=0.0
% INFO    : Bus 81637	: V=0.989501, theta=-42.690202 -> V=1.0, theta=0.0
% INFO    : Bus 81638	: V=0.9835137, theta=-43.372491 -> V=1.0, theta=0.0
% INFO    : Bus 81639	: V=1.00109, theta=-41.449657 -> V=1.0, theta=0.0
% INFO    : Bus 81640	: V=0.9920108, theta=-42.060347 -> V=1.0, theta=0.0
% INFO    : Bus 81641	: V=0.9972377, theta=-41.932389 -> V=1.0, theta=0.0
% INFO    : Bus 81642	: V=0.98768, theta=-42.349048 -> V=1.0, theta=0.0
% INFO    : Bus 81643	: V=1.0059106, theta=-40.804414 -> V=1.0, theta=0.0
% INFO    : Bus 81644	: V=1.0038685, theta=-41.204841 -> V=1.0, theta=0.0
% INFO    : Bus 81645	: V=0.998339, theta=-41.816238 -> V=1.0, theta=0.0
% INFO    : Bus 81646	: V=0.9791067, theta=-43.162238 -> V=1.0, theta=0.0
% INFO    : Bus 81647	: V=0.9907402, theta=-42.185072 -> V=1.0, theta=0.0
% INFO    : Bus 81648	: V=0.9533393, theta=-50.268589 -> V=1.0, theta=0.0
% INFO    : Bus 81649	: V=0.9517087, theta=-50.494342 -> V=1.0, theta=0.0
% INFO    : Bus 81650	: V=0.9507716, theta=-49.419275 -> V=1.0, theta=0.0
% INFO    : Bus 81651	: V=0.9549742, theta=-50.143861 -> V=1.0, theta=0.0
% INFO    : Bus 81652	: V=0.9518616, theta=-50.407044 -> V=1.0, theta=0.0
% INFO    : Bus 81653	: V=0.9518444, theta=-50.468417 -> V=1.0, theta=0.0
% INFO    : Bus 81654	: V=0.9512967, theta=-50.656655 -> V=1.0, theta=0.0
% INFO    : Bus 81655	: V=0.953707, theta=-50.261521 -> V=1.0, theta=0.0
% INFO    : Bus 81656	: V=0.9526105, theta=-50.315414 -> V=1.0, theta=0.0
% INFO    : Bus 81657	: V=0.9504001, theta=-50.489368 -> V=1.0, theta=0.0
% INFO    : Bus 81658	: V=0.9534523, theta=-49.891983 -> V=1.0, theta=0.0
% INFO    : Bus 81659	: V=0.9792744, theta=-46.146745 -> V=1.0, theta=0.0
% INFO    : Bus 81660	: V=0.9608874, theta=-49.033165 -> V=1.0, theta=0.0
% INFO    : Bus 81661	: V=0.9591302, theta=-49.699362 -> V=1.0, theta=0.0
% INFO    : Bus 81662	: V=0.9536135, theta=-50.353784 -> V=1.0, theta=0.0
% INFO    : Bus 81663	: V=1.0101906, theta=-42.191795 -> V=1.0, theta=0.0
% INFO    : Bus 81664	: V=1.0123595, theta=-41.785657 -> V=1.0, theta=0.0
% INFO    : Bus 81665	: V=1.0098362, theta=-42.28711 -> V=1.0, theta=0.0
% INFO    : Bus 81666	: V=1.008667, theta=-42.467738 -> V=1.0, theta=0.0
% INFO    : Bus 81667	: V=0.9714342, theta=-43.576098 -> V=1.0, theta=0.0
% INFO    : Bus 81668	: V=0.9646275, theta=-43.778438 -> V=1.0, theta=0.0
% INFO    : Bus 81669	: V=0.9669696, theta=-43.756669 -> V=1.0, theta=0.0
% INFO    : Bus 81670	: V=0.9618154, theta=-43.864909 -> V=1.0, theta=0.0
% INFO    : Bus 81671	: V=0.9643813, theta=-43.692551 -> V=1.0, theta=0.0
% INFO    : Bus 81672	: V=0.9680297, theta=-43.20939 -> V=1.0, theta=0.0
% INFO    : Bus 81673	: V=0.9766534, theta=-43.48799 -> V=1.0, theta=0.0
% INFO    : Bus 81674	: V=0.9726838, theta=-44.181456 -> V=1.0, theta=0.0
% INFO    : Bus 81675	: V=0.9654918, theta=-44.674528 -> V=1.0, theta=0.0
% INFO    : Bus 81676	: V=0.9665066, theta=-44.581286 -> V=1.0, theta=0.0
% INFO    : Bus 81677	: V=0.9639997, theta=-45.001924 -> V=1.0, theta=0.0
% INFO    : Bus 81678	: V=0.9604213, theta=-45.219917 -> V=1.0, theta=0.0
% INFO    : Bus 81679	: V=0.9610111, theta=-45.602204 -> V=1.0, theta=0.0
% INFO    : Bus 81680	: V=0.96175, theta=-45.570117 -> V=1.0, theta=0.0
% INFO    : Bus 81681	: V=0.9645748, theta=-45.271628 -> V=1.0, theta=0.0
% INFO    : Bus 81682	: V=0.9600045, theta=-45.586758 -> V=1.0, theta=0.0
% INFO    : Bus 81683	: V=0.9586629, theta=-46.345889 -> V=1.0, theta=0.0
% INFO    : Bus 81684	: V=0.9630025, theta=-45.586431 -> V=1.0, theta=0.0
% INFO    : Bus 81685	: V=0.9726333, theta=-44.181676 -> V=1.0, theta=0.0
% INFO    : Bus 81686	: V=0.9693493, theta=-44.891084 -> V=1.0, theta=0.0
% INFO    : Bus 81687	: V=0.9593192, theta=-46.26721 -> V=1.0, theta=0.0
% INFO    : Bus 81688	: V=0.9621332, theta=-45.311948 -> V=1.0, theta=0.0
% INFO    : Bus 81689	: V=0.9664085, theta=-44.891481 -> V=1.0, theta=0.0
% INFO    : Bus 81690	: V=0.9669582, theta=-44.860556 -> V=1.0, theta=0.0
% INFO    : Bus 81691	: V=0.962274, theta=-45.513114 -> V=1.0, theta=0.0
% INFO    : Bus 81692	: V=0.9649021, theta=-44.750218 -> V=1.0, theta=0.0
% INFO    : Bus 81693	: V=0.9682531, theta=-44.629509 -> V=1.0, theta=0.0
% INFO    : Bus 81694	: V=0.9738845, theta=-44.14241 -> V=1.0, theta=0.0
% INFO    : Bus 81695	: V=0.9682632, theta=-44.737404 -> V=1.0, theta=0.0
% INFO    : Bus 81696	: V=1.0052239, theta=-42.804397 -> V=1.0, theta=0.0
% INFO    : Bus 81697	: V=1.009153, theta=-42.405085 -> V=1.0, theta=0.0
% INFO    : Bus 81698	: V=1.0078578, theta=-42.595429 -> V=1.0, theta=0.0
% INFO    : Bus 81699	: V=0.9930984, theta=-41.068535 -> V=1.0, theta=0.0
% INFO    : Bus 81700	: V=0.9873164, theta=-55.421597 -> V=1.0, theta=0.0
% INFO    : Bus 81701	: V=1.0001732, theta=-53.841118 -> V=1.0, theta=0.0
% INFO    : Bus 81702	: V=0.9952121, theta=-54.396043 -> V=1.0, theta=0.0
% INFO    : Bus 81703	: V=0.9955955, theta=-54.264881 -> V=1.0, theta=0.0
% INFO    : Bus 81704	: V=0.9916916, theta=-55.013098 -> V=1.0, theta=0.0
% INFO    : Bus 81705	: V=0.9991495, theta=-49.808877 -> V=1.0, theta=0.0
% INFO    : Bus 81706	: V=1.0015259, theta=-55.473522 -> V=1.0, theta=0.0
% INFO    : Bus 81707	: V=0.9907589, theta=-56.186031 -> V=1.0, theta=0.0
% INFO    : Bus 81708	: V=0.9986627, theta=-55.230259 -> V=1.0, theta=0.0
% INFO    : Bus 81709	: V=0.9981647, theta=-55.455591 -> V=1.0, theta=0.0
% INFO    : Bus 81710	: V=0.998411, theta=-55.223814 -> V=1.0, theta=0.0
% INFO    : Bus 81711	: V=0.9893715, theta=-56.275323 -> V=1.0, theta=0.0
% INFO    : Bus 81712	: V=1.0176364, theta=-39.072573 -> V=1.0, theta=0.0
% INFO    : Bus 81713	: V=1.0152148, theta=-39.151588 -> V=1.0, theta=0.0
% INFO    : Bus 81714	: V=1.0113778, theta=-39.603116 -> V=1.0, theta=0.0
% INFO    : Bus 81715	: V=0.9760268, theta=-48.819278 -> V=1.0, theta=0.0
% INFO    : Bus 81716	: V=0.9767031, theta=-47.296223 -> V=1.0, theta=0.0
% INFO    : Bus 81717	: V=1.0037717, theta=-53.102467 -> V=1.0, theta=0.0
% INFO    : Bus 81718	: V=1.0054224, theta=-52.380307 -> V=1.0, theta=0.0
% INFO    : Bus 81719	: V=1.0061628, theta=-52.724544 -> V=1.0, theta=0.0
% INFO    : Bus 81720	: V=0.994053, theta=-34.77013 -> V=1.0, theta=0.0
% INFO    : Bus 81721	: V=0.9935464, theta=-34.507066 -> V=1.0, theta=0.0
% INFO    : Bus 81722	: V=0.9934842, theta=-34.722013 -> V=1.0, theta=0.0
% INFO    : Bus 81723	: V=0.9960026, theta=-34.201165 -> V=1.0, theta=0.0
% INFO    : Bus 81724	: V=0.996242, theta=-34.054101 -> V=1.0, theta=0.0
% INFO    : Bus 81725	: V=0.990599, theta=-35.744756 -> V=1.0, theta=0.0
% INFO    : Bus 81726	: V=0.997311, theta=-46.309631 -> V=1.0, theta=0.0
% INFO    : Bus 81727	: V=1.0029838, theta=-43.956531 -> V=1.0, theta=0.0
% INFO    : Bus 81728	: V=1.0037566, theta=-43.772547 -> V=1.0, theta=0.0
% INFO    : Bus 81729	: V=0.988237, theta=-46.158127 -> V=1.0, theta=0.0
% INFO    : Bus 81730	: V=0.980346, theta=-46.574052 -> V=1.0, theta=0.0
% INFO    : Bus 81731	: V=1.0034586, theta=-43.405519 -> V=1.0, theta=0.0
% INFO    : Bus 81732	: V=1.0048359, theta=-43.239222 -> V=1.0, theta=0.0
% INFO    : Bus 81733	: V=0.982479, theta=-46.676904 -> V=1.0, theta=0.0
% INFO    : Bus 81734	: V=1.0124212, theta=-52.535102 -> V=1.0, theta=0.0
% INFO    : Bus 81735	: V=1.0091938, theta=-51.989108 -> V=1.0, theta=0.0
% INFO    : Bus 81736	: V=0.996661, theta=-54.409439 -> V=1.0, theta=0.0
% INFO    : Bus 81737	: V=1.00344, theta=-54.935936 -> V=1.0, theta=0.0
% INFO    : Bus 81738	: V=1.0021377, theta=-53.827746 -> V=1.0, theta=0.0
% INFO    : Bus 81739	: V=1.0102784, theta=-50.328045 -> V=1.0, theta=0.0
% INFO    : Bus 81740	: V=1.0077096, theta=-50.400921 -> V=1.0, theta=0.0
% INFO    : Bus 81741	: V=1.0062554, theta=-50.665145 -> V=1.0, theta=0.0
% INFO    : Bus 81742	: V=1.0080233, theta=-47.625418 -> V=1.0, theta=0.0
% INFO    : Bus 81743	: V=1.008568, theta=-47.703831 -> V=1.0, theta=0.0
% INFO    : Bus 81744	: V=1.0038694, theta=-48.133088 -> V=1.0, theta=0.0
% INFO    : Bus 81745	: V=1.0123178, theta=-46.752009 -> V=1.0, theta=0.0
% INFO    : Bus 81746	: V=1.0129795, theta=-46.850794 -> V=1.0, theta=0.0
% INFO    : Bus 81747	: V=1.0107645, theta=-47.373099 -> V=1.0, theta=0.0
% INFO    : Bus 81748	: V=1.0088689, theta=-47.712667 -> V=1.0, theta=0.0
% INFO    : Bus 81749	: V=1.0119845, theta=-46.120134 -> V=1.0, theta=0.0
% INFO    : Bus 81750	: V=1.0187346, theta=-47.180767 -> V=1.0, theta=0.0
% INFO    : Bus 81751	: V=1.012364, theta=-37.555119 -> V=1.0, theta=0.0
% INFO    : Bus 81752	: V=1.011244, theta=-37.766332 -> V=1.0, theta=0.0
% INFO    : Bus 81753	: V=1.0074971, theta=-40.170083 -> V=1.0, theta=0.0
% INFO    : Bus 81754	: V=0.9962826, theta=-55.830372 -> V=1.0, theta=0.0
% INFO    : Bus 81755	: V=0.9961546, theta=-55.776382 -> V=1.0, theta=0.0
% INFO    : Bus 81756	: V=0.9926208, theta=-55.269143 -> V=1.0, theta=0.0
% INFO    : Bus 81757	: V=0.990665, theta=-55.609287 -> V=1.0, theta=0.0
% INFO    : Bus 81758	: V=0.9946775, theta=-55.295697 -> V=1.0, theta=0.0
% INFO    : Bus 81759	: V=0.9966792, theta=-55.30239 -> V=1.0, theta=0.0
% INFO    : Bus 81760	: V=0.9926875, theta=-42.651289 -> V=1.0, theta=0.0
% INFO    : Bus 81761	: V=0.9931385, theta=-42.751653 -> V=1.0, theta=0.0
% INFO    : Bus 81762	: V=0.997386, theta=-41.971213 -> V=1.0, theta=0.0
% INFO    : Bus 81763	: V=1.0091765, theta=-39.584888 -> V=1.0, theta=0.0
% INFO    : Bus 81764	: V=1.0011101, theta=-41.111558 -> V=1.0, theta=0.0
% INFO    : Bus 81765	: V=0.9978583, theta=-41.303545 -> V=1.0, theta=0.0
% INFO    : Bus 81766	: V=1.0027958, theta=-40.60616 -> V=1.0, theta=0.0
% INFO    : Bus 81767	: V=1.0010126, theta=-40.901078 -> V=1.0, theta=0.0
% INFO    : Bus 81768	: V=1.001749, theta=-40.715284 -> V=1.0, theta=0.0
% INFO    : Bus 81769	: V=0.999389, theta=-42.274842 -> V=1.0, theta=0.0
% INFO    : Bus 81770	: V=0.9912633, theta=-43.22178 -> V=1.0, theta=0.0
% INFO    : Bus 81771	: V=0.9999335, theta=-42.176242 -> V=1.0, theta=0.0
% INFO    : Bus 81772	: V=1.0002153, theta=-42.235667 -> V=1.0, theta=0.0
% INFO    : Bus 81773	: V=1.0101798, theta=-39.579381 -> V=1.0, theta=0.0
% INFO    : Bus 81774	: V=1.001849, theta=-41.262975 -> V=1.0, theta=0.0
% INFO    : Bus 81775	: V=1.0027407, theta=-41.393747 -> V=1.0, theta=0.0
% INFO    : Bus 81776	: V=1.0000012, theta=-41.797057 -> V=1.0, theta=0.0
% INFO    : Bus 81777	: V=1.0032331, theta=-40.754263 -> V=1.0, theta=0.0
% INFO    : Bus 81778	: V=1.0006216, theta=-41.115427 -> V=1.0, theta=0.0
% INFO    : Bus 81779	: V=0.991745, theta=-40.709032 -> V=1.0, theta=0.0
% INFO    : Bus 81780	: V=0.9834519, theta=-49.314076 -> V=1.0, theta=0.0
% INFO    : Bus 81781	: V=0.9998202, theta=-41.008356 -> V=1.0, theta=0.0
% INFO    : Bus 81782	: V=0.9692724, theta=-43.457933 -> V=1.0, theta=0.0
% INFO    : Bus 81783	: V=0.9623427, theta=-45.481976 -> V=1.0, theta=0.0
% INFO    : Bus 81784	: V=0.9726742, theta=-44.071444 -> V=1.0, theta=0.0
% INFO    : Bus 81785	: V=0.9467624, theta=-50.220908 -> V=1.0, theta=0.0
% INFO    : Bus 81786	: V=0.9512215, theta=-50.174341 -> V=1.0, theta=0.0
% INFO    : Bus 81787	: V=0.9534646, theta=-49.766122 -> V=1.0, theta=0.0
% INFO    : Bus 81788	: V=1.0060325, theta=-51.25144 -> V=1.0, theta=0.0
% INFO    : Bus 81789	: V=1.0055127, theta=-49.537715 -> V=1.0, theta=0.0
% INFO    : Bus 81790	: V=1.0191161, theta=-47.893149 -> V=1.0, theta=0.0
% INFO    : Bus 81791	: V=1.0195054, theta=-49.334886 -> V=1.0, theta=0.0
% INFO    : Bus 81792	: V=1.0095665, theta=-48.787304 -> V=1.0, theta=0.0
% INFO    : Bus 81793	: V=1.0125124, theta=-46.532522 -> V=1.0, theta=0.0
% INFO    : Bus 81794	: V=1.0168623, theta=-45.407163 -> V=1.0, theta=0.0
% INFO    : Bus 81795	: V=1.0160472, theta=-45.649524 -> V=1.0, theta=0.0
% INFO    : Bus 81796	: V=1.0076962, theta=-35.95543 -> V=1.0, theta=0.0
% INFO    : Bus 81797	: V=1.0098727, theta=-34.576723 -> V=1.0, theta=0.0
% INFO    : Bus 81798	: V=1.0077963, theta=-35.545742 -> V=1.0, theta=0.0
% INFO    : Bus 81799	: V=0.9570238, theta=-50.09165 -> V=1.0, theta=0.0
% INFO    : Bus 81800	: V=0.9519849, theta=-50.963481 -> V=1.0, theta=0.0
% INFO    : Bus 81801	: V=0.9542657, theta=-50.629457 -> V=1.0, theta=0.0
% INFO    : Bus 81802	: V=0.954523, theta=-50.702292 -> V=1.0, theta=0.0
% INFO    : Bus 81803	: V=1.012786, theta=-53.370767 -> V=1.0, theta=0.0
% INFO    : Bus 81804	: V=1.0155523, theta=-52.62509 -> V=1.0, theta=0.0
% INFO    : Bus 81805	: V=1.0196435, theta=-51.786181 -> V=1.0, theta=0.0
% INFO    : Bus 81806	: V=1.0100455, theta=-51.835267 -> V=1.0, theta=0.0
% INFO    : Bus 81807	: V=1.0104837, theta=-51.786788 -> V=1.0, theta=0.0
% INFO    : Bus 81808	: V=1.0174046, theta=-50.840727 -> V=1.0, theta=0.0
% INFO    : Bus 81809	: V=1.0169103, theta=-50.899777 -> V=1.0, theta=0.0
% INFO    : Bus 81810	: V=1.0100319, theta=-51.822079 -> V=1.0, theta=0.0
% INFO    : Bus 81811	: V=1.0174322, theta=-50.859389 -> V=1.0, theta=0.0
% INFO    : Bus 81812	: V=1.0176885, theta=-50.511153 -> V=1.0, theta=0.0
% INFO    : Bus 81813	: V=0.9790415, theta=-47.412119 -> V=1.0, theta=0.0
% INFO    : Bus 81814	: V=1.0054484, theta=-55.569291 -> V=1.0, theta=0.0
% INFO    : Bus 81815	: V=1.0076922, theta=-55.00458 -> V=1.0, theta=0.0
% INFO    : Bus 81816	: V=1.0042157, theta=-55.486202 -> V=1.0, theta=0.0
% INFO    : Bus 81817	: V=1.0045168, theta=-55.327457 -> V=1.0, theta=0.0
% INFO    : Bus 81818	: V=1.0046256, theta=-43.369621 -> V=1.0, theta=0.0
% INFO    : Bus 81819	: V=0.9915754, theta=-50.905286 -> V=1.0, theta=0.0
% INFO    : Bus 81820	: V=0.9917842, theta=-50.216335 -> V=1.0, theta=0.0
% INFO    : Bus 81821	: V=0.9935514, theta=-48.855409 -> V=1.0, theta=0.0
% INFO    : Bus 81822	: V=1.0056464, theta=-46.237893 -> V=1.0, theta=0.0
% INFO    : Bus 81823	: V=1.0115052, theta=-44.072425 -> V=1.0, theta=0.0
% INFO    : Bus 81824	: V=1.0177393, theta=-51.515985 -> V=1.0, theta=0.0
% INFO    : Bus 81825	: V=1.0185463, theta=-50.935595 -> V=1.0, theta=0.0
% INFO    : Bus 81826	: V=1.018914, theta=-51.074553 -> V=1.0, theta=0.0
% INFO    : Bus 81827	: V=1.0173228, theta=-50.926308 -> V=1.0, theta=0.0
% INFO    : Bus 81828	: V=1.0055647, theta=-38.153565 -> V=1.0, theta=0.0
% INFO    : Bus 81829	: V=1.0039278, theta=-38.939034 -> V=1.0, theta=0.0
% INFO    : Bus 81830	: V=0.9967449, theta=-39.046776 -> V=1.0, theta=0.0
% INFO    : Bus 81831	: V=0.9658391, theta=-47.861805 -> V=1.0, theta=0.0
% INFO    : Bus 81832	: V=0.9728905, theta=-47.61314 -> V=1.0, theta=0.0
% INFO    : Bus 81833	: V=0.9663112, theta=-47.991278 -> V=1.0, theta=0.0
% INFO    : Bus 81834	: V=0.9620548, theta=-48.602996 -> V=1.0, theta=0.0
% INFO    : Bus 81835	: V=0.9629451, theta=-48.028698 -> V=1.0, theta=0.0
% INFO    : Bus 81836	: V=0.9737882, theta=-46.844194 -> V=1.0, theta=0.0
% INFO    : Bus 81837	: V=0.9765921, theta=-46.746975 -> V=1.0, theta=0.0
% INFO    : Bus 81838	: V=0.9818175, theta=-45.526226 -> V=1.0, theta=0.0
% INFO    : Bus 81839	: V=0.9926598, theta=-42.618686 -> V=1.0, theta=0.0
% INFO    : Bus 81840	: V=0.9814695, theta=-47.287748 -> V=1.0, theta=0.0
% INFO    : Bus 81841	: V=1.0016873, theta=-45.887561 -> V=1.0, theta=0.0
% INFO    : Bus 81842	: V=0.9720035, theta=-49.318065 -> V=1.0, theta=0.0
% INFO    : Bus 81843	: V=1.0048447, theta=-32.239261 -> V=1.0, theta=0.0
% INFO    : Bus 81844	: V=1.0055326, theta=-32.061451 -> V=1.0, theta=0.0
% INFO    : Bus 81845	: V=1.0129687, theta=-32.096145 -> V=1.0, theta=0.0
% INFO    : Bus 81846	: V=0.9948522, theta=-35.865467 -> V=1.0, theta=0.0
% INFO    : Bus 81847	: V=0.987298, theta=-37.560954 -> V=1.0, theta=0.0
% INFO    : Bus 81848	: V=1.0177534, theta=-44.9162 -> V=1.0, theta=0.0
% INFO    : Bus 81849	: V=1.0159177, theta=-45.204536 -> V=1.0, theta=0.0
% INFO    : Bus 81850	: V=1.0128389, theta=-47.085228 -> V=1.0, theta=0.0
% INFO    : Bus 81851	: V=0.998238, theta=-41.280964 -> V=1.0, theta=0.0
% INFO    : Bus 81852	: V=0.998084, theta=-42.085034 -> V=1.0, theta=0.0
% INFO    : Bus 81853	: V=0.9976156, theta=-41.85064 -> V=1.0, theta=0.0
% INFO    : Bus 81854	: V=0.9952645, theta=-42.118282 -> V=1.0, theta=0.0
% INFO    : Bus 81855	: V=0.9965619, theta=-42.529861 -> V=1.0, theta=0.0
% INFO    : Bus 81856	: V=0.9964946, theta=-42.452634 -> V=1.0, theta=0.0
% INFO    : Bus 81857	: V=1.0058147, theta=-41.061352 -> V=1.0, theta=0.0
% INFO    : Bus 81858	: V=0.9554498, theta=-47.879137 -> V=1.0, theta=0.0
% INFO    : Bus 81859	: V=1.0175364, theta=-9.024575 -> V=1.0, theta=0.0
% INFO    : Bus 81860	: V=1.0171942, theta=-9.185852 -> V=1.0, theta=0.0
% INFO    : Bus 81861	: V=1.0195496, theta=-6.061354 -> V=1.0, theta=0.0
% INFO    : Bus 81862	: V=1.0184601, theta=-6.397125 -> V=1.0, theta=0.0
% INFO    : Bus 81863	: V=1.018403, theta=-6.481165 -> V=1.0, theta=0.0
% INFO    : Bus 81864	: V=0.9711763, theta=2.03527 -> V=1.0, theta=0.0
% INFO    : Bus 81865	: V=0.9696208, theta=1.66172 -> V=1.0, theta=0.0
% INFO    : Bus 81866	: V=1.019001, theta=-5.740277 -> V=1.0, theta=0.0
% INFO    : Bus 81867	: V=1.0182813, theta=-6.182567 -> V=1.0, theta=0.0
% INFO    : Bus 81868	: V=1.0189701, theta=-6.431663 -> V=1.0, theta=0.0
% INFO    : Bus 81869	: V=1.0162711, theta=-1.080428 -> V=1.0, theta=0.0
% INFO    : Bus 81870	: V=1.0152451, theta=-1.515639 -> V=1.0, theta=0.0
% INFO    : Bus 81871	: V=1.0182052, theta=-4.974872 -> V=1.0, theta=0.0
% INFO    : Bus 81872	: V=1.0186886, theta=-5.140765 -> V=1.0, theta=0.0
% INFO    : Bus 81873	: V=1.0102655, theta=-9.429516 -> V=1.0, theta=0.0
% INFO    : Bus 81874	: V=1.0083478, theta=-9.82551 -> V=1.0, theta=0.0
% INFO    : Bus 81875	: V=1.0092589, theta=-15.443961 -> V=1.0, theta=0.0
% INFO    : Bus 81876	: V=1.0080407, theta=-15.634934 -> V=1.0, theta=0.0
% INFO    : Bus 81877	: V=1.0165132, theta=-5.432229 -> V=1.0, theta=0.0
% INFO    : Bus 81878	: V=0.987773, theta=-6.54845 -> V=1.0, theta=0.0
% INFO    : Bus 81879	: V=0.9866991, theta=-7.216138 -> V=1.0, theta=0.0
% INFO    : Bus 81880	: V=0.9752949, theta=3.979253 -> V=1.0, theta=0.0
% INFO    : Bus 81881	: V=0.9668539, theta=9.047931 -> V=1.0, theta=0.0
% INFO    : Bus 81882	: V=0.9651613, theta=8.410044 -> V=1.0, theta=0.0
% INFO    : Bus 81883	: V=1.0168127, theta=-19.403262 -> V=1.0, theta=0.0
% INFO    : Bus 81884	: V=1.0140662, theta=-20.014269 -> V=1.0, theta=0.0
% INFO    : Bus 81885	: V=1.0134108, theta=-20.177892 -> V=1.0, theta=0.0
% INFO    : Bus 81886	: V=0.9846791, theta=-17.042847 -> V=1.0, theta=0.0
% INFO    : Bus 81887	: V=0.9823498, theta=-17.460254 -> V=1.0, theta=0.0
% INFO    : Bus 81888	: V=1.014854, theta=-8.718549 -> V=1.0, theta=0.0
% INFO    : Bus 81889	: V=0.9647934, theta=6.567766 -> V=1.0, theta=0.0
% INFO    : Bus 81890	: V=1.0167948, theta=-19.634101 -> V=1.0, theta=0.0
% INFO    : Bus 81891	: V=1.0151955, theta=-19.803495 -> V=1.0, theta=0.0
% INFO    : Bus 81892	: V=1.0147885, theta=-19.932366 -> V=1.0, theta=0.0
% INFO    : Bus 81893	: V=0.9686591, theta=9.362327 -> V=1.0, theta=0.0
% INFO    : Bus 81894	: V=1.0184536, theta=-14.072835 -> V=1.0, theta=0.0
% INFO    : Bus 81895	: V=0.9968457, theta=3.640217 -> V=1.0, theta=0.0
% INFO    : Bus 81896	: V=0.9928985, theta=0.297802 -> V=1.0, theta=0.0
% INFO    : Bus 81897	: V=0.9694017, theta=8.284729 -> V=1.0, theta=0.0
% INFO    : Bus 81898	: V=1.0192962, theta=-5.919639 -> V=1.0, theta=0.0
% INFO    : Bus 81899	: V=1.0180428, theta=-6.302674 -> V=1.0, theta=0.0
% INFO    : Bus 81900	: V=1.02, theta=-6.372355 -> V=1.0, theta=0.0
% INFO    : Bus 81901	: V=1.0192632, theta=-6.779892 -> V=1.0, theta=0.0
% INFO    : Bus 81902	: V=1.0173852, theta=-5.695387 -> V=1.0, theta=0.0
% INFO    : Bus 81903	: V=1.0148001, theta=-6.293738 -> V=1.0, theta=0.0
% INFO    : Bus 81904	: V=0.9965027, theta=1.465762 -> V=1.0, theta=0.0
% INFO    : Bus 81905	: V=0.9647657, theta=-15.853717 -> V=1.0, theta=0.0
% INFO    : Bus 81906	: V=1.0153121, theta=-8.68303 -> V=1.0, theta=0.0
% INFO    : Bus 81907	: V=0.993953, theta=-4.93679 -> V=1.0, theta=0.0
% INFO    : Bus 81908	: V=0.9976336, theta=0.787471 -> V=1.0, theta=0.0
% INFO    : Bus 81909	: V=0.9974448, theta=0.525796 -> V=1.0, theta=0.0
% INFO    : Bus 81910	: V=0.9642628, theta=8.227923 -> V=1.0, theta=0.0
% INFO    : Bus 81911	: V=1.0163014, theta=-1.112873 -> V=1.0, theta=0.0
% INFO    : Bus 81912	: V=1.0162313, theta=-1.322039 -> V=1.0, theta=0.0
% INFO    : Bus 81913	: V=1.0036148, theta=-12.983521 -> V=1.0, theta=0.0
% INFO    : Bus 81914	: V=0.9978985, theta=-14.08138 -> V=1.0, theta=0.0
% INFO    : Bus 81915	: V=0.9622983, theta=3.135276 -> V=1.0, theta=0.0
% INFO    : Bus 81916	: V=0.9757789, theta=-17.933887 -> V=1.0, theta=0.0
% INFO    : Bus 81917	: V=1.02, theta=-8.018147 -> V=1.0, theta=0.0
% INFO    : Bus 81918	: V=1.0174426, theta=-8.416926 -> V=1.0, theta=0.0
% INFO    : Bus 81919	: V=0.9639109, theta=-24.495463 -> V=1.0, theta=0.0
% INFO    : Bus 81920	: V=0.9618055, theta=-24.668683 -> V=1.0, theta=0.0
% INFO    : Bus 81921	: V=1.0097616, theta=-10.152774 -> V=1.0, theta=0.0
% INFO    : Bus 81922	: V=0.9732368, theta=2.998923 -> V=1.0, theta=0.0
% INFO    : Bus 81923	: V=0.9953634, theta=-16.515272 -> V=1.0, theta=0.0
% INFO    : Bus 81924	: V=0.9711098, theta=-25.28172 -> V=1.0, theta=0.0
% INFO    : Bus 81925	: V=0.984756, theta=-26.114948 -> V=1.0, theta=0.0
% INFO    : Bus 81926	: V=0.9664621, theta=-21.028221 -> V=1.0, theta=0.0
% INFO    : Bus 81927	: V=0.9718837, theta=-14.344194 -> V=1.0, theta=0.0
% INFO    : Bus 81928	: V=1.0149508, theta=-17.77538 -> V=1.0, theta=0.0
% INFO    : Bus 81929	: V=1.0107748, theta=-3.904648 -> V=1.0, theta=0.0
% INFO    : Bus 81930	: V=1.0074567, theta=-4.292625 -> V=1.0, theta=0.0
% INFO    : Bus 81931	: V=1.0073675, theta=-4.338581 -> V=1.0, theta=0.0
% INFO    : Bus 81932	: V=0.9995779, theta=-3.784564 -> V=1.0, theta=0.0
% INFO    : Bus 81933	: V=0.9928156, theta=-4.401845 -> V=1.0, theta=0.0
% INFO    : Bus 81934	: V=1.0142896, theta=-2.668537 -> V=1.0, theta=0.0
% INFO    : Bus 81935	: V=1.0160318, theta=-17.073392 -> V=1.0, theta=0.0
% INFO    : Bus 81936	: V=1.0138611, theta=-17.10881 -> V=1.0, theta=0.0
% INFO    : Bus 81937	: V=1.01503, theta=8.011168 -> V=1.0, theta=0.0
% INFO    : Bus 81938	: V=1.0149804, theta=7.927823 -> V=1.0, theta=0.0
% INFO    : Bus 81939	: V=1.0142507, theta=3.989032 -> V=1.0, theta=0.0
% INFO    : Bus 81940	: V=1.0137609, theta=3.752328 -> V=1.0, theta=0.0
% INFO    : Bus 81941	: V=1.0101981, theta=-2.142994 -> V=1.0, theta=0.0
% INFO    : Bus 81942	: V=1.0058355, theta=-11.187681 -> V=1.0, theta=0.0
% INFO    : Bus 81943	: V=1.0060369, theta=2.680052 -> V=1.0, theta=0.0
% INFO    : Bus 81944	: V=0.9925561, theta=-22.781748 -> V=1.0, theta=0.0
% INFO    : Bus 81945	: V=0.9889231, theta=-23.269817 -> V=1.0, theta=0.0
% INFO    : Bus 81946	: V=1.0065445, theta=-2.795032 -> V=1.0, theta=0.0
% INFO    : Bus 81947	: V=1.0053424, theta=-2.959245 -> V=1.0, theta=0.0
% INFO    : Bus 81948	: V=0.968663, theta=-20.957665 -> V=1.0, theta=0.0
% INFO    : Bus 81949	: V=1.0140385, theta=-5.110942 -> V=1.0, theta=0.0
% INFO    : Bus 81950	: V=0.9803401, theta=-7.306666 -> V=1.0, theta=0.0
% INFO    : Bus 81951	: V=1.0144659, theta=-5.029336 -> V=1.0, theta=0.0
% INFO    : Bus 81952	: V=1.0079962, theta=-20.012579 -> V=1.0, theta=0.0
% INFO    : Bus 81953	: V=0.9929611, theta=-21.644348 -> V=1.0, theta=0.0
% INFO    : Bus 81954	: V=1.0134086, theta=-10.499815 -> V=1.0, theta=0.0
% INFO    : Bus 81955	: V=0.9916221, theta=-23.905256 -> V=1.0, theta=0.0
% INFO    : Bus 81956	: V=0.9907366, theta=-24.197944 -> V=1.0, theta=0.0
% INFO    : Bus 81957	: V=0.991447, theta=-29.135305 -> V=1.0, theta=0.0
% INFO    : Bus 81958	: V=0.9871424, theta=-29.521974 -> V=1.0, theta=0.0
% INFO    : Bus 81959	: V=1.0228388, theta=11.981832 -> V=1.0, theta=0.0
% INFO    : Bus 81960	: V=1.0168645, theta=11.695439 -> V=1.0, theta=0.0
% INFO    : Bus 81961	: V=1.0159509, theta=11.630587 -> V=1.0, theta=0.0
% INFO    : Bus 81962	: V=1.0136156, theta=-17.134757 -> V=1.0, theta=0.0
% INFO    : Bus 81963	: V=1.0131484, theta=-17.229537 -> V=1.0, theta=0.0
% INFO    : Bus 81964	: V=1.0100956, theta=-12.59048 -> V=1.0, theta=0.0
% INFO    : Bus 81965	: V=1.0085172, theta=-13.159439 -> V=1.0, theta=0.0
% INFO    : Bus 81966	: V=0.9837356, theta=-25.854623 -> V=1.0, theta=0.0
% INFO    : Bus 81967	: V=1.02, theta=8.506102 -> V=1.0, theta=0.0
% INFO    : Bus 81968	: V=1.0165575, theta=-0.59898 -> V=1.0, theta=0.0
% INFO    : Bus 81969	: V=1.0057473, theta=3.915173 -> V=1.0, theta=0.0
% INFO    : Bus 81970	: V=1.0106979, theta=4.277372 -> V=1.0, theta=0.0
% INFO    : Bus 81971	: V=1.0098113, theta=-16.544648 -> V=1.0, theta=0.0
% INFO    : Bus 81972	: V=0.9719184, theta=-8.560916 -> V=1.0, theta=0.0
% INFO    : Bus 81973	: V=0.9670386, theta=-8.868477 -> V=1.0, theta=0.0
% INFO    : Bus 81974	: V=1.0013073, theta=-11.755495 -> V=1.0, theta=0.0
% INFO    : Bus 81975	: V=0.9826473, theta=-22.352155 -> V=1.0, theta=0.0
% INFO    : Bus 81976	: V=0.9901968, theta=-26.494079 -> V=1.0, theta=0.0
% INFO    : Bus 81977	: V=0.9703145, theta=-22.975203 -> V=1.0, theta=0.0
% INFO    : Bus 81978	: V=0.9752835, theta=-25.477442 -> V=1.0, theta=0.0
% INFO    : Bus 81979	: V=0.9892778, theta=-7.835292 -> V=1.0, theta=0.0
% INFO    : Bus 81980	: V=1.0100867, theta=-20.498022 -> V=1.0, theta=0.0
% INFO    : Bus 81981	: V=0.9960449, theta=-0.112548 -> V=1.0, theta=0.0
% INFO    : Bus 81982	: V=0.9705552, theta=-25.648383 -> V=1.0, theta=0.0
% INFO    : Bus 81983	: V=0.9960772, theta=-5.982691 -> V=1.0, theta=0.0
% INFO    : Bus 81984	: V=0.9867252, theta=-7.284387 -> V=1.0, theta=0.0
% INFO    : Bus 81985	: V=0.9968777, theta=0.964073 -> V=1.0, theta=0.0
% INFO    : Bus 81986	: V=1.0151568, theta=-0.642461 -> V=1.0, theta=0.0
% INFO    : Bus 81987	: V=1.0188477, theta=6.209191 -> V=1.0, theta=0.0
% INFO    : Bus 81988	: V=0.9826775, theta=-1.157497 -> V=1.0, theta=0.0
% INFO    : Bus 81989	: V=0.9864863, theta=22.922175 -> V=1.0, theta=0.0
% INFO    : Bus 81990	: V=0.9949219, theta=22.991373 -> V=1.0, theta=0.0
% INFO    : Bus 81991	: V=1.02, theta=-0.386116 -> V=1.0, theta=0.0
% INFO    : Bus 81992	: V=1.0078546, theta=0.454931 -> V=1.0, theta=0.0
% INFO    : Bus 81993	: V=0.9705772, theta=-5.635013 -> V=1.0, theta=0.0
% INFO    : Bus 81994	: V=1.0161631, theta=11.687765 -> V=1.0, theta=0.0
% INFO    : Bus 81995	: V=0.9920491, theta=3.180329 -> V=1.0, theta=0.0
% INFO    : Bus 81996	: V=1.0141116, theta=-24.189817 -> V=1.0, theta=0.0
% INFO    : Bus 81997	: V=1.0122674, theta=-24.51175 -> V=1.0, theta=0.0
% INFO    : Bus 81998	: V=1.0117008, theta=-24.640225 -> V=1.0, theta=0.0
% INFO    : Bus 81999	: V=1.0165885, theta=-50.292038 -> V=1.0, theta=0.0
% INFO    : Bus 82000	: V=1.019816, theta=-28.579212 -> V=1.0, theta=0.0
% INFO    : Bus 82001	: V=1.0188839, theta=-28.772867 -> V=1.0, theta=0.0
% INFO    : Bus 82002	: V=1.003011, theta=-32.846215 -> V=1.0, theta=0.0
% INFO    : Bus 82003	: V=1.0162413, theta=-24.830499 -> V=1.0, theta=0.0
% INFO    : Bus 82004	: V=1.0151626, theta=-25.166306 -> V=1.0, theta=0.0
% INFO    : Bus 82005	: V=1.0139581, theta=-50.00733 -> V=1.0, theta=0.0
% INFO    : Bus 82006	: V=1.0191859, theta=-22.805247 -> V=1.0, theta=0.0
% INFO    : Bus 82007	: V=1.0180766, theta=-23.103067 -> V=1.0, theta=0.0
% INFO    : Bus 82008	: V=1.000753, theta=-26.72539 -> V=1.0, theta=0.0
% INFO    : Bus 82009	: V=0.9989175, theta=-27.129864 -> V=1.0, theta=0.0
% INFO    : Bus 82010	: V=1.02, theta=-51.634552 -> V=1.0, theta=0.0
% INFO    : Bus 82011	: V=0.9728849, theta=-52.08731 -> V=1.0, theta=0.0
% INFO    : Bus 82012	: V=1.0196119, theta=-33.725914 -> V=1.0, theta=0.0
% INFO    : Bus 82013	: V=1.0146522, theta=-30.587061 -> V=1.0, theta=0.0
% INFO    : Bus 82014	: V=1.0175856, theta=-35.443645 -> V=1.0, theta=0.0
% INFO    : Bus 82015	: V=0.9829177, theta=-25.697985 -> V=1.0, theta=0.0
% INFO    : Bus 82016	: V=0.9823679, theta=-25.868727 -> V=1.0, theta=0.0
% INFO    : Bus 82017	: V=1.0087896, theta=-31.178424 -> V=1.0, theta=0.0
% INFO    : Bus 82018	: V=1.0080767, theta=-31.465304 -> V=1.0, theta=0.0
% INFO    : Bus 82019	: V=1.0100613, theta=-53.894005 -> V=1.0, theta=0.0
% INFO    : Bus 82020	: V=1.008746, theta=-54.048616 -> V=1.0, theta=0.0
% INFO    : Bus 82021	: V=1.0137819, theta=-35.447798 -> V=1.0, theta=0.0
% INFO    : Bus 82022	: V=1.0131897, theta=-35.621178 -> V=1.0, theta=0.0
% INFO    : Bus 82023	: V=0.99268, theta=-31.547375 -> V=1.0, theta=0.0
% INFO    : Bus 82024	: V=0.9931074, theta=-31.68176 -> V=1.0, theta=0.0
% INFO    : Bus 82025	: V=1.0151545, theta=-25.382674 -> V=1.0, theta=0.0
% INFO    : Bus 82026	: V=1.0124863, theta=-27.600204 -> V=1.0, theta=0.0
% INFO    : Bus 82027	: V=1.0129066, theta=-28.162761 -> V=1.0, theta=0.0
% INFO    : Bus 82028	: V=1.005974, theta=-41.623541 -> V=1.0, theta=0.0
% INFO    : Bus 82029	: V=0.9925308, theta=-30.460498 -> V=1.0, theta=0.0
% INFO    : Bus 82030	: V=0.9737627, theta=-62.080058 -> V=1.0, theta=0.0
% INFO    : Bus 82031	: V=1.0061654, theta=-50.297417 -> V=1.0, theta=0.0
% INFO    : Bus 82032	: V=1.0097045, theta=-24.974017 -> V=1.0, theta=0.0
% INFO    : Bus 82033	: V=1.0088997, theta=-25.124765 -> V=1.0, theta=0.0
% INFO    : Bus 82034	: V=0.9732181, theta=-40.278114 -> V=1.0, theta=0.0
% INFO    : Bus 82035	: V=1.0161805, theta=-45.90765 -> V=1.0, theta=0.0
% INFO    : Bus 82036	: V=1.0141954, theta=-46.335476 -> V=1.0, theta=0.0
% INFO    : Bus 82037	: V=1.0002661, theta=-27.124456 -> V=1.0, theta=0.0
% INFO    : Bus 82038	: V=0.9810019, theta=-37.552012 -> V=1.0, theta=0.0
% INFO    : Bus 82039	: V=0.9773987, theta=-31.507858 -> V=1.0, theta=0.0
% INFO    : Bus 82040	: V=0.9989944, theta=-26.944476 -> V=1.0, theta=0.0
% INFO    : Bus 82041	: V=0.9977644, theta=-27.093312 -> V=1.0, theta=0.0
% INFO    : Bus 82042	: V=0.9850333, theta=-47.507937 -> V=1.0, theta=0.0
% INFO    : Bus 82043	: V=0.9828836, theta=-47.962129 -> V=1.0, theta=0.0
% INFO    : Bus 82044	: V=0.9879637, theta=-45.400398 -> V=1.0, theta=0.0
% INFO    : Bus 82045	: V=0.985314, theta=-45.918531 -> V=1.0, theta=0.0
% INFO    : Bus 82046	: V=0.9767683, theta=-31.37342 -> V=1.0, theta=0.0
% INFO    : Bus 82047	: V=0.9772433, theta=-31.525088 -> V=1.0, theta=0.0
% INFO    : Bus 82048	: V=0.9874732, theta=-29.407478 -> V=1.0, theta=0.0
% INFO    : Bus 82049	: V=0.9659429, theta=-51.368625 -> V=1.0, theta=0.0
% INFO    : Bus 82050	: V=0.9761494, theta=-30.027856 -> V=1.0, theta=0.0
% INFO    : Bus 82051	: V=1.0031606, theta=-51.406584 -> V=1.0, theta=0.0
% INFO    : Bus 82052	: V=0.9848901, theta=-32.184406 -> V=1.0, theta=0.0
% INFO    : Bus 82053	: V=0.9890167, theta=-29.375096 -> V=1.0, theta=0.0
% INFO    : Bus 82054	: V=0.9664648, theta=-51.101815 -> V=1.0, theta=0.0
% INFO    : Bus 82055	: V=0.976527, theta=-27.502925 -> V=1.0, theta=0.0
% INFO    : Bus 82056	: V=0.9901267, theta=-46.292297 -> V=1.0, theta=0.0
% INFO    : Bus 82057	: V=0.9778247, theta=-49.281431 -> V=1.0, theta=0.0
% INFO    : Bus 82058	: V=0.99711, theta=-26.705224 -> V=1.0, theta=0.0
% INFO    : Bus 82059	: V=0.9898374, theta=-33.734094 -> V=1.0, theta=0.0
% INFO    : Bus 82060	: V=0.9655102, theta=-35.613141 -> V=1.0, theta=0.0
% INFO    : Bus 82061	: V=1.0068015, theta=-53.041153 -> V=1.0, theta=0.0
% INFO    : Bus 82062	: V=0.9473012, theta=-28.346156 -> V=1.0, theta=0.0
% INFO    : Bus 82063	: V=0.9485357, theta=-28.249011 -> V=1.0, theta=0.0
% INFO    : Bus 82064	: V=0.9349133, theta=-28.756265 -> V=1.0, theta=0.0
% INFO    : Bus 82065	: V=0.9310009, theta=-29.026407 -> V=1.0, theta=0.0
% INFO    : Bus 82066	: V=0.9467027, theta=-27.065636 -> V=1.0, theta=0.0
% INFO    : Bus 82067	: V=0.9470199, theta=-27.351895 -> V=1.0, theta=0.0
% INFO    : Bus 82068	: V=0.9411738, theta=-27.366112 -> V=1.0, theta=0.0
% INFO    : Bus 82069	: V=0.9386669, theta=-28.160025 -> V=1.0, theta=0.0
% INFO    : Bus 82070	: V=0.9299145, theta=-28.961672 -> V=1.0, theta=0.0
% INFO    : Bus 82071	: V=0.9259778, theta=-29.464796 -> V=1.0, theta=0.0
% INFO    : Bus 82072	: V=0.9353285, theta=-28.674432 -> V=1.0, theta=0.0
% INFO    : Bus 82073	: V=0.9387436, theta=-28.311781 -> V=1.0, theta=0.0
% INFO    : Bus 82074	: V=0.9310664, theta=-28.851351 -> V=1.0, theta=0.0
% INFO    : Bus 82075	: V=0.9323182, theta=-29.070955 -> V=1.0, theta=0.0
% INFO    : Bus 82076	: V=0.940983, theta=-27.408776 -> V=1.0, theta=0.0
% INFO    : Bus 82077	: V=0.9346052, theta=-28.824775 -> V=1.0, theta=0.0
% INFO    : Bus 82078	: V=0.9326716, theta=-28.628778 -> V=1.0, theta=0.0
% INFO    : Bus 82079	: V=0.9321677, theta=-30.084298 -> V=1.0, theta=0.0
% INFO    : Bus 82080	: V=0.9279452, theta=-29.690704 -> V=1.0, theta=0.0
% INFO    : Bus 82081	: V=0.9270914, theta=-29.948685 -> V=1.0, theta=0.0
% INFO    : Bus 82082	: V=0.9244592, theta=-29.12636 -> V=1.0, theta=0.0
% INFO    : Bus 82083	: V=0.9310263, theta=-29.286156 -> V=1.0, theta=0.0
% INFO    : Bus 82084	: V=0.9374477, theta=-27.261418 -> V=1.0, theta=0.0
% INFO    : Bus 82085	: V=0.9333788, theta=-28.452125 -> V=1.0, theta=0.0
% INFO    : Bus 82086	: V=0.9282436, theta=-29.504451 -> V=1.0, theta=0.0
% INFO    : Bus 82087	: V=0.9248805, theta=-29.894053 -> V=1.0, theta=0.0
% INFO    : Bus 82088	: V=0.9276804, theta=-29.614045 -> V=1.0, theta=0.0
% INFO    : Bus 82089	: V=0.9335253, theta=-28.87647 -> V=1.0, theta=0.0
% INFO    : Bus 82090	: V=0.9371873, theta=-28.73188 -> V=1.0, theta=0.0
% INFO    : Bus 82091	: V=0.9661521, theta=-26.961778 -> V=1.0, theta=0.0
% INFO    : Bus 82092	: V=0.9356388, theta=-28.590866 -> V=1.0, theta=0.0
% INFO    : Bus 82093	: V=0.9468666, theta=-27.195809 -> V=1.0, theta=0.0
% INFO    : Bus 82094	: V=0.9472122, theta=-27.675053 -> V=1.0, theta=0.0
% INFO    : Bus 82095	: V=0.9422721, theta=-28.201772 -> V=1.0, theta=0.0
% INFO    : Bus 82096	: V=0.9271968, theta=-29.598054 -> V=1.0, theta=0.0
% INFO    : Bus 82097	: V=0.9294467, theta=-28.817512 -> V=1.0, theta=0.0
% INFO    : Bus 82098	: V=0.9245042, theta=-29.298832 -> V=1.0, theta=0.0
% INFO    : Bus 82099	: V=0.9382685, theta=-28.683048 -> V=1.0, theta=0.0
% INFO    : Bus 82100	: V=0.9682215, theta=-26.356594 -> V=1.0, theta=0.0
% INFO    : Bus 82101	: V=0.9327446, theta=-28.474147 -> V=1.0, theta=0.0
% INFO    : Bus 82102	: V=0.9313888, theta=-28.727203 -> V=1.0, theta=0.0
% INFO    : Bus 82103	: V=0.9775011, theta=-18.245157 -> V=1.0, theta=0.0
% INFO    : Bus 82104	: V=0.9691101, theta=-19.655435 -> V=1.0, theta=0.0
% INFO    : Bus 82105	: V=0.9784054, theta=-18.151598 -> V=1.0, theta=0.0
% INFO    : Bus 82106	: V=0.9782082, theta=-18.174757 -> V=1.0, theta=0.0
% INFO    : Bus 82107	: V=0.969269, theta=-19.763716 -> V=1.0, theta=0.0
% INFO    : Bus 82108	: V=0.9643302, theta=-19.789701 -> V=1.0, theta=0.0
% INFO    : Bus 82109	: V=0.9725759, theta=-18.718911 -> V=1.0, theta=0.0
% INFO    : Bus 82110	: V=0.9651376, theta=-19.899127 -> V=1.0, theta=0.0
% INFO    : Bus 82111	: V=0.9763923, theta=-18.448118 -> V=1.0, theta=0.0
% INFO    : Bus 82112	: V=0.9721703, theta=-19.300746 -> V=1.0, theta=0.0
% INFO    : Bus 82113	: V=0.9501156, theta=-20.752489 -> V=1.0, theta=0.0
% INFO    : Bus 82114	: V=0.9781037, theta=-18.404314 -> V=1.0, theta=0.0
% INFO    : Bus 82115	: V=0.9765352, theta=-18.643796 -> V=1.0, theta=0.0
% INFO    : Bus 82116	: V=0.9938914, theta=1.945717 -> V=1.0, theta=0.0
% INFO    : Bus 82117	: V=0.9469333, theta=-24.99033 -> V=1.0, theta=0.0
% INFO    : Bus 82118	: V=0.9647516, theta=-13.555961 -> V=1.0, theta=0.0
% INFO    : Bus 82119	: V=0.9496206, theta=-15.779813 -> V=1.0, theta=0.0
% INFO    : Bus 82120	: V=0.9845908, theta=-15.75563 -> V=1.0, theta=0.0
% INFO    : Bus 82121	: V=0.9814875, theta=-16.838565 -> V=1.0, theta=0.0
% INFO    : Bus 82122	: V=0.9718824, theta=-18.349989 -> V=1.0, theta=0.0
% INFO    : Bus 82123	: V=0.9759396, theta=-11.564062 -> V=1.0, theta=0.0
% INFO    : Bus 82124	: V=0.9732114, theta=-10.756698 -> V=1.0, theta=0.0
% INFO    : Bus 82125	: V=0.9667287, theta=-11.918723 -> V=1.0, theta=0.0
% INFO    : Bus 82126	: V=0.9716725, theta=-11.417876 -> V=1.0, theta=0.0
% INFO    : Bus 82127	: V=0.9691297, theta=-12.258525 -> V=1.0, theta=0.0
% INFO    : Bus 82128	: V=0.9642319, theta=-10.467312 -> V=1.0, theta=0.0
% INFO    : Bus 82129	: V=0.9576502, theta=-13.44483 -> V=1.0, theta=0.0
% INFO    : Bus 82130	: V=0.9713618, theta=-12.957475 -> V=1.0, theta=0.0
% INFO    : Bus 82131	: V=0.9831936, theta=-11.161588 -> V=1.0, theta=0.0
% INFO    : Bus 82132	: V=0.9774263, theta=-12.053227 -> V=1.0, theta=0.0
% INFO    : Bus 82133	: V=0.9693718, theta=-13.603017 -> V=1.0, theta=0.0
% INFO    : Bus 82134	: V=1.0061182, theta=-16.161063 -> V=1.0, theta=0.0
% INFO    : Bus 82135	: V=0.9918488, theta=-17.98452 -> V=1.0, theta=0.0
% INFO    : Bus 82136	: V=1.0063162, theta=-16.156341 -> V=1.0, theta=0.0
% INFO    : Bus 82137	: V=0.9965992, theta=-17.692909 -> V=1.0, theta=0.0
% INFO    : Bus 82138	: V=0.9956212, theta=-17.687378 -> V=1.0, theta=0.0
% INFO    : Bus 82139	: V=1.0011921, theta=-17.232216 -> V=1.0, theta=0.0
% INFO    : Bus 82140	: V=0.9982449, theta=-17.406068 -> V=1.0, theta=0.0
% INFO    : Bus 82141	: V=0.9978197, theta=-17.496631 -> V=1.0, theta=0.0
% INFO    : Bus 82142	: V=0.9969264, theta=-17.589774 -> V=1.0, theta=0.0
% INFO    : Bus 82143	: V=0.9924803, theta=-17.419081 -> V=1.0, theta=0.0
% INFO    : Bus 82144	: V=1.0066979, theta=-16.402205 -> V=1.0, theta=0.0
% INFO    : Bus 82145	: V=1.0027696, theta=-16.965043 -> V=1.0, theta=0.0
% INFO    : Bus 82146	: V=0.9527244, theta=-14.475063 -> V=1.0, theta=0.0
% INFO    : Bus 82147	: V=0.9451979, theta=-15.45259 -> V=1.0, theta=0.0
% INFO    : Bus 82148	: V=0.9472471, theta=-15.443319 -> V=1.0, theta=0.0
% INFO    : Bus 82149	: V=0.9465836, theta=-15.350439 -> V=1.0, theta=0.0
% INFO    : Bus 82150	: V=0.9999511, theta=-14.475239 -> V=1.0, theta=0.0
% INFO    : Bus 82151	: V=1.0082971, theta=-13.005218 -> V=1.0, theta=0.0
% INFO    : Bus 82152	: V=1.006749, theta=-13.389355 -> V=1.0, theta=0.0
% INFO    : Bus 82153	: V=0.9981962, theta=-9.295455 -> V=1.0, theta=0.0
% INFO    : Bus 82154	: V=1.0128252, theta=-6.08191 -> V=1.0, theta=0.0
% INFO    : Bus 82155	: V=1.0069135, theta=-7.607045 -> V=1.0, theta=0.0
% INFO    : Bus 82156	: V=1.0130256, theta=-20.170767 -> V=1.0, theta=0.0
% INFO    : Bus 82157	: V=1.0122015, theta=-20.278032 -> V=1.0, theta=0.0
% INFO    : Bus 82158	: V=0.9917878, theta=-22.739451 -> V=1.0, theta=0.0
% INFO    : Bus 82159	: V=0.9987094, theta=-20.764787 -> V=1.0, theta=0.0
% INFO    : Bus 82160	: V=0.9483175, theta=-24.634964 -> V=1.0, theta=0.0
% INFO    : Bus 82161	: V=0.9534231, theta=-23.584581 -> V=1.0, theta=0.0
% INFO    : Bus 82162	: V=0.9584205, theta=-22.521083 -> V=1.0, theta=0.0
% INFO    : Bus 82163	: V=0.927522, theta=-29.959228 -> V=1.0, theta=0.0
% INFO    : Bus 82164	: V=0.9378712, theta=-29.43037 -> V=1.0, theta=0.0
% INFO    : Bus 82165	: V=0.9307809, theta=-28.274271 -> V=1.0, theta=0.0
% INFO    : Bus 82166	: V=0.9280974, theta=-28.462916 -> V=1.0, theta=0.0
% INFO    : Bus 82167	: V=0.9231806, theta=-28.52151 -> V=1.0, theta=0.0
% INFO    : Bus 82168	: V=0.9337619, theta=-29.840441 -> V=1.0, theta=0.0
% INFO    : Bus 82169	: V=0.9555902, theta=-23.567814 -> V=1.0, theta=0.0
% INFO    : Bus 82170	: V=0.9527028, theta=-24.200157 -> V=1.0, theta=0.0
% INFO    : Bus 82171	: V=0.9558694, theta=-23.443991 -> V=1.0, theta=0.0
% INFO    : Bus 82172	: V=0.9523629, theta=-24.120979 -> V=1.0, theta=0.0
% INFO    : Bus 82173	: V=0.9562195, theta=-23.427117 -> V=1.0, theta=0.0
% INFO    : Bus 82174	: V=0.9540957, theta=-23.869349 -> V=1.0, theta=0.0
% INFO    : Bus 82175	: V=0.9527153, theta=-23.939127 -> V=1.0, theta=0.0
% INFO    : Bus 82176	: V=0.9531216, theta=-24.005651 -> V=1.0, theta=0.0
% INFO    : Bus 82177	: V=0.9551736, theta=-23.817927 -> V=1.0, theta=0.0
% INFO    : Bus 82178	: V=0.9489986, theta=-24.634837 -> V=1.0, theta=0.0
% INFO    : Bus 82179	: V=0.9558026, theta=-23.474482 -> V=1.0, theta=0.0
% INFO    : Bus 82180	: V=0.9512162, theta=-24.552793 -> V=1.0, theta=0.0
% INFO    : Bus 82181	: V=0.9561861, theta=-23.479819 -> V=1.0, theta=0.0
% INFO    : Bus 82182	: V=0.9617368, theta=-22.456554 -> V=1.0, theta=0.0
% INFO    : Bus 82183	: V=0.9595216, theta=-22.816503 -> V=1.0, theta=0.0
% INFO    : Bus 82184	: V=0.9570193, theta=-23.211481 -> V=1.0, theta=0.0
% INFO    : Bus 82185	: V=0.9505837, theta=-24.284455 -> V=1.0, theta=0.0
% INFO    : Bus 82186	: V=0.9513151, theta=-23.996078 -> V=1.0, theta=0.0
% INFO    : Bus 82187	: V=0.9598067, theta=-24.403392 -> V=1.0, theta=0.0
% INFO    : Bus 82188	: V=0.950754, theta=-24.097132 -> V=1.0, theta=0.0
% INFO    : Bus 82189	: V=1.0037483, theta=-10.443038 -> V=1.0, theta=0.0
% INFO    : Bus 82190	: V=0.9905364, theta=-13.010708 -> V=1.0, theta=0.0
% INFO    : Bus 82191	: V=1.006462, theta=-10.262536 -> V=1.0, theta=0.0
% INFO    : Bus 82192	: V=1.0040825, theta=-10.459605 -> V=1.0, theta=0.0
% INFO    : Bus 82193	: V=0.9196665, theta=-17.613062 -> V=1.0, theta=0.0
% INFO    : Bus 82194	: V=0.9119363, theta=-19.938656 -> V=1.0, theta=0.0
% INFO    : Bus 82195	: V=0.9202572, theta=-19.201158 -> V=1.0, theta=0.0
% INFO    : Bus 82196	: V=0.9391511, theta=-17.580712 -> V=1.0, theta=0.0
% INFO    : Bus 82197	: V=0.9373555, theta=-14.614301 -> V=1.0, theta=0.0
% INFO    : Bus 82198	: V=0.9602508, theta=-11.246556 -> V=1.0, theta=0.0
% INFO    : Bus 82199	: V=0.9484282, theta=-12.803791 -> V=1.0, theta=0.0
% INFO    : Bus 82200	: V=0.9341657, theta=-14.677048 -> V=1.0, theta=0.0
% INFO    : Bus 82201	: V=0.9353869, theta=-14.68698 -> V=1.0, theta=0.0
% INFO    : Bus 82202	: V=0.9409632, theta=-13.53558 -> V=1.0, theta=0.0
% INFO    : Bus 82203	: V=0.9401153, theta=-14.156113 -> V=1.0, theta=0.0
% INFO    : Bus 82204	: V=0.9342675, theta=-15.05465 -> V=1.0, theta=0.0
% INFO    : Bus 82205	: V=0.9341833, theta=-15.232875 -> V=1.0, theta=0.0
% INFO    : Bus 82206	: V=0.9368195, theta=-14.572825 -> V=1.0, theta=0.0
% INFO    : Bus 82207	: V=0.9324007, theta=-15.586268 -> V=1.0, theta=0.0
% INFO    : Bus 82208	: V=0.9270502, theta=-15.868727 -> V=1.0, theta=0.0
% INFO    : Bus 82209	: V=0.9419176, theta=-13.749328 -> V=1.0, theta=0.0
% INFO    : Bus 82210	: V=0.9287196, theta=-15.266551 -> V=1.0, theta=0.0
% INFO    : Bus 82211	: V=0.9692526, theta=-25.404831 -> V=1.0, theta=0.0
% INFO    : Bus 82212	: V=0.9631519, theta=-25.716766 -> V=1.0, theta=0.0
% INFO    : Bus 82213	: V=0.9671965, theta=-25.534998 -> V=1.0, theta=0.0
% INFO    : Bus 82214	: V=0.9697783, theta=-25.289008 -> V=1.0, theta=0.0
% INFO    : Bus 82215	: V=0.9649254, theta=-25.286951 -> V=1.0, theta=0.0
% INFO    : Bus 82216	: V=0.9961015, theta=-17.31734 -> V=1.0, theta=0.0
% INFO    : Bus 82217	: V=0.9966448, theta=-17.203469 -> V=1.0, theta=0.0
% INFO    : Bus 82218	: V=1.0069075, theta=-16.161538 -> V=1.0, theta=0.0
% INFO    : Bus 82219	: V=1.0043072, theta=-16.356214 -> V=1.0, theta=0.0
% INFO    : Bus 82220	: V=1.0005097, theta=-16.845659 -> V=1.0, theta=0.0
% INFO    : Bus 82221	: V=1.0051752, theta=-16.43797 -> V=1.0, theta=0.0
% INFO    : Bus 82222	: V=1.0019361, theta=-17.000534 -> V=1.0, theta=0.0
% INFO    : Bus 82223	: V=1.0005415, theta=-16.750932 -> V=1.0, theta=0.0
% INFO    : Bus 82224	: V=1.001216, theta=-16.987547 -> V=1.0, theta=0.0
% INFO    : Bus 82225	: V=1.0009323, theta=-17.011754 -> V=1.0, theta=0.0
% INFO    : Bus 82226	: V=1.0002591, theta=-17.030279 -> V=1.0, theta=0.0
% INFO    : Bus 82227	: V=1.0048615, theta=-15.707448 -> V=1.0, theta=0.0
% INFO    : Bus 82228	: V=1.0111409, theta=-15.364681 -> V=1.0, theta=0.0
% INFO    : Bus 82229	: V=0.9929797, theta=-3.003971 -> V=1.0, theta=0.0
% INFO    : Bus 82230	: V=0.9835503, theta=-3.487827 -> V=1.0, theta=0.0
% INFO    : Bus 82231	: V=0.9952858, theta=-3.735769 -> V=1.0, theta=0.0
% INFO    : Bus 82232	: V=1.0125931, theta=-1.348567 -> V=1.0, theta=0.0
% INFO    : Bus 82233	: V=0.9758669, theta=-25.151617 -> V=1.0, theta=0.0
% INFO    : Bus 82234	: V=0.9423354, theta=-13.659226 -> V=1.0, theta=0.0
% INFO    : Bus 82235	: V=0.9512973, theta=-14.098702 -> V=1.0, theta=0.0
% INFO    : Bus 82236	: V=0.9877778, theta=-10.607808 -> V=1.0, theta=0.0
% INFO    : Bus 82237	: V=0.9933206, theta=-10.44678 -> V=1.0, theta=0.0
% INFO    : Bus 82238	: V=0.9426292, theta=-22.348587 -> V=1.0, theta=0.0
% INFO    : Bus 82239	: V=0.9372595, theta=-22.907549 -> V=1.0, theta=0.0
% INFO    : Bus 82240	: V=0.9513912, theta=-20.706404 -> V=1.0, theta=0.0
% INFO    : Bus 82241	: V=0.9465681, theta=-21.699121 -> V=1.0, theta=0.0
% INFO    : Bus 82242	: V=0.9498789, theta=-23.291132 -> V=1.0, theta=0.0
% INFO    : Bus 82243	: V=0.9538294, theta=-20.806281 -> V=1.0, theta=0.0
% INFO    : Bus 82244	: V=0.9526089, theta=-20.835588 -> V=1.0, theta=0.0
% INFO    : Bus 82245	: V=0.9503475, theta=-21.348027 -> V=1.0, theta=0.0
% INFO    : Bus 82246	: V=1.0155362, theta=-8.4484 -> V=1.0, theta=0.0
% INFO    : Bus 82247	: V=1.0124372, theta=-8.420233 -> V=1.0, theta=0.0
% INFO    : Bus 82248	: V=1.0099517, theta=-9.022478 -> V=1.0, theta=0.0
% INFO    : Bus 82249	: V=0.972001, theta=-18.566048 -> V=1.0, theta=0.0
% INFO    : Bus 82250	: V=0.9736808, theta=-16.970323 -> V=1.0, theta=0.0
% INFO    : Bus 82251	: V=0.970355, theta=-17.031721 -> V=1.0, theta=0.0
% INFO    : Bus 82252	: V=0.9712743, theta=-17.999662 -> V=1.0, theta=0.0
% INFO    : Bus 82253	: V=0.9780759, theta=-17.2172 -> V=1.0, theta=0.0
% INFO    : Bus 82254	: V=0.9764972, theta=-17.426313 -> V=1.0, theta=0.0
% INFO    : Bus 82255	: V=0.9733783, theta=-17.995005 -> V=1.0, theta=0.0
% INFO    : Bus 82256	: V=0.9678225, theta=-18.769745 -> V=1.0, theta=0.0
% INFO    : Bus 82257	: V=0.9700097, theta=-18.768089 -> V=1.0, theta=0.0
% INFO    : Bus 82258	: V=0.9645529, theta=-19.344542 -> V=1.0, theta=0.0
% INFO    : Bus 82259	: V=0.9834165, theta=-16.370783 -> V=1.0, theta=0.0
% INFO    : Bus 82260	: V=0.9795598, theta=-16.945294 -> V=1.0, theta=0.0
% INFO    : Bus 82261	: V=0.9775084, theta=-17.270639 -> V=1.0, theta=0.0
% INFO    : Bus 82262	: V=0.9746081, theta=-17.801624 -> V=1.0, theta=0.0
% INFO    : Bus 82263	: V=0.9740284, theta=-18.087366 -> V=1.0, theta=0.0
% INFO    : Bus 82264	: V=0.9732694, theta=-18.149099 -> V=1.0, theta=0.0
% INFO    : Bus 82265	: V=0.9800693, theta=-16.896839 -> V=1.0, theta=0.0
% INFO    : Bus 82266	: V=0.9758511, theta=-17.608618 -> V=1.0, theta=0.0
% INFO    : Bus 82267	: V=0.972277, theta=-17.718799 -> V=1.0, theta=0.0
% INFO    : Bus 82268	: V=0.979585, theta=-17.040689 -> V=1.0, theta=0.0
% INFO    : Bus 82269	: V=0.9770428, theta=-17.506196 -> V=1.0, theta=0.0
% INFO    : Bus 82270	: V=0.9780526, theta=-17.328364 -> V=1.0, theta=0.0
% INFO    : Bus 82271	: V=0.9467177, theta=-23.424931 -> V=1.0, theta=0.0
% INFO    : Bus 82272	: V=0.9405382, theta=-24.178304 -> V=1.0, theta=0.0
% INFO    : Bus 82273	: V=0.9343506, theta=-24.682758 -> V=1.0, theta=0.0
% INFO    : Bus 82274	: V=1.0094848, theta=-14.394556 -> V=1.0, theta=0.0
% INFO    : Bus 82275	: V=1.0060671, theta=-14.805767 -> V=1.0, theta=0.0
% INFO    : Bus 82276	: V=1.0101445, theta=-14.089707 -> V=1.0, theta=0.0
% INFO    : Bus 82277	: V=1.0072341, theta=-14.505355 -> V=1.0, theta=0.0
% INFO    : Bus 82278	: V=0.9826521, theta=-16.460858 -> V=1.0, theta=0.0
% INFO    : Bus 82279	: V=0.9826507, theta=-16.606966 -> V=1.0, theta=0.0
% INFO    : Bus 82280	: V=0.9947764, theta=-13.889043 -> V=1.0, theta=0.0
% INFO    : Bus 82281	: V=0.9917315, theta=-14.493655 -> V=1.0, theta=0.0
% INFO    : Bus 82282	: V=0.9594542, theta=-16.322769 -> V=1.0, theta=0.0
% INFO    : Bus 82283	: V=0.9540052, theta=-18.057765 -> V=1.0, theta=0.0
% INFO    : Bus 82284	: V=0.9567931, theta=-18.577591 -> V=1.0, theta=0.0
% INFO    : Bus 82285	: V=0.9518446, theta=-19.076879 -> V=1.0, theta=0.0
% INFO    : Bus 82286	: V=0.9627647, theta=-18.506276 -> V=1.0, theta=0.0
% INFO    : Bus 82287	: V=0.9590354, theta=-18.521468 -> V=1.0, theta=0.0
% INFO    : Bus 82288	: V=0.9634899, theta=-16.201488 -> V=1.0, theta=0.0
% INFO    : Bus 82289	: V=0.9529743, theta=-23.498675 -> V=1.0, theta=0.0
% INFO    : Bus 82290	: V=0.9477377, theta=-25.122099 -> V=1.0, theta=0.0
% INFO    : Bus 82291	: V=0.9480331, theta=-25.267754 -> V=1.0, theta=0.0
% INFO    : Bus 82292	: V=0.9616945, theta=-15.5696 -> V=1.0, theta=0.0
% INFO    : Bus 82293	: V=0.9518462, theta=-17.400782 -> V=1.0, theta=0.0
% INFO    : Bus 82294	: V=0.9469825, theta=-17.844958 -> V=1.0, theta=0.0
% INFO    : Bus 82295	: V=0.9590231, theta=-16.523422 -> V=1.0, theta=0.0
% INFO    : Bus 82296	: V=0.9555392, theta=-17.369549 -> V=1.0, theta=0.0
% INFO    : Bus 82297	: V=0.9507983, theta=-17.997693 -> V=1.0, theta=0.0
% INFO    : Bus 82298	: V=0.934865, theta=-23.975913 -> V=1.0, theta=0.0
% INFO    : Bus 82299	: V=0.9385738, theta=-24.030594 -> V=1.0, theta=0.0
% INFO    : Bus 82300	: V=0.9426095, theta=-21.600592 -> V=1.0, theta=0.0
% INFO    : Bus 82301	: V=0.9403781, theta=-22.79894 -> V=1.0, theta=0.0
% INFO    : Bus 82302	: V=0.94574, theta=-20.286214 -> V=1.0, theta=0.0
% INFO    : Bus 82303	: V=0.9592382, theta=-19.726174 -> V=1.0, theta=0.0
% INFO    : Bus 82304	: V=0.9583676, theta=-19.788798 -> V=1.0, theta=0.0
% INFO    : Bus 82305	: V=0.9600991, theta=-19.545758 -> V=1.0, theta=0.0
% INFO    : Bus 82306	: V=0.9723783, theta=-17.663531 -> V=1.0, theta=0.0
% INFO    : Bus 82307	: V=0.9681384, theta=-18.203407 -> V=1.0, theta=0.0
% INFO    : Bus 82308	: V=0.955761, theta=1.224122 -> V=1.0, theta=0.0
% INFO    : Bus 82309	: V=0.967116, theta=-1.540676 -> V=1.0, theta=0.0
% INFO    : Bus 82310	: V=0.96619, theta=0.899528 -> V=1.0, theta=0.0
% INFO    : Bus 82311	: V=0.981777, theta=0.970992 -> V=1.0, theta=0.0
% INFO    : Bus 82312	: V=0.9738876, theta=-2.7836 -> V=1.0, theta=0.0
% INFO    : Bus 82313	: V=0.973485, theta=-3.473953 -> V=1.0, theta=0.0
% INFO    : Bus 82314	: V=0.9890121, theta=0.604809 -> V=1.0, theta=0.0
% INFO    : Bus 82315	: V=0.9864585, theta=-0.410181 -> V=1.0, theta=0.0
% INFO    : Bus 82316	: V=0.9622042, theta=-25.443902 -> V=1.0, theta=0.0
% INFO    : Bus 82317	: V=0.961901, theta=-26.128547 -> V=1.0, theta=0.0
% INFO    : Bus 82318	: V=0.9596443, theta=-26.791721 -> V=1.0, theta=0.0
% INFO    : Bus 82319	: V=0.9523043, theta=-27.394415 -> V=1.0, theta=0.0
% INFO    : Bus 82320	: V=0.955861, theta=-26.512262 -> V=1.0, theta=0.0
% INFO    : Bus 82321	: V=0.9508698, theta=-27.331887 -> V=1.0, theta=0.0
% INFO    : Bus 82322	: V=0.9595109, theta=-25.051643 -> V=1.0, theta=0.0
% INFO    : Bus 82323	: V=0.9996157, theta=-17.964681 -> V=1.0, theta=0.0
% INFO    : Bus 82324	: V=0.9941899, theta=-16.813137 -> V=1.0, theta=0.0
% INFO    : Bus 82325	: V=1.0094203, theta=-15.024379 -> V=1.0, theta=0.0
% INFO    : Bus 82326	: V=0.9511506, theta=-21.80444 -> V=1.0, theta=0.0
% INFO    : Bus 82327	: V=0.9612038, theta=-20.786258 -> V=1.0, theta=0.0
% INFO    : Bus 82328	: V=0.9521981, theta=-21.252571 -> V=1.0, theta=0.0
% INFO    : Bus 82329	: V=0.9723107, theta=-18.433422 -> V=1.0, theta=0.0
% INFO    : Bus 82330	: V=0.9666531, theta=-19.283118 -> V=1.0, theta=0.0
% INFO    : Bus 82331	: V=0.9574159, theta=-20.171835 -> V=1.0, theta=0.0
% INFO    : Bus 82332	: V=0.9654387, theta=-19.577457 -> V=1.0, theta=0.0
% INFO    : Bus 82333	: V=1.0098021, theta=-8.858127 -> V=1.0, theta=0.0
% INFO    : Bus 82334	: V=0.9805423, theta=-9.498578 -> V=1.0, theta=0.0
% INFO    : Bus 82335	: V=0.9298003, theta=-19.939552 -> V=1.0, theta=0.0
% INFO    : Bus 82336	: V=0.9219268, theta=-18.576196 -> V=1.0, theta=0.0
% INFO    : Bus 82337	: V=0.9302391, theta=-21.238707 -> V=1.0, theta=0.0
% INFO    : Bus 82338	: V=0.9350296, theta=-19.602345 -> V=1.0, theta=0.0
% INFO    : Bus 82339	: V=0.9347774, theta=-20.129632 -> V=1.0, theta=0.0
% INFO    : Bus 82340	: V=0.9293066, theta=-21.187439 -> V=1.0, theta=0.0
% INFO    : Bus 82341	: V=0.9454204, theta=-17.706203 -> V=1.0, theta=0.0
% INFO    : Bus 82342	: V=0.9328668, theta=-19.671227 -> V=1.0, theta=0.0
% INFO    : Bus 82343	: V=0.9179017, theta=-21.858996 -> V=1.0, theta=0.0
% INFO    : Bus 82344	: V=0.9233088, theta=-20.567588 -> V=1.0, theta=0.0
% INFO    : Bus 82345	: V=0.9176417, theta=-21.447698 -> V=1.0, theta=0.0
% INFO    : Bus 82346	: V=0.9660088, theta=7.625526 -> V=1.0, theta=0.0
% INFO    : Bus 82347	: V=0.9642034, theta=7.210348 -> V=1.0, theta=0.0
% INFO    : Bus 82348	: V=0.9682949, theta=6.994996 -> V=1.0, theta=0.0
% INFO    : Bus 82349	: V=0.9643361, theta=6.106133 -> V=1.0, theta=0.0
% INFO    : Bus 82350	: V=0.962656, theta=7.61152 -> V=1.0, theta=0.0
% INFO    : Bus 82351	: V=0.955628, theta=6.211927 -> V=1.0, theta=0.0
% INFO    : Bus 82352	: V=0.9619107, theta=6.180639 -> V=1.0, theta=0.0
% INFO    : Bus 82353	: V=0.961654, theta=5.558666 -> V=1.0, theta=0.0
% INFO    : Bus 82354	: V=0.9578464, theta=5.167164 -> V=1.0, theta=0.0
% INFO    : Bus 82355	: V=0.9573352, theta=4.31341 -> V=1.0, theta=0.0
% INFO    : Bus 82356	: V=0.9597017, theta=5.308275 -> V=1.0, theta=0.0
% INFO    : Bus 82357	: V=0.9612876, theta=5.911212 -> V=1.0, theta=0.0
% INFO    : Bus 82358	: V=0.9630356, theta=8.151764 -> V=1.0, theta=0.0
% INFO    : Bus 82359	: V=0.9513194, theta=6.532802 -> V=1.0, theta=0.0
% INFO    : Bus 82360	: V=0.9531997, theta=6.165501 -> V=1.0, theta=0.0
% INFO    : Bus 82361	: V=0.9523864, theta=6.051175 -> V=1.0, theta=0.0
% INFO    : Bus 82362	: V=0.9520491, theta=6.037743 -> V=1.0, theta=0.0
% INFO    : Bus 82363	: V=0.9587056, theta=7.7905 -> V=1.0, theta=0.0
% INFO    : Bus 82364	: V=0.9605966, theta=7.81731 -> V=1.0, theta=0.0
% INFO    : Bus 82365	: V=0.9610427, theta=8.206583 -> V=1.0, theta=0.0
% INFO    : Bus 82366	: V=0.959695, theta=7.82495 -> V=1.0, theta=0.0
% INFO    : Bus 82367	: V=0.9542523, theta=6.856045 -> V=1.0, theta=0.0
% INFO    : Bus 82368	: V=0.957306, theta=7.049676 -> V=1.0, theta=0.0
% INFO    : Bus 82369	: V=0.9445465, theta=5.326998 -> V=1.0, theta=0.0
% INFO    : Bus 82370	: V=0.9501608, theta=5.751101 -> V=1.0, theta=0.0
% INFO    : Bus 82371	: V=0.9629709, theta=7.046283 -> V=1.0, theta=0.0
% INFO    : Bus 82372	: V=0.9574546, theta=6.175877 -> V=1.0, theta=0.0
% INFO    : Bus 82373	: V=0.9557215, theta=5.806442 -> V=1.0, theta=0.0
% INFO    : Bus 82374	: V=0.9537637, theta=5.182098 -> V=1.0, theta=0.0
% INFO    : Bus 82375	: V=0.9522495, theta=5.033417 -> V=1.0, theta=0.0
% INFO    : Bus 82376	: V=0.9478387, theta=4.048195 -> V=1.0, theta=0.0
% INFO    : Bus 82377	: V=0.9492316, theta=4.700019 -> V=1.0, theta=0.0
% INFO    : Bus 82378	: V=0.9508233, theta=5.581394 -> V=1.0, theta=0.0
% INFO    : Bus 82379	: V=0.9601236, theta=6.876339 -> V=1.0, theta=0.0
% INFO    : Bus 82380	: V=0.9565321, theta=6.059459 -> V=1.0, theta=0.0
% INFO    : Bus 82381	: V=0.9438341, theta=5.12986 -> V=1.0, theta=0.0
% INFO    : Bus 82382	: V=0.9442059, theta=3.897965 -> V=1.0, theta=0.0
% INFO    : Bus 82383	: V=0.9475485, theta=3.938015 -> V=1.0, theta=0.0
% INFO    : Bus 82384	: V=0.9415475, theta=2.158567 -> V=1.0, theta=0.0
% INFO    : Bus 82385	: V=0.9479157, theta=1.437577 -> V=1.0, theta=0.0
% INFO    : Bus 82386	: V=0.971604, theta=2.582115 -> V=1.0, theta=0.0
% INFO    : Bus 82387	: V=0.969111, theta=1.669332 -> V=1.0, theta=0.0
% INFO    : Bus 82388	: V=0.972055, theta=1.824108 -> V=1.0, theta=0.0
% INFO    : Bus 82389	: V=0.9721489, theta=1.475297 -> V=1.0, theta=0.0
% INFO    : Bus 82390	: V=0.9646693, theta=0.40503 -> V=1.0, theta=0.0
% INFO    : Bus 82391	: V=0.9577107, theta=-2.870069 -> V=1.0, theta=0.0
% INFO    : Bus 82392	: V=0.9557966, theta=-2.632525 -> V=1.0, theta=0.0
% INFO    : Bus 82393	: V=0.9644346, theta=0.114505 -> V=1.0, theta=0.0
% INFO    : Bus 82394	: V=0.9591967, theta=-0.252625 -> V=1.0, theta=0.0
% INFO    : Bus 82395	: V=0.9602677, theta=-0.369094 -> V=1.0, theta=0.0
% INFO    : Bus 82396	: V=0.9568004, theta=-0.058718 -> V=1.0, theta=0.0
% INFO    : Bus 82397	: V=0.9512878, theta=-3.132804 -> V=1.0, theta=0.0
% INFO    : Bus 82398	: V=0.9829329, theta=-15.216181 -> V=1.0, theta=0.0
% INFO    : Bus 82399	: V=0.9795692, theta=-13.928177 -> V=1.0, theta=0.0
% INFO    : Bus 82400	: V=0.9926002, theta=-13.758171 -> V=1.0, theta=0.0
% INFO    : Bus 82401	: V=0.9836596, theta=-14.678469 -> V=1.0, theta=0.0
% INFO    : Bus 82402	: V=0.9610148, theta=-21.303873 -> V=1.0, theta=0.0
% INFO    : Bus 82403	: V=0.9618946, theta=-21.25601 -> V=1.0, theta=0.0
% INFO    : Bus 82404	: V=0.9623022, theta=-21.736392 -> V=1.0, theta=0.0
% INFO    : Bus 82405	: V=0.9617579, theta=-21.174346 -> V=1.0, theta=0.0
% INFO    : Bus 82406	: V=0.955471, theta=-20.66858 -> V=1.0, theta=0.0
% INFO    : Bus 82407	: V=0.9599886, theta=-20.894148 -> V=1.0, theta=0.0
% INFO    : Bus 82408	: V=0.9534748, theta=-22.007106 -> V=1.0, theta=0.0
% INFO    : Bus 82409	: V=0.9611991, theta=-20.83872 -> V=1.0, theta=0.0
% INFO    : Bus 82410	: V=0.9659241, theta=-19.897433 -> V=1.0, theta=0.0
% INFO    : Bus 82411	: V=0.954693, theta=-22.882515 -> V=1.0, theta=0.0
% INFO    : Bus 82412	: V=0.990235, theta=-15.429635 -> V=1.0, theta=0.0
% INFO    : Bus 82413	: V=0.9845257, theta=-16.268845 -> V=1.0, theta=0.0
% INFO    : Bus 82414	: V=0.977987, theta=-17.303801 -> V=1.0, theta=0.0
% INFO    : Bus 82415	: V=0.9792371, theta=-17.009644 -> V=1.0, theta=0.0
% INFO    : Bus 82416	: V=0.9747363, theta=-17.497003 -> V=1.0, theta=0.0
% INFO    : Bus 82417	: V=0.970394, theta=-17.987682 -> V=1.0, theta=0.0
% INFO    : Bus 82418	: V=0.9806725, theta=-16.842907 -> V=1.0, theta=0.0
% INFO    : Bus 82419	: V=0.974274, theta=-17.519772 -> V=1.0, theta=0.0
% INFO    : Bus 82420	: V=0.9726019, theta=-17.594094 -> V=1.0, theta=0.0
% INFO    : Bus 82421	: V=0.9776922, theta=-17.401734 -> V=1.0, theta=0.0
% INFO    : Bus 82422	: V=0.9812578, theta=-16.788006 -> V=1.0, theta=0.0
% INFO    : Bus 82423	: V=0.9714151, theta=-18.286551 -> V=1.0, theta=0.0
% INFO    : Bus 82424	: V=0.9703103, theta=-18.544965 -> V=1.0, theta=0.0
% INFO    : Bus 82425	: V=0.9752779, theta=-17.590951 -> V=1.0, theta=0.0
% INFO    : Bus 82426	: V=0.9717083, theta=-18.044506 -> V=1.0, theta=0.0
% INFO    : Bus 82427	: V=0.9694786, theta=-18.336481 -> V=1.0, theta=0.0
% INFO    : Bus 82428	: V=0.9686827, theta=-18.406865 -> V=1.0, theta=0.0
% INFO    : Bus 82429	: V=0.9715834, theta=-18.151452 -> V=1.0, theta=0.0
% INFO    : Bus 82430	: V=0.9710025, theta=-18.157323 -> V=1.0, theta=0.0
% INFO    : Bus 82431	: V=0.9713124, theta=-18.285452 -> V=1.0, theta=0.0
% INFO    : Bus 82432	: V=0.9709759, theta=-18.28096 -> V=1.0, theta=0.0
% INFO    : Bus 82433	: V=0.9704971, theta=-18.215864 -> V=1.0, theta=0.0
% INFO    : Bus 82434	: V=0.9693503, theta=-18.331474 -> V=1.0, theta=0.0
% INFO    : Bus 82435	: V=0.9677291, theta=-18.538065 -> V=1.0, theta=0.0
% INFO    : Bus 82436	: V=0.9740024, theta=-17.959627 -> V=1.0, theta=0.0
% INFO    : Bus 82437	: V=0.9699441, theta=-18.648918 -> V=1.0, theta=0.0
% INFO    : Bus 82438	: V=0.9735145, theta=-17.97117 -> V=1.0, theta=0.0
% INFO    : Bus 82439	: V=0.967955, theta=-18.791795 -> V=1.0, theta=0.0
% INFO    : Bus 82440	: V=0.9508839, theta=-20.191029 -> V=1.0, theta=0.0
% INFO    : Bus 82441	: V=0.9831949, theta=-16.453124 -> V=1.0, theta=0.0
% INFO    : Bus 82442	: V=0.978224, theta=-17.189987 -> V=1.0, theta=0.0
% INFO    : Bus 82443	: V=0.9830211, theta=-16.564624 -> V=1.0, theta=0.0
% INFO    : Bus 82444	: V=0.981666, theta=-16.841168 -> V=1.0, theta=0.0
% INFO    : Bus 82445	: V=0.977039, theta=-17.126922 -> V=1.0, theta=0.0
% INFO    : Bus 82446	: V=0.9845852, theta=-16.289411 -> V=1.0, theta=0.0
% INFO    : Bus 82447	: V=0.9725674, theta=-17.952613 -> V=1.0, theta=0.0
% INFO    : Bus 82448	: V=0.9713758, theta=-18.003139 -> V=1.0, theta=0.0
% INFO    : Bus 82449	: V=0.9684511, theta=-18.122741 -> V=1.0, theta=0.0
% INFO    : Bus 82450	: V=0.9759944, theta=-17.828617 -> V=1.0, theta=0.0
% INFO    : Bus 82451	: V=0.983327, theta=-16.777498 -> V=1.0, theta=0.0
% INFO    : Bus 82452	: V=0.9770903, theta=-17.272392 -> V=1.0, theta=0.0
% INFO    : Bus 82453	: V=0.9914743, theta=-15.047453 -> V=1.0, theta=0.0
% INFO    : Bus 82454	: V=0.9816098, theta=-16.614079 -> V=1.0, theta=0.0
% INFO    : Bus 82455	: V=0.9818847, theta=-16.668093 -> V=1.0, theta=0.0
% INFO    : Bus 82456	: V=0.9777376, theta=-17.375033 -> V=1.0, theta=0.0
% INFO    : Bus 82457	: V=0.9905432, theta=-15.566467 -> V=1.0, theta=0.0
% INFO    : Bus 82458	: V=0.9856429, theta=-16.526255 -> V=1.0, theta=0.0
% INFO    : Bus 82459	: V=0.9839685, theta=-16.669587 -> V=1.0, theta=0.0
% INFO    : Bus 82460	: V=0.9705144, theta=-18.270866 -> V=1.0, theta=0.0
% INFO    : Bus 82461	: V=0.9686474, theta=-18.379223 -> V=1.0, theta=0.0
% INFO    : Bus 82462	: V=0.9704325, theta=-18.399366 -> V=1.0, theta=0.0
% INFO    : Bus 82463	: V=0.9715426, theta=-18.274149 -> V=1.0, theta=0.0
% INFO    : Bus 82464	: V=0.9769027, theta=-17.597739 -> V=1.0, theta=0.0
% INFO    : Bus 82465	: V=0.9746078, theta=-18.236432 -> V=1.0, theta=0.0
% INFO    : Bus 82466	: V=0.9690395, theta=-18.673509 -> V=1.0, theta=0.0
% INFO    : Bus 82467	: V=0.960832, theta=-19.21613 -> V=1.0, theta=0.0
% INFO    : Bus 82468	: V=0.9776833, theta=-17.532212 -> V=1.0, theta=0.0
% INFO    : Bus 82469	: V=0.9738121, theta=-18.018469 -> V=1.0, theta=0.0
% INFO    : Bus 82470	: V=0.969355, theta=-18.700608 -> V=1.0, theta=0.0
% INFO    : Bus 82471	: V=0.9692603, theta=-18.950695 -> V=1.0, theta=0.0
% INFO    : Bus 82472	: V=0.9667885, theta=-19.032561 -> V=1.0, theta=0.0
% INFO    : Bus 82473	: V=0.9755352, theta=-17.864761 -> V=1.0, theta=0.0
% INFO    : Bus 82474	: V=0.9722909, theta=-18.814034 -> V=1.0, theta=0.0
% INFO    : Bus 82475	: V=0.9772354, theta=-17.7138 -> V=1.0, theta=0.0
% INFO    : Bus 82476	: V=0.9785316, theta=-17.609975 -> V=1.0, theta=0.0
% INFO    : Bus 82477	: V=0.9726571, theta=-18.924687 -> V=1.0, theta=0.0
% INFO    : Bus 82478	: V=0.9714279, theta=-18.563275 -> V=1.0, theta=0.0
% INFO    : Bus 82479	: V=0.9743339, theta=-18.249047 -> V=1.0, theta=0.0
% INFO    : Bus 82480	: V=0.9754151, theta=-17.966211 -> V=1.0, theta=0.0
% INFO    : Bus 82481	: V=0.9729423, theta=-18.336997 -> V=1.0, theta=0.0
% INFO    : Bus 82482	: V=0.9795147, theta=-17.478217 -> V=1.0, theta=0.0
% INFO    : Bus 82483	: V=0.9684535, theta=-19.301198 -> V=1.0, theta=0.0
% INFO    : Bus 82484	: V=0.9813666, theta=-17.341165 -> V=1.0, theta=0.0
% INFO    : Bus 82485	: V=0.97859, theta=-18.020039 -> V=1.0, theta=0.0
% INFO    : Bus 82486	: V=0.9819653, theta=-17.28393 -> V=1.0, theta=0.0
% INFO    : Bus 82487	: V=0.9846746, theta=-16.650953 -> V=1.0, theta=0.0
% INFO    : Bus 82488	: V=0.9508911, theta=-20.490999 -> V=1.0, theta=0.0
% INFO    : Bus 82489	: V=0.9695426, theta=-18.302259 -> V=1.0, theta=0.0
% INFO    : Bus 82490	: V=0.9496315, theta=-20.502765 -> V=1.0, theta=0.0
% INFO    : Bus 82491	: V=0.9564586, theta=-20.112894 -> V=1.0, theta=0.0
% INFO    : Bus 82492	: V=0.9720151, theta=-18.133797 -> V=1.0, theta=0.0
% INFO    : Bus 82493	: V=0.9735657, theta=-18.020112 -> V=1.0, theta=0.0
% INFO    : Bus 82494	: V=0.9665265, theta=-19.321717 -> V=1.0, theta=0.0
% INFO    : Bus 82495	: V=0.9583363, theta=-19.765248 -> V=1.0, theta=0.0
% INFO    : Bus 82496	: V=0.9767152, theta=-17.779549 -> V=1.0, theta=0.0
% INFO    : Bus 82497	: V=0.974665, theta=-18.475401 -> V=1.0, theta=0.0
% INFO    : Bus 82498	: V=0.9810475, theta=-17.403412 -> V=1.0, theta=0.0
% INFO    : Bus 82499	: V=0.9708415, theta=-18.474647 -> V=1.0, theta=0.0
% INFO    : Bus 82500	: V=0.9666068, theta=-19.317106 -> V=1.0, theta=0.0
% INFO    : Bus 82501	: V=0.968504, theta=-18.919201 -> V=1.0, theta=0.0
% INFO    : Bus 82502	: V=0.9680907, theta=-18.817659 -> V=1.0, theta=0.0
% INFO    : Bus 82503	: V=0.9662187, theta=-19.079081 -> V=1.0, theta=0.0
% INFO    : Bus 82504	: V=0.9687783, theta=-18.845665 -> V=1.0, theta=0.0
% INFO    : Bus 82505	: V=0.9747021, theta=-17.974862 -> V=1.0, theta=0.0
% INFO    : Bus 82506	: V=0.9703185, theta=-18.692111 -> V=1.0, theta=0.0
% INFO    : Bus 82507	: V=0.9584417, theta=-19.996244 -> V=1.0, theta=0.0
% INFO    : Bus 82508	: V=0.9600223, theta=-19.635013 -> V=1.0, theta=0.0
% INFO    : Bus 82509	: V=0.9841836, theta=-16.67415 -> V=1.0, theta=0.0
% INFO    : Bus 82510	: V=0.9775064, theta=-17.61631 -> V=1.0, theta=0.0
% INFO    : Bus 82511	: V=0.9768504, theta=-17.83797 -> V=1.0, theta=0.0
% INFO    : Bus 82512	: V=0.9444193, theta=-13.247081 -> V=1.0, theta=0.0
% INFO    : Bus 82513	: V=0.941983, theta=-12.788263 -> V=1.0, theta=0.0
% INFO    : Bus 82514	: V=0.9207448, theta=-17.491222 -> V=1.0, theta=0.0
% INFO    : Bus 82515	: V=0.9500332, theta=-8.571961 -> V=1.0, theta=0.0
% INFO    : Bus 82516	: V=0.9474968, theta=-9.113918 -> V=1.0, theta=0.0
% INFO    : Bus 82517	: V=0.961425, theta=-6.277418 -> V=1.0, theta=0.0
% INFO    : Bus 82518	: V=0.9589004, theta=-7.373392 -> V=1.0, theta=0.0
% INFO    : Bus 82519	: V=0.9431733, theta=-10.43229 -> V=1.0, theta=0.0
% INFO    : Bus 82520	: V=0.9422253, theta=-10.673926 -> V=1.0, theta=0.0
% INFO    : Bus 82521	: V=0.9591091, theta=-14.109452 -> V=1.0, theta=0.0
% INFO    : Bus 82522	: V=0.9620907, theta=-14.304842 -> V=1.0, theta=0.0
% INFO    : Bus 82523	: V=0.95931, theta=-14.798006 -> V=1.0, theta=0.0
% INFO    : Bus 82524	: V=0.9632411, theta=-14.106856 -> V=1.0, theta=0.0
% INFO    : Bus 82525	: V=0.9612757, theta=-14.713683 -> V=1.0, theta=0.0
% INFO    : Bus 82526	: V=0.9636427, theta=-14.54569 -> V=1.0, theta=0.0
% INFO    : Bus 82527	: V=0.960811, theta=-14.591848 -> V=1.0, theta=0.0
% INFO    : Bus 82528	: V=0.9620586, theta=-15.669554 -> V=1.0, theta=0.0
% INFO    : Bus 82529	: V=0.9638945, theta=-15.380792 -> V=1.0, theta=0.0
% INFO    : Bus 82530	: V=0.9688926, theta=-15.141981 -> V=1.0, theta=0.0
% INFO    : Bus 82531	: V=0.9672157, theta=-15.733251 -> V=1.0, theta=0.0
% INFO    : Bus 82532	: V=0.9676881, theta=-15.525215 -> V=1.0, theta=0.0
% INFO    : Bus 82533	: V=0.9650528, theta=-15.67392 -> V=1.0, theta=0.0
% INFO    : Bus 82534	: V=0.9673432, theta=-15.380287 -> V=1.0, theta=0.0
% INFO    : Bus 82535	: V=0.9647852, theta=-15.367916 -> V=1.0, theta=0.0
% INFO    : Bus 82536	: V=0.9743788, theta=-14.381943 -> V=1.0, theta=0.0
% INFO    : Bus 82537	: V=0.9925437, theta=-12.998076 -> V=1.0, theta=0.0
% INFO    : Bus 82538	: V=0.9919805, theta=-13.343167 -> V=1.0, theta=0.0
% INFO    : Bus 82539	: V=0.9831413, theta=-14.462838 -> V=1.0, theta=0.0
% INFO    : Bus 82540	: V=0.9755402, theta=-15.39113 -> V=1.0, theta=0.0
% INFO    : Bus 82541	: V=0.9811617, theta=-14.625634 -> V=1.0, theta=0.0
% INFO    : Bus 82542	: V=0.9668963, theta=-9.947092 -> V=1.0, theta=0.0
% INFO    : Bus 82543	: V=0.9796115, theta=-7.782606 -> V=1.0, theta=0.0
% INFO    : Bus 82544	: V=0.9729037, theta=-10.006211 -> V=1.0, theta=0.0
% INFO    : Bus 82545	: V=0.9819183, theta=-7.361863 -> V=1.0, theta=0.0
% INFO    : Bus 82546	: V=0.9751437, theta=-9.539756 -> V=1.0, theta=0.0
% INFO    : Bus 82547	: V=0.983588, theta=-17.856711 -> V=1.0, theta=0.0
% INFO    : Bus 82548	: V=0.9698096, theta=-18.405288 -> V=1.0, theta=0.0
% INFO    : Bus 82549	: V=0.9775252, theta=-17.904659 -> V=1.0, theta=0.0
% INFO    : Bus 82550	: V=0.9899338, theta=-16.192548 -> V=1.0, theta=0.0
% INFO    : Bus 82551	: V=0.9610175, theta=0.508906 -> V=1.0, theta=0.0
% INFO    : Bus 82552	: V=0.9897095, theta=2.669094 -> V=1.0, theta=0.0
% INFO    : Bus 82553	: V=0.9868003, theta=1.663274 -> V=1.0, theta=0.0
% INFO    : Bus 82554	: V=0.9209167, theta=-26.399779 -> V=1.0, theta=0.0
% INFO    : Bus 82555	: V=0.9295455, theta=-24.389379 -> V=1.0, theta=0.0
% INFO    : Bus 82556	: V=0.9253285, theta=-25.805981 -> V=1.0, theta=0.0
% INFO    : Bus 82557	: V=0.9342149, theta=-18.91631 -> V=1.0, theta=0.0
% INFO    : Bus 82558	: V=0.9342439, theta=-19.423751 -> V=1.0, theta=0.0
% INFO    : Bus 82559	: V=0.9344039, theta=-18.308785 -> V=1.0, theta=0.0
% INFO    : Bus 82560	: V=0.9864772, theta=-13.271132 -> V=1.0, theta=0.0
% INFO    : Bus 82561	: V=0.9870514, theta=-13.716552 -> V=1.0, theta=0.0
% INFO    : Bus 82562	: V=0.9806751, theta=-14.492025 -> V=1.0, theta=0.0
% INFO    : Bus 82563	: V=0.9880895, theta=-13.885835 -> V=1.0, theta=0.0
% INFO    : Bus 82564	: V=0.9893885, theta=-12.13147 -> V=1.0, theta=0.0
% INFO    : Bus 82565	: V=0.9990283, theta=-11.773019 -> V=1.0, theta=0.0
% INFO    : Bus 82566	: V=0.996864, theta=-5.505956 -> V=1.0, theta=0.0
% INFO    : Bus 82567	: V=0.9953154, theta=-6.486866 -> V=1.0, theta=0.0
% INFO    : Bus 82568	: V=1.0101429, theta=-11.484392 -> V=1.0, theta=0.0
% INFO    : Bus 82569	: V=1.0043804, theta=-12.428617 -> V=1.0, theta=0.0
% INFO    : Bus 82570	: V=0.9956174, theta=-12.782407 -> V=1.0, theta=0.0
% INFO    : Bus 82571	: V=0.9962534, theta=-9.514312 -> V=1.0, theta=0.0
% INFO    : Bus 82572	: V=0.9941826, theta=-9.391946 -> V=1.0, theta=0.0
% INFO    : Bus 82573	: V=0.9711357, theta=2.403661 -> V=1.0, theta=0.0
% INFO    : Bus 82574	: V=0.9745187, theta=3.43756 -> V=1.0, theta=0.0
% INFO    : Bus 82575	: V=0.9745311, theta=3.583959 -> V=1.0, theta=0.0
% INFO    : Bus 82576	: V=0.9540258, theta=2.669924 -> V=1.0, theta=0.0
% INFO    : Bus 82577	: V=0.9488881, theta=1.772235 -> V=1.0, theta=0.0
% INFO    : Bus 82578	: V=0.9536658, theta=2.163115 -> V=1.0, theta=0.0
% INFO    : Bus 82579	: V=0.9522164, theta=0.086288 -> V=1.0, theta=0.0
% INFO    : Bus 82580	: V=0.9727196, theta=0.449623 -> V=1.0, theta=0.0
% INFO    : Bus 82581	: V=0.9874275, theta=-0.344348 -> V=1.0, theta=0.0
% INFO    : Bus 82582	: V=0.9878005, theta=-11.734846 -> V=1.0, theta=0.0
% INFO    : Bus 82583	: V=0.9899755, theta=-12.250347 -> V=1.0, theta=0.0
% INFO    : Bus 82584	: V=0.9730563, theta=-13.761895 -> V=1.0, theta=0.0
% INFO    : Bus 82585	: V=0.9692792, theta=-5.636489 -> V=1.0, theta=0.0
% INFO    : Bus 82586	: V=0.9663267, theta=-6.161457 -> V=1.0, theta=0.0
% INFO    : Bus 82587	: V=0.972991, theta=-4.07728 -> V=1.0, theta=0.0
% INFO    : Bus 82588	: V=0.9721385, theta=-4.0667 -> V=1.0, theta=0.0
% INFO    : Bus 82589	: V=0.9483815, theta=-13.541121 -> V=1.0, theta=0.0
% INFO    : Bus 82590	: V=0.9646591, theta=-15.58864 -> V=1.0, theta=0.0
% INFO    : Bus 82591	: V=0.9681028, theta=-14.803719 -> V=1.0, theta=0.0
% INFO    : Bus 82592	: V=0.9400022, theta=-28.150939 -> V=1.0, theta=0.0
% INFO    : Bus 82593	: V=0.9521531, theta=-28.847942 -> V=1.0, theta=0.0
% INFO    : Bus 82594	: V=0.9437482, theta=-27.700482 -> V=1.0, theta=0.0
% INFO    : Bus 82595	: V=0.9441716, theta=-26.710649 -> V=1.0, theta=0.0
% INFO    : Bus 82596	: V=0.9684907, theta=-29.437931 -> V=1.0, theta=0.0
% INFO    : Bus 82597	: V=0.9422299, theta=-26.938049 -> V=1.0, theta=0.0
% INFO    : Bus 82598	: V=0.9637853, theta=-24.031355 -> V=1.0, theta=0.0
% INFO    : Bus 82599	: V=0.9429413, theta=-25.677494 -> V=1.0, theta=0.0
% INFO    : Bus 82600	: V=0.9629241, theta=-23.364894 -> V=1.0, theta=0.0
% INFO    : Bus 82601	: V=0.9556277, theta=-23.92693 -> V=1.0, theta=0.0
% INFO    : Bus 82602	: V=0.940488, theta=-11.058684 -> V=1.0, theta=0.0
% INFO    : Bus 82603	: V=0.9389784, theta=-11.28072 -> V=1.0, theta=0.0
% INFO    : Bus 82604	: V=0.9413298, theta=-10.989254 -> V=1.0, theta=0.0
% INFO    : Bus 82605	: V=0.9361245, theta=-11.851895 -> V=1.0, theta=0.0
% INFO    : Bus 82606	: V=0.9404358, theta=-11.165657 -> V=1.0, theta=0.0
% INFO    : Bus 82607	: V=0.9462754, theta=-10.2038 -> V=1.0, theta=0.0
% INFO    : Bus 82608	: V=0.9469537, theta=-10.029395 -> V=1.0, theta=0.0
% INFO    : Bus 82609	: V=0.9467562, theta=-10.080811 -> V=1.0, theta=0.0
% INFO    : Bus 82610	: V=0.9465943, theta=-10.034038 -> V=1.0, theta=0.0
% INFO    : Bus 82611	: V=0.9448996, theta=-10.611246 -> V=1.0, theta=0.0
% INFO    : Bus 82612	: V=0.9375144, theta=-11.750723 -> V=1.0, theta=0.0
% INFO    : Bus 82613	: V=0.9430094, theta=-10.680266 -> V=1.0, theta=0.0
% INFO    : Bus 82614	: V=0.9369117, theta=-11.942465 -> V=1.0, theta=0.0
% INFO    : Bus 82615	: V=0.9475129, theta=-11.334906 -> V=1.0, theta=0.0
% INFO    : Bus 82616	: V=0.9339172, theta=-12.694076 -> V=1.0, theta=0.0
% INFO    : Bus 82617	: V=0.9586336, theta=-6.20906 -> V=1.0, theta=0.0
% INFO    : Bus 82618	: V=0.9549665, theta=-7.73304 -> V=1.0, theta=0.0
% INFO    : Bus 82619	: V=0.9410488, theta=-10.95846 -> V=1.0, theta=0.0
% INFO    : Bus 82620	: V=0.9361308, theta=-12.180025 -> V=1.0, theta=0.0
% INFO    : Bus 82621	: V=0.9343723, theta=-12.675615 -> V=1.0, theta=0.0
% INFO    : Bus 82622	: V=0.9350248, theta=-13.321401 -> V=1.0, theta=0.0
% INFO    : Bus 82623	: V=0.9490203, theta=-12.137858 -> V=1.0, theta=0.0
% INFO    : Bus 82624	: V=0.9460673, theta=-12.592611 -> V=1.0, theta=0.0
% INFO    : Bus 82625	: V=0.9460699, theta=-12.76633 -> V=1.0, theta=0.0
% INFO    : Bus 82626	: V=0.9449738, theta=-12.387173 -> V=1.0, theta=0.0
% INFO    : Bus 82627	: V=0.9404038, theta=-11.135239 -> V=1.0, theta=0.0
% INFO    : Bus 82628	: V=0.9583544, theta=-3.997416 -> V=1.0, theta=0.0
% INFO    : Bus 82629	: V=0.9637003, theta=-3.832191 -> V=1.0, theta=0.0
% INFO    : Bus 82630	: V=0.9586311, theta=-5.07978 -> V=1.0, theta=0.0
% INFO    : Bus 82631	: V=0.9484509, theta=-9.711048 -> V=1.0, theta=0.0
% INFO    : Bus 82632	: V=0.9690856, theta=-18.869983 -> V=1.0, theta=0.0
% INFO    : Bus 82633	: V=0.9809687, theta=-18.178897 -> V=1.0, theta=0.0
% INFO    : Bus 82634	: V=0.9560371, theta=-22.481008 -> V=1.0, theta=0.0
% INFO    : Bus 82635	: V=0.9680997, theta=-20.122015 -> V=1.0, theta=0.0
% INFO    : Bus 82636	: V=0.9622221, theta=-20.930556 -> V=1.0, theta=0.0
% INFO    : Bus 82637	: V=0.9688101, theta=-19.999402 -> V=1.0, theta=0.0
% INFO    : Bus 82638	: V=0.9652786, theta=-20.619007 -> V=1.0, theta=0.0
% INFO    : Bus 82639	: V=0.9692443, theta=-19.901861 -> V=1.0, theta=0.0
% INFO    : Bus 82640	: V=0.9649417, theta=-20.647408 -> V=1.0, theta=0.0
% INFO    : Bus 82641	: V=0.9647795, theta=-20.498865 -> V=1.0, theta=0.0
% INFO    : Bus 82642	: V=0.9763519, theta=-18.410377 -> V=1.0, theta=0.0
% INFO    : Bus 82643	: V=1.0034702, theta=-10.406907 -> V=1.0, theta=0.0
% INFO    : Bus 82644	: V=0.9686049, theta=-4.462678 -> V=1.0, theta=0.0
% INFO    : Bus 82645	: V=0.9750272, theta=-3.060302 -> V=1.0, theta=0.0
% INFO    : Bus 82646	: V=0.9240668, theta=-30.108224 -> V=1.0, theta=0.0
% INFO    : Bus 82647	: V=0.926165, theta=-28.017968 -> V=1.0, theta=0.0
% INFO    : Bus 82648	: V=0.9246136, theta=-29.20247 -> V=1.0, theta=0.0
% INFO    : Bus 82649	: V=1.0101165, theta=-7.533496 -> V=1.0, theta=0.0
% INFO    : Bus 82650	: V=1.0074737, theta=-8.674038 -> V=1.0, theta=0.0
% INFO    : Bus 82651	: V=1.0099936, theta=-18.451727 -> V=1.0, theta=0.0
% INFO    : Bus 82652	: V=0.9704277, theta=-9.077848 -> V=1.0, theta=0.0
% INFO    : Bus 82653	: V=0.9660938, theta=-9.471303 -> V=1.0, theta=0.0
% INFO    : Bus 82654	: V=0.9716032, theta=-8.682233 -> V=1.0, theta=0.0
% INFO    : Bus 82655	: V=0.9719496, theta=-8.769735 -> V=1.0, theta=0.0
% INFO    : Bus 82656	: V=0.9683193, theta=-9.501028 -> V=1.0, theta=0.0
% INFO    : Bus 82657	: V=0.9735724, theta=-8.53309 -> V=1.0, theta=0.0
% INFO    : Bus 82658	: V=0.9706216, theta=-8.298795 -> V=1.0, theta=0.0
% INFO    : Bus 82659	: V=0.9719842, theta=-8.668514 -> V=1.0, theta=0.0
% INFO    : Bus 82660	: V=0.9781901, theta=-8.106272 -> V=1.0, theta=0.0
% INFO    : Bus 82661	: V=0.9767958, theta=-8.198547 -> V=1.0, theta=0.0
% INFO    : Bus 82662	: V=0.9779542, theta=-7.559707 -> V=1.0, theta=0.0
% INFO    : Bus 82663	: V=0.9779768, theta=-8.040087 -> V=1.0, theta=0.0
% INFO    : Bus 82664	: V=0.9728024, theta=-8.871913 -> V=1.0, theta=0.0
% INFO    : Bus 82665	: V=0.9704612, theta=-8.957197 -> V=1.0, theta=0.0
% INFO    : Bus 82666	: V=0.9688453, theta=-18.182244 -> V=1.0, theta=0.0
% INFO    : Bus 82667	: V=0.9638881, theta=-19.219002 -> V=1.0, theta=0.0
% INFO    : Bus 82668	: V=0.9887843, theta=-12.101854 -> V=1.0, theta=0.0
% INFO    : Bus 82669	: V=0.988828, theta=-12.007558 -> V=1.0, theta=0.0
% INFO    : Bus 82670	: V=0.9890396, theta=-11.961877 -> V=1.0, theta=0.0
% INFO    : Bus 82671	: V=1.0048353, theta=-10.474384 -> V=1.0, theta=0.0
% INFO    : Bus 82672	: V=0.9950175, theta=-12.050905 -> V=1.0, theta=0.0
% INFO    : Bus 82673	: V=0.9894004, theta=-12.3112 -> V=1.0, theta=0.0
% INFO    : Bus 82674	: V=0.9894099, theta=-12.369814 -> V=1.0, theta=0.0
% INFO    : Bus 82675	: V=0.9928876, theta=-12.193133 -> V=1.0, theta=0.0
% INFO    : Bus 82676	: V=0.986565, theta=-12.016694 -> V=1.0, theta=0.0
% INFO    : Bus 82677	: V=1.0026256, theta=-10.695002 -> V=1.0, theta=0.0
% INFO    : Bus 82678	: V=0.9965195, theta=-11.54753 -> V=1.0, theta=0.0
% INFO    : Bus 82679	: V=0.9891901, theta=-12.288893 -> V=1.0, theta=0.0
% INFO    : Bus 82680	: V=0.9892345, theta=-11.915151 -> V=1.0, theta=0.0
% INFO    : Bus 82681	: V=0.9860542, theta=-12.394599 -> V=1.0, theta=0.0
% INFO    : Bus 82682	: V=1.0101446, theta=-10.009954 -> V=1.0, theta=0.0
% INFO    : Bus 82683	: V=1.0023462, theta=-11.364277 -> V=1.0, theta=0.0
% INFO    : Bus 82684	: V=0.9782193, theta=-12.703214 -> V=1.0, theta=0.0
% INFO    : Bus 82685	: V=1.0066016, theta=-3.251857 -> V=1.0, theta=0.0
% INFO    : Bus 82686	: V=1.0050153, theta=-6.080599 -> V=1.0, theta=0.0
% INFO    : Bus 82687	: V=1.0083308, theta=-6.053968 -> V=1.0, theta=0.0
% INFO    : Bus 82688	: V=1.0026007, theta=-6.250964 -> V=1.0, theta=0.0
% INFO    : Bus 82689	: V=1.0041016, theta=-7.472194 -> V=1.0, theta=0.0
% INFO    : Bus 82690	: V=1.0030545, theta=-7.428639 -> V=1.0, theta=0.0
% INFO    : Bus 82691	: V=1.0097598, theta=-6.741886 -> V=1.0, theta=0.0
% INFO    : Bus 82692	: V=1.0069809, theta=-7.269174 -> V=1.0, theta=0.0
% INFO    : Bus 82693	: V=1.005309, theta=-7.394631 -> V=1.0, theta=0.0
% INFO    : Bus 82694	: V=1.0131659, theta=-6.246956 -> V=1.0, theta=0.0
% INFO    : Bus 82695	: V=1.002688, theta=-7.569168 -> V=1.0, theta=0.0
% INFO    : Bus 82696	: V=1.0132179, theta=-6.194193 -> V=1.0, theta=0.0
% INFO    : Bus 82697	: V=0.9470176, theta=-17.118988 -> V=1.0, theta=0.0
% INFO    : Bus 82698	: V=0.9537392, theta=-16.841492 -> V=1.0, theta=0.0
% INFO    : Bus 82699	: V=0.9570413, theta=-16.259191 -> V=1.0, theta=0.0
% INFO    : Bus 82700	: V=0.949226, theta=-18.329297 -> V=1.0, theta=0.0
% INFO    : Bus 82701	: V=0.9548912, theta=-16.677685 -> V=1.0, theta=0.0
% INFO    : Bus 82702	: V=0.9621416, theta=-16.018652 -> V=1.0, theta=0.0
% INFO    : Bus 82703	: V=0.9562364, theta=-16.966605 -> V=1.0, theta=0.0
% INFO    : Bus 82704	: V=0.9917892, theta=-11.581691 -> V=1.0, theta=0.0
% INFO    : Bus 82705	: V=0.9941141, theta=-11.33718 -> V=1.0, theta=0.0
% INFO    : Bus 82706	: V=0.9776615, theta=-17.065217 -> V=1.0, theta=0.0
% INFO    : Bus 82707	: V=0.9702924, theta=-28.378152 -> V=1.0, theta=0.0
% INFO    : Bus 82708	: V=0.9807868, theta=-26.676004 -> V=1.0, theta=0.0
% INFO    : Bus 82709	: V=0.9707508, theta=-28.238368 -> V=1.0, theta=0.0
% INFO    : Bus 82710	: V=0.9713657, theta=-28.375092 -> V=1.0, theta=0.0
% INFO    : Bus 82711	: V=0.9701686, theta=-28.384957 -> V=1.0, theta=0.0
% INFO    : Bus 82712	: V=0.9810433, theta=-25.71433 -> V=1.0, theta=0.0
% INFO    : Bus 82713	: V=0.9821481, theta=-26.02352 -> V=1.0, theta=0.0
% INFO    : Bus 82714	: V=0.9793431, theta=-26.201291 -> V=1.0, theta=0.0
% INFO    : Bus 82715	: V=0.9589754, theta=-25.23062 -> V=1.0, theta=0.0
% INFO    : Bus 82716	: V=0.9662488, theta=-7.348446 -> V=1.0, theta=0.0
% INFO    : Bus 82717	: V=0.9801823, theta=-4.352816 -> V=1.0, theta=0.0
% INFO    : Bus 82718	: V=0.9733688, theta=-7.491541 -> V=1.0, theta=0.0
% INFO    : Bus 82719	: V=0.9701402, theta=-8.826562 -> V=1.0, theta=0.0
% INFO    : Bus 82720	: V=0.9240997, theta=-25.528075 -> V=1.0, theta=0.0
% INFO    : Bus 82721	: V=0.9250598, theta=-24.287888 -> V=1.0, theta=0.0
% INFO    : Bus 82722	: V=0.9237765, theta=-25.582822 -> V=1.0, theta=0.0
% INFO    : Bus 82723	: V=0.922489, theta=-28.006343 -> V=1.0, theta=0.0
% INFO    : Bus 82724	: V=1.0263191, theta=6.000364 -> V=1.0, theta=0.0
% INFO    : Bus 82725	: V=1.0154336, theta=5.918571 -> V=1.0, theta=0.0
% INFO    : Bus 82726	: V=1.0021995, theta=1.65861 -> V=1.0, theta=0.0
% INFO    : Bus 82727	: V=1.0029799, theta=0.572302 -> V=1.0, theta=0.0
% INFO    : Bus 82728	: V=0.9738912, theta=-2.94943 -> V=1.0, theta=0.0
% INFO    : Bus 82729	: V=0.9998105, theta=-0.243647 -> V=1.0, theta=0.0
% INFO    : Bus 82730	: V=0.9961621, theta=-0.345162 -> V=1.0, theta=0.0
% INFO    : Bus 82731	: V=0.9978092, theta=0.203411 -> V=1.0, theta=0.0
% INFO    : Bus 82732	: V=0.9934019, theta=-1.951877 -> V=1.0, theta=0.0
% INFO    : Bus 82733	: V=0.9798401, theta=-2.856235 -> V=1.0, theta=0.0
% INFO    : Bus 82734	: V=0.9817412, theta=-3.846966 -> V=1.0, theta=0.0
% INFO    : Bus 82735	: V=0.9761032, theta=-4.414128 -> V=1.0, theta=0.0
% INFO    : Bus 82736	: V=0.9696054, theta=-5.737403 -> V=1.0, theta=0.0
% INFO    : Bus 82737	: V=0.9669958, theta=-5.945881 -> V=1.0, theta=0.0
% INFO    : Bus 82738	: V=0.9675316, theta=-5.817433 -> V=1.0, theta=0.0
% INFO    : Bus 82739	: V=0.9636556, theta=-6.362181 -> V=1.0, theta=0.0
% INFO    : Bus 82740	: V=1.0064927, theta=1.670366 -> V=1.0, theta=0.0
% INFO    : Bus 82741	: V=1.0066702, theta=1.589012 -> V=1.0, theta=0.0
% INFO    : Bus 82742	: V=1.0051406, theta=-4.404082 -> V=1.0, theta=0.0
% INFO    : Bus 82743	: V=0.9820489, theta=-6.629463 -> V=1.0, theta=0.0
% INFO    : Bus 82744	: V=0.977117, theta=8.551238 -> V=1.0, theta=0.0
% INFO    : Bus 82745	: V=0.9647552, theta=-4.837651 -> V=1.0, theta=0.0
% INFO    : Bus 82746	: V=1.0016047, theta=-6.461847 -> V=1.0, theta=0.0
% INFO    : Bus 82747	: V=1.0006622, theta=-6.504406 -> V=1.0, theta=0.0
% INFO    : Bus 82748	: V=1.0004072, theta=-6.499155 -> V=1.0, theta=0.0
% INFO    : Bus 82749	: V=1.009163, theta=-5.702747 -> V=1.0, theta=0.0
% INFO    : Bus 82750	: V=0.9975949, theta=-6.455353 -> V=1.0, theta=0.0
% INFO    : Bus 82751	: V=0.9988126, theta=-6.340874 -> V=1.0, theta=0.0
% INFO    : Bus 82752	: V=1.0067793, theta=-5.646163 -> V=1.0, theta=0.0
% INFO    : Bus 82753	: V=1.0014025, theta=-6.204383 -> V=1.0, theta=0.0
% INFO    : Bus 82754	: V=0.9930296, theta=-6.107369 -> V=1.0, theta=0.0
% INFO    : Bus 82755	: V=0.9861933, theta=-6.317651 -> V=1.0, theta=0.0
% INFO    : Bus 82756	: V=0.997979, theta=-6.643778 -> V=1.0, theta=0.0
% INFO    : Bus 82757	: V=0.9669914, theta=0.85249 -> V=1.0, theta=0.0
% INFO    : Bus 82758	: V=0.9751189, theta=1.529445 -> V=1.0, theta=0.0
% INFO    : Bus 82759	: V=0.9897307, theta=-4.529067 -> V=1.0, theta=0.0
% INFO    : Bus 82760	: V=0.9828446, theta=-5.135582 -> V=1.0, theta=0.0
% INFO    : Bus 82761	: V=0.9929695, theta=-4.149329 -> V=1.0, theta=0.0
% INFO    : Bus 82762	: V=0.983654, theta=-5.049846 -> V=1.0, theta=0.0
% INFO    : Bus 82763	: V=0.9828928, theta=-5.067952 -> V=1.0, theta=0.0
% INFO    : Bus 82764	: V=0.9932632, theta=-4.107327 -> V=1.0, theta=0.0
% INFO    : Bus 82765	: V=0.9858752, theta=-4.46569 -> V=1.0, theta=0.0
% INFO    : Bus 82766	: V=0.9764074, theta=-5.220556 -> V=1.0, theta=0.0
% INFO    : Bus 82767	: V=0.9760666, theta=-5.537649 -> V=1.0, theta=0.0
% INFO    : Bus 82768	: V=0.9915066, theta=-4.404549 -> V=1.0, theta=0.0
% INFO    : Bus 82769	: V=0.9891355, theta=-4.769824 -> V=1.0, theta=0.0
% INFO    : Bus 82770	: V=0.9872768, theta=-3.912111 -> V=1.0, theta=0.0
% INFO    : Bus 82771	: V=0.9849539, theta=-4.056338 -> V=1.0, theta=0.0
% INFO    : Bus 82772	: V=0.9741157, theta=0.288832 -> V=1.0, theta=0.0
% INFO    : Bus 82773	: V=0.9737797, theta=-0.449192 -> V=1.0, theta=0.0
% INFO    : Bus 82774	: V=0.976524, theta=-1.038009 -> V=1.0, theta=0.0
% INFO    : Bus 82775	: V=0.9754411, theta=-1.884218 -> V=1.0, theta=0.0
% INFO    : Bus 82776	: V=0.9551433, theta=-8.613352 -> V=1.0, theta=0.0
% INFO    : Bus 82777	: V=0.9750642, theta=-5.861276 -> V=1.0, theta=0.0
% INFO    : Bus 82778	: V=0.9665392, theta=-8.051324 -> V=1.0, theta=0.0
% INFO    : Bus 82779	: V=0.951585, theta=-10.992079 -> V=1.0, theta=0.0
% INFO    : Bus 82780	: V=0.936469, theta=-11.815391 -> V=1.0, theta=0.0
% INFO    : Bus 82781	: V=0.9355359, theta=-11.969115 -> V=1.0, theta=0.0
% INFO    : Bus 82782	: V=0.9808316, theta=-5.797552 -> V=1.0, theta=0.0
% INFO    : Bus 82783	: V=0.9419272, theta=-16.354806 -> V=1.0, theta=0.0
% INFO    : Bus 82784	: V=0.9477051, theta=-18.964941 -> V=1.0, theta=0.0
% INFO    : Bus 82785	: V=0.949832, theta=-17.287671 -> V=1.0, theta=0.0
% INFO    : Bus 82786	: V=0.9485203, theta=-18.930879 -> V=1.0, theta=0.0
% INFO    : Bus 82787	: V=0.9533051, theta=-11.153059 -> V=1.0, theta=0.0
% INFO    : Bus 82788	: V=0.9553285, theta=-10.800104 -> V=1.0, theta=0.0
% INFO    : Bus 82789	: V=0.9557081, theta=-10.874258 -> V=1.0, theta=0.0
% INFO    : Bus 82790	: V=0.9545497, theta=-11.309362 -> V=1.0, theta=0.0
% INFO    : Bus 82791	: V=0.962135, theta=-9.668369 -> V=1.0, theta=0.0
% INFO    : Bus 82792	: V=0.9569768, theta=-16.688041 -> V=1.0, theta=0.0
% INFO    : Bus 82793	: V=0.9547834, theta=-14.221684 -> V=1.0, theta=0.0
% INFO    : Bus 82794	: V=0.9536659, theta=-11.230237 -> V=1.0, theta=0.0
% INFO    : Bus 82795	: V=0.9707899, theta=-7.640484 -> V=1.0, theta=0.0
% INFO    : Bus 82796	: V=0.9857389, theta=-1.758586 -> V=1.0, theta=0.0
% INFO    : Bus 82797	: V=0.9594391, theta=-1.511629 -> V=1.0, theta=0.0
% INFO    : Bus 82798	: V=0.9884758, theta=3.366574 -> V=1.0, theta=0.0
% INFO    : Bus 82799	: V=0.9834792, theta=-2.42244 -> V=1.0, theta=0.0
% INFO    : Bus 82800	: V=0.9719819, theta=-4.312633 -> V=1.0, theta=0.0
% INFO    : Bus 82801	: V=0.9865243, theta=-6.915757 -> V=1.0, theta=0.0
% INFO    : Bus 82802	: V=0.9872433, theta=-6.85284 -> V=1.0, theta=0.0
% INFO    : Bus 82803	: V=0.9808902, theta=-6.748765 -> V=1.0, theta=0.0
% INFO    : Bus 82804	: V=0.9996156, theta=-4.0856 -> V=1.0, theta=0.0
% INFO    : Bus 82805	: V=1.0015056, theta=-4.734679 -> V=1.0, theta=0.0
% INFO    : Bus 82806	: V=0.9980599, theta=-5.349085 -> V=1.0, theta=0.0
% INFO    : Bus 82807	: V=0.9794885, theta=-8.042197 -> V=1.0, theta=0.0
% INFO    : Bus 82808	: V=0.9799346, theta=-7.815617 -> V=1.0, theta=0.0
% INFO    : Bus 82809	: V=0.9853417, theta=-3.279861 -> V=1.0, theta=0.0
% INFO    : Bus 82810	: V=0.9738493, theta=22.962897 -> V=1.0, theta=0.0
% INFO    : Bus 82811	: V=0.9909862, theta=21.268794 -> V=1.0, theta=0.0
% INFO    : Bus 82812	: V=0.9795863, theta=22.245057 -> V=1.0, theta=0.0
% INFO    : Bus 82813	: V=0.964724, theta=17.131643 -> V=1.0, theta=0.0
% INFO    : Bus 82814	: V=0.9843312, theta=-7.405918 -> V=1.0, theta=0.0
% INFO    : Bus 82815	: V=0.9698482, theta=-6.279334 -> V=1.0, theta=0.0
% INFO    : Bus 82816	: V=0.9696213, theta=-8.087968 -> V=1.0, theta=0.0
% INFO    : Bus 82817	: V=0.9673226, theta=-8.398005 -> V=1.0, theta=0.0
% INFO    : Bus 82818	: V=0.9800019, theta=-7.524959 -> V=1.0, theta=0.0
% INFO    : Bus 82819	: V=0.9666023, theta=-1.608892 -> V=1.0, theta=0.0
% INFO    : Bus 82820	: V=0.9841347, theta=-12.234396 -> V=1.0, theta=0.0
% INFO    : Bus 82821	: V=0.9845757, theta=-12.324378 -> V=1.0, theta=0.0
% INFO    : Bus 82822	: V=0.9798472, theta=-12.494175 -> V=1.0, theta=0.0
% INFO    : Bus 82823	: V=0.9817593, theta=-12.556858 -> V=1.0, theta=0.0
% INFO    : Bus 82824	: V=0.9769856, theta=-12.72423 -> V=1.0, theta=0.0
% INFO    : Bus 82825	: V=0.9771048, theta=-12.801084 -> V=1.0, theta=0.0
% INFO    : Bus 82826	: V=0.9763094, theta=-12.748738 -> V=1.0, theta=0.0
% INFO    : Bus 82827	: V=0.9909366, theta=-12.384406 -> V=1.0, theta=0.0
% INFO    : Bus 82828	: V=0.9799842, theta=-12.881229 -> V=1.0, theta=0.0
% INFO    : Bus 82829	: V=0.9858792, theta=-12.874572 -> V=1.0, theta=0.0
% INFO    : Bus 82830	: V=0.9810654, theta=-13.352319 -> V=1.0, theta=0.0
% INFO    : Bus 82831	: V=0.9775456, theta=-13.005595 -> V=1.0, theta=0.0
% INFO    : Bus 82832	: V=0.9742692, theta=-13.590218 -> V=1.0, theta=0.0
% INFO    : Bus 82833	: V=0.9740756, theta=-13.529818 -> V=1.0, theta=0.0
% INFO    : Bus 82834	: V=0.9757635, theta=-13.090848 -> V=1.0, theta=0.0
% INFO    : Bus 82835	: V=0.9891996, theta=-10.650805 -> V=1.0, theta=0.0
% INFO    : Bus 82836	: V=0.9906295, theta=-10.393446 -> V=1.0, theta=0.0
% INFO    : Bus 82837	: V=0.9922781, theta=-10.940854 -> V=1.0, theta=0.0
% INFO    : Bus 82838	: V=0.9847889, theta=-12.219801 -> V=1.0, theta=0.0
% INFO    : Bus 82839	: V=0.9864936, theta=-11.613525 -> V=1.0, theta=0.0
% INFO    : Bus 82840	: V=0.9771054, theta=-12.229999 -> V=1.0, theta=0.0
% INFO    : Bus 82841	: V=0.9819445, theta=-11.150056 -> V=1.0, theta=0.0
% INFO    : Bus 82842	: V=0.978969, theta=-12.465301 -> V=1.0, theta=0.0
% INFO    : Bus 82843	: V=0.9721969, theta=-12.962368 -> V=1.0, theta=0.0
% INFO    : Bus 82844	: V=0.9664185, theta=-13.384176 -> V=1.0, theta=0.0
% INFO    : Bus 82845	: V=0.9681057, theta=-15.414791 -> V=1.0, theta=0.0
% INFO    : Bus 82846	: V=0.9665979, theta=-15.337427 -> V=1.0, theta=0.0
% INFO    : Bus 82847	: V=0.9701264, theta=-15.016302 -> V=1.0, theta=0.0
% INFO    : Bus 82848	: V=0.9705817, theta=-14.207213 -> V=1.0, theta=0.0
% INFO    : Bus 82849	: V=0.9720787, theta=-13.695271 -> V=1.0, theta=0.0
% INFO    : Bus 82850	: V=0.9778146, theta=-13.655516 -> V=1.0, theta=0.0
% INFO    : Bus 82851	: V=1.0015702, theta=-11.850927 -> V=1.0, theta=0.0
% INFO    : Bus 82852	: V=0.9911148, theta=-12.393448 -> V=1.0, theta=0.0
% INFO    : Bus 82853	: V=0.9929669, theta=-12.158971 -> V=1.0, theta=0.0
% INFO    : Bus 82854	: V=0.9909817, theta=-9.434892 -> V=1.0, theta=0.0
% INFO    : Bus 82855	: V=0.9865575, theta=-10.425201 -> V=1.0, theta=0.0
% INFO    : Bus 82856	: V=0.9674871, theta=-13.558745 -> V=1.0, theta=0.0
% INFO    : Bus 82857	: V=0.969353, theta=-14.145654 -> V=1.0, theta=0.0
% INFO    : Bus 82858	: V=0.9659513, theta=-14.65183 -> V=1.0, theta=0.0
% INFO    : Bus 82859	: V=0.9653805, theta=-14.519005 -> V=1.0, theta=0.0
% INFO    : Bus 82860	: V=0.9609631, theta=-14.957627 -> V=1.0, theta=0.0
% INFO    : Bus 82861	: V=0.960096, theta=-15.469062 -> V=1.0, theta=0.0
% INFO    : Bus 82862	: V=0.9585642, theta=-15.944645 -> V=1.0, theta=0.0
% INFO    : Bus 82863	: V=0.9815647, theta=-12.566475 -> V=1.0, theta=0.0
% INFO    : Bus 82864	: V=0.971197, theta=-13.584834 -> V=1.0, theta=0.0
% INFO    : Bus 82865	: V=0.9832733, theta=-12.699631 -> V=1.0, theta=0.0
% INFO    : Bus 82866	: V=0.9764571, theta=-5.26036 -> V=1.0, theta=0.0
% INFO    : Bus 82867	: V=0.9837188, theta=7.817955 -> V=1.0, theta=0.0
% INFO    : Bus 82868	: V=0.959773, theta=-0.695864 -> V=1.0, theta=0.0
% INFO    : Bus 82869	: V=0.9769589, theta=1.031503 -> V=1.0, theta=0.0
% INFO    : Bus 82870	: V=0.9693997, theta=-0.193449 -> V=1.0, theta=0.0
% INFO    : Bus 82871	: V=0.9645659, theta=-0.435863 -> V=1.0, theta=0.0
% INFO    : Bus 82872	: V=0.9636587, theta=-0.49572 -> V=1.0, theta=0.0
% INFO    : Bus 82873	: V=0.9613358, theta=-0.541987 -> V=1.0, theta=0.0
% INFO    : Bus 82874	: V=0.9880343, theta=-4.421932 -> V=1.0, theta=0.0
% INFO    : Bus 82875	: V=0.983222, theta=-4.316734 -> V=1.0, theta=0.0
% INFO    : Bus 82876	: V=0.9954012, theta=-4.949346 -> V=1.0, theta=0.0
% INFO    : Bus 82877	: V=0.9885406, theta=-5.880691 -> V=1.0, theta=0.0
% INFO    : Bus 82878	: V=0.971745, theta=-21.554655 -> V=1.0, theta=0.0
% INFO    : Bus 82879	: V=0.963874, theta=-23.08515 -> V=1.0, theta=0.0
% INFO    : Bus 82880	: V=0.9535698, theta=6.326254 -> V=1.0, theta=0.0
% INFO    : Bus 82881	: V=0.9568494, theta=6.734207 -> V=1.0, theta=0.0
% INFO    : Bus 82882	: V=0.9615225, theta=7.317794 -> V=1.0, theta=0.0
% INFO    : Bus 82883	: V=1.0103888, theta=-10.958885 -> V=1.0, theta=0.0
% INFO    : Bus 82884	: V=0.9870172, theta=-7.372475 -> V=1.0, theta=0.0
% INFO    : Bus 82885	: V=0.9874863, theta=-7.377764 -> V=1.0, theta=0.0
% INFO    : Bus 82886	: V=0.9840296, theta=-7.014509 -> V=1.0, theta=0.0
% INFO    : Bus 82887	: V=0.9783767, theta=-8.3882 -> V=1.0, theta=0.0
% INFO    : Bus 82888	: V=0.9777549, theta=-8.09661 -> V=1.0, theta=0.0
% INFO    : Bus 82889	: V=0.9738213, theta=-9.339061 -> V=1.0, theta=0.0
% INFO    : Bus 82890	: V=0.9729562, theta=-9.556019 -> V=1.0, theta=0.0
% INFO    : Bus 82891	: V=0.9960601, theta=-6.234144 -> V=1.0, theta=0.0
% INFO    : Bus 82892	: V=0.9887285, theta=-7.243447 -> V=1.0, theta=0.0
% INFO    : Bus 82893	: V=0.987391, theta=-7.337645 -> V=1.0, theta=0.0
% INFO    : Bus 82894	: V=0.9672439, theta=-10.758038 -> V=1.0, theta=0.0
% INFO    : Bus 82895	: V=0.9650869, theta=-12.20503 -> V=1.0, theta=0.0
% INFO    : Bus 82896	: V=0.9783636, theta=-9.572304 -> V=1.0, theta=0.0
% INFO    : Bus 82897	: V=0.9784265, theta=-10.61095 -> V=1.0, theta=0.0
% INFO    : Bus 82898	: V=0.9832186, theta=-7.333326 -> V=1.0, theta=0.0
% INFO    : Bus 82899	: V=0.9877886, theta=-4.050279 -> V=1.0, theta=0.0
% INFO    : Bus 82900	: V=0.9746228, theta=-5.153001 -> V=1.0, theta=0.0
% INFO    : Bus 82901	: V=0.9697073, theta=-5.640183 -> V=1.0, theta=0.0
% INFO    : Bus 82902	: V=0.9749955, theta=-4.129349 -> V=1.0, theta=0.0
% INFO    : Bus 82903	: V=0.9750165, theta=-3.901289 -> V=1.0, theta=0.0
% INFO    : Bus 82904	: V=0.9652806, theta=-7.723697 -> V=1.0, theta=0.0
% INFO    : Bus 82905	: V=0.9654946, theta=10.847529 -> V=1.0, theta=0.0
% INFO    : Bus 82906	: V=0.982824, theta=-3.585974 -> V=1.0, theta=0.0
% INFO    : Bus 82907	: V=0.9877176, theta=-3.725716 -> V=1.0, theta=0.0
% INFO    : Bus 82908	: V=0.994516, theta=-2.662166 -> V=1.0, theta=0.0
% INFO    : Bus 82909	: V=0.9886779, theta=-3.313657 -> V=1.0, theta=0.0
% INFO    : Bus 82910	: V=1.0015396, theta=-20.347575 -> V=1.0, theta=0.0
% INFO    : Bus 82911	: V=1.0042283, theta=-20.719609 -> V=1.0, theta=0.0
% INFO    : Bus 82912	: V=1.0028497, theta=-20.814828 -> V=1.0, theta=0.0
% INFO    : Bus 82913	: V=1.0006751, theta=-21.126995 -> V=1.0, theta=0.0
% INFO    : Bus 82914	: V=1.0058902, theta=-20.95406 -> V=1.0, theta=0.0
% INFO    : Bus 82915	: V=0.9844177, theta=-19.610986 -> V=1.0, theta=0.0
% INFO    : Bus 82916	: V=1.0013842, theta=-20.485314 -> V=1.0, theta=0.0
% INFO    : Bus 82917	: V=1.0010476, theta=-19.734324 -> V=1.0, theta=0.0
% INFO    : Bus 82918	: V=1.0048135, theta=-20.194733 -> V=1.0, theta=0.0
% INFO    : Bus 82919	: V=0.9940061, theta=-22.584264 -> V=1.0, theta=0.0
% INFO    : Bus 82920	: V=0.9894493, theta=-24.688161 -> V=1.0, theta=0.0
% INFO    : Bus 82921	: V=1.0051811, theta=-20.640277 -> V=1.0, theta=0.0
% INFO    : Bus 82922	: V=0.957776, theta=-8.860795 -> V=1.0, theta=0.0
% INFO    : Bus 82923	: V=0.9584397, theta=-9.085075 -> V=1.0, theta=0.0
% INFO    : Bus 82924	: V=0.9549593, theta=-9.196295 -> V=1.0, theta=0.0
% INFO    : Bus 82925	: V=0.9601094, theta=-8.605321 -> V=1.0, theta=0.0
% INFO    : Bus 82926	: V=0.9670187, theta=-8.633336 -> V=1.0, theta=0.0
% INFO    : Bus 82927	: V=0.9605012, theta=-9.167501 -> V=1.0, theta=0.0
% INFO    : Bus 82928	: V=0.9553819, theta=-9.228931 -> V=1.0, theta=0.0
% INFO    : Bus 82929	: V=0.9686287, theta=-9.073781 -> V=1.0, theta=0.0
% INFO    : Bus 82930	: V=0.9668771, theta=-9.315447 -> V=1.0, theta=0.0
% INFO    : Bus 82931	: V=0.95594, theta=-9.225957 -> V=1.0, theta=0.0
% INFO    : Bus 82932	: V=0.9678892, theta=-9.136624 -> V=1.0, theta=0.0
% INFO    : Bus 82933	: V=0.9629741, theta=-7.943978 -> V=1.0, theta=0.0
% INFO    : Bus 82934	: V=0.9609023, theta=-8.016844 -> V=1.0, theta=0.0
% INFO    : Bus 82935	: V=0.9668374, theta=-7.026177 -> V=1.0, theta=0.0
% INFO    : Bus 82936	: V=0.9759491, theta=-6.818486 -> V=1.0, theta=0.0
% INFO    : Bus 82937	: V=0.9678688, theta=-9.468458 -> V=1.0, theta=0.0
% INFO    : Bus 82938	: V=0.9651817, theta=-10.089502 -> V=1.0, theta=0.0
% INFO    : Bus 82939	: V=0.9581426, theta=-9.24749 -> V=1.0, theta=0.0
% INFO    : Bus 82940	: V=0.9535763, theta=-10.945164 -> V=1.0, theta=0.0
% INFO    : Bus 82941	: V=0.9691756, theta=-0.797543 -> V=1.0, theta=0.0
% INFO    : Bus 82942	: V=0.9672059, theta=-0.851207 -> V=1.0, theta=0.0
% INFO    : Bus 82943	: V=0.9708959, theta=-0.804364 -> V=1.0, theta=0.0
% INFO    : Bus 82944	: V=0.978538, theta=-0.196522 -> V=1.0, theta=0.0
% INFO    : Bus 82945	: V=0.9719112, theta=-0.754328 -> V=1.0, theta=0.0
% INFO    : Bus 82946	: V=0.9790867, theta=0.181252 -> V=1.0, theta=0.0
% INFO    : Bus 82947	: V=0.9724367, theta=-0.726321 -> V=1.0, theta=0.0
% INFO    : Bus 82948	: V=0.9758938, theta=-0.210651 -> V=1.0, theta=0.0
% INFO    : Bus 82949	: V=0.9716547, theta=-0.826604 -> V=1.0, theta=0.0
% INFO    : Bus 82950	: V=0.9665878, theta=-1.104758 -> V=1.0, theta=0.0
% INFO    : Bus 82951	: V=0.9804101, theta=0.257579 -> V=1.0, theta=0.0
% INFO    : Bus 82952	: V=0.9742441, theta=-0.564345 -> V=1.0, theta=0.0
% INFO    : Bus 82953	: V=0.9769725, theta=-0.055343 -> V=1.0, theta=0.0
% INFO    : Bus 82954	: V=0.9725218, theta=-0.743997 -> V=1.0, theta=0.0
% INFO    : Bus 82955	: V=0.9690966, theta=-1.051602 -> V=1.0, theta=0.0
% INFO    : Bus 82956	: V=0.9709752, theta=-1.091357 -> V=1.0, theta=0.0
% INFO    : Bus 82957	: V=0.9665825, theta=-1.052125 -> V=1.0, theta=0.0
% INFO    : Bus 82958	: V=0.9727946, theta=0.500718 -> V=1.0, theta=0.0
% INFO    : Bus 82959	: V=0.9705622, theta=0.370411 -> V=1.0, theta=0.0
% INFO    : Bus 82960	: V=0.9688566, theta=-0.240646 -> V=1.0, theta=0.0
% INFO    : Bus 82961	: V=0.9651784, theta=-0.927635 -> V=1.0, theta=0.0
% INFO    : Bus 82962	: V=0.9784796, theta=0.195246 -> V=1.0, theta=0.0
% INFO    : Bus 82963	: V=0.9689362, theta=-0.676452 -> V=1.0, theta=0.0
% INFO    : Bus 82964	: V=0.9835462, theta=0.559541 -> V=1.0, theta=0.0
% INFO    : Bus 82965	: V=0.9786825, theta=-0.026595 -> V=1.0, theta=0.0
% INFO    : Bus 82966	: V=0.965973, theta=-1.704245 -> V=1.0, theta=0.0
% INFO    : Bus 82967	: V=0.9756306, theta=-2.125377 -> V=1.0, theta=0.0
% INFO    : Bus 82968	: V=0.9763117, theta=-2.458016 -> V=1.0, theta=0.0
% INFO    : Bus 82969	: V=0.9828952, theta=-0.718226 -> V=1.0, theta=0.0
% INFO    : Bus 82970	: V=0.9820976, theta=-0.933703 -> V=1.0, theta=0.0
% INFO    : Bus 82971	: V=0.9693596, theta=-1.053383 -> V=1.0, theta=0.0
% INFO    : Bus 82972	: V=0.9567417, theta=-2.45093 -> V=1.0, theta=0.0
% INFO    : Bus 82973	: V=0.980085, theta=-0.528792 -> V=1.0, theta=0.0
% INFO    : Bus 82974	: V=0.9730818, theta=-1.212635 -> V=1.0, theta=0.0
% INFO    : Bus 82975	: V=0.9769417, theta=-0.026697 -> V=1.0, theta=0.0
% INFO    : Bus 82976	: V=0.9768793, theta=-0.129921 -> V=1.0, theta=0.0
% INFO    : Bus 82977	: V=0.9711923, theta=-0.689418 -> V=1.0, theta=0.0
% INFO    : Bus 82978	: V=0.9704138, theta=-0.684954 -> V=1.0, theta=0.0
% INFO    : Bus 82979	: V=0.9713218, theta=-0.804058 -> V=1.0, theta=0.0
% INFO    : Bus 82980	: V=0.9749211, theta=-0.247357 -> V=1.0, theta=0.0
% INFO    : Bus 82981	: V=0.9666543, theta=-1.18624 -> V=1.0, theta=0.0
% INFO    : Bus 82982	: V=0.9664977, theta=-1.091465 -> V=1.0, theta=0.0
% INFO    : Bus 82983	: V=0.9787458, theta=-0.248136 -> V=1.0, theta=0.0
% INFO    : Bus 82984	: V=0.9739371, theta=-2.096239 -> V=1.0, theta=0.0
% INFO    : Bus 82985	: V=0.9805282, theta=-13.520084 -> V=1.0, theta=0.0
% INFO    : Bus 82986	: V=0.9701651, theta=-14.637262 -> V=1.0, theta=0.0
% INFO    : Bus 82987	: V=0.9766328, theta=-14.384428 -> V=1.0, theta=0.0
% INFO    : Bus 82988	: V=0.9762139, theta=-14.129495 -> V=1.0, theta=0.0
% INFO    : Bus 82989	: V=0.9735463, theta=-14.988607 -> V=1.0, theta=0.0
% INFO    : Bus 82990	: V=0.97775, theta=-14.978807 -> V=1.0, theta=0.0
% INFO    : Bus 82991	: V=0.9740973, theta=-15.192762 -> V=1.0, theta=0.0
% INFO    : Bus 82992	: V=0.9749722, theta=-16.7052 -> V=1.0, theta=0.0
% INFO    : Bus 82993	: V=0.9751043, theta=-17.736772 -> V=1.0, theta=0.0
% INFO    : Bus 82994	: V=0.9588889, theta=-29.534503 -> V=1.0, theta=0.0
% INFO    : Bus 82995	: V=0.9589949, theta=-29.361483 -> V=1.0, theta=0.0
% INFO    : Bus 82996	: V=0.965437, theta=-29.641473 -> V=1.0, theta=0.0
% INFO    : Bus 82997	: V=0.9591342, theta=-30.387904 -> V=1.0, theta=0.0
% INFO    : Bus 82998	: V=0.9621027, theta=-30.047669 -> V=1.0, theta=0.0
% INFO    : Bus 82999	: V=0.9528548, theta=-30.664757 -> V=1.0, theta=0.0
% INFO    : Bus 83000	: V=0.9612332, theta=-28.713241 -> V=1.0, theta=0.0
% INFO    : Bus 83001	: V=0.9577782, theta=-30.555104 -> V=1.0, theta=0.0
% INFO    : Bus 83002	: V=0.9573582, theta=-16.695093 -> V=1.0, theta=0.0
% INFO    : Bus 83003	: V=0.9582676, theta=-17.51596 -> V=1.0, theta=0.0
% INFO    : Bus 83004	: V=0.9558808, theta=-17.80902 -> V=1.0, theta=0.0
% INFO    : Bus 83005	: V=0.9606734, theta=-14.503607 -> V=1.0, theta=0.0
% INFO    : Bus 83006	: V=0.9605181, theta=-14.572184 -> V=1.0, theta=0.0
% INFO    : Bus 83007	: V=0.9593278, theta=-15.267041 -> V=1.0, theta=0.0
% INFO    : Bus 83008	: V=0.9590203, theta=-16.690569 -> V=1.0, theta=0.0
% INFO    : Bus 83009	: V=0.9578961, theta=-17.036688 -> V=1.0, theta=0.0
% INFO    : Bus 83010	: V=0.9561123, theta=-19.006498 -> V=1.0, theta=0.0
% INFO    : Bus 83011	: V=0.954854, theta=-19.049306 -> V=1.0, theta=0.0
% INFO    : Bus 83012	: V=0.9572635, theta=-17.572777 -> V=1.0, theta=0.0
% INFO    : Bus 83013	: V=0.9602154, theta=-18.225859 -> V=1.0, theta=0.0
% INFO    : Bus 83014	: V=0.9576789, theta=-19.895009 -> V=1.0, theta=0.0
% INFO    : Bus 83015	: V=0.9577725, theta=-20.345552 -> V=1.0, theta=0.0
% INFO    : Bus 83016	: V=0.9596174, theta=-20.755788 -> V=1.0, theta=0.0
% INFO    : Bus 83017	: V=1.0012414, theta=5.217782 -> V=1.0, theta=0.0
% INFO    : Bus 83018	: V=0.9966106, theta=-17.967539 -> V=1.0, theta=0.0
% INFO    : Bus 83019	: V=0.9924396, theta=-17.949099 -> V=1.0, theta=0.0
% INFO    : Bus 83020	: V=0.9766375, theta=-19.061636 -> V=1.0, theta=0.0
% INFO    : Bus 83021	: V=0.9686422, theta=-18.821179 -> V=1.0, theta=0.0
% INFO    : Bus 83022	: V=0.9644958, theta=-19.992156 -> V=1.0, theta=0.0
% INFO    : Bus 83023	: V=0.9905533, theta=-18.953717 -> V=1.0, theta=0.0
% INFO    : Bus 83024	: V=0.9887388, theta=-19.236966 -> V=1.0, theta=0.0
% INFO    : Bus 83025	: V=0.9917724, theta=-19.449558 -> V=1.0, theta=0.0
% INFO    : Bus 83026	: V=0.9910166, theta=-19.529388 -> V=1.0, theta=0.0
% INFO    : Bus 83027	: V=0.9825332, theta=-20.356234 -> V=1.0, theta=0.0
% INFO    : Bus 83028	: V=0.9678026, theta=-21.456194 -> V=1.0, theta=0.0
% INFO    : Bus 83029	: V=0.9860171, theta=-19.841501 -> V=1.0, theta=0.0
% INFO    : Bus 83030	: V=0.9603911, theta=-20.999006 -> V=1.0, theta=0.0
% INFO    : Bus 83031	: V=0.9638835, theta=-20.896048 -> V=1.0, theta=0.0
% INFO    : Bus 83032	: V=0.9575758, theta=-22.030633 -> V=1.0, theta=0.0
% INFO    : Bus 83033	: V=0.9601995, theta=-22.063521 -> V=1.0, theta=0.0
% INFO    : Bus 83034	: V=0.9690096, theta=-21.75727 -> V=1.0, theta=0.0
% INFO    : Bus 83035	: V=0.980097, theta=-21.177751 -> V=1.0, theta=0.0
% INFO    : Bus 83036	: V=0.9712374, theta=-21.978465 -> V=1.0, theta=0.0
% INFO    : Bus 83037	: V=0.9806899, theta=-21.159879 -> V=1.0, theta=0.0
% INFO    : Bus 83038	: V=0.9795908, theta=-21.214295 -> V=1.0, theta=0.0
% INFO    : Bus 83039	: V=0.9707101, theta=-21.759468 -> V=1.0, theta=0.0
% INFO    : Bus 83040	: V=0.9760627, theta=-21.394309 -> V=1.0, theta=0.0
% INFO    : Bus 83041	: V=0.9734914, theta=-21.756104 -> V=1.0, theta=0.0
% INFO    : Bus 83042	: V=0.9712829, theta=-22.005801 -> V=1.0, theta=0.0
% INFO    : Bus 83043	: V=0.9769797, theta=-21.472374 -> V=1.0, theta=0.0
% INFO    : Bus 83044	: V=0.9733292, theta=-21.838418 -> V=1.0, theta=0.0
% INFO    : Bus 83045	: V=0.974417, theta=-21.948023 -> V=1.0, theta=0.0
% INFO    : Bus 83046	: V=0.9734368, theta=-22.017852 -> V=1.0, theta=0.0
% INFO    : Bus 83047	: V=0.9648438, theta=-22.038047 -> V=1.0, theta=0.0
% INFO    : Bus 83048	: V=0.9649703, theta=-22.032931 -> V=1.0, theta=0.0
% INFO    : Bus 83049	: V=0.9682193, theta=-21.970763 -> V=1.0, theta=0.0
% INFO    : Bus 83050	: V=0.9657012, theta=-22.067257 -> V=1.0, theta=0.0
% INFO    : Bus 83051	: V=0.9682725, theta=-21.840246 -> V=1.0, theta=0.0
% INFO    : Bus 83052	: V=0.9621593, theta=-22.014703 -> V=1.0, theta=0.0
% INFO    : Bus 83053	: V=0.9768579, theta=-21.100913 -> V=1.0, theta=0.0
% INFO    : Bus 83054	: V=0.9702823, theta=-21.710611 -> V=1.0, theta=0.0
% INFO    : Bus 83055	: V=0.9667512, theta=-21.855386 -> V=1.0, theta=0.0
% INFO    : Bus 83056	: V=0.9740775, theta=-21.532974 -> V=1.0, theta=0.0
% INFO    : Bus 83057	: V=0.9669132, theta=-22.229699 -> V=1.0, theta=0.0
% INFO    : Bus 83058	: V=0.9692488, theta=-22.052804 -> V=1.0, theta=0.0
% INFO    : Bus 83059	: V=0.9647759, theta=-22.470511 -> V=1.0, theta=0.0
% INFO    : Bus 83060	: V=0.9634787, theta=-22.703332 -> V=1.0, theta=0.0
% INFO    : Bus 83061	: V=0.971972, theta=-22.140534 -> V=1.0, theta=0.0
% INFO    : Bus 83062	: V=0.9749121, theta=-22.107519 -> V=1.0, theta=0.0
% INFO    : Bus 83063	: V=0.9717848, theta=-22.387601 -> V=1.0, theta=0.0
% INFO    : Bus 83064	: V=0.9717433, theta=-22.493257 -> V=1.0, theta=0.0
% INFO    : Bus 83065	: V=0.9725379, theta=-22.405526 -> V=1.0, theta=0.0
% INFO    : Bus 83066	: V=0.9719144, theta=-22.382057 -> V=1.0, theta=0.0
% INFO    : Bus 83067	: V=0.9677343, theta=-22.896484 -> V=1.0, theta=0.0
% INFO    : Bus 83068	: V=0.9702227, theta=-22.445017 -> V=1.0, theta=0.0
% INFO    : Bus 83069	: V=0.9655047, theta=-22.778983 -> V=1.0, theta=0.0
% INFO    : Bus 83070	: V=0.9709705, theta=-22.845433 -> V=1.0, theta=0.0
% INFO    : Bus 83071	: V=0.9682261, theta=-22.816767 -> V=1.0, theta=0.0
% INFO    : Bus 83072	: V=0.9798104, theta=-22.03469 -> V=1.0, theta=0.0
% INFO    : Bus 83073	: V=0.9761401, theta=-22.444484 -> V=1.0, theta=0.0
% INFO    : Bus 83074	: V=0.9880142, theta=-20.490835 -> V=1.0, theta=0.0
% INFO    : Bus 83075	: V=0.979646, theta=-21.233622 -> V=1.0, theta=0.0
% INFO    : Bus 83076	: V=0.9790154, theta=-21.328851 -> V=1.0, theta=0.0
% INFO    : Bus 83077	: V=0.9720196, theta=-21.156036 -> V=1.0, theta=0.0
% INFO    : Bus 83078	: V=0.9793325, theta=-21.613507 -> V=1.0, theta=0.0
% INFO    : Bus 83079	: V=0.9758297, theta=-21.998291 -> V=1.0, theta=0.0
% INFO    : Bus 83080	: V=0.9869909, theta=3.105926 -> V=1.0, theta=0.0
% INFO    : Bus 83081	: V=0.9981581, theta=4.802456 -> V=1.0, theta=0.0
% INFO    : Bus 83082	: V=0.9915135, theta=4.231651 -> V=1.0, theta=0.0
% INFO    : Bus 83083	: V=1.0138884, theta=11.631819 -> V=1.0, theta=0.0
% INFO    : Bus 83084	: V=1.0150593, theta=11.634728 -> V=1.0, theta=0.0
% INFO    : Bus 83085	: V=1.0189168, theta=11.63166 -> V=1.0, theta=0.0
% INFO    : Bus 83086	: V=1.0125904, theta=7.385306 -> V=1.0, theta=0.0
% INFO    : Bus 83087	: V=1.0186421, theta=8.35871 -> V=1.0, theta=0.0
% INFO    : Bus 83088	: V=1.0110899, theta=7.261873 -> V=1.0, theta=0.0
% INFO    : Bus 83089	: V=0.9811693, theta=0.386123 -> V=1.0, theta=0.0
% INFO    : Bus 83090	: V=0.9789683, theta=-0.529479 -> V=1.0, theta=0.0
% INFO    : Bus 83091	: V=0.9626175, theta=23.868425 -> V=1.0, theta=0.0
% INFO    : Bus 83092	: V=0.9606494, theta=37.659818 -> V=1.0, theta=0.0
% INFO    : Bus 83093	: V=0.9987002, theta=-4.898456 -> V=1.0, theta=0.0
% INFO    : Bus 83094	: V=0.9976479, theta=-5.260634 -> V=1.0, theta=0.0
% INFO    : Bus 83095	: V=1.0099754, theta=-4.296497 -> V=1.0, theta=0.0
% INFO    : Bus 83096	: V=1.0026839, theta=-5.019132 -> V=1.0, theta=0.0
% INFO    : Bus 83097	: V=0.9989227, theta=-4.775485 -> V=1.0, theta=0.0
% INFO    : Bus 83098	: V=0.996115, theta=-5.260853 -> V=1.0, theta=0.0
% INFO    : Bus 83099	: V=0.993795, theta=-5.130107 -> V=1.0, theta=0.0
% INFO    : Bus 83100	: V=0.9839477, theta=-4.968816 -> V=1.0, theta=0.0
% INFO    : Bus 83101	: V=0.9877977, theta=-26.371966 -> V=1.0, theta=0.0
% INFO    : Bus 83102	: V=0.9752072, theta=-27.20464 -> V=1.0, theta=0.0
% INFO    : Bus 83103	: V=0.9547988, theta=-29.632597 -> V=1.0, theta=0.0
% INFO    : Bus 83104	: V=0.9878491, theta=-26.979681 -> V=1.0, theta=0.0
% INFO    : Bus 83105	: V=0.9909142, theta=-27.377243 -> V=1.0, theta=0.0
% INFO    : Bus 83106	: V=0.981173, theta=-28.236168 -> V=1.0, theta=0.0
% INFO    : Bus 83107	: V=0.9734808, theta=-28.838189 -> V=1.0, theta=0.0
% INFO    : Bus 83108	: V=0.9766201, theta=-31.499414 -> V=1.0, theta=0.0
% INFO    : Bus 83109	: V=0.9869847, theta=-29.618212 -> V=1.0, theta=0.0
% INFO    : Bus 83110	: V=0.9809356, theta=-30.119322 -> V=1.0, theta=0.0
% INFO    : Bus 83111	: V=0.9900873, theta=-3.399027 -> V=1.0, theta=0.0
% INFO    : Bus 83112	: V=0.9800677, theta=-2.971634 -> V=1.0, theta=0.0
% INFO    : Bus 83113	: V=0.9676717, theta=-2.8703 -> V=1.0, theta=0.0
% INFO    : Bus 83114	: V=0.9690228, theta=-2.836561 -> V=1.0, theta=0.0
% INFO    : Bus 83115	: V=1.00284, theta=-2.592094 -> V=1.0, theta=0.0
% INFO    : Bus 83116	: V=0.9918303, theta=3.206191 -> V=1.0, theta=0.0
% INFO    : Bus 83117	: V=0.9860817, theta=2.627939 -> V=1.0, theta=0.0
% INFO    : Bus 83118	: V=0.9856149, theta=2.694835 -> V=1.0, theta=0.0
% INFO    : Bus 83119	: V=0.9818243, theta=2.410599 -> V=1.0, theta=0.0
% INFO    : Bus 83120	: V=0.9832396, theta=2.466381 -> V=1.0, theta=0.0
% INFO    : Bus 83121	: V=0.9784984, theta=2.435811 -> V=1.0, theta=0.0
% INFO    : Bus 83122	: V=0.9858887, theta=2.957835 -> V=1.0, theta=0.0
% INFO    : Bus 83123	: V=0.9774098, theta=2.335509 -> V=1.0, theta=0.0
% INFO    : Bus 83124	: V=0.9845876, theta=2.535022 -> V=1.0, theta=0.0
% INFO    : Bus 83125	: V=0.9873893, theta=2.63171 -> V=1.0, theta=0.0
% INFO    : Bus 83126	: V=0.9987657, theta=3.700912 -> V=1.0, theta=0.0
% INFO    : Bus 83127	: V=0.9809417, theta=1.766763 -> V=1.0, theta=0.0
% INFO    : Bus 83128	: V=0.9805207, theta=3.191561 -> V=1.0, theta=0.0
% INFO    : Bus 83129	: V=0.9906966, theta=3.534588 -> V=1.0, theta=0.0
% INFO    : Bus 83130	: V=0.9814456, theta=2.414473 -> V=1.0, theta=0.0
% INFO    : Bus 83131	: V=0.9894905, theta=2.596832 -> V=1.0, theta=0.0
% INFO    : Bus 83132	: V=0.9780106, theta=1.271108 -> V=1.0, theta=0.0
% INFO    : Bus 83133	: V=0.9760736, theta=0.998072 -> V=1.0, theta=0.0
% INFO    : Bus 83134	: V=0.9712776, theta=-18.557453 -> V=1.0, theta=0.0
% INFO    : Bus 83135	: V=0.9670941, theta=-18.489789 -> V=1.0, theta=0.0
% INFO    : Bus 83136	: V=0.9662753, theta=-18.660664 -> V=1.0, theta=0.0
% INFO    : Bus 83137	: V=0.9650025, theta=-19.145811 -> V=1.0, theta=0.0
% INFO    : Bus 83138	: V=0.9679484, theta=-17.455699 -> V=1.0, theta=0.0
% INFO    : Bus 83139	: V=0.9634066, theta=-18.247071 -> V=1.0, theta=0.0
% INFO    : Bus 83140	: V=0.9636676, theta=-16.806871 -> V=1.0, theta=0.0
% INFO    : Bus 83141	: V=0.9627859, theta=-18.519673 -> V=1.0, theta=0.0
% INFO    : Bus 83142	: V=0.9611063, theta=-18.779778 -> V=1.0, theta=0.0
% INFO    : Bus 83143	: V=0.9592605, theta=-19.660014 -> V=1.0, theta=0.0
% INFO    : Bus 83144	: V=0.9585419, theta=-20.144427 -> V=1.0, theta=0.0
% INFO    : Bus 83145	: V=0.9587475, theta=-20.321763 -> V=1.0, theta=0.0
% INFO    : Bus 83146	: V=0.9638955, theta=-19.64951 -> V=1.0, theta=0.0
% INFO    : Bus 83147	: V=0.9601163, theta=-19.8239 -> V=1.0, theta=0.0
% INFO    : Bus 83148	: V=0.9648995, theta=-19.524156 -> V=1.0, theta=0.0
% INFO    : Bus 83149	: V=0.9619132, theta=-19.60808 -> V=1.0, theta=0.0
% INFO    : Bus 83150	: V=0.9623524, theta=-18.988572 -> V=1.0, theta=0.0
% INFO    : Bus 83151	: V=0.9637071, theta=-20.055871 -> V=1.0, theta=0.0
% INFO    : Bus 83152	: V=0.960973, theta=-18.606704 -> V=1.0, theta=0.0
% INFO    : Bus 83153	: V=0.9547362, theta=-19.792009 -> V=1.0, theta=0.0
% INFO    : Bus 83154	: V=0.9606765, theta=-19.691135 -> V=1.0, theta=0.0
% INFO    : Bus 83155	: V=0.9596158, theta=-20.730469 -> V=1.0, theta=0.0
% INFO    : Bus 83156	: V=0.9646544, theta=-19.903801 -> V=1.0, theta=0.0
% INFO    : Bus 83157	: V=0.9636392, theta=-20.617392 -> V=1.0, theta=0.0
% INFO    : Bus 83158	: V=0.9655227, theta=-20.422189 -> V=1.0, theta=0.0
% INFO    : Bus 83159	: V=0.9655836, theta=-20.807351 -> V=1.0, theta=0.0
% INFO    : Bus 83160	: V=0.9613999, theta=-19.996652 -> V=1.0, theta=0.0
% INFO    : Bus 83161	: V=0.9599784, theta=-21.287381 -> V=1.0, theta=0.0
% INFO    : Bus 83162	: V=0.9572038, theta=-22.711188 -> V=1.0, theta=0.0
% INFO    : Bus 83163	: V=0.9579578, theta=-21.425666 -> V=1.0, theta=0.0
% INFO    : Bus 83164	: V=0.9604224, theta=-21.656071 -> V=1.0, theta=0.0
% INFO    : Bus 83165	: V=0.9597532, theta=-21.246991 -> V=1.0, theta=0.0
% INFO    : Bus 83166	: V=0.9693366, theta=-20.737222 -> V=1.0, theta=0.0
% INFO    : Bus 83167	: V=0.961573, theta=-21.069106 -> V=1.0, theta=0.0
% INFO    : Bus 83168	: V=0.9670513, theta=-19.895197 -> V=1.0, theta=0.0
% INFO    : Bus 83169	: V=0.9631696, theta=-20.520084 -> V=1.0, theta=0.0
% INFO    : Bus 83170	: V=0.9577688, theta=-20.748504 -> V=1.0, theta=0.0
% INFO    : Bus 83171	: V=0.9603039, theta=-21.543503 -> V=1.0, theta=0.0
% INFO    : Bus 83172	: V=0.9589655, theta=-21.113955 -> V=1.0, theta=0.0
% INFO    : Bus 83173	: V=0.9591435, theta=-20.878122 -> V=1.0, theta=0.0
% INFO    : Bus 83174	: V=0.9585156, theta=-21.30336 -> V=1.0, theta=0.0
% INFO    : Bus 83175	: V=0.9585455, theta=-21.55159 -> V=1.0, theta=0.0
% INFO    : Bus 83176	: V=0.9577581, theta=-21.462789 -> V=1.0, theta=0.0
% INFO    : Bus 83177	: V=0.9584903, theta=-20.70457 -> V=1.0, theta=0.0
% INFO    : Bus 83178	: V=0.9611379, theta=-19.628515 -> V=1.0, theta=0.0
% INFO    : Bus 83179	: V=0.9620276, theta=-20.522044 -> V=1.0, theta=0.0
% INFO    : Bus 83180	: V=0.9603961, theta=-20.683012 -> V=1.0, theta=0.0
% INFO    : Bus 83181	: V=0.9605583, theta=-20.866461 -> V=1.0, theta=0.0
% INFO    : Bus 83182	: V=0.9592451, theta=-21.154705 -> V=1.0, theta=0.0
% INFO    : Bus 83183	: V=0.9599865, theta=-20.820933 -> V=1.0, theta=0.0
% INFO    : Bus 83184	: V=0.9559762, theta=-22.12766 -> V=1.0, theta=0.0
% INFO    : Bus 83185	: V=0.9601663, theta=-22.2685 -> V=1.0, theta=0.0
% INFO    : Bus 83186	: V=0.9594521, theta=-22.519033 -> V=1.0, theta=0.0
% INFO    : Bus 83187	: V=0.9596297, theta=-22.057373 -> V=1.0, theta=0.0
% INFO    : Bus 83188	: V=0.9687134, theta=-20.38532 -> V=1.0, theta=0.0
% INFO    : Bus 83189	: V=0.9678423, theta=-21.768399 -> V=1.0, theta=0.0
% INFO    : Bus 83190	: V=0.9651643, theta=-21.913347 -> V=1.0, theta=0.0
% INFO    : Bus 83191	: V=0.9576972, theta=-23.069341 -> V=1.0, theta=0.0
% INFO    : Bus 83192	: V=0.957776, theta=-23.465326 -> V=1.0, theta=0.0
% INFO    : Bus 83193	: V=0.9575091, theta=-23.563146 -> V=1.0, theta=0.0
% INFO    : Bus 83194	: V=0.9585077, theta=-23.449009 -> V=1.0, theta=0.0
% INFO    : Bus 83195	: V=0.9599952, theta=-23.416706 -> V=1.0, theta=0.0
% INFO    : Bus 83196	: V=0.9596271, theta=-23.314192 -> V=1.0, theta=0.0
% INFO    : Bus 83197	: V=0.9597878, theta=-22.982737 -> V=1.0, theta=0.0
% INFO    : Bus 83198	: V=0.9578091, theta=-23.698555 -> V=1.0, theta=0.0
% INFO    : Bus 83199	: V=0.9762613, theta=-22.081889 -> V=1.0, theta=0.0
% INFO    : Bus 83200	: V=0.966604, theta=-22.865106 -> V=1.0, theta=0.0
% INFO    : Bus 83201	: V=0.9761095, theta=-22.137762 -> V=1.0, theta=0.0
% INFO    : Bus 83202	: V=0.967778, theta=-22.976301 -> V=1.0, theta=0.0
% INFO    : Bus 83203	: V=0.9658934, theta=-23.266086 -> V=1.0, theta=0.0
% INFO    : Bus 83204	: V=0.9589932, theta=-22.618014 -> V=1.0, theta=0.0
% INFO    : Bus 83205	: V=0.9630557, theta=-23.008208 -> V=1.0, theta=0.0
% INFO    : Bus 83206	: V=0.9713777, theta=-22.40938 -> V=1.0, theta=0.0
% INFO    : Bus 83207	: V=0.9692668, theta=-22.614738 -> V=1.0, theta=0.0
% INFO    : Bus 83208	: V=0.9641344, theta=-19.875185 -> V=1.0, theta=0.0
% INFO    : Bus 83209	: V=0.9621418, theta=-20.506983 -> V=1.0, theta=0.0
% INFO    : Bus 83210	: V=0.9618632, theta=-20.688306 -> V=1.0, theta=0.0
% INFO    : Bus 83211	: V=0.9600356, theta=-20.910986 -> V=1.0, theta=0.0
% INFO    : Bus 83212	: V=0.9576354, theta=-21.110578 -> V=1.0, theta=0.0
% INFO    : Bus 83213	: V=0.9582291, theta=-21.801719 -> V=1.0, theta=0.0
% INFO    : Bus 83214	: V=0.9617839, theta=-21.064026 -> V=1.0, theta=0.0
% INFO    : Bus 83215	: V=0.9602608, theta=-21.303358 -> V=1.0, theta=0.0
% INFO    : Bus 83216	: V=0.9617881, theta=-21.695735 -> V=1.0, theta=0.0
% INFO    : Bus 83217	: V=0.9627459, theta=-22.051935 -> V=1.0, theta=0.0
% INFO    : Bus 83218	: V=0.9626728, theta=-22.077643 -> V=1.0, theta=0.0
% INFO    : Bus 83219	: V=0.9673488, theta=-21.987056 -> V=1.0, theta=0.0
% INFO    : Bus 83220	: V=0.9664405, theta=-22.143921 -> V=1.0, theta=0.0
% INFO    : Bus 83221	: V=0.9653556, theta=-22.397605 -> V=1.0, theta=0.0
% INFO    : Bus 83222	: V=0.9612815, theta=-22.540491 -> V=1.0, theta=0.0
% INFO    : Bus 83223	: V=0.9606315, theta=-22.579895 -> V=1.0, theta=0.0
% INFO    : Bus 83224	: V=0.9584903, theta=-22.838289 -> V=1.0, theta=0.0
% INFO    : Bus 83225	: V=0.9919303, theta=4.384938 -> V=1.0, theta=0.0
% INFO    : Bus 83226	: V=1.0052933, theta=5.962204 -> V=1.0, theta=0.0
% INFO    : Bus 83227	: V=1.002619, theta=5.559912 -> V=1.0, theta=0.0
% INFO    : Bus 83228	: V=0.9717644, theta=-6.527499 -> V=1.0, theta=0.0
% INFO    : Bus 83229	: V=1.0128327, theta=9.397418 -> V=1.0, theta=0.0
% INFO    : Bus 83230	: V=1.0054828, theta=8.617545 -> V=1.0, theta=0.0
% INFO    : Bus 83231	: V=0.9904592, theta=0.582189 -> V=1.0, theta=0.0
% INFO    : Bus 83232	: V=1.0099901, theta=-1.560929 -> V=1.0, theta=0.0
% INFO    : Bus 83233	: V=1.0151975, theta=-0.626039 -> V=1.0, theta=0.0
% INFO    : Bus 83234	: V=1.0026214, theta=-2.340481 -> V=1.0, theta=0.0
% INFO    : Bus 83235	: V=0.9854733, theta=1.547997 -> V=1.0, theta=0.0
% INFO    : Bus 83236	: V=0.9948593, theta=2.75302 -> V=1.0, theta=0.0
% INFO    : Bus 83237	: V=0.9946006, theta=3.093564 -> V=1.0, theta=0.0
% INFO    : Bus 83238	: V=1.0073342, theta=4.083601 -> V=1.0, theta=0.0
% INFO    : Bus 83239	: V=1.0021578, theta=3.661697 -> V=1.0, theta=0.0
% INFO    : Bus 83240	: V=1.0060253, theta=3.870788 -> V=1.0, theta=0.0
% INFO    : Bus 83241	: V=1.0084624, theta=3.856403 -> V=1.0, theta=0.0
% INFO    : Bus 83242	: V=1.0062409, theta=3.495985 -> V=1.0, theta=0.0
% INFO    : Bus 83243	: V=0.9841296, theta=0.808251 -> V=1.0, theta=0.0
% INFO    : Bus 83244	: V=0.9881323, theta=1.06925 -> V=1.0, theta=0.0
% INFO    : Bus 83245	: V=0.986942, theta=1.008792 -> V=1.0, theta=0.0
% INFO    : Bus 83246	: V=0.9948789, theta=1.780476 -> V=1.0, theta=0.0
% INFO    : Bus 83247	: V=0.9998631, theta=1.501802 -> V=1.0, theta=0.0
% INFO    : Bus 83248	: V=1.0092171, theta=2.868873 -> V=1.0, theta=0.0
% INFO    : Bus 83249	: V=0.9886721, theta=1.43074 -> V=1.0, theta=0.0
% INFO    : Bus 83250	: V=0.9831177, theta=0.715739 -> V=1.0, theta=0.0
% INFO    : Bus 83251	: V=1.0107061, theta=2.635153 -> V=1.0, theta=0.0
% INFO    : Bus 83252	: V=1.0096927, theta=2.252216 -> V=1.0, theta=0.0
% INFO    : Bus 83253	: V=1.0064206, theta=1.92774 -> V=1.0, theta=0.0
% INFO    : Bus 83254	: V=1.007012, theta=1.933838 -> V=1.0, theta=0.0
% INFO    : Bus 83255	: V=0.9922687, theta=-2.312079 -> V=1.0, theta=0.0
% INFO    : Bus 83256	: V=0.99861, theta=-7.175707 -> V=1.0, theta=0.0
% INFO    : Bus 83257	: V=0.9943477, theta=-7.402661 -> V=1.0, theta=0.0
% INFO    : Bus 83258	: V=0.9955039, theta=-7.367726 -> V=1.0, theta=0.0
% INFO    : Bus 83259	: V=0.99541, theta=-7.580374 -> V=1.0, theta=0.0
% INFO    : Bus 83260	: V=0.9954605, theta=-7.716666 -> V=1.0, theta=0.0
% INFO    : Bus 83261	: V=0.9952752, theta=-7.432621 -> V=1.0, theta=0.0
% INFO    : Bus 83262	: V=0.9959402, theta=-7.317358 -> V=1.0, theta=0.0
% INFO    : Bus 83263	: V=0.9963367, theta=-7.326297 -> V=1.0, theta=0.0
% INFO    : Bus 83264	: V=1.0000384, theta=-6.881728 -> V=1.0, theta=0.0
% INFO    : Bus 83265	: V=1.0043817, theta=-5.544535 -> V=1.0, theta=0.0
% INFO    : Bus 83266	: V=0.9956665, theta=-7.247527 -> V=1.0, theta=0.0
% INFO    : Bus 83267	: V=0.999905, theta=-6.701243 -> V=1.0, theta=0.0
% INFO    : Bus 83268	: V=0.9968792, theta=-7.15101 -> V=1.0, theta=0.0
% INFO    : Bus 83269	: V=0.9999797, theta=-6.636204 -> V=1.0, theta=0.0
% INFO    : Bus 83270	: V=0.9965566, theta=-7.207221 -> V=1.0, theta=0.0
% INFO    : Bus 83271	: V=0.9997665, theta=-6.745497 -> V=1.0, theta=0.0
% INFO    : Bus 83272	: V=0.9949713, theta=-7.236137 -> V=1.0, theta=0.0
% INFO    : Bus 83273	: V=0.9963778, theta=-7.600967 -> V=1.0, theta=0.0
% INFO    : Bus 83274	: V=0.9939274, theta=-7.86524 -> V=1.0, theta=0.0
% INFO    : Bus 83275	: V=1.0031162, theta=-6.469246 -> V=1.0, theta=0.0
% INFO    : Bus 83276	: V=0.9990225, theta=-7.243618 -> V=1.0, theta=0.0
% INFO    : Bus 83277	: V=0.9989645, theta=-8.374892 -> V=1.0, theta=0.0
% INFO    : Bus 83278	: V=0.9971245, theta=-8.393281 -> V=1.0, theta=0.0
% INFO    : Bus 83279	: V=0.9947215, theta=-7.712965 -> V=1.0, theta=0.0
% INFO    : Bus 83280	: V=0.9968774, theta=-7.884433 -> V=1.0, theta=0.0
% INFO    : Bus 83281	: V=0.9957322, theta=-7.99358 -> V=1.0, theta=0.0
% INFO    : Bus 83282	: V=0.9921004, theta=-7.264914 -> V=1.0, theta=0.0
% INFO    : Bus 83283	: V=0.9954778, theta=-7.122539 -> V=1.0, theta=0.0
% INFO    : Bus 83284	: V=0.9952796, theta=-6.611292 -> V=1.0, theta=0.0
% INFO    : Bus 83285	: V=0.9937072, theta=-6.208455 -> V=1.0, theta=0.0
% INFO    : Bus 83286	: V=0.9826705, theta=-7.59686 -> V=1.0, theta=0.0
% INFO    : Bus 83287	: V=0.9770909, theta=-8.749783 -> V=1.0, theta=0.0
% INFO    : Bus 83288	: V=0.9945292, theta=-8.419102 -> V=1.0, theta=0.0
% INFO    : Bus 83289	: V=0.9927117, theta=-8.739323 -> V=1.0, theta=0.0
% INFO    : Bus 83290	: V=0.9926567, theta=-9.994289 -> V=1.0, theta=0.0
% INFO    : Bus 83291	: V=1.0003413, theta=-16.834024 -> V=1.0, theta=0.0
% INFO    : Bus 83292	: V=0.9951392, theta=-16.679553 -> V=1.0, theta=0.0
% INFO    : Bus 83293	: V=1.0087834, theta=-16.906586 -> V=1.0, theta=0.0
% INFO    : Bus 83294	: V=1.0069071, theta=-17.355653 -> V=1.0, theta=0.0
% INFO    : Bus 83295	: V=1.0087332, theta=-17.218731 -> V=1.0, theta=0.0
% INFO    : Bus 83296	: V=1.0074621, theta=-17.589013 -> V=1.0, theta=0.0
% INFO    : Bus 83297	: V=0.9970571, theta=-18.400192 -> V=1.0, theta=0.0
% INFO    : Bus 83298	: V=0.9954805, theta=-19.043784 -> V=1.0, theta=0.0
% INFO    : Bus 83299	: V=0.9971494, theta=-15.062393 -> V=1.0, theta=0.0
% INFO    : Bus 83300	: V=0.9289268, theta=-14.472126 -> V=1.0, theta=0.0
% INFO    : Bus 83301	: V=0.9250671, theta=-18.890622 -> V=1.0, theta=0.0
% INFO    : Bus 83302	: V=0.9263801, theta=-17.90948 -> V=1.0, theta=0.0
% INFO    : Bus 83303	: V=0.933228, theta=-14.696607 -> V=1.0, theta=0.0
% INFO    : Bus 83304	: V=0.9224879, theta=-17.302364 -> V=1.0, theta=0.0
% INFO    : Bus 83305	: V=0.9361024, theta=-16.863609 -> V=1.0, theta=0.0
% INFO    : Bus 83306	: V=0.9960431, theta=-12.765122 -> V=1.0, theta=0.0
% INFO    : Bus 83307	: V=0.9811346, theta=-13.270809 -> V=1.0, theta=0.0
% INFO    : Bus 83308	: V=0.9703914, theta=12.61814 -> V=1.0, theta=0.0
% INFO    : Bus 83309	: V=0.9678509, theta=-10.295744 -> V=1.0, theta=0.0
% INFO    : Bus 83310	: V=0.9581907, theta=-13.297786 -> V=1.0, theta=0.0
% INFO    : Bus 83311	: V=0.9638009, theta=-11.340615 -> V=1.0, theta=0.0
% INFO    : Bus 83312	: V=0.9607383, theta=-12.953076 -> V=1.0, theta=0.0
% INFO    : Bus 83313	: V=0.997897, theta=-8.870935 -> V=1.0, theta=0.0
% INFO    : Bus 83314	: V=0.9886286, theta=-9.734159 -> V=1.0, theta=0.0
% INFO    : Bus 83315	: V=0.9827772, theta=-11.702047 -> V=1.0, theta=0.0
% INFO    : Bus 83316	: V=0.9921094, theta=-3.029987 -> V=1.0, theta=0.0
% INFO    : Bus 83317	: V=0.9892088, theta=-2.72886 -> V=1.0, theta=0.0
% INFO    : Bus 83318	: V=0.9789155, theta=-6.357267 -> V=1.0, theta=0.0
% INFO    : Bus 83319	: V=0.9816412, theta=-5.00127 -> V=1.0, theta=0.0
% INFO    : Bus 83320	: V=0.9861978, theta=-4.418405 -> V=1.0, theta=0.0
% INFO    : Bus 83321	: V=0.9801656, theta=-6.213373 -> V=1.0, theta=0.0
% INFO    : Bus 83322	: V=0.9746129, theta=-6.696776 -> V=1.0, theta=0.0
% INFO    : Bus 83323	: V=0.9876926, theta=-4.113963 -> V=1.0, theta=0.0
% INFO    : Bus 83324	: V=0.9692918, theta=-25.576368 -> V=1.0, theta=0.0
% INFO    : Bus 83325	: V=0.9686534, theta=-25.708912 -> V=1.0, theta=0.0
% INFO    : Bus 83326	: V=0.9679002, theta=-25.377282 -> V=1.0, theta=0.0
% INFO    : Bus 83327	: V=0.9650172, theta=-26.09059 -> V=1.0, theta=0.0
% INFO    : Bus 83328	: V=0.9659987, theta=-26.1242 -> V=1.0, theta=0.0
% INFO    : Bus 83329	: V=0.9667259, theta=-24.765651 -> V=1.0, theta=0.0
% INFO    : Bus 83330	: V=0.969331, theta=-25.854901 -> V=1.0, theta=0.0
% INFO    : Bus 83331	: V=0.9746499, theta=-26.192513 -> V=1.0, theta=0.0
% INFO    : Bus 83332	: V=0.9758771, theta=-26.302136 -> V=1.0, theta=0.0
% INFO    : Bus 83333	: V=0.9693305, theta=-26.155913 -> V=1.0, theta=0.0
% INFO    : Bus 83334	: V=0.9679879, theta=-26.218242 -> V=1.0, theta=0.0
% INFO    : Bus 83335	: V=0.9623454, theta=-26.130442 -> V=1.0, theta=0.0
% INFO    : Bus 83336	: V=0.9689828, theta=-26.417385 -> V=1.0, theta=0.0
% INFO    : Bus 83337	: V=0.9495541, theta=-28.143789 -> V=1.0, theta=0.0
% INFO    : Bus 83338	: V=0.9594806, theta=-28.071164 -> V=1.0, theta=0.0
% INFO    : Bus 83339	: V=0.9722716, theta=-22.609029 -> V=1.0, theta=0.0
% INFO    : Bus 83340	: V=0.9653857, theta=-24.651149 -> V=1.0, theta=0.0
% INFO    : Bus 83341	: V=0.9682779, theta=-25.328521 -> V=1.0, theta=0.0
% INFO    : Bus 83342	: V=0.9744331, theta=-22.472319 -> V=1.0, theta=0.0
% INFO    : Bus 83343	: V=0.9767579, theta=-22.206068 -> V=1.0, theta=0.0
% INFO    : Bus 83344	: V=0.9826937, theta=-22.018821 -> V=1.0, theta=0.0
% INFO    : Bus 83345	: V=0.9706778, theta=-22.897609 -> V=1.0, theta=0.0
% INFO    : Bus 83346	: V=0.9707646, theta=-22.905086 -> V=1.0, theta=0.0
% INFO    : Bus 83347	: V=0.9743471, theta=-23.032967 -> V=1.0, theta=0.0
% INFO    : Bus 83348	: V=0.9757542, theta=-22.57897 -> V=1.0, theta=0.0
% INFO    : Bus 83349	: V=0.9753625, theta=-22.569508 -> V=1.0, theta=0.0
% INFO    : Bus 83350	: V=0.9711693, theta=-23.063278 -> V=1.0, theta=0.0
% INFO    : Bus 83351	: V=0.9698512, theta=-23.206781 -> V=1.0, theta=0.0
% INFO    : Bus 83352	: V=0.9818269, theta=-22.538578 -> V=1.0, theta=0.0
% INFO    : Bus 83353	: V=0.9749896, theta=-23.108411 -> V=1.0, theta=0.0
% INFO    : Bus 83354	: V=0.9830739, theta=-22.255997 -> V=1.0, theta=0.0
% INFO    : Bus 83355	: V=0.9852353, theta=-21.898444 -> V=1.0, theta=0.0
% INFO    : Bus 83356	: V=0.9827722, theta=-22.433739 -> V=1.0, theta=0.0
% INFO    : Bus 83357	: V=0.992222, theta=-21.155411 -> V=1.0, theta=0.0
% INFO    : Bus 83358	: V=0.9913157, theta=-21.7356 -> V=1.0, theta=0.0
% INFO    : Bus 83359	: V=0.9742768, theta=-23.096932 -> V=1.0, theta=0.0
% INFO    : Bus 83360	: V=0.9781371, theta=-22.727122 -> V=1.0, theta=0.0
% INFO    : Bus 83361	: V=0.9744295, theta=-23.13504 -> V=1.0, theta=0.0
% INFO    : Bus 83362	: V=0.9798756, theta=-22.975592 -> V=1.0, theta=0.0
% INFO    : Bus 83363	: V=0.9792462, theta=-23.020999 -> V=1.0, theta=0.0
% INFO    : Bus 83364	: V=0.9816752, theta=-23.144481 -> V=1.0, theta=0.0
% INFO    : Bus 83365	: V=0.9805641, theta=-23.144513 -> V=1.0, theta=0.0
% INFO    : Bus 83366	: V=0.9782409, theta=-23.107648 -> V=1.0, theta=0.0
% INFO    : Bus 83367	: V=0.9830422, theta=-23.227931 -> V=1.0, theta=0.0
% INFO    : Bus 83368	: V=0.9797873, theta=-23.045097 -> V=1.0, theta=0.0
% INFO    : Bus 83369	: V=0.9918703, theta=-22.683783 -> V=1.0, theta=0.0
% INFO    : Bus 83370	: V=0.9935308, theta=-22.69234 -> V=1.0, theta=0.0
% INFO    : Bus 83371	: V=0.9910924, theta=-22.984759 -> V=1.0, theta=0.0
% INFO    : Bus 83372	: V=0.9893129, theta=-23.131326 -> V=1.0, theta=0.0
% INFO    : Bus 83373	: V=0.9913779, theta=-23.002982 -> V=1.0, theta=0.0
% INFO    : Bus 83374	: V=0.9914384, theta=-23.149267 -> V=1.0, theta=0.0
% INFO    : Bus 83375	: V=0.9941067, theta=-22.765181 -> V=1.0, theta=0.0
% INFO    : Bus 83376	: V=0.9894663, theta=-23.123749 -> V=1.0, theta=0.0
% INFO    : Bus 83377	: V=0.9886981, theta=-22.920796 -> V=1.0, theta=0.0
% INFO    : Bus 83378	: V=0.9857021, theta=-23.128248 -> V=1.0, theta=0.0
% INFO    : Bus 83379	: V=0.9856386, theta=-23.180992 -> V=1.0, theta=0.0
% INFO    : Bus 83380	: V=0.9882609, theta=-23.134288 -> V=1.0, theta=0.0
% INFO    : Bus 83381	: V=0.9876333, theta=-22.757407 -> V=1.0, theta=0.0
% INFO    : Bus 83382	: V=0.9850794, theta=-23.122343 -> V=1.0, theta=0.0
% INFO    : Bus 83383	: V=0.974614, theta=-23.619791 -> V=1.0, theta=0.0
% INFO    : Bus 83384	: V=0.9741349, theta=-23.462669 -> V=1.0, theta=0.0
% INFO    : Bus 83385	: V=0.9681654, theta=-23.577398 -> V=1.0, theta=0.0
% INFO    : Bus 83386	: V=0.9727098, theta=-23.373424 -> V=1.0, theta=0.0
% INFO    : Bus 83387	: V=0.9769602, theta=-23.427101 -> V=1.0, theta=0.0
% INFO    : Bus 83388	: V=0.9786975, theta=-23.409171 -> V=1.0, theta=0.0
% INFO    : Bus 83389	: V=0.973958, theta=-23.234649 -> V=1.0, theta=0.0
% INFO    : Bus 83390	: V=0.974326, theta=-23.657793 -> V=1.0, theta=0.0
% INFO    : Bus 83391	: V=0.9693448, theta=-23.833949 -> V=1.0, theta=0.0
% INFO    : Bus 83392	: V=0.9723531, theta=-23.743944 -> V=1.0, theta=0.0
% INFO    : Bus 83393	: V=0.9659746, theta=-23.742964 -> V=1.0, theta=0.0
% INFO    : Bus 83394	: V=0.9641194, theta=-23.916771 -> V=1.0, theta=0.0
% INFO    : Bus 83395	: V=0.9841066, theta=-21.927745 -> V=1.0, theta=0.0
% INFO    : Bus 83396	: V=0.9629851, theta=-22.753498 -> V=1.0, theta=0.0
% INFO    : Bus 83397	: V=0.958745, theta=-23.60516 -> V=1.0, theta=0.0
% INFO    : Bus 83398	: V=0.96375, theta=-23.613341 -> V=1.0, theta=0.0
% INFO    : Bus 83399	: V=0.9643554, theta=-23.829021 -> V=1.0, theta=0.0
% INFO    : Bus 83400	: V=0.97393, theta=-23.217511 -> V=1.0, theta=0.0
% INFO    : Bus 83401	: V=0.9701107, theta=-23.456432 -> V=1.0, theta=0.0
% INFO    : Bus 83402	: V=0.967968, theta=-23.766801 -> V=1.0, theta=0.0
% INFO    : Bus 83403	: V=0.9652567, theta=-23.91747 -> V=1.0, theta=0.0
% INFO    : Bus 83404	: V=0.9599944, theta=-23.264097 -> V=1.0, theta=0.0
% INFO    : Bus 83405	: V=0.9614792, theta=-23.517427 -> V=1.0, theta=0.0
% INFO    : Bus 83406	: V=0.9674809, theta=-23.385509 -> V=1.0, theta=0.0
% INFO    : Bus 83407	: V=0.9668952, theta=-23.300683 -> V=1.0, theta=0.0
% INFO    : Bus 83408	: V=0.9651743, theta=-23.319567 -> V=1.0, theta=0.0
% INFO    : Bus 83409	: V=0.9657465, theta=-23.35867 -> V=1.0, theta=0.0
% INFO    : Bus 83410	: V=0.9730494, theta=-22.866118 -> V=1.0, theta=0.0
% INFO    : Bus 83411	: V=0.9702145, theta=-23.177511 -> V=1.0, theta=0.0
% INFO    : Bus 83412	: V=0.9817559, theta=-21.826392 -> V=1.0, theta=0.0
% INFO    : Bus 83413	: V=0.9744714, theta=-22.888004 -> V=1.0, theta=0.0
% INFO    : Bus 83414	: V=0.9738023, theta=-23.025098 -> V=1.0, theta=0.0
% INFO    : Bus 83415	: V=0.9748604, theta=-23.011967 -> V=1.0, theta=0.0
% INFO    : Bus 83416	: V=0.9721343, theta=-23.534662 -> V=1.0, theta=0.0
% INFO    : Bus 83417	: V=0.9712807, theta=-23.55977 -> V=1.0, theta=0.0
% INFO    : Bus 83418	: V=0.9688542, theta=-23.703197 -> V=1.0, theta=0.0
% INFO    : Bus 83419	: V=0.962362, theta=-23.48544 -> V=1.0, theta=0.0
% INFO    : Bus 83420	: V=0.9653439, theta=-23.143401 -> V=1.0, theta=0.0
% INFO    : Bus 83421	: V=0.9661204, theta=-23.634628 -> V=1.0, theta=0.0
% INFO    : Bus 83422	: V=0.9655244, theta=-23.784984 -> V=1.0, theta=0.0
% INFO    : Bus 83423	: V=0.9743672, theta=-23.161851 -> V=1.0, theta=0.0
% INFO    : Bus 83424	: V=0.9689696, theta=-23.902052 -> V=1.0, theta=0.0
% INFO    : Bus 83425	: V=0.968639, theta=-24.145513 -> V=1.0, theta=0.0
% INFO    : Bus 83426	: V=0.9753053, theta=-23.321999 -> V=1.0, theta=0.0
% INFO    : Bus 83427	: V=0.9737298, theta=-23.955382 -> V=1.0, theta=0.0
% INFO    : Bus 83428	: V=0.974685, theta=-23.525305 -> V=1.0, theta=0.0
% INFO    : Bus 83429	: V=0.969477, theta=-24.096818 -> V=1.0, theta=0.0
% INFO    : Bus 83430	: V=0.965987, theta=-24.926357 -> V=1.0, theta=0.0
% INFO    : Bus 83431	: V=0.9645651, theta=-24.129982 -> V=1.0, theta=0.0
% INFO    : Bus 83432	: V=0.9667645, theta=-23.738716 -> V=1.0, theta=0.0
% INFO    : Bus 83433	: V=0.9639573, theta=-24.379486 -> V=1.0, theta=0.0
% INFO    : Bus 83434	: V=0.9636199, theta=-24.410607 -> V=1.0, theta=0.0
% INFO    : Bus 83435	: V=0.9693843, theta=-24.018046 -> V=1.0, theta=0.0
% INFO    : Bus 83436	: V=0.9626113, theta=-24.485311 -> V=1.0, theta=0.0
% INFO    : Bus 83437	: V=0.9707367, theta=-23.530429 -> V=1.0, theta=0.0
% INFO    : Bus 83438	: V=0.9670437, theta=-23.827876 -> V=1.0, theta=0.0
% INFO    : Bus 83439	: V=0.9701239, theta=-23.708725 -> V=1.0, theta=0.0
% INFO    : Bus 83440	: V=0.9689835, theta=-23.873189 -> V=1.0, theta=0.0
% INFO    : Bus 83441	: V=0.9669052, theta=-24.10825 -> V=1.0, theta=0.0
% INFO    : Bus 83442	: V=0.9641851, theta=-24.406355 -> V=1.0, theta=0.0
% INFO    : Bus 83443	: V=0.9624787, theta=-24.480687 -> V=1.0, theta=0.0
% INFO    : Bus 83444	: V=0.962391, theta=-24.48328 -> V=1.0, theta=0.0
% INFO    : Bus 83445	: V=0.9598292, theta=-24.640614 -> V=1.0, theta=0.0
% INFO    : Bus 83446	: V=0.963686, theta=-24.13848 -> V=1.0, theta=0.0
% INFO    : Bus 83447	: V=0.969877, theta=-24.329754 -> V=1.0, theta=0.0
% INFO    : Bus 83448	: V=0.9663792, theta=-24.350422 -> V=1.0, theta=0.0
% INFO    : Bus 83449	: V=0.9905193, theta=-22.814052 -> V=1.0, theta=0.0
% INFO    : Bus 83450	: V=0.9869494, theta=-23.23263 -> V=1.0, theta=0.0
% INFO    : Bus 83451	: V=0.980478, theta=-23.067772 -> V=1.0, theta=0.0
% INFO    : Bus 83452	: V=0.9742834, theta=-23.613386 -> V=1.0, theta=0.0
% INFO    : Bus 83453	: V=0.9715867, theta=-23.824112 -> V=1.0, theta=0.0
% INFO    : Bus 83454	: V=0.9732629, theta=-23.806966 -> V=1.0, theta=0.0
% INFO    : Bus 83455	: V=0.97661, theta=-23.761207 -> V=1.0, theta=0.0
% INFO    : Bus 83456	: V=0.9694714, theta=-24.200036 -> V=1.0, theta=0.0
% INFO    : Bus 83457	: V=0.9696664, theta=-24.28401 -> V=1.0, theta=0.0
% INFO    : Bus 83458	: V=0.9740372, theta=-24.027324 -> V=1.0, theta=0.0
% INFO    : Bus 83459	: V=0.9757727, theta=-23.99956 -> V=1.0, theta=0.0
% INFO    : Bus 83460	: V=0.9835226, theta=-24.16701 -> V=1.0, theta=0.0
% INFO    : Bus 83461	: V=0.9901531, theta=-23.072482 -> V=1.0, theta=0.0
% INFO    : Bus 83462	: V=0.9799738, theta=-24.180043 -> V=1.0, theta=0.0
% INFO    : Bus 83463	: V=0.9864261, theta=-23.442897 -> V=1.0, theta=0.0
% INFO    : Bus 83464	: V=0.9845772, theta=-23.51861 -> V=1.0, theta=0.0
% INFO    : Bus 83465	: V=0.9850367, theta=-24.090798 -> V=1.0, theta=0.0
% INFO    : Bus 83466	: V=0.9653743, theta=-24.157701 -> V=1.0, theta=0.0
% INFO    : Bus 83467	: V=0.9866609, theta=-24.072408 -> V=1.0, theta=0.0
% INFO    : Bus 83468	: V=0.9816262, theta=-24.373503 -> V=1.0, theta=0.0
% INFO    : Bus 83469	: V=0.980686, theta=-24.413961 -> V=1.0, theta=0.0
% INFO    : Bus 83470	: V=0.9630058, theta=-24.6601 -> V=1.0, theta=0.0
% INFO    : Bus 83471	: V=0.9650123, theta=-24.566762 -> V=1.0, theta=0.0
% INFO    : Bus 83472	: V=0.9648404, theta=-24.631632 -> V=1.0, theta=0.0
% INFO    : Bus 83473	: V=0.9747119, theta=-24.001692 -> V=1.0, theta=0.0
% INFO    : Bus 83474	: V=0.9735059, theta=-24.381807 -> V=1.0, theta=0.0
% INFO    : Bus 83475	: V=0.9748492, theta=-24.51514 -> V=1.0, theta=0.0
% INFO    : Bus 83476	: V=0.9721333, theta=-24.619343 -> V=1.0, theta=0.0
% INFO    : Bus 83477	: V=0.9626802, theta=-25.031157 -> V=1.0, theta=0.0
% INFO    : Bus 83478	: V=0.9690433, theta=-24.806704 -> V=1.0, theta=0.0
% INFO    : Bus 83479	: V=0.9665065, theta=-25.413976 -> V=1.0, theta=0.0
% INFO    : Bus 83480	: V=0.9684901, theta=-25.232305 -> V=1.0, theta=0.0
% INFO    : Bus 83481	: V=0.9687841, theta=-25.8192 -> V=1.0, theta=0.0
% INFO    : Bus 83482	: V=0.9779542, theta=-24.579515 -> V=1.0, theta=0.0
% INFO    : Bus 83483	: V=0.9787978, theta=-25.019041 -> V=1.0, theta=0.0
% INFO    : Bus 83484	: V=0.9857491, theta=-24.511999 -> V=1.0, theta=0.0
% INFO    : Bus 83485	: V=0.9822455, theta=-24.885388 -> V=1.0, theta=0.0
% INFO    : Bus 83486	: V=0.9839647, theta=-24.471963 -> V=1.0, theta=0.0
% INFO    : Bus 83487	: V=0.9914929, theta=-23.88384 -> V=1.0, theta=0.0
% INFO    : Bus 83488	: V=0.9857562, theta=-24.45204 -> V=1.0, theta=0.0
% INFO    : Bus 83489	: V=0.9810616, theta=-24.490946 -> V=1.0, theta=0.0
% INFO    : Bus 83490	: V=0.9809579, theta=-24.503754 -> V=1.0, theta=0.0
% INFO    : Bus 83491	: V=0.9829997, theta=-24.871921 -> V=1.0, theta=0.0
% INFO    : Bus 83492	: V=0.9834355, theta=-23.26618 -> V=1.0, theta=0.0
% INFO    : Bus 83493	: V=0.9927244, theta=-22.948461 -> V=1.0, theta=0.0
% INFO    : Bus 83494	: V=0.988219, theta=-23.330025 -> V=1.0, theta=0.0
% INFO    : Bus 83495	: V=0.9857138, theta=-23.357863 -> V=1.0, theta=0.0
% INFO    : Bus 83496	: V=0.9794139, theta=0.009766 -> V=1.0, theta=0.0
% INFO    : Bus 83497	: V=0.9934386, theta=1.388711 -> V=1.0, theta=0.0
% INFO    : Bus 83498	: V=0.9938699, theta=0.965663 -> V=1.0, theta=0.0
% INFO    : Bus 83499	: V=1.001937, theta=-29.20273 -> V=1.0, theta=0.0
% INFO    : Bus 83500	: V=1.0032054, theta=-28.274508 -> V=1.0, theta=0.0
% INFO    : Bus 83501	: V=0.9998066, theta=-25.90703 -> V=1.0, theta=0.0
% INFO    : Bus 83502	: V=0.9795805, theta=-28.8285 -> V=1.0, theta=0.0
% INFO    : Bus 83503	: V=0.982577, theta=-29.367626 -> V=1.0, theta=0.0
% INFO    : Bus 83504	: V=0.9815478, theta=-29.571645 -> V=1.0, theta=0.0
% INFO    : Bus 83505	: V=0.9785153, theta=-30.151533 -> V=1.0, theta=0.0
% INFO    : Bus 83506	: V=0.9755512, theta=-30.626382 -> V=1.0, theta=0.0
% INFO    : Bus 83507	: V=0.9753636, theta=-31.876133 -> V=1.0, theta=0.0
% INFO    : Bus 83508	: V=0.9926804, theta=-27.579483 -> V=1.0, theta=0.0
% INFO    : Bus 83509	: V=0.9885423, theta=-28.563344 -> V=1.0, theta=0.0
% INFO    : Bus 83510	: V=0.9876639, theta=-28.945777 -> V=1.0, theta=0.0
% INFO    : Bus 83511	: V=0.975462, theta=-30.258967 -> V=1.0, theta=0.0
% INFO    : Bus 83512	: V=0.9757519, theta=-30.236906 -> V=1.0, theta=0.0
% INFO    : Bus 83513	: V=0.9788422, theta=-29.708877 -> V=1.0, theta=0.0
% INFO    : Bus 83514	: V=0.9831372, theta=-29.429292 -> V=1.0, theta=0.0
% INFO    : Bus 83515	: V=0.9827982, theta=-29.424716 -> V=1.0, theta=0.0
% INFO    : Bus 83516	: V=0.9806833, theta=-29.568967 -> V=1.0, theta=0.0
% INFO    : Bus 83517	: V=0.9833328, theta=-29.410469 -> V=1.0, theta=0.0
% INFO    : Bus 83518	: V=0.9817816, theta=-29.554236 -> V=1.0, theta=0.0
% INFO    : Bus 83519	: V=0.9807244, theta=-30.132389 -> V=1.0, theta=0.0
% INFO    : Bus 83520	: V=0.9822866, theta=-29.524373 -> V=1.0, theta=0.0
% INFO    : Bus 83521	: V=0.9799333, theta=-30.181518 -> V=1.0, theta=0.0
% INFO    : Bus 83522	: V=0.9714394, theta=-50.211904 -> V=1.0, theta=0.0
% INFO    : Bus 83523	: V=0.9703749, theta=-51.152261 -> V=1.0, theta=0.0
% INFO    : Bus 83524	: V=0.971669, theta=-51.007967 -> V=1.0, theta=0.0
% INFO    : Bus 83525	: V=0.9725864, theta=-49.97022 -> V=1.0, theta=0.0
% INFO    : Bus 83526	: V=0.986511, theta=-55.304251 -> V=1.0, theta=0.0
% INFO    : Bus 83527	: V=1.0095737, theta=-53.046018 -> V=1.0, theta=0.0
% INFO    : Bus 83528	: V=1.0069622, theta=-53.261132 -> V=1.0, theta=0.0
% INFO    : Bus 83529	: V=1.0079619, theta=-53.005907 -> V=1.0, theta=0.0
% INFO    : Bus 83530	: V=1.0073493, theta=-52.781867 -> V=1.0, theta=0.0
% INFO    : Bus 83531	: V=1.0076141, theta=-52.913096 -> V=1.0, theta=0.0
% INFO    : Bus 83532	: V=1.0073012, theta=-52.733679 -> V=1.0, theta=0.0
% INFO    : Bus 83533	: V=1.008584, theta=-51.467979 -> V=1.0, theta=0.0
% INFO    : Bus 83534	: V=0.9897844, theta=-54.703262 -> V=1.0, theta=0.0
% INFO    : Bus 83535	: V=0.9884623, theta=-54.830785 -> V=1.0, theta=0.0
% INFO    : Bus 83536	: V=1.0043767, theta=-34.81911 -> V=1.0, theta=0.0
% INFO    : Bus 83537	: V=1.0096891, theta=-32.404952 -> V=1.0, theta=0.0
% INFO    : Bus 83538	: V=1.001423, theta=-33.676079 -> V=1.0, theta=0.0
% INFO    : Bus 83539	: V=1.0153452, theta=-35.193863 -> V=1.0, theta=0.0
% INFO    : Bus 83540	: V=1.0100742, theta=-33.081803 -> V=1.0, theta=0.0
% INFO    : Bus 83541	: V=1.0036111, theta=-33.584937 -> V=1.0, theta=0.0
% INFO    : Bus 83542	: V=0.9549861, theta=-32.503859 -> V=1.0, theta=0.0
% INFO    : Bus 83543	: V=0.9504, theta=-32.471527 -> V=1.0, theta=0.0
% INFO    : Bus 83544	: V=0.9497224, theta=-32.637887 -> V=1.0, theta=0.0
% INFO    : Bus 83545	: V=0.9557694, theta=-32.753787 -> V=1.0, theta=0.0
% INFO    : Bus 83546	: V=0.9536105, theta=-31.865537 -> V=1.0, theta=0.0
% INFO    : Bus 83547	: V=1.0086794, theta=-48.155344 -> V=1.0, theta=0.0
% INFO    : Bus 83548	: V=1.0045438, theta=-48.70428 -> V=1.0, theta=0.0
% INFO    : Bus 83549	: V=0.9952181, theta=-47.4162 -> V=1.0, theta=0.0
% INFO    : Bus 83550	: V=0.9954619, theta=-45.406809 -> V=1.0, theta=0.0
% INFO    : Bus 83551	: V=1.0068051, theta=-47.082014 -> V=1.0, theta=0.0
% INFO    : Bus 83552	: V=1.0017793, theta=-48.974419 -> V=1.0, theta=0.0
% INFO    : Bus 83553	: V=0.9943383, theta=-50.408087 -> V=1.0, theta=0.0
% INFO    : Bus 83554	: V=0.9953411, theta=-27.041355 -> V=1.0, theta=0.0
% INFO    : Bus 83555	: V=1.0077645, theta=-25.20301 -> V=1.0, theta=0.0
% INFO    : Bus 83556	: V=0.9976345, theta=-25.95852 -> V=1.0, theta=0.0
% INFO    : Bus 83557	: V=0.9932214, theta=-26.969529 -> V=1.0, theta=0.0
% INFO    : Bus 83558	: V=0.9931963, theta=-26.720969 -> V=1.0, theta=0.0
% INFO    : Bus 83559	: V=0.9832973, theta=-26.211915 -> V=1.0, theta=0.0
% INFO    : Bus 83560	: V=0.9830153, theta=-26.293649 -> V=1.0, theta=0.0
% INFO    : Bus 83561	: V=0.9930748, theta=-24.580777 -> V=1.0, theta=0.0
% INFO    : Bus 83562	: V=0.9989729, theta=-23.25449 -> V=1.0, theta=0.0
% INFO    : Bus 83563	: V=0.9796796, theta=-27.079482 -> V=1.0, theta=0.0
% INFO    : Bus 83564	: V=0.9800581, theta=-27.224608 -> V=1.0, theta=0.0
% INFO    : Bus 83565	: V=0.9758256, theta=-27.510156 -> V=1.0, theta=0.0
% INFO    : Bus 83566	: V=0.9810495, theta=-26.979839 -> V=1.0, theta=0.0
% INFO    : Bus 83567	: V=0.9776023, theta=-27.356115 -> V=1.0, theta=0.0
% INFO    : Bus 83568	: V=0.9806222, theta=-26.596686 -> V=1.0, theta=0.0
% INFO    : Bus 83569	: V=0.9842645, theta=-27.663813 -> V=1.0, theta=0.0
% INFO    : Bus 83570	: V=0.9827014, theta=-27.484602 -> V=1.0, theta=0.0
% INFO    : Bus 83571	: V=0.9857212, theta=-27.17687 -> V=1.0, theta=0.0
% INFO    : Bus 83572	: V=0.9836058, theta=-27.653151 -> V=1.0, theta=0.0
% INFO    : Bus 83573	: V=0.9975272, theta=-26.817363 -> V=1.0, theta=0.0
% INFO    : Bus 83574	: V=0.9817303, theta=-28.17713 -> V=1.0, theta=0.0
% INFO    : Bus 83575	: V=0.9914391, theta=-27.505407 -> V=1.0, theta=0.0
% INFO    : Bus 83576	: V=0.9839736, theta=-27.281067 -> V=1.0, theta=0.0
% INFO    : Bus 83577	: V=0.9834478, theta=-27.421371 -> V=1.0, theta=0.0
% INFO    : Bus 83578	: V=0.9803483, theta=-28.107805 -> V=1.0, theta=0.0
% INFO    : Bus 83579	: V=0.980864, theta=-27.974119 -> V=1.0, theta=0.0
% INFO    : Bus 83580	: V=0.9736536, theta=-28.624779 -> V=1.0, theta=0.0
% INFO    : Bus 83581	: V=0.995413, theta=-27.408517 -> V=1.0, theta=0.0
% INFO    : Bus 83582	: V=0.9862777, theta=-28.836345 -> V=1.0, theta=0.0
% INFO    : Bus 83583	: V=0.9963877, theta=-27.429759 -> V=1.0, theta=0.0
% INFO    : Bus 83584	: V=0.9939174, theta=-27.479618 -> V=1.0, theta=0.0
% INFO    : Bus 83585	: V=0.9914459, theta=-28.654425 -> V=1.0, theta=0.0
% INFO    : Bus 83586	: V=0.9942678, theta=-27.954839 -> V=1.0, theta=0.0
% INFO    : Bus 83587	: V=0.9914514, theta=-28.56558 -> V=1.0, theta=0.0
% INFO    : Bus 83588	: V=0.9909212, theta=-28.57457 -> V=1.0, theta=0.0
% INFO    : Bus 83589	: V=0.9953082, theta=-27.695703 -> V=1.0, theta=0.0
% INFO    : Bus 83590	: V=0.991475, theta=-28.545451 -> V=1.0, theta=0.0
% INFO    : Bus 83591	: V=0.9943534, theta=-27.904981 -> V=1.0, theta=0.0
% INFO    : Bus 83592	: V=0.9928716, theta=-28.114747 -> V=1.0, theta=0.0
% INFO    : Bus 83593	: V=0.9938172, theta=-28.036795 -> V=1.0, theta=0.0
% INFO    : Bus 83594	: V=0.9921932, theta=-28.514351 -> V=1.0, theta=0.0
% INFO    : Bus 83595	: V=0.9949717, theta=-26.817812 -> V=1.0, theta=0.0
% INFO    : Bus 83596	: V=0.9971417, theta=-27.505007 -> V=1.0, theta=0.0
% INFO    : Bus 83597	: V=0.9778072, theta=-53.927673 -> V=1.0, theta=0.0
% INFO    : Bus 83598	: V=0.9771626, theta=-53.463953 -> V=1.0, theta=0.0
% INFO    : Bus 83599	: V=0.9792308, theta=-53.626364 -> V=1.0, theta=0.0
% INFO    : Bus 83600	: V=0.9408455, theta=-38.416703 -> V=1.0, theta=0.0
% INFO    : Bus 83601	: V=0.9430605, theta=-38.560022 -> V=1.0, theta=0.0
% INFO    : Bus 83602	: V=0.9495394, theta=-38.790431 -> V=1.0, theta=0.0
% INFO    : Bus 83603	: V=0.9553745, theta=-36.968398 -> V=1.0, theta=0.0
% INFO    : Bus 83604	: V=0.9599832, theta=-35.926111 -> V=1.0, theta=0.0
% INFO    : Bus 83605	: V=0.9583748, theta=-36.251382 -> V=1.0, theta=0.0
% INFO    : Bus 83606	: V=0.9565755, theta=-36.85406 -> V=1.0, theta=0.0
% INFO    : Bus 83607	: V=0.9543412, theta=-36.950768 -> V=1.0, theta=0.0
% INFO    : Bus 83608	: V=0.9586095, theta=-35.755292 -> V=1.0, theta=0.0
% INFO    : Bus 83609	: V=0.9610823, theta=-36.635314 -> V=1.0, theta=0.0
% INFO    : Bus 83610	: V=0.9541316, theta=-37.176728 -> V=1.0, theta=0.0
% INFO    : Bus 83611	: V=0.9579139, theta=-36.616559 -> V=1.0, theta=0.0
% INFO    : Bus 83612	: V=0.9544115, theta=-37.442553 -> V=1.0, theta=0.0
% INFO    : Bus 83613	: V=0.9550828, theta=-35.52547 -> V=1.0, theta=0.0
% INFO    : Bus 83614	: V=0.9608602, theta=-34.987198 -> V=1.0, theta=0.0
% INFO    : Bus 83615	: V=0.9602556, theta=-35.25065 -> V=1.0, theta=0.0
% INFO    : Bus 83616	: V=0.9553728, theta=-36.881224 -> V=1.0, theta=0.0
% INFO    : Bus 83617	: V=0.9833136, theta=-28.574462 -> V=1.0, theta=0.0
% INFO    : Bus 83618	: V=0.98294, theta=-28.400116 -> V=1.0, theta=0.0
% INFO    : Bus 83619	: V=0.9861094, theta=-28.060481 -> V=1.0, theta=0.0
% INFO    : Bus 83620	: V=0.9852588, theta=-27.56294 -> V=1.0, theta=0.0
% INFO    : Bus 83621	: V=0.9853396, theta=-27.474469 -> V=1.0, theta=0.0
% INFO    : Bus 83622	: V=0.9832054, theta=-27.746205 -> V=1.0, theta=0.0
% INFO    : Bus 83623	: V=0.9862147, theta=-27.445686 -> V=1.0, theta=0.0
% INFO    : Bus 83624	: V=0.9848152, theta=-27.705714 -> V=1.0, theta=0.0
% INFO    : Bus 83625	: V=0.9879059, theta=-27.4503 -> V=1.0, theta=0.0
% INFO    : Bus 83626	: V=0.9925378, theta=-26.932139 -> V=1.0, theta=0.0
% INFO    : Bus 83627	: V=0.9901903, theta=-27.461208 -> V=1.0, theta=0.0
% INFO    : Bus 83628	: V=0.9821967, theta=-27.766837 -> V=1.0, theta=0.0
% INFO    : Bus 83629	: V=0.9816194, theta=-27.942935 -> V=1.0, theta=0.0
% INFO    : Bus 83630	: V=0.9907105, theta=-27.182551 -> V=1.0, theta=0.0
% INFO    : Bus 83631	: V=0.9985458, theta=-26.339991 -> V=1.0, theta=0.0
% INFO    : Bus 83632	: V=0.9960007, theta=-26.719279 -> V=1.0, theta=0.0
% INFO    : Bus 83633	: V=0.9912811, theta=-27.280733 -> V=1.0, theta=0.0
% INFO    : Bus 83634	: V=0.993002, theta=-26.801087 -> V=1.0, theta=0.0
% INFO    : Bus 83635	: V=1.0106986, theta=-24.922562 -> V=1.0, theta=0.0
% INFO    : Bus 83636	: V=0.9829599, theta=-30.404501 -> V=1.0, theta=0.0
% INFO    : Bus 83637	: V=0.9828322, theta=-30.427008 -> V=1.0, theta=0.0
% INFO    : Bus 83638	: V=0.9827487, theta=-30.30925 -> V=1.0, theta=0.0
% INFO    : Bus 83639	: V=0.9759857, theta=-31.625169 -> V=1.0, theta=0.0
% INFO    : Bus 83640	: V=0.9804479, theta=-29.559094 -> V=1.0, theta=0.0
% INFO    : Bus 83641	: V=0.9812838, theta=-58.33984 -> V=1.0, theta=0.0
% INFO    : Bus 83642	: V=0.9844684, theta=-57.931479 -> V=1.0, theta=0.0
% INFO    : Bus 83643	: V=0.9810802, theta=-58.081844 -> V=1.0, theta=0.0
% INFO    : Bus 83644	: V=0.9758128, theta=-58.15031 -> V=1.0, theta=0.0
% INFO    : Bus 83645	: V=0.9784291, theta=-58.215627 -> V=1.0, theta=0.0
% INFO    : Bus 83646	: V=0.9750991, theta=-58.738754 -> V=1.0, theta=0.0
% INFO    : Bus 83647	: V=0.9738771, theta=-57.784015 -> V=1.0, theta=0.0
% INFO    : Bus 83648	: V=0.9886988, theta=-57.945242 -> V=1.0, theta=0.0
% INFO    : Bus 83649	: V=0.9856642, theta=-59.268231 -> V=1.0, theta=0.0
% INFO    : Bus 83650	: V=0.9940265, theta=-57.469156 -> V=1.0, theta=0.0
% INFO    : Bus 83651	: V=1.001977, theta=-55.666638 -> V=1.0, theta=0.0
% INFO    : Bus 83652	: V=1.0010424, theta=-55.877946 -> V=1.0, theta=0.0
% INFO    : Bus 83653	: V=1.0086753, theta=-55.158276 -> V=1.0, theta=0.0
% INFO    : Bus 83654	: V=0.9991199, theta=-56.490084 -> V=1.0, theta=0.0
% INFO    : Bus 83655	: V=1.0023997, theta=-56.072114 -> V=1.0, theta=0.0
% INFO    : Bus 83656	: V=0.9928191, theta=-45.400777 -> V=1.0, theta=0.0
% INFO    : Bus 83657	: V=0.9988551, theta=-42.963338 -> V=1.0, theta=0.0
% INFO    : Bus 83658	: V=1.0074257, theta=-41.983805 -> V=1.0, theta=0.0
% INFO    : Bus 83659	: V=0.9988318, theta=-43.791815 -> V=1.0, theta=0.0
% INFO    : Bus 83660	: V=0.9901374, theta=-44.820803 -> V=1.0, theta=0.0
% INFO    : Bus 83661	: V=1.0041459, theta=-42.628529 -> V=1.0, theta=0.0
% INFO    : Bus 83662	: V=1.0043229, theta=-42.355923 -> V=1.0, theta=0.0
% INFO    : Bus 83663	: V=0.9989037, theta=-42.597677 -> V=1.0, theta=0.0
% INFO    : Bus 83664	: V=0.9449019, theta=-47.183712 -> V=1.0, theta=0.0
% INFO    : Bus 83665	: V=0.9502052, theta=-47.2088 -> V=1.0, theta=0.0
% INFO    : Bus 83666	: V=0.965445, theta=-48.326876 -> V=1.0, theta=0.0
% INFO    : Bus 83667	: V=0.9722983, theta=-49.173263 -> V=1.0, theta=0.0
% INFO    : Bus 83668	: V=0.9638969, theta=-52.267565 -> V=1.0, theta=0.0
% INFO    : Bus 83669	: V=0.9640766, theta=-51.194154 -> V=1.0, theta=0.0
% INFO    : Bus 83670	: V=0.96633, theta=-50.794224 -> V=1.0, theta=0.0
% INFO    : Bus 83671	: V=0.9650448, theta=-51.173166 -> V=1.0, theta=0.0
% INFO    : Bus 83672	: V=0.9632847, theta=-52.574089 -> V=1.0, theta=0.0
% INFO    : Bus 83673	: V=0.9645629, theta=-52.1931 -> V=1.0, theta=0.0
% INFO    : Bus 83674	: V=0.9624516, theta=-51.629795 -> V=1.0, theta=0.0
% INFO    : Bus 83675	: V=0.9668701, theta=-50.485562 -> V=1.0, theta=0.0
% INFO    : Bus 83676	: V=0.9656736, theta=-51.140688 -> V=1.0, theta=0.0
% INFO    : Bus 83677	: V=0.9687518, theta=-50.337177 -> V=1.0, theta=0.0
% INFO    : Bus 83678	: V=0.9661379, theta=-51.071688 -> V=1.0, theta=0.0
% INFO    : Bus 83679	: V=0.9627345, theta=-51.523492 -> V=1.0, theta=0.0
% INFO    : Bus 83680	: V=0.9681926, theta=-50.758761 -> V=1.0, theta=0.0
% INFO    : Bus 83681	: V=0.9656952, theta=-51.459261 -> V=1.0, theta=0.0
% INFO    : Bus 83682	: V=0.9658699, theta=-51.437988 -> V=1.0, theta=0.0
% INFO    : Bus 83683	: V=0.9670877, theta=-50.459123 -> V=1.0, theta=0.0
% INFO    : Bus 83684	: V=0.9668936, theta=-50.50904 -> V=1.0, theta=0.0
% INFO    : Bus 83685	: V=0.96709, theta=-51.094991 -> V=1.0, theta=0.0
% INFO    : Bus 83686	: V=0.9629551, theta=-51.592952 -> V=1.0, theta=0.0
% INFO    : Bus 83687	: V=0.9613584, theta=-51.991143 -> V=1.0, theta=0.0
% INFO    : Bus 83688	: V=0.9611864, theta=-52.006928 -> V=1.0, theta=0.0
% INFO    : Bus 83689	: V=0.9610021, theta=-52.186485 -> V=1.0, theta=0.0
% INFO    : Bus 83690	: V=0.9625257, theta=-51.785713 -> V=1.0, theta=0.0
% INFO    : Bus 83691	: V=0.9664335, theta=-52.045163 -> V=1.0, theta=0.0
% INFO    : Bus 83692	: V=0.9626602, theta=-52.029553 -> V=1.0, theta=0.0
% INFO    : Bus 83693	: V=0.9632851, theta=-51.684142 -> V=1.0, theta=0.0
% INFO    : Bus 83694	: V=0.9691098, theta=-52.28018 -> V=1.0, theta=0.0
% INFO    : Bus 83695	: V=0.9686149, theta=-52.249259 -> V=1.0, theta=0.0
% INFO    : Bus 83696	: V=0.961239, theta=-52.093235 -> V=1.0, theta=0.0
% INFO    : Bus 83697	: V=0.961778, theta=-51.985435 -> V=1.0, theta=0.0
% INFO    : Bus 83698	: V=0.9608433, theta=-51.786159 -> V=1.0, theta=0.0
% INFO    : Bus 83699	: V=0.9616965, theta=-51.957246 -> V=1.0, theta=0.0
% INFO    : Bus 83700	: V=0.9696832, theta=-52.524079 -> V=1.0, theta=0.0
% INFO    : Bus 83701	: V=0.9755281, theta=-52.331417 -> V=1.0, theta=0.0
% INFO    : Bus 83702	: V=0.9707368, theta=-52.604542 -> V=1.0, theta=0.0
% INFO    : Bus 83703	: V=0.9836118, theta=-51.661196 -> V=1.0, theta=0.0
% INFO    : Bus 83704	: V=0.9793195, theta=-52.114384 -> V=1.0, theta=0.0
% INFO    : Bus 83705	: V=0.9847743, theta=-51.626671 -> V=1.0, theta=0.0
% INFO    : Bus 83706	: V=0.9814507, theta=-51.778664 -> V=1.0, theta=0.0
% INFO    : Bus 83707	: V=0.9766141, theta=-52.490507 -> V=1.0, theta=0.0
% INFO    : Bus 83708	: V=0.9706596, theta=-52.707446 -> V=1.0, theta=0.0
% INFO    : Bus 83709	: V=0.9616015, theta=-52.531215 -> V=1.0, theta=0.0
% INFO    : Bus 83710	: V=0.9603425, theta=-52.223882 -> V=1.0, theta=0.0
% INFO    : Bus 83711	: V=0.9603708, theta=-51.710752 -> V=1.0, theta=0.0
% INFO    : Bus 83712	: V=0.9583545, theta=-52.706935 -> V=1.0, theta=0.0
% INFO    : Bus 83713	: V=0.9612658, theta=-52.146739 -> V=1.0, theta=0.0
% INFO    : Bus 83714	: V=0.9593482, theta=-52.512275 -> V=1.0, theta=0.0
% INFO    : Bus 83715	: V=0.9588609, theta=-53.083381 -> V=1.0, theta=0.0
% INFO    : Bus 83716	: V=0.9599932, theta=-52.691738 -> V=1.0, theta=0.0
% INFO    : Bus 83717	: V=0.9585842, theta=-53.146567 -> V=1.0, theta=0.0
% INFO    : Bus 83718	: V=0.9643378, theta=-52.585928 -> V=1.0, theta=0.0
% INFO    : Bus 83719	: V=0.9649636, theta=-51.075506 -> V=1.0, theta=0.0
% INFO    : Bus 83720	: V=0.963975, theta=-52.461598 -> V=1.0, theta=0.0
% INFO    : Bus 83721	: V=0.9631185, theta=-52.655726 -> V=1.0, theta=0.0
% INFO    : Bus 83722	: V=0.9633522, theta=-52.688029 -> V=1.0, theta=0.0
% INFO    : Bus 83723	: V=0.9614656, theta=-52.984359 -> V=1.0, theta=0.0
% INFO    : Bus 83724	: V=0.9619369, theta=-50.874838 -> V=1.0, theta=0.0
% INFO    : Bus 83725	: V=0.9610031, theta=-51.662687 -> V=1.0, theta=0.0
% INFO    : Bus 83726	: V=0.9592755, theta=-53.506206 -> V=1.0, theta=0.0
% INFO    : Bus 83727	: V=0.9595624, theta=-53.691072 -> V=1.0, theta=0.0
% INFO    : Bus 83728	: V=0.9587549, theta=-53.897391 -> V=1.0, theta=0.0
% INFO    : Bus 83729	: V=0.9592231, theta=-53.921314 -> V=1.0, theta=0.0
% INFO    : Bus 83730	: V=0.9637739, theta=-52.79782 -> V=1.0, theta=0.0
% INFO    : Bus 83731	: V=0.9600178, theta=-53.517331 -> V=1.0, theta=0.0
% INFO    : Bus 83732	: V=0.9612939, theta=-53.197256 -> V=1.0, theta=0.0
% INFO    : Bus 83733	: V=0.9604435, theta=-53.82883 -> V=1.0, theta=0.0
% INFO    : Bus 83734	: V=0.961574, theta=-52.519281 -> V=1.0, theta=0.0
% INFO    : Bus 83735	: V=0.9617406, theta=-52.989648 -> V=1.0, theta=0.0
% INFO    : Bus 83736	: V=0.9614468, theta=-52.799278 -> V=1.0, theta=0.0
% INFO    : Bus 83737	: V=0.9632771, theta=-51.909386 -> V=1.0, theta=0.0
% INFO    : Bus 83738	: V=0.9614284, theta=-53.125009 -> V=1.0, theta=0.0
% INFO    : Bus 83739	: V=0.9607521, theta=-53.17373 -> V=1.0, theta=0.0
% INFO    : Bus 83740	: V=0.9679349, theta=-52.748138 -> V=1.0, theta=0.0
% INFO    : Bus 83741	: V=0.9873631, theta=-51.633019 -> V=1.0, theta=0.0
% INFO    : Bus 83742	: V=0.9876924, theta=-51.619782 -> V=1.0, theta=0.0
% INFO    : Bus 83743	: V=0.9840565, theta=-51.739513 -> V=1.0, theta=0.0
% INFO    : Bus 83744	: V=0.9843832, theta=-51.842602 -> V=1.0, theta=0.0
% INFO    : Bus 83745	: V=0.9785927, theta=-52.253946 -> V=1.0, theta=0.0
% INFO    : Bus 83746	: V=0.9727074, theta=-53.005459 -> V=1.0, theta=0.0
% INFO    : Bus 83747	: V=0.9736942, theta=-52.685352 -> V=1.0, theta=0.0
% INFO    : Bus 83748	: V=0.9607543, theta=-52.252529 -> V=1.0, theta=0.0
% INFO    : Bus 83749	: V=0.9624062, theta=-51.551407 -> V=1.0, theta=0.0
% INFO    : Bus 83750	: V=0.9616672, theta=-52.467249 -> V=1.0, theta=0.0
% INFO    : Bus 83751	: V=0.9613311, theta=-52.650799 -> V=1.0, theta=0.0
% INFO    : Bus 83752	: V=0.968708, theta=-53.512377 -> V=1.0, theta=0.0
% INFO    : Bus 83753	: V=0.9614509, theta=-52.488771 -> V=1.0, theta=0.0
% INFO    : Bus 83754	: V=0.9611148, theta=-52.801253 -> V=1.0, theta=0.0
% INFO    : Bus 83755	: V=0.9633294, theta=-52.514919 -> V=1.0, theta=0.0
% INFO    : Bus 83756	: V=0.9643787, theta=-52.445791 -> V=1.0, theta=0.0
% INFO    : Bus 83757	: V=0.9637011, theta=-52.383097 -> V=1.0, theta=0.0
% INFO    : Bus 83758	: V=0.9647035, theta=-52.226212 -> V=1.0, theta=0.0
% INFO    : Bus 83759	: V=0.9640698, theta=-52.270692 -> V=1.0, theta=0.0
% INFO    : Bus 83760	: V=0.9626394, theta=-53.328379 -> V=1.0, theta=0.0
% INFO    : Bus 83761	: V=0.9593985, theta=-53.407782 -> V=1.0, theta=0.0
% INFO    : Bus 83762	: V=0.9613674, theta=-52.746803 -> V=1.0, theta=0.0
% INFO    : Bus 83763	: V=0.9600397, theta=-53.204579 -> V=1.0, theta=0.0
% INFO    : Bus 83764	: V=0.9662864, theta=-53.618253 -> V=1.0, theta=0.0
% INFO    : Bus 83765	: V=0.9610601, theta=-53.720371 -> V=1.0, theta=0.0
% INFO    : Bus 83766	: V=0.9591383, theta=-53.426408 -> V=1.0, theta=0.0
% INFO    : Bus 83767	: V=0.9694707, theta=-51.320936 -> V=1.0, theta=0.0
% INFO    : Bus 83768	: V=0.9676278, theta=-51.807321 -> V=1.0, theta=0.0
% INFO    : Bus 83769	: V=0.968408, theta=-51.690061 -> V=1.0, theta=0.0
% INFO    : Bus 83770	: V=0.9671113, theta=-51.87025 -> V=1.0, theta=0.0
% INFO    : Bus 83771	: V=0.9642847, theta=-52.615816 -> V=1.0, theta=0.0
% INFO    : Bus 83772	: V=0.9587202, theta=-53.442966 -> V=1.0, theta=0.0
% INFO    : Bus 83773	: V=0.9589699, theta=-53.389767 -> V=1.0, theta=0.0
% INFO    : Bus 83774	: V=0.9590323, theta=-53.68138 -> V=1.0, theta=0.0
% INFO    : Bus 83775	: V=0.9650858, theta=-52.435227 -> V=1.0, theta=0.0
% INFO    : Bus 83776	: V=0.9617985, theta=-52.228797 -> V=1.0, theta=0.0
% INFO    : Bus 83777	: V=0.9608387, theta=-52.871418 -> V=1.0, theta=0.0
% INFO    : Bus 83778	: V=0.9618855, theta=-52.328747 -> V=1.0, theta=0.0
% INFO    : Bus 83779	: V=0.961026, theta=-52.417918 -> V=1.0, theta=0.0
% INFO    : Bus 83780	: V=0.9613423, theta=-52.439649 -> V=1.0, theta=0.0
% INFO    : Bus 83781	: V=0.9607001, theta=-52.976242 -> V=1.0, theta=0.0
% INFO    : Bus 83782	: V=0.9604341, theta=-53.255234 -> V=1.0, theta=0.0
% INFO    : Bus 83783	: V=0.959733, theta=-53.265999 -> V=1.0, theta=0.0
% INFO    : Bus 83784	: V=0.9604482, theta=-53.044335 -> V=1.0, theta=0.0
% INFO    : Bus 83785	: V=0.9586201, theta=-53.266864 -> V=1.0, theta=0.0
% INFO    : Bus 83786	: V=0.9593618, theta=-53.054064 -> V=1.0, theta=0.0
% INFO    : Bus 83787	: V=0.9604538, theta=-53.027305 -> V=1.0, theta=0.0
% INFO    : Bus 83788	: V=0.9650416, theta=-53.191227 -> V=1.0, theta=0.0
% INFO    : Bus 83789	: V=0.9623827, theta=-51.524712 -> V=1.0, theta=0.0
% INFO    : Bus 83790	: V=0.9621753, theta=-52.312564 -> V=1.0, theta=0.0
% INFO    : Bus 83791	: V=0.9604888, theta=-52.701256 -> V=1.0, theta=0.0
% INFO    : Bus 83792	: V=0.9604738, theta=-53.013463 -> V=1.0, theta=0.0
% INFO    : Bus 83793	: V=0.9594156, theta=-54.340359 -> V=1.0, theta=0.0
% INFO    : Bus 83794	: V=0.9591898, theta=-55.025741 -> V=1.0, theta=0.0
% INFO    : Bus 83795	: V=0.963171, theta=-53.109827 -> V=1.0, theta=0.0
% INFO    : Bus 83796	: V=0.9598979, theta=-53.617256 -> V=1.0, theta=0.0
% INFO    : Bus 83797	: V=0.9623615, theta=-52.027435 -> V=1.0, theta=0.0
% INFO    : Bus 83798	: V=0.961089, theta=-53.2291 -> V=1.0, theta=0.0
% INFO    : Bus 83799	: V=0.9595351, theta=-53.529789 -> V=1.0, theta=0.0
% INFO    : Bus 83800	: V=0.9686771, theta=-51.730245 -> V=1.0, theta=0.0
% INFO    : Bus 83801	: V=0.9679002, theta=-51.910934 -> V=1.0, theta=0.0
% INFO    : Bus 83802	: V=0.9712326, theta=-50.867131 -> V=1.0, theta=0.0
% INFO    : Bus 83803	: V=0.9663273, theta=-52.100057 -> V=1.0, theta=0.0
% INFO    : Bus 83804	: V=0.9624833, theta=-51.381394 -> V=1.0, theta=0.0
% INFO    : Bus 83805	: V=0.9586673, theta=-54.019617 -> V=1.0, theta=0.0
% INFO    : Bus 83806	: V=0.9704864, theta=-53.580186 -> V=1.0, theta=0.0
% INFO    : Bus 83807	: V=0.9650132, theta=-48.500813 -> V=1.0, theta=0.0
% INFO    : Bus 83808	: V=0.9623553, theta=-51.050344 -> V=1.0, theta=0.0
% INFO    : Bus 83809	: V=0.9654462, theta=-51.586619 -> V=1.0, theta=0.0
% INFO    : Bus 83810	: V=0.9585976, theta=-53.45202 -> V=1.0, theta=0.0
% INFO    : Bus 83811	: V=0.9735418, theta=-29.884605 -> V=1.0, theta=0.0
% INFO    : Bus 83812	: V=0.9705672, theta=-31.43454 -> V=1.0, theta=0.0
% INFO    : Bus 83813	: V=0.9984326, theta=-27.052144 -> V=1.0, theta=0.0
% INFO    : Bus 83814	: V=0.9858347, theta=-27.823169 -> V=1.0, theta=0.0
% INFO    : Bus 83815	: V=0.9904523, theta=-27.520123 -> V=1.0, theta=0.0
% INFO    : Bus 83816	: V=0.9576375, theta=-44.293487 -> V=1.0, theta=0.0
% INFO    : Bus 83817	: V=0.9614338, theta=-43.783637 -> V=1.0, theta=0.0
% INFO    : Bus 83818	: V=0.965933, theta=-42.371036 -> V=1.0, theta=0.0
% INFO    : Bus 83819	: V=0.9623431, theta=-43.603533 -> V=1.0, theta=0.0
% INFO    : Bus 83820	: V=0.9607474, theta=-43.733169 -> V=1.0, theta=0.0
% INFO    : Bus 83821	: V=0.9581212, theta=-44.293213 -> V=1.0, theta=0.0
% INFO    : Bus 83822	: V=0.9594928, theta=-44.195406 -> V=1.0, theta=0.0
% INFO    : Bus 83823	: V=0.9561389, theta=-45.392821 -> V=1.0, theta=0.0
% INFO    : Bus 83824	: V=0.9546511, theta=-45.193052 -> V=1.0, theta=0.0
% INFO    : Bus 83825	: V=0.9635218, theta=-42.680065 -> V=1.0, theta=0.0
% INFO    : Bus 83826	: V=0.962168, theta=-43.184082 -> V=1.0, theta=0.0
% INFO    : Bus 83827	: V=0.9665729, theta=-42.497759 -> V=1.0, theta=0.0
% INFO    : Bus 83828	: V=0.9554133, theta=-44.820408 -> V=1.0, theta=0.0
% INFO    : Bus 83829	: V=0.9774987, theta=-44.318332 -> V=1.0, theta=0.0
% INFO    : Bus 83830	: V=0.9814911, theta=-42.540674 -> V=1.0, theta=0.0
% INFO    : Bus 83831	: V=0.9827471, theta=-39.655327 -> V=1.0, theta=0.0
% INFO    : Bus 83832	: V=0.9753964, theta=-41.135881 -> V=1.0, theta=0.0
% INFO    : Bus 83833	: V=0.9756298, theta=-41.370282 -> V=1.0, theta=0.0
% INFO    : Bus 83834	: V=0.9808277, theta=-40.469263 -> V=1.0, theta=0.0
% INFO    : Bus 83835	: V=0.9748163, theta=-41.136982 -> V=1.0, theta=0.0
% INFO    : Bus 83836	: V=0.9690794, theta=-43.366108 -> V=1.0, theta=0.0
% INFO    : Bus 83837	: V=0.982984, theta=-40.109539 -> V=1.0, theta=0.0
% INFO    : Bus 83838	: V=0.9822733, theta=-39.984227 -> V=1.0, theta=0.0
% INFO    : Bus 83839	: V=0.9791134, theta=-40.152746 -> V=1.0, theta=0.0
% INFO    : Bus 83840	: V=0.9756364, theta=-40.735259 -> V=1.0, theta=0.0
% INFO    : Bus 83841	: V=0.9609749, theta=-42.919917 -> V=1.0, theta=0.0
% INFO    : Bus 83842	: V=0.9876751, theta=-37.532377 -> V=1.0, theta=0.0
% INFO    : Bus 83843	: V=0.9836836, theta=-38.34439 -> V=1.0, theta=0.0
% INFO    : Bus 83844	: V=0.9781012, theta=-39.287081 -> V=1.0, theta=0.0
% INFO    : Bus 83845	: V=0.9750813, theta=-39.274417 -> V=1.0, theta=0.0
% INFO    : Bus 83846	: V=0.9772336, theta=-39.043481 -> V=1.0, theta=0.0
% INFO    : Bus 83847	: V=0.9839281, theta=-37.800803 -> V=1.0, theta=0.0
% INFO    : Bus 83848	: V=0.9794553, theta=-38.326507 -> V=1.0, theta=0.0
% INFO    : Bus 83849	: V=0.9580927, theta=-43.374839 -> V=1.0, theta=0.0
% INFO    : Bus 83850	: V=0.9695937, theta=-34.062011 -> V=1.0, theta=0.0
% INFO    : Bus 83851	: V=0.9688112, theta=-35.476874 -> V=1.0, theta=0.0
% INFO    : Bus 83852	: V=0.9838157, theta=-33.433106 -> V=1.0, theta=0.0
% INFO    : Bus 83853	: V=0.957504, theta=-43.920905 -> V=1.0, theta=0.0
% INFO    : Bus 83854	: V=0.95727, theta=-43.431911 -> V=1.0, theta=0.0
% INFO    : Bus 83855	: V=0.9582804, theta=-43.531834 -> V=1.0, theta=0.0
% INFO    : Bus 83856	: V=0.9579463, theta=-43.503889 -> V=1.0, theta=0.0
% INFO    : Bus 83857	: V=0.9575848, theta=-43.394303 -> V=1.0, theta=0.0
% INFO    : Bus 83858	: V=0.9557432, theta=-43.754293 -> V=1.0, theta=0.0
% INFO    : Bus 83859	: V=0.9579665, theta=-43.418227 -> V=1.0, theta=0.0
% INFO    : Bus 83860	: V=0.9593018, theta=-43.307865 -> V=1.0, theta=0.0
% INFO    : Bus 83861	: V=0.9574766, theta=-43.435075 -> V=1.0, theta=0.0
% INFO    : Bus 83862	: V=0.9563241, theta=-43.610349 -> V=1.0, theta=0.0
% INFO    : Bus 83863	: V=0.9585003, theta=-43.352488 -> V=1.0, theta=0.0
% INFO    : Bus 83864	: V=0.9586075, theta=-43.558761 -> V=1.0, theta=0.0
% INFO    : Bus 83865	: V=0.9586121, theta=-44.197591 -> V=1.0, theta=0.0
% INFO    : Bus 83866	: V=0.9575978, theta=-43.466389 -> V=1.0, theta=0.0
% INFO    : Bus 83867	: V=0.9598043, theta=-43.241495 -> V=1.0, theta=0.0
% INFO    : Bus 83868	: V=0.9625194, theta=-42.429814 -> V=1.0, theta=0.0
% INFO    : Bus 83869	: V=0.9607202, theta=-43.116864 -> V=1.0, theta=0.0
% INFO    : Bus 83870	: V=0.9567746, theta=-43.294126 -> V=1.0, theta=0.0
% INFO    : Bus 83871	: V=0.9593599, theta=-43.289835 -> V=1.0, theta=0.0
% INFO    : Bus 83872	: V=0.9584453, theta=-43.108288 -> V=1.0, theta=0.0
% INFO    : Bus 83873	: V=0.9626779, theta=-42.420561 -> V=1.0, theta=0.0
% INFO    : Bus 83874	: V=0.9615716, theta=-42.326411 -> V=1.0, theta=0.0
% INFO    : Bus 83875	: V=0.9612807, theta=-42.278563 -> V=1.0, theta=0.0
% INFO    : Bus 83876	: V=0.9595363, theta=-43.035553 -> V=1.0, theta=0.0
% INFO    : Bus 83877	: V=0.9607798, theta=-42.958112 -> V=1.0, theta=0.0
% INFO    : Bus 83878	: V=0.9607345, theta=-42.961511 -> V=1.0, theta=0.0
% INFO    : Bus 83879	: V=0.9592581, theta=-42.907884 -> V=1.0, theta=0.0
% INFO    : Bus 83880	: V=0.9604855, theta=-42.972704 -> V=1.0, theta=0.0
% INFO    : Bus 83881	: V=0.959111, theta=-43.014464 -> V=1.0, theta=0.0
% INFO    : Bus 83882	: V=0.9592202, theta=-43.269885 -> V=1.0, theta=0.0
% INFO    : Bus 83883	: V=0.9625754, theta=-42.389469 -> V=1.0, theta=0.0
% INFO    : Bus 83884	: V=0.95795, theta=-43.372571 -> V=1.0, theta=0.0
% INFO    : Bus 83885	: V=0.9595106, theta=-43.254134 -> V=1.0, theta=0.0
% INFO    : Bus 83886	: V=0.9637157, theta=-42.407254 -> V=1.0, theta=0.0
% INFO    : Bus 83887	: V=0.9592429, theta=-43.371694 -> V=1.0, theta=0.0
% INFO    : Bus 83888	: V=0.9594298, theta=-43.199286 -> V=1.0, theta=0.0
% INFO    : Bus 83889	: V=0.9590348, theta=-43.289363 -> V=1.0, theta=0.0
% INFO    : Bus 83890	: V=0.9576793, theta=-44.1371 -> V=1.0, theta=0.0
% INFO    : Bus 83891	: V=0.9580284, theta=-43.698433 -> V=1.0, theta=0.0
% INFO    : Bus 83892	: V=0.9578527, theta=-44.477369 -> V=1.0, theta=0.0
% INFO    : Bus 83893	: V=0.9584949, theta=-44.103964 -> V=1.0, theta=0.0
% INFO    : Bus 83894	: V=0.9627941, theta=-42.418915 -> V=1.0, theta=0.0
% INFO    : Bus 83895	: V=0.9596154, theta=-43.639624 -> V=1.0, theta=0.0
% INFO    : Bus 83896	: V=0.9558038, theta=-44.410459 -> V=1.0, theta=0.0
% INFO    : Bus 83897	: V=0.958018, theta=-44.211131 -> V=1.0, theta=0.0
% INFO    : Bus 83898	: V=0.9584735, theta=-44.190869 -> V=1.0, theta=0.0
% INFO    : Bus 83899	: V=0.9560649, theta=-44.647151 -> V=1.0, theta=0.0
% INFO    : Bus 83900	: V=0.9544192, theta=-45.076777 -> V=1.0, theta=0.0
% INFO    : Bus 83901	: V=0.9558549, theta=-44.792395 -> V=1.0, theta=0.0
% INFO    : Bus 83902	: V=0.9571392, theta=-44.436568 -> V=1.0, theta=0.0
% INFO    : Bus 83903	: V=0.9563194, theta=-44.601371 -> V=1.0, theta=0.0
% INFO    : Bus 83904	: V=0.957931, theta=-44.947115 -> V=1.0, theta=0.0
% INFO    : Bus 83905	: V=0.958545, theta=-44.60349 -> V=1.0, theta=0.0
% INFO    : Bus 83906	: V=0.9541101, theta=-44.804354 -> V=1.0, theta=0.0
% INFO    : Bus 83907	: V=0.9591521, theta=-44.761698 -> V=1.0, theta=0.0
% INFO    : Bus 83908	: V=0.9561086, theta=-44.272568 -> V=1.0, theta=0.0
% INFO    : Bus 83909	: V=0.9583785, theta=-43.754533 -> V=1.0, theta=0.0
% INFO    : Bus 83910	: V=0.9581855, theta=-44.186507 -> V=1.0, theta=0.0
% INFO    : Bus 83911	: V=0.9587682, theta=-43.829813 -> V=1.0, theta=0.0
% INFO    : Bus 83912	: V=0.9580041, theta=-44.139408 -> V=1.0, theta=0.0
% INFO    : Bus 83913	: V=0.9588785, theta=-43.615599 -> V=1.0, theta=0.0
% INFO    : Bus 83914	: V=0.9596036, theta=-43.648535 -> V=1.0, theta=0.0
% INFO    : Bus 83915	: V=0.9621044, theta=-42.582453 -> V=1.0, theta=0.0
% INFO    : Bus 83916	: V=0.9570246, theta=-44.056482 -> V=1.0, theta=0.0
% INFO    : Bus 83917	: V=0.9601112, theta=-42.994711 -> V=1.0, theta=0.0
% INFO    : Bus 83918	: V=0.9601457, theta=-43.004232 -> V=1.0, theta=0.0
% INFO    : Bus 83919	: V=0.9587738, theta=-43.593539 -> V=1.0, theta=0.0
% INFO    : Bus 83920	: V=0.9655779, theta=-41.576668 -> V=1.0, theta=0.0
% INFO    : Bus 83921	: V=0.9635338, theta=-42.183922 -> V=1.0, theta=0.0
% INFO    : Bus 83922	: V=0.9556019, theta=-42.5019 -> V=1.0, theta=0.0
% INFO    : Bus 83923	: V=0.9679689, theta=-40.829593 -> V=1.0, theta=0.0
% INFO    : Bus 83924	: V=0.9651622, theta=-41.511893 -> V=1.0, theta=0.0
% INFO    : Bus 83925	: V=0.9651841, theta=-41.571132 -> V=1.0, theta=0.0
% INFO    : Bus 83926	: V=0.9637232, theta=-41.98306 -> V=1.0, theta=0.0
% INFO    : Bus 83927	: V=0.9608698, theta=-42.41808 -> V=1.0, theta=0.0
% INFO    : Bus 83928	: V=0.9590477, theta=-42.714556 -> V=1.0, theta=0.0
% INFO    : Bus 83929	: V=0.9620835, theta=-42.315128 -> V=1.0, theta=0.0
% INFO    : Bus 83930	: V=0.958457, theta=-43.288275 -> V=1.0, theta=0.0
% INFO    : Bus 83931	: V=0.9634227, theta=-42.298622 -> V=1.0, theta=0.0
% INFO    : Bus 83932	: V=0.9620288, theta=-42.754044 -> V=1.0, theta=0.0
% INFO    : Bus 83933	: V=0.9641003, theta=-42.049245 -> V=1.0, theta=0.0
% INFO    : Bus 83934	: V=0.9620589, theta=-42.532276 -> V=1.0, theta=0.0
% INFO    : Bus 83935	: V=0.9585588, theta=-43.060892 -> V=1.0, theta=0.0
% INFO    : Bus 83936	: V=0.9680923, theta=-40.959083 -> V=1.0, theta=0.0
% INFO    : Bus 83937	: V=0.9695136, theta=-40.773656 -> V=1.0, theta=0.0
% INFO    : Bus 83938	: V=0.9670749, theta=-41.751641 -> V=1.0, theta=0.0
% INFO    : Bus 83939	: V=0.9599818, theta=-43.009965 -> V=1.0, theta=0.0
% INFO    : Bus 83940	: V=0.9614216, theta=-43.101958 -> V=1.0, theta=0.0
% INFO    : Bus 83941	: V=0.9580226, theta=-43.448843 -> V=1.0, theta=0.0
% INFO    : Bus 83942	: V=0.9573934, theta=-43.541239 -> V=1.0, theta=0.0
% INFO    : Bus 83943	: V=0.9574414, theta=-43.470644 -> V=1.0, theta=0.0
% INFO    : Bus 83944	: V=0.9588819, theta=-44.197787 -> V=1.0, theta=0.0
% INFO    : Bus 83945	: V=0.9580453, theta=-43.55758 -> V=1.0, theta=0.0
% INFO    : Bus 83946	: V=0.9590173, theta=-42.923671 -> V=1.0, theta=0.0
% INFO    : Bus 83947	: V=0.9577933, theta=-42.894883 -> V=1.0, theta=0.0
% INFO    : Bus 83948	: V=0.9646052, theta=-41.754844 -> V=1.0, theta=0.0
% INFO    : Bus 83949	: V=0.9630926, theta=-42.193182 -> V=1.0, theta=0.0
% INFO    : Bus 83950	: V=0.9572219, theta=-42.580839 -> V=1.0, theta=0.0
% INFO    : Bus 83951	: V=0.9730544, theta=-39.83051 -> V=1.0, theta=0.0
% INFO    : Bus 83952	: V=0.9735565, theta=-38.525243 -> V=1.0, theta=0.0
% INFO    : Bus 83953	: V=0.9553321, theta=-43.248817 -> V=1.0, theta=0.0
% INFO    : Bus 83954	: V=0.9586475, theta=-44.320396 -> V=1.0, theta=0.0
% INFO    : Bus 83955	: V=0.9662634, theta=-30.990329 -> V=1.0, theta=0.0
% INFO    : Bus 83956	: V=0.9682583, theta=-30.747284 -> V=1.0, theta=0.0
% INFO    : Bus 83957	: V=0.9841361, theta=-28.40508 -> V=1.0, theta=0.0
% INFO    : Bus 83958	: V=0.9831325, theta=-28.539296 -> V=1.0, theta=0.0
% INFO    : Bus 83959	: V=1.0080181, theta=-33.058697 -> V=1.0, theta=0.0
% INFO    : Bus 83960	: V=1.0010166, theta=-33.668589 -> V=1.0, theta=0.0
% INFO    : Bus 83961	: V=1.0059815, theta=-33.042148 -> V=1.0, theta=0.0
% INFO    : Bus 83962	: V=0.9692036, theta=-54.124142 -> V=1.0, theta=0.0
% INFO    : Bus 83963	: V=0.9760831, theta=-55.290364 -> V=1.0, theta=0.0
% INFO    : Bus 83964	: V=0.9665897, theta=-56.08878 -> V=1.0, theta=0.0
% INFO    : Bus 83965	: V=0.965446, theta=-54.799363 -> V=1.0, theta=0.0
% INFO    : Bus 83966	: V=0.9564284, theta=-55.132877 -> V=1.0, theta=0.0
% INFO    : Bus 83967	: V=0.9898137, theta=-53.380416 -> V=1.0, theta=0.0
% INFO    : Bus 83968	: V=0.9838722, theta=-54.234636 -> V=1.0, theta=0.0
% INFO    : Bus 83969	: V=0.9655266, theta=-58.090126 -> V=1.0, theta=0.0
% INFO    : Bus 83970	: V=0.9583931, theta=-34.742463 -> V=1.0, theta=0.0
% INFO    : Bus 83971	: V=0.9665245, theta=-32.652032 -> V=1.0, theta=0.0
% INFO    : Bus 83972	: V=0.9760712, theta=-31.295643 -> V=1.0, theta=0.0
% INFO    : Bus 83973	: V=0.9640047, theta=-33.84268 -> V=1.0, theta=0.0
% INFO    : Bus 83974	: V=0.9630621, theta=-34.125467 -> V=1.0, theta=0.0
% INFO    : Bus 83975	: V=0.960604, theta=-34.737168 -> V=1.0, theta=0.0
% INFO    : Bus 83976	: V=0.9732906, theta=-32.496177 -> V=1.0, theta=0.0
% INFO    : Bus 83977	: V=0.9659073, theta=-33.369423 -> V=1.0, theta=0.0
% INFO    : Bus 83978	: V=0.9656565, theta=-33.534299 -> V=1.0, theta=0.0
% INFO    : Bus 83979	: V=1.007032, theta=-39.08806 -> V=1.0, theta=0.0
% INFO    : Bus 83980	: V=1.0081962, theta=-38.694231 -> V=1.0, theta=0.0
% INFO    : Bus 83981	: V=1.007466, theta=-38.682172 -> V=1.0, theta=0.0
% INFO    : Bus 83982	: V=1.0045303, theta=-39.259387 -> V=1.0, theta=0.0
% INFO    : Bus 83983	: V=1.0094197, theta=-37.30395 -> V=1.0, theta=0.0
% INFO    : Bus 83984	: V=1.0130654, theta=-37.241775 -> V=1.0, theta=0.0
% INFO    : Bus 83985	: V=1.0134708, theta=-36.645245 -> V=1.0, theta=0.0
% INFO    : Bus 83986	: V=0.9807558, theta=-26.545738 -> V=1.0, theta=0.0
% INFO    : Bus 83987	: V=0.9865352, theta=-27.39771 -> V=1.0, theta=0.0
% INFO    : Bus 83988	: V=0.9747165, theta=-27.759388 -> V=1.0, theta=0.0
% INFO    : Bus 83989	: V=0.975572, theta=-27.996767 -> V=1.0, theta=0.0
% INFO    : Bus 83990	: V=0.9729023, theta=-27.933094 -> V=1.0, theta=0.0
% INFO    : Bus 83991	: V=0.9715221, theta=-27.915105 -> V=1.0, theta=0.0
% INFO    : Bus 83992	: V=0.9740505, theta=-27.889587 -> V=1.0, theta=0.0
% INFO    : Bus 83993	: V=0.975546, theta=-27.343828 -> V=1.0, theta=0.0
% INFO    : Bus 83994	: V=0.9829507, theta=-26.385179 -> V=1.0, theta=0.0
% INFO    : Bus 83995	: V=0.9829043, theta=-26.266187 -> V=1.0, theta=0.0
% INFO    : Bus 83996	: V=0.9796343, theta=-26.758009 -> V=1.0, theta=0.0
% INFO    : Bus 83997	: V=0.9833163, theta=-26.104259 -> V=1.0, theta=0.0
% INFO    : Bus 83998	: V=0.9660614, theta=-27.909426 -> V=1.0, theta=0.0
% INFO    : Bus 83999	: V=0.9848452, theta=-25.883031 -> V=1.0, theta=0.0
% INFO    : Bus 84000	: V=0.9801038, theta=-26.629638 -> V=1.0, theta=0.0
% INFO    : Bus 84001	: V=0.9818724, theta=-25.999959 -> V=1.0, theta=0.0
% INFO    : Bus 84002	: V=0.9807174, theta=-26.191848 -> V=1.0, theta=0.0
% INFO    : Bus 84003	: V=0.984228, theta=-25.402409 -> V=1.0, theta=0.0
% INFO    : Bus 84004	: V=0.9842059, theta=-25.908413 -> V=1.0, theta=0.0
% INFO    : Bus 84005	: V=0.9858109, theta=-25.300001 -> V=1.0, theta=0.0
% INFO    : Bus 84006	: V=0.9842245, theta=-25.566142 -> V=1.0, theta=0.0
% INFO    : Bus 84007	: V=0.9878116, theta=-25.230536 -> V=1.0, theta=0.0
% INFO    : Bus 84008	: V=0.9856385, theta=-25.751508 -> V=1.0, theta=0.0
% INFO    : Bus 84009	: V=0.9890041, theta=-25.102009 -> V=1.0, theta=0.0
% INFO    : Bus 84010	: V=0.9786772, theta=-25.622644 -> V=1.0, theta=0.0
% INFO    : Bus 84011	: V=0.9880029, theta=-24.90502 -> V=1.0, theta=0.0
% INFO    : Bus 84012	: V=0.9863251, theta=-25.140697 -> V=1.0, theta=0.0
% INFO    : Bus 84013	: V=0.9856235, theta=-25.350656 -> V=1.0, theta=0.0
% INFO    : Bus 84014	: V=0.9747164, theta=-27.859194 -> V=1.0, theta=0.0
% INFO    : Bus 84015	: V=1.0024576, theta=-22.627167 -> V=1.0, theta=0.0
% INFO    : Bus 84016	: V=1.0039483, theta=-22.321855 -> V=1.0, theta=0.0
% INFO    : Bus 84017	: V=0.9987549, theta=-23.517565 -> V=1.0, theta=0.0
% INFO    : Bus 84018	: V=0.9972093, theta=-23.891395 -> V=1.0, theta=0.0
% INFO    : Bus 84019	: V=0.9824275, theta=-26.478266 -> V=1.0, theta=0.0
% INFO    : Bus 84020	: V=0.9911789, theta=-24.836246 -> V=1.0, theta=0.0
% INFO    : Bus 84021	: V=0.9932149, theta=-24.35186 -> V=1.0, theta=0.0
% INFO    : Bus 84022	: V=0.9836261, theta=-25.656914 -> V=1.0, theta=0.0
% INFO    : Bus 84023	: V=0.9898502, theta=-24.881805 -> V=1.0, theta=0.0
% INFO    : Bus 84024	: V=0.9852544, theta=-26.188776 -> V=1.0, theta=0.0
% INFO    : Bus 84025	: V=0.9871272, theta=-25.247763 -> V=1.0, theta=0.0
% INFO    : Bus 84026	: V=0.9899717, theta=-25.217392 -> V=1.0, theta=0.0
% INFO    : Bus 84027	: V=0.9875821, theta=-25.516259 -> V=1.0, theta=0.0
% INFO    : Bus 84028	: V=0.9899328, theta=-25.132164 -> V=1.0, theta=0.0
% INFO    : Bus 84029	: V=0.9954493, theta=-24.207576 -> V=1.0, theta=0.0
% INFO    : Bus 84030	: V=0.9938704, theta=-24.2536 -> V=1.0, theta=0.0
% INFO    : Bus 84031	: V=0.9951559, theta=-24.295189 -> V=1.0, theta=0.0
% INFO    : Bus 84032	: V=0.9910023, theta=-24.655395 -> V=1.0, theta=0.0
% INFO    : Bus 84033	: V=0.9879854, theta=-25.089994 -> V=1.0, theta=0.0
% INFO    : Bus 84034	: V=0.9801819, theta=-26.764601 -> V=1.0, theta=0.0
% INFO    : Bus 84035	: V=0.9814192, theta=-26.73829 -> V=1.0, theta=0.0
% INFO    : Bus 84036	: V=0.986676, theta=-25.978481 -> V=1.0, theta=0.0
% INFO    : Bus 84037	: V=0.9850901, theta=-26.234185 -> V=1.0, theta=0.0
% INFO    : Bus 84038	: V=0.989019, theta=-25.423424 -> V=1.0, theta=0.0
% INFO    : Bus 84039	: V=0.985277, theta=-26.177565 -> V=1.0, theta=0.0
% INFO    : Bus 84040	: V=0.9833033, theta=-26.405065 -> V=1.0, theta=0.0
% INFO    : Bus 84041	: V=0.981383, theta=-26.552484 -> V=1.0, theta=0.0
% INFO    : Bus 84042	: V=0.9819347, theta=-26.428899 -> V=1.0, theta=0.0
% INFO    : Bus 84043	: V=0.9788421, theta=-26.850104 -> V=1.0, theta=0.0
% INFO    : Bus 84044	: V=0.9767992, theta=-27.516478 -> V=1.0, theta=0.0
% INFO    : Bus 84045	: V=0.982676, theta=-27.130055 -> V=1.0, theta=0.0
% INFO    : Bus 84046	: V=0.9782761, theta=-27.642325 -> V=1.0, theta=0.0
% INFO    : Bus 84047	: V=0.9769094, theta=-28.018771 -> V=1.0, theta=0.0
% INFO    : Bus 84048	: V=0.9792415, theta=-27.61818 -> V=1.0, theta=0.0
% INFO    : Bus 84049	: V=0.9762759, theta=-28.067933 -> V=1.0, theta=0.0
% INFO    : Bus 84050	: V=0.9743563, theta=-27.926475 -> V=1.0, theta=0.0
% INFO    : Bus 84051	: V=0.9724212, theta=-28.317055 -> V=1.0, theta=0.0
% INFO    : Bus 84052	: V=0.969221, theta=-28.868336 -> V=1.0, theta=0.0
% INFO    : Bus 84053	: V=0.9695705, theta=-28.61973 -> V=1.0, theta=0.0
% INFO    : Bus 84054	: V=0.9710077, theta=-28.305327 -> V=1.0, theta=0.0
% INFO    : Bus 84055	: V=0.9721802, theta=-28.65499 -> V=1.0, theta=0.0
% INFO    : Bus 84056	: V=0.9743814, theta=-28.302913 -> V=1.0, theta=0.0
% INFO    : Bus 84057	: V=0.9777799, theta=-27.871946 -> V=1.0, theta=0.0
% INFO    : Bus 84058	: V=0.9762636, theta=-27.979792 -> V=1.0, theta=0.0
% INFO    : Bus 84059	: V=0.9914842, theta=-26.752583 -> V=1.0, theta=0.0
% INFO    : Bus 84060	: V=0.9899342, theta=-27.097224 -> V=1.0, theta=0.0
% INFO    : Bus 84061	: V=0.9925642, theta=-26.574683 -> V=1.0, theta=0.0
% INFO    : Bus 84062	: V=0.9873991, theta=-27.339817 -> V=1.0, theta=0.0
% INFO    : Bus 84063	: V=0.9992502, theta=-26.200582 -> V=1.0, theta=0.0
% INFO    : Bus 84064	: V=0.9968831, theta=-26.468661 -> V=1.0, theta=0.0
% INFO    : Bus 84065	: V=0.9753716, theta=-27.597558 -> V=1.0, theta=0.0
% INFO    : Bus 84066	: V=0.9753035, theta=-27.46598 -> V=1.0, theta=0.0
% INFO    : Bus 84067	: V=0.9818222, theta=-26.808296 -> V=1.0, theta=0.0
% INFO    : Bus 84068	: V=0.9809904, theta=-26.878186 -> V=1.0, theta=0.0
% INFO    : Bus 84069	: V=0.9953759, theta=-24.207392 -> V=1.0, theta=0.0
% INFO    : Bus 84070	: V=0.9956308, theta=-24.772945 -> V=1.0, theta=0.0
% INFO    : Bus 84071	: V=0.9913579, theta=-24.921269 -> V=1.0, theta=0.0
% INFO    : Bus 84072	: V=0.9923364, theta=-23.977641 -> V=1.0, theta=0.0
% INFO    : Bus 84073	: V=0.9965657, theta=-22.384999 -> V=1.0, theta=0.0
% INFO    : Bus 84074	: V=0.9971283, theta=-23.572237 -> V=1.0, theta=0.0
% INFO    : Bus 84075	: V=0.9747592, theta=-27.700268 -> V=1.0, theta=0.0
% INFO    : Bus 84076	: V=0.9775426, theta=-26.874424 -> V=1.0, theta=0.0
% INFO    : Bus 84077	: V=0.9704544, theta=-28.117697 -> V=1.0, theta=0.0
% INFO    : Bus 84078	: V=0.9648281, theta=-36.386944 -> V=1.0, theta=0.0
% INFO    : Bus 84079	: V=0.952282, theta=-38.621007 -> V=1.0, theta=0.0
% INFO    : Bus 84080	: V=0.9692401, theta=-34.636252 -> V=1.0, theta=0.0
% INFO    : Bus 84081	: V=0.9575142, theta=-36.515145 -> V=1.0, theta=0.0
% INFO    : Bus 84082	: V=0.9558299, theta=-36.214701 -> V=1.0, theta=0.0
% INFO    : Bus 84083	: V=0.9580638, theta=-36.11801 -> V=1.0, theta=0.0
% INFO    : Bus 84084	: V=0.9587763, theta=-35.982559 -> V=1.0, theta=0.0
% INFO    : Bus 84085	: V=0.9545566, theta=-38.256846 -> V=1.0, theta=0.0
% INFO    : Bus 84086	: V=0.9818479, theta=-30.046377 -> V=1.0, theta=0.0
% INFO    : Bus 84087	: V=0.9807441, theta=-30.12395 -> V=1.0, theta=0.0
% INFO    : Bus 84088	: V=0.9726284, theta=-31.844795 -> V=1.0, theta=0.0
% INFO    : Bus 84089	: V=0.9881199, theta=-31.97862 -> V=1.0, theta=0.0
% INFO    : Bus 84090	: V=0.9859857, theta=-32.171665 -> V=1.0, theta=0.0
% INFO    : Bus 84091	: V=0.985053, theta=-30.353571 -> V=1.0, theta=0.0
% INFO    : Bus 84092	: V=0.9921197, theta=-31.458921 -> V=1.0, theta=0.0
% INFO    : Bus 84093	: V=0.9946884, theta=-36.484995 -> V=1.0, theta=0.0
% INFO    : Bus 84094	: V=0.9982693, theta=-35.819998 -> V=1.0, theta=0.0
% INFO    : Bus 84095	: V=0.9703521, theta=-50.314727 -> V=1.0, theta=0.0
% INFO    : Bus 84096	: V=0.9743981, theta=-49.686844 -> V=1.0, theta=0.0
% INFO    : Bus 84097	: V=0.9758165, theta=-48.55363 -> V=1.0, theta=0.0
% INFO    : Bus 84098	: V=0.9827716, theta=-47.43975 -> V=1.0, theta=0.0
% INFO    : Bus 84099	: V=0.9784567, theta=-48.594005 -> V=1.0, theta=0.0
% INFO    : Bus 84100	: V=0.9772983, theta=-49.072164 -> V=1.0, theta=0.0
% INFO    : Bus 84101	: V=0.967909, theta=-44.726693 -> V=1.0, theta=0.0
% INFO    : Bus 84102	: V=0.9670849, theta=-44.743587 -> V=1.0, theta=0.0
% INFO    : Bus 84103	: V=0.9680386, theta=-44.371112 -> V=1.0, theta=0.0
% INFO    : Bus 84104	: V=0.9619552, theta=-43.813956 -> V=1.0, theta=0.0
% INFO    : Bus 84105	: V=0.9584383, theta=-48.58105 -> V=1.0, theta=0.0
% INFO    : Bus 84106	: V=0.9704159, theta=-34.55815 -> V=1.0, theta=0.0
% INFO    : Bus 84107	: V=1.0107358, theta=-52.437176 -> V=1.0, theta=0.0
% INFO    : Bus 84108	: V=1.012109, theta=-51.829896 -> V=1.0, theta=0.0
% INFO    : Bus 84109	: V=1.008604, theta=-52.204239 -> V=1.0, theta=0.0
% INFO    : Bus 84110	: V=1.01514, theta=-51.351261 -> V=1.0, theta=0.0
% INFO    : Bus 84111	: V=1.0154713, theta=-52.008456 -> V=1.0, theta=0.0
% INFO    : Bus 84112	: V=1.0159743, theta=-50.974022 -> V=1.0, theta=0.0
% INFO    : Bus 84113	: V=1.0130776, theta=-51.338478 -> V=1.0, theta=0.0
% INFO    : Bus 84114	: V=0.9919968, theta=-51.477673 -> V=1.0, theta=0.0
% INFO    : Bus 84115	: V=0.9873224, theta=-44.539956 -> V=1.0, theta=0.0
% INFO    : Bus 84116	: V=0.987372, theta=-45.185311 -> V=1.0, theta=0.0
% INFO    : Bus 84117	: V=0.9792178, theta=-46.109159 -> V=1.0, theta=0.0
% INFO    : Bus 84118	: V=0.9669861, theta=-47.737559 -> V=1.0, theta=0.0
% INFO    : Bus 84119	: V=0.9707408, theta=-46.583502 -> V=1.0, theta=0.0
% INFO    : Bus 84120	: V=0.9738096, theta=-46.009521 -> V=1.0, theta=0.0
% INFO    : Bus 84121	: V=0.9783145, theta=-45.264011 -> V=1.0, theta=0.0
% INFO    : Bus 84122	: V=0.9754513, theta=-45.852615 -> V=1.0, theta=0.0
% INFO    : Bus 84123	: V=0.9612805, theta=-46.85655 -> V=1.0, theta=0.0
% INFO    : Bus 84124	: V=0.9903557, theta=-51.882949 -> V=1.0, theta=0.0
% INFO    : Bus 84125	: V=0.9894098, theta=-51.837913 -> V=1.0, theta=0.0
% INFO    : Bus 84126	: V=0.9987499, theta=-50.771285 -> V=1.0, theta=0.0
% INFO    : Bus 84127	: V=0.9880752, theta=-52.071475 -> V=1.0, theta=0.0
% INFO    : Bus 84128	: V=0.9897081, theta=-51.976602 -> V=1.0, theta=0.0
% INFO    : Bus 84129	: V=0.99011, theta=-52.012788 -> V=1.0, theta=0.0
% INFO    : Bus 84130	: V=0.9863751, theta=-52.381606 -> V=1.0, theta=0.0
% INFO    : Bus 84131	: V=0.9901439, theta=-52.065648 -> V=1.0, theta=0.0
% INFO    : Bus 84132	: V=0.9967251, theta=-51.583109 -> V=1.0, theta=0.0
% INFO    : Bus 84133	: V=1.0058823, theta=-50.351301 -> V=1.0, theta=0.0
% INFO    : Bus 84134	: V=0.9999863, theta=-51.523579 -> V=1.0, theta=0.0
% INFO    : Bus 84135	: V=0.9938792, theta=-51.882764 -> V=1.0, theta=0.0
% INFO    : Bus 84136	: V=0.9962976, theta=-51.688177 -> V=1.0, theta=0.0
% INFO    : Bus 84137	: V=0.9926569, theta=-51.992254 -> V=1.0, theta=0.0
% INFO    : Bus 84138	: V=1.0084927, theta=-50.748834 -> V=1.0, theta=0.0
% INFO    : Bus 84139	: V=0.9950056, theta=-51.885652 -> V=1.0, theta=0.0
% INFO    : Bus 84140	: V=1.0103277, theta=-50.659786 -> V=1.0, theta=0.0
% INFO    : Bus 84141	: V=1.0088169, theta=-50.994297 -> V=1.0, theta=0.0
% INFO    : Bus 84142	: V=1.0154377, theta=-50.581701 -> V=1.0, theta=0.0
% INFO    : Bus 84143	: V=1.013114, theta=-50.875082 -> V=1.0, theta=0.0
% INFO    : Bus 84144	: V=1.0010273, theta=-51.553381 -> V=1.0, theta=0.0
% INFO    : Bus 84145	: V=1.0063416, theta=-51.816815 -> V=1.0, theta=0.0
% INFO    : Bus 84146	: V=1.0026439, theta=-51.875405 -> V=1.0, theta=0.0
% INFO    : Bus 84147	: V=0.9995068, theta=-51.343158 -> V=1.0, theta=0.0
% INFO    : Bus 84148	: V=0.9978242, theta=-51.569395 -> V=1.0, theta=0.0
% INFO    : Bus 84149	: V=0.9937469, theta=-51.817736 -> V=1.0, theta=0.0
% INFO    : Bus 84150	: V=1.0066613, theta=-30.47655 -> V=1.0, theta=0.0
% INFO    : Bus 84151	: V=1.0072852, theta=-29.112455 -> V=1.0, theta=0.0
% INFO    : Bus 84152	: V=1.0021642, theta=-33.140916 -> V=1.0, theta=0.0
% INFO    : Bus 84153	: V=0.9580475, theta=-44.83225 -> V=1.0, theta=0.0
% INFO    : Bus 84154	: V=0.9573648, theta=-44.650672 -> V=1.0, theta=0.0
% INFO    : Bus 84155	: V=0.9613799, theta=-44.507795 -> V=1.0, theta=0.0
% INFO    : Bus 84156	: V=0.9620103, theta=-44.549112 -> V=1.0, theta=0.0
% INFO    : Bus 84157	: V=0.9590124, theta=-45.88078 -> V=1.0, theta=0.0
% INFO    : Bus 84158	: V=0.9601661, theta=-43.339116 -> V=1.0, theta=0.0
% INFO    : Bus 84159	: V=0.9601677, theta=-43.869643 -> V=1.0, theta=0.0
% INFO    : Bus 84160	: V=0.9674295, theta=-42.984192 -> V=1.0, theta=0.0
% INFO    : Bus 84161	: V=0.971227, theta=-42.563502 -> V=1.0, theta=0.0
% INFO    : Bus 84162	: V=0.9653122, theta=-43.703552 -> V=1.0, theta=0.0
% INFO    : Bus 84163	: V=0.9543201, theta=-34.358383 -> V=1.0, theta=0.0
% INFO    : Bus 84164	: V=0.9506173, theta=-35.393965 -> V=1.0, theta=0.0
% INFO    : Bus 84165	: V=0.9408281, theta=-37.387976 -> V=1.0, theta=0.0
% INFO    : Bus 84166	: V=0.9374416, theta=-40.579229 -> V=1.0, theta=0.0
% INFO    : Bus 84167	: V=0.9830415, theta=-47.90114 -> V=1.0, theta=0.0
% INFO    : Bus 84168	: V=0.9745271, theta=-50.173695 -> V=1.0, theta=0.0
% INFO    : Bus 84169	: V=0.9824668, theta=-48.196513 -> V=1.0, theta=0.0
% INFO    : Bus 84170	: V=0.9825104, theta=-47.820209 -> V=1.0, theta=0.0
% INFO    : Bus 84171	: V=0.9861862, theta=-46.282263 -> V=1.0, theta=0.0
% INFO    : Bus 84172	: V=0.9740098, theta=-47.960161 -> V=1.0, theta=0.0
% INFO    : Bus 84173	: V=0.9747732, theta=-47.907121 -> V=1.0, theta=0.0
% INFO    : Bus 84174	: V=0.982083, theta=-46.852769 -> V=1.0, theta=0.0
% INFO    : Bus 84175	: V=0.9752242, theta=-47.848299 -> V=1.0, theta=0.0
% INFO    : Bus 84176	: V=0.9854472, theta=-46.348763 -> V=1.0, theta=0.0
% INFO    : Bus 84177	: V=0.9808586, theta=-47.103667 -> V=1.0, theta=0.0
% INFO    : Bus 84178	: V=0.9833814, theta=-47.171259 -> V=1.0, theta=0.0
% INFO    : Bus 84179	: V=0.9692354, theta=-48.589578 -> V=1.0, theta=0.0
% INFO    : Bus 84180	: V=0.9734604, theta=-48.680518 -> V=1.0, theta=0.0
% INFO    : Bus 84181	: V=0.97411, theta=-48.077677 -> V=1.0, theta=0.0
% INFO    : Bus 84182	: V=0.9773573, theta=-48.05164 -> V=1.0, theta=0.0
% INFO    : Bus 84183	: V=0.9806332, theta=-47.766218 -> V=1.0, theta=0.0
% INFO    : Bus 84184	: V=0.9694671, theta=-49.894142 -> V=1.0, theta=0.0
% INFO    : Bus 84185	: V=0.9714567, theta=-50.855027 -> V=1.0, theta=0.0
% INFO    : Bus 84186	: V=0.9722221, theta=-49.998694 -> V=1.0, theta=0.0
% INFO    : Bus 84187	: V=0.9708006, theta=-50.898964 -> V=1.0, theta=0.0
% INFO    : Bus 84188	: V=0.9680555, theta=-50.901022 -> V=1.0, theta=0.0
% INFO    : Bus 84189	: V=0.9654151, theta=-51.303867 -> V=1.0, theta=0.0
% INFO    : Bus 84190	: V=0.9674863, theta=-50.875289 -> V=1.0, theta=0.0
% INFO    : Bus 84191	: V=0.9889371, theta=-45.439367 -> V=1.0, theta=0.0
% INFO    : Bus 84192	: V=0.9611389, theta=-33.196169 -> V=1.0, theta=0.0
% INFO    : Bus 84193	: V=0.9700587, theta=-32.414444 -> V=1.0, theta=0.0
% INFO    : Bus 84194	: V=0.9769325, theta=-32.163387 -> V=1.0, theta=0.0
% INFO    : Bus 84195	: V=0.9731137, theta=-32.392377 -> V=1.0, theta=0.0
% INFO    : Bus 84196	: V=0.9740276, theta=-32.422225 -> V=1.0, theta=0.0
% INFO    : Bus 84197	: V=0.9730465, theta=-32.405764 -> V=1.0, theta=0.0
% INFO    : Bus 84198	: V=0.9704133, theta=-32.596162 -> V=1.0, theta=0.0
% INFO    : Bus 84199	: V=0.962286, theta=-33.082977 -> V=1.0, theta=0.0
% INFO    : Bus 84200	: V=0.9684418, theta=-32.718884 -> V=1.0, theta=0.0
% INFO    : Bus 84201	: V=0.9711568, theta=-32.526413 -> V=1.0, theta=0.0
% INFO    : Bus 84202	: V=0.9614597, theta=-33.152345 -> V=1.0, theta=0.0
% INFO    : Bus 84203	: V=0.9657095, theta=-32.958687 -> V=1.0, theta=0.0
% INFO    : Bus 84204	: V=0.9730882, theta=-32.502781 -> V=1.0, theta=0.0
% INFO    : Bus 84205	: V=0.9677339, theta=-32.827044 -> V=1.0, theta=0.0
% INFO    : Bus 84206	: V=0.9950063, theta=-29.447395 -> V=1.0, theta=0.0
% INFO    : Bus 84207	: V=0.9873742, theta=-30.848706 -> V=1.0, theta=0.0
% INFO    : Bus 84208	: V=0.9848078, theta=-31.364389 -> V=1.0, theta=0.0
% INFO    : Bus 84209	: V=0.9705418, theta=-31.921087 -> V=1.0, theta=0.0
% INFO    : Bus 84210	: V=0.9733045, theta=-32.074732 -> V=1.0, theta=0.0
% INFO    : Bus 84211	: V=0.9764932, theta=-32.023122 -> V=1.0, theta=0.0
% INFO    : Bus 84212	: V=0.9654156, theta=-32.4008 -> V=1.0, theta=0.0
% INFO    : Bus 84213	: V=0.9601619, theta=-33.333977 -> V=1.0, theta=0.0
% INFO    : Bus 84214	: V=0.9740554, theta=-31.911727 -> V=1.0, theta=0.0
% INFO    : Bus 84215	: V=0.969046, theta=-32.773333 -> V=1.0, theta=0.0
% INFO    : Bus 84216	: V=0.9732863, theta=-31.905841 -> V=1.0, theta=0.0
% INFO    : Bus 84217	: V=0.970079, theta=-32.504659 -> V=1.0, theta=0.0
% INFO    : Bus 84218	: V=0.9594669, theta=-33.396716 -> V=1.0, theta=0.0
% INFO    : Bus 84219	: V=0.9614235, theta=-33.300406 -> V=1.0, theta=0.0
% INFO    : Bus 84220	: V=0.9603268, theta=-33.165202 -> V=1.0, theta=0.0
% INFO    : Bus 84221	: V=0.9597142, theta=-33.352896 -> V=1.0, theta=0.0
% INFO    : Bus 84222	: V=0.966775, theta=-32.643617 -> V=1.0, theta=0.0
% INFO    : Bus 84223	: V=0.9670661, theta=-32.685084 -> V=1.0, theta=0.0
% INFO    : Bus 84224	: V=0.9624151, theta=-33.15374 -> V=1.0, theta=0.0
% INFO    : Bus 84225	: V=0.9724051, theta=-31.691626 -> V=1.0, theta=0.0
% INFO    : Bus 84226	: V=0.9830411, theta=-31.774794 -> V=1.0, theta=0.0
% INFO    : Bus 84227	: V=0.9749428, theta=-32.319792 -> V=1.0, theta=0.0
% INFO    : Bus 84228	: V=0.9792935, theta=-31.847097 -> V=1.0, theta=0.0
% INFO    : Bus 84229	: V=0.9794397, theta=-32.069817 -> V=1.0, theta=0.0
% INFO    : Bus 84230	: V=0.9663705, theta=-32.900185 -> V=1.0, theta=0.0
% INFO    : Bus 84231	: V=0.9687523, theta=-37.1943 -> V=1.0, theta=0.0
% INFO    : Bus 84232	: V=0.9608636, theta=-38.033026 -> V=1.0, theta=0.0
% INFO    : Bus 84233	: V=0.9689158, theta=-39.052123 -> V=1.0, theta=0.0
% INFO    : Bus 84234	: V=0.9618304, theta=-62.322833 -> V=1.0, theta=0.0
% INFO    : Bus 84235	: V=0.9631299, theta=-61.944195 -> V=1.0, theta=0.0
% INFO    : Bus 84236	: V=0.9630628, theta=-62.204349 -> V=1.0, theta=0.0
% INFO    : Bus 84237	: V=0.9629217, theta=-62.19382 -> V=1.0, theta=0.0
% INFO    : Bus 84238	: V=0.9621863, theta=-62.00584 -> V=1.0, theta=0.0
% INFO    : Bus 84239	: V=0.9626424, theta=-62.339136 -> V=1.0, theta=0.0
% INFO    : Bus 84240	: V=0.9609157, theta=-62.725187 -> V=1.0, theta=0.0
% INFO    : Bus 84241	: V=0.9646751, theta=-62.221562 -> V=1.0, theta=0.0
% INFO    : Bus 84242	: V=0.965223, theta=-61.936196 -> V=1.0, theta=0.0
% INFO    : Bus 84243	: V=0.966192, theta=-61.84953 -> V=1.0, theta=0.0
% INFO    : Bus 84244	: V=0.9753193, theta=-60.554939 -> V=1.0, theta=0.0
% INFO    : Bus 84245	: V=0.9636597, theta=-61.830337 -> V=1.0, theta=0.0
% INFO    : Bus 84246	: V=0.9642808, theta=-61.724677 -> V=1.0, theta=0.0
% INFO    : Bus 84247	: V=0.9663333, theta=-60.65754 -> V=1.0, theta=0.0
% INFO    : Bus 84248	: V=0.9728037, theta=-59.798315 -> V=1.0, theta=0.0
% INFO    : Bus 84249	: V=0.9679362, theta=-60.476039 -> V=1.0, theta=0.0
% INFO    : Bus 84250	: V=0.96428, theta=-61.857624 -> V=1.0, theta=0.0
% INFO    : Bus 84251	: V=0.9688815, theta=-62.165296 -> V=1.0, theta=0.0
% INFO    : Bus 84252	: V=0.9672364, theta=-61.431915 -> V=1.0, theta=0.0
% INFO    : Bus 84253	: V=0.9713665, theta=-59.80824 -> V=1.0, theta=0.0
% INFO    : Bus 84254	: V=0.9618498, theta=-62.573789 -> V=1.0, theta=0.0
% INFO    : Bus 84255	: V=0.9596482, theta=-43.597688 -> V=1.0, theta=0.0
% INFO    : Bus 84256	: V=0.954772, theta=-45.390671 -> V=1.0, theta=0.0
% INFO    : Bus 84257	: V=0.9542269, theta=-45.638639 -> V=1.0, theta=0.0
% INFO    : Bus 84258	: V=0.9550565, theta=-54.390407 -> V=1.0, theta=0.0
% INFO    : Bus 84259	: V=0.9609832, theta=-53.650248 -> V=1.0, theta=0.0
% INFO    : Bus 84260	: V=0.9594117, theta=-53.983865 -> V=1.0, theta=0.0
% INFO    : Bus 84261	: V=0.9635649, theta=-52.626804 -> V=1.0, theta=0.0
% INFO    : Bus 84262	: V=0.9665391, theta=-53.16569 -> V=1.0, theta=0.0
% INFO    : Bus 84263	: V=0.9589511, theta=-54.225956 -> V=1.0, theta=0.0
% INFO    : Bus 84264	: V=0.9587734, theta=-54.148017 -> V=1.0, theta=0.0
% INFO    : Bus 84265	: V=0.9612558, theta=-56.05084 -> V=1.0, theta=0.0
% INFO    : Bus 84266	: V=0.9633021, theta=-55.556963 -> V=1.0, theta=0.0
% INFO    : Bus 84267	: V=0.9620794, theta=-54.944842 -> V=1.0, theta=0.0
% INFO    : Bus 84268	: V=1.0166232, theta=-31.051416 -> V=1.0, theta=0.0
% INFO    : Bus 84269	: V=1.008163, theta=-31.560856 -> V=1.0, theta=0.0
% INFO    : Bus 84270	: V=1.0182898, theta=-30.773526 -> V=1.0, theta=0.0
% INFO    : Bus 84271	: V=1.0183945, theta=-33.381666 -> V=1.0, theta=0.0
% INFO    : Bus 84272	: V=0.9505448, theta=-31.315504 -> V=1.0, theta=0.0
% INFO    : Bus 84273	: V=0.9467384, theta=-31.732773 -> V=1.0, theta=0.0
% INFO    : Bus 84274	: V=0.9519973, theta=-31.404464 -> V=1.0, theta=0.0
% INFO    : Bus 84275	: V=0.9519426, theta=-30.97028 -> V=1.0, theta=0.0
% INFO    : Bus 84276	: V=0.9531668, theta=-31.363458 -> V=1.0, theta=0.0
% INFO    : Bus 84277	: V=0.9542578, theta=-31.683648 -> V=1.0, theta=0.0
% INFO    : Bus 84278	: V=0.9423509, theta=-36.70009 -> V=1.0, theta=0.0
% INFO    : Bus 84279	: V=0.9507599, theta=-35.202114 -> V=1.0, theta=0.0
% INFO    : Bus 84280	: V=0.9505039, theta=-35.549975 -> V=1.0, theta=0.0
% INFO    : Bus 84281	: V=0.948221, theta=-35.201567 -> V=1.0, theta=0.0
% INFO    : Bus 84282	: V=0.9558952, theta=-34.287836 -> V=1.0, theta=0.0
% INFO    : Bus 84283	: V=0.9523279, theta=-35.222848 -> V=1.0, theta=0.0
% INFO    : Bus 84284	: V=0.9477282, theta=-35.521198 -> V=1.0, theta=0.0
% INFO    : Bus 84285	: V=0.9449431, theta=-35.678218 -> V=1.0, theta=0.0
% INFO    : Bus 84286	: V=0.9471885, theta=-36.215307 -> V=1.0, theta=0.0
% INFO    : Bus 84287	: V=0.9734137, theta=-31.826271 -> V=1.0, theta=0.0
% INFO    : Bus 84288	: V=0.9713311, theta=-32.188545 -> V=1.0, theta=0.0
% INFO    : Bus 84289	: V=0.9704561, theta=-32.189273 -> V=1.0, theta=0.0
% INFO    : Bus 84290	: V=0.9689357, theta=-32.313603 -> V=1.0, theta=0.0
% INFO    : Bus 84291	: V=0.9724003, theta=-32.040025 -> V=1.0, theta=0.0
% INFO    : Bus 84292	: V=0.9700959, theta=-32.533616 -> V=1.0, theta=0.0
% INFO    : Bus 84293	: V=0.9721099, theta=-32.379593 -> V=1.0, theta=0.0
% INFO    : Bus 84294	: V=0.9682659, theta=-32.661033 -> V=1.0, theta=0.0
% INFO    : Bus 84295	: V=0.9553406, theta=-33.844603 -> V=1.0, theta=0.0
% INFO    : Bus 84296	: V=0.9720135, theta=-32.118368 -> V=1.0, theta=0.0
% INFO    : Bus 84297	: V=0.9674143, theta=-32.716428 -> V=1.0, theta=0.0
% INFO    : Bus 84298	: V=0.9693808, theta=-32.307484 -> V=1.0, theta=0.0
% INFO    : Bus 84299	: V=0.97049, theta=-32.237649 -> V=1.0, theta=0.0
% INFO    : Bus 84300	: V=0.9669428, theta=-32.648288 -> V=1.0, theta=0.0
% INFO    : Bus 84301	: V=0.9670634, theta=-32.645059 -> V=1.0, theta=0.0
% INFO    : Bus 84302	: V=0.9759032, theta=-31.52954 -> V=1.0, theta=0.0
% INFO    : Bus 84303	: V=0.9730629, theta=-31.906818 -> V=1.0, theta=0.0
% INFO    : Bus 84304	: V=0.9715532, theta=-32.036368 -> V=1.0, theta=0.0
% INFO    : Bus 84305	: V=0.9701768, theta=-32.261906 -> V=1.0, theta=0.0
% INFO    : Bus 84306	: V=0.9698682, theta=-32.239105 -> V=1.0, theta=0.0
% INFO    : Bus 84307	: V=0.9693627, theta=-32.291777 -> V=1.0, theta=0.0
% INFO    : Bus 84308	: V=0.9684864, theta=-32.407934 -> V=1.0, theta=0.0
% INFO    : Bus 84309	: V=0.9705399, theta=-32.098618 -> V=1.0, theta=0.0
% INFO    : Bus 84310	: V=0.9687346, theta=-32.27358 -> V=1.0, theta=0.0
% INFO    : Bus 84311	: V=0.971448, theta=-31.997276 -> V=1.0, theta=0.0
% INFO    : Bus 84312	: V=0.9724908, theta=-31.811123 -> V=1.0, theta=0.0
% INFO    : Bus 84313	: V=0.9719638, theta=-31.73935 -> V=1.0, theta=0.0
% INFO    : Bus 84314	: V=0.9743288, theta=-31.446197 -> V=1.0, theta=0.0
% INFO    : Bus 84315	: V=0.9733571, theta=-31.628221 -> V=1.0, theta=0.0
% INFO    : Bus 84316	: V=0.9768314, theta=-31.253307 -> V=1.0, theta=0.0
% INFO    : Bus 84317	: V=0.9842618, theta=-30.200851 -> V=1.0, theta=0.0
% INFO    : Bus 84318	: V=0.9844514, theta=-30.155506 -> V=1.0, theta=0.0
% INFO    : Bus 84319	: V=0.9850288, theta=-29.866829 -> V=1.0, theta=0.0
% INFO    : Bus 84320	: V=0.9746771, theta=-31.061844 -> V=1.0, theta=0.0
% INFO    : Bus 84321	: V=0.9776852, theta=-30.96053 -> V=1.0, theta=0.0
% INFO    : Bus 84322	: V=0.9831577, theta=-30.281498 -> V=1.0, theta=0.0
% INFO    : Bus 84323	: V=0.9835509, theta=-30.11354 -> V=1.0, theta=0.0
% INFO    : Bus 84324	: V=0.9819962, theta=-30.359409 -> V=1.0, theta=0.0
% INFO    : Bus 84325	: V=0.9852446, theta=-29.916874 -> V=1.0, theta=0.0
% INFO    : Bus 84326	: V=0.9875882, theta=-29.387082 -> V=1.0, theta=0.0
% INFO    : Bus 84327	: V=0.9861723, theta=-29.747912 -> V=1.0, theta=0.0
% INFO    : Bus 84328	: V=0.984421, theta=-29.906392 -> V=1.0, theta=0.0
% INFO    : Bus 84329	: V=0.9677676, theta=-32.323473 -> V=1.0, theta=0.0
% INFO    : Bus 84330	: V=0.9717641, theta=-32.030613 -> V=1.0, theta=0.0
% INFO    : Bus 84331	: V=0.9685435, theta=-32.364716 -> V=1.0, theta=0.0
% INFO    : Bus 84332	: V=0.9718571, theta=-32.002099 -> V=1.0, theta=0.0
% INFO    : Bus 84333	: V=0.9642244, theta=-33.377056 -> V=1.0, theta=0.0
% INFO    : Bus 84334	: V=0.9633412, theta=-33.44707 -> V=1.0, theta=0.0
% INFO    : Bus 84335	: V=0.9613601, theta=-33.693957 -> V=1.0, theta=0.0
% INFO    : Bus 84336	: V=0.9608136, theta=-33.634376 -> V=1.0, theta=0.0
% INFO    : Bus 84337	: V=0.960928, theta=-33.804924 -> V=1.0, theta=0.0
% INFO    : Bus 84338	: V=0.9650224, theta=-32.96927 -> V=1.0, theta=0.0
% INFO    : Bus 84339	: V=0.9650256, theta=-32.792559 -> V=1.0, theta=0.0
% INFO    : Bus 84340	: V=0.9649249, theta=-33.011633 -> V=1.0, theta=0.0
% INFO    : Bus 84341	: V=0.9566799, theta=-34.255199 -> V=1.0, theta=0.0
% INFO    : Bus 84342	: V=0.9579303, theta=-34.07402 -> V=1.0, theta=0.0
% INFO    : Bus 84343	: V=0.9523882, theta=-34.421177 -> V=1.0, theta=0.0
% INFO    : Bus 84344	: V=0.9566082, theta=-34.223209 -> V=1.0, theta=0.0
% INFO    : Bus 84345	: V=0.9508869, theta=-34.922685 -> V=1.0, theta=0.0
% INFO    : Bus 84346	: V=0.9491011, theta=-34.763894 -> V=1.0, theta=0.0
% INFO    : Bus 84347	: V=0.95825, theta=-33.339327 -> V=1.0, theta=0.0
% INFO    : Bus 84348	: V=0.9569035, theta=-34.119324 -> V=1.0, theta=0.0
% INFO    : Bus 84349	: V=0.9867805, theta=-29.306172 -> V=1.0, theta=0.0
% INFO    : Bus 84350	: V=0.9845276, theta=-29.582019 -> V=1.0, theta=0.0
% INFO    : Bus 84351	: V=0.9739997, theta=-31.828824 -> V=1.0, theta=0.0
% INFO    : Bus 84352	: V=0.9709446, theta=-32.412074 -> V=1.0, theta=0.0
% INFO    : Bus 84353	: V=1.0088389, theta=-36.045942 -> V=1.0, theta=0.0
% INFO    : Bus 84354	: V=0.956558, theta=-48.147711 -> V=1.0, theta=0.0
% INFO    : Bus 84355	: V=0.9576266, theta=-47.018317 -> V=1.0, theta=0.0
% INFO    : Bus 84356	: V=0.9855331, theta=-42.645649 -> V=1.0, theta=0.0
% INFO    : Bus 84357	: V=0.9904215, theta=-40.873231 -> V=1.0, theta=0.0
% INFO    : Bus 84358	: V=0.9979994, theta=-40.612259 -> V=1.0, theta=0.0
% INFO    : Bus 84359	: V=0.9933584, theta=-41.015626 -> V=1.0, theta=0.0
% INFO    : Bus 84360	: V=0.9954778, theta=-40.073427 -> V=1.0, theta=0.0
% INFO    : Bus 84361	: V=0.9933684, theta=-40.787881 -> V=1.0, theta=0.0
% INFO    : Bus 84362	: V=0.9935672, theta=-40.600425 -> V=1.0, theta=0.0
% INFO    : Bus 84363	: V=0.9928907, theta=-40.653963 -> V=1.0, theta=0.0
% INFO    : Bus 84364	: V=1.0160814, theta=-36.592575 -> V=1.0, theta=0.0
% INFO    : Bus 84365	: V=1.0151004, theta=-37.040703 -> V=1.0, theta=0.0
% INFO    : Bus 84366	: V=0.9850869, theta=-37.416909 -> V=1.0, theta=0.0
% INFO    : Bus 84367	: V=0.9844174, theta=-37.346833 -> V=1.0, theta=0.0
% INFO    : Bus 84368	: V=0.9848955, theta=-37.410192 -> V=1.0, theta=0.0
% INFO    : Bus 84369	: V=0.9958846, theta=-31.077757 -> V=1.0, theta=0.0
% INFO    : Bus 84370	: V=0.9932633, theta=-31.962586 -> V=1.0, theta=0.0
% INFO    : Bus 84371	: V=0.9884742, theta=-31.605835 -> V=1.0, theta=0.0
% INFO    : Bus 84372	: V=0.988119, theta=-36.48604 -> V=1.0, theta=0.0
% INFO    : Bus 84373	: V=0.9533507, theta=-29.056282 -> V=1.0, theta=0.0
% INFO    : Bus 84374	: V=0.9835478, theta=-25.396564 -> V=1.0, theta=0.0
% INFO    : Bus 84375	: V=0.9757969, theta=-27.356358 -> V=1.0, theta=0.0
% INFO    : Bus 84376	: V=0.9842465, theta=-40.326819 -> V=1.0, theta=0.0
% INFO    : Bus 84377	: V=0.9927541, theta=-38.525441 -> V=1.0, theta=0.0
% INFO    : Bus 84378	: V=0.9826713, theta=-37.303156 -> V=1.0, theta=0.0
% INFO    : Bus 84379	: V=0.9783873, theta=-37.801355 -> V=1.0, theta=0.0
% INFO    : Bus 84380	: V=0.9823986, theta=-37.394267 -> V=1.0, theta=0.0
% INFO    : Bus 84381	: V=0.9826382, theta=-37.316276 -> V=1.0, theta=0.0
% INFO    : Bus 84382	: V=0.976068, theta=-38.470929 -> V=1.0, theta=0.0
% INFO    : Bus 84383	: V=0.9881218, theta=-34.121126 -> V=1.0, theta=0.0
% INFO    : Bus 84384	: V=0.9844216, theta=-36.565745 -> V=1.0, theta=0.0
% INFO    : Bus 84385	: V=0.9917119, theta=-31.596421 -> V=1.0, theta=0.0
% INFO    : Bus 84386	: V=0.979304, theta=-32.753387 -> V=1.0, theta=0.0
% INFO    : Bus 84387	: V=0.9574378, theta=-56.722599 -> V=1.0, theta=0.0
% INFO    : Bus 84388	: V=0.957462, theta=-60.21204 -> V=1.0, theta=0.0
% INFO    : Bus 84389	: V=0.9602393, theta=-58.995074 -> V=1.0, theta=0.0
% INFO    : Bus 84390	: V=0.9584071, theta=-60.14948 -> V=1.0, theta=0.0
% INFO    : Bus 84391	: V=0.9642888, theta=-59.830371 -> V=1.0, theta=0.0
% INFO    : Bus 84392	: V=0.9596162, theta=-58.76362 -> V=1.0, theta=0.0
% INFO    : Bus 84393	: V=0.9601589, theta=-58.178133 -> V=1.0, theta=0.0
% INFO    : Bus 84394	: V=0.9627328, theta=-57.042019 -> V=1.0, theta=0.0
% INFO    : Bus 84395	: V=0.9636141, theta=-55.607698 -> V=1.0, theta=0.0
% INFO    : Bus 84396	: V=0.964314, theta=-56.67856 -> V=1.0, theta=0.0
% INFO    : Bus 84397	: V=0.9638125, theta=-55.994909 -> V=1.0, theta=0.0
% INFO    : Bus 84398	: V=0.9632622, theta=-57.101562 -> V=1.0, theta=0.0
% INFO    : Bus 84399	: V=0.9642922, theta=-55.944623 -> V=1.0, theta=0.0
% INFO    : Bus 84400	: V=0.9617559, theta=-57.736592 -> V=1.0, theta=0.0
% INFO    : Bus 84401	: V=0.9685974, theta=-55.536588 -> V=1.0, theta=0.0
% INFO    : Bus 84402	: V=0.9687114, theta=-56.334681 -> V=1.0, theta=0.0
% INFO    : Bus 84403	: V=0.9720951, theta=-30.259509 -> V=1.0, theta=0.0
% INFO    : Bus 84404	: V=0.9875292, theta=-27.835499 -> V=1.0, theta=0.0
% INFO    : Bus 84405	: V=0.992356, theta=-27.521728 -> V=1.0, theta=0.0
% INFO    : Bus 84406	: V=0.990362, theta=-27.856845 -> V=1.0, theta=0.0
% INFO    : Bus 84407	: V=0.9796094, theta=-28.548066 -> V=1.0, theta=0.0
% INFO    : Bus 84408	: V=0.9926752, theta=-27.036707 -> V=1.0, theta=0.0
% INFO    : Bus 84409	: V=0.9902767, theta=-27.468455 -> V=1.0, theta=0.0
% INFO    : Bus 84410	: V=0.960574, theta=-32.561569 -> V=1.0, theta=0.0
% INFO    : Bus 84411	: V=0.9668766, theta=-50.067335 -> V=1.0, theta=0.0
% INFO    : Bus 84412	: V=0.9655336, theta=-50.567961 -> V=1.0, theta=0.0
% INFO    : Bus 84413	: V=0.9678142, theta=-50.499373 -> V=1.0, theta=0.0
% INFO    : Bus 84414	: V=0.9659343, theta=-50.440232 -> V=1.0, theta=0.0
% INFO    : Bus 84415	: V=0.9653317, theta=-50.553131 -> V=1.0, theta=0.0
% INFO    : Bus 84416	: V=0.9656502, theta=-50.934138 -> V=1.0, theta=0.0
% INFO    : Bus 84417	: V=0.9699844, theta=-50.457705 -> V=1.0, theta=0.0
% INFO    : Bus 84418	: V=0.9739196, theta=-48.921318 -> V=1.0, theta=0.0
% INFO    : Bus 84419	: V=0.9738581, theta=-49.432852 -> V=1.0, theta=0.0
% INFO    : Bus 84420	: V=0.9689673, theta=-50.040151 -> V=1.0, theta=0.0
% INFO    : Bus 84421	: V=0.9648931, theta=-51.073581 -> V=1.0, theta=0.0
% INFO    : Bus 84422	: V=0.9631582, theta=-50.439834 -> V=1.0, theta=0.0
% INFO    : Bus 84423	: V=0.9682807, theta=-48.868232 -> V=1.0, theta=0.0
% INFO    : Bus 84424	: V=0.9771576, theta=-48.010995 -> V=1.0, theta=0.0
% INFO    : Bus 84425	: V=0.9657276, theta=-50.552417 -> V=1.0, theta=0.0
% INFO    : Bus 84426	: V=0.9875252, theta=-35.664868 -> V=1.0, theta=0.0
% INFO    : Bus 84427	: V=0.9849001, theta=-34.191772 -> V=1.0, theta=0.0
% INFO    : Bus 84428	: V=0.9882566, theta=-32.092847 -> V=1.0, theta=0.0
% INFO    : Bus 84429	: V=0.9913096, theta=-32.708844 -> V=1.0, theta=0.0
% INFO    : Bus 84430	: V=0.9900314, theta=-32.81534 -> V=1.0, theta=0.0
% INFO    : Bus 84431	: V=0.98739, theta=-33.388709 -> V=1.0, theta=0.0
% INFO    : Bus 84432	: V=0.9874005, theta=-33.655973 -> V=1.0, theta=0.0
% INFO    : Bus 84433	: V=0.9904108, theta=-33.332683 -> V=1.0, theta=0.0
% INFO    : Bus 84434	: V=0.9920938, theta=-33.397288 -> V=1.0, theta=0.0
% INFO    : Bus 84435	: V=0.9793635, theta=-37.639084 -> V=1.0, theta=0.0
% INFO    : Bus 84436	: V=0.9763148, theta=-38.480188 -> V=1.0, theta=0.0
% INFO    : Bus 84437	: V=0.982336, theta=-33.996632 -> V=1.0, theta=0.0
% INFO    : Bus 84438	: V=0.9636935, theta=-37.83804 -> V=1.0, theta=0.0
% INFO    : Bus 84439	: V=0.963069, theta=-38.637049 -> V=1.0, theta=0.0
% INFO    : Bus 84440	: V=0.9644971, theta=-41.256237 -> V=1.0, theta=0.0
% INFO    : Bus 84441	: V=1.0008421, theta=-28.745434 -> V=1.0, theta=0.0
% INFO    : Bus 84442	: V=0.9988122, theta=-27.96566 -> V=1.0, theta=0.0
% INFO    : Bus 84443	: V=1.0018964, theta=-28.250324 -> V=1.0, theta=0.0
% INFO    : Bus 84444	: V=1.0140663, theta=-25.551105 -> V=1.0, theta=0.0
% INFO    : Bus 84445	: V=1.0123818, theta=-26.326628 -> V=1.0, theta=0.0
% INFO    : Bus 84446	: V=1.0114324, theta=-26.851572 -> V=1.0, theta=0.0
% INFO    : Bus 84447	: V=1.0093212, theta=-26.662292 -> V=1.0, theta=0.0
% INFO    : Bus 84448	: V=1.0073847, theta=-27.04866 -> V=1.0, theta=0.0
% INFO    : Bus 84449	: V=1.0077946, theta=-26.755087 -> V=1.0, theta=0.0
% INFO    : Bus 84450	: V=1.0050959, theta=-27.150271 -> V=1.0, theta=0.0
% INFO    : Bus 84451	: V=1.0045039, theta=-27.205801 -> V=1.0, theta=0.0
% INFO    : Bus 84452	: V=0.9507072, theta=-39.241919 -> V=1.0, theta=0.0
% INFO    : Bus 84453	: V=0.9487556, theta=-39.37549 -> V=1.0, theta=0.0
% INFO    : Bus 84454	: V=0.9481398, theta=-40.656031 -> V=1.0, theta=0.0
% INFO    : Bus 84455	: V=0.9497914, theta=-34.289555 -> V=1.0, theta=0.0
% INFO    : Bus 84456	: V=0.9382056, theta=-35.565898 -> V=1.0, theta=0.0
% INFO    : Bus 84457	: V=0.9370752, theta=-35.896966 -> V=1.0, theta=0.0
% INFO    : Bus 84458	: V=0.9398091, theta=-35.688694 -> V=1.0, theta=0.0
% INFO    : Bus 84459	: V=0.9606913, theta=-55.51618 -> V=1.0, theta=0.0
% INFO    : Bus 84460	: V=0.968242, theta=-54.007059 -> V=1.0, theta=0.0
% INFO    : Bus 84461	: V=0.9653727, theta=-54.834042 -> V=1.0, theta=0.0
% INFO    : Bus 84462	: V=0.9637917, theta=-55.11054 -> V=1.0, theta=0.0
% INFO    : Bus 84463	: V=0.9612152, theta=-55.551369 -> V=1.0, theta=0.0
% INFO    : Bus 84464	: V=0.9676506, theta=-54.151181 -> V=1.0, theta=0.0
% INFO    : Bus 84465	: V=0.9740852, theta=-56.763568 -> V=1.0, theta=0.0
% INFO    : Bus 84466	: V=0.9714163, theta=-57.043024 -> V=1.0, theta=0.0
% INFO    : Bus 84467	: V=0.963733, theta=-55.545903 -> V=1.0, theta=0.0
% INFO    : Bus 84468	: V=0.964829, theta=-54.585674 -> V=1.0, theta=0.0
% INFO    : Bus 84469	: V=0.9687294, theta=-53.875449 -> V=1.0, theta=0.0
% INFO    : Bus 84470	: V=0.9679719, theta=-54.01156 -> V=1.0, theta=0.0
% INFO    : Bus 84471	: V=0.9643987, theta=-55.156874 -> V=1.0, theta=0.0
% INFO    : Bus 84472	: V=0.9638051, theta=-55.528544 -> V=1.0, theta=0.0
% INFO    : Bus 84473	: V=0.9637023, theta=-55.613721 -> V=1.0, theta=0.0
% INFO    : Bus 84474	: V=0.9632945, theta=-55.832862 -> V=1.0, theta=0.0
% INFO    : Bus 84475	: V=0.9615743, theta=-55.884299 -> V=1.0, theta=0.0
% INFO    : Bus 84476	: V=0.970956, theta=-54.47219 -> V=1.0, theta=0.0
% INFO    : Bus 84477	: V=0.9687272, theta=-55.609611 -> V=1.0, theta=0.0
% INFO    : Bus 84478	: V=0.9706201, theta=-53.568065 -> V=1.0, theta=0.0
% INFO    : Bus 84479	: V=0.9648228, theta=-54.855228 -> V=1.0, theta=0.0
% INFO    : Bus 84480	: V=0.9683036, theta=-53.870492 -> V=1.0, theta=0.0
% INFO    : Bus 84481	: V=0.966019, theta=-54.690409 -> V=1.0, theta=0.0
% INFO    : Bus 84482	: V=0.9648955, theta=-54.832381 -> V=1.0, theta=0.0
% INFO    : Bus 84483	: V=0.9689129, theta=-53.564268 -> V=1.0, theta=0.0
% INFO    : Bus 84484	: V=0.967854, theta=-53.992686 -> V=1.0, theta=0.0
% INFO    : Bus 84485	: V=0.96376, theta=-53.959286 -> V=1.0, theta=0.0
% INFO    : Bus 84486	: V=0.9661261, theta=-53.566632 -> V=1.0, theta=0.0
% INFO    : Bus 84487	: V=0.9679099, theta=-53.810448 -> V=1.0, theta=0.0
% INFO    : Bus 84488	: V=0.9692162, theta=-53.267043 -> V=1.0, theta=0.0
% INFO    : Bus 84489	: V=0.9671818, theta=-52.226597 -> V=1.0, theta=0.0
% INFO    : Bus 84490	: V=0.9650324, theta=-54.170115 -> V=1.0, theta=0.0
% INFO    : Bus 84491	: V=0.9561802, theta=-57.933192 -> V=1.0, theta=0.0
% INFO    : Bus 84492	: V=0.9602454, theta=-57.378997 -> V=1.0, theta=0.0
% INFO    : Bus 84493	: V=0.9646716, theta=-55.679856 -> V=1.0, theta=0.0
% INFO    : Bus 84494	: V=0.9639228, theta=-56.481859 -> V=1.0, theta=0.0
% INFO    : Bus 84495	: V=0.9657505, theta=-55.615612 -> V=1.0, theta=0.0
% INFO    : Bus 84496	: V=0.9666226, theta=-56.190198 -> V=1.0, theta=0.0
% INFO    : Bus 84497	: V=0.9608581, theta=-57.059279 -> V=1.0, theta=0.0
% INFO    : Bus 84498	: V=0.9651434, theta=-55.741751 -> V=1.0, theta=0.0
% INFO    : Bus 84499	: V=0.9631095, theta=-56.76593 -> V=1.0, theta=0.0
% INFO    : Bus 84500	: V=0.9597891, theta=-57.111507 -> V=1.0, theta=0.0
% INFO    : Bus 84501	: V=0.9566195, theta=-57.280027 -> V=1.0, theta=0.0
% INFO    : Bus 84502	: V=0.9622836, theta=-56.140923 -> V=1.0, theta=0.0
% INFO    : Bus 84503	: V=0.9626591, theta=-56.694062 -> V=1.0, theta=0.0
% INFO    : Bus 84504	: V=0.9593199, theta=-57.092903 -> V=1.0, theta=0.0
% INFO    : Bus 84505	: V=0.9611669, theta=-56.975888 -> V=1.0, theta=0.0
% INFO    : Bus 84506	: V=0.963031, theta=-55.907232 -> V=1.0, theta=0.0
% INFO    : Bus 84507	: V=0.9608677, theta=-57.003006 -> V=1.0, theta=0.0
% INFO    : Bus 84508	: V=0.9597154, theta=-57.059853 -> V=1.0, theta=0.0
% INFO    : Bus 84509	: V=0.9605239, theta=-57.006294 -> V=1.0, theta=0.0
% INFO    : Bus 84510	: V=0.9589441, theta=-57.386386 -> V=1.0, theta=0.0
% INFO    : Bus 84511	: V=0.9629902, theta=-55.863268 -> V=1.0, theta=0.0
% INFO    : Bus 84512	: V=0.9618024, theta=-56.934575 -> V=1.0, theta=0.0
% INFO    : Bus 84513	: V=0.9593415, theta=-56.920691 -> V=1.0, theta=0.0
% INFO    : Bus 84514	: V=0.9608724, theta=-57.022711 -> V=1.0, theta=0.0
% INFO    : Bus 84515	: V=0.9598086, theta=-57.067811 -> V=1.0, theta=0.0
% INFO    : Bus 84516	: V=0.9572305, theta=-57.165358 -> V=1.0, theta=0.0
% INFO    : Bus 84517	: V=0.9568181, theta=-57.811565 -> V=1.0, theta=0.0
% INFO    : Bus 84518	: V=0.9591781, theta=-57.264619 -> V=1.0, theta=0.0
% INFO    : Bus 84519	: V=0.9599946, theta=-57.178392 -> V=1.0, theta=0.0
% INFO    : Bus 84520	: V=0.9589799, theta=-57.280656 -> V=1.0, theta=0.0
% INFO    : Bus 84521	: V=0.9535037, theta=-56.244784 -> V=1.0, theta=0.0
% INFO    : Bus 84522	: V=0.9625708, theta=-56.561417 -> V=1.0, theta=0.0
% INFO    : Bus 84523	: V=0.9612794, theta=-56.771404 -> V=1.0, theta=0.0
% INFO    : Bus 84524	: V=0.960223, theta=-56.80507 -> V=1.0, theta=0.0
% INFO    : Bus 84525	: V=0.9628744, theta=-56.490387 -> V=1.0, theta=0.0
% INFO    : Bus 84526	: V=0.9626838, theta=-56.667502 -> V=1.0, theta=0.0
% INFO    : Bus 84527	: V=0.953735, theta=-58.077139 -> V=1.0, theta=0.0
% INFO    : Bus 84528	: V=0.9675427, theta=-55.538421 -> V=1.0, theta=0.0
% INFO    : Bus 84529	: V=0.9658994, theta=-57.055765 -> V=1.0, theta=0.0
% INFO    : Bus 84530	: V=0.963078, theta=-57.08604 -> V=1.0, theta=0.0
% INFO    : Bus 84531	: V=0.9621239, theta=-56.357094 -> V=1.0, theta=0.0
% INFO    : Bus 84532	: V=0.9630875, theta=-55.954419 -> V=1.0, theta=0.0
% INFO    : Bus 84533	: V=0.960236, theta=-56.359621 -> V=1.0, theta=0.0
% INFO    : Bus 84534	: V=0.9592767, theta=-57.051303 -> V=1.0, theta=0.0
% INFO    : Bus 84535	: V=0.9588201, theta=-57.219804 -> V=1.0, theta=0.0
% INFO    : Bus 84536	: V=0.9626364, theta=-56.732219 -> V=1.0, theta=0.0
% INFO    : Bus 84537	: V=0.9605995, theta=-54.434068 -> V=1.0, theta=0.0
% INFO    : Bus 84538	: V=0.9598606, theta=-54.611352 -> V=1.0, theta=0.0
% INFO    : Bus 84539	: V=0.9585462, theta=-54.732995 -> V=1.0, theta=0.0
% INFO    : Bus 84540	: V=0.9514659, theta=-58.041631 -> V=1.0, theta=0.0
% INFO    : Bus 84541	: V=0.9629532, theta=-56.543508 -> V=1.0, theta=0.0
% INFO    : Bus 84542	: V=0.9623081, theta=-56.43736 -> V=1.0, theta=0.0
% INFO    : Bus 84543	: V=0.9573826, theta=-57.214333 -> V=1.0, theta=0.0
% INFO    : Bus 84544	: V=0.9573685, theta=-55.723005 -> V=1.0, theta=0.0
% INFO    : Bus 84545	: V=0.9690618, theta=-62.061465 -> V=1.0, theta=0.0
% INFO    : Bus 84546	: V=0.9682663, theta=-62.043017 -> V=1.0, theta=0.0
% INFO    : Bus 84547	: V=0.9660832, theta=-61.842092 -> V=1.0, theta=0.0
% INFO    : Bus 84548	: V=0.9684006, theta=-61.852193 -> V=1.0, theta=0.0
% INFO    : Bus 84549	: V=0.9653825, theta=-61.506542 -> V=1.0, theta=0.0
% INFO    : Bus 84550	: V=0.9645804, theta=-62.144535 -> V=1.0, theta=0.0
% INFO    : Bus 84551	: V=0.9639504, theta=-62.175423 -> V=1.0, theta=0.0
% INFO    : Bus 84552	: V=0.9616544, theta=-62.408437 -> V=1.0, theta=0.0
% INFO    : Bus 84553	: V=0.9647045, theta=-61.175322 -> V=1.0, theta=0.0
% INFO    : Bus 84554	: V=0.9630444, theta=-62.373161 -> V=1.0, theta=0.0
% INFO    : Bus 84555	: V=0.9575911, theta=-63.545726 -> V=1.0, theta=0.0
% INFO    : Bus 84556	: V=0.960202, theta=-62.937864 -> V=1.0, theta=0.0
% INFO    : Bus 84557	: V=0.9744242, theta=-62.225245 -> V=1.0, theta=0.0
% INFO    : Bus 84558	: V=0.9736097, theta=-62.10314 -> V=1.0, theta=0.0
% INFO    : Bus 84559	: V=0.9697488, theta=-63.903379 -> V=1.0, theta=0.0
% INFO    : Bus 84560	: V=0.9682625, theta=-62.396812 -> V=1.0, theta=0.0
% INFO    : Bus 84561	: V=0.9617633, theta=-60.757 -> V=1.0, theta=0.0
% INFO    : Bus 84562	: V=0.9592853, theta=-60.953838 -> V=1.0, theta=0.0
% INFO    : Bus 84563	: V=0.9677696, theta=-61.90351 -> V=1.0, theta=0.0
% INFO    : Bus 84564	: V=0.9667333, theta=-62.510298 -> V=1.0, theta=0.0
% INFO    : Bus 84565	: V=0.9777276, theta=-49.591761 -> V=1.0, theta=0.0
% INFO    : Bus 84566	: V=0.9673947, theta=-50.617887 -> V=1.0, theta=0.0
% INFO    : Bus 84567	: V=0.9780798, theta=-48.999632 -> V=1.0, theta=0.0
% INFO    : Bus 84568	: V=0.9780284, theta=-49.10649 -> V=1.0, theta=0.0
% INFO    : Bus 84569	: V=0.9762772, theta=-48.643484 -> V=1.0, theta=0.0
% INFO    : Bus 84570	: V=0.979434, theta=-45.509486 -> V=1.0, theta=0.0
% INFO    : Bus 84571	: V=0.9782013, theta=-47.272634 -> V=1.0, theta=0.0
% INFO    : Bus 84572	: V=0.9805648, theta=-47.00702 -> V=1.0, theta=0.0
% INFO    : Bus 84573	: V=0.9454496, theta=-41.113588 -> V=1.0, theta=0.0
% INFO    : Bus 84574	: V=0.9503121, theta=-41.627868 -> V=1.0, theta=0.0
% INFO    : Bus 84575	: V=0.9644715, theta=-41.744318 -> V=1.0, theta=0.0
% INFO    : Bus 84576	: V=0.9611013, theta=-41.932403 -> V=1.0, theta=0.0
% INFO    : Bus 84577	: V=0.95466, theta=-40.691049 -> V=1.0, theta=0.0
% INFO    : Bus 84578	: V=0.9696565, theta=-29.853124 -> V=1.0, theta=0.0
% INFO    : Bus 84579	: V=0.9628111, theta=-29.600072 -> V=1.0, theta=0.0
% INFO    : Bus 84580	: V=0.9636954, theta=-29.625834 -> V=1.0, theta=0.0
% INFO    : Bus 84581	: V=1.011138, theta=-32.040816 -> V=1.0, theta=0.0
% INFO    : Bus 84582	: V=0.9916467, theta=-28.550986 -> V=1.0, theta=0.0
% INFO    : Bus 84583	: V=0.9898529, theta=-28.866015 -> V=1.0, theta=0.0
% INFO    : Bus 84584	: V=0.9869266, theta=-29.407075 -> V=1.0, theta=0.0
% INFO    : Bus 84585	: V=0.9794453, theta=-30.143385 -> V=1.0, theta=0.0
% INFO    : Bus 84586	: V=0.9893063, theta=-28.733204 -> V=1.0, theta=0.0
% INFO    : Bus 84587	: V=0.9849785, theta=-29.256197 -> V=1.0, theta=0.0
% INFO    : Bus 84588	: V=0.9798815, theta=-29.742375 -> V=1.0, theta=0.0
% INFO    : Bus 84589	: V=0.9860529, theta=-28.869737 -> V=1.0, theta=0.0
% INFO    : Bus 84590	: V=0.9817062, theta=-29.399351 -> V=1.0, theta=0.0
% INFO    : Bus 84591	: V=0.9783999, theta=-29.635812 -> V=1.0, theta=0.0
% INFO    : Bus 84592	: V=0.976575, theta=-29.587124 -> V=1.0, theta=0.0
% INFO    : Bus 84593	: V=0.9709765, theta=-28.654737 -> V=1.0, theta=0.0
% INFO    : Bus 84594	: V=0.9697041, theta=-28.960372 -> V=1.0, theta=0.0
% INFO    : Bus 84595	: V=0.9717167, theta=-29.096986 -> V=1.0, theta=0.0
% INFO    : Bus 84596	: V=0.9669619, theta=-28.970404 -> V=1.0, theta=0.0
% INFO    : Bus 84597	: V=0.9868847, theta=-28.355179 -> V=1.0, theta=0.0
% INFO    : Bus 84598	: V=0.9862131, theta=-28.209431 -> V=1.0, theta=0.0
% INFO    : Bus 84599	: V=0.9817304, theta=-29.991148 -> V=1.0, theta=0.0
% INFO    : Bus 84600	: V=1.0085812, theta=-36.820618 -> V=1.0, theta=0.0
% INFO    : Bus 84601	: V=1.0016824, theta=-40.057073 -> V=1.0, theta=0.0
% INFO    : Bus 84602	: V=1.0073203, theta=-40.033629 -> V=1.0, theta=0.0
% INFO    : Bus 84603	: V=1.0076866, theta=-41.191141 -> V=1.0, theta=0.0
% INFO    : Bus 84604	: V=1.002618, theta=-41.885458 -> V=1.0, theta=0.0
% INFO    : Bus 84605	: V=1.0088622, theta=-38.130714 -> V=1.0, theta=0.0
% INFO    : Bus 84606	: V=0.9746229, theta=-51.22945 -> V=1.0, theta=0.0
% INFO    : Bus 84607	: V=0.9736383, theta=-51.578176 -> V=1.0, theta=0.0
% INFO    : Bus 84608	: V=0.9734949, theta=-51.659007 -> V=1.0, theta=0.0
% INFO    : Bus 84609	: V=0.9751452, theta=-51.042493 -> V=1.0, theta=0.0
% INFO    : Bus 84610	: V=0.9745152, theta=-50.903938 -> V=1.0, theta=0.0
% INFO    : Bus 84611	: V=0.9714196, theta=-52.873001 -> V=1.0, theta=0.0
% INFO    : Bus 84612	: V=0.9724342, theta=-53.281906 -> V=1.0, theta=0.0
% INFO    : Bus 84613	: V=0.9705685, theta=-53.823762 -> V=1.0, theta=0.0
% INFO    : Bus 84614	: V=0.9726874, theta=-52.300555 -> V=1.0, theta=0.0
% INFO    : Bus 84615	: V=0.9721602, theta=-52.614908 -> V=1.0, theta=0.0
% INFO    : Bus 84616	: V=0.9691911, theta=-52.156204 -> V=1.0, theta=0.0
% INFO    : Bus 84617	: V=0.9699941, theta=-52.529327 -> V=1.0, theta=0.0
% INFO    : Bus 84618	: V=0.9683218, theta=-53.147738 -> V=1.0, theta=0.0
% INFO    : Bus 84619	: V=0.9665793, theta=-55.078881 -> V=1.0, theta=0.0
% INFO    : Bus 84620	: V=0.9685943, theta=-54.604975 -> V=1.0, theta=0.0
% INFO    : Bus 84621	: V=0.9711328, theta=-52.741945 -> V=1.0, theta=0.0
% INFO    : Bus 84622	: V=0.9638905, theta=-54.470984 -> V=1.0, theta=0.0
% INFO    : Bus 84623	: V=0.9554839, theta=-29.015721 -> V=1.0, theta=0.0
% INFO    : Bus 84624	: V=0.9743226, theta=-29.334847 -> V=1.0, theta=0.0
% INFO    : Bus 84625	: V=0.9808958, theta=-28.082016 -> V=1.0, theta=0.0
% INFO    : Bus 84626	: V=0.9693208, theta=-32.873983 -> V=1.0, theta=0.0
% INFO    : Bus 84627	: V=0.9650426, theta=-33.130776 -> V=1.0, theta=0.0
% INFO    : Bus 84628	: V=0.96158, theta=-33.841586 -> V=1.0, theta=0.0
% INFO    : Bus 84629	: V=0.9803249, theta=-31.801282 -> V=1.0, theta=0.0
% INFO    : Bus 84630	: V=0.9750277, theta=-32.440199 -> V=1.0, theta=0.0
% INFO    : Bus 84631	: V=0.9958272, theta=-31.011686 -> V=1.0, theta=0.0
% INFO    : Bus 84632	: V=0.9697605, theta=-34.498501 -> V=1.0, theta=0.0
% INFO    : Bus 84633	: V=0.967213, theta=-33.789856 -> V=1.0, theta=0.0
% INFO    : Bus 84634	: V=0.9707104, theta=-32.71888 -> V=1.0, theta=0.0
% INFO    : Bus 84635	: V=0.9787116, theta=-32.385823 -> V=1.0, theta=0.0
% INFO    : Bus 84636	: V=0.974064, theta=-32.482114 -> V=1.0, theta=0.0
% INFO    : Bus 84637	: V=0.9631848, theta=-33.881853 -> V=1.0, theta=0.0
% INFO    : Bus 84638	: V=0.9618985, theta=-36.917063 -> V=1.0, theta=0.0
% INFO    : Bus 84639	: V=0.9437784, theta=-41.780409 -> V=1.0, theta=0.0
% INFO    : Bus 84640	: V=0.9509621, theta=-38.411006 -> V=1.0, theta=0.0
% INFO    : Bus 84641	: V=1.0098683, theta=-32.195443 -> V=1.0, theta=0.0
% INFO    : Bus 84642	: V=1.0054193, theta=-32.971423 -> V=1.0, theta=0.0
% INFO    : Bus 84643	: V=1.0044319, theta=-33.110434 -> V=1.0, theta=0.0
% INFO    : Bus 84644	: V=1.0122542, theta=-43.45701 -> V=1.0, theta=0.0
% INFO    : Bus 84645	: V=1.0102281, theta=-43.819964 -> V=1.0, theta=0.0
% INFO    : Bus 84646	: V=1.003203, theta=-41.667713 -> V=1.0, theta=0.0
% INFO    : Bus 84647	: V=1.0079938, theta=-51.157937 -> V=1.0, theta=0.0
% INFO    : Bus 84648	: V=1.0124031, theta=-50.815498 -> V=1.0, theta=0.0
% INFO    : Bus 84649	: V=1.000635, theta=-43.839925 -> V=1.0, theta=0.0
% INFO    : Bus 84650	: V=0.9988778, theta=-43.956536 -> V=1.0, theta=0.0
% INFO    : Bus 84651	: V=1.0098693, theta=-46.643286 -> V=1.0, theta=0.0
% INFO    : Bus 84652	: V=1.0076703, theta=-46.920505 -> V=1.0, theta=0.0
% INFO    : Bus 84653	: V=1.0065677, theta=-45.337864 -> V=1.0, theta=0.0
% INFO    : Bus 84654	: V=1.0053921, theta=-45.939875 -> V=1.0, theta=0.0
% INFO    : Bus 84655	: V=1.0161332, theta=-40.712615 -> V=1.0, theta=0.0
% INFO    : Bus 84656	: V=1.02, theta=-29.011174 -> V=1.0, theta=0.0
% INFO    : Bus 84657	: V=1.0193183, theta=-29.292295 -> V=1.0, theta=0.0
% INFO    : Bus 84658	: V=1.002565, theta=-47.267704 -> V=1.0, theta=0.0
% INFO    : Bus 84659	: V=0.9980573, theta=-37.192472 -> V=1.0, theta=0.0
% INFO    : Bus 84660	: V=1.00107, theta=-36.917297 -> V=1.0, theta=0.0
% INFO    : Bus 84661	: V=1.0113615, theta=-32.61727 -> V=1.0, theta=0.0
% INFO    : Bus 84662	: V=1.0110413, theta=-32.700429 -> V=1.0, theta=0.0
% INFO    : Bus 84663	: V=1.0034783, theta=-41.559622 -> V=1.0, theta=0.0
% INFO    : Bus 84664	: V=1.0143048, theta=-49.582436 -> V=1.0, theta=0.0
% INFO    : Bus 84665	: V=1.0060238, theta=-33.178259 -> V=1.0, theta=0.0
% INFO    : Bus 84666	: V=1.0106345, theta=-32.872992 -> V=1.0, theta=0.0
% INFO    : Bus 84667	: V=1.0072658, theta=-50.452576 -> V=1.0, theta=0.0
% INFO    : Bus 84668	: V=1.0111456, theta=-50.186131 -> V=1.0, theta=0.0
% INFO    : Bus 84669	: V=1.0106301, theta=-42.639972 -> V=1.0, theta=0.0
% INFO    : Bus 84670	: V=1.0139148, theta=-54.038187 -> V=1.0, theta=0.0
% INFO    : Bus 84671	: V=1.0144496, theta=-43.898947 -> V=1.0, theta=0.0
% INFO    : Bus 84672	: V=0.9937671, theta=-49.188307 -> V=1.0, theta=0.0
% INFO    : Bus 84673	: V=0.9905952, theta=-49.485013 -> V=1.0, theta=0.0
% INFO    : Bus 84674	: V=1.0113944, theta=-40.822976 -> V=1.0, theta=0.0
% INFO    : Bus 84675	: V=1.011902, theta=-40.843782 -> V=1.0, theta=0.0
% INFO    : Bus 84676	: V=1.0147059, theta=-44.650336 -> V=1.0, theta=0.0
% INFO    : Bus 84677	: V=1.0169941, theta=-43.916923 -> V=1.0, theta=0.0
% INFO    : Bus 84678	: V=1.0069666, theta=-46.483679 -> V=1.0, theta=0.0
% INFO    : Bus 84679	: V=1.0034209, theta=-46.64227 -> V=1.0, theta=0.0
% INFO    : Bus 84680	: V=1.0035716, theta=-47.730188 -> V=1.0, theta=0.0
% INFO    : Bus 84681	: V=1.0017262, theta=-48.101976 -> V=1.0, theta=0.0
% INFO    : Bus 84682	: V=1.0075619, theta=-48.150437 -> V=1.0, theta=0.0
% INFO    : Bus 84683	: V=1.0081949, theta=-48.03915 -> V=1.0, theta=0.0
% INFO    : Bus 84684	: V=1.0093535, theta=-43.130916 -> V=1.0, theta=0.0
% INFO    : Bus 84685	: V=1.009647, theta=-43.09954 -> V=1.0, theta=0.0
% INFO    : Bus 84686	: V=1.009098, theta=-46.295293 -> V=1.0, theta=0.0
% INFO    : Bus 84687	: V=1.005689, theta=-46.752279 -> V=1.0, theta=0.0
% INFO    : Bus 84688	: V=1.0014182, theta=-46.965294 -> V=1.0, theta=0.0
% INFO    : Bus 84689	: V=1.0084216, theta=-29.105449 -> V=1.0, theta=0.0
% INFO    : Bus 84690	: V=1.0096896, theta=-29.036179 -> V=1.0, theta=0.0
% INFO    : Bus 84691	: V=1.0106387, theta=-39.018874 -> V=1.0, theta=0.0
% INFO    : Bus 84692	: V=1.0088296, theta=-39.532043 -> V=1.0, theta=0.0
% INFO    : Bus 84693	: V=1.0088455, theta=-39.532156 -> V=1.0, theta=0.0
% INFO    : Bus 84694	: V=0.9989894, theta=-41.190446 -> V=1.0, theta=0.0
% INFO    : Bus 84695	: V=0.991862, theta=-42.32295 -> V=1.0, theta=0.0
% INFO    : Bus 84696	: V=0.9898531, theta=-42.785532 -> V=1.0, theta=0.0
% INFO    : Bus 84697	: V=0.995414, theta=-42.584012 -> V=1.0, theta=0.0
% INFO    : Bus 84698	: V=0.9965849, theta=-42.556794 -> V=1.0, theta=0.0
% INFO    : Bus 84699	: V=1.0069025, theta=-43.043125 -> V=1.0, theta=0.0
% INFO    : Bus 84700	: V=1.0116242, theta=-42.549133 -> V=1.0, theta=0.0
% INFO    : Bus 84701	: V=1.0182511, theta=-42.856488 -> V=1.0, theta=0.0
% INFO    : Bus 84702	: V=1.0181207, theta=-43.324039 -> V=1.0, theta=0.0
% INFO    : Bus 84703	: V=0.9986462, theta=-50.92181 -> V=1.0, theta=0.0
% INFO    : Bus 84704	: V=1.015473, theta=-43.933927 -> V=1.0, theta=0.0
% INFO    : Bus 84705	: V=1.0169118, theta=-43.838483 -> V=1.0, theta=0.0
% INFO    : Bus 84706	: V=1.0062636, theta=-47.794778 -> V=1.0, theta=0.0
% INFO    : Bus 84707	: V=1.0073809, theta=-46.163433 -> V=1.0, theta=0.0
% INFO    : Bus 84708	: V=0.9974497, theta=-50.055536 -> V=1.0, theta=0.0
% INFO    : Bus 84709	: V=1.0041986, theta=-46.716323 -> V=1.0, theta=0.0
% INFO    : Bus 84710	: V=1.0075594, theta=-43.414751 -> V=1.0, theta=0.0
% INFO    : Bus 84711	: V=1.0015569, theta=-44.333579 -> V=1.0, theta=0.0
% INFO    : Bus 84712	: V=0.9972566, theta=-44.913686 -> V=1.0, theta=0.0
% INFO    : Bus 84713	: V=1.0015727, theta=-45.029665 -> V=1.0, theta=0.0
% INFO    : Bus 84714	: V=0.9933318, theta=-46.113762 -> V=1.0, theta=0.0
% INFO    : Bus 84715	: V=0.9932697, theta=-46.262459 -> V=1.0, theta=0.0
% INFO    : Bus 84716	: V=1.0051993, theta=-54.168113 -> V=1.0, theta=0.0
% INFO    : Bus 84717	: V=1.0051585, theta=-54.251321 -> V=1.0, theta=0.0
% INFO    : Bus 84718	: V=1.0076957, theta=-52.987394 -> V=1.0, theta=0.0
% INFO    : Bus 84719	: V=1.02, theta=-43.010824 -> V=1.0, theta=0.0
% INFO    : Bus 84720	: V=1.0192135, theta=-43.610858 -> V=1.0, theta=0.0
% INFO    : Bus 84721	: V=1.0201413, theta=-43.777134 -> V=1.0, theta=0.0
% INFO    : Bus 84722	: V=1.0128331, theta=-44.157959 -> V=1.0, theta=0.0
% INFO    : Bus 84723	: V=1.0104152, theta=-44.446086 -> V=1.0, theta=0.0
% INFO    : Bus 84724	: V=1.0131682, theta=-44.404195 -> V=1.0, theta=0.0
% INFO    : Bus 84725	: V=1.0049053, theta=-45.059535 -> V=1.0, theta=0.0
% INFO    : Bus 84726	: V=1.0192069, theta=-40.33264 -> V=1.0, theta=0.0
% INFO    : Bus 84727	: V=1.0199831, theta=-40.779871 -> V=1.0, theta=0.0
% INFO    : Bus 84728	: V=1.0167461, theta=-40.911849 -> V=1.0, theta=0.0
% INFO    : Bus 84729	: V=1.0017865, theta=-44.005372 -> V=1.0, theta=0.0
% INFO    : Bus 84730	: V=1.000679, theta=-35.761144 -> V=1.0, theta=0.0
% INFO    : Bus 84731	: V=1.012398, theta=-35.686729 -> V=1.0, theta=0.0
% INFO    : Bus 84732	: V=0.9809559, theta=-42.136011 -> V=1.0, theta=0.0
% INFO    : Bus 84733	: V=0.9884025, theta=-42.669484 -> V=1.0, theta=0.0
% INFO    : Bus 84734	: V=0.9782944, theta=-38.397177 -> V=1.0, theta=0.0
% INFO    : Bus 84735	: V=1.0139246, theta=-52.077761 -> V=1.0, theta=0.0
% INFO    : Bus 84736	: V=0.9958041, theta=-34.703114 -> V=1.0, theta=0.0
% INFO    : Bus 84737	: V=0.9818839, theta=-51.025119 -> V=1.0, theta=0.0
% INFO    : Bus 84738	: V=0.9820363, theta=-53.601652 -> V=1.0, theta=0.0
% INFO    : Bus 84739	: V=0.9900147, theta=-46.148322 -> V=1.0, theta=0.0
% INFO    : Bus 84740	: V=1.0156972, theta=-45.789592 -> V=1.0, theta=0.0
% INFO    : Bus 84741	: V=1.0142721, theta=-38.189292 -> V=1.0, theta=0.0
% INFO    : Bus 84742	: V=0.9835273, theta=-47.997242 -> V=1.0, theta=0.0
% INFO    : Bus 84743	: V=1.0083555, theta=-48.561764 -> V=1.0, theta=0.0
% INFO    : Bus 84744	: V=1.0057635, theta=-48.485607 -> V=1.0, theta=0.0
% INFO    : Bus 84745	: V=0.9903179, theta=-49.114989 -> V=1.0, theta=0.0
% INFO    : Bus 84746	: V=0.9879474, theta=-49.666334 -> V=1.0, theta=0.0
% INFO    : Bus 84747	: V=0.9805354, theta=-44.779009 -> V=1.0, theta=0.0
% INFO    : Bus 84748	: V=1.02, theta=-44.295035 -> V=1.0, theta=0.0
% INFO    : Bus 84749	: V=1.003747, theta=-40.718131 -> V=1.0, theta=0.0
% INFO    : Bus 84750	: V=0.9999721, theta=-41.351252 -> V=1.0, theta=0.0
% INFO    : Bus 84751	: V=1.0093976, theta=-45.593617 -> V=1.0, theta=0.0
% INFO    : Bus 84752	: V=1.02, theta=-45.641858 -> V=1.0, theta=0.0
% INFO    : Bus 84753	: V=0.9786012, theta=-39.071673 -> V=1.0, theta=0.0
% INFO    : Bus 84754	: V=1.0099775, theta=-48.879239 -> V=1.0, theta=0.0
% INFO    : Bus 84755	: V=1.02, theta=-44.553668 -> V=1.0, theta=0.0
% INFO    : Bus 84756	: V=0.9793016, theta=-51.023636 -> V=1.0, theta=0.0
% INFO    : Bus 84757	: V=1.0192914, theta=-22.707669 -> V=1.0, theta=0.0
% INFO    : Bus 84758	: V=1.015282, theta=-23.644235 -> V=1.0, theta=0.0
% INFO    : Bus 84759	: V=1.0197913, theta=-25.514048 -> V=1.0, theta=0.0
% INFO    : Bus 84760	: V=1.015117, theta=-26.306159 -> V=1.0, theta=0.0
% INFO    : Bus 84761	: V=1.0135546, theta=-26.719923 -> V=1.0, theta=0.0
% INFO    : Bus 84762	: V=1.0178785, theta=-26.432967 -> V=1.0, theta=0.0
% INFO    : Bus 84763	: V=1.018535, theta=-26.374118 -> V=1.0, theta=0.0
% INFO    : Bus 84764	: V=1.0128817, theta=-25.692097 -> V=1.0, theta=0.0
% INFO    : Bus 84765	: V=1.0103443, theta=-26.345939 -> V=1.0, theta=0.0
% INFO    : Bus 84766	: V=0.9914861, theta=-30.539913 -> V=1.0, theta=0.0
% INFO    : Bus 84767	: V=0.9797554, theta=-32.470437 -> V=1.0, theta=0.0
% INFO    : Bus 84768	: V=0.9794456, theta=-32.526664 -> V=1.0, theta=0.0
% INFO    : Bus 84769	: V=1.0160816, theta=-23.387668 -> V=1.0, theta=0.0
% INFO    : Bus 84770	: V=1.0170925, theta=-23.266487 -> V=1.0, theta=0.0
% INFO    : Bus 84771	: V=1.0165397, theta=-25.441888 -> V=1.0, theta=0.0
% INFO    : Bus 84772	: V=1.0155524, theta=-26.229637 -> V=1.0, theta=0.0
% INFO    : Bus 84773	: V=1.0140452, theta=-26.463397 -> V=1.0, theta=0.0
% INFO    : Bus 84774	: V=0.9642988, theta=-38.908906 -> V=1.0, theta=0.0
% INFO    : Bus 84775	: V=0.9685816, theta=-38.053452 -> V=1.0, theta=0.0
% INFO    : Bus 84776	: V=1.0094986, theta=-23.987994 -> V=1.0, theta=0.0
% INFO    : Bus 84777	: V=1.0103748, theta=-23.870569 -> V=1.0, theta=0.0
% INFO    : Bus 84778	: V=1.0197058, theta=-25.088378 -> V=1.0, theta=0.0
% INFO    : Bus 84779	: V=1.0131446, theta=-26.517185 -> V=1.0, theta=0.0
% INFO    : Bus 84780	: V=1.0174288, theta=-23.014037 -> V=1.0, theta=0.0
% INFO    : Bus 84781	: V=1.0182048, theta=-22.782978 -> V=1.0, theta=0.0
% INFO    : Bus 84782	: V=1.0036035, theta=-35.0411 -> V=1.0, theta=0.0
% INFO    : Bus 84783	: V=1.0076653, theta=-34.968376 -> V=1.0, theta=0.0
% INFO    : Bus 84784	: V=1.0197405, theta=-26.047154 -> V=1.0, theta=0.0
% INFO    : Bus 84785	: V=1.0135522, theta=-26.809081 -> V=1.0, theta=0.0
% INFO    : Bus 84786	: V=1.0170474, theta=-32.568361 -> V=1.0, theta=0.0
% INFO    : Bus 84787	: V=1.0182029, theta=-24.037894 -> V=1.0, theta=0.0
% INFO    : Bus 84788	: V=1.0180325, theta=-23.753399 -> V=1.0, theta=0.0
% INFO    : Bus 84789	: V=1.0199631, theta=-25.537159 -> V=1.0, theta=0.0
% INFO    : Bus 84790	: V=1.012999, theta=-33.813505 -> V=1.0, theta=0.0
% INFO    : Bus 84791	: V=1.0135719, theta=-26.381727 -> V=1.0, theta=0.0
% INFO    : Bus 84792	: V=1.0147447, theta=-26.219964 -> V=1.0, theta=0.0
% INFO    : Bus 84793	: V=1.0104528, theta=-28.325447 -> V=1.0, theta=0.0
% INFO    : Bus 84794	: V=1.0083938, theta=-35.652516 -> V=1.0, theta=0.0
% INFO    : Bus 84795	: V=1.0073981, theta=-35.301669 -> V=1.0, theta=0.0
% INFO    : Bus 84796	: V=1.0045217, theta=-49.569532 -> V=1.0, theta=0.0
% INFO    : Bus 84797	: V=1.0144761, theta=-25.212837 -> V=1.0, theta=0.0
% INFO    : Bus 84798	: V=1.0156332, theta=-23.691034 -> V=1.0, theta=0.0
% INFO    : Bus 84799	: V=1.0178283, theta=-23.619462 -> V=1.0, theta=0.0
% INFO    : Bus 84800	: V=1.008117, theta=-27.815962 -> V=1.0, theta=0.0
% INFO    : Bus 84801	: V=1.0066619, theta=-30.047478 -> V=1.0, theta=0.0
% INFO    : Bus 84802	: V=1.0062588, theta=-30.098639 -> V=1.0, theta=0.0
% INFO    : Bus 84803	: V=1.0164704, theta=-24.092739 -> V=1.0, theta=0.0
% INFO    : Bus 84804	: V=1.0175122, theta=-27.599651 -> V=1.0, theta=0.0
% INFO    : Bus 84805	: V=1.008837, theta=-30.232249 -> V=1.0, theta=0.0
% INFO    : Bus 84806	: V=1.0127403, theta=-29.199094 -> V=1.0, theta=0.0
% INFO    : Bus 84807	: V=1.0076963, theta=-34.348804 -> V=1.0, theta=0.0
% INFO    : Bus 84808	: V=1.0046983, theta=-33.524273 -> V=1.0, theta=0.0
% INFO    : Bus 84809	: V=1.0102941, theta=-33.236936 -> V=1.0, theta=0.0
% INFO    : Bus 84810	: V=1.0105462, theta=-33.374475 -> V=1.0, theta=0.0
% INFO    : Bus 84811	: V=1.0184082, theta=-23.331618 -> V=1.0, theta=0.0
% INFO    : Bus 84812	: V=1.0117908, theta=-33.845967 -> V=1.0, theta=0.0
% INFO    : Bus 84813	: V=1.0119672, theta=-33.797609 -> V=1.0, theta=0.0
% INFO    : Bus 84814	: V=1.0130159, theta=-35.272235 -> V=1.0, theta=0.0
% INFO    : Bus 84815	: V=1.0127748, theta=-27.905949 -> V=1.0, theta=0.0
% INFO    : Bus 84816	: V=1.0154864, theta=-27.391575 -> V=1.0, theta=0.0
% INFO    : Bus 84817	: V=0.9661487, theta=-41.263636 -> V=1.0, theta=0.0
% INFO    : Bus 84818	: V=1.018688, theta=-25.016875 -> V=1.0, theta=0.0
% INFO    : Bus 84819	: V=1.0190513, theta=-25.101343 -> V=1.0, theta=0.0
% INFO    : Bus 84820	: V=0.9942863, theta=-49.24665 -> V=1.0, theta=0.0
% INFO    : Bus 84821	: V=1.0107198, theta=-49.923756 -> V=1.0, theta=0.0
% INFO    : Bus 84822	: V=0.9796241, theta=-38.644983 -> V=1.0, theta=0.0
% INFO    : Bus 84823	: V=1.0013531, theta=-36.363937 -> V=1.0, theta=0.0
% INFO    : Bus 84824	: V=0.989491, theta=-27.73099 -> V=1.0, theta=0.0
% INFO    : Bus 84825	: V=1.0109357, theta=-35.145887 -> V=1.0, theta=0.0
% INFO    : Bus 84826	: V=1.0071585, theta=-35.165861 -> V=1.0, theta=0.0
% INFO    : Bus 84827	: V=1.0161484, theta=-28.11097 -> V=1.0, theta=0.0
% INFO    : Bus 84828	: V=1.0102896, theta=-34.923971 -> V=1.0, theta=0.0
% INFO    : Bus 84829	: V=1.007851, theta=-35.303373 -> V=1.0, theta=0.0
% INFO    : Bus 84830	: V=1.0078046, theta=-35.384144 -> V=1.0, theta=0.0
% INFO    : Bus 84831	: V=0.9950669, theta=-27.379086 -> V=1.0, theta=0.0
% INFO    : Bus 84832	: V=0.9959546, theta=-27.283806 -> V=1.0, theta=0.0
% INFO    : Bus 84833	: V=1.0130297, theta=-23.731839 -> V=1.0, theta=0.0
% INFO    : Bus 84834	: V=1.0092692, theta=-24.338813 -> V=1.0, theta=0.0
% INFO    : Bus 84835	: V=1.008965, theta=-24.509418 -> V=1.0, theta=0.0
% INFO    : Bus 84836	: V=1.0143827, theta=-25.112937 -> V=1.0, theta=0.0
% INFO    : Bus 84837	: V=1.0121516, theta=-25.356272 -> V=1.0, theta=0.0
% INFO    : Bus 84838	: V=1.0076159, theta=-28.533741 -> V=1.0, theta=0.0
% INFO    : Bus 84839	: V=1.0122717, theta=-28.046244 -> V=1.0, theta=0.0
% INFO    : Bus 84840	: V=1.0144658, theta=-24.492303 -> V=1.0, theta=0.0
% INFO    : Bus 84841	: V=1.01318, theta=-24.510119 -> V=1.0, theta=0.0
% INFO    : Bus 84842	: V=1.0092219, theta=-26.68199 -> V=1.0, theta=0.0
% INFO    : Bus 84843	: V=1.0113621, theta=-26.406166 -> V=1.0, theta=0.0
% INFO    : Bus 84844	: V=1.0166039, theta=-24.605296 -> V=1.0, theta=0.0
% INFO    : Bus 84845	: V=1.012215, theta=-25.702617 -> V=1.0, theta=0.0
% INFO    : Bus 84846	: V=1.0070605, theta=-26.381857 -> V=1.0, theta=0.0
% INFO    : Bus 84847	: V=1.0101414, theta=-38.54939 -> V=1.0, theta=0.0
% INFO    : Bus 84848	: V=1.0051546, theta=-38.942596 -> V=1.0, theta=0.0
% INFO    : Bus 84849	: V=1.0093645, theta=-38.394423 -> V=1.0, theta=0.0
% INFO    : Bus 84850	: V=1.0051922, theta=-29.832926 -> V=1.0, theta=0.0
% INFO    : Bus 84851	: V=1.00994, theta=-37.120694 -> V=1.0, theta=0.0
% INFO    : Bus 84852	: V=1.0113751, theta=-36.818708 -> V=1.0, theta=0.0
% INFO    : Bus 84853	: V=1.0147509, theta=-33.21587 -> V=1.0, theta=0.0
% INFO    : Bus 84854	: V=0.9964941, theta=-32.039229 -> V=1.0, theta=0.0
% INFO    : Bus 84855	: V=1.0116432, theta=-26.607656 -> V=1.0, theta=0.0
% INFO    : Bus 84856	: V=0.9775747, theta=-34.219844 -> V=1.0, theta=0.0
% INFO    : Bus 84857	: V=1.0022213, theta=-28.8953 -> V=1.0, theta=0.0
% INFO    : Bus 84858	: V=1.0115413, theta=-36.351362 -> V=1.0, theta=0.0
% INFO    : Bus 84859	: V=0.9822388, theta=-39.632469 -> V=1.0, theta=0.0
% INFO    : Bus 84860	: V=0.9844431, theta=-39.128166 -> V=1.0, theta=0.0
% INFO    : Bus 84861	: V=0.9962719, theta=-33.621145 -> V=1.0, theta=0.0
% INFO    : Bus 84862	: V=0.9999079, theta=-36.439474 -> V=1.0, theta=0.0
% INFO    : Bus 84863	: V=1.0027319, theta=-35.983662 -> V=1.0, theta=0.0
% INFO    : Bus 84864	: V=1.0100293, theta=-29.409322 -> V=1.0, theta=0.0
% INFO    : Bus 84865	: V=1.0147204, theta=-25.858543 -> V=1.0, theta=0.0
% INFO    : Bus 84866	: V=1.0131116, theta=-27.848103 -> V=1.0, theta=0.0
% INFO    : Bus 84867	: V=0.9972817, theta=-39.522212 -> V=1.0, theta=0.0
% INFO    : Bus 84868	: V=1.0100917, theta=-29.110882 -> V=1.0, theta=0.0
% INFO    : Bus 84869	: V=1.0139337, theta=-32.360098 -> V=1.0, theta=0.0
% INFO    : Bus 84870	: V=1.0132618, theta=-32.451025 -> V=1.0, theta=0.0
% INFO    : Bus 84871	: V=1.0113119, theta=-32.598638 -> V=1.0, theta=0.0
% INFO    : Bus 84872	: V=0.9864412, theta=-32.891234 -> V=1.0, theta=0.0
% INFO    : Bus 84873	: V=0.9589857, theta=-30.962717 -> V=1.0, theta=0.0
% INFO    : Bus 84874	: V=1.0196719, theta=-24.359509 -> V=1.0, theta=0.0
% INFO    : Bus 84875	: V=0.989629, theta=-29.128679 -> V=1.0, theta=0.0
% INFO    : Bus 84876	: V=1.0055886, theta=-48.040333 -> V=1.0, theta=0.0
% INFO    : Bus 84877	: V=1.004654, theta=-48.919914 -> V=1.0, theta=0.0
% INFO    : Bus 84878	: V=0.9958354, theta=-49.917193 -> V=1.0, theta=0.0
% INFO    : Bus 84879	: V=0.9868877, theta=-50.524524 -> V=1.0, theta=0.0
% INFO    : Bus 84880	: V=0.9964986, theta=-49.602955 -> V=1.0, theta=0.0
% INFO    : Bus 84881	: V=0.9933963, theta=-50.230898 -> V=1.0, theta=0.0
% INFO    : Bus 84882	: V=0.9969523, theta=-50.047302 -> V=1.0, theta=0.0
% INFO    : Bus 84883	: V=0.9996458, theta=-49.925458 -> V=1.0, theta=0.0
% INFO    : Bus 84884	: V=1.003492, theta=-49.927277 -> V=1.0, theta=0.0
% INFO    : Bus 84885	: V=0.9917665, theta=-48.879609 -> V=1.0, theta=0.0
% INFO    : Bus 84886	: V=0.9919699, theta=-50.396463 -> V=1.0, theta=0.0
% INFO    : Bus 84887	: V=0.9937944, theta=-50.464751 -> V=1.0, theta=0.0
% INFO    : Bus 84888	: V=0.9871352, theta=-50.740973 -> V=1.0, theta=0.0
% INFO    : Bus 84889	: V=0.9897352, theta=-50.097474 -> V=1.0, theta=0.0
% INFO    : Bus 84890	: V=0.9765978, theta=-46.259985 -> V=1.0, theta=0.0
% INFO    : Bus 84891	: V=0.9920298, theta=-49.531826 -> V=1.0, theta=0.0
% INFO    : Bus 84892	: V=0.9995425, theta=-48.190714 -> V=1.0, theta=0.0
% INFO    : Bus 84893	: V=1.0001745, theta=-48.167658 -> V=1.0, theta=0.0
% INFO    : Bus 84894	: V=0.9672463, theta=-51.188292 -> V=1.0, theta=0.0
% INFO    : Bus 84895	: V=0.9726624, theta=-50.664851 -> V=1.0, theta=0.0
% INFO    : Bus 84896	: V=0.9810523, theta=-50.120492 -> V=1.0, theta=0.0
% INFO    : Bus 84897	: V=0.9875984, theta=-49.503132 -> V=1.0, theta=0.0
% INFO    : Bus 84898	: V=0.9937268, theta=-49.170619 -> V=1.0, theta=0.0
% INFO    : Bus 84899	: V=0.9913643, theta=-49.30756 -> V=1.0, theta=0.0
% INFO    : Bus 84900	: V=0.9841115, theta=-49.966049 -> V=1.0, theta=0.0
% INFO    : Bus 84901	: V=0.9981102, theta=-48.501346 -> V=1.0, theta=0.0
% INFO    : Bus 84902	: V=0.9900818, theta=-49.487388 -> V=1.0, theta=0.0
% INFO    : Bus 84903	: V=0.9865933, theta=-49.720752 -> V=1.0, theta=0.0
% INFO    : Bus 84904	: V=0.9993069, theta=-48.657153 -> V=1.0, theta=0.0
% INFO    : Bus 84905	: V=0.9910173, theta=-49.424979 -> V=1.0, theta=0.0
% INFO    : Bus 84906	: V=1.0003903, theta=-46.909117 -> V=1.0, theta=0.0
% INFO    : Bus 84907	: V=0.990377, theta=-48.10311 -> V=1.0, theta=0.0
% INFO    : Bus 84908	: V=1.0053211, theta=-41.985308 -> V=1.0, theta=0.0
% INFO    : Bus 84909	: V=1.0106443, theta=-41.406282 -> V=1.0, theta=0.0
% INFO    : Bus 84910	: V=1.0079071, theta=-41.729385 -> V=1.0, theta=0.0
% INFO    : Bus 84911	: V=1.0071051, theta=-41.8114 -> V=1.0, theta=0.0
% INFO    : Bus 84912	: V=1.0067191, theta=-41.855909 -> V=1.0, theta=0.0
% INFO    : Bus 84913	: V=1.0085071, theta=-41.441642 -> V=1.0, theta=0.0
% INFO    : Bus 84914	: V=1.0094384, theta=-40.941783 -> V=1.0, theta=0.0
% INFO    : Bus 84915	: V=1.016172, theta=-40.77245 -> V=1.0, theta=0.0
% INFO    : Bus 84916	: V=1.0067492, theta=-41.074386 -> V=1.0, theta=0.0
% INFO    : Bus 84917	: V=1.0085469, theta=-41.087264 -> V=1.0, theta=0.0
% INFO    : Bus 84918	: V=0.9882824, theta=-42.281555 -> V=1.0, theta=0.0
% INFO    : Bus 84919	: V=0.9842511, theta=-41.991836 -> V=1.0, theta=0.0
% INFO    : Bus 84920	: V=1.0021506, theta=-41.097775 -> V=1.0, theta=0.0
% INFO    : Bus 84921	: V=0.9985712, theta=-41.421669 -> V=1.0, theta=0.0
% INFO    : Bus 84922	: V=0.9714838, theta=-42.083735 -> V=1.0, theta=0.0
% INFO    : Bus 84923	: V=0.9716415, theta=-42.254459 -> V=1.0, theta=0.0
% INFO    : Bus 84924	: V=0.9870689, theta=-39.913495 -> V=1.0, theta=0.0
% INFO    : Bus 84925	: V=0.9839548, theta=-40.339638 -> V=1.0, theta=0.0
% INFO    : Bus 84926	: V=0.9694814, theta=-41.760632 -> V=1.0, theta=0.0
% INFO    : Bus 84927	: V=0.9689832, theta=-41.59984 -> V=1.0, theta=0.0
% INFO    : Bus 84928	: V=0.9750578, theta=-40.465244 -> V=1.0, theta=0.0
% INFO    : Bus 84929	: V=0.97828, theta=-40.205547 -> V=1.0, theta=0.0
% INFO    : Bus 84930	: V=0.9723362, theta=-41.364792 -> V=1.0, theta=0.0
% INFO    : Bus 84931	: V=0.9789724, theta=-39.900358 -> V=1.0, theta=0.0
% INFO    : Bus 84932	: V=0.9787999, theta=-40.038252 -> V=1.0, theta=0.0
% INFO    : Bus 84933	: V=0.9810192, theta=-39.211214 -> V=1.0, theta=0.0
% INFO    : Bus 84934	: V=0.9651897, theta=-44.135374 -> V=1.0, theta=0.0
% INFO    : Bus 84935	: V=0.9877621, theta=-42.554532 -> V=1.0, theta=0.0
% INFO    : Bus 84936	: V=0.9831146, theta=-40.826152 -> V=1.0, theta=0.0
% INFO    : Bus 84937	: V=0.9999157, theta=-37.412334 -> V=1.0, theta=0.0
% INFO    : Bus 84938	: V=0.9937539, theta=-38.443476 -> V=1.0, theta=0.0
% INFO    : Bus 84939	: V=0.9877003, theta=-39.085752 -> V=1.0, theta=0.0
% INFO    : Bus 84940	: V=0.9903376, theta=-39.06393 -> V=1.0, theta=0.0
% INFO    : Bus 84941	: V=0.9837114, theta=-39.952263 -> V=1.0, theta=0.0
% INFO    : Bus 84942	: V=0.9824197, theta=-40.053733 -> V=1.0, theta=0.0
% INFO    : Bus 84943	: V=1.0004007, theta=-37.163996 -> V=1.0, theta=0.0
% INFO    : Bus 84944	: V=0.9941232, theta=-37.871839 -> V=1.0, theta=0.0
% INFO    : Bus 84945	: V=1.0137998, theta=-41.120404 -> V=1.0, theta=0.0
% INFO    : Bus 84946	: V=1.0093888, theta=-41.534045 -> V=1.0, theta=0.0
% INFO    : Bus 84947	: V=0.9976621, theta=-41.748885 -> V=1.0, theta=0.0
% INFO    : Bus 84948	: V=0.9609229, theta=-44.50579 -> V=1.0, theta=0.0
% INFO    : Bus 84949	: V=0.9651268, theta=-43.89099 -> V=1.0, theta=0.0
% INFO    : Bus 84950	: V=0.9706599, theta=-43.766852 -> V=1.0, theta=0.0
% INFO    : Bus 84951	: V=0.9695892, theta=-43.935092 -> V=1.0, theta=0.0
% INFO    : Bus 84952	: V=0.9620477, theta=-44.178696 -> V=1.0, theta=0.0
% INFO    : Bus 84953	: V=0.9687751, theta=-43.846007 -> V=1.0, theta=0.0
% INFO    : Bus 84954	: V=0.9753074, theta=-43.508722 -> V=1.0, theta=0.0
% INFO    : Bus 84955	: V=0.9765525, theta=-43.532055 -> V=1.0, theta=0.0
% INFO    : Bus 84956	: V=0.9765898, theta=-43.528261 -> V=1.0, theta=0.0
% INFO    : Bus 84957	: V=0.9748276, theta=-43.678794 -> V=1.0, theta=0.0
% INFO    : Bus 84958	: V=0.9738886, theta=-43.825454 -> V=1.0, theta=0.0
% INFO    : Bus 84959	: V=0.969506, theta=-43.964551 -> V=1.0, theta=0.0
% INFO    : Bus 84960	: V=0.9661474, theta=-44.310512 -> V=1.0, theta=0.0
% INFO    : Bus 84961	: V=0.9758187, theta=-43.656643 -> V=1.0, theta=0.0
% INFO    : Bus 84962	: V=0.9714908, theta=-44.11265 -> V=1.0, theta=0.0
% INFO    : Bus 84963	: V=0.9746249, theta=-43.782228 -> V=1.0, theta=0.0
% INFO    : Bus 84964	: V=0.9682538, theta=-44.085787 -> V=1.0, theta=0.0
% INFO    : Bus 84965	: V=0.9759766, theta=-43.291207 -> V=1.0, theta=0.0
% INFO    : Bus 84966	: V=0.9919635, theta=-40.440866 -> V=1.0, theta=0.0
% INFO    : Bus 84967	: V=0.9808677, theta=-42.269398 -> V=1.0, theta=0.0
% INFO    : Bus 84968	: V=0.9773261, theta=-43.11824 -> V=1.0, theta=0.0
% INFO    : Bus 84969	: V=0.9831758, theta=-42.316975 -> V=1.0, theta=0.0
% INFO    : Bus 84970	: V=0.9816989, theta=-42.783153 -> V=1.0, theta=0.0
% INFO    : Bus 84971	: V=0.9720539, theta=-44.190076 -> V=1.0, theta=0.0
% INFO    : Bus 84972	: V=0.9835231, theta=-42.981703 -> V=1.0, theta=0.0
% INFO    : Bus 84973	: V=0.9836663, theta=-42.989808 -> V=1.0, theta=0.0
% INFO    : Bus 84974	: V=0.9860472, theta=-43.019362 -> V=1.0, theta=0.0
% INFO    : Bus 84975	: V=0.9924817, theta=-42.098509 -> V=1.0, theta=0.0
% INFO    : Bus 84976	: V=0.9883891, theta=-42.773107 -> V=1.0, theta=0.0
% INFO    : Bus 84977	: V=0.991878, theta=-42.138042 -> V=1.0, theta=0.0
% INFO    : Bus 84978	: V=0.9873648, theta=-42.886405 -> V=1.0, theta=0.0
% INFO    : Bus 84979	: V=0.9806079, theta=-42.98984 -> V=1.0, theta=0.0
% INFO    : Bus 84980	: V=0.9972355, theta=-40.67623 -> V=1.0, theta=0.0
% INFO    : Bus 84981	: V=0.9885213, theta=-42.096975 -> V=1.0, theta=0.0
% INFO    : Bus 84982	: V=0.9866459, theta=-42.50205 -> V=1.0, theta=0.0
% INFO    : Bus 84983	: V=0.9876788, theta=-42.240012 -> V=1.0, theta=0.0
% INFO    : Bus 84984	: V=0.9867675, theta=-42.59023 -> V=1.0, theta=0.0
% INFO    : Bus 84985	: V=0.9844083, theta=-42.901671 -> V=1.0, theta=0.0
% INFO    : Bus 84986	: V=0.9803396, theta=-43.458587 -> V=1.0, theta=0.0
% INFO    : Bus 84987	: V=0.9735686, theta=-44.245207 -> V=1.0, theta=0.0
% INFO    : Bus 84988	: V=0.9831514, theta=-42.778821 -> V=1.0, theta=0.0
% INFO    : Bus 84989	: V=0.9839393, theta=-42.879459 -> V=1.0, theta=0.0
% INFO    : Bus 84990	: V=0.9808363, theta=-43.413408 -> V=1.0, theta=0.0
% INFO    : Bus 84991	: V=0.9840061, theta=-42.881876 -> V=1.0, theta=0.0
% INFO    : Bus 84992	: V=0.9791331, theta=-43.572839 -> V=1.0, theta=0.0
% INFO    : Bus 84993	: V=0.9842089, theta=-43.073099 -> V=1.0, theta=0.0
% INFO    : Bus 84994	: V=0.9846087, theta=-43.009298 -> V=1.0, theta=0.0
% INFO    : Bus 84995	: V=0.9760403, theta=-44.127297 -> V=1.0, theta=0.0
% INFO    : Bus 84996	: V=0.9731385, theta=-44.410677 -> V=1.0, theta=0.0
% INFO    : Bus 84997	: V=0.9821466, theta=-43.539983 -> V=1.0, theta=0.0
% INFO    : Bus 84998	: V=0.9843774, theta=-43.201739 -> V=1.0, theta=0.0
% INFO    : Bus 84999	: V=0.9957431, theta=-41.851582 -> V=1.0, theta=0.0
% INFO    : Bus 85000	: V=0.9785046, theta=-44.314964 -> V=1.0, theta=0.0
% INFO    : Bus 85001	: V=0.972939, theta=-44.55025 -> V=1.0, theta=0.0
% INFO    : Bus 85002	: V=0.9657108, theta=-45.24241 -> V=1.0, theta=0.0
% INFO    : Bus 85003	: V=0.9831599, theta=-43.797126 -> V=1.0, theta=0.0
% INFO    : Bus 85004	: V=0.9851176, theta=-43.01084 -> V=1.0, theta=0.0
% INFO    : Bus 85005	: V=0.9811516, theta=-44.134828 -> V=1.0, theta=0.0
% INFO    : Bus 85006	: V=0.9829606, theta=-43.053186 -> V=1.0, theta=0.0
% INFO    : Bus 85007	: V=0.9812655, theta=-43.416175 -> V=1.0, theta=0.0
% INFO    : Bus 85008	: V=0.996546, theta=-41.77661 -> V=1.0, theta=0.0
% INFO    : Bus 85009	: V=0.9797413, theta=-43.518043 -> V=1.0, theta=0.0
% INFO    : Bus 85010	: V=0.9816665, theta=-43.591658 -> V=1.0, theta=0.0
% INFO    : Bus 85011	: V=0.9819962, theta=-43.347718 -> V=1.0, theta=0.0
% INFO    : Bus 85012	: V=0.9836631, theta=-43.231477 -> V=1.0, theta=0.0
% INFO    : Bus 85013	: V=0.9816269, theta=-43.870162 -> V=1.0, theta=0.0
% INFO    : Bus 85014	: V=0.9771918, theta=-44.501298 -> V=1.0, theta=0.0
% INFO    : Bus 85015	: V=0.983076, theta=-43.295281 -> V=1.0, theta=0.0
% INFO    : Bus 85016	: V=0.9825554, theta=-43.33605 -> V=1.0, theta=0.0
% INFO    : Bus 85017	: V=0.9802866, theta=-43.521052 -> V=1.0, theta=0.0
% INFO    : Bus 85018	: V=0.982127, theta=-43.716006 -> V=1.0, theta=0.0
% INFO    : Bus 85019	: V=0.9843675, theta=-43.238763 -> V=1.0, theta=0.0
% INFO    : Bus 85020	: V=0.984624, theta=-43.259725 -> V=1.0, theta=0.0
% INFO    : Bus 85021	: V=0.9810145, theta=-43.410798 -> V=1.0, theta=0.0
% INFO    : Bus 85022	: V=0.9813599, theta=-43.874229 -> V=1.0, theta=0.0
% INFO    : Bus 85023	: V=0.9767717, theta=-44.621788 -> V=1.0, theta=0.0
% INFO    : Bus 85024	: V=0.9933557, theta=-42.073656 -> V=1.0, theta=0.0
% INFO    : Bus 85025	: V=0.9891244, theta=-42.962357 -> V=1.0, theta=0.0
% INFO    : Bus 85026	: V=0.9805636, theta=-44.178955 -> V=1.0, theta=0.0
% INFO    : Bus 85027	: V=0.9779812, theta=-44.496442 -> V=1.0, theta=0.0
% INFO    : Bus 85028	: V=0.9930788, theta=-42.081748 -> V=1.0, theta=0.0
% INFO    : Bus 85029	: V=0.9934283, theta=-42.241948 -> V=1.0, theta=0.0
% INFO    : Bus 85030	: V=0.9650067, theta=-51.659975 -> V=1.0, theta=0.0
% INFO    : Bus 85031	: V=0.9655171, theta=-51.44396 -> V=1.0, theta=0.0
% INFO    : Bus 85032	: V=0.9650737, theta=-52.111307 -> V=1.0, theta=0.0
% INFO    : Bus 85033	: V=0.9661838, theta=-52.095584 -> V=1.0, theta=0.0
% INFO    : Bus 85034	: V=0.9668877, theta=-52.275372 -> V=1.0, theta=0.0
% INFO    : Bus 85035	: V=0.9734694, theta=-51.081495 -> V=1.0, theta=0.0
% INFO    : Bus 85036	: V=0.9688579, theta=-51.687492 -> V=1.0, theta=0.0
% INFO    : Bus 85037	: V=0.9599391, theta=-53.209307 -> V=1.0, theta=0.0
% INFO    : Bus 85038	: V=0.9637382, theta=-51.967014 -> V=1.0, theta=0.0
% INFO    : Bus 85039	: V=0.9595654, theta=-52.487078 -> V=1.0, theta=0.0
% INFO    : Bus 85040	: V=0.9792463, theta=-49.883637 -> V=1.0, theta=0.0
% INFO    : Bus 85041	: V=0.9925825, theta=-48.154222 -> V=1.0, theta=0.0
% INFO    : Bus 85042	: V=0.9924824, theta=-47.896323 -> V=1.0, theta=0.0
% INFO    : Bus 85043	: V=0.9798802, theta=-49.651853 -> V=1.0, theta=0.0
% INFO    : Bus 85044	: V=0.9947387, theta=-48.081988 -> V=1.0, theta=0.0
% INFO    : Bus 85045	: V=0.9927755, theta=-49.139677 -> V=1.0, theta=0.0
% INFO    : Bus 85046	: V=0.9756568, theta=-50.030635 -> V=1.0, theta=0.0
% INFO    : Bus 85047	: V=0.9746155, theta=-49.896379 -> V=1.0, theta=0.0
% INFO    : Bus 85048	: V=0.9670842, theta=-50.946297 -> V=1.0, theta=0.0
% INFO    : Bus 85049	: V=0.9732219, theta=-50.865829 -> V=1.0, theta=0.0
% INFO    : Bus 85050	: V=0.9692215, theta=-51.155438 -> V=1.0, theta=0.0
% INFO    : Bus 85051	: V=0.9696899, theta=-51.356162 -> V=1.0, theta=0.0
% INFO    : Bus 85052	: V=0.9729246, theta=-50.902514 -> V=1.0, theta=0.0
% INFO    : Bus 85053	: V=0.9919178, theta=-49.927463 -> V=1.0, theta=0.0
% INFO    : Bus 85054	: V=0.9891123, theta=-50.185776 -> V=1.0, theta=0.0
% INFO    : Bus 85055	: V=0.9807703, theta=-51.096904 -> V=1.0, theta=0.0
% INFO    : Bus 85056	: V=0.9584976, theta=-46.926541 -> V=1.0, theta=0.0
% INFO    : Bus 85057	: V=0.969173, theta=-45.639517 -> V=1.0, theta=0.0
% INFO    : Bus 85058	: V=0.9582689, theta=-47.174105 -> V=1.0, theta=0.0
% INFO    : Bus 85059	: V=0.9567233, theta=-47.12848 -> V=1.0, theta=0.0
% INFO    : Bus 85060	: V=0.9559466, theta=-47.277862 -> V=1.0, theta=0.0
% INFO    : Bus 85061	: V=0.9825402, theta=-48.346018 -> V=1.0, theta=0.0
% INFO    : Bus 85062	: V=0.9585712, theta=-47.863875 -> V=1.0, theta=0.0
% INFO    : Bus 85063	: V=0.9869794, theta=-45.188523 -> V=1.0, theta=0.0
% INFO    : Bus 85064	: V=0.9891798, theta=-44.918304 -> V=1.0, theta=0.0
% INFO    : Bus 85065	: V=0.9553615, theta=-56.089327 -> V=1.0, theta=0.0
% INFO    : Bus 85066	: V=0.9565398, theta=-55.965546 -> V=1.0, theta=0.0
% INFO    : Bus 85067	: V=0.9666846, theta=-54.280083 -> V=1.0, theta=0.0
% INFO    : Bus 85068	: V=0.9619734, theta=-55.503754 -> V=1.0, theta=0.0
% INFO    : Bus 85069	: V=0.9554611, theta=-56.293392 -> V=1.0, theta=0.0
% INFO    : Bus 85070	: V=0.9569211, theta=-56.08021 -> V=1.0, theta=0.0
% INFO    : Bus 85071	: V=0.9496612, theta=-51.630552 -> V=1.0, theta=0.0
% INFO    : Bus 85072	: V=0.9832635, theta=-51.820121 -> V=1.0, theta=0.0
% INFO    : Bus 85073	: V=0.9831089, theta=-51.200563 -> V=1.0, theta=0.0
% INFO    : Bus 85074	: V=0.9769489, theta=-52.192455 -> V=1.0, theta=0.0
% INFO    : Bus 85075	: V=0.9807652, theta=-51.970878 -> V=1.0, theta=0.0
% INFO    : Bus 85076	: V=0.9773028, theta=-52.021152 -> V=1.0, theta=0.0
% INFO    : Bus 85077	: V=0.9864796, theta=-45.982945 -> V=1.0, theta=0.0
% INFO    : Bus 85078	: V=1.0108773, theta=-44.67907 -> V=1.0, theta=0.0
% INFO    : Bus 85079	: V=0.9954575, theta=-46.8023 -> V=1.0, theta=0.0
% INFO    : Bus 85080	: V=1.0156125, theta=-46.460603 -> V=1.0, theta=0.0
% INFO    : Bus 85081	: V=1.0131888, theta=-46.782834 -> V=1.0, theta=0.0
% INFO    : Bus 85082	: V=1.0088657, theta=-48.184628 -> V=1.0, theta=0.0
% INFO    : Bus 85083	: V=1.0079908, theta=-48.140033 -> V=1.0, theta=0.0
% INFO    : Bus 85084	: V=0.9919834, theta=-43.292677 -> V=1.0, theta=0.0
% INFO    : Bus 85085	: V=0.9895472, theta=-43.658779 -> V=1.0, theta=0.0
% INFO    : Bus 85086	: V=0.9737382, theta=-44.735378 -> V=1.0, theta=0.0
% INFO    : Bus 85087	: V=0.9704526, theta=-45.467194 -> V=1.0, theta=0.0
% INFO    : Bus 85088	: V=0.9786307, theta=-44.441412 -> V=1.0, theta=0.0
% INFO    : Bus 85089	: V=0.9708401, theta=-44.921735 -> V=1.0, theta=0.0
% INFO    : Bus 85090	: V=0.9654103, theta=-45.034786 -> V=1.0, theta=0.0
% INFO    : Bus 85091	: V=0.9773403, theta=-44.5229 -> V=1.0, theta=0.0
% INFO    : Bus 85092	: V=0.9762119, theta=-44.448473 -> V=1.0, theta=0.0
% INFO    : Bus 85093	: V=0.9863439, theta=-43.64004 -> V=1.0, theta=0.0
% INFO    : Bus 85094	: V=0.9989554, theta=-42.271715 -> V=1.0, theta=0.0
% INFO    : Bus 85095	: V=0.9944591, theta=-42.953345 -> V=1.0, theta=0.0
% INFO    : Bus 85096	: V=0.9882965, theta=-43.467423 -> V=1.0, theta=0.0
% INFO    : Bus 85097	: V=0.9888049, theta=-43.489605 -> V=1.0, theta=0.0
% INFO    : Bus 85098	: V=0.9818643, theta=-44.126381 -> V=1.0, theta=0.0
% INFO    : Bus 85099	: V=0.9839108, theta=-44.51523 -> V=1.0, theta=0.0
% INFO    : Bus 85100	: V=0.9762949, theta=-44.393438 -> V=1.0, theta=0.0
% INFO    : Bus 85101	: V=0.9816008, theta=-44.148156 -> V=1.0, theta=0.0
% INFO    : Bus 85102	: V=0.9769837, theta=-44.358315 -> V=1.0, theta=0.0
% INFO    : Bus 85103	: V=0.9797793, theta=-44.274712 -> V=1.0, theta=0.0
% INFO    : Bus 85104	: V=0.9764756, theta=-44.381695 -> V=1.0, theta=0.0
% INFO    : Bus 85105	: V=0.9768152, theta=-44.763893 -> V=1.0, theta=0.0
% INFO    : Bus 85106	: V=0.9815269, theta=-44.225199 -> V=1.0, theta=0.0
% INFO    : Bus 85107	: V=0.9855296, theta=-43.958852 -> V=1.0, theta=0.0
% INFO    : Bus 85108	: V=0.9797672, theta=-44.610033 -> V=1.0, theta=0.0
% INFO    : Bus 85109	: V=0.9777273, theta=-45.024933 -> V=1.0, theta=0.0
% INFO    : Bus 85110	: V=0.9637355, theta=-45.914462 -> V=1.0, theta=0.0
% INFO    : Bus 85111	: V=0.9700187, theta=-45.026515 -> V=1.0, theta=0.0
% INFO    : Bus 85112	: V=0.9642902, theta=-45.982887 -> V=1.0, theta=0.0
% INFO    : Bus 85113	: V=0.9732565, theta=-45.299928 -> V=1.0, theta=0.0
% INFO    : Bus 85114	: V=0.9910819, theta=-43.0934 -> V=1.0, theta=0.0
% INFO    : Bus 85115	: V=0.9736741, theta=-45.10184 -> V=1.0, theta=0.0
% INFO    : Bus 85116	: V=0.9699956, theta=-45.586236 -> V=1.0, theta=0.0
% INFO    : Bus 85117	: V=0.9613133, theta=-46.394527 -> V=1.0, theta=0.0
% INFO    : Bus 85118	: V=0.9773578, theta=-45.455017 -> V=1.0, theta=0.0
% INFO    : Bus 85119	: V=0.9580591, theta=-46.547363 -> V=1.0, theta=0.0
% INFO    : Bus 85120	: V=0.9572001, theta=-46.678546 -> V=1.0, theta=0.0
% INFO    : Bus 85121	: V=0.9593412, theta=-46.433754 -> V=1.0, theta=0.0
% INFO    : Bus 85122	: V=0.9599491, theta=-46.381034 -> V=1.0, theta=0.0
% INFO    : Bus 85123	: V=0.9545723, theta=-47.439752 -> V=1.0, theta=0.0
% INFO    : Bus 85124	: V=0.9678186, theta=-45.322683 -> V=1.0, theta=0.0
% INFO    : Bus 85125	: V=0.9777123, theta=-44.401887 -> V=1.0, theta=0.0
% INFO    : Bus 85126	: V=0.9733216, theta=-44.968484 -> V=1.0, theta=0.0
% INFO    : Bus 85127	: V=0.9671231, theta=-45.388565 -> V=1.0, theta=0.0
% INFO    : Bus 85128	: V=0.9651385, theta=-45.881667 -> V=1.0, theta=0.0
% INFO    : Bus 85129	: V=0.9577459, theta=-46.478892 -> V=1.0, theta=0.0
% INFO    : Bus 85130	: V=0.9547859, theta=-46.967861 -> V=1.0, theta=0.0
% INFO    : Bus 85131	: V=0.9591078, theta=-46.638506 -> V=1.0, theta=0.0
% INFO    : Bus 85132	: V=0.9862441, theta=-43.614397 -> V=1.0, theta=0.0
% INFO    : Bus 85133	: V=0.9843139, theta=-43.707585 -> V=1.0, theta=0.0
% INFO    : Bus 85134	: V=0.993297, theta=-42.728721 -> V=1.0, theta=0.0
% INFO    : Bus 85135	: V=0.9829827, theta=-43.788293 -> V=1.0, theta=0.0
% INFO    : Bus 85136	: V=0.9795821, theta=-43.984769 -> V=1.0, theta=0.0
% INFO    : Bus 85137	: V=0.9775721, theta=-44.181848 -> V=1.0, theta=0.0
% INFO    : Bus 85138	: V=0.9739628, theta=-44.878642 -> V=1.0, theta=0.0
% INFO    : Bus 85139	: V=0.9698994, theta=-45.146271 -> V=1.0, theta=0.0
% INFO    : Bus 85140	: V=0.9701614, theta=-45.142871 -> V=1.0, theta=0.0
% INFO    : Bus 85141	: V=0.9610979, theta=-46.150232 -> V=1.0, theta=0.0
% INFO    : Bus 85142	: V=0.9608211, theta=-46.343688 -> V=1.0, theta=0.0
% INFO    : Bus 85143	: V=0.961604, theta=-46.292911 -> V=1.0, theta=0.0
% INFO    : Bus 85144	: V=0.9644625, theta=-46.069763 -> V=1.0, theta=0.0
% INFO    : Bus 85145	: V=0.9614685, theta=-46.332581 -> V=1.0, theta=0.0
% INFO    : Bus 85146	: V=0.9533443, theta=-47.335657 -> V=1.0, theta=0.0
% INFO    : Bus 85147	: V=0.9565621, theta=-46.752575 -> V=1.0, theta=0.0
% INFO    : Bus 85148	: V=0.9558249, theta=-46.891817 -> V=1.0, theta=0.0
% INFO    : Bus 85149	: V=0.9552618, theta=-46.918165 -> V=1.0, theta=0.0
% INFO    : Bus 85150	: V=0.9573775, theta=-46.745909 -> V=1.0, theta=0.0
% INFO    : Bus 85151	: V=0.9763349, theta=-46.641973 -> V=1.0, theta=0.0
% INFO    : Bus 85152	: V=0.9812213, theta=-43.993239 -> V=1.0, theta=0.0
% INFO    : Bus 85153	: V=0.9764586, theta=-44.517152 -> V=1.0, theta=0.0
% INFO    : Bus 85154	: V=0.9643635, theta=-58.163389 -> V=1.0, theta=0.0
% INFO    : Bus 85155	: V=0.98859, theta=-55.552903 -> V=1.0, theta=0.0
% INFO    : Bus 85156	: V=0.9870626, theta=-55.847948 -> V=1.0, theta=0.0
% INFO    : Bus 85157	: V=0.9743701, theta=-56.862185 -> V=1.0, theta=0.0
% INFO    : Bus 85158	: V=0.9619751, theta=-58.241489 -> V=1.0, theta=0.0
% INFO    : Bus 85159	: V=0.9626017, theta=-58.322194 -> V=1.0, theta=0.0
% INFO    : Bus 85160	: V=0.9682257, theta=-58.054912 -> V=1.0, theta=0.0
% INFO    : Bus 85161	: V=0.9640167, theta=-57.974873 -> V=1.0, theta=0.0
% INFO    : Bus 85162	: V=0.9817175, theta=-56.184624 -> V=1.0, theta=0.0
% INFO    : Bus 85163	: V=0.9867475, theta=-55.737445 -> V=1.0, theta=0.0
% INFO    : Bus 85164	: V=1.0016606, theta=-54.779061 -> V=1.0, theta=0.0
% INFO    : Bus 85165	: V=0.9593695, theta=-49.632596 -> V=1.0, theta=0.0
% INFO    : Bus 85166	: V=0.9596292, theta=-49.607894 -> V=1.0, theta=0.0
% INFO    : Bus 85167	: V=0.9578569, theta=-49.796015 -> V=1.0, theta=0.0
% INFO    : Bus 85168	: V=0.9576725, theta=-49.886169 -> V=1.0, theta=0.0
% INFO    : Bus 85169	: V=0.9578234, theta=-49.887726 -> V=1.0, theta=0.0
% INFO    : Bus 85170	: V=0.959577, theta=-49.757126 -> V=1.0, theta=0.0
% INFO    : Bus 85171	: V=0.9595058, theta=-49.711631 -> V=1.0, theta=0.0
% INFO    : Bus 85172	: V=0.9716818, theta=-51.353964 -> V=1.0, theta=0.0
% INFO    : Bus 85173	: V=0.9733175, theta=-51.067938 -> V=1.0, theta=0.0
% INFO    : Bus 85174	: V=0.9821545, theta=-51.396232 -> V=1.0, theta=0.0
% INFO    : Bus 85175	: V=0.9730707, theta=-51.100079 -> V=1.0, theta=0.0
% INFO    : Bus 85176	: V=0.9726063, theta=-51.353683 -> V=1.0, theta=0.0
% INFO    : Bus 85177	: V=0.9826581, theta=-50.963699 -> V=1.0, theta=0.0
% INFO    : Bus 85178	: V=0.9899229, theta=-50.590849 -> V=1.0, theta=0.0
% INFO    : Bus 85179	: V=0.955256, theta=-45.55935 -> V=1.0, theta=0.0
% INFO    : Bus 85180	: V=1.0003298, theta=-45.286607 -> V=1.0, theta=0.0
% INFO    : Bus 85181	: V=1.0089458, theta=-44.559209 -> V=1.0, theta=0.0
% INFO    : Bus 85182	: V=0.9976334, theta=-37.029956 -> V=1.0, theta=0.0
% INFO    : Bus 85183	: V=0.9574915, theta=-47.548608 -> V=1.0, theta=0.0
% INFO    : Bus 85184	: V=0.9760057, theta=-51.7878 -> V=1.0, theta=0.0
% INFO    : Bus 85185	: V=0.9760041, theta=-51.926181 -> V=1.0, theta=0.0
% INFO    : Bus 85186	: V=0.9777201, theta=-51.899497 -> V=1.0, theta=0.0
% INFO    : Bus 85187	: V=0.9946095, theta=-50.338814 -> V=1.0, theta=0.0
% INFO    : Bus 85188	: V=0.9941357, theta=-50.316083 -> V=1.0, theta=0.0
% INFO    : Bus 85189	: V=0.9947386, theta=-50.413966 -> V=1.0, theta=0.0
% INFO    : Bus 85190	: V=0.9947651, theta=-50.625873 -> V=1.0, theta=0.0
% INFO    : Bus 85191	: V=0.9944034, theta=-50.594751 -> V=1.0, theta=0.0
% INFO    : Bus 85192	: V=0.9915929, theta=-50.686371 -> V=1.0, theta=0.0
% INFO    : Bus 85193	: V=0.9864075, theta=-51.765873 -> V=1.0, theta=0.0
% INFO    : Bus 85194	: V=0.9880032, theta=-51.642773 -> V=1.0, theta=0.0
% INFO    : Bus 85195	: V=0.9877446, theta=-51.418504 -> V=1.0, theta=0.0
% INFO    : Bus 85196	: V=0.9839066, theta=-51.667073 -> V=1.0, theta=0.0
% INFO    : Bus 85197	: V=0.9791368, theta=-52.06305 -> V=1.0, theta=0.0
% INFO    : Bus 85198	: V=0.9922003, theta=-50.733149 -> V=1.0, theta=0.0
% INFO    : Bus 85199	: V=0.9878299, theta=-51.425877 -> V=1.0, theta=0.0
% INFO    : Bus 85200	: V=0.9885144, theta=-51.453803 -> V=1.0, theta=0.0
% INFO    : Bus 85201	: V=0.9901701, theta=-51.273937 -> V=1.0, theta=0.0
% INFO    : Bus 85202	: V=0.9902316, theta=-51.273278 -> V=1.0, theta=0.0
% INFO    : Bus 85203	: V=0.9880897, theta=-51.476799 -> V=1.0, theta=0.0
% INFO    : Bus 85204	: V=0.9913047, theta=-51.197279 -> V=1.0, theta=0.0
% INFO    : Bus 85205	: V=0.9913154, theta=-51.205292 -> V=1.0, theta=0.0
% INFO    : Bus 85206	: V=0.9912142, theta=-51.292266 -> V=1.0, theta=0.0
% INFO    : Bus 85207	: V=0.9919246, theta=-51.257264 -> V=1.0, theta=0.0
% INFO    : Bus 85208	: V=0.984179, theta=-51.67339 -> V=1.0, theta=0.0
% INFO    : Bus 85209	: V=0.9695657, theta=-48.199266 -> V=1.0, theta=0.0
% INFO    : Bus 85210	: V=0.9728253, theta=-47.921108 -> V=1.0, theta=0.0
% INFO    : Bus 85211	: V=0.9669811, theta=-48.464105 -> V=1.0, theta=0.0
% INFO    : Bus 85212	: V=0.9646475, theta=-49.021557 -> V=1.0, theta=0.0
% INFO    : Bus 85213	: V=0.9634038, theta=-43.350685 -> V=1.0, theta=0.0
% INFO    : Bus 85214	: V=0.963295, theta=-47.257266 -> V=1.0, theta=0.0
% INFO    : Bus 85215	: V=0.9635946, theta=-45.48861 -> V=1.0, theta=0.0
% INFO    : Bus 85216	: V=0.9739387, theta=-50.695285 -> V=1.0, theta=0.0
% INFO    : Bus 85217	: V=0.9725677, theta=-50.868181 -> V=1.0, theta=0.0
% INFO    : Bus 85218	: V=0.9705604, theta=-51.382574 -> V=1.0, theta=0.0
% INFO    : Bus 85219	: V=0.9734272, theta=-50.783708 -> V=1.0, theta=0.0
% INFO    : Bus 85220	: V=0.973764, theta=-50.739739 -> V=1.0, theta=0.0
% INFO    : Bus 85221	: V=0.9757287, theta=-51.134179 -> V=1.0, theta=0.0
% INFO    : Bus 85222	: V=0.9764481, theta=-50.933906 -> V=1.0, theta=0.0
% INFO    : Bus 85223	: V=0.9789056, theta=-50.456917 -> V=1.0, theta=0.0
% INFO    : Bus 85224	: V=0.9833099, theta=-50.177331 -> V=1.0, theta=0.0
% INFO    : Bus 85225	: V=0.9827688, theta=-50.298458 -> V=1.0, theta=0.0
% INFO    : Bus 85226	: V=0.9823407, theta=-50.33502 -> V=1.0, theta=0.0
% INFO    : Bus 85227	: V=0.9861403, theta=-49.927031 -> V=1.0, theta=0.0
% INFO    : Bus 85228	: V=0.9838443, theta=-50.16548 -> V=1.0, theta=0.0
% INFO    : Bus 85229	: V=0.9844778, theta=-50.058184 -> V=1.0, theta=0.0
% INFO    : Bus 85230	: V=0.9699902, theta=-50.700265 -> V=1.0, theta=0.0
% INFO    : Bus 85231	: V=0.9916157, theta=-48.873332 -> V=1.0, theta=0.0
% INFO    : Bus 85232	: V=0.9926071, theta=-48.814914 -> V=1.0, theta=0.0
% INFO    : Bus 85233	: V=0.9816156, theta=-50.230584 -> V=1.0, theta=0.0
% INFO    : Bus 85234	: V=0.9928909, theta=-49.320375 -> V=1.0, theta=0.0
% INFO    : Bus 85235	: V=0.9930816, theta=-49.303922 -> V=1.0, theta=0.0
% INFO    : Bus 85236	: V=0.9916379, theta=-49.406698 -> V=1.0, theta=0.0
% INFO    : Bus 85237	: V=0.9860922, theta=-49.932807 -> V=1.0, theta=0.0
% INFO    : Bus 85238	: V=0.9964464, theta=-49.130031 -> V=1.0, theta=0.0
% INFO    : Bus 85239	: V=0.9936014, theta=-49.517687 -> V=1.0, theta=0.0
% INFO    : Bus 85240	: V=0.986774, theta=-49.926908 -> V=1.0, theta=0.0
% INFO    : Bus 85241	: V=0.9811422, theta=-50.561517 -> V=1.0, theta=0.0
% INFO    : Bus 85242	: V=0.9943926, theta=-49.122217 -> V=1.0, theta=0.0
% INFO    : Bus 85243	: V=0.999089, theta=-48.360336 -> V=1.0, theta=0.0
% INFO    : Bus 85244	: V=0.9914606, theta=-49.061817 -> V=1.0, theta=0.0
% INFO    : Bus 85245	: V=0.9878331, theta=-49.754468 -> V=1.0, theta=0.0
% INFO    : Bus 85246	: V=0.9969696, theta=-49.115156 -> V=1.0, theta=0.0
% INFO    : Bus 85247	: V=0.9956216, theta=-49.459528 -> V=1.0, theta=0.0
% INFO    : Bus 85248	: V=0.9855831, theta=-49.955888 -> V=1.0, theta=0.0
% INFO    : Bus 85249	: V=0.9931322, theta=-49.631623 -> V=1.0, theta=0.0
% INFO    : Bus 85250	: V=0.9931456, theta=-49.860395 -> V=1.0, theta=0.0
% INFO    : Bus 85251	: V=0.9906069, theta=-49.886313 -> V=1.0, theta=0.0
% INFO    : Bus 85252	: V=0.9941612, theta=-49.697864 -> V=1.0, theta=0.0
% INFO    : Bus 85253	: V=0.9953491, theta=-49.455837 -> V=1.0, theta=0.0
% INFO    : Bus 85254	: V=0.9955991, theta=-49.893487 -> V=1.0, theta=0.0
% INFO    : Bus 85255	: V=0.996258, theta=-49.108413 -> V=1.0, theta=0.0
% INFO    : Bus 85256	: V=0.9758095, theta=-49.763209 -> V=1.0, theta=0.0
% INFO    : Bus 85257	: V=0.969009, theta=-50.200224 -> V=1.0, theta=0.0
% INFO    : Bus 85258	: V=0.9564318, theta=-53.262595 -> V=1.0, theta=0.0
% INFO    : Bus 85259	: V=0.9543635, theta=-53.149614 -> V=1.0, theta=0.0
% INFO    : Bus 85260	: V=0.9652694, theta=-51.213289 -> V=1.0, theta=0.0
% INFO    : Bus 85261	: V=0.9594783, theta=-51.457614 -> V=1.0, theta=0.0
% INFO    : Bus 85262	: V=0.9697993, theta=-50.480934 -> V=1.0, theta=0.0
% INFO    : Bus 85263	: V=0.9783633, theta=-50.421834 -> V=1.0, theta=0.0
% INFO    : Bus 85264	: V=0.9818442, theta=-49.794085 -> V=1.0, theta=0.0
% INFO    : Bus 85265	: V=0.9613977, theta=-52.164617 -> V=1.0, theta=0.0
% INFO    : Bus 85266	: V=0.9558897, theta=-52.465141 -> V=1.0, theta=0.0
% INFO    : Bus 85267	: V=0.9609739, theta=-52.031533 -> V=1.0, theta=0.0
% INFO    : Bus 85268	: V=0.9657426, theta=-51.376228 -> V=1.0, theta=0.0
% INFO    : Bus 85269	: V=0.9600531, theta=-52.560137 -> V=1.0, theta=0.0
% INFO    : Bus 85270	: V=0.9602966, theta=-52.386389 -> V=1.0, theta=0.0
% INFO    : Bus 85271	: V=0.9576338, theta=-53.04978 -> V=1.0, theta=0.0
% INFO    : Bus 85272	: V=0.9587616, theta=-52.738209 -> V=1.0, theta=0.0
% INFO    : Bus 85273	: V=0.9638308, theta=-52.104083 -> V=1.0, theta=0.0
% INFO    : Bus 85274	: V=0.962042, theta=-52.709741 -> V=1.0, theta=0.0
% INFO    : Bus 85275	: V=0.9985606, theta=-48.748951 -> V=1.0, theta=0.0
% INFO    : Bus 85276	: V=0.9875581, theta=-50.177984 -> V=1.0, theta=0.0
% INFO    : Bus 85277	: V=0.9873396, theta=-50.201776 -> V=1.0, theta=0.0
% INFO    : Bus 85278	: V=0.9704441, theta=-52.052518 -> V=1.0, theta=0.0
% INFO    : Bus 85279	: V=0.970621, theta=-52.056586 -> V=1.0, theta=0.0
% INFO    : Bus 85280	: V=0.976614, theta=-51.033258 -> V=1.0, theta=0.0
% INFO    : Bus 85281	: V=0.9721243, theta=-51.786422 -> V=1.0, theta=0.0
% INFO    : Bus 85282	: V=0.9722993, theta=-51.827703 -> V=1.0, theta=0.0
% INFO    : Bus 85283	: V=0.9704913, theta=-52.025161 -> V=1.0, theta=0.0
% INFO    : Bus 85284	: V=0.9708957, theta=-52.010517 -> V=1.0, theta=0.0
% INFO    : Bus 85285	: V=0.9725129, theta=-52.074287 -> V=1.0, theta=0.0
% INFO    : Bus 85286	: V=0.9745341, theta=-51.332404 -> V=1.0, theta=0.0
% INFO    : Bus 85287	: V=0.9844954, theta=-49.591191 -> V=1.0, theta=0.0
% INFO    : Bus 85288	: V=0.9718069, theta=-50.260156 -> V=1.0, theta=0.0
% INFO    : Bus 85289	: V=0.9735367, theta=-49.605365 -> V=1.0, theta=0.0
% INFO    : Bus 85290	: V=0.9843846, theta=-49.472522 -> V=1.0, theta=0.0
% INFO    : Bus 85291	: V=0.9850017, theta=-49.38242 -> V=1.0, theta=0.0
% INFO    : Bus 85292	: V=0.9738596, theta=-49.76307 -> V=1.0, theta=0.0
% INFO    : Bus 85293	: V=0.9712339, theta=-49.60744 -> V=1.0, theta=0.0
% INFO    : Bus 85294	: V=0.9715327, theta=-49.60748 -> V=1.0, theta=0.0
% INFO    : Bus 85295	: V=0.9675614, theta=-49.832052 -> V=1.0, theta=0.0
% INFO    : Bus 85296	: V=0.9781086, theta=-49.283193 -> V=1.0, theta=0.0
% INFO    : Bus 85297	: V=0.9789663, theta=-48.576166 -> V=1.0, theta=0.0
% INFO    : Bus 85298	: V=0.9768023, theta=-49.35074 -> V=1.0, theta=0.0
% INFO    : Bus 85299	: V=0.9835175, theta=-48.989 -> V=1.0, theta=0.0
% INFO    : Bus 85300	: V=0.9808185, theta=-49.216455 -> V=1.0, theta=0.0
% INFO    : Bus 85301	: V=0.9751657, theta=-49.587275 -> V=1.0, theta=0.0
% INFO    : Bus 85302	: V=0.9795186, theta=-49.306235 -> V=1.0, theta=0.0
% INFO    : Bus 85303	: V=0.9849823, theta=-48.537687 -> V=1.0, theta=0.0
% INFO    : Bus 85304	: V=0.9894311, theta=-47.890355 -> V=1.0, theta=0.0
% INFO    : Bus 85305	: V=0.9897179, theta=-47.839048 -> V=1.0, theta=0.0
% INFO    : Bus 85306	: V=0.9819396, theta=-49.896632 -> V=1.0, theta=0.0
% INFO    : Bus 85307	: V=0.981475, theta=-49.486868 -> V=1.0, theta=0.0
% INFO    : Bus 85308	: V=0.9992482, theta=-47.782999 -> V=1.0, theta=0.0
% INFO    : Bus 85309	: V=0.9843336, theta=-48.965106 -> V=1.0, theta=0.0
% INFO    : Bus 85310	: V=0.9854712, theta=-48.573867 -> V=1.0, theta=0.0
% INFO    : Bus 85311	: V=1.002269, theta=-47.123522 -> V=1.0, theta=0.0
% INFO    : Bus 85312	: V=0.9982305, theta=-47.674452 -> V=1.0, theta=0.0
% INFO    : Bus 85313	: V=1.013829, theta=-44.494082 -> V=1.0, theta=0.0
% INFO    : Bus 85314	: V=0.9890993, theta=-48.468271 -> V=1.0, theta=0.0
% INFO    : Bus 85315	: V=0.9917323, theta=-47.589417 -> V=1.0, theta=0.0
% INFO    : Bus 85316	: V=0.9900514, theta=-48.387374 -> V=1.0, theta=0.0
% INFO    : Bus 85317	: V=0.9927314, theta=-47.890754 -> V=1.0, theta=0.0
% INFO    : Bus 85318	: V=0.9877613, theta=-48.145101 -> V=1.0, theta=0.0
% INFO    : Bus 85319	: V=0.9896565, theta=-48.053041 -> V=1.0, theta=0.0
% INFO    : Bus 85320	: V=0.9843143, theta=-48.541808 -> V=1.0, theta=0.0
% INFO    : Bus 85321	: V=1.0073388, theta=-45.656878 -> V=1.0, theta=0.0
% INFO    : Bus 85322	: V=0.9954905, theta=-47.120179 -> V=1.0, theta=0.0
% INFO    : Bus 85323	: V=0.9860803, theta=-48.973112 -> V=1.0, theta=0.0
% INFO    : Bus 85324	: V=0.9948586, theta=-47.636977 -> V=1.0, theta=0.0
% INFO    : Bus 85325	: V=0.9974928, theta=-47.533242 -> V=1.0, theta=0.0
% INFO    : Bus 85326	: V=0.9955112, theta=-48.02748 -> V=1.0, theta=0.0
% INFO    : Bus 85327	: V=1.0021936, theta=-47.401861 -> V=1.0, theta=0.0
% INFO    : Bus 85328	: V=1.0041464, theta=-47.143646 -> V=1.0, theta=0.0
% INFO    : Bus 85329	: V=0.9991904, theta=-47.625179 -> V=1.0, theta=0.0
% INFO    : Bus 85330	: V=1.0009072, theta=-47.381796 -> V=1.0, theta=0.0
% INFO    : Bus 85331	: V=1.0026202, theta=-47.383279 -> V=1.0, theta=0.0
% INFO    : Bus 85332	: V=0.9898029, theta=-48.233817 -> V=1.0, theta=0.0
% INFO    : Bus 85333	: V=0.9966753, theta=-49.129342 -> V=1.0, theta=0.0
% INFO    : Bus 85334	: V=0.9942793, theta=-49.475399 -> V=1.0, theta=0.0
% INFO    : Bus 85335	: V=0.9589516, theta=-53.615443 -> V=1.0, theta=0.0
% INFO    : Bus 85336	: V=1.0044673, theta=-33.825179 -> V=1.0, theta=0.0
% INFO    : Bus 85337	: V=0.9980502, theta=-34.752695 -> V=1.0, theta=0.0
% INFO    : Bus 85338	: V=0.9945232, theta=-35.042135 -> V=1.0, theta=0.0
% INFO    : Bus 85339	: V=0.9937713, theta=-34.78021 -> V=1.0, theta=0.0
% INFO    : Bus 85340	: V=0.9987029, theta=-34.345051 -> V=1.0, theta=0.0
% INFO    : Bus 85341	: V=0.998453, theta=-34.097562 -> V=1.0, theta=0.0
% INFO    : Bus 85342	: V=0.9957313, theta=-34.599939 -> V=1.0, theta=0.0
% INFO    : Bus 85343	: V=0.9985941, theta=-34.044996 -> V=1.0, theta=0.0
% INFO    : Bus 85344	: V=0.9955612, theta=-34.293734 -> V=1.0, theta=0.0
% INFO    : Bus 85345	: V=0.9901133, theta=-36.517913 -> V=1.0, theta=0.0
% INFO    : Bus 85346	: V=0.9841634, theta=-37.314285 -> V=1.0, theta=0.0
% INFO    : Bus 85347	: V=0.9793686, theta=-37.723444 -> V=1.0, theta=0.0
% INFO    : Bus 85348	: V=0.9837482, theta=-37.523951 -> V=1.0, theta=0.0
% INFO    : Bus 85349	: V=0.9774707, theta=-38.048151 -> V=1.0, theta=0.0
% INFO    : Bus 85350	: V=1.0059644, theta=-33.397866 -> V=1.0, theta=0.0
% INFO    : Bus 85351	: V=1.0048521, theta=-33.51745 -> V=1.0, theta=0.0
% INFO    : Bus 85352	: V=0.9837114, theta=-50.831458 -> V=1.0, theta=0.0
% INFO    : Bus 85353	: V=0.9714054, theta=-52.908438 -> V=1.0, theta=0.0
% INFO    : Bus 85354	: V=0.967519, theta=-52.958469 -> V=1.0, theta=0.0
% INFO    : Bus 85355	: V=0.9933757, theta=-50.877292 -> V=1.0, theta=0.0
% INFO    : Bus 85356	: V=0.9711241, theta=-52.01222 -> V=1.0, theta=0.0
% INFO    : Bus 85357	: V=0.978928, theta=-52.775789 -> V=1.0, theta=0.0
% INFO    : Bus 85358	: V=0.9981141, theta=-48.985148 -> V=1.0, theta=0.0
% INFO    : Bus 85359	: V=0.9865896, theta=-46.37996 -> V=1.0, theta=0.0
% INFO    : Bus 85360	: V=0.9632104, theta=-50.188245 -> V=1.0, theta=0.0
% INFO    : Bus 85361	: V=0.9730531, theta=-49.60069 -> V=1.0, theta=0.0
% INFO    : Bus 85362	: V=0.9608837, theta=-50.682051 -> V=1.0, theta=0.0
% INFO    : Bus 85363	: V=0.9617286, theta=-51.080216 -> V=1.0, theta=0.0
% INFO    : Bus 85364	: V=0.9577761, theta=-51.670056 -> V=1.0, theta=0.0
% INFO    : Bus 85365	: V=0.9561938, theta=-51.758448 -> V=1.0, theta=0.0
% INFO    : Bus 85366	: V=0.955732, theta=-51.832078 -> V=1.0, theta=0.0
% INFO    : Bus 85367	: V=0.9588892, theta=-51.052823 -> V=1.0, theta=0.0
% INFO    : Bus 85368	: V=0.9691678, theta=-47.61297 -> V=1.0, theta=0.0
% INFO    : Bus 85369	: V=0.960964, theta=-50.471136 -> V=1.0, theta=0.0
% INFO    : Bus 85370	: V=0.9585856, theta=-49.712543 -> V=1.0, theta=0.0
% INFO    : Bus 85371	: V=0.9559377, theta=-51.852158 -> V=1.0, theta=0.0
% INFO    : Bus 85372	: V=0.9558438, theta=-51.839869 -> V=1.0, theta=0.0
% INFO    : Bus 85373	: V=0.9571853, theta=-51.360756 -> V=1.0, theta=0.0
% INFO    : Bus 85374	: V=0.9682369, theta=-50.40393 -> V=1.0, theta=0.0
% INFO    : Bus 85375	: V=0.9583944, theta=-51.864981 -> V=1.0, theta=0.0
% INFO    : Bus 85376	: V=0.9693809, theta=-50.112905 -> V=1.0, theta=0.0
% INFO    : Bus 85377	: V=0.9693672, theta=-50.078347 -> V=1.0, theta=0.0
% INFO    : Bus 85378	: V=0.9586764, theta=-50.765773 -> V=1.0, theta=0.0
% INFO    : Bus 85379	: V=0.9684747, theta=-49.804907 -> V=1.0, theta=0.0
% INFO    : Bus 85380	: V=0.9653857, theta=-50.029524 -> V=1.0, theta=0.0
% INFO    : Bus 85381	: V=1.0038377, theta=-48.528768 -> V=1.0, theta=0.0
% INFO    : Bus 85382	: V=0.9994198, theta=-49.119837 -> V=1.0, theta=0.0
% INFO    : Bus 85383	: V=0.9903129, theta=-49.619946 -> V=1.0, theta=0.0
% INFO    : Bus 85384	: V=0.9981671, theta=-48.976448 -> V=1.0, theta=0.0
% INFO    : Bus 85385	: V=0.9838613, theta=-50.449053 -> V=1.0, theta=0.0
% INFO    : Bus 85386	: V=0.9822175, theta=-50.568454 -> V=1.0, theta=0.0
% INFO    : Bus 85387	: V=0.9672935, theta=-53.567096 -> V=1.0, theta=0.0
% INFO    : Bus 85388	: V=0.9969326, theta=-49.118916 -> V=1.0, theta=0.0
% INFO    : Bus 85389	: V=0.9849226, theta=-50.670089 -> V=1.0, theta=0.0
% INFO    : Bus 85390	: V=0.977158, theta=-51.60753 -> V=1.0, theta=0.0
% INFO    : Bus 85391	: V=0.9800358, theta=-51.166039 -> V=1.0, theta=0.0
% INFO    : Bus 85392	: V=0.9678448, theta=-52.676629 -> V=1.0, theta=0.0
% INFO    : Bus 85393	: V=0.9661075, theta=-52.985026 -> V=1.0, theta=0.0
% INFO    : Bus 85394	: V=0.9664985, theta=-53.81604 -> V=1.0, theta=0.0
% INFO    : Bus 85395	: V=0.9641804, theta=-53.438851 -> V=1.0, theta=0.0
% INFO    : Bus 85396	: V=0.9535674, theta=-55.279141 -> V=1.0, theta=0.0
% INFO    : Bus 85397	: V=0.9691051, theta=-52.476101 -> V=1.0, theta=0.0
% INFO    : Bus 85398	: V=0.9809406, theta=-50.921076 -> V=1.0, theta=0.0
% INFO    : Bus 85399	: V=0.9778116, theta=-51.416177 -> V=1.0, theta=0.0
% INFO    : Bus 85400	: V=0.9586687, theta=-54.383239 -> V=1.0, theta=0.0
% INFO    : Bus 85401	: V=0.9633722, theta=-53.354298 -> V=1.0, theta=0.0
% INFO    : Bus 85402	: V=0.961374, theta=-54.19194 -> V=1.0, theta=0.0
% INFO    : Bus 85403	: V=0.9562339, theta=-54.600289 -> V=1.0, theta=0.0
% INFO    : Bus 85404	: V=0.960646, theta=-53.839247 -> V=1.0, theta=0.0
% INFO    : Bus 85405	: V=0.9753663, theta=-51.459174 -> V=1.0, theta=0.0
% INFO    : Bus 85406	: V=0.9860252, theta=-50.530175 -> V=1.0, theta=0.0
% INFO    : Bus 85407	: V=0.9878995, theta=-50.413051 -> V=1.0, theta=0.0
% INFO    : Bus 85408	: V=0.9771054, theta=-51.432634 -> V=1.0, theta=0.0
% INFO    : Bus 85409	: V=0.9975545, theta=-48.515317 -> V=1.0, theta=0.0
% INFO    : Bus 85410	: V=0.9943802, theta=-49.272132 -> V=1.0, theta=0.0
% INFO    : Bus 85411	: V=0.9660686, theta=-53.884718 -> V=1.0, theta=0.0
% INFO    : Bus 85412	: V=0.9757647, theta=-51.397525 -> V=1.0, theta=0.0
% INFO    : Bus 85413	: V=0.9764858, theta=-51.21185 -> V=1.0, theta=0.0
% INFO    : Bus 85414	: V=0.9876098, theta=-50.21043 -> V=1.0, theta=0.0
% INFO    : Bus 85415	: V=0.984279, theta=-50.24826 -> V=1.0, theta=0.0
% INFO    : Bus 85416	: V=0.9721493, theta=-51.036348 -> V=1.0, theta=0.0
% INFO    : Bus 85417	: V=0.9660738, theta=-51.491226 -> V=1.0, theta=0.0
% INFO    : Bus 85418	: V=0.9644745, theta=-53.984745 -> V=1.0, theta=0.0
% INFO    : Bus 85419	: V=0.9646684, theta=-53.724928 -> V=1.0, theta=0.0
% INFO    : Bus 85420	: V=0.9588698, theta=-54.896498 -> V=1.0, theta=0.0
% INFO    : Bus 85421	: V=0.9538185, theta=-55.852117 -> V=1.0, theta=0.0
% INFO    : Bus 85422	: V=0.9759952, theta=-51.046285 -> V=1.0, theta=0.0
% INFO    : Bus 85423	: V=0.9667274, theta=-52.247189 -> V=1.0, theta=0.0
% INFO    : Bus 85424	: V=0.9655676, theta=-51.748393 -> V=1.0, theta=0.0
% INFO    : Bus 85425	: V=0.9663125, theta=-51.738302 -> V=1.0, theta=0.0
% INFO    : Bus 85426	: V=0.9717101, theta=-51.313028 -> V=1.0, theta=0.0
% INFO    : Bus 85427	: V=0.9704825, theta=-51.394334 -> V=1.0, theta=0.0
% INFO    : Bus 85428	: V=0.9712886, theta=-51.304445 -> V=1.0, theta=0.0
% INFO    : Bus 85429	: V=0.9736799, theta=-51.124532 -> V=1.0, theta=0.0
% INFO    : Bus 85430	: V=0.990126, theta=-49.55162 -> V=1.0, theta=0.0
% INFO    : Bus 85431	: V=0.9778577, theta=-50.830786 -> V=1.0, theta=0.0
% INFO    : Bus 85432	: V=0.9791229, theta=-50.672126 -> V=1.0, theta=0.0
% INFO    : Bus 85433	: V=0.97849, theta=-50.812385 -> V=1.0, theta=0.0
% INFO    : Bus 85434	: V=0.9803456, theta=-50.572085 -> V=1.0, theta=0.0
% INFO    : Bus 85435	: V=0.9694852, theta=-51.400104 -> V=1.0, theta=0.0
% INFO    : Bus 85436	: V=0.96893, theta=-51.456465 -> V=1.0, theta=0.0
% INFO    : Bus 85437	: V=0.9735588, theta=-51.380157 -> V=1.0, theta=0.0
% INFO    : Bus 85438	: V=0.9680529, theta=-51.459097 -> V=1.0, theta=0.0
% INFO    : Bus 85439	: V=0.967732, theta=-51.616762 -> V=1.0, theta=0.0
% INFO    : Bus 85440	: V=0.9823676, theta=-50.302818 -> V=1.0, theta=0.0
% INFO    : Bus 85441	: V=0.9790603, theta=-50.580727 -> V=1.0, theta=0.0
% INFO    : Bus 85442	: V=0.9737352, theta=-51.124631 -> V=1.0, theta=0.0
% INFO    : Bus 85443	: V=0.9829477, theta=-49.906978 -> V=1.0, theta=0.0
% INFO    : Bus 85444	: V=0.9755315, theta=-51.435249 -> V=1.0, theta=0.0
% INFO    : Bus 85445	: V=0.993651, theta=-52.786495 -> V=1.0, theta=0.0
% INFO    : Bus 85446	: V=0.9614133, theta=-51.59783 -> V=1.0, theta=0.0
% INFO    : Bus 85447	: V=0.9624542, theta=-51.564319 -> V=1.0, theta=0.0
% INFO    : Bus 85448	: V=0.9674098, theta=-51.187454 -> V=1.0, theta=0.0
% INFO    : Bus 85449	: V=0.9760799, theta=-50.442615 -> V=1.0, theta=0.0
% INFO    : Bus 85450	: V=0.9836987, theta=-49.19925 -> V=1.0, theta=0.0
% INFO    : Bus 85451	: V=0.9771314, theta=-50.429466 -> V=1.0, theta=0.0
% INFO    : Bus 85452	: V=0.9992965, theta=-46.877707 -> V=1.0, theta=0.0
% INFO    : Bus 85453	: V=0.9647623, theta=-51.284343 -> V=1.0, theta=0.0
% INFO    : Bus 85454	: V=0.9756979, theta=-50.644187 -> V=1.0, theta=0.0
% INFO    : Bus 85455	: V=0.9916202, theta=-48.111947 -> V=1.0, theta=0.0
% INFO    : Bus 85456	: V=0.9842201, theta=-49.518447 -> V=1.0, theta=0.0
% INFO    : Bus 85457	: V=0.9808911, theta=-49.811688 -> V=1.0, theta=0.0
% INFO    : Bus 85458	: V=0.9831711, theta=-49.591784 -> V=1.0, theta=0.0
% INFO    : Bus 85459	: V=0.9941487, theta=-47.946296 -> V=1.0, theta=0.0
% INFO    : Bus 85460	: V=1.0002895, theta=-47.353884 -> V=1.0, theta=0.0
% INFO    : Bus 85461	: V=0.9665497, theta=-51.549233 -> V=1.0, theta=0.0
% INFO    : Bus 85462	: V=0.979312, theta=-50.013126 -> V=1.0, theta=0.0
% INFO    : Bus 85463	: V=0.9666176, theta=-50.547382 -> V=1.0, theta=0.0
% INFO    : Bus 85464	: V=0.9710932, theta=-49.688147 -> V=1.0, theta=0.0
% INFO    : Bus 85465	: V=0.9589254, theta=-51.356223 -> V=1.0, theta=0.0
% INFO    : Bus 85466	: V=0.9581032, theta=-52.639 -> V=1.0, theta=0.0
% INFO    : Bus 85467	: V=0.9608752, theta=-52.363004 -> V=1.0, theta=0.0
% INFO    : Bus 85468	: V=0.9683984, theta=-51.139857 -> V=1.0, theta=0.0
% INFO    : Bus 85469	: V=0.9681784, theta=-51.273229 -> V=1.0, theta=0.0
% INFO    : Bus 85470	: V=0.9587402, theta=-52.899782 -> V=1.0, theta=0.0
% INFO    : Bus 85471	: V=0.9572374, theta=-52.21664 -> V=1.0, theta=0.0
% INFO    : Bus 85472	: V=0.9691673, theta=-51.352173 -> V=1.0, theta=0.0
% INFO    : Bus 85473	: V=0.965345, theta=-51.533018 -> V=1.0, theta=0.0
% INFO    : Bus 85474	: V=0.9566117, theta=-52.475797 -> V=1.0, theta=0.0
% INFO    : Bus 85475	: V=0.9709213, theta=-51.137714 -> V=1.0, theta=0.0
% INFO    : Bus 85476	: V=0.9713166, theta=-51.193676 -> V=1.0, theta=0.0
% INFO    : Bus 85477	: V=0.9572816, theta=-52.424891 -> V=1.0, theta=0.0
% INFO    : Bus 85478	: V=0.959287, theta=-52.224957 -> V=1.0, theta=0.0
% INFO    : Bus 85479	: V=0.958171, theta=-52.356567 -> V=1.0, theta=0.0
% INFO    : Bus 85480	: V=0.9599317, theta=-52.054286 -> V=1.0, theta=0.0
% INFO    : Bus 85481	: V=0.9596327, theta=-52.090355 -> V=1.0, theta=0.0
% INFO    : Bus 85482	: V=0.9573935, theta=-52.231369 -> V=1.0, theta=0.0
% INFO    : Bus 85483	: V=0.9593898, theta=-52.454146 -> V=1.0, theta=0.0
% INFO    : Bus 85484	: V=0.9664766, theta=-51.655444 -> V=1.0, theta=0.0
% INFO    : Bus 85485	: V=0.9835475, theta=-50.187361 -> V=1.0, theta=0.0
% INFO    : Bus 85486	: V=0.9888596, theta=-33.716959 -> V=1.0, theta=0.0
% INFO    : Bus 85487	: V=0.9881971, theta=-33.95376 -> V=1.0, theta=0.0
% INFO    : Bus 85488	: V=0.9722202, theta=-35.309774 -> V=1.0, theta=0.0
% INFO    : Bus 85489	: V=0.9767151, theta=-34.961256 -> V=1.0, theta=0.0
% INFO    : Bus 85490	: V=0.9684146, theta=-35.461456 -> V=1.0, theta=0.0
% INFO    : Bus 85491	: V=0.9722838, theta=-35.558978 -> V=1.0, theta=0.0
% INFO    : Bus 85492	: V=0.9705045, theta=-35.43328 -> V=1.0, theta=0.0
% INFO    : Bus 85493	: V=0.9713005, theta=-35.389895 -> V=1.0, theta=0.0
% INFO    : Bus 85494	: V=0.9642803, theta=-36.74326 -> V=1.0, theta=0.0
% INFO    : Bus 85495	: V=0.9697206, theta=-36.180012 -> V=1.0, theta=0.0
% INFO    : Bus 85496	: V=0.9682726, theta=-35.680663 -> V=1.0, theta=0.0
% INFO    : Bus 85497	: V=0.9898309, theta=-33.113886 -> V=1.0, theta=0.0
% INFO    : Bus 85498	: V=0.9776681, theta=-44.472059 -> V=1.0, theta=0.0
% INFO    : Bus 85499	: V=0.9734204, theta=-45.069435 -> V=1.0, theta=0.0
% INFO    : Bus 85500	: V=0.9783104, theta=-44.245402 -> V=1.0, theta=0.0
% INFO    : Bus 85501	: V=0.9756975, theta=-44.629947 -> V=1.0, theta=0.0
% INFO    : Bus 85502	: V=0.9748647, theta=-44.779933 -> V=1.0, theta=0.0
% INFO    : Bus 85503	: V=0.9738532, theta=-44.870976 -> V=1.0, theta=0.0
% INFO    : Bus 85504	: V=0.9741053, theta=-44.959676 -> V=1.0, theta=0.0
% INFO    : Bus 85505	: V=0.9702878, theta=-45.37743 -> V=1.0, theta=0.0
% INFO    : Bus 85506	: V=0.9679139, theta=-45.728338 -> V=1.0, theta=0.0
% INFO    : Bus 85507	: V=0.9706147, theta=-45.439169 -> V=1.0, theta=0.0
% INFO    : Bus 85508	: V=0.9678168, theta=-45.866781 -> V=1.0, theta=0.0
% INFO    : Bus 85509	: V=0.9705134, theta=-45.498626 -> V=1.0, theta=0.0
% INFO    : Bus 85510	: V=0.966645, theta=-46.347873 -> V=1.0, theta=0.0
% INFO    : Bus 85511	: V=0.9697927, theta=-45.646012 -> V=1.0, theta=0.0
% INFO    : Bus 85512	: V=0.9731645, theta=-45.313885 -> V=1.0, theta=0.0
% INFO    : Bus 85513	: V=0.9707177, theta=-45.669378 -> V=1.0, theta=0.0
% INFO    : Bus 85514	: V=0.9744315, theta=-45.239894 -> V=1.0, theta=0.0
% INFO    : Bus 85515	: V=0.9733878, theta=-45.453853 -> V=1.0, theta=0.0
% INFO    : Bus 85516	: V=0.9690957, theta=-45.503093 -> V=1.0, theta=0.0
% INFO    : Bus 85517	: V=0.9659198, theta=-46.140715 -> V=1.0, theta=0.0
% INFO    : Bus 85518	: V=0.9700396, theta=-45.758907 -> V=1.0, theta=0.0
% INFO    : Bus 85519	: V=0.96541, theta=-46.425394 -> V=1.0, theta=0.0
% INFO    : Bus 85520	: V=0.9627003, theta=-46.581015 -> V=1.0, theta=0.0
% INFO    : Bus 85521	: V=0.9634453, theta=-46.525318 -> V=1.0, theta=0.0
% INFO    : Bus 85522	: V=0.9677067, theta=-45.72748 -> V=1.0, theta=0.0
% INFO    : Bus 85523	: V=0.9709264, theta=-45.389021 -> V=1.0, theta=0.0
% INFO    : Bus 85524	: V=0.9735037, theta=-44.92642 -> V=1.0, theta=0.0
% INFO    : Bus 85525	: V=0.9730782, theta=-45.147619 -> V=1.0, theta=0.0
% INFO    : Bus 85526	: V=0.9737742, theta=-45.374759 -> V=1.0, theta=0.0
% INFO    : Bus 85527	: V=0.9716407, theta=-45.590625 -> V=1.0, theta=0.0
% INFO    : Bus 85528	: V=0.9702095, theta=-46.089768 -> V=1.0, theta=0.0
% INFO    : Bus 85529	: V=0.9664749, theta=-46.37393 -> V=1.0, theta=0.0
% INFO    : Bus 85530	: V=0.968067, theta=-46.23365 -> V=1.0, theta=0.0
% INFO    : Bus 85531	: V=0.9735397, theta=-45.712006 -> V=1.0, theta=0.0
% INFO    : Bus 85532	: V=0.9791146, theta=-44.269822 -> V=1.0, theta=0.0
% INFO    : Bus 85533	: V=0.9734078, theta=-45.775756 -> V=1.0, theta=0.0
% INFO    : Bus 85534	: V=0.9702802, theta=-45.751417 -> V=1.0, theta=0.0
% INFO    : Bus 85535	: V=0.9703673, theta=-45.732319 -> V=1.0, theta=0.0
% INFO    : Bus 85536	: V=0.9700122, theta=-45.781989 -> V=1.0, theta=0.0
% INFO    : Bus 85537	: V=0.9674982, theta=-46.303015 -> V=1.0, theta=0.0
% INFO    : Bus 85538	: V=0.9669761, theta=-46.295705 -> V=1.0, theta=0.0
% INFO    : Bus 85539	: V=0.9689971, theta=-46.057073 -> V=1.0, theta=0.0
% INFO    : Bus 85540	: V=0.9695734, theta=-46.235067 -> V=1.0, theta=0.0
% INFO    : Bus 85541	: V=0.9742911, theta=-45.976119 -> V=1.0, theta=0.0
% INFO    : Bus 85542	: V=0.9707251, theta=-45.784006 -> V=1.0, theta=0.0
% INFO    : Bus 85543	: V=0.9787629, theta=-45.410798 -> V=1.0, theta=0.0
% INFO    : Bus 85544	: V=0.9839103, theta=-45.194451 -> V=1.0, theta=0.0
% INFO    : Bus 85545	: V=0.9895863, theta=-44.784616 -> V=1.0, theta=0.0
% INFO    : Bus 85546	: V=0.9831233, theta=-44.466423 -> V=1.0, theta=0.0
% INFO    : Bus 85547	: V=0.9749869, theta=-45.154871 -> V=1.0, theta=0.0
% INFO    : Bus 85548	: V=0.9748261, theta=-44.335036 -> V=1.0, theta=0.0
% INFO    : Bus 85549	: V=0.9765717, theta=-44.504819 -> V=1.0, theta=0.0
% INFO    : Bus 85550	: V=0.9699836, theta=-45.749423 -> V=1.0, theta=0.0
% INFO    : Bus 85551	: V=0.9706056, theta=-45.67313 -> V=1.0, theta=0.0
% INFO    : Bus 85552	: V=0.9700628, theta=-45.541098 -> V=1.0, theta=0.0
% INFO    : Bus 85553	: V=0.9692824, theta=-45.661462 -> V=1.0, theta=0.0
% INFO    : Bus 85554	: V=0.9692846, theta=-45.829394 -> V=1.0, theta=0.0
% INFO    : Bus 85555	: V=0.9666467, theta=-46.014177 -> V=1.0, theta=0.0
% INFO    : Bus 85556	: V=0.9652262, theta=-46.226079 -> V=1.0, theta=0.0
% INFO    : Bus 85557	: V=0.9641051, theta=-46.255335 -> V=1.0, theta=0.0
% INFO    : Bus 85558	: V=0.9745919, theta=-45.395184 -> V=1.0, theta=0.0
% INFO    : Bus 85559	: V=0.9790127, theta=-44.847264 -> V=1.0, theta=0.0
% INFO    : Bus 85560	: V=0.9735456, theta=-45.378229 -> V=1.0, theta=0.0
% INFO    : Bus 85561	: V=0.9858387, theta=-43.236996 -> V=1.0, theta=0.0
% INFO    : Bus 85562	: V=0.9786608, theta=-44.699952 -> V=1.0, theta=0.0
% INFO    : Bus 85563	: V=0.9814942, theta=-43.911737 -> V=1.0, theta=0.0
% INFO    : Bus 85564	: V=0.9811655, theta=-44.233836 -> V=1.0, theta=0.0
% INFO    : Bus 85565	: V=0.978053, theta=-44.753105 -> V=1.0, theta=0.0
% INFO    : Bus 85566	: V=0.9738107, theta=-45.133983 -> V=1.0, theta=0.0
% INFO    : Bus 85567	: V=0.9740818, theta=-44.890533 -> V=1.0, theta=0.0
% INFO    : Bus 85568	: V=0.9783016, theta=-44.419934 -> V=1.0, theta=0.0
% INFO    : Bus 85569	: V=0.9791506, theta=-44.289273 -> V=1.0, theta=0.0
% INFO    : Bus 85570	: V=0.9792506, theta=-44.244355 -> V=1.0, theta=0.0
% INFO    : Bus 85571	: V=0.9792314, theta=-44.248419 -> V=1.0, theta=0.0
% INFO    : Bus 85572	: V=0.9735234, theta=-44.993369 -> V=1.0, theta=0.0
% INFO    : Bus 85573	: V=0.9770027, theta=-44.675124 -> V=1.0, theta=0.0
% INFO    : Bus 85574	: V=0.9782163, theta=-44.52682 -> V=1.0, theta=0.0
% INFO    : Bus 85575	: V=0.9833307, theta=-43.165565 -> V=1.0, theta=0.0
% INFO    : Bus 85576	: V=0.9842617, theta=-43.148557 -> V=1.0, theta=0.0
% INFO    : Bus 85577	: V=0.9797878, theta=-42.958535 -> V=1.0, theta=0.0
% INFO    : Bus 85578	: V=0.984816, theta=-42.853027 -> V=1.0, theta=0.0
% INFO    : Bus 85579	: V=0.9884485, theta=-42.50892 -> V=1.0, theta=0.0
% INFO    : Bus 85580	: V=0.9937694, theta=-41.891917 -> V=1.0, theta=0.0
% INFO    : Bus 85581	: V=0.9942259, theta=-41.943294 -> V=1.0, theta=0.0
% INFO    : Bus 85582	: V=0.9875418, theta=-43.255077 -> V=1.0, theta=0.0
% INFO    : Bus 85583	: V=0.9842289, theta=-43.794992 -> V=1.0, theta=0.0
% INFO    : Bus 85584	: V=0.985152, theta=-43.507531 -> V=1.0, theta=0.0
% INFO    : Bus 85585	: V=0.9803378, theta=-44.4454 -> V=1.0, theta=0.0
% INFO    : Bus 85586	: V=0.9832916, theta=-43.671433 -> V=1.0, theta=0.0
% INFO    : Bus 85587	: V=0.9816591, theta=-44.160861 -> V=1.0, theta=0.0
% INFO    : Bus 85588	: V=0.9812175, theta=-43.81994 -> V=1.0, theta=0.0
% INFO    : Bus 85589	: V=0.981382, theta=-44.16222 -> V=1.0, theta=0.0
% INFO    : Bus 85590	: V=0.9800907, theta=-44.663261 -> V=1.0, theta=0.0
% INFO    : Bus 85591	: V=0.97714, theta=-44.877901 -> V=1.0, theta=0.0
% INFO    : Bus 85592	: V=0.9807904, theta=-44.199074 -> V=1.0, theta=0.0
% INFO    : Bus 85593	: V=0.9690629, theta=-45.608759 -> V=1.0, theta=0.0
% INFO    : Bus 85594	: V=0.9702474, theta=-45.494757 -> V=1.0, theta=0.0
% INFO    : Bus 85595	: V=0.9746907, theta=-44.736714 -> V=1.0, theta=0.0
% INFO    : Bus 85596	: V=0.9761398, theta=-44.532465 -> V=1.0, theta=0.0
% INFO    : Bus 85597	: V=0.981643, theta=-43.447748 -> V=1.0, theta=0.0
% INFO    : Bus 85598	: V=0.9773615, theta=-44.53983 -> V=1.0, theta=0.0
% INFO    : Bus 85599	: V=0.9945442, theta=-41.336465 -> V=1.0, theta=0.0
% INFO    : Bus 85600	: V=0.9856629, theta=-42.746185 -> V=1.0, theta=0.0
% INFO    : Bus 85601	: V=0.9809752, theta=-43.658512 -> V=1.0, theta=0.0
% INFO    : Bus 85602	: V=0.9809602, theta=-43.643622 -> V=1.0, theta=0.0
% INFO    : Bus 85603	: V=0.9811291, theta=-44.037156 -> V=1.0, theta=0.0
% INFO    : Bus 85604	: V=0.9808678, theta=-44.095867 -> V=1.0, theta=0.0
% INFO    : Bus 85605	: V=1.0004603, theta=-40.554697 -> V=1.0, theta=0.0
% INFO    : Bus 85606	: V=0.9976961, theta=-40.971666 -> V=1.0, theta=0.0
% INFO    : Bus 85607	: V=0.9779502, theta=-44.107075 -> V=1.0, theta=0.0
% INFO    : Bus 85608	: V=0.9737584, theta=-45.082335 -> V=1.0, theta=0.0
% INFO    : Bus 85609	: V=0.9977588, theta=-41.665822 -> V=1.0, theta=0.0
% INFO    : Bus 85610	: V=0.9844867, theta=-43.394081 -> V=1.0, theta=0.0
% INFO    : Bus 85611	: V=1.0052878, theta=-44.633165 -> V=1.0, theta=0.0
% INFO    : Bus 85612	: V=1.0008584, theta=-44.740612 -> V=1.0, theta=0.0
% INFO    : Bus 85613	: V=0.9962953, theta=-47.426449 -> V=1.0, theta=0.0
% INFO    : Bus 85614	: V=1.0091766, theta=-48.855608 -> V=1.0, theta=0.0
% INFO    : Bus 85615	: V=1.0068642, theta=-49.127009 -> V=1.0, theta=0.0
% INFO    : Bus 85616	: V=1.0055156, theta=-49.334765 -> V=1.0, theta=0.0
% INFO    : Bus 85617	: V=0.9783345, theta=-44.476801 -> V=1.0, theta=0.0
% INFO    : Bus 85618	: V=0.9712616, theta=-44.524101 -> V=1.0, theta=0.0
% INFO    : Bus 85619	: V=0.9792083, theta=-44.202108 -> V=1.0, theta=0.0
% INFO    : Bus 85620	: V=0.9632966, theta=-45.312689 -> V=1.0, theta=0.0
% INFO    : Bus 85621	: V=0.978844, theta=-44.064035 -> V=1.0, theta=0.0
% INFO    : Bus 85622	: V=1.0034652, theta=-47.223685 -> V=1.0, theta=0.0
% INFO    : Bus 85623	: V=0.996144, theta=-48.729336 -> V=1.0, theta=0.0
% INFO    : Bus 85624	: V=0.9941239, theta=-49.076467 -> V=1.0, theta=0.0
% INFO    : Bus 85625	: V=0.9859349, theta=-50.455109 -> V=1.0, theta=0.0
% INFO    : Bus 85626	: V=0.9934329, theta=-50.047012 -> V=1.0, theta=0.0
% INFO    : Bus 85627	: V=0.965846, theta=-53.794809 -> V=1.0, theta=0.0
% INFO    : Bus 85628	: V=0.9771571, theta=-52.02536 -> V=1.0, theta=0.0
% INFO    : Bus 85629	: V=0.9793351, theta=-51.637101 -> V=1.0, theta=0.0
% INFO    : Bus 85630	: V=0.9609859, theta=-54.440608 -> V=1.0, theta=0.0
% INFO    : Bus 85631	: V=0.9590632, theta=-54.544395 -> V=1.0, theta=0.0
% INFO    : Bus 85632	: V=0.9626545, theta=-54.042594 -> V=1.0, theta=0.0
% INFO    : Bus 85633	: V=0.9568944, theta=-55.575501 -> V=1.0, theta=0.0
% INFO    : Bus 85634	: V=0.9594609, theta=-54.379418 -> V=1.0, theta=0.0
% INFO    : Bus 85635	: V=0.957499, theta=-55.65603 -> V=1.0, theta=0.0
% INFO    : Bus 85636	: V=0.9694419, theta=-53.07763 -> V=1.0, theta=0.0
% INFO    : Bus 85637	: V=0.978516, theta=-37.907329 -> V=1.0, theta=0.0
% INFO    : Bus 85638	: V=0.987887, theta=-37.188111 -> V=1.0, theta=0.0
% INFO    : Bus 85639	: V=0.9860358, theta=-37.084071 -> V=1.0, theta=0.0
% INFO    : Bus 85640	: V=0.9814867, theta=-35.54492 -> V=1.0, theta=0.0
% INFO    : Bus 85641	: V=0.9805765, theta=-36.124612 -> V=1.0, theta=0.0
% INFO    : Bus 85642	: V=0.9634504, theta=-48.382058 -> V=1.0, theta=0.0
% INFO    : Bus 85643	: V=0.9644183, theta=-48.255819 -> V=1.0, theta=0.0
% INFO    : Bus 85644	: V=0.967785, theta=-47.854306 -> V=1.0, theta=0.0
% INFO    : Bus 85645	: V=0.9652624, theta=-47.793877 -> V=1.0, theta=0.0
% INFO    : Bus 85646	: V=0.9552036, theta=-48.350361 -> V=1.0, theta=0.0
% INFO    : Bus 85647	: V=0.957179, theta=-48.312414 -> V=1.0, theta=0.0
% INFO    : Bus 85648	: V=0.9590899, theta=-48.200411 -> V=1.0, theta=0.0
% INFO    : Bus 85649	: V=0.9593456, theta=-48.18202 -> V=1.0, theta=0.0
% INFO    : Bus 85650	: V=0.9571453, theta=-48.285237 -> V=1.0, theta=0.0
% INFO    : Bus 85651	: V=0.9660212, theta=-47.161865 -> V=1.0, theta=0.0
% INFO    : Bus 85652	: V=0.9653606, theta=-47.615908 -> V=1.0, theta=0.0
% INFO    : Bus 85653	: V=0.9624824, theta=-47.748865 -> V=1.0, theta=0.0
% INFO    : Bus 85654	: V=0.9592276, theta=-47.999848 -> V=1.0, theta=0.0
% INFO    : Bus 85655	: V=0.956803, theta=-48.139418 -> V=1.0, theta=0.0
% INFO    : Bus 85656	: V=0.9592787, theta=-47.821153 -> V=1.0, theta=0.0
% INFO    : Bus 85657	: V=0.9565129, theta=-48.351896 -> V=1.0, theta=0.0
% INFO    : Bus 85658	: V=0.9587238, theta=-48.40424 -> V=1.0, theta=0.0
% INFO    : Bus 85659	: V=0.9617692, theta=-48.262863 -> V=1.0, theta=0.0
% INFO    : Bus 85660	: V=0.9636652, theta=-47.992489 -> V=1.0, theta=0.0
% INFO    : Bus 85661	: V=0.9592266, theta=-48.944032 -> V=1.0, theta=0.0
% INFO    : Bus 85662	: V=0.9587948, theta=-48.954228 -> V=1.0, theta=0.0
% INFO    : Bus 85663	: V=0.9694604, theta=-48.178528 -> V=1.0, theta=0.0
% INFO    : Bus 85664	: V=0.9714681, theta=-47.580042 -> V=1.0, theta=0.0
% INFO    : Bus 85665	: V=0.9696415, theta=-48.090355 -> V=1.0, theta=0.0
% INFO    : Bus 85666	: V=0.9633787, theta=-48.364601 -> V=1.0, theta=0.0
% INFO    : Bus 85667	: V=0.9647717, theta=-48.22992 -> V=1.0, theta=0.0
% INFO    : Bus 85668	: V=0.989483, theta=-45.440593 -> V=1.0, theta=0.0
% INFO    : Bus 85669	: V=0.9774318, theta=-46.943907 -> V=1.0, theta=0.0
% INFO    : Bus 85670	: V=0.9740641, theta=-47.329792 -> V=1.0, theta=0.0
% INFO    : Bus 85671	: V=0.9596592, theta=-48.950359 -> V=1.0, theta=0.0
% INFO    : Bus 85672	: V=0.9653535, theta=-47.854126 -> V=1.0, theta=0.0
% INFO    : Bus 85673	: V=0.9605801, theta=-48.137162 -> V=1.0, theta=0.0
% INFO    : Bus 85674	: V=0.955901, theta=-48.274758 -> V=1.0, theta=0.0
% INFO    : Bus 85675	: V=0.9598579, theta=-47.875317 -> V=1.0, theta=0.0
% INFO    : Bus 85676	: V=0.9583954, theta=-48.179838 -> V=1.0, theta=0.0
% INFO    : Bus 85677	: V=0.962961, theta=-47.601742 -> V=1.0, theta=0.0
% INFO    : Bus 85678	: V=0.9631859, theta=-47.601094 -> V=1.0, theta=0.0
% INFO    : Bus 85679	: V=0.9585936, theta=-48.103221 -> V=1.0, theta=0.0
% INFO    : Bus 85680	: V=0.9591655, theta=-47.98415 -> V=1.0, theta=0.0
% INFO    : Bus 85681	: V=0.9577008, theta=-48.25227 -> V=1.0, theta=0.0
% INFO    : Bus 85682	: V=0.9515911, theta=-48.432871 -> V=1.0, theta=0.0
% INFO    : Bus 85683	: V=0.9555166, theta=-48.152161 -> V=1.0, theta=0.0
% INFO    : Bus 85684	: V=0.9607584, theta=-47.798197 -> V=1.0, theta=0.0
% INFO    : Bus 85685	: V=0.9628552, theta=-47.679723 -> V=1.0, theta=0.0
% INFO    : Bus 85686	: V=0.9656509, theta=-47.181515 -> V=1.0, theta=0.0
% INFO    : Bus 85687	: V=0.9625381, theta=-47.673813 -> V=1.0, theta=0.0
% INFO    : Bus 85688	: V=0.9768869, theta=-46.001362 -> V=1.0, theta=0.0
% INFO    : Bus 85689	: V=0.9563812, theta=-48.313481 -> V=1.0, theta=0.0
% INFO    : Bus 85690	: V=0.9700703, theta=-47.02859 -> V=1.0, theta=0.0
% INFO    : Bus 85691	: V=0.9711045, theta=-46.90625 -> V=1.0, theta=0.0
% INFO    : Bus 85692	: V=0.9733812, theta=-46.894827 -> V=1.0, theta=0.0
% INFO    : Bus 85693	: V=0.9721235, theta=-46.864407 -> V=1.0, theta=0.0
% INFO    : Bus 85694	: V=0.9685298, theta=-46.961715 -> V=1.0, theta=0.0
% INFO    : Bus 85695	: V=0.9572841, theta=-47.978511 -> V=1.0, theta=0.0
% INFO    : Bus 85696	: V=0.9642501, theta=-47.450092 -> V=1.0, theta=0.0
% INFO    : Bus 85697	: V=0.9732461, theta=-46.741288 -> V=1.0, theta=0.0
% INFO    : Bus 85698	: V=0.9760422, theta=-46.583487 -> V=1.0, theta=0.0
% INFO    : Bus 85699	: V=0.9717663, theta=-47.208913 -> V=1.0, theta=0.0
% INFO    : Bus 85700	: V=0.9765415, theta=-46.711368 -> V=1.0, theta=0.0
% INFO    : Bus 85701	: V=0.9655492, theta=-47.770162 -> V=1.0, theta=0.0
% INFO    : Bus 85702	: V=0.9671062, theta=-47.663636 -> V=1.0, theta=0.0
% INFO    : Bus 85703	: V=0.9732741, theta=-47.110535 -> V=1.0, theta=0.0
% INFO    : Bus 85704	: V=0.9857166, theta=-45.845877 -> V=1.0, theta=0.0
% INFO    : Bus 85705	: V=0.982918, theta=-46.260319 -> V=1.0, theta=0.0
% INFO    : Bus 85706	: V=0.9591945, theta=-48.540243 -> V=1.0, theta=0.0
% INFO    : Bus 85707	: V=0.9735131, theta=-47.37871 -> V=1.0, theta=0.0
% INFO    : Bus 85708	: V=0.9788441, theta=-47.114999 -> V=1.0, theta=0.0
% INFO    : Bus 85709	: V=0.9696693, theta=-47.780863 -> V=1.0, theta=0.0
% INFO    : Bus 85710	: V=0.9676392, theta=-47.682464 -> V=1.0, theta=0.0
% INFO    : Bus 85711	: V=0.9698812, theta=-47.761559 -> V=1.0, theta=0.0
% INFO    : Bus 85712	: V=0.9757394, theta=-47.49648 -> V=1.0, theta=0.0
% INFO    : Bus 85713	: V=0.9747215, theta=-47.586515 -> V=1.0, theta=0.0
% INFO    : Bus 85714	: V=0.9660125, theta=-49.640259 -> V=1.0, theta=0.0
% INFO    : Bus 85715	: V=0.9603847, theta=-50.58332 -> V=1.0, theta=0.0
% INFO    : Bus 85716	: V=0.9641957, theta=-49.401839 -> V=1.0, theta=0.0
% INFO    : Bus 85717	: V=0.9640416, theta=-47.760132 -> V=1.0, theta=0.0
% INFO    : Bus 85718	: V=0.9735713, theta=-48.574559 -> V=1.0, theta=0.0
% INFO    : Bus 85719	: V=0.9538417, theta=-49.608512 -> V=1.0, theta=0.0
% INFO    : Bus 85720	: V=0.9615714, theta=-48.544423 -> V=1.0, theta=0.0
% INFO    : Bus 85721	: V=0.9708766, theta=-47.633747 -> V=1.0, theta=0.0
% INFO    : Bus 85722	: V=0.9845927, theta=-46.415363 -> V=1.0, theta=0.0
% INFO    : Bus 85723	: V=0.9761927, theta=-47.208862 -> V=1.0, theta=0.0
% INFO    : Bus 85724	: V=0.9701354, theta=-47.97019 -> V=1.0, theta=0.0
% INFO    : Bus 85725	: V=0.9653343, theta=-49.051263 -> V=1.0, theta=0.0
% INFO    : Bus 85726	: V=0.9706114, theta=-47.45854 -> V=1.0, theta=0.0
% INFO    : Bus 85727	: V=0.966618, theta=-47.89792 -> V=1.0, theta=0.0
% INFO    : Bus 85728	: V=0.9527822, theta=-48.504887 -> V=1.0, theta=0.0
% INFO    : Bus 85729	: V=0.9716779, theta=-47.209089 -> V=1.0, theta=0.0
% INFO    : Bus 85730	: V=0.968288, theta=-47.695955 -> V=1.0, theta=0.0
% INFO    : Bus 85731	: V=0.9574173, theta=-48.317197 -> V=1.0, theta=0.0
% INFO    : Bus 85732	: V=0.958346, theta=-48.249915 -> V=1.0, theta=0.0
% INFO    : Bus 85733	: V=0.9823308, theta=-47.678544 -> V=1.0, theta=0.0
% INFO    : Bus 85734	: V=0.9728657, theta=-47.769871 -> V=1.0, theta=0.0
% INFO    : Bus 85735	: V=0.9712821, theta=-47.880893 -> V=1.0, theta=0.0
% INFO    : Bus 85736	: V=0.9671882, theta=-48.165847 -> V=1.0, theta=0.0
% INFO    : Bus 85737	: V=0.9747559, theta=-47.356737 -> V=1.0, theta=0.0
% INFO    : Bus 85738	: V=0.9685045, theta=-48.111763 -> V=1.0, theta=0.0
% INFO    : Bus 85739	: V=0.9848655, theta=-46.517386 -> V=1.0, theta=0.0
% INFO    : Bus 85740	: V=0.9831112, theta=-46.659299 -> V=1.0, theta=0.0
% INFO    : Bus 85741	: V=0.9812932, theta=-46.749965 -> V=1.0, theta=0.0
% INFO    : Bus 85742	: V=0.9805502, theta=-46.780137 -> V=1.0, theta=0.0
% INFO    : Bus 85743	: V=0.9820165, theta=-46.515766 -> V=1.0, theta=0.0
% INFO    : Bus 85744	: V=0.9858088, theta=-45.848411 -> V=1.0, theta=0.0
% INFO    : Bus 85745	: V=0.9824898, theta=-46.352359 -> V=1.0, theta=0.0
% INFO    : Bus 85746	: V=0.9847215, theta=-46.344586 -> V=1.0, theta=0.0
% INFO    : Bus 85747	: V=0.9830032, theta=-46.289628 -> V=1.0, theta=0.0
% INFO    : Bus 85748	: V=0.9841015, theta=-46.296413 -> V=1.0, theta=0.0
% INFO    : Bus 85749	: V=0.9851012, theta=-46.663134 -> V=1.0, theta=0.0
% INFO    : Bus 85750	: V=0.9663978, theta=-48.122976 -> V=1.0, theta=0.0
% INFO    : Bus 85751	: V=0.9877392, theta=-45.972594 -> V=1.0, theta=0.0
% INFO    : Bus 85752	: V=0.9865843, theta=-46.00828 -> V=1.0, theta=0.0
% INFO    : Bus 85753	: V=0.956625, theta=-39.40891 -> V=1.0, theta=0.0
% INFO    : Bus 85754	: V=0.9721257, theta=-39.301603 -> V=1.0, theta=0.0
% INFO    : Bus 85755	: V=0.9747545, theta=-38.998261 -> V=1.0, theta=0.0
% INFO    : Bus 85756	: V=0.9759423, theta=-38.662458 -> V=1.0, theta=0.0
% INFO    : Bus 85757	: V=0.9851156, theta=-38.16908 -> V=1.0, theta=0.0
% INFO    : Bus 85758	: V=0.982325, theta=-38.503835 -> V=1.0, theta=0.0
% INFO    : Bus 85759	: V=1.0005827, theta=-36.52377 -> V=1.0, theta=0.0
% INFO    : Bus 85760	: V=0.9917353, theta=-37.556391 -> V=1.0, theta=0.0
% INFO    : Bus 85761	: V=0.9870693, theta=-38.04948 -> V=1.0, theta=0.0
% INFO    : Bus 85762	: V=0.9918024, theta=-37.331085 -> V=1.0, theta=0.0
% INFO    : Bus 85763	: V=0.9869587, theta=-38.015622 -> V=1.0, theta=0.0
% INFO    : Bus 85764	: V=0.9842314, theta=-38.233935 -> V=1.0, theta=0.0
% INFO    : Bus 85765	: V=0.9904401, theta=-37.729454 -> V=1.0, theta=0.0
% INFO    : Bus 85766	: V=0.988492, theta=-38.098373 -> V=1.0, theta=0.0
% INFO    : Bus 85767	: V=0.980993, theta=-38.553194 -> V=1.0, theta=0.0
% INFO    : Bus 85768	: V=0.9734092, theta=-38.688488 -> V=1.0, theta=0.0
% INFO    : Bus 85769	: V=0.9836622, theta=-38.317299 -> V=1.0, theta=0.0
% INFO    : Bus 85770	: V=0.9851281, theta=-38.275024 -> V=1.0, theta=0.0
% INFO    : Bus 85771	: V=0.9832448, theta=-38.466373 -> V=1.0, theta=0.0
% INFO    : Bus 85772	: V=0.9710804, theta=-39.15672 -> V=1.0, theta=0.0
% INFO    : Bus 85773	: V=0.9742219, theta=-38.66712 -> V=1.0, theta=0.0
% INFO    : Bus 85774	: V=0.9723269, theta=-38.740506 -> V=1.0, theta=0.0
% INFO    : Bus 85775	: V=0.9755913, theta=-39.081468 -> V=1.0, theta=0.0
% INFO    : Bus 85776	: V=0.974725, theta=-39.830924 -> V=1.0, theta=0.0
% INFO    : Bus 85777	: V=0.9809321, theta=-38.254996 -> V=1.0, theta=0.0
% INFO    : Bus 85778	: V=0.9804113, theta=-38.378842 -> V=1.0, theta=0.0
% INFO    : Bus 85779	: V=0.9731115, theta=-38.732657 -> V=1.0, theta=0.0
% INFO    : Bus 85780	: V=0.9719287, theta=-38.86185 -> V=1.0, theta=0.0
% INFO    : Bus 85781	: V=0.9721452, theta=-38.842629 -> V=1.0, theta=0.0
% INFO    : Bus 85782	: V=0.9703208, theta=-39.056984 -> V=1.0, theta=0.0
% INFO    : Bus 85783	: V=0.9759044, theta=-38.753449 -> V=1.0, theta=0.0
% INFO    : Bus 85784	: V=0.9729995, theta=-39.237445 -> V=1.0, theta=0.0
% INFO    : Bus 85785	: V=0.9773931, theta=-38.588422 -> V=1.0, theta=0.0
% INFO    : Bus 85786	: V=0.9715922, theta=-39.216223 -> V=1.0, theta=0.0
% INFO    : Bus 85787	: V=0.9733291, theta=-38.804593 -> V=1.0, theta=0.0
% INFO    : Bus 85788	: V=0.971412, theta=-39.163958 -> V=1.0, theta=0.0
% INFO    : Bus 85789	: V=0.9700727, theta=-39.30551 -> V=1.0, theta=0.0
% INFO    : Bus 85790	: V=0.9724237, theta=-38.90683 -> V=1.0, theta=0.0
% INFO    : Bus 85791	: V=0.9729827, theta=-38.873084 -> V=1.0, theta=0.0
% INFO    : Bus 85792	: V=0.972444, theta=-39.336671 -> V=1.0, theta=0.0
% INFO    : Bus 85793	: V=0.9723433, theta=-39.512175 -> V=1.0, theta=0.0
% INFO    : Bus 85794	: V=0.9806928, theta=-39.042987 -> V=1.0, theta=0.0
% INFO    : Bus 85795	: V=0.975445, theta=-39.196187 -> V=1.0, theta=0.0
% INFO    : Bus 85796	: V=0.9773187, theta=-39.279298 -> V=1.0, theta=0.0
% INFO    : Bus 85797	: V=0.9720066, theta=-39.846018 -> V=1.0, theta=0.0
% INFO    : Bus 85798	: V=0.9741526, theta=-39.437036 -> V=1.0, theta=0.0
% INFO    : Bus 85799	: V=0.9766326, theta=-39.252082 -> V=1.0, theta=0.0
% INFO    : Bus 85800	: V=0.9720649, theta=-39.875193 -> V=1.0, theta=0.0
% INFO    : Bus 85801	: V=0.9733432, theta=-39.600076 -> V=1.0, theta=0.0
% INFO    : Bus 85802	: V=0.9709831, theta=-39.673501 -> V=1.0, theta=0.0
% INFO    : Bus 85803	: V=0.9707065, theta=-39.667204 -> V=1.0, theta=0.0
% INFO    : Bus 85804	: V=0.9684705, theta=-39.74579 -> V=1.0, theta=0.0
% INFO    : Bus 85805	: V=0.9650132, theta=-40.558254 -> V=1.0, theta=0.0
% INFO    : Bus 85806	: V=0.968738, theta=-39.846474 -> V=1.0, theta=0.0
% INFO    : Bus 85807	: V=0.9662537, theta=-40.781862 -> V=1.0, theta=0.0
% INFO    : Bus 85808	: V=0.9625707, theta=-41.594312 -> V=1.0, theta=0.0
% INFO    : Bus 85809	: V=0.9615129, theta=-41.946555 -> V=1.0, theta=0.0
% INFO    : Bus 85810	: V=0.9689284, theta=-40.344677 -> V=1.0, theta=0.0
% INFO    : Bus 85811	: V=0.9666976, theta=-40.82162 -> V=1.0, theta=0.0
% INFO    : Bus 85812	: V=0.9645098, theta=-40.629928 -> V=1.0, theta=0.0
% INFO    : Bus 85813	: V=0.9630804, theta=-41.71239 -> V=1.0, theta=0.0
% INFO    : Bus 85814	: V=0.9653999, theta=-41.010445 -> V=1.0, theta=0.0
% INFO    : Bus 85815	: V=0.9672432, theta=-40.697976 -> V=1.0, theta=0.0
% INFO    : Bus 85816	: V=0.9672786, theta=-40.214392 -> V=1.0, theta=0.0
% INFO    : Bus 85817	: V=0.967197, theta=-40.691541 -> V=1.0, theta=0.0
% INFO    : Bus 85818	: V=0.9650727, theta=-41.023353 -> V=1.0, theta=0.0
% INFO    : Bus 85819	: V=0.9631934, theta=-41.254665 -> V=1.0, theta=0.0
% INFO    : Bus 85820	: V=0.9592782, theta=-41.951935 -> V=1.0, theta=0.0
% INFO    : Bus 85821	: V=0.9631932, theta=-41.401963 -> V=1.0, theta=0.0
% INFO    : Bus 85822	: V=0.9567685, theta=-42.317721 -> V=1.0, theta=0.0
% INFO    : Bus 85823	: V=0.9576134, theta=-42.720158 -> V=1.0, theta=0.0
% INFO    : Bus 85824	: V=0.9560768, theta=-44.510884 -> V=1.0, theta=0.0
% INFO    : Bus 85825	: V=0.9549387, theta=-44.6729 -> V=1.0, theta=0.0
% INFO    : Bus 85826	: V=0.9647211, theta=-41.825679 -> V=1.0, theta=0.0
% INFO    : Bus 85827	: V=0.9611003, theta=-43.721649 -> V=1.0, theta=0.0
% INFO    : Bus 85828	: V=0.9868535, theta=-35.740551 -> V=1.0, theta=0.0
% INFO    : Bus 85829	: V=0.9776485, theta=-38.554246 -> V=1.0, theta=0.0
% INFO    : Bus 85830	: V=0.9756824, theta=-38.704074 -> V=1.0, theta=0.0
% INFO    : Bus 85831	: V=0.9748628, theta=-37.629007 -> V=1.0, theta=0.0
% INFO    : Bus 85832	: V=0.9852263, theta=-36.777997 -> V=1.0, theta=0.0
% INFO    : Bus 85833	: V=1.0075566, theta=-35.077177 -> V=1.0, theta=0.0
% INFO    : Bus 85834	: V=1.0047132, theta=-35.088361 -> V=1.0, theta=0.0
% INFO    : Bus 85835	: V=1.0083922, theta=-30.099481 -> V=1.0, theta=0.0
% INFO    : Bus 85836	: V=0.9997236, theta=-33.725547 -> V=1.0, theta=0.0
% INFO    : Bus 85837	: V=0.9713921, theta=-38.852272 -> V=1.0, theta=0.0
% INFO    : Bus 85838	: V=0.994013, theta=-52.189631 -> V=1.0, theta=0.0
% INFO    : Bus 85839	: V=0.9945475, theta=-52.206791 -> V=1.0, theta=0.0
% INFO    : Bus 85840	: V=0.9941374, theta=-52.171517 -> V=1.0, theta=0.0
% INFO    : Bus 85841	: V=0.9969374, theta=-51.87694 -> V=1.0, theta=0.0
% INFO    : Bus 85842	: V=0.9946808, theta=-52.145144 -> V=1.0, theta=0.0
% INFO    : Bus 85843	: V=1.001242, theta=-51.491622 -> V=1.0, theta=0.0
% INFO    : Bus 85844	: V=1.0003605, theta=-51.7012 -> V=1.0, theta=0.0
% INFO    : Bus 85845	: V=0.9788557, theta=-53.294588 -> V=1.0, theta=0.0
% INFO    : Bus 85846	: V=0.9838978, theta=-52.448351 -> V=1.0, theta=0.0
% INFO    : Bus 85847	: V=0.9844483, theta=-52.573694 -> V=1.0, theta=0.0
% INFO    : Bus 85848	: V=0.984668, theta=-52.551743 -> V=1.0, theta=0.0
% INFO    : Bus 85849	: V=0.9790985, theta=-52.710026 -> V=1.0, theta=0.0
% INFO    : Bus 85850	: V=0.9851984, theta=-52.29819 -> V=1.0, theta=0.0
% INFO    : Bus 85851	: V=0.9902486, theta=-51.730467 -> V=1.0, theta=0.0
% INFO    : Bus 85852	: V=0.9858006, theta=-52.329712 -> V=1.0, theta=0.0
% INFO    : Bus 85853	: V=0.9880842, theta=-52.425236 -> V=1.0, theta=0.0
% INFO    : Bus 85854	: V=0.9928202, theta=-52.128826 -> V=1.0, theta=0.0
% INFO    : Bus 85855	: V=0.9925062, theta=-52.140418 -> V=1.0, theta=0.0
% INFO    : Bus 85856	: V=0.9838046, theta=-52.726257 -> V=1.0, theta=0.0
% INFO    : Bus 85857	: V=0.9876835, theta=-52.503243 -> V=1.0, theta=0.0
% INFO    : Bus 85858	: V=0.9664022, theta=-53.046758 -> V=1.0, theta=0.0
% INFO    : Bus 85859	: V=0.9820178, theta=-52.640752 -> V=1.0, theta=0.0
% INFO    : Bus 85860	: V=0.9905598, theta=-52.221856 -> V=1.0, theta=0.0
% INFO    : Bus 85861	: V=0.9828267, theta=-52.726759 -> V=1.0, theta=0.0
% INFO    : Bus 85862	: V=0.9917135, theta=-51.59419 -> V=1.0, theta=0.0
% INFO    : Bus 85863	: V=0.9972384, theta=-50.828988 -> V=1.0, theta=0.0
% INFO    : Bus 85864	: V=0.991155, theta=-51.705645 -> V=1.0, theta=0.0
% INFO    : Bus 85865	: V=1.0014296, theta=-51.063561 -> V=1.0, theta=0.0
% INFO    : Bus 85866	: V=0.9988719, theta=-51.333269 -> V=1.0, theta=0.0
% INFO    : Bus 85867	: V=0.9780449, theta=-52.321075 -> V=1.0, theta=0.0
% INFO    : Bus 85868	: V=0.9700017, theta=-52.289357 -> V=1.0, theta=0.0
% INFO    : Bus 85869	: V=0.9680186, theta=-52.672141 -> V=1.0, theta=0.0
% INFO    : Bus 85870	: V=0.9567818, theta=-53.478721 -> V=1.0, theta=0.0
% INFO    : Bus 85871	: V=0.9643014, theta=-52.847553 -> V=1.0, theta=0.0
% INFO    : Bus 85872	: V=0.9664268, theta=-52.298706 -> V=1.0, theta=0.0
% INFO    : Bus 85873	: V=0.972112, theta=-51.728407 -> V=1.0, theta=0.0
% INFO    : Bus 85874	: V=0.9716428, theta=-51.458732 -> V=1.0, theta=0.0
% INFO    : Bus 85875	: V=0.9625242, theta=-52.005697 -> V=1.0, theta=0.0
% INFO    : Bus 85876	: V=0.9702376, theta=-51.52711 -> V=1.0, theta=0.0
% INFO    : Bus 85877	: V=0.9713793, theta=-51.439141 -> V=1.0, theta=0.0
% INFO    : Bus 85878	: V=0.9687245, theta=-51.615057 -> V=1.0, theta=0.0
% INFO    : Bus 85879	: V=0.9774053, theta=-51.04268 -> V=1.0, theta=0.0
% INFO    : Bus 85880	: V=0.9751629, theta=-54.043222 -> V=1.0, theta=0.0
% INFO    : Bus 85881	: V=0.9641881, theta=-54.713843 -> V=1.0, theta=0.0
% INFO    : Bus 85882	: V=0.9723339, theta=-53.964105 -> V=1.0, theta=0.0
% INFO    : Bus 85883	: V=0.9761908, theta=-53.717317 -> V=1.0, theta=0.0
% INFO    : Bus 85884	: V=0.9870398, theta=-52.793811 -> V=1.0, theta=0.0
% INFO    : Bus 85885	: V=0.9845927, theta=-53.013201 -> V=1.0, theta=0.0
% INFO    : Bus 85886	: V=0.9940758, theta=-52.038326 -> V=1.0, theta=0.0
% INFO    : Bus 85887	: V=0.9831439, theta=-52.505062 -> V=1.0, theta=0.0
% INFO    : Bus 85888	: V=0.9916718, theta=-52.208024 -> V=1.0, theta=0.0
% INFO    : Bus 85889	: V=0.9659717, theta=-53.959184 -> V=1.0, theta=0.0
% INFO    : Bus 85890	: V=0.9878274, theta=-52.548678 -> V=1.0, theta=0.0
% INFO    : Bus 85891	: V=0.9877637, theta=-52.574148 -> V=1.0, theta=0.0
% INFO    : Bus 85892	: V=0.9897776, theta=-52.387549 -> V=1.0, theta=0.0
% INFO    : Bus 85893	: V=0.9723268, theta=-54.008867 -> V=1.0, theta=0.0
% INFO    : Bus 85894	: V=0.973542, theta=-53.987687 -> V=1.0, theta=0.0
% INFO    : Bus 85895	: V=0.9754756, theta=-53.672442 -> V=1.0, theta=0.0
% INFO    : Bus 85896	: V=0.9650716, theta=-54.211738 -> V=1.0, theta=0.0
% INFO    : Bus 85897	: V=0.97081, theta=-53.658367 -> V=1.0, theta=0.0
% INFO    : Bus 85898	: V=0.970055, theta=-53.729491 -> V=1.0, theta=0.0
% INFO    : Bus 85899	: V=0.9585524, theta=-55.229667 -> V=1.0, theta=0.0
% INFO    : Bus 85900	: V=0.9584087, theta=-54.827124 -> V=1.0, theta=0.0
% INFO    : Bus 85901	: V=0.9578563, theta=-55.320089 -> V=1.0, theta=0.0
% INFO    : Bus 85902	: V=0.9607103, theta=-55.374286 -> V=1.0, theta=0.0
% INFO    : Bus 85903	: V=0.9597665, theta=-54.93435 -> V=1.0, theta=0.0
% INFO    : Bus 85904	: V=0.9683119, theta=-53.754714 -> V=1.0, theta=0.0
% INFO    : Bus 85905	: V=0.9750812, theta=-52.660992 -> V=1.0, theta=0.0
% INFO    : Bus 85906	: V=0.9676247, theta=-53.795413 -> V=1.0, theta=0.0
% INFO    : Bus 85907	: V=0.963343, theta=-54.135591 -> V=1.0, theta=0.0
% INFO    : Bus 85908	: V=0.9594764, theta=-54.765943 -> V=1.0, theta=0.0
% INFO    : Bus 85909	: V=0.9687996, theta=-54.049247 -> V=1.0, theta=0.0
% INFO    : Bus 85910	: V=0.9596798, theta=-54.623821 -> V=1.0, theta=0.0
% INFO    : Bus 85911	: V=0.9645063, theta=-54.293062 -> V=1.0, theta=0.0
% INFO    : Bus 85912	: V=0.9745832, theta=-53.634189 -> V=1.0, theta=0.0
% INFO    : Bus 85913	: V=0.9811428, theta=-53.060071 -> V=1.0, theta=0.0
% INFO    : Bus 85914	: V=0.9693132, theta=-53.986356 -> V=1.0, theta=0.0
% INFO    : Bus 85915	: V=0.9707528, theta=-53.960718 -> V=1.0, theta=0.0
% INFO    : Bus 85916	: V=0.9994774, theta=-51.70852 -> V=1.0, theta=0.0
% INFO    : Bus 85917	: V=0.9661532, theta=-53.941448 -> V=1.0, theta=0.0
% INFO    : Bus 85918	: V=0.9710351, theta=-53.388611 -> V=1.0, theta=0.0
% INFO    : Bus 85919	: V=0.970492, theta=-53.472509 -> V=1.0, theta=0.0
% INFO    : Bus 85920	: V=0.9833676, theta=-52.982192 -> V=1.0, theta=0.0
% INFO    : Bus 85921	: V=0.9786015, theta=-53.536123 -> V=1.0, theta=0.0
% INFO    : Bus 85922	: V=0.9871139, theta=-48.544801 -> V=1.0, theta=0.0
% INFO    : Bus 85923	: V=0.9844799, theta=-48.569706 -> V=1.0, theta=0.0
% INFO    : Bus 85924	: V=0.9888201, theta=-48.272757 -> V=1.0, theta=0.0
% INFO    : Bus 85925	: V=0.9871999, theta=-48.238712 -> V=1.0, theta=0.0
% INFO    : Bus 85926	: V=0.9878944, theta=-48.200874 -> V=1.0, theta=0.0
% INFO    : Bus 85927	: V=0.980707, theta=-48.951615 -> V=1.0, theta=0.0
% INFO    : Bus 85928	: V=0.983593, theta=-48.923709 -> V=1.0, theta=0.0
% INFO    : Bus 85929	: V=0.9872321, theta=-48.523366 -> V=1.0, theta=0.0
% INFO    : Bus 85930	: V=1.0031316, theta=-47.868954 -> V=1.0, theta=0.0
% INFO    : Bus 85931	: V=1.0045752, theta=-47.423969 -> V=1.0, theta=0.0
% INFO    : Bus 85932	: V=1.0071287, theta=-46.806928 -> V=1.0, theta=0.0
% INFO    : Bus 85933	: V=0.9952741, theta=-47.671226 -> V=1.0, theta=0.0
% INFO    : Bus 85934	: V=0.9996201, theta=-47.269125 -> V=1.0, theta=0.0
% INFO    : Bus 85935	: V=0.9957366, theta=-47.612263 -> V=1.0, theta=0.0
% INFO    : Bus 85936	: V=0.9887033, theta=-48.278783 -> V=1.0, theta=0.0
% INFO    : Bus 85937	: V=0.9874613, theta=-48.199996 -> V=1.0, theta=0.0
% INFO    : Bus 85938	: V=0.9912133, theta=-47.747431 -> V=1.0, theta=0.0
% INFO    : Bus 85939	: V=0.9954637, theta=-47.405677 -> V=1.0, theta=0.0
% INFO    : Bus 85940	: V=0.9823612, theta=-48.482808 -> V=1.0, theta=0.0
% INFO    : Bus 85941	: V=0.9811774, theta=-48.593982 -> V=1.0, theta=0.0
% INFO    : Bus 85942	: V=0.9847668, theta=-48.29959 -> V=1.0, theta=0.0
% INFO    : Bus 85943	: V=0.9830384, theta=-48.331269 -> V=1.0, theta=0.0
% INFO    : Bus 85944	: V=0.9855951, theta=-48.1781 -> V=1.0, theta=0.0
% INFO    : Bus 85945	: V=0.983655, theta=-48.309866 -> V=1.0, theta=0.0
% INFO    : Bus 85946	: V=0.9845787, theta=-49.792799 -> V=1.0, theta=0.0
% INFO    : Bus 85947	: V=0.9819471, theta=-49.050908 -> V=1.0, theta=0.0
% INFO    : Bus 85948	: V=0.9874243, theta=-49.152112 -> V=1.0, theta=0.0
% INFO    : Bus 85949	: V=0.9794742, theta=-48.302343 -> V=1.0, theta=0.0
% INFO    : Bus 85950	: V=0.9939235, theta=-47.939227 -> V=1.0, theta=0.0
% INFO    : Bus 85951	: V=1.005333, theta=-46.755244 -> V=1.0, theta=0.0
% INFO    : Bus 85952	: V=0.9920993, theta=-46.332187 -> V=1.0, theta=0.0
% INFO    : Bus 85953	: V=0.9913335, theta=-46.457437 -> V=1.0, theta=0.0
% INFO    : Bus 85954	: V=0.9677943, theta=-48.208163 -> V=1.0, theta=0.0
% INFO    : Bus 85955	: V=0.982453, theta=-47.430517 -> V=1.0, theta=0.0
% INFO    : Bus 85956	: V=0.9761611, theta=-47.85876 -> V=1.0, theta=0.0
% INFO    : Bus 85957	: V=0.9791292, theta=-47.96376 -> V=1.0, theta=0.0
% INFO    : Bus 85958	: V=0.9957392, theta=-47.177165 -> V=1.0, theta=0.0
% INFO    : Bus 85959	: V=0.9854395, theta=-47.6429 -> V=1.0, theta=0.0
% INFO    : Bus 85960	: V=0.9842354, theta=-47.6877 -> V=1.0, theta=0.0
% INFO    : Bus 85961	: V=0.9766751, theta=-48.009088 -> V=1.0, theta=0.0
% INFO    : Bus 85962	: V=0.9697031, theta=-46.728238 -> V=1.0, theta=0.0
% INFO    : Bus 85963	: V=0.9654809, theta=-48.503639 -> V=1.0, theta=0.0
% INFO    : Bus 85964	: V=0.9968292, theta=-46.545396 -> V=1.0, theta=0.0
% INFO    : Bus 85965	: V=0.9867533, theta=-47.293739 -> V=1.0, theta=0.0
% INFO    : Bus 85966	: V=0.9954573, theta=-46.893976 -> V=1.0, theta=0.0
% INFO    : Bus 85967	: V=1.0026109, theta=-46.083895 -> V=1.0, theta=0.0
% INFO    : Bus 85968	: V=0.9878669, theta=-47.924121 -> V=1.0, theta=0.0
% INFO    : Bus 85969	: V=0.9723242, theta=-47.091472 -> V=1.0, theta=0.0
% INFO    : Bus 85970	: V=0.9707475, theta=-46.442028 -> V=1.0, theta=0.0
% INFO    : Bus 85971	: V=1.0066807, theta=-45.21746 -> V=1.0, theta=0.0
% INFO    : Bus 85972	: V=1.0125865, theta=-45.693454 -> V=1.0, theta=0.0
% INFO    : Bus 85973	: V=1.0140959, theta=-46.492834 -> V=1.0, theta=0.0
% INFO    : Bus 85974	: V=0.990071, theta=-46.69648 -> V=1.0, theta=0.0
% INFO    : Bus 85975	: V=0.9794623, theta=-48.563105 -> V=1.0, theta=0.0
% INFO    : Bus 85976	: V=0.9827067, theta=-48.509357 -> V=1.0, theta=0.0
% INFO    : Bus 85977	: V=0.984551, theta=-48.793079 -> V=1.0, theta=0.0
% INFO    : Bus 85978	: V=0.9821306, theta=-47.653099 -> V=1.0, theta=0.0
% INFO    : Bus 85979	: V=1.0054351, theta=-44.909091 -> V=1.0, theta=0.0
% INFO    : Bus 85980	: V=1.0155029, theta=-43.674517 -> V=1.0, theta=0.0
% INFO    : Bus 85981	: V=1.0086672, theta=-44.438556 -> V=1.0, theta=0.0
% INFO    : Bus 85982	: V=1.012002, theta=-44.108289 -> V=1.0, theta=0.0
% INFO    : Bus 85983	: V=1.0081704, theta=-44.347564 -> V=1.0, theta=0.0
% INFO    : Bus 85984	: V=1.0088758, theta=-44.515469 -> V=1.0, theta=0.0
% INFO    : Bus 85985	: V=1.0045424, theta=-45.024321 -> V=1.0, theta=0.0
% INFO    : Bus 85986	: V=0.995812, theta=-45.640174 -> V=1.0, theta=0.0
% INFO    : Bus 85987	: V=0.9579148, theta=-48.924896 -> V=1.0, theta=0.0
% INFO    : Bus 85988	: V=0.9540742, theta=-50.010625 -> V=1.0, theta=0.0
% INFO    : Bus 85989	: V=0.9565963, theta=-47.304431 -> V=1.0, theta=0.0
% INFO    : Bus 85990	: V=0.9576239, theta=-47.229907 -> V=1.0, theta=0.0
% INFO    : Bus 85991	: V=0.9607488, theta=-46.646445 -> V=1.0, theta=0.0
% INFO    : Bus 85992	: V=0.9591052, theta=-46.901048 -> V=1.0, theta=0.0
% INFO    : Bus 85993	: V=0.9752121, theta=-46.095918 -> V=1.0, theta=0.0
% INFO    : Bus 85994	: V=0.9870546, theta=-46.001795 -> V=1.0, theta=0.0
% INFO    : Bus 85995	: V=0.9597315, theta=-48.971671 -> V=1.0, theta=0.0
% INFO    : Bus 85996	: V=0.959271, theta=-49.107775 -> V=1.0, theta=0.0
% INFO    : Bus 85997	: V=0.9600467, theta=-49.01861 -> V=1.0, theta=0.0
% INFO    : Bus 85998	: V=0.9589293, theta=-49.153731 -> V=1.0, theta=0.0
% INFO    : Bus 85999	: V=0.9967791, theta=-34.03453 -> V=1.0, theta=0.0
% INFO    : Bus 86000	: V=0.9920975, theta=-34.505318 -> V=1.0, theta=0.0
% INFO    : Bus 86001	: V=1.001428, theta=-33.430861 -> V=1.0, theta=0.0
% INFO    : Bus 86002	: V=0.9952122, theta=-34.169494 -> V=1.0, theta=0.0
% INFO    : Bus 86003	: V=0.9881191, theta=-34.790553 -> V=1.0, theta=0.0
% INFO    : Bus 86004	: V=0.9918139, theta=-34.604634 -> V=1.0, theta=0.0
% INFO    : Bus 86005	: V=0.9917214, theta=-34.658142 -> V=1.0, theta=0.0
% INFO    : Bus 86006	: V=0.9909694, theta=-34.658923 -> V=1.0, theta=0.0
% INFO    : Bus 86007	: V=0.9904518, theta=-34.52136 -> V=1.0, theta=0.0
% INFO    : Bus 86008	: V=0.9923549, theta=-34.161671 -> V=1.0, theta=0.0
% INFO    : Bus 86009	: V=0.9922005, theta=-34.136189 -> V=1.0, theta=0.0
% INFO    : Bus 86010	: V=0.9823838, theta=-34.692049 -> V=1.0, theta=0.0
% INFO    : Bus 86011	: V=0.987498, theta=-34.428837 -> V=1.0, theta=0.0
% INFO    : Bus 86012	: V=0.9996581, theta=-32.923068 -> V=1.0, theta=0.0
% INFO    : Bus 86013	: V=0.9994671, theta=-32.853929 -> V=1.0, theta=0.0
% INFO    : Bus 86014	: V=0.9994279, theta=-33.63514 -> V=1.0, theta=0.0
% INFO    : Bus 86015	: V=0.997232, theta=-32.809137 -> V=1.0, theta=0.0
% INFO    : Bus 86016	: V=1.0027025, theta=-32.58879 -> V=1.0, theta=0.0
% INFO    : Bus 86017	: V=0.9823498, theta=-34.608765 -> V=1.0, theta=0.0
% INFO    : Bus 86018	: V=0.9921775, theta=-34.566321 -> V=1.0, theta=0.0
% INFO    : Bus 86019	: V=1.0100004, theta=-53.422128 -> V=1.0, theta=0.0
% INFO    : Bus 86020	: V=1.0009052, theta=-54.12241 -> V=1.0, theta=0.0
% INFO    : Bus 86021	: V=1.0015899, theta=-54.904414 -> V=1.0, theta=0.0
% INFO    : Bus 86022	: V=1.0018954, theta=-55.203812 -> V=1.0, theta=0.0
% INFO    : Bus 86023	: V=1.0145138, theta=-53.43611 -> V=1.0, theta=0.0
% INFO    : Bus 86024	: V=1.0103264, theta=-53.138329 -> V=1.0, theta=0.0
% INFO    : Bus 86025	: V=1.0098757, theta=-52.49393 -> V=1.0, theta=0.0
% INFO    : Bus 86026	: V=1.0077587, theta=-53.979428 -> V=1.0, theta=0.0
% INFO    : Bus 86027	: V=0.9548103, theta=-57.727558 -> V=1.0, theta=0.0
% INFO    : Bus 86028	: V=0.9503604, theta=-57.871542 -> V=1.0, theta=0.0
% INFO    : Bus 86029	: V=0.94851, theta=-57.088126 -> V=1.0, theta=0.0
% INFO    : Bus 86030	: V=0.9599706, theta=-57.636962 -> V=1.0, theta=0.0
% INFO    : Bus 86031	: V=0.9714726, theta=-51.860265 -> V=1.0, theta=0.0
% INFO    : Bus 86032	: V=0.9668214, theta=-52.535532 -> V=1.0, theta=0.0
% INFO    : Bus 86033	: V=0.9663714, theta=-52.609844 -> V=1.0, theta=0.0
% INFO    : Bus 86034	: V=0.967497, theta=-52.396482 -> V=1.0, theta=0.0
% INFO    : Bus 86035	: V=0.9881024, theta=-49.013631 -> V=1.0, theta=0.0
% INFO    : Bus 86036	: V=0.9750531, theta=-51.029483 -> V=1.0, theta=0.0
% INFO    : Bus 86037	: V=0.968821, theta=-51.863907 -> V=1.0, theta=0.0
% INFO    : Bus 86038	: V=0.9672798, theta=-52.545323 -> V=1.0, theta=0.0
% INFO    : Bus 86039	: V=0.9692184, theta=-51.26009 -> V=1.0, theta=0.0
% INFO    : Bus 86040	: V=0.9683584, theta=-51.758046 -> V=1.0, theta=0.0
% INFO    : Bus 86041	: V=0.960911, theta=-53.134112 -> V=1.0, theta=0.0
% INFO    : Bus 86042	: V=0.9608448, theta=-52.606971 -> V=1.0, theta=0.0
% INFO    : Bus 86043	: V=0.9652417, theta=-52.721336 -> V=1.0, theta=0.0
% INFO    : Bus 86044	: V=0.9628725, theta=-53.073981 -> V=1.0, theta=0.0
% INFO    : Bus 86045	: V=0.959951, theta=-53.430303 -> V=1.0, theta=0.0
% INFO    : Bus 86046	: V=0.9572111, theta=-53.761626 -> V=1.0, theta=0.0
% INFO    : Bus 86047	: V=0.9513328, theta=-54.398838 -> V=1.0, theta=0.0
% INFO    : Bus 86048	: V=0.9573269, theta=-53.782502 -> V=1.0, theta=0.0
% INFO    : Bus 86049	: V=0.9519045, theta=-54.853483 -> V=1.0, theta=0.0
% INFO    : Bus 86050	: V=0.9489064, theta=-55.499765 -> V=1.0, theta=0.0
% INFO    : Bus 86051	: V=0.9664434, theta=-52.931157 -> V=1.0, theta=0.0
% INFO    : Bus 86052	: V=0.9902537, theta=-49.270769 -> V=1.0, theta=0.0
% INFO    : Bus 86053	: V=0.9807425, theta=-50.638151 -> V=1.0, theta=0.0
% INFO    : Bus 86054	: V=0.976145, theta=-51.460614 -> V=1.0, theta=0.0
% INFO    : Bus 86055	: V=0.9598777, theta=-51.554593 -> V=1.0, theta=0.0
% INFO    : Bus 86056	: V=0.9488134, theta=-55.586908 -> V=1.0, theta=0.0
% INFO    : Bus 86057	: V=0.9526354, theta=-55.053013 -> V=1.0, theta=0.0
% INFO    : Bus 86058	: V=0.9600893, theta=-53.805275 -> V=1.0, theta=0.0
% INFO    : Bus 86059	: V=0.9768183, theta=-46.482493 -> V=1.0, theta=0.0
% INFO    : Bus 86060	: V=0.9746874, theta=-46.43748 -> V=1.0, theta=0.0
% INFO    : Bus 86061	: V=0.999344, theta=-44.082926 -> V=1.0, theta=0.0
% INFO    : Bus 86062	: V=0.9833507, theta=-45.737887 -> V=1.0, theta=0.0
% INFO    : Bus 86063	: V=0.9826683, theta=-45.898002 -> V=1.0, theta=0.0
% INFO    : Bus 86064	: V=0.9695447, theta=-46.86467 -> V=1.0, theta=0.0
% INFO    : Bus 86065	: V=0.9732108, theta=-46.606134 -> V=1.0, theta=0.0
% INFO    : Bus 86066	: V=0.9704593, theta=-46.873188 -> V=1.0, theta=0.0
% INFO    : Bus 86067	: V=0.9740855, theta=-46.617486 -> V=1.0, theta=0.0
% INFO    : Bus 86068	: V=0.9721046, theta=-46.731032 -> V=1.0, theta=0.0
% INFO    : Bus 86069	: V=0.9754865, theta=-46.487367 -> V=1.0, theta=0.0
% INFO    : Bus 86070	: V=0.9766006, theta=-46.152195 -> V=1.0, theta=0.0
% INFO    : Bus 86071	: V=0.990439, theta=-44.720643 -> V=1.0, theta=0.0
% INFO    : Bus 86072	: V=0.965861, theta=-47.187158 -> V=1.0, theta=0.0
% INFO    : Bus 86073	: V=0.9647145, theta=-47.215525 -> V=1.0, theta=0.0
% INFO    : Bus 86074	: V=0.9611399, theta=-47.777826 -> V=1.0, theta=0.0
% INFO    : Bus 86075	: V=0.9747144, theta=-46.712478 -> V=1.0, theta=0.0
% INFO    : Bus 86076	: V=0.9761205, theta=-46.6417 -> V=1.0, theta=0.0
% INFO    : Bus 86077	: V=0.9671079, theta=-47.416996 -> V=1.0, theta=0.0
% INFO    : Bus 86078	: V=0.9673391, theta=-47.653373 -> V=1.0, theta=0.0
% INFO    : Bus 86079	: V=0.9681033, theta=-47.324362 -> V=1.0, theta=0.0
% INFO    : Bus 86080	: V=0.9675627, theta=-47.607125 -> V=1.0, theta=0.0
% INFO    : Bus 86081	: V=0.9614769, theta=-47.9774 -> V=1.0, theta=0.0
% INFO    : Bus 86082	: V=0.9536749, theta=-48.4166 -> V=1.0, theta=0.0
% INFO    : Bus 86083	: V=0.9578376, theta=-48.600884 -> V=1.0, theta=0.0
% INFO    : Bus 86084	: V=0.9530267, theta=-48.944774 -> V=1.0, theta=0.0
% INFO    : Bus 86085	: V=0.9557236, theta=-48.337938 -> V=1.0, theta=0.0
% INFO    : Bus 86086	: V=0.9600284, theta=-47.815347 -> V=1.0, theta=0.0
% INFO    : Bus 86087	: V=0.9600376, theta=-47.864052 -> V=1.0, theta=0.0
% INFO    : Bus 86088	: V=0.9582225, theta=-51.883708 -> V=1.0, theta=0.0
% INFO    : Bus 86089	: V=0.9652954, theta=-51.586184 -> V=1.0, theta=0.0
% INFO    : Bus 86090	: V=0.9612656, theta=-51.357255 -> V=1.0, theta=0.0
% INFO    : Bus 86091	: V=0.9684637, theta=-50.734067 -> V=1.0, theta=0.0
% INFO    : Bus 86092	: V=0.9691845, theta=-50.681546 -> V=1.0, theta=0.0
% INFO    : Bus 86093	: V=0.9619927, theta=-51.549215 -> V=1.0, theta=0.0
% INFO    : Bus 86094	: V=0.9582065, theta=-51.891896 -> V=1.0, theta=0.0
% INFO    : Bus 86095	: V=0.9606399, theta=-51.621678 -> V=1.0, theta=0.0
% INFO    : Bus 86096	: V=1.0031156, theta=-51.983358 -> V=1.0, theta=0.0
% INFO    : Bus 86097	: V=0.9908497, theta=-51.763643 -> V=1.0, theta=0.0
% INFO    : Bus 86098	: V=1.0011219, theta=-50.060102 -> V=1.0, theta=0.0
% INFO    : Bus 86099	: V=0.9546316, theta=-50.282649 -> V=1.0, theta=0.0
% INFO    : Bus 86100	: V=0.9601331, theta=-49.205323 -> V=1.0, theta=0.0
% INFO    : Bus 86101	: V=0.9597091, theta=-49.299487 -> V=1.0, theta=0.0
% INFO    : Bus 86102	: V=0.9600641, theta=-49.266059 -> V=1.0, theta=0.0
% INFO    : Bus 86103	: V=0.9602951, theta=-49.242104 -> V=1.0, theta=0.0
% INFO    : Bus 86104	: V=0.9572755, theta=-49.837076 -> V=1.0, theta=0.0
% INFO    : Bus 86105	: V=0.9623667, theta=-48.398619 -> V=1.0, theta=0.0
% INFO    : Bus 86106	: V=0.9617897, theta=-48.453783 -> V=1.0, theta=0.0
% INFO    : Bus 86107	: V=0.9616733, theta=-48.42383 -> V=1.0, theta=0.0
% INFO    : Bus 86108	: V=0.9635089, theta=-48.243904 -> V=1.0, theta=0.0
% INFO    : Bus 86109	: V=0.960688, theta=-49.54197 -> V=1.0, theta=0.0
% INFO    : Bus 86110	: V=0.9650163, theta=-47.986609 -> V=1.0, theta=0.0
% INFO    : Bus 86111	: V=0.9624116, theta=-48.332804 -> V=1.0, theta=0.0
% INFO    : Bus 86112	: V=0.963805, theta=-48.071843 -> V=1.0, theta=0.0
% INFO    : Bus 86113	: V=0.9613805, theta=-48.709614 -> V=1.0, theta=0.0
% INFO    : Bus 86114	: V=0.9668291, theta=-47.896587 -> V=1.0, theta=0.0
% INFO    : Bus 86115	: V=0.9648857, theta=-48.029671 -> V=1.0, theta=0.0
% INFO    : Bus 86116	: V=0.9739691, theta=-46.96361 -> V=1.0, theta=0.0
% INFO    : Bus 86117	: V=0.9792634, theta=-46.368248 -> V=1.0, theta=0.0
% INFO    : Bus 86118	: V=0.9847347, theta=-45.866254 -> V=1.0, theta=0.0
% INFO    : Bus 86119	: V=0.9685049, theta=-47.679081 -> V=1.0, theta=0.0
% INFO    : Bus 86120	: V=1.0014135, theta=-43.091421 -> V=1.0, theta=0.0
% INFO    : Bus 86121	: V=0.996283, theta=-43.853031 -> V=1.0, theta=0.0
% INFO    : Bus 86122	: V=0.9949237, theta=-44.005886 -> V=1.0, theta=0.0
% INFO    : Bus 86123	: V=0.9832433, theta=-45.757417 -> V=1.0, theta=0.0
% INFO    : Bus 86124	: V=0.9868232, theta=-45.077895 -> V=1.0, theta=0.0
% INFO    : Bus 86125	: V=0.9583232, theta=-49.495357 -> V=1.0, theta=0.0
% INFO    : Bus 86126	: V=0.9942765, theta=-45.695373 -> V=1.0, theta=0.0
% INFO    : Bus 86127	: V=0.9817672, theta=-46.159617 -> V=1.0, theta=0.0
% INFO    : Bus 86128	: V=0.9893032, theta=-45.53968 -> V=1.0, theta=0.0
% INFO    : Bus 86129	: V=0.9897967, theta=-45.339034 -> V=1.0, theta=0.0
% INFO    : Bus 86130	: V=0.9862726, theta=-45.754868 -> V=1.0, theta=0.0
% INFO    : Bus 86131	: V=0.9928931, theta=-45.04552 -> V=1.0, theta=0.0
% INFO    : Bus 86132	: V=0.9942647, theta=-44.949581 -> V=1.0, theta=0.0
% INFO    : Bus 86133	: V=0.9917135, theta=-45.26 -> V=1.0, theta=0.0
% INFO    : Bus 86134	: V=0.9864376, theta=-45.706812 -> V=1.0, theta=0.0
% INFO    : Bus 86135	: V=0.9900114, theta=-45.363276 -> V=1.0, theta=0.0
% INFO    : Bus 86136	: V=0.9804622, theta=-45.800916 -> V=1.0, theta=0.0
% INFO    : Bus 86137	: V=0.9829549, theta=-46.118387 -> V=1.0, theta=0.0
% INFO    : Bus 86138	: V=0.9828364, theta=-46.135045 -> V=1.0, theta=0.0
% INFO    : Bus 86139	: V=0.9727624, theta=-46.598057 -> V=1.0, theta=0.0
% INFO    : Bus 86140	: V=0.9697893, theta=-47.682613 -> V=1.0, theta=0.0
% INFO    : Bus 86141	: V=0.9687089, theta=-47.754994 -> V=1.0, theta=0.0
% INFO    : Bus 86142	: V=0.9862041, theta=-51.383084 -> V=1.0, theta=0.0
% INFO    : Bus 86143	: V=0.969269, theta=-51.285014 -> V=1.0, theta=0.0
% INFO    : Bus 86144	: V=0.9728203, theta=-51.9596 -> V=1.0, theta=0.0
% INFO    : Bus 86145	: V=0.9702473, theta=-51.937461 -> V=1.0, theta=0.0
% INFO    : Bus 86146	: V=1.0037585, theta=-30.551142 -> V=1.0, theta=0.0
% INFO    : Bus 86147	: V=0.9955243, theta=-34.842467 -> V=1.0, theta=0.0
% INFO    : Bus 86148	: V=0.9829016, theta=-38.215035 -> V=1.0, theta=0.0
% INFO    : Bus 86149	: V=0.9584907, theta=-40.190956 -> V=1.0, theta=0.0
% INFO    : Bus 86150	: V=0.9627495, theta=-40.380107 -> V=1.0, theta=0.0
% INFO    : Bus 86151	: V=0.9798768, theta=-40.865071 -> V=1.0, theta=0.0
% INFO    : Bus 86152	: V=0.9800705, theta=-39.599052 -> V=1.0, theta=0.0
% INFO    : Bus 86153	: V=0.9795736, theta=-40.151957 -> V=1.0, theta=0.0
% INFO    : Bus 86154	: V=0.986239, theta=-38.874646 -> V=1.0, theta=0.0
% INFO    : Bus 86155	: V=0.982698, theta=-39.494484 -> V=1.0, theta=0.0
% INFO    : Bus 86156	: V=0.9521542, theta=-35.873725 -> V=1.0, theta=0.0
% INFO    : Bus 86157	: V=0.9636656, theta=-34.319543 -> V=1.0, theta=0.0
% INFO    : Bus 86158	: V=0.963953, theta=-34.723356 -> V=1.0, theta=0.0
% INFO    : Bus 86159	: V=0.9579226, theta=-35.531898 -> V=1.0, theta=0.0
% INFO    : Bus 86160	: V=0.9573314, theta=-36.057199 -> V=1.0, theta=0.0
% INFO    : Bus 86161	: V=0.9534084, theta=-37.021141 -> V=1.0, theta=0.0
% INFO    : Bus 86162	: V=0.9907908, theta=-47.322117 -> V=1.0, theta=0.0
% INFO    : Bus 86163	: V=0.9922189, theta=-46.69375 -> V=1.0, theta=0.0
% INFO    : Bus 86164	: V=0.9972036, theta=-47.781866 -> V=1.0, theta=0.0
% INFO    : Bus 86165	: V=0.9878854, theta=-31.091623 -> V=1.0, theta=0.0
% INFO    : Bus 86166	: V=0.9873148, theta=-31.696234 -> V=1.0, theta=0.0
% INFO    : Bus 86167	: V=0.9899562, theta=-31.80487 -> V=1.0, theta=0.0
% INFO    : Bus 86168	: V=0.9885677, theta=-31.568478 -> V=1.0, theta=0.0
% INFO    : Bus 86169	: V=0.9979694, theta=-32.196757 -> V=1.0, theta=0.0
% INFO    : Bus 86170	: V=0.9935726, theta=-32.276043 -> V=1.0, theta=0.0
% INFO    : Bus 86171	: V=1.010634, theta=-29.186249 -> V=1.0, theta=0.0
% INFO    : Bus 86172	: V=1.0096618, theta=-29.726099 -> V=1.0, theta=0.0
% INFO    : Bus 86173	: V=0.984546, theta=-31.962493 -> V=1.0, theta=0.0
% INFO    : Bus 86174	: V=0.9966106, theta=-36.900443 -> V=1.0, theta=0.0
% INFO    : Bus 86175	: V=0.9966676, theta=-37.356325 -> V=1.0, theta=0.0
% INFO    : Bus 86176	: V=0.9854845, theta=-41.686262 -> V=1.0, theta=0.0
% INFO    : Bus 86177	: V=0.9801347, theta=-54.850738 -> V=1.0, theta=0.0
% INFO    : Bus 86178	: V=0.978253, theta=-55.418324 -> V=1.0, theta=0.0
% INFO    : Bus 86179	: V=0.9914649, theta=-29.977338 -> V=1.0, theta=0.0
% INFO    : Bus 86180	: V=0.9827738, theta=-31.626144 -> V=1.0, theta=0.0
% INFO    : Bus 86181	: V=0.9660761, theta=-30.65204 -> V=1.0, theta=0.0
% INFO    : Bus 86182	: V=0.9891308, theta=-28.362591 -> V=1.0, theta=0.0
% INFO    : Bus 86183	: V=0.9850936, theta=-33.475705 -> V=1.0, theta=0.0
% INFO    : Bus 86184	: V=0.9937245, theta=-42.956641 -> V=1.0, theta=0.0
% INFO    : Bus 86185	: V=0.9910683, theta=-43.001217 -> V=1.0, theta=0.0
% INFO    : Bus 86186	: V=0.980696, theta=-43.86132 -> V=1.0, theta=0.0
% INFO    : Bus 86187	: V=0.9864518, theta=-43.580624 -> V=1.0, theta=0.0
% INFO    : Bus 86188	: V=0.987402, theta=-43.380572 -> V=1.0, theta=0.0
% INFO    : Bus 86189	: V=0.9648098, theta=-32.009854 -> V=1.0, theta=0.0
% INFO    : Bus 86190	: V=0.9748103, theta=-30.745198 -> V=1.0, theta=0.0
% INFO    : Bus 86191	: V=0.9825709, theta=-29.375137 -> V=1.0, theta=0.0
% INFO    : Bus 86192	: V=0.9841123, theta=-29.869524 -> V=1.0, theta=0.0
% INFO    : Bus 86193	: V=0.9819527, theta=-30.190898 -> V=1.0, theta=0.0
% INFO    : Bus 86194	: V=1.0047312, theta=-27.487885 -> V=1.0, theta=0.0
% INFO    : Bus 86195	: V=0.9862582, theta=-29.992335 -> V=1.0, theta=0.0
% INFO    : Bus 86196	: V=0.987991, theta=-31.173328 -> V=1.0, theta=0.0
% INFO    : Bus 86197	: V=0.9918006, theta=-31.088218 -> V=1.0, theta=0.0
% INFO    : Bus 86198	: V=0.987108, theta=-30.790886 -> V=1.0, theta=0.0
% INFO    : Bus 86199	: V=1.0090051, theta=-26.709774 -> V=1.0, theta=0.0
% INFO    : Bus 86200	: V=1.001246, theta=-28.722722 -> V=1.0, theta=0.0
% INFO    : Bus 86201	: V=0.9958648, theta=-30.03516 -> V=1.0, theta=0.0
% INFO    : Bus 86202	: V=0.9936973, theta=-30.294183 -> V=1.0, theta=0.0
% INFO    : Bus 86203	: V=0.9945012, theta=-30.240299 -> V=1.0, theta=0.0
% INFO    : Bus 86204	: V=0.9872859, theta=-32.973163 -> V=1.0, theta=0.0
% INFO    : Bus 86205	: V=1.0065138, theta=-28.375869 -> V=1.0, theta=0.0
% INFO    : Bus 86206	: V=0.9881165, theta=-30.959583 -> V=1.0, theta=0.0
% INFO    : Bus 86207	: V=1.0087235, theta=-30.643743 -> V=1.0, theta=0.0
% INFO    : Bus 86208	: V=1.0111275, theta=-30.49612 -> V=1.0, theta=0.0
% INFO    : Bus 86209	: V=0.9635777, theta=-39.445926 -> V=1.0, theta=0.0
% INFO    : Bus 86210	: V=0.963632, theta=-37.489946 -> V=1.0, theta=0.0
% INFO    : Bus 86211	: V=0.9563761, theta=-40.45269 -> V=1.0, theta=0.0
% INFO    : Bus 86212	: V=0.9530529, theta=-41.634006 -> V=1.0, theta=0.0
% INFO    : Bus 86213	: V=0.9539277, theta=-40.461921 -> V=1.0, theta=0.0
% INFO    : Bus 86214	: V=0.9545597, theta=-40.563178 -> V=1.0, theta=0.0
% INFO    : Bus 86215	: V=0.9507679, theta=-41.48598 -> V=1.0, theta=0.0
% INFO    : Bus 86216	: V=0.9488574, theta=-39.172479 -> V=1.0, theta=0.0
% INFO    : Bus 86217	: V=0.950153, theta=-38.544678 -> V=1.0, theta=0.0
% INFO    : Bus 86218	: V=0.9503195, theta=-38.78744 -> V=1.0, theta=0.0
% INFO    : Bus 86219	: V=0.9827473, theta=-35.668504 -> V=1.0, theta=0.0
% INFO    : Bus 86220	: V=0.9906201, theta=-35.251608 -> V=1.0, theta=0.0
% INFO    : Bus 86221	: V=0.9911753, theta=-34.957967 -> V=1.0, theta=0.0
% INFO    : Bus 86222	: V=1.0033025, theta=-33.833486 -> V=1.0, theta=0.0
% INFO    : Bus 86223	: V=0.999802, theta=-35.007248 -> V=1.0, theta=0.0
% INFO    : Bus 86224	: V=0.9987381, theta=-35.693836 -> V=1.0, theta=0.0
% INFO    : Bus 86225	: V=0.9896456, theta=-35.145438 -> V=1.0, theta=0.0
% INFO    : Bus 86226	: V=0.9486085, theta=-40.434623 -> V=1.0, theta=0.0
% INFO    : Bus 86227	: V=0.9501286, theta=-39.672555 -> V=1.0, theta=0.0
% INFO    : Bus 86228	: V=0.9501707, theta=-39.732233 -> V=1.0, theta=0.0
% INFO    : Bus 86229	: V=0.9490146, theta=-40.419212 -> V=1.0, theta=0.0
% INFO    : Bus 86230	: V=0.9488396, theta=-40.981965 -> V=1.0, theta=0.0
% INFO    : Bus 86231	: V=0.948374, theta=-42.688838 -> V=1.0, theta=0.0
% INFO    : Bus 86232	: V=0.9504282, theta=-40.572343 -> V=1.0, theta=0.0
% INFO    : Bus 86233	: V=0.9502177, theta=-39.798139 -> V=1.0, theta=0.0
% INFO    : Bus 86234	: V=0.9564242, theta=-38.975273 -> V=1.0, theta=0.0
% INFO    : Bus 86235	: V=0.9566646, theta=-38.987044 -> V=1.0, theta=0.0
% INFO    : Bus 86236	: V=0.9543348, theta=-38.929341 -> V=1.0, theta=0.0
% INFO    : Bus 86237	: V=0.955018, theta=-38.876488 -> V=1.0, theta=0.0
% INFO    : Bus 86238	: V=0.9545199, theta=-38.76846 -> V=1.0, theta=0.0
% INFO    : Bus 86239	: V=0.9538159, theta=-38.818486 -> V=1.0, theta=0.0
% INFO    : Bus 86240	: V=0.9470433, theta=-40.444419 -> V=1.0, theta=0.0
% INFO    : Bus 86241	: V=0.9473823, theta=-40.377342 -> V=1.0, theta=0.0
% INFO    : Bus 86242	: V=0.9525797, theta=-39.005169 -> V=1.0, theta=0.0
% INFO    : Bus 86243	: V=0.9494162, theta=-40.044204 -> V=1.0, theta=0.0
% INFO    : Bus 86244	: V=0.9950222, theta=-48.510612 -> V=1.0, theta=0.0
% INFO    : Bus 86245	: V=0.9512512, theta=-37.324686 -> V=1.0, theta=0.0
% INFO    : Bus 86246	: V=0.9545484, theta=-36.617622 -> V=1.0, theta=0.0
% INFO    : Bus 86247	: V=0.9483333, theta=-39.126624 -> V=1.0, theta=0.0
% INFO    : Bus 86248	: V=0.9521687, theta=-38.587612 -> V=1.0, theta=0.0
% INFO    : Bus 86249	: V=0.9540914, theta=-37.711555 -> V=1.0, theta=0.0
% INFO    : Bus 86250	: V=0.9559367, theta=-36.354482 -> V=1.0, theta=0.0
% INFO    : Bus 86251	: V=0.9532005, theta=-36.848527 -> V=1.0, theta=0.0
% INFO    : Bus 86252	: V=0.9538824, theta=-39.067719 -> V=1.0, theta=0.0
% INFO    : Bus 86253	: V=0.9509793, theta=-39.114438 -> V=1.0, theta=0.0
% INFO    : Bus 86254	: V=0.9540598, theta=-40.111666 -> V=1.0, theta=0.0
% INFO    : Bus 86255	: V=0.9521637, theta=-41.382377 -> V=1.0, theta=0.0
% INFO    : Bus 86256	: V=0.9504913, theta=-41.748687 -> V=1.0, theta=0.0
% INFO    : Bus 86257	: V=0.9546873, theta=-40.18262 -> V=1.0, theta=0.0
% INFO    : Bus 86258	: V=0.9521662, theta=-40.907985 -> V=1.0, theta=0.0
% INFO    : Bus 86259	: V=0.9545111, theta=-40.781121 -> V=1.0, theta=0.0
% INFO    : Bus 86260	: V=0.952093, theta=-40.415063 -> V=1.0, theta=0.0
% INFO    : Bus 86261	: V=0.9568791, theta=-38.69133 -> V=1.0, theta=0.0
% INFO    : Bus 86262	: V=0.9581396, theta=-38.675607 -> V=1.0, theta=0.0
% INFO    : Bus 86263	: V=0.9525771, theta=-40.56282 -> V=1.0, theta=0.0
% INFO    : Bus 86264	: V=0.9541431, theta=-39.9884 -> V=1.0, theta=0.0
% INFO    : Bus 86265	: V=0.9513689, theta=-39.930328 -> V=1.0, theta=0.0
% INFO    : Bus 86266	: V=0.9530722, theta=-40.570281 -> V=1.0, theta=0.0
% INFO    : Bus 86267	: V=0.9521395, theta=-40.500732 -> V=1.0, theta=0.0
% INFO    : Bus 86268	: V=0.9538503, theta=-40.12378 -> V=1.0, theta=0.0
% INFO    : Bus 86269	: V=0.9551192, theta=-40.592108 -> V=1.0, theta=0.0
% INFO    : Bus 86270	: V=0.9559396, theta=-40.868424 -> V=1.0, theta=0.0
% INFO    : Bus 86271	: V=0.9544915, theta=-40.542643 -> V=1.0, theta=0.0
% INFO    : Bus 86272	: V=0.958135, theta=-39.75569 -> V=1.0, theta=0.0
% INFO    : Bus 86273	: V=0.9539245, theta=-37.688549 -> V=1.0, theta=0.0
% INFO    : Bus 86274	: V=0.9567937, theta=-39.019032 -> V=1.0, theta=0.0
% INFO    : Bus 86275	: V=0.9518436, theta=-37.758753 -> V=1.0, theta=0.0
% INFO    : Bus 86276	: V=0.9554449, theta=-37.185839 -> V=1.0, theta=0.0
% INFO    : Bus 86277	: V=0.9861631, theta=-43.014312 -> V=1.0, theta=0.0
% INFO    : Bus 86278	: V=0.985136, theta=-44.871369 -> V=1.0, theta=0.0
% INFO    : Bus 86279	: V=0.9890763, theta=-45.741593 -> V=1.0, theta=0.0
% INFO    : Bus 86280	: V=0.9905488, theta=-47.046481 -> V=1.0, theta=0.0
% INFO    : Bus 86281	: V=0.987935, theta=-46.92486 -> V=1.0, theta=0.0
% INFO    : Bus 86282	: V=0.9796433, theta=-55.175733 -> V=1.0, theta=0.0
% INFO    : Bus 86283	: V=0.9803124, theta=-54.56537 -> V=1.0, theta=0.0
% INFO    : Bus 86284	: V=0.9937931, theta=-52.886204 -> V=1.0, theta=0.0
% INFO    : Bus 86285	: V=0.9857007, theta=-30.121462 -> V=1.0, theta=0.0
% INFO    : Bus 86286	: V=0.9773204, theta=-30.242456 -> V=1.0, theta=0.0
% INFO    : Bus 86287	: V=0.9805028, theta=-30.340836 -> V=1.0, theta=0.0
% INFO    : Bus 86288	: V=0.9926684, theta=-29.619313 -> V=1.0, theta=0.0
% INFO    : Bus 86289	: V=0.9874578, theta=-29.864378 -> V=1.0, theta=0.0
% INFO    : Bus 86290	: V=0.9757326, theta=-30.999834 -> V=1.0, theta=0.0
% INFO    : Bus 86291	: V=0.9666818, theta=-55.40923 -> V=1.0, theta=0.0
% INFO    : Bus 86292	: V=1.0059554, theta=-28.252577 -> V=1.0, theta=0.0
% INFO    : Bus 86293	: V=0.989277, theta=-31.963115 -> V=1.0, theta=0.0
% INFO    : Bus 86294	: V=0.991861, theta=-31.680968 -> V=1.0, theta=0.0
% INFO    : Bus 86295	: V=0.9888529, theta=-32.086009 -> V=1.0, theta=0.0
% INFO    : Bus 86296	: V=0.9685709, theta=-35.894748 -> V=1.0, theta=0.0
% INFO    : Bus 86297	: V=0.9800019, theta=-33.040454 -> V=1.0, theta=0.0
% INFO    : Bus 86298	: V=0.9835692, theta=-33.081113 -> V=1.0, theta=0.0
% INFO    : Bus 86299	: V=0.9763275, theta=-45.148086 -> V=1.0, theta=0.0
% INFO    : Bus 86300	: V=0.9782756, theta=-46.643316 -> V=1.0, theta=0.0
% INFO    : Bus 86301	: V=0.9828913, theta=-48.230079 -> V=1.0, theta=0.0
% INFO    : Bus 86302	: V=0.9825798, theta=-48.741418 -> V=1.0, theta=0.0
% INFO    : Bus 86303	: V=0.9800404, theta=-48.907581 -> V=1.0, theta=0.0
% INFO    : Bus 86304	: V=0.9522554, theta=-42.357902 -> V=1.0, theta=0.0
% INFO    : Bus 86305	: V=0.9521506, theta=-42.455055 -> V=1.0, theta=0.0
% INFO    : Bus 86306	: V=0.9553222, theta=-41.905699 -> V=1.0, theta=0.0
% INFO    : Bus 86307	: V=0.9524782, theta=-42.116961 -> V=1.0, theta=0.0
% INFO    : Bus 86308	: V=0.9546287, theta=-42.124795 -> V=1.0, theta=0.0
% INFO    : Bus 86309	: V=0.9552817, theta=-42.012776 -> V=1.0, theta=0.0
% INFO    : Bus 86310	: V=0.9707176, theta=-36.611954 -> V=1.0, theta=0.0
% INFO    : Bus 86311	: V=0.9594071, theta=-39.941171 -> V=1.0, theta=0.0
% INFO    : Bus 86312	: V=0.958506, theta=-41.06515 -> V=1.0, theta=0.0
% INFO    : Bus 86313	: V=0.949369, theta=-42.548096 -> V=1.0, theta=0.0
% INFO    : Bus 86314	: V=0.9479959, theta=-42.748361 -> V=1.0, theta=0.0
% INFO    : Bus 86315	: V=0.9487695, theta=-42.609749 -> V=1.0, theta=0.0
% INFO    : Bus 86316	: V=0.9481422, theta=-42.904715 -> V=1.0, theta=0.0
% INFO    : Bus 86317	: V=0.9509871, theta=-42.458851 -> V=1.0, theta=0.0
% INFO    : Bus 86318	: V=0.9492985, theta=-42.792659 -> V=1.0, theta=0.0
% INFO    : Bus 86319	: V=0.9564686, theta=-40.676534 -> V=1.0, theta=0.0
% INFO    : Bus 86320	: V=0.95874, theta=-41.248751 -> V=1.0, theta=0.0
% INFO    : Bus 86321	: V=0.9517193, theta=-42.986198 -> V=1.0, theta=0.0
% INFO    : Bus 86322	: V=0.9519475, theta=-42.686453 -> V=1.0, theta=0.0
% INFO    : Bus 86323	: V=0.9476398, theta=-43.007444 -> V=1.0, theta=0.0
% INFO    : Bus 86324	: V=0.9484469, theta=-42.927196 -> V=1.0, theta=0.0
% INFO    : Bus 86325	: V=0.9486748, theta=-42.300968 -> V=1.0, theta=0.0
% INFO    : Bus 86326	: V=0.9476287, theta=-42.733221 -> V=1.0, theta=0.0
% INFO    : Bus 86327	: V=0.9463334, theta=-42.896713 -> V=1.0, theta=0.0
% INFO    : Bus 86328	: V=0.9459826, theta=-43.2004 -> V=1.0, theta=0.0
% INFO    : Bus 86329	: V=0.9428534, theta=-43.603374 -> V=1.0, theta=0.0
% INFO    : Bus 86330	: V=0.9508073, theta=-42.920824 -> V=1.0, theta=0.0
% INFO    : Bus 86331	: V=0.9446796, theta=-42.907082 -> V=1.0, theta=0.0
% INFO    : Bus 86332	: V=0.9454184, theta=-42.901221 -> V=1.0, theta=0.0
% INFO    : Bus 86333	: V=0.949325, theta=-42.045576 -> V=1.0, theta=0.0
% INFO    : Bus 86334	: V=0.9462371, theta=-42.883916 -> V=1.0, theta=0.0
% INFO    : Bus 86335	: V=0.978195, theta=-35.420231 -> V=1.0, theta=0.0
% INFO    : Bus 86336	: V=0.981555, theta=-39.575037 -> V=1.0, theta=0.0
% INFO    : Bus 86337	: V=0.9888596, theta=-40.857578 -> V=1.0, theta=0.0
% INFO    : Bus 86338	: V=0.9811745, theta=-43.388854 -> V=1.0, theta=0.0
% INFO    : Bus 86339	: V=0.9777119, theta=-51.20009 -> V=1.0, theta=0.0
% INFO    : Bus 86340	: V=0.9826777, theta=-51.055447 -> V=1.0, theta=0.0
% INFO    : Bus 86341	: V=0.9812625, theta=-51.473647 -> V=1.0, theta=0.0
% INFO    : Bus 86342	: V=0.9785255, theta=-51.1318 -> V=1.0, theta=0.0
% INFO    : Bus 86343	: V=0.9795189, theta=-51.655447 -> V=1.0, theta=0.0
% INFO    : Bus 86344	: V=0.9557202, theta=-37.294784 -> V=1.0, theta=0.0
% INFO    : Bus 86345	: V=0.9624726, theta=-35.958625 -> V=1.0, theta=0.0
% INFO    : Bus 86346	: V=0.9625956, theta=-35.879885 -> V=1.0, theta=0.0
% INFO    : Bus 86347	: V=0.9507722, theta=-35.679532 -> V=1.0, theta=0.0
% INFO    : Bus 86348	: V=0.9579789, theta=-33.150617 -> V=1.0, theta=0.0
% INFO    : Bus 86349	: V=0.9519994, theta=-35.15458 -> V=1.0, theta=0.0
% INFO    : Bus 86350	: V=0.9607794, theta=-33.088728 -> V=1.0, theta=0.0
% INFO    : Bus 86351	: V=0.9558545, theta=-34.396565 -> V=1.0, theta=0.0
% INFO    : Bus 86352	: V=0.9826817, theta=-47.634474 -> V=1.0, theta=0.0
% INFO    : Bus 86353	: V=0.9946489, theta=-28.976949 -> V=1.0, theta=0.0
% INFO    : Bus 86354	: V=1.0085817, theta=-27.80168 -> V=1.0, theta=0.0
% INFO    : Bus 86355	: V=1.0150905, theta=-26.625987 -> V=1.0, theta=0.0
% INFO    : Bus 86356	: V=1.0185831, theta=-25.539064 -> V=1.0, theta=0.0
% INFO    : Bus 86357	: V=1.0164927, theta=-25.899551 -> V=1.0, theta=0.0
% INFO    : Bus 86358	: V=0.9966866, theta=-29.200249 -> V=1.0, theta=0.0
% INFO    : Bus 86359	: V=1.0046049, theta=-29.602206 -> V=1.0, theta=0.0
% INFO    : Bus 86360	: V=1.0112593, theta=-25.439756 -> V=1.0, theta=0.0
% INFO    : Bus 86361	: V=0.9559726, theta=-38.290776 -> V=1.0, theta=0.0
% INFO    : Bus 86362	: V=0.9644602, theta=-35.599027 -> V=1.0, theta=0.0
% INFO    : Bus 86363	: V=0.962777, theta=-35.830761 -> V=1.0, theta=0.0
% INFO    : Bus 86364	: V=0.960593, theta=-36.305658 -> V=1.0, theta=0.0
% INFO    : Bus 86365	: V=0.9613488, theta=-37.160109 -> V=1.0, theta=0.0
% INFO    : Bus 86366	: V=0.9540384, theta=-37.178003 -> V=1.0, theta=0.0
% INFO    : Bus 86367	: V=0.9531812, theta=-38.572455 -> V=1.0, theta=0.0
% INFO    : Bus 86368	: V=0.9935241, theta=-26.49345 -> V=1.0, theta=0.0
% INFO    : Bus 86369	: V=0.9914079, theta=-26.65859 -> V=1.0, theta=0.0
% INFO    : Bus 86370	: V=0.9868209, theta=-27.597083 -> V=1.0, theta=0.0
% INFO    : Bus 86371	: V=1.0073213, theta=-25.487067 -> V=1.0, theta=0.0
% INFO    : Bus 86372	: V=0.9853625, theta=-27.335824 -> V=1.0, theta=0.0
% INFO    : Bus 86373	: V=0.9916782, theta=-27.540191 -> V=1.0, theta=0.0
% INFO    : Bus 86374	: V=0.9877549, theta=-27.348494 -> V=1.0, theta=0.0
% INFO    : Bus 86375	: V=1.0108385, theta=-25.446887 -> V=1.0, theta=0.0
% INFO    : Bus 86376	: V=0.9550497, theta=-40.630788 -> V=1.0, theta=0.0
% INFO    : Bus 86377	: V=0.9555023, theta=-41.923913 -> V=1.0, theta=0.0
% INFO    : Bus 86378	: V=0.9531578, theta=-42.52137 -> V=1.0, theta=0.0
% INFO    : Bus 86379	: V=0.9536735, theta=-42.30454 -> V=1.0, theta=0.0
% INFO    : Bus 86380	: V=0.9565649, theta=-42.317289 -> V=1.0, theta=0.0
% INFO    : Bus 86381	: V=0.9639038, theta=-42.200128 -> V=1.0, theta=0.0
% INFO    : Bus 86382	: V=0.9488323, theta=-43.552295 -> V=1.0, theta=0.0
% INFO    : Bus 86383	: V=0.9923017, theta=-36.072726 -> V=1.0, theta=0.0
% INFO    : Bus 86384	: V=0.949152, theta=-42.307673 -> V=1.0, theta=0.0
% INFO    : Bus 86385	: V=0.9528818, theta=-41.291655 -> V=1.0, theta=0.0
% INFO    : Bus 86386	: V=0.9501847, theta=-42.062538 -> V=1.0, theta=0.0
% INFO    : Bus 86387	: V=0.9507772, theta=-41.937386 -> V=1.0, theta=0.0
% INFO    : Bus 86388	: V=0.9496676, theta=-42.09019 -> V=1.0, theta=0.0
% INFO    : Bus 86389	: V=0.9491131, theta=-42.176226 -> V=1.0, theta=0.0
% INFO    : Bus 86390	: V=0.9522183, theta=-41.406394 -> V=1.0, theta=0.0
% INFO    : Bus 86391	: V=0.9516484, theta=-41.449179 -> V=1.0, theta=0.0
% INFO    : Bus 86392	: V=0.9486186, theta=-42.082121 -> V=1.0, theta=0.0
% INFO    : Bus 86393	: V=0.9521414, theta=-41.373066 -> V=1.0, theta=0.0
% INFO    : Bus 86394	: V=0.9504041, theta=-41.216762 -> V=1.0, theta=0.0
% INFO    : Bus 86395	: V=0.947984, theta=-41.961695 -> V=1.0, theta=0.0
% INFO    : Bus 86396	: V=0.9514349, theta=-40.842488 -> V=1.0, theta=0.0
% INFO    : Bus 86397	: V=0.9535249, theta=-40.417856 -> V=1.0, theta=0.0
% INFO    : Bus 86398	: V=0.9507975, theta=-40.78543 -> V=1.0, theta=0.0
% INFO    : Bus 86399	: V=0.9491436, theta=-41.472589 -> V=1.0, theta=0.0
% INFO    : Bus 86400	: V=0.9481794, theta=-40.503934 -> V=1.0, theta=0.0
% INFO    : Bus 86401	: V=0.9486699, theta=-41.504969 -> V=1.0, theta=0.0
% INFO    : Bus 86402	: V=0.9467647, theta=-43.664574 -> V=1.0, theta=0.0
% INFO    : Bus 86403	: V=0.9536744, theta=-39.665451 -> V=1.0, theta=0.0
% INFO    : Bus 86404	: V=0.9574556, theta=-38.356763 -> V=1.0, theta=0.0
% INFO    : Bus 86405	: V=0.9594182, theta=-38.395085 -> V=1.0, theta=0.0
% INFO    : Bus 86406	: V=0.964815, theta=-37.967221 -> V=1.0, theta=0.0
% INFO    : Bus 86407	: V=0.9593637, theta=-38.942005 -> V=1.0, theta=0.0
% INFO    : Bus 86408	: V=0.9544429, theta=-39.965191 -> V=1.0, theta=0.0
% INFO    : Bus 86409	: V=0.9639452, theta=-38.410255 -> V=1.0, theta=0.0
% INFO    : Bus 86410	: V=0.9532782, theta=-40.734061 -> V=1.0, theta=0.0
% INFO    : Bus 86411	: V=0.9557774, theta=-40.155114 -> V=1.0, theta=0.0
% INFO    : Bus 86412	: V=0.9528913, theta=-41.52616 -> V=1.0, theta=0.0
% INFO    : Bus 86413	: V=0.9519726, theta=-41.288854 -> V=1.0, theta=0.0
% INFO    : Bus 86414	: V=0.9518718, theta=-42.250197 -> V=1.0, theta=0.0
% INFO    : Bus 86415	: V=0.9499553, theta=-42.403111 -> V=1.0, theta=0.0
% INFO    : Bus 86416	: V=0.951067, theta=-42.155862 -> V=1.0, theta=0.0
% INFO    : Bus 86417	: V=0.9585787, theta=-39.748483 -> V=1.0, theta=0.0
% INFO    : Bus 86418	: V=0.9526396, theta=-41.298981 -> V=1.0, theta=0.0
% INFO    : Bus 86419	: V=0.9528527, theta=-41.552587 -> V=1.0, theta=0.0
% INFO    : Bus 86420	: V=0.9517284, theta=-41.953096 -> V=1.0, theta=0.0
% INFO    : Bus 86421	: V=0.9561758, theta=-41.013821 -> V=1.0, theta=0.0
% INFO    : Bus 86422	: V=0.9795772, theta=-33.919363 -> V=1.0, theta=0.0
% INFO    : Bus 86423	: V=0.9710654, theta=-36.033803 -> V=1.0, theta=0.0
% INFO    : Bus 86424	: V=0.970292, theta=-36.247836 -> V=1.0, theta=0.0
% INFO    : Bus 86425	: V=0.9723279, theta=-33.751872 -> V=1.0, theta=0.0
% INFO    : Bus 86426	: V=0.9539991, theta=-38.581412 -> V=1.0, theta=0.0
% INFO    : Bus 86427	: V=0.9840133, theta=-32.98847 -> V=1.0, theta=0.0
% INFO    : Bus 86428	: V=0.9735509, theta=-35.274784 -> V=1.0, theta=0.0
% INFO    : Bus 86429	: V=0.969924, theta=-35.955314 -> V=1.0, theta=0.0
% INFO    : Bus 86430	: V=0.9624754, theta=-37.057711 -> V=1.0, theta=0.0
% INFO    : Bus 86431	: V=0.9569098, theta=-38.419166 -> V=1.0, theta=0.0
% INFO    : Bus 86432	: V=0.951252, theta=-39.844063 -> V=1.0, theta=0.0
% INFO    : Bus 86433	: V=0.9487231, theta=-40.170714 -> V=1.0, theta=0.0
% INFO    : Bus 86434	: V=0.9489748, theta=-40.406666 -> V=1.0, theta=0.0
% INFO    : Bus 86435	: V=0.9495559, theta=-40.055831 -> V=1.0, theta=0.0
% INFO    : Bus 86436	: V=0.9557102, theta=-38.447704 -> V=1.0, theta=0.0
% INFO    : Bus 86437	: V=0.9486099, theta=-42.398017 -> V=1.0, theta=0.0
% INFO    : Bus 86438	: V=0.9455356, theta=-43.433886 -> V=1.0, theta=0.0
% INFO    : Bus 86439	: V=0.9510089, theta=-41.57866 -> V=1.0, theta=0.0
% INFO    : Bus 86440	: V=0.9485508, theta=-41.887062 -> V=1.0, theta=0.0
% INFO    : Bus 86441	: V=0.9500222, theta=-41.405313 -> V=1.0, theta=0.0
% INFO    : Bus 86442	: V=0.9487595, theta=-40.11176 -> V=1.0, theta=0.0
% INFO    : Bus 86443	: V=0.9895629, theta=-32.884504 -> V=1.0, theta=0.0
% INFO    : Bus 86444	: V=1.0085928, theta=-25.530187 -> V=1.0, theta=0.0
% INFO    : Bus 86445	: V=1.0034765, theta=-39.216782 -> V=1.0, theta=0.0
% INFO    : Bus 86446	: V=1.0113563, theta=-39.036459 -> V=1.0, theta=0.0
% INFO    : Bus 86447	: V=1.0032414, theta=-39.881537 -> V=1.0, theta=0.0
% INFO    : Bus 86448	: V=1.0124369, theta=-39.152767 -> V=1.0, theta=0.0
% INFO    : Bus 86449	: V=1.0104745, theta=-39.432568 -> V=1.0, theta=0.0
% INFO    : Bus 86450	: V=1.0112843, theta=-39.172804 -> V=1.0, theta=0.0
% INFO    : Bus 86451	: V=1.0112364, theta=-39.444658 -> V=1.0, theta=0.0
% INFO    : Bus 86452	: V=1.0112778, theta=-40.408362 -> V=1.0, theta=0.0
% INFO    : Bus 86453	: V=1.0053713, theta=-41.227066 -> V=1.0, theta=0.0
% INFO    : Bus 86454	: V=0.9894531, theta=-30.277853 -> V=1.0, theta=0.0
% INFO    : Bus 86455	: V=0.9708021, theta=-31.0971 -> V=1.0, theta=0.0
% INFO    : Bus 86456	: V=0.9614927, theta=-31.772895 -> V=1.0, theta=0.0
% INFO    : Bus 86457	: V=1.0150931, theta=-27.93199 -> V=1.0, theta=0.0
% INFO    : Bus 86458	: V=1.0137714, theta=-28.03283 -> V=1.0, theta=0.0
% INFO    : Bus 86459	: V=1.007043, theta=-28.880434 -> V=1.0, theta=0.0
% INFO    : Bus 86460	: V=1.0119177, theta=-28.017424 -> V=1.0, theta=0.0
% INFO    : Bus 86461	: V=0.9554484, theta=-42.83 -> V=1.0, theta=0.0
% INFO    : Bus 86462	: V=0.952077, theta=-43.317579 -> V=1.0, theta=0.0
% INFO    : Bus 86463	: V=0.9515881, theta=-43.970781 -> V=1.0, theta=0.0
% INFO    : Bus 86464	: V=0.9526583, theta=-44.134115 -> V=1.0, theta=0.0
% INFO    : Bus 86465	: V=0.9513774, theta=-43.816663 -> V=1.0, theta=0.0
% INFO    : Bus 86466	: V=0.9532534, theta=-43.267791 -> V=1.0, theta=0.0
% INFO    : Bus 86467	: V=0.9534407, theta=-43.210791 -> V=1.0, theta=0.0
% INFO    : Bus 86468	: V=0.9666395, theta=-37.6344 -> V=1.0, theta=0.0
% INFO    : Bus 86469	: V=0.9585991, theta=-40.795163 -> V=1.0, theta=0.0
% INFO    : Bus 86470	: V=0.9573121, theta=-42.071217 -> V=1.0, theta=0.0
% INFO    : Bus 86471	: V=0.9571085, theta=-41.240327 -> V=1.0, theta=0.0
% INFO    : Bus 86472	: V=0.9594445, theta=-41.166171 -> V=1.0, theta=0.0
% INFO    : Bus 86473	: V=0.955154, theta=-42.640024 -> V=1.0, theta=0.0
% INFO    : Bus 86474	: V=0.952179, theta=-43.302577 -> V=1.0, theta=0.0
% INFO    : Bus 86475	: V=0.9557853, theta=-42.226505 -> V=1.0, theta=0.0
% INFO    : Bus 86476	: V=0.9549633, theta=-42.710939 -> V=1.0, theta=0.0
% INFO    : Bus 86477	: V=0.951367, theta=-43.618202 -> V=1.0, theta=0.0
% INFO    : Bus 86478	: V=0.9560567, theta=-41.998726 -> V=1.0, theta=0.0
% INFO    : Bus 86479	: V=0.9560476, theta=-42.219428 -> V=1.0, theta=0.0
% INFO    : Bus 86480	: V=0.9501154, theta=-44.228906 -> V=1.0, theta=0.0
% INFO    : Bus 86481	: V=0.9551023, theta=-44.161312 -> V=1.0, theta=0.0
% INFO    : Bus 86482	: V=0.9557223, theta=-43.254423 -> V=1.0, theta=0.0
% INFO    : Bus 86483	: V=0.963629, theta=-41.905507 -> V=1.0, theta=0.0
% INFO    : Bus 86484	: V=0.9591501, theta=-42.178969 -> V=1.0, theta=0.0
% INFO    : Bus 86485	: V=0.9558988, theta=-42.704541 -> V=1.0, theta=0.0
% INFO    : Bus 86486	: V=0.9726284, theta=-41.526651 -> V=1.0, theta=0.0
% INFO    : Bus 86487	: V=0.9592898, theta=-42.429318 -> V=1.0, theta=0.0
% INFO    : Bus 86488	: V=0.9691978, theta=-39.473183 -> V=1.0, theta=0.0
% INFO    : Bus 86489	: V=0.9464761, theta=-42.649584 -> V=1.0, theta=0.0
% INFO    : Bus 86490	: V=0.944381, theta=-42.204125 -> V=1.0, theta=0.0
% INFO    : Bus 86491	: V=0.95328, theta=-41.982603 -> V=1.0, theta=0.0
% INFO    : Bus 86492	: V=0.9526961, theta=-42.563677 -> V=1.0, theta=0.0
% INFO    : Bus 86493	: V=0.954153, theta=-41.906925 -> V=1.0, theta=0.0
% INFO    : Bus 86494	: V=0.9503968, theta=-42.240386 -> V=1.0, theta=0.0
% INFO    : Bus 86495	: V=0.9500148, theta=-42.875243 -> V=1.0, theta=0.0
% INFO    : Bus 86496	: V=0.9598128, theta=-41.541113 -> V=1.0, theta=0.0
% INFO    : Bus 86497	: V=0.9505649, theta=-42.992313 -> V=1.0, theta=0.0
% INFO    : Bus 86498	: V=0.9498008, theta=-43.313934 -> V=1.0, theta=0.0
% INFO    : Bus 86499	: V=0.9494033, theta=-43.280213 -> V=1.0, theta=0.0
% INFO    : Bus 86500	: V=0.9533784, theta=-42.704363 -> V=1.0, theta=0.0
% INFO    : Bus 86501	: V=0.9560119, theta=-42.01725 -> V=1.0, theta=0.0
% INFO    : Bus 86502	: V=0.9521501, theta=-42.756893 -> V=1.0, theta=0.0
% INFO    : Bus 86503	: V=0.9493565, theta=-43.155584 -> V=1.0, theta=0.0
% INFO    : Bus 86504	: V=0.9519044, theta=-42.878673 -> V=1.0, theta=0.0
% INFO    : Bus 86505	: V=0.953664, theta=-43.22897 -> V=1.0, theta=0.0
% INFO    : Bus 86506	: V=0.9538357, theta=-42.956947 -> V=1.0, theta=0.0
% INFO    : Bus 86507	: V=0.982545, theta=-29.315059 -> V=1.0, theta=0.0
% INFO    : Bus 86508	: V=0.9743574, theta=-34.58774 -> V=1.0, theta=0.0
% INFO    : Bus 86509	: V=0.9883109, theta=-32.929626 -> V=1.0, theta=0.0
% INFO    : Bus 86510	: V=1.0036601, theta=-34.959062 -> V=1.0, theta=0.0
% INFO    : Bus 86511	: V=1.0008209, theta=-28.747349 -> V=1.0, theta=0.0
% INFO    : Bus 86512	: V=0.9461626, theta=-41.802193 -> V=1.0, theta=0.0
% INFO    : Bus 86513	: V=0.944671, theta=-43.072969 -> V=1.0, theta=0.0
% INFO    : Bus 86514	: V=0.945496, theta=-41.892648 -> V=1.0, theta=0.0
% INFO    : Bus 86515	: V=0.9459847, theta=-42.001448 -> V=1.0, theta=0.0
% INFO    : Bus 86516	: V=0.9437555, theta=-42.132546 -> V=1.0, theta=0.0
% INFO    : Bus 86517	: V=0.9481039, theta=-42.131412 -> V=1.0, theta=0.0
% INFO    : Bus 86518	: V=0.9465579, theta=-38.473621 -> V=1.0, theta=0.0
% INFO    : Bus 86519	: V=0.9509507, theta=-39.461038 -> V=1.0, theta=0.0
% INFO    : Bus 86520	: V=1.000379, theta=-32.067692 -> V=1.0, theta=0.0
% INFO    : Bus 86521	: V=0.9914781, theta=-32.965524 -> V=1.0, theta=0.0
% INFO    : Bus 86522	: V=1.0032814, theta=-33.830726 -> V=1.0, theta=0.0
% INFO    : Bus 86523	: V=0.9953142, theta=-33.192026 -> V=1.0, theta=0.0
% INFO    : Bus 86524	: V=0.9979085, theta=-33.235696 -> V=1.0, theta=0.0
% INFO    : Bus 86525	: V=0.9889769, theta=-33.835217 -> V=1.0, theta=0.0
% INFO    : Bus 86526	: V=0.9854035, theta=-35.041394 -> V=1.0, theta=0.0
% INFO    : Bus 86527	: V=0.983, theta=-36.137469 -> V=1.0, theta=0.0
% INFO    : Bus 86528	: V=0.9648992, theta=-40.697539 -> V=1.0, theta=0.0
% INFO    : Bus 86529	: V=0.9716902, theta=-40.023221 -> V=1.0, theta=0.0
% INFO    : Bus 86530	: V=0.986684, theta=-37.078275 -> V=1.0, theta=0.0
% INFO    : Bus 86531	: V=0.9915981, theta=-35.97244 -> V=1.0, theta=0.0
% INFO    : Bus 86532	: V=0.9965169, theta=-31.022436 -> V=1.0, theta=0.0
% INFO    : Bus 86533	: V=0.9939599, theta=-31.715549 -> V=1.0, theta=0.0
% INFO    : Bus 86534	: V=0.9896059, theta=-27.74521 -> V=1.0, theta=0.0
% INFO    : Bus 86535	: V=0.9997403, theta=-27.38804 -> V=1.0, theta=0.0
% INFO    : Bus 86536	: V=0.995992, theta=-28.877263 -> V=1.0, theta=0.0
% INFO    : Bus 86537	: V=0.9698949, theta=-36.37374 -> V=1.0, theta=0.0
% INFO    : Bus 86538	: V=0.9856588, theta=-29.350436 -> V=1.0, theta=0.0
% INFO    : Bus 86539	: V=0.9889317, theta=-30.795824 -> V=1.0, theta=0.0
% INFO    : Bus 86540	: V=0.9869023, theta=-31.110712 -> V=1.0, theta=0.0
% INFO    : Bus 86541	: V=0.9820191, theta=-33.361191 -> V=1.0, theta=0.0
% INFO    : Bus 86542	: V=0.9761228, theta=-50.289824 -> V=1.0, theta=0.0
% INFO    : Bus 86543	: V=0.9762184, theta=-50.464242 -> V=1.0, theta=0.0
% INFO    : Bus 86544	: V=0.9686256, theta=-34.609473 -> V=1.0, theta=0.0
% INFO    : Bus 86545	: V=0.9693229, theta=-34.34002 -> V=1.0, theta=0.0
% INFO    : Bus 86546	: V=0.972782, theta=-34.298304 -> V=1.0, theta=0.0
% INFO    : Bus 86547	: V=0.9727548, theta=-34.465588 -> V=1.0, theta=0.0
% INFO    : Bus 86548	: V=0.9733372, theta=-35.11725 -> V=1.0, theta=0.0
% INFO    : Bus 86549	: V=0.9997126, theta=-53.383921 -> V=1.0, theta=0.0
% INFO    : Bus 86550	: V=0.996836, theta=-54.627265 -> V=1.0, theta=0.0
% INFO    : Bus 86551	: V=0.9914267, theta=-55.870652 -> V=1.0, theta=0.0
% INFO    : Bus 86552	: V=0.9913012, theta=-56.029984 -> V=1.0, theta=0.0
% INFO    : Bus 86553	: V=0.9834681, theta=-56.05684 -> V=1.0, theta=0.0
% INFO    : Bus 86554	: V=0.991276, theta=-55.976227 -> V=1.0, theta=0.0
% INFO    : Bus 86555	: V=0.9552727, theta=-41.030338 -> V=1.0, theta=0.0
% INFO    : Bus 86556	: V=1.0055909, theta=-27.403446 -> V=1.0, theta=0.0
% INFO    : Bus 86557	: V=1.0056321, theta=-27.372231 -> V=1.0, theta=0.0
% INFO    : Bus 86558	: V=1.0099168, theta=-26.477038 -> V=1.0, theta=0.0
% INFO    : Bus 86559	: V=1.0095274, theta=-32.498905 -> V=1.0, theta=0.0
% INFO    : Bus 86560	: V=1.0157574, theta=-31.601881 -> V=1.0, theta=0.0
% INFO    : Bus 86561	: V=1.0151501, theta=-31.634883 -> V=1.0, theta=0.0
% INFO    : Bus 86562	: V=1.0151434, theta=-32.01932 -> V=1.0, theta=0.0
% INFO    : Bus 86563	: V=1.0049409, theta=-34.004647 -> V=1.0, theta=0.0
% INFO    : Bus 86564	: V=0.978711, theta=-40.033279 -> V=1.0, theta=0.0
% INFO    : Bus 86565	: V=0.9811895, theta=-32.890292 -> V=1.0, theta=0.0
% INFO    : Bus 86566	: V=0.9871819, theta=-32.525083 -> V=1.0, theta=0.0
% INFO    : Bus 86567	: V=0.9857341, theta=-33.474822 -> V=1.0, theta=0.0
% INFO    : Bus 86568	: V=0.9718774, theta=-49.274315 -> V=1.0, theta=0.0
% INFO    : Bus 86569	: V=0.9938314, theta=-52.797028 -> V=1.0, theta=0.0
% INFO    : Bus 86570	: V=1.0058195, theta=-28.663335 -> V=1.0, theta=0.0
% INFO    : Bus 86571	: V=1.0006346, theta=-30.186226 -> V=1.0, theta=0.0
% INFO    : Bus 86572	: V=0.990954, theta=-32.6272 -> V=1.0, theta=0.0
% INFO    : Bus 86573	: V=0.9906867, theta=-29.698746 -> V=1.0, theta=0.0
% INFO    : Bus 86574	: V=0.9992696, theta=-27.854865 -> V=1.0, theta=0.0
% INFO    : Bus 86575	: V=0.9994356, theta=-28.740794 -> V=1.0, theta=0.0
% INFO    : Bus 86576	: V=0.9917532, theta=-36.731209 -> V=1.0, theta=0.0
% INFO    : Bus 86577	: V=0.9630398, theta=-38.172752 -> V=1.0, theta=0.0
% INFO    : Bus 86578	: V=0.9613515, theta=-38.095996 -> V=1.0, theta=0.0
% INFO    : Bus 86579	: V=0.9621007, theta=-38.60727 -> V=1.0, theta=0.0
% INFO    : Bus 86580	: V=0.9608528, theta=-38.757289 -> V=1.0, theta=0.0
% INFO    : Bus 86581	: V=0.9616916, theta=-38.835563 -> V=1.0, theta=0.0
% INFO    : Bus 86582	: V=0.9638422, theta=-37.593693 -> V=1.0, theta=0.0
% INFO    : Bus 86583	: V=0.9835391, theta=-34.051232 -> V=1.0, theta=0.0
% INFO    : Bus 86584	: V=0.9642504, theta=-37.192024 -> V=1.0, theta=0.0
% INFO    : Bus 86585	: V=0.9614505, theta=-37.867503 -> V=1.0, theta=0.0
% INFO    : Bus 86586	: V=0.9645072, theta=-37.555679 -> V=1.0, theta=0.0
% INFO    : Bus 86587	: V=0.96303, theta=-37.858445 -> V=1.0, theta=0.0
% INFO    : Bus 86588	: V=0.9619956, theta=-38.153146 -> V=1.0, theta=0.0
% INFO    : Bus 86589	: V=0.9658901, theta=-37.49018 -> V=1.0, theta=0.0
% INFO    : Bus 86590	: V=0.9642423, theta=-37.809917 -> V=1.0, theta=0.0
% INFO    : Bus 86591	: V=0.9636932, theta=-38.685491 -> V=1.0, theta=0.0
% INFO    : Bus 86592	: V=0.9992233, theta=-36.564521 -> V=1.0, theta=0.0
% INFO    : Bus 86593	: V=0.9707381, theta=-35.060783 -> V=1.0, theta=0.0
% INFO    : Bus 86594	: V=0.9612225, theta=-39.068989 -> V=1.0, theta=0.0
% INFO    : Bus 86595	: V=0.9609513, theta=-39.201647 -> V=1.0, theta=0.0
% INFO    : Bus 86596	: V=0.9594515, theta=-39.216969 -> V=1.0, theta=0.0
% INFO    : Bus 86597	: V=0.9687532, theta=-37.350158 -> V=1.0, theta=0.0
% INFO    : Bus 86598	: V=0.9680558, theta=-37.566143 -> V=1.0, theta=0.0
% INFO    : Bus 86599	: V=0.9661898, theta=-36.911803 -> V=1.0, theta=0.0
% INFO    : Bus 86600	: V=0.9538997, theta=-40.160129 -> V=1.0, theta=0.0
% INFO    : Bus 86601	: V=1.0022604, theta=-35.123972 -> V=1.0, theta=0.0
% INFO    : Bus 86602	: V=0.9846798, theta=-35.413598 -> V=1.0, theta=0.0
% INFO    : Bus 86603	: V=0.9888885, theta=-34.023648 -> V=1.0, theta=0.0
% INFO    : Bus 86604	: V=1.0108717, theta=-30.284165 -> V=1.0, theta=0.0
% INFO    : Bus 86605	: V=1.0103563, theta=-30.53307 -> V=1.0, theta=0.0
% INFO    : Bus 86606	: V=0.9611152, theta=-35.340242 -> V=1.0, theta=0.0
% INFO    : Bus 86607	: V=0.9589647, theta=-35.552656 -> V=1.0, theta=0.0
% INFO    : Bus 86608	: V=0.9545619, theta=-36.288922 -> V=1.0, theta=0.0
% INFO    : Bus 86609	: V=0.9547358, theta=-33.871524 -> V=1.0, theta=0.0
% INFO    : Bus 86610	: V=0.9662265, theta=-32.443897 -> V=1.0, theta=0.0
% INFO    : Bus 86611	: V=0.9560332, theta=-35.228152 -> V=1.0, theta=0.0
% INFO    : Bus 86612	: V=0.9865775, theta=-35.582134 -> V=1.0, theta=0.0
% INFO    : Bus 86613	: V=0.9707676, theta=-33.817557 -> V=1.0, theta=0.0
% INFO    : Bus 86614	: V=0.9644073, theta=-38.050943 -> V=1.0, theta=0.0
% INFO    : Bus 86615	: V=0.9990183, theta=-36.562415 -> V=1.0, theta=0.0
% INFO    : Bus 86616	: V=1.0027533, theta=-41.211695 -> V=1.0, theta=0.0
% INFO    : Bus 86617	: V=0.9995501, theta=-26.614168 -> V=1.0, theta=0.0
% INFO    : Bus 86618	: V=1.009418, theta=-25.513307 -> V=1.0, theta=0.0
% INFO    : Bus 86619	: V=0.9989206, theta=-27.096264 -> V=1.0, theta=0.0
% INFO    : Bus 86620	: V=0.9916974, theta=-27.757279 -> V=1.0, theta=0.0
% INFO    : Bus 86621	: V=1.0091688, theta=-27.047557 -> V=1.0, theta=0.0
% INFO    : Bus 86622	: V=1.0028805, theta=-39.603212 -> V=1.0, theta=0.0
% INFO    : Bus 86623	: V=0.9863269, theta=-39.364324 -> V=1.0, theta=0.0
% INFO    : Bus 86624	: V=0.966501, theta=-45.181686 -> V=1.0, theta=0.0
% INFO    : Bus 86625	: V=0.9773928, theta=-30.950769 -> V=1.0, theta=0.0
% INFO    : Bus 86626	: V=0.9780627, theta=-30.692338 -> V=1.0, theta=0.0
% INFO    : Bus 86627	: V=0.9747137, theta=-30.815162 -> V=1.0, theta=0.0
% INFO    : Bus 86628	: V=0.9730345, theta=-30.414997 -> V=1.0, theta=0.0
% INFO    : Bus 86629	: V=0.9799201, theta=-30.232129 -> V=1.0, theta=0.0
% INFO    : Bus 86630	: V=0.984369, theta=-30.133709 -> V=1.0, theta=0.0
% INFO    : Bus 86631	: V=0.9800096, theta=-29.416558 -> V=1.0, theta=0.0
% INFO    : Bus 86632	: V=0.9715832, theta=-29.981969 -> V=1.0, theta=0.0
% INFO    : Bus 86633	: V=0.9787297, theta=-30.740247 -> V=1.0, theta=0.0
% INFO    : Bus 86634	: V=0.9517262, theta=-42.564666 -> V=1.0, theta=0.0
% INFO    : Bus 86635	: V=0.9499833, theta=-42.507632 -> V=1.0, theta=0.0
% INFO    : Bus 86636	: V=0.9498184, theta=-42.751131 -> V=1.0, theta=0.0
% INFO    : Bus 86637	: V=0.9530655, theta=-42.088301 -> V=1.0, theta=0.0
% INFO    : Bus 86638	: V=0.94958, theta=-40.038446 -> V=1.0, theta=0.0
% INFO    : Bus 86639	: V=0.9932454, theta=-26.452168 -> V=1.0, theta=0.0
% INFO    : Bus 86640	: V=0.9780114, theta=-28.85473 -> V=1.0, theta=0.0
% INFO    : Bus 86641	: V=0.9704018, theta=-49.786409 -> V=1.0, theta=0.0
% INFO    : Bus 86642	: V=0.961153, theta=-38.613104 -> V=1.0, theta=0.0
% INFO    : Bus 86643	: V=0.9530018, theta=-39.281637 -> V=1.0, theta=0.0
% INFO    : Bus 86644	: V=0.9677371, theta=-36.40993 -> V=1.0, theta=0.0
% INFO    : Bus 86645	: V=0.9627362, theta=-38.391496 -> V=1.0, theta=0.0
% INFO    : Bus 86646	: V=0.96587, theta=-38.365744 -> V=1.0, theta=0.0
% INFO    : Bus 86647	: V=0.964318, theta=-38.050607 -> V=1.0, theta=0.0
% INFO    : Bus 86648	: V=0.9697997, theta=-42.407369 -> V=1.0, theta=0.0
% INFO    : Bus 86649	: V=0.9699428, theta=-44.646548 -> V=1.0, theta=0.0
% INFO    : Bus 86650	: V=0.9752136, theta=-47.964159 -> V=1.0, theta=0.0
% INFO    : Bus 86651	: V=0.9784551, theta=-46.78434 -> V=1.0, theta=0.0
% INFO    : Bus 86652	: V=0.9911736, theta=-39.704245 -> V=1.0, theta=0.0
% INFO    : Bus 86653	: V=0.9910091, theta=-41.445667 -> V=1.0, theta=0.0
% INFO    : Bus 86654	: V=0.9911642, theta=-41.223892 -> V=1.0, theta=0.0
% INFO    : Bus 86655	: V=0.9702312, theta=-46.120985 -> V=1.0, theta=0.0
% INFO    : Bus 86656	: V=0.9715448, theta=-47.199038 -> V=1.0, theta=0.0
% INFO    : Bus 86657	: V=0.9704451, theta=-47.58897 -> V=1.0, theta=0.0
% INFO    : Bus 86658	: V=0.9731898, theta=-53.734281 -> V=1.0, theta=0.0
% INFO    : Bus 86659	: V=0.9686342, theta=-53.494598 -> V=1.0, theta=0.0
% INFO    : Bus 86660	: V=0.9690911, theta=-52.421121 -> V=1.0, theta=0.0
% INFO    : Bus 86661	: V=0.9664913, theta=-53.289498 -> V=1.0, theta=0.0
% INFO    : Bus 86662	: V=1.0116835, theta=-26.362832 -> V=1.0, theta=0.0
% INFO    : Bus 86663	: V=1.0087053, theta=-25.221639 -> V=1.0, theta=0.0
% INFO    : Bus 86664	: V=0.9954657, theta=-30.340504 -> V=1.0, theta=0.0
% INFO    : Bus 86665	: V=0.993701, theta=-30.003861 -> V=1.0, theta=0.0
% INFO    : Bus 86666	: V=0.9813307, theta=-32.074589 -> V=1.0, theta=0.0
% INFO    : Bus 86667	: V=0.9857469, theta=-30.793273 -> V=1.0, theta=0.0
% INFO    : Bus 86668	: V=0.9851171, theta=-31.600587 -> V=1.0, theta=0.0
% INFO    : Bus 86669	: V=0.9781592, theta=-32.133425 -> V=1.0, theta=0.0
% INFO    : Bus 86670	: V=0.9845925, theta=-31.813154 -> V=1.0, theta=0.0
% INFO    : Bus 86671	: V=0.97902, theta=-33.438163 -> V=1.0, theta=0.0
% INFO    : Bus 86672	: V=0.9718511, theta=-50.367025 -> V=1.0, theta=0.0
% INFO    : Bus 86673	: V=0.9721792, theta=-39.861989 -> V=1.0, theta=0.0
% INFO    : Bus 86674	: V=1.0097299, theta=-34.365886 -> V=1.0, theta=0.0
% INFO    : Bus 86675	: V=1.0058655, theta=-36.119158 -> V=1.0, theta=0.0
% INFO    : Bus 86676	: V=1.0048416, theta=-35.340984 -> V=1.0, theta=0.0
% INFO    : Bus 86677	: V=0.9671452, theta=-29.613395 -> V=1.0, theta=0.0
% INFO    : Bus 86678	: V=1.0123957, theta=-37.000689 -> V=1.0, theta=0.0
% INFO    : Bus 86679	: V=0.9879967, theta=-39.222975 -> V=1.0, theta=0.0
% INFO    : Bus 86680	: V=0.9627699, theta=-42.519175 -> V=1.0, theta=0.0
% INFO    : Bus 86681	: V=0.9777296, theta=-39.870052 -> V=1.0, theta=0.0
% INFO    : Bus 86682	: V=0.9609462, theta=-41.250728 -> V=1.0, theta=0.0
% INFO    : Bus 86683	: V=0.9839809, theta=-37.082771 -> V=1.0, theta=0.0
% INFO    : Bus 86684	: V=0.9878175, theta=-43.256241 -> V=1.0, theta=0.0
% INFO    : Bus 86685	: V=1.0167799, theta=-46.997597 -> V=1.0, theta=0.0
% INFO    : Bus 86686	: V=0.9994996, theta=-26.396206 -> V=1.0, theta=0.0
% INFO    : Bus 86687	: V=1.007736, theta=-25.748656 -> V=1.0, theta=0.0
% INFO    : Bus 86688	: V=0.9996455, theta=-35.881834 -> V=1.0, theta=0.0
% INFO    : Bus 86689	: V=0.997406, theta=-37.186141 -> V=1.0, theta=0.0
% INFO    : Bus 86690	: V=0.9765648, theta=-40.448025 -> V=1.0, theta=0.0
% INFO    : Bus 86691	: V=0.9730336, theta=-41.320777 -> V=1.0, theta=0.0
% INFO    : Bus 86692	: V=0.9723346, theta=-43.222378 -> V=1.0, theta=0.0
% INFO    : Bus 86693	: V=0.9727351, theta=-35.578556 -> V=1.0, theta=0.0
% INFO    : Bus 86694	: V=0.9879772, theta=-28.551236 -> V=1.0, theta=0.0
% INFO    : Bus 86695	: V=0.97619, theta=-29.386179 -> V=1.0, theta=0.0
% INFO    : Bus 86696	: V=0.9875361, theta=-28.443546 -> V=1.0, theta=0.0
% INFO    : Bus 86697	: V=1.005371, theta=-26.003646 -> V=1.0, theta=0.0
% INFO    : Bus 86698	: V=1.007181, theta=-25.951086 -> V=1.0, theta=0.0
% INFO    : Bus 86699	: V=0.997661, theta=-27.06736 -> V=1.0, theta=0.0
% INFO    : Bus 86700	: V=1.0041038, theta=-25.955419 -> V=1.0, theta=0.0
% INFO    : Bus 86701	: V=0.9912061, theta=-44.114993 -> V=1.0, theta=0.0
% INFO    : Bus 86702	: V=1.009636, theta=-28.746707 -> V=1.0, theta=0.0
% INFO    : Bus 86703	: V=1.00575, theta=-28.515686 -> V=1.0, theta=0.0
% INFO    : Bus 86704	: V=1.0199564, theta=-23.470207 -> V=1.0, theta=0.0
% INFO    : Bus 86705	: V=1.0183759, theta=-24.215328 -> V=1.0, theta=0.0
% INFO    : Bus 86706	: V=1.017942, theta=-24.493419 -> V=1.0, theta=0.0
% INFO    : Bus 86707	: V=0.9695713, theta=-38.681148 -> V=1.0, theta=0.0
% INFO    : Bus 86708	: V=0.9870723, theta=-35.221137 -> V=1.0, theta=0.0
% INFO    : Bus 86709	: V=0.9755828, theta=-35.160315 -> V=1.0, theta=0.0
% INFO    : Bus 86710	: V=0.9768764, theta=-30.856375 -> V=1.0, theta=0.0
% INFO    : Bus 86711	: V=0.992691, theta=-28.742805 -> V=1.0, theta=0.0
% INFO    : Bus 86712	: V=0.9792914, theta=-30.014261 -> V=1.0, theta=0.0
% INFO    : Bus 86713	: V=0.978577, theta=-30.379161 -> V=1.0, theta=0.0
% INFO    : Bus 86714	: V=0.9736351, theta=-30.691107 -> V=1.0, theta=0.0
% INFO    : Bus 86715	: V=0.9777158, theta=-30.63449 -> V=1.0, theta=0.0
% INFO    : Bus 86716	: V=0.985588, theta=-28.956835 -> V=1.0, theta=0.0
% INFO    : Bus 86717	: V=0.9976269, theta=-28.517032 -> V=1.0, theta=0.0
% INFO    : Bus 86718	: V=0.9847825, theta=-30.225527 -> V=1.0, theta=0.0
% INFO    : Bus 86719	: V=0.9856, theta=-29.844479 -> V=1.0, theta=0.0
% INFO    : Bus 86720	: V=0.982783, theta=-29.438856 -> V=1.0, theta=0.0
% INFO    : Bus 86721	: V=0.9875432, theta=-27.814868 -> V=1.0, theta=0.0
% INFO    : Bus 86722	: V=0.9795947, theta=-29.829428 -> V=1.0, theta=0.0
% INFO    : Bus 86723	: V=0.9845234, theta=-29.401014 -> V=1.0, theta=0.0
% INFO    : Bus 86724	: V=0.9979869, theta=-27.487917 -> V=1.0, theta=0.0
% INFO    : Bus 86725	: V=0.9932751, theta=-27.707172 -> V=1.0, theta=0.0
% INFO    : Bus 86726	: V=0.9897974, theta=-26.832833 -> V=1.0, theta=0.0
% INFO    : Bus 86727	: V=0.9835755, theta=-36.832764 -> V=1.0, theta=0.0
% INFO    : Bus 86728	: V=0.9675582, theta=-40.613722 -> V=1.0, theta=0.0
% INFO    : Bus 86729	: V=0.9817167, theta=-39.154853 -> V=1.0, theta=0.0
% INFO    : Bus 86730	: V=0.9806532, theta=-39.167493 -> V=1.0, theta=0.0
% INFO    : Bus 86731	: V=0.9823593, theta=-38.728247 -> V=1.0, theta=0.0
% INFO    : Bus 86732	: V=0.979946, theta=-38.659906 -> V=1.0, theta=0.0
% INFO    : Bus 86733	: V=0.9925444, theta=-36.743822 -> V=1.0, theta=0.0
% INFO    : Bus 86734	: V=0.9984907, theta=-35.544324 -> V=1.0, theta=0.0
% INFO    : Bus 86735	: V=0.9801616, theta=-37.036116 -> V=1.0, theta=0.0
% INFO    : Bus 86736	: V=0.9804696, theta=-38.487268 -> V=1.0, theta=0.0
% INFO    : Bus 86737	: V=0.9864024, theta=-37.262037 -> V=1.0, theta=0.0
% INFO    : Bus 86738	: V=0.9832474, theta=-38.051679 -> V=1.0, theta=0.0
% INFO    : Bus 86739	: V=0.9942046, theta=-36.389452 -> V=1.0, theta=0.0
% INFO    : Bus 86740	: V=0.990335, theta=-36.68715 -> V=1.0, theta=0.0
% INFO    : Bus 86741	: V=0.9859695, theta=-36.697877 -> V=1.0, theta=0.0
% INFO    : Bus 86742	: V=0.9851342, theta=-36.122726 -> V=1.0, theta=0.0
% INFO    : Bus 86743	: V=0.983932, theta=-37.132906 -> V=1.0, theta=0.0
% INFO    : Bus 86744	: V=1.0093394, theta=-24.86342 -> V=1.0, theta=0.0
% INFO    : Bus 86745	: V=0.9842225, theta=-27.905499 -> V=1.0, theta=0.0
% INFO    : Bus 86746	: V=1.0022647, theta=-25.102568 -> V=1.0, theta=0.0
% INFO    : Bus 86747	: V=0.9963984, theta=-26.675039 -> V=1.0, theta=0.0
% INFO    : Bus 86748	: V=0.9931506, theta=-27.13322 -> V=1.0, theta=0.0
% INFO    : Bus 86749	: V=0.9869166, theta=-27.871972 -> V=1.0, theta=0.0
% INFO    : Bus 86750	: V=0.9849356, theta=-28.40217 -> V=1.0, theta=0.0
% INFO    : Bus 86751	: V=0.9855852, theta=-28.746078 -> V=1.0, theta=0.0
% INFO    : Bus 86752	: V=0.9798237, theta=-29.46534 -> V=1.0, theta=0.0
% INFO    : Bus 86753	: V=0.9836673, theta=-29.427113 -> V=1.0, theta=0.0
% INFO    : Bus 86754	: V=0.9860903, theta=-29.256514 -> V=1.0, theta=0.0
% INFO    : Bus 86755	: V=1.0119586, theta=-25.32731 -> V=1.0, theta=0.0
% INFO    : Bus 86756	: V=1.0075682, theta=-24.95072 -> V=1.0, theta=0.0
% INFO    : Bus 86757	: V=1.0048761, theta=-26.308061 -> V=1.0, theta=0.0
% INFO    : Bus 86758	: V=0.9773455, theta=-29.076863 -> V=1.0, theta=0.0
% INFO    : Bus 86759	: V=0.9872751, theta=-27.188117 -> V=1.0, theta=0.0
% INFO    : Bus 86760	: V=0.9915683, theta=-26.702917 -> V=1.0, theta=0.0
% INFO    : Bus 86761	: V=0.9824965, theta=-27.329196 -> V=1.0, theta=0.0
% INFO    : Bus 86762	: V=0.9886755, theta=-27.176493 -> V=1.0, theta=0.0
% INFO    : Bus 86763	: V=0.9755357, theta=-29.399225 -> V=1.0, theta=0.0
% INFO    : Bus 86764	: V=0.9597929, theta=-30.071818 -> V=1.0, theta=0.0
% INFO    : Bus 86765	: V=0.9605933, theta=-29.896189 -> V=1.0, theta=0.0
% INFO    : Bus 86766	: V=0.9617827, theta=-29.848528 -> V=1.0, theta=0.0
% INFO    : Bus 86767	: V=0.958558, theta=-30.097106 -> V=1.0, theta=0.0
% INFO    : Bus 86768	: V=0.9751192, theta=-29.265275 -> V=1.0, theta=0.0
% INFO    : Bus 86769	: V=0.9648992, theta=-29.923744 -> V=1.0, theta=0.0
% INFO    : Bus 86770	: V=0.9706103, theta=-29.25913 -> V=1.0, theta=0.0
% INFO    : Bus 86771	: V=0.9573193, theta=-30.647055 -> V=1.0, theta=0.0
% INFO    : Bus 86772	: V=0.9790158, theta=-28.81918 -> V=1.0, theta=0.0
% INFO    : Bus 86773	: V=0.9779729, theta=-28.811783 -> V=1.0, theta=0.0
% INFO    : Bus 86774	: V=0.9977325, theta=-29.316465 -> V=1.0, theta=0.0
% INFO    : Bus 86775	: V=1.0037128, theta=-28.871345 -> V=1.0, theta=0.0
% INFO    : Bus 86776	: V=0.9506874, theta=-32.341182 -> V=1.0, theta=0.0
% INFO    : Bus 86777	: V=0.9645551, theta=-31.088442 -> V=1.0, theta=0.0
% INFO    : Bus 86778	: V=0.9528332, theta=-32.076845 -> V=1.0, theta=0.0
% INFO    : Bus 86779	: V=0.9659817, theta=-29.348294 -> V=1.0, theta=0.0
% INFO    : Bus 86780	: V=0.9840365, theta=-27.475585 -> V=1.0, theta=0.0
% INFO    : Bus 86781	: V=0.9777456, theta=-28.093736 -> V=1.0, theta=0.0
% INFO    : Bus 86782	: V=0.9637402, theta=-30.352122 -> V=1.0, theta=0.0
% INFO    : Bus 86783	: V=0.9673874, theta=-29.64554 -> V=1.0, theta=0.0
% INFO    : Bus 86784	: V=0.9631997, theta=-30.116387 -> V=1.0, theta=0.0
% INFO    : Bus 86785	: V=0.9578511, theta=-30.69778 -> V=1.0, theta=0.0
% INFO    : Bus 86786	: V=0.9583729, theta=-30.38938 -> V=1.0, theta=0.0
% INFO    : Bus 86787	: V=0.9557565, theta=-30.74438 -> V=1.0, theta=0.0
% INFO    : Bus 86788	: V=0.9502725, theta=-30.99263 -> V=1.0, theta=0.0
% INFO    : Bus 86789	: V=0.9529562, theta=-30.970939 -> V=1.0, theta=0.0
% INFO    : Bus 86790	: V=0.9600535, theta=-30.556767 -> V=1.0, theta=0.0
% INFO    : Bus 86791	: V=0.9895809, theta=-27.093626 -> V=1.0, theta=0.0
% INFO    : Bus 86792	: V=0.9701532, theta=-29.3247 -> V=1.0, theta=0.0
% INFO    : Bus 86793	: V=0.9661708, theta=-29.859263 -> V=1.0, theta=0.0
% INFO    : Bus 86794	: V=0.9554219, theta=-31.807525 -> V=1.0, theta=0.0
% INFO    : Bus 86795	: V=0.9545667, theta=-30.673228 -> V=1.0, theta=0.0
% INFO    : Bus 86796	: V=0.9819442, theta=-27.811607 -> V=1.0, theta=0.0
% INFO    : Bus 86797	: V=0.9676982, theta=-44.93996 -> V=1.0, theta=0.0
% INFO    : Bus 86798	: V=1.009594, theta=-38.546915 -> V=1.0, theta=0.0
% INFO    : Bus 86799	: V=0.983551, theta=-41.490236 -> V=1.0, theta=0.0
% INFO    : Bus 86800	: V=0.9789276, theta=-42.282525 -> V=1.0, theta=0.0
% INFO    : Bus 86801	: V=0.9813774, theta=-35.265816 -> V=1.0, theta=0.0
% INFO    : Bus 86802	: V=0.9787945, theta=-36.777002 -> V=1.0, theta=0.0
% INFO    : Bus 86803	: V=0.995954, theta=-33.230846 -> V=1.0, theta=0.0
% INFO    : Bus 86804	: V=0.9907502, theta=-34.124881 -> V=1.0, theta=0.0
% INFO    : Bus 86805	: V=0.9550483, theta=-34.689645 -> V=1.0, theta=0.0
% INFO    : Bus 86806	: V=0.9693849, theta=-32.339174 -> V=1.0, theta=0.0
% INFO    : Bus 86807	: V=0.9621718, theta=-32.735308 -> V=1.0, theta=0.0
% INFO    : Bus 86808	: V=0.9547983, theta=-34.475693 -> V=1.0, theta=0.0
% INFO    : Bus 86809	: V=0.986988, theta=-29.562134 -> V=1.0, theta=0.0
% INFO    : Bus 86810	: V=0.9804049, theta=-28.170325 -> V=1.0, theta=0.0
% INFO    : Bus 86811	: V=0.9925948, theta=-26.430868 -> V=1.0, theta=0.0
% INFO    : Bus 86812	: V=0.9862355, theta=-26.692053 -> V=1.0, theta=0.0
% INFO    : Bus 86813	: V=0.9955825, theta=-26.416734 -> V=1.0, theta=0.0
% INFO    : Bus 86814	: V=0.9904844, theta=-28.087062 -> V=1.0, theta=0.0
% INFO    : Bus 86815	: V=0.974337, theta=-29.274394 -> V=1.0, theta=0.0
% INFO    : Bus 86816	: V=0.9961555, theta=-26.45279 -> V=1.0, theta=0.0
% INFO    : Bus 86817	: V=1.0040968, theta=-27.225966 -> V=1.0, theta=0.0
% INFO    : Bus 86818	: V=0.9940825, theta=-28.17267 -> V=1.0, theta=0.0
% INFO    : Bus 86819	: V=0.9950579, theta=-27.99435 -> V=1.0, theta=0.0
% INFO    : Bus 86820	: V=1.004366, theta=-27.108897 -> V=1.0, theta=0.0
% INFO    : Bus 86821	: V=0.9710619, theta=-30.659146 -> V=1.0, theta=0.0
% INFO    : Bus 86822	: V=0.9799117, theta=-29.76125 -> V=1.0, theta=0.0
% INFO    : Bus 86823	: V=0.9874414, theta=-28.070996 -> V=1.0, theta=0.0
% INFO    : Bus 86824	: V=0.9638403, theta=-29.968867 -> V=1.0, theta=0.0
% INFO    : Bus 86825	: V=0.9588235, theta=-30.183067 -> V=1.0, theta=0.0
% INFO    : Bus 86826	: V=0.9549584, theta=-30.386726 -> V=1.0, theta=0.0
% INFO    : Bus 86827	: V=0.954032, theta=-30.476294 -> V=1.0, theta=0.0
% INFO    : Bus 86828	: V=0.9511519, theta=-30.65765 -> V=1.0, theta=0.0
% INFO    : Bus 86829	: V=0.9477987, theta=-31.044479 -> V=1.0, theta=0.0
% INFO    : Bus 86830	: V=0.9497282, theta=-30.919599 -> V=1.0, theta=0.0
% INFO    : Bus 86831	: V=0.9498396, theta=-31.035814 -> V=1.0, theta=0.0
% INFO    : Bus 86832	: V=0.9964155, theta=-28.865355 -> V=1.0, theta=0.0
% INFO    : Bus 86833	: V=0.9951492, theta=-29.070691 -> V=1.0, theta=0.0
% INFO    : Bus 86834	: V=0.9698946, theta=-31.345024 -> V=1.0, theta=0.0
% INFO    : Bus 86835	: V=0.9815199, theta=-33.324348 -> V=1.0, theta=0.0
% INFO    : Bus 86836	: V=0.9975056, theta=-30.675743 -> V=1.0, theta=0.0
% INFO    : Bus 86837	: V=0.977963, theta=-30.356105 -> V=1.0, theta=0.0
% INFO    : Bus 86838	: V=0.9764627, theta=-30.451551 -> V=1.0, theta=0.0
% INFO    : Bus 86839	: V=0.9680756, theta=-31.35916 -> V=1.0, theta=0.0
% INFO    : Bus 86840	: V=0.9596267, theta=-33.48364 -> V=1.0, theta=0.0
% INFO    : Bus 86841	: V=0.9617857, theta=-32.20072 -> V=1.0, theta=0.0
% INFO    : Bus 86842	: V=0.964375, theta=-31.858717 -> V=1.0, theta=0.0
% INFO    : Bus 86843	: V=0.9637496, theta=-31.826019 -> V=1.0, theta=0.0
% INFO    : Bus 86844	: V=0.961797, theta=-31.943176 -> V=1.0, theta=0.0
% INFO    : Bus 86845	: V=0.9655727, theta=-31.48974 -> V=1.0, theta=0.0
% INFO    : Bus 86846	: V=0.9644178, theta=-31.668191 -> V=1.0, theta=0.0
% INFO    : Bus 86847	: V=0.977777, theta=-32.456014 -> V=1.0, theta=0.0
% INFO    : Bus 86848	: V=0.9587153, theta=-31.620194 -> V=1.0, theta=0.0
% INFO    : Bus 86849	: V=0.9650072, theta=-31.286133 -> V=1.0, theta=0.0
% INFO    : Bus 86850	: V=0.9997496, theta=-26.599432 -> V=1.0, theta=0.0
% INFO    : Bus 86851	: V=0.9870499, theta=-28.465323 -> V=1.0, theta=0.0
% INFO    : Bus 86852	: V=0.985173, theta=-29.150072 -> V=1.0, theta=0.0
% INFO    : Bus 86853	: V=0.968974, theta=-32.536802 -> V=1.0, theta=0.0
% INFO    : Bus 86854	: V=0.9697472, theta=-32.4467 -> V=1.0, theta=0.0
% INFO    : Bus 86855	: V=1.0100684, theta=-25.471591 -> V=1.0, theta=0.0
% INFO    : Bus 86856	: V=1.0014011, theta=-27.032054 -> V=1.0, theta=0.0
% INFO    : Bus 86857	: V=1.0010911, theta=-27.061575 -> V=1.0, theta=0.0
% INFO    : Bus 86858	: V=1.0030666, theta=-25.61119 -> V=1.0, theta=0.0
% INFO    : Bus 86859	: V=0.9513573, theta=-44.61231 -> V=1.0, theta=0.0
% INFO    : Bus 86860	: V=0.9541146, theta=-44.459194 -> V=1.0, theta=0.0
% INFO    : Bus 86861	: V=0.9519138, theta=-44.71891 -> V=1.0, theta=0.0
% INFO    : Bus 86862	: V=0.9571583, theta=-44.013182 -> V=1.0, theta=0.0
% INFO    : Bus 86863	: V=0.9671026, theta=-42.335242 -> V=1.0, theta=0.0
% INFO    : Bus 86864	: V=0.9584144, theta=-43.543581 -> V=1.0, theta=0.0
% INFO    : Bus 86865	: V=0.9581017, theta=-43.503638 -> V=1.0, theta=0.0
% INFO    : Bus 86866	: V=0.9565664, theta=-43.833666 -> V=1.0, theta=0.0
% INFO    : Bus 86867	: V=0.9601968, theta=-43.806695 -> V=1.0, theta=0.0
% INFO    : Bus 86868	: V=0.9591708, theta=-43.892212 -> V=1.0, theta=0.0
% INFO    : Bus 86869	: V=0.9536692, theta=-44.322564 -> V=1.0, theta=0.0
% INFO    : Bus 86870	: V=0.9507557, theta=-44.962206 -> V=1.0, theta=0.0
% INFO    : Bus 86871	: V=0.9540802, theta=-44.306195 -> V=1.0, theta=0.0
% INFO    : Bus 86872	: V=0.9621073, theta=-43.516284 -> V=1.0, theta=0.0
% INFO    : Bus 86873	: V=0.9628711, theta=-43.544084 -> V=1.0, theta=0.0
% INFO    : Bus 86874	: V=0.9606756, theta=-43.102512 -> V=1.0, theta=0.0
% INFO    : Bus 86875	: V=0.9552145, theta=-44.208232 -> V=1.0, theta=0.0
% INFO    : Bus 86876	: V=0.9658013, theta=-42.742629 -> V=1.0, theta=0.0
% INFO    : Bus 86877	: V=0.9622993, theta=-43.47212 -> V=1.0, theta=0.0
% INFO    : Bus 86878	: V=0.9669405, theta=-42.396751 -> V=1.0, theta=0.0
% INFO    : Bus 86879	: V=0.9685955, theta=-42.409449 -> V=1.0, theta=0.0
% INFO    : Bus 86880	: V=0.962254, theta=-43.195647 -> V=1.0, theta=0.0
% INFO    : Bus 86881	: V=0.9660773, theta=-42.406274 -> V=1.0, theta=0.0
% INFO    : Bus 86882	: V=0.953983, theta=-43.33316 -> V=1.0, theta=0.0
% INFO    : Bus 86883	: V=0.982158, theta=-39.288438 -> V=1.0, theta=0.0
% INFO    : Bus 86884	: V=0.9777346, theta=-39.877 -> V=1.0, theta=0.0
% INFO    : Bus 86885	: V=0.9825456, theta=-39.84158 -> V=1.0, theta=0.0
% INFO    : Bus 86886	: V=0.9761259, theta=-40.951024 -> V=1.0, theta=0.0
% INFO    : Bus 86887	: V=0.974024, theta=-41.455842 -> V=1.0, theta=0.0
% INFO    : Bus 86888	: V=0.958362, theta=-43.506731 -> V=1.0, theta=0.0
% INFO    : Bus 86889	: V=0.9559635, theta=-43.494946 -> V=1.0, theta=0.0
% INFO    : Bus 86890	: V=0.9538098, theta=-43.817687 -> V=1.0, theta=0.0
% INFO    : Bus 86891	: V=0.9653378, theta=-37.722856 -> V=1.0, theta=0.0
% INFO    : Bus 86892	: V=0.9595294, theta=-39.475146 -> V=1.0, theta=0.0
% INFO    : Bus 86893	: V=0.9618471, theta=-36.502695 -> V=1.0, theta=0.0
% INFO    : Bus 86894	: V=0.9630896, theta=-38.396216 -> V=1.0, theta=0.0
% INFO    : Bus 86895	: V=0.9824304, theta=-39.244594 -> V=1.0, theta=0.0
% INFO    : Bus 86896	: V=0.9873931, theta=-27.197628 -> V=1.0, theta=0.0
% INFO    : Bus 86897	: V=0.9946814, theta=-27.274027 -> V=1.0, theta=0.0
% INFO    : Bus 86898	: V=0.9881371, theta=-26.949568 -> V=1.0, theta=0.0
% INFO    : Bus 86899	: V=0.9753483, theta=-34.815991 -> V=1.0, theta=0.0
% INFO    : Bus 86900	: V=0.9784613, theta=-34.623523 -> V=1.0, theta=0.0
% INFO    : Bus 86901	: V=0.9660838, theta=-33.973741 -> V=1.0, theta=0.0
% INFO    : Bus 86902	: V=0.9661562, theta=-33.66286 -> V=1.0, theta=0.0
% INFO    : Bus 86903	: V=0.9669852, theta=-33.417107 -> V=1.0, theta=0.0
% INFO    : Bus 86904	: V=0.9692189, theta=-34.293265 -> V=1.0, theta=0.0
% INFO    : Bus 86905	: V=0.970816, theta=-34.349174 -> V=1.0, theta=0.0
% INFO    : Bus 86906	: V=0.9741026, theta=-34.288385 -> V=1.0, theta=0.0
% INFO    : Bus 86907	: V=0.9887568, theta=-33.708129 -> V=1.0, theta=0.0
% INFO    : Bus 86908	: V=0.9845638, theta=-32.790183 -> V=1.0, theta=0.0
% INFO    : Bus 86909	: V=0.9815596, theta=-33.776345 -> V=1.0, theta=0.0
% INFO    : Bus 86910	: V=1.0067785, theta=-25.995304 -> V=1.0, theta=0.0
% INFO    : Bus 86911	: V=1.0031634, theta=-26.43971 -> V=1.0, theta=0.0
% INFO    : Bus 86912	: V=0.9828182, theta=-32.739838 -> V=1.0, theta=0.0
% INFO    : Bus 86913	: V=0.9696965, theta=-33.4157 -> V=1.0, theta=0.0
% INFO    : Bus 86914	: V=0.9646938, theta=-34.222248 -> V=1.0, theta=0.0
% INFO    : Bus 86915	: V=0.9568593, theta=-33.969634 -> V=1.0, theta=0.0
% INFO    : Bus 86916	: V=0.9869603, theta=-33.814581 -> V=1.0, theta=0.0
% INFO    : Bus 86917	: V=0.9687307, theta=-34.982745 -> V=1.0, theta=0.0
% INFO    : Bus 86918	: V=0.9539592, theta=-35.5896 -> V=1.0, theta=0.0
% INFO    : Bus 86919	: V=0.9726499, theta=-34.801932 -> V=1.0, theta=0.0
% INFO    : Bus 86920	: V=0.9566775, theta=-44.022539 -> V=1.0, theta=0.0
% INFO    : Bus 86921	: V=0.9628406, theta=-43.022403 -> V=1.0, theta=0.0
% INFO    : Bus 86922	: V=0.9656134, theta=-40.004624 -> V=1.0, theta=0.0
% INFO    : Bus 86923	: V=0.9581609, theta=-43.291597 -> V=1.0, theta=0.0
% INFO    : Bus 86924	: V=0.9596674, theta=-41.885086 -> V=1.0, theta=0.0
% INFO    : Bus 86925	: V=0.9542573, theta=-43.777525 -> V=1.0, theta=0.0
% INFO    : Bus 86926	: V=0.9705671, theta=-40.211782 -> V=1.0, theta=0.0
% INFO    : Bus 86927	: V=0.9732436, theta=-33.498052 -> V=1.0, theta=0.0
% INFO    : Bus 86928	: V=0.9900542, theta=-31.556459 -> V=1.0, theta=0.0
% INFO    : Bus 86929	: V=0.9841646, theta=-32.434836 -> V=1.0, theta=0.0
% INFO    : Bus 86930	: V=0.976889, theta=-32.838793 -> V=1.0, theta=0.0
% INFO    : Bus 86931	: V=0.9807723, theta=-32.702833 -> V=1.0, theta=0.0
% INFO    : Bus 86932	: V=0.9824675, theta=-32.640256 -> V=1.0, theta=0.0
% INFO    : Bus 86933	: V=0.9811053, theta=-32.83603 -> V=1.0, theta=0.0
% INFO    : Bus 86934	: V=0.9768195, theta=-33.142579 -> V=1.0, theta=0.0
% INFO    : Bus 86935	: V=0.9777023, theta=-33.16679 -> V=1.0, theta=0.0
% INFO    : Bus 86936	: V=0.9869187, theta=-31.615046 -> V=1.0, theta=0.0
% INFO    : Bus 86937	: V=0.9955468, theta=-31.167193 -> V=1.0, theta=0.0
% INFO    : Bus 86938	: V=0.9915984, theta=-30.438658 -> V=1.0, theta=0.0
% INFO    : Bus 86939	: V=0.9901776, theta=-30.518683 -> V=1.0, theta=0.0
% INFO    : Bus 86940	: V=0.9758218, theta=-31.486734 -> V=1.0, theta=0.0
% INFO    : Bus 86941	: V=0.965471, theta=-33.062791 -> V=1.0, theta=0.0
% INFO    : Bus 86942	: V=0.9713982, theta=-32.877986 -> V=1.0, theta=0.0
% INFO    : Bus 86943	: V=0.9770526, theta=-32.45482 -> V=1.0, theta=0.0
% INFO    : Bus 86944	: V=0.967146, theta=-33.222009 -> V=1.0, theta=0.0
% INFO    : Bus 86945	: V=0.9755314, theta=-33.073731 -> V=1.0, theta=0.0
% INFO    : Bus 86946	: V=0.9803103, theta=-32.90388 -> V=1.0, theta=0.0
% INFO    : Bus 86947	: V=0.9820796, theta=-32.89384 -> V=1.0, theta=0.0
% INFO    : Bus 86948	: V=0.9763762, theta=-31.848526 -> V=1.0, theta=0.0
% INFO    : Bus 86949	: V=0.9873653, theta=-31.150482 -> V=1.0, theta=0.0
% INFO    : Bus 86950	: V=0.9700723, theta=-32.078602 -> V=1.0, theta=0.0
% INFO    : Bus 86951	: V=0.968699, theta=-32.042448 -> V=1.0, theta=0.0
% INFO    : Bus 86952	: V=0.9784871, theta=-32.590183 -> V=1.0, theta=0.0
% INFO    : Bus 86953	: V=1.0032789, theta=-28.813135 -> V=1.0, theta=0.0
% INFO    : Bus 86954	: V=0.9988944, theta=-29.287506 -> V=1.0, theta=0.0
% INFO    : Bus 86955	: V=0.9854024, theta=-32.639879 -> V=1.0, theta=0.0
% INFO    : Bus 86956	: V=0.9843528, theta=-31.803816 -> V=1.0, theta=0.0
% INFO    : Bus 86957	: V=0.9852213, theta=-32.212881 -> V=1.0, theta=0.0
% INFO    : Bus 86958	: V=0.9663549, theta=-34.183847 -> V=1.0, theta=0.0
% INFO    : Bus 86959	: V=0.9798433, theta=-30.769731 -> V=1.0, theta=0.0
% INFO    : Bus 86960	: V=0.9746015, theta=-41.99488 -> V=1.0, theta=0.0
% INFO    : Bus 86961	: V=1.0040869, theta=-35.880212 -> V=1.0, theta=0.0
% INFO    : Bus 86962	: V=0.9896244, theta=-38.192423 -> V=1.0, theta=0.0
% INFO    : Bus 86963	: V=0.9924151, theta=-37.746544 -> V=1.0, theta=0.0
% INFO    : Bus 86964	: V=1.0018834, theta=-35.883373 -> V=1.0, theta=0.0
% INFO    : Bus 86965	: V=0.9988268, theta=-36.070468 -> V=1.0, theta=0.0
% INFO    : Bus 86966	: V=1.0002184, theta=-36.099902 -> V=1.0, theta=0.0
% INFO    : Bus 86967	: V=1.0027371, theta=-35.443924 -> V=1.0, theta=0.0
% INFO    : Bus 86968	: V=0.9998585, theta=-35.83606 -> V=1.0, theta=0.0
% INFO    : Bus 86969	: V=0.9940873, theta=-36.264351 -> V=1.0, theta=0.0
% INFO    : Bus 86970	: V=0.9907979, theta=-37.086362 -> V=1.0, theta=0.0
% INFO    : Bus 86971	: V=1.0127641, theta=-24.396467 -> V=1.0, theta=0.0
% INFO    : Bus 86972	: V=0.9881191, theta=-27.086842 -> V=1.0, theta=0.0
% INFO    : Bus 86973	: V=1.0061079, theta=-25.397346 -> V=1.0, theta=0.0
% INFO    : Bus 86974	: V=1.0024231, theta=-26.012877 -> V=1.0, theta=0.0
% INFO    : Bus 86975	: V=0.9979406, theta=-27.837776 -> V=1.0, theta=0.0
% INFO    : Bus 86976	: V=0.9929539, theta=-28.141798 -> V=1.0, theta=0.0
% INFO    : Bus 86977	: V=1.008381, theta=-26.714995 -> V=1.0, theta=0.0
% INFO    : Bus 86978	: V=1.010368, theta=-26.413455 -> V=1.0, theta=0.0
% INFO    : Bus 86979	: V=1.0043639, theta=-26.993345 -> V=1.0, theta=0.0
% INFO    : Bus 86980	: V=1.0028067, theta=-27.105028 -> V=1.0, theta=0.0
% INFO    : Bus 86981	: V=1.0152524, theta=-25.880202 -> V=1.0, theta=0.0
% INFO    : Bus 86982	: V=1.0122755, theta=-26.250173 -> V=1.0, theta=0.0
% INFO    : Bus 86983	: V=1.0119192, theta=-26.283186 -> V=1.0, theta=0.0
% INFO    : Bus 86984	: V=0.9989817, theta=-28.898017 -> V=1.0, theta=0.0
% INFO    : Bus 86985	: V=0.986608, theta=-38.324138 -> V=1.0, theta=0.0
% INFO    : Bus 86986	: V=0.9792893, theta=-39.809573 -> V=1.0, theta=0.0
% INFO    : Bus 86987	: V=0.9739374, theta=-41.587391 -> V=1.0, theta=0.0
% INFO    : Bus 86988	: V=0.9663461, theta=-42.288523 -> V=1.0, theta=0.0
% INFO    : Bus 86989	: V=0.9829694, theta=-39.400101 -> V=1.0, theta=0.0
% INFO    : Bus 86990	: V=0.9822346, theta=-39.282155 -> V=1.0, theta=0.0
% INFO    : Bus 86991	: V=0.9705362, theta=-41.14217 -> V=1.0, theta=0.0
% INFO    : Bus 86992	: V=0.963999, theta=-42.506905 -> V=1.0, theta=0.0
% INFO    : Bus 86993	: V=0.9793492, theta=-39.642599 -> V=1.0, theta=0.0
% INFO    : Bus 86994	: V=0.9837621, theta=-38.539825 -> V=1.0, theta=0.0
% INFO    : Bus 86995	: V=0.9904186, theta=-36.68343 -> V=1.0, theta=0.0
% INFO    : Bus 86996	: V=0.9670941, theta=-33.956994 -> V=1.0, theta=0.0
% INFO    : Bus 86997	: V=0.9622087, theta=-34.759677 -> V=1.0, theta=0.0
% INFO    : Bus 86998	: V=0.966524, theta=-33.989401 -> V=1.0, theta=0.0
% INFO    : Bus 86999	: V=0.9587297, theta=-35.058703 -> V=1.0, theta=0.0
% INFO    : Bus 87000	: V=0.9610691, theta=-34.597597 -> V=1.0, theta=0.0
% INFO    : Bus 87001	: V=0.965477, theta=-34.222662 -> V=1.0, theta=0.0
% INFO    : Bus 87002	: V=0.9581784, theta=-35.115009 -> V=1.0, theta=0.0
% INFO    : Bus 87003	: V=0.9794284, theta=-32.479946 -> V=1.0, theta=0.0
% INFO    : Bus 87004	: V=0.981009, theta=-32.115398 -> V=1.0, theta=0.0
% INFO    : Bus 87005	: V=0.988619, theta=-32.298498 -> V=1.0, theta=0.0
% INFO    : Bus 87006	: V=0.9991436, theta=-31.084282 -> V=1.0, theta=0.0
% INFO    : Bus 87007	: V=0.9736566, theta=-33.526904 -> V=1.0, theta=0.0
% INFO    : Bus 87008	: V=0.9779718, theta=-32.918934 -> V=1.0, theta=0.0
% INFO    : Bus 87009	: V=0.9751816, theta=-33.15946 -> V=1.0, theta=0.0
% INFO    : Bus 87010	: V=0.967094, theta=-33.968259 -> V=1.0, theta=0.0
% INFO    : Bus 87011	: V=0.9580348, theta=-35.297453 -> V=1.0, theta=0.0
% INFO    : Bus 87012	: V=0.9591988, theta=-34.930763 -> V=1.0, theta=0.0
% INFO    : Bus 87013	: V=0.9571023, theta=-35.246957 -> V=1.0, theta=0.0
% INFO    : Bus 87014	: V=0.9609878, theta=-34.895571 -> V=1.0, theta=0.0
% INFO    : Bus 87015	: V=0.9464284, theta=-37.49688 -> V=1.0, theta=0.0
% INFO    : Bus 87016	: V=0.9610865, theta=-34.543859 -> V=1.0, theta=0.0
% INFO    : Bus 87017	: V=0.9669832, theta=-33.398806 -> V=1.0, theta=0.0
% INFO    : Bus 87018	: V=0.9589051, theta=-35.142121 -> V=1.0, theta=0.0
% INFO    : Bus 87019	: V=0.9611551, theta=-34.64718 -> V=1.0, theta=0.0
% INFO    : Bus 87020	: V=0.9571355, theta=-35.03199 -> V=1.0, theta=0.0
% INFO    : Bus 87021	: V=0.9669826, theta=-33.689007 -> V=1.0, theta=0.0
% INFO    : Bus 87022	: V=0.9769677, theta=-33.061851 -> V=1.0, theta=0.0
% INFO    : Bus 87023	: V=0.9686805, theta=-33.609546 -> V=1.0, theta=0.0
% INFO    : Bus 87024	: V=0.9757516, theta=-32.322909 -> V=1.0, theta=0.0
% INFO    : Bus 87025	: V=0.9504522, theta=-47.203028 -> V=1.0, theta=0.0
% INFO    : Bus 87026	: V=0.9555457, theta=-46.568141 -> V=1.0, theta=0.0
% INFO    : Bus 87027	: V=0.9530106, theta=-47.029129 -> V=1.0, theta=0.0
% INFO    : Bus 87028	: V=0.9528735, theta=-47.113067 -> V=1.0, theta=0.0
% INFO    : Bus 87029	: V=0.9533664, theta=-47.110063 -> V=1.0, theta=0.0
% INFO    : Bus 87030	: V=0.9579127, theta=-45.092505 -> V=1.0, theta=0.0
% INFO    : Bus 87031	: V=0.9602158, theta=-45.228885 -> V=1.0, theta=0.0
% INFO    : Bus 87032	: V=0.9527513, theta=-46.390176 -> V=1.0, theta=0.0
% INFO    : Bus 87033	: V=0.9540004, theta=-45.868246 -> V=1.0, theta=0.0
% INFO    : Bus 87034	: V=0.9558051, theta=-45.948571 -> V=1.0, theta=0.0
% INFO    : Bus 87035	: V=0.9539902, theta=-46.517995 -> V=1.0, theta=0.0
% INFO    : Bus 87036	: V=0.9577015, theta=-45.606808 -> V=1.0, theta=0.0
% INFO    : Bus 87037	: V=0.963367, theta=-45.942925 -> V=1.0, theta=0.0
% INFO    : Bus 87038	: V=0.9556443, theta=-44.910847 -> V=1.0, theta=0.0
% INFO    : Bus 87039	: V=0.9506227, theta=-46.722182 -> V=1.0, theta=0.0
% INFO    : Bus 87040	: V=0.9540569, theta=-46.115315 -> V=1.0, theta=0.0
% INFO    : Bus 87041	: V=0.9521702, theta=-45.796157 -> V=1.0, theta=0.0
% INFO    : Bus 87042	: V=0.9532304, theta=-45.746922 -> V=1.0, theta=0.0
% INFO    : Bus 87043	: V=0.9603823, theta=-43.891257 -> V=1.0, theta=0.0
% INFO    : Bus 87044	: V=0.9616055, theta=-43.704917 -> V=1.0, theta=0.0
% INFO    : Bus 87045	: V=0.9508658, theta=-46.7325 -> V=1.0, theta=0.0
% INFO    : Bus 87046	: V=0.9530025, theta=-45.850632 -> V=1.0, theta=0.0
% INFO    : Bus 87047	: V=0.9535624, theta=-44.637686 -> V=1.0, theta=0.0
% INFO    : Bus 87048	: V=0.9741303, theta=-31.328357 -> V=1.0, theta=0.0
% INFO    : Bus 87049	: V=0.9576723, theta=-32.335889 -> V=1.0, theta=0.0
% INFO    : Bus 87050	: V=0.960309, theta=-32.088239 -> V=1.0, theta=0.0
% INFO    : Bus 87051	: V=0.961606, theta=-31.95181 -> V=1.0, theta=0.0
% INFO    : Bus 87052	: V=0.9767613, theta=-31.268025 -> V=1.0, theta=0.0
% INFO    : Bus 87053	: V=0.9865585, theta=-29.030492 -> V=1.0, theta=0.0
% INFO    : Bus 87054	: V=0.9912538, theta=-28.500201 -> V=1.0, theta=0.0
% INFO    : Bus 87055	: V=0.9619819, theta=-37.859265 -> V=1.0, theta=0.0
% INFO    : Bus 87056	: V=0.9570722, theta=-39.291812 -> V=1.0, theta=0.0
% INFO    : Bus 87057	: V=0.9690477, theta=-30.121748 -> V=1.0, theta=0.0
% INFO    : Bus 87058	: V=0.9833539, theta=-27.662337 -> V=1.0, theta=0.0
% INFO    : Bus 87059	: V=0.9778783, theta=-29.265543 -> V=1.0, theta=0.0
% INFO    : Bus 87060	: V=0.9878993, theta=-27.18204 -> V=1.0, theta=0.0
% INFO    : Bus 87061	: V=1.0061663, theta=-25.527887 -> V=1.0, theta=0.0
% INFO    : Bus 87062	: V=0.9929883, theta=-26.901664 -> V=1.0, theta=0.0
% INFO    : Bus 87063	: V=1.0083639, theta=-25.377156 -> V=1.0, theta=0.0
% INFO    : Bus 87064	: V=1.0069443, theta=-25.668768 -> V=1.0, theta=0.0
% INFO    : Bus 87065	: V=1.0028999, theta=-35.028409 -> V=1.0, theta=0.0
% INFO    : Bus 87066	: V=0.9930991, theta=-36.143443 -> V=1.0, theta=0.0
% INFO    : Bus 87067	: V=0.9873883, theta=-36.723435 -> V=1.0, theta=0.0
% INFO    : Bus 87068	: V=0.9771494, theta=-37.356696 -> V=1.0, theta=0.0
% INFO    : Bus 87069	: V=0.9952938, theta=-36.243779 -> V=1.0, theta=0.0
% INFO    : Bus 87070	: V=0.9824943, theta=-37.130759 -> V=1.0, theta=0.0
% INFO    : Bus 87071	: V=0.9815118, theta=-37.107956 -> V=1.0, theta=0.0
% INFO    : Bus 87072	: V=0.9805137, theta=-37.246804 -> V=1.0, theta=0.0
% INFO    : Bus 87073	: V=0.9806265, theta=-36.488003 -> V=1.0, theta=0.0
% INFO    : Bus 87074	: V=0.9782706, theta=-37.785297 -> V=1.0, theta=0.0
% INFO    : Bus 87075	: V=0.9776696, theta=-37.562343 -> V=1.0, theta=0.0
% INFO    : Bus 87076	: V=1.0121423, theta=-35.611667 -> V=1.0, theta=0.0
% INFO    : Bus 87077	: V=0.9964527, theta=-36.174278 -> V=1.0, theta=0.0
% INFO    : Bus 87078	: V=0.9988645, theta=-36.135616 -> V=1.0, theta=0.0
% INFO    : Bus 87079	: V=1.0088756, theta=-35.754668 -> V=1.0, theta=0.0
% INFO    : Bus 87080	: V=1.0056281, theta=-36.012471 -> V=1.0, theta=0.0
% INFO    : Bus 87081	: V=1.0194832, theta=-17.658326 -> V=1.0, theta=0.0
% INFO    : Bus 87082	: V=1.0179916, theta=-17.513739 -> V=1.0, theta=0.0
% INFO    : Bus 87083	: V=1.010198, theta=-38.13657 -> V=1.0, theta=0.0
% INFO    : Bus 87084	: V=1.0099161, theta=-38.175949 -> V=1.0, theta=0.0
% INFO    : Bus 87085	: V=1.0061857, theta=-20.250922 -> V=1.0, theta=0.0
% INFO    : Bus 87086	: V=0.996154, theta=-22.019978 -> V=1.0, theta=0.0
% INFO    : Bus 87087	: V=0.9953177, theta=-22.225382 -> V=1.0, theta=0.0
% INFO    : Bus 87088	: V=1.0123051, theta=-41.297675 -> V=1.0, theta=0.0
% INFO    : Bus 87089	: V=1.0072801, theta=-41.597595 -> V=1.0, theta=0.0
% INFO    : Bus 87090	: V=1.0072454, theta=-41.605096 -> V=1.0, theta=0.0
% INFO    : Bus 87091	: V=1.0102161, theta=-46.759358 -> V=1.0, theta=0.0
% INFO    : Bus 87092	: V=1.0083612, theta=-21.896146 -> V=1.0, theta=0.0
% INFO    : Bus 87093	: V=1.004586, theta=-22.988144 -> V=1.0, theta=0.0
% INFO    : Bus 87094	: V=1.0045011, theta=-23.001424 -> V=1.0, theta=0.0
% INFO    : Bus 87095	: V=1.014111, theta=-21.942861 -> V=1.0, theta=0.0
% INFO    : Bus 87096	: V=1.0120404, theta=-23.458542 -> V=1.0, theta=0.0
% INFO    : Bus 87097	: V=1.0191131, theta=-22.91903 -> V=1.0, theta=0.0
% INFO    : Bus 87098	: V=1.0175143, theta=-23.395283 -> V=1.0, theta=0.0
% INFO    : Bus 87099	: V=1.017352, theta=-23.514907 -> V=1.0, theta=0.0
% INFO    : Bus 87100	: V=1.0118229, theta=-19.130227 -> V=1.0, theta=0.0
% INFO    : Bus 87101	: V=1.018263, theta=-17.817135 -> V=1.0, theta=0.0
% INFO    : Bus 87102	: V=1.0199327, theta=-25.077429 -> V=1.0, theta=0.0
% INFO    : Bus 87103	: V=1.0197388, theta=-24.835491 -> V=1.0, theta=0.0
% INFO    : Bus 87104	: V=1.018006, theta=-18.078285 -> V=1.0, theta=0.0
% INFO    : Bus 87105	: V=1.0167453, theta=-18.340514 -> V=1.0, theta=0.0
% INFO    : Bus 87106	: V=1.0068075, theta=-25.296315 -> V=1.0, theta=0.0
% INFO    : Bus 87107	: V=1.019958, theta=-23.019628 -> V=1.0, theta=0.0
% INFO    : Bus 87108	: V=1.0197957, theta=-21.330776 -> V=1.0, theta=0.0
% INFO    : Bus 87109	: V=1.0201051, theta=-21.134797 -> V=1.0, theta=0.0
% INFO    : Bus 87110	: V=1.02, theta=-25.555839 -> V=1.0, theta=0.0
% INFO    : Bus 87111	: V=1.0132522, theta=-26.223749 -> V=1.0, theta=0.0
% INFO    : Bus 87112	: V=1.0169681, theta=-22.79476 -> V=1.0, theta=0.0
% INFO    : Bus 87113	: V=1.0142773, theta=-23.362118 -> V=1.0, theta=0.0
% INFO    : Bus 87114	: V=1.0163651, theta=-19.057826 -> V=1.0, theta=0.0
% INFO    : Bus 87115	: V=1.0159886, theta=-19.167985 -> V=1.0, theta=0.0
% INFO    : Bus 87116	: V=1.0179862, theta=-44.06628 -> V=1.0, theta=0.0
% INFO    : Bus 87117	: V=1.0158076, theta=-43.677026 -> V=1.0, theta=0.0
% INFO    : Bus 87118	: V=1.0088896, theta=-26.395587 -> V=1.0, theta=0.0
% INFO    : Bus 87119	: V=1.0181672, theta=-43.989346 -> V=1.0, theta=0.0
% INFO    : Bus 87120	: V=1.02, theta=-43.599629 -> V=1.0, theta=0.0
% INFO    : Bus 87121	: V=1.02, theta=-23.415363 -> V=1.0, theta=0.0
% INFO    : Bus 87122	: V=1.0119364, theta=-24.407595 -> V=1.0, theta=0.0
% INFO    : Bus 87123	: V=1.018246, theta=-40.977324 -> V=1.0, theta=0.0
% INFO    : Bus 87124	: V=1.0172301, theta=-26.352795 -> V=1.0, theta=0.0
% INFO    : Bus 87125	: V=1.017107, theta=-23.99278 -> V=1.0, theta=0.0
% INFO    : Bus 87126	: V=1.014506, theta=-41.556123 -> V=1.0, theta=0.0
% INFO    : Bus 87127	: V=0.9998629, theta=-23.290524 -> V=1.0, theta=0.0
% INFO    : Bus 87128	: V=1.0013621, theta=-23.24144 -> V=1.0, theta=0.0
% INFO    : Bus 87129	: V=0.9905848, theta=-25.766551 -> V=1.0, theta=0.0
% INFO    : Bus 87130	: V=1.0116155, theta=-25.159753 -> V=1.0, theta=0.0
% INFO    : Bus 87131	: V=1.0162035, theta=-33.156589 -> V=1.0, theta=0.0
% INFO    : Bus 87132	: V=1.0145495, theta=-17.963341 -> V=1.0, theta=0.0
% INFO    : Bus 87133	: V=1.0153318, theta=-17.564443 -> V=1.0, theta=0.0
% INFO    : Bus 87134	: V=1.015914, theta=-32.80313 -> V=1.0, theta=0.0
% INFO    : Bus 87135	: V=0.9941595, theta=-27.812876 -> V=1.0, theta=0.0
% INFO    : Bus 87136	: V=0.9709889, theta=-28.100561 -> V=1.0, theta=0.0
% INFO    : Bus 87137	: V=1.0122828, theta=-24.182105 -> V=1.0, theta=0.0
% INFO    : Bus 87138	: V=1.0151188, theta=-18.848388 -> V=1.0, theta=0.0
% INFO    : Bus 87139	: V=1.0150014, theta=-27.242646 -> V=1.0, theta=0.0
% INFO    : Bus 87140	: V=1.0206529, theta=-20.932606 -> V=1.0, theta=0.0
% INFO    : Bus 87141	: V=1.0075446, theta=-10.45145 -> V=1.0, theta=0.0
% INFO    : Bus 87142	: V=1.0117212, theta=-10.287645 -> V=1.0, theta=0.0
% INFO    : Bus 87143	: V=1.0176882, theta=-9.178539 -> V=1.0, theta=0.0
% INFO    : Bus 87144	: V=1.0182797, theta=-9.067801 -> V=1.0, theta=0.0
% INFO    : Bus 87145	: V=1.014038, theta=-9.373463 -> V=1.0, theta=0.0
% INFO    : Bus 87146	: V=1.0110381, theta=-9.372103 -> V=1.0, theta=0.0
% INFO    : Bus 87147	: V=1.0108333, theta=-9.374291 -> V=1.0, theta=0.0
% INFO    : Bus 87148	: V=1.0159969, theta=-11.155167 -> V=1.0, theta=0.0
% INFO    : Bus 87149	: V=1.0159783, theta=-10.983855 -> V=1.0, theta=0.0
% INFO    : Bus 87150	: V=1.0170396, theta=-8.245014 -> V=1.0, theta=0.0
% INFO    : Bus 87151	: V=1.0145363, theta=-8.273654 -> V=1.0, theta=0.0
% INFO    : Bus 87152	: V=1.0141882, theta=-8.274487 -> V=1.0, theta=0.0
% INFO    : Bus 87153	: V=1.011194, theta=-8.607019 -> V=1.0, theta=0.0
% INFO    : Bus 87154	: V=1.0090145, theta=-8.691293 -> V=1.0, theta=0.0
% INFO    : Bus 87155	: V=1.0070374, theta=-16.628104 -> V=1.0, theta=0.0
% INFO    : Bus 87156	: V=1.0058159, theta=-16.57453 -> V=1.0, theta=0.0
% INFO    : Bus 87157	: V=1.0085402, theta=-7.223631 -> V=1.0, theta=0.0
% INFO    : Bus 87158	: V=1.0127764, theta=-30.874661 -> V=1.0, theta=0.0
% INFO    : Bus 87159	: V=1.0083866, theta=-8.665259 -> V=1.0, theta=0.0
% INFO    : Bus 87160	: V=1.0123759, theta=-8.424602 -> V=1.0, theta=0.0
% INFO    : Bus 87161	: V=1.0181154, theta=-8.187504 -> V=1.0, theta=0.0
% INFO    : Bus 87162	: V=1.0034311, theta=-8.471042 -> V=1.0, theta=0.0
% INFO    : Bus 87163	: V=1.0045644, theta=-18.327148 -> V=1.0, theta=0.0
% INFO    : Bus 87164	: V=0.9969264, theta=-18.64308 -> V=1.0, theta=0.0
% INFO    : Bus 87165	: V=0.9983398, theta=-18.619218 -> V=1.0, theta=0.0
% INFO    : Bus 87166	: V=0.947152, theta=-32.209623 -> V=1.0, theta=0.0
% INFO    : Bus 87167	: V=0.9458714, theta=-32.478763 -> V=1.0, theta=0.0
% INFO    : Bus 87168	: V=1.0200031, theta=-6.394051 -> V=1.0, theta=0.0
% INFO    : Bus 87169	: V=1.0056311, theta=-18.499374 -> V=1.0, theta=0.0
% INFO    : Bus 87170	: V=1.0004278, theta=-18.91844 -> V=1.0, theta=0.0
% INFO    : Bus 87171	: V=1.02, theta=-8.526511 -> V=1.0, theta=0.0
% INFO    : Bus 87172	: V=1.0046793, theta=-26.030178 -> V=1.0, theta=0.0
% INFO    : Bus 87173	: V=1.0185002, theta=-9.000643 -> V=1.0, theta=0.0
% INFO    : Bus 87174	: V=1.02, theta=-8.496302 -> V=1.0, theta=0.0
% INFO    : Bus 87175	: V=1.0184338, theta=-8.578877 -> V=1.0, theta=0.0
% INFO    : Bus 87176	: V=1.02, theta=-8.408174 -> V=1.0, theta=0.0
% INFO    : Bus 87177	: V=1.0027337, theta=-18.398051 -> V=1.0, theta=0.0
% INFO    : Bus 87178	: V=0.9870011, theta=-39.721319 -> V=1.0, theta=0.0
% INFO    : Bus 87179	: V=0.9876496, theta=-39.850642 -> V=1.0, theta=0.0
% INFO    : Bus 87180	: V=1.0094707, theta=-50.657181 -> V=1.0, theta=0.0
% INFO    : Bus 87181	: V=1.0048787, theta=-51.306664 -> V=1.0, theta=0.0
% INFO    : Bus 87182	: V=1.0055393, theta=-32.565102 -> V=1.0, theta=0.0
% INFO    : Bus 87183	: V=1.0069868, theta=-31.96818 -> V=1.0, theta=0.0
% INFO    : Bus 87184	: V=1.0196957, theta=-20.164628 -> V=1.0, theta=0.0
% INFO    : Bus 87185	: V=1.0177818, theta=-20.642209 -> V=1.0, theta=0.0
% INFO    : Bus 87186	: V=1.0176473, theta=-20.655349 -> V=1.0, theta=0.0
% INFO    : Bus 87187	: V=1.0176967, theta=-48.995384 -> V=1.0, theta=0.0
% INFO    : Bus 87188	: V=1.0165771, theta=-23.153207 -> V=1.0, theta=0.0
% INFO    : Bus 87189	: V=1.0149365, theta=-23.239528 -> V=1.0, theta=0.0
% INFO    : Bus 87190	: V=0.993911, theta=-26.44313 -> V=1.0, theta=0.0
% INFO    : Bus 87191	: V=0.9953414, theta=-26.299315 -> V=1.0, theta=0.0
% INFO    : Bus 87192	: V=1.0185386, theta=-22.286509 -> V=1.0, theta=0.0
% INFO    : Bus 87193	: V=1.0040647, theta=-23.812401 -> V=1.0, theta=0.0
% INFO    : Bus 87194	: V=1.0096653, theta=-37.625358 -> V=1.0, theta=0.0
% INFO    : Bus 87195	: V=1.0149072, theta=-24.748904 -> V=1.0, theta=0.0
% INFO    : Bus 87196	: V=1.0158344, theta=-20.636279 -> V=1.0, theta=0.0
% INFO    : Bus 87197	: V=1.0140749, theta=-21.040526 -> V=1.0, theta=0.0
% INFO    : Bus 87198	: V=1.0239914, theta=-24.642606 -> V=1.0, theta=0.0
% INFO    : Bus 87199	: V=1.02, theta=-24.354551 -> V=1.0, theta=0.0
% INFO    : Bus 87200	: V=1.0185187, theta=-24.371981 -> V=1.0, theta=0.0
% INFO    : Bus 87201	: V=1.0127339, theta=-21.025509 -> V=1.0, theta=0.0
% INFO    : Bus 87202	: V=1.0114383, theta=-22.971244 -> V=1.0, theta=0.0
% INFO    : Bus 87203	: V=1.0121264, theta=-22.913715 -> V=1.0, theta=0.0
% INFO    : Bus 87204	: V=1.0086896, theta=-47.803255 -> V=1.0, theta=0.0
% INFO    : Bus 87205	: V=1.0155885, theta=-45.658118 -> V=1.0, theta=0.0
% INFO    : Bus 87206	: V=1.0107459, theta=-52.877526 -> V=1.0, theta=0.0
% INFO    : Bus 87207	: V=1.0085311, theta=-53.164233 -> V=1.0, theta=0.0
% INFO    : Bus 87208	: V=1.009902, theta=-50.229501 -> V=1.0, theta=0.0
% INFO    : Bus 87209	: V=1.0093693, theta=-20.761315 -> V=1.0, theta=0.0
% INFO    : Bus 87210	: V=1.0141548, theta=-14.234249 -> V=1.0, theta=0.0
% INFO    : Bus 87211	: V=1.0125968, theta=-14.562074 -> V=1.0, theta=0.0
% INFO    : Bus 87212	: V=1.0083146, theta=-31.252604 -> V=1.0, theta=0.0
% INFO    : Bus 87213	: V=1.0079112, theta=-31.319632 -> V=1.0, theta=0.0
% INFO    : Bus 87214	: V=0.9986074, theta=-27.049704 -> V=1.0, theta=0.0
% INFO    : Bus 87215	: V=0.9824744, theta=-30.653539 -> V=1.0, theta=0.0
% INFO    : Bus 87216	: V=0.9813327, theta=-31.268787 -> V=1.0, theta=0.0
% INFO    : Bus 87217	: V=0.9933592, theta=-37.866159 -> V=1.0, theta=0.0
% INFO    : Bus 87218	: V=0.9986439, theta=-37.14933 -> V=1.0, theta=0.0
% INFO    : Bus 87219	: V=1.007256, theta=-25.21522 -> V=1.0, theta=0.0
% INFO    : Bus 87220	: V=1.0087915, theta=-24.864166 -> V=1.0, theta=0.0
% INFO    : Bus 87221	: V=1.0153259, theta=-23.020736 -> V=1.0, theta=0.0
% INFO    : Bus 87222	: V=1.0039782, theta=-47.111567 -> V=1.0, theta=0.0
% INFO    : Bus 87223	: V=1.0092651, theta=-46.560423 -> V=1.0, theta=0.0
% INFO    : Bus 87224	: V=0.9955921, theta=-49.356719 -> V=1.0, theta=0.0
% INFO    : Bus 87225	: V=0.9869933, theta=-49.384209 -> V=1.0, theta=0.0
% INFO    : Bus 87226	: V=1.0119055, theta=-33.841246 -> V=1.0, theta=0.0
% INFO    : Bus 87227	: V=1.0078225, theta=-34.381351 -> V=1.0, theta=0.0
% INFO    : Bus 87228	: V=1.0074233, theta=-34.448671 -> V=1.0, theta=0.0
% INFO    : Bus 87229	: V=1.0086911, theta=-18.409238 -> V=1.0, theta=0.0
% INFO    : Bus 87230	: V=1.0036447, theta=-19.386112 -> V=1.0, theta=0.0
% INFO    : Bus 87231	: V=1.0039794, theta=-19.455646 -> V=1.0, theta=0.0
% INFO    : Bus 87232	: V=1.0150715, theta=-14.219454 -> V=1.0, theta=0.0
% INFO    : Bus 87233	: V=1.0147591, theta=-14.376768 -> V=1.0, theta=0.0
% INFO    : Bus 87234	: V=1.0081534, theta=-19.242955 -> V=1.0, theta=0.0
% INFO    : Bus 87235	: V=1.0108409, theta=-19.142894 -> V=1.0, theta=0.0
% INFO    : Bus 87236	: V=1.0088039, theta=-31.935557 -> V=1.0, theta=0.0
% INFO    : Bus 87237	: V=1.0115631, theta=-31.257895 -> V=1.0, theta=0.0
% INFO    : Bus 87238	: V=1.0190667, theta=-30.733425 -> V=1.0, theta=0.0
% INFO    : Bus 87239	: V=1.02, theta=-30.387754 -> V=1.0, theta=0.0
% INFO    : Bus 87240	: V=1.0017871, theta=-38.539288 -> V=1.0, theta=0.0
% INFO    : Bus 87241	: V=1.0059269, theta=-38.55884 -> V=1.0, theta=0.0
% INFO    : Bus 87242	: V=0.9977433, theta=-40.358005 -> V=1.0, theta=0.0
% INFO    : Bus 87243	: V=0.9894728, theta=-28.755016 -> V=1.0, theta=0.0
% INFO    : Bus 87244	: V=0.9804042, theta=-39.143169 -> V=1.0, theta=0.0
% INFO    : Bus 87245	: V=0.9899921, theta=-29.082177 -> V=1.0, theta=0.0
% INFO    : Bus 87246	: V=1.02, theta=-30.80526 -> V=1.0, theta=0.0
% INFO    : Bus 87247	: V=1.0170491, theta=-31.328255 -> V=1.0, theta=0.0
% INFO    : Bus 87248	: V=1.0105308, theta=-34.198845 -> V=1.0, theta=0.0
% INFO    : Bus 87249	: V=1.004944, theta=-49.771063 -> V=1.0, theta=0.0
% INFO    : Bus 87250	: V=0.9734032, theta=-51.558144 -> V=1.0, theta=0.0
% INFO    : Bus 87251	: V=1.02, theta=-24.224088 -> V=1.0, theta=0.0
% INFO    : Bus 87252	: V=1.0146392, theta=-37.624549 -> V=1.0, theta=0.0
% INFO    : Bus 87253	: V=1.0110461, theta=-23.690107 -> V=1.0, theta=0.0
% INFO    : Bus 87254	: V=1.0103218, theta=-23.940312 -> V=1.0, theta=0.0
% INFO    : Bus 87255	: V=0.9959986, theta=-26.031363 -> V=1.0, theta=0.0
% INFO    : Bus 87256	: V=1.0172657, theta=-23.962402 -> V=1.0, theta=0.0
% INFO    : Bus 87257	: V=1.0174955, theta=-23.754555 -> V=1.0, theta=0.0
% INFO    : Bus 87258	: V=1.0200153, theta=-22.793702 -> V=1.0, theta=0.0
% INFO    : Bus 87259	: V=0.973626, theta=-51.782423 -> V=1.0, theta=0.0
% INFO    : Bus 87260	: V=0.9719215, theta=-53.087775 -> V=1.0, theta=0.0
% INFO    : Bus 87261	: V=0.9715714, theta=-53.594098 -> V=1.0, theta=0.0
% INFO    : Bus 87262	: V=0.9727434, theta=-54.070946 -> V=1.0, theta=0.0
% INFO    : Bus 87263	: V=0.9592938, theta=-57.49808 -> V=1.0, theta=0.0
% INFO    : Bus 87264	: V=0.9555879, theta=-58.086644 -> V=1.0, theta=0.0
% INFO    : Bus 87265	: V=0.9976533, theta=-32.929513 -> V=1.0, theta=0.0
% INFO    : Bus 87266	: V=0.9888886, theta=-38.887357 -> V=1.0, theta=0.0
% INFO    : Bus 87267	: V=1.0021065, theta=-36.324983 -> V=1.0, theta=0.0
% INFO    : Bus 87268	: V=1.0012687, theta=-37.580483 -> V=1.0, theta=0.0
% INFO    : Bus 87269	: V=0.9966768, theta=-38.248006 -> V=1.0, theta=0.0
% INFO    : Bus 87270	: V=0.9835651, theta=-25.386885 -> V=1.0, theta=0.0
% INFO    : Bus 87271	: V=0.9812988, theta=-25.166587 -> V=1.0, theta=0.0
% INFO    : Bus 87272	: V=0.9851611, theta=-26.020528 -> V=1.0, theta=0.0
% INFO    : Bus 87273	: V=0.9512779, theta=-30.436921 -> V=1.0, theta=0.0
% INFO    : Bus 87274	: V=0.955492, theta=-29.181964 -> V=1.0, theta=0.0
% INFO    : Bus 87275	: V=0.9557114, theta=-30.278399 -> V=1.0, theta=0.0
% INFO    : Bus 87276	: V=0.9621783, theta=-27.71591 -> V=1.0, theta=0.0
% INFO    : Bus 87277	: V=0.9629366, theta=-27.028197 -> V=1.0, theta=0.0
% INFO    : Bus 87278	: V=0.9745509, theta=-34.521575 -> V=1.0, theta=0.0
% INFO    : Bus 87279	: V=0.9963736, theta=-40.708434 -> V=1.0, theta=0.0
% INFO    : Bus 87280	: V=1.0178339, theta=-41.572288 -> V=1.0, theta=0.0
% INFO    : Bus 87281	: V=1.0151877, theta=-41.500394 -> V=1.0, theta=0.0
% INFO    : Bus 87282	: V=1.0190373, theta=-41.984508 -> V=1.0, theta=0.0
% INFO    : Bus 87283	: V=1.0183001, theta=-42.274521 -> V=1.0, theta=0.0
% INFO    : Bus 87284	: V=0.9852523, theta=-27.926152 -> V=1.0, theta=0.0
% INFO    : Bus 87285	: V=0.9837514, theta=-27.946223 -> V=1.0, theta=0.0
% INFO    : Bus 87286	: V=0.9786647, theta=-28.599241 -> V=1.0, theta=0.0
% INFO    : Bus 87287	: V=0.9719681, theta=-29.278199 -> V=1.0, theta=0.0
% INFO    : Bus 87288	: V=0.9846877, theta=-27.964553 -> V=1.0, theta=0.0
% INFO    : Bus 87289	: V=0.9876361, theta=-27.562331 -> V=1.0, theta=0.0
% INFO    : Bus 87290	: V=0.9833262, theta=-28.083517 -> V=1.0, theta=0.0
% INFO    : Bus 87291	: V=0.9777953, theta=-28.668386 -> V=1.0, theta=0.0
% INFO    : Bus 87292	: V=0.9750944, theta=-28.974676 -> V=1.0, theta=0.0
% INFO    : Bus 87293	: V=1.0137311, theta=-23.762892 -> V=1.0, theta=0.0
% INFO    : Bus 87294	: V=1.0041069, theta=-25.24878 -> V=1.0, theta=0.0
% INFO    : Bus 87295	: V=1.0041012, theta=-25.25144 -> V=1.0, theta=0.0
% INFO    : Bus 87296	: V=1.0016642, theta=-26.868894 -> V=1.0, theta=0.0
% INFO    : Bus 87297	: V=1.0037169, theta=-26.415017 -> V=1.0, theta=0.0
% INFO    : Bus 87298	: V=1.0103088, theta=-25.846036 -> V=1.0, theta=0.0
% INFO    : Bus 87299	: V=1.0210452, theta=-24.672296 -> V=1.0, theta=0.0
% INFO    : Bus 87300	: V=1.020146, theta=-24.727472 -> V=1.0, theta=0.0
% INFO    : Bus 87301	: V=1.0182397, theta=-20.985499 -> V=1.0, theta=0.0
% INFO    : Bus 87302	: V=1.0156897, theta=-21.500153 -> V=1.0, theta=0.0
% INFO    : Bus 87303	: V=1.0146779, theta=-21.502162 -> V=1.0, theta=0.0
% INFO    : Bus 87304	: V=1.0133724, theta=-21.624858 -> V=1.0, theta=0.0
% INFO    : Bus 87305	: V=1.0135443, theta=-22.379417 -> V=1.0, theta=0.0
% INFO    : Bus 87306	: V=0.9916377, theta=-41.52793 -> V=1.0, theta=0.0
% INFO    : Bus 87307	: V=0.9973273, theta=-37.192864 -> V=1.0, theta=0.0
% INFO    : Bus 87308	: V=1.0127783, theta=-40.220952 -> V=1.0, theta=0.0
% INFO    : Bus 87309	: V=1.0118634, theta=-40.862574 -> V=1.0, theta=0.0
% INFO    : Bus 87310	: V=0.9900277, theta=-26.959519 -> V=1.0, theta=0.0
% INFO    : Bus 87311	: V=0.9830905, theta=-42.666692 -> V=1.0, theta=0.0
% INFO    : Bus 87312	: V=0.9791468, theta=-42.906606 -> V=1.0, theta=0.0
% INFO    : Bus 87313	: V=0.9669132, theta=-44.488796 -> V=1.0, theta=0.0
% INFO    : Bus 87314	: V=1.0044427, theta=-19.860951 -> V=1.0, theta=0.0
% INFO    : Bus 87315	: V=1.0070164, theta=-20.062695 -> V=1.0, theta=0.0
% INFO    : Bus 87316	: V=1.015528, theta=-42.604411 -> V=1.0, theta=0.0
% INFO    : Bus 87317	: V=1.0185274, theta=-41.8927 -> V=1.0, theta=0.0
% INFO    : Bus 87318	: V=0.999153, theta=-42.10267 -> V=1.0, theta=0.0
% INFO    : Bus 87319	: V=0.995253, theta=-42.745697 -> V=1.0, theta=0.0
% INFO    : Bus 87320	: V=0.9915185, theta=-43.187184 -> V=1.0, theta=0.0
% INFO    : Bus 87321	: V=0.980882, theta=-43.517627 -> V=1.0, theta=0.0
% INFO    : Bus 87322	: V=0.9820689, theta=-42.234817 -> V=1.0, theta=0.0
% INFO    : Bus 87323	: V=0.9517569, theta=-28.920727 -> V=1.0, theta=0.0
% INFO    : Bus 87324	: V=0.9574557, theta=-28.023451 -> V=1.0, theta=0.0
% INFO    : Bus 87325	: V=0.9619071, theta=-26.929041 -> V=1.0, theta=0.0
% INFO    : Bus 87326	: V=0.9560538, theta=-27.721417 -> V=1.0, theta=0.0
% INFO    : Bus 87327	: V=0.9992421, theta=-40.561892 -> V=1.0, theta=0.0
% INFO    : Bus 87328	: V=0.9979932, theta=-40.766824 -> V=1.0, theta=0.0
% INFO    : Bus 87329	: V=0.9845936, theta=-41.786512 -> V=1.0, theta=0.0
% INFO    : Bus 87330	: V=0.9876629, theta=-41.284312 -> V=1.0, theta=0.0
% INFO    : Bus 87331	: V=0.9855943, theta=-42.192422 -> V=1.0, theta=0.0
% INFO    : Bus 87332	: V=0.9806984, theta=-42.98869 -> V=1.0, theta=0.0
% INFO    : Bus 87333	: V=0.9975293, theta=-28.395335 -> V=1.0, theta=0.0
% INFO    : Bus 87334	: V=1.0010603, theta=-30.236356 -> V=1.0, theta=0.0
% INFO    : Bus 87335	: V=0.9978419, theta=-29.930253 -> V=1.0, theta=0.0
% INFO    : Bus 87336	: V=1.0010995, theta=-30.714071 -> V=1.0, theta=0.0
% INFO    : Bus 87337	: V=0.9883515, theta=-26.604714 -> V=1.0, theta=0.0
% INFO    : Bus 87338	: V=0.9680453, theta=-29.512753 -> V=1.0, theta=0.0
% INFO    : Bus 87339	: V=0.9647821, theta=-29.471053 -> V=1.0, theta=0.0
% INFO    : Bus 87340	: V=0.9636057, theta=-29.943585 -> V=1.0, theta=0.0
% INFO    : Bus 87341	: V=0.9727946, theta=-28.764065 -> V=1.0, theta=0.0
% INFO    : Bus 87342	: V=1.0056344, theta=-25.315065 -> V=1.0, theta=0.0
% INFO    : Bus 87343	: V=0.9862292, theta=-26.82463 -> V=1.0, theta=0.0
% INFO    : Bus 87344	: V=0.9918702, theta=-26.590599 -> V=1.0, theta=0.0
% INFO    : Bus 87345	: V=0.990231, theta=-47.871823 -> V=1.0, theta=0.0
% INFO    : Bus 87346	: V=1.0177179, theta=-44.39982 -> V=1.0, theta=0.0
% INFO    : Bus 87347	: V=1.0154031, theta=-44.729651 -> V=1.0, theta=0.0
% INFO    : Bus 87348	: V=0.9966585, theta=-46.964121 -> V=1.0, theta=0.0
% INFO    : Bus 87349	: V=0.9689907, theta=-29.978694 -> V=1.0, theta=0.0
% INFO    : Bus 87350	: V=0.9808214, theta=-29.675026 -> V=1.0, theta=0.0
% INFO    : Bus 87351	: V=0.9815085, theta=-29.357676 -> V=1.0, theta=0.0
% INFO    : Bus 87352	: V=0.9824628, theta=-29.007593 -> V=1.0, theta=0.0
% INFO    : Bus 87353	: V=0.9663928, theta=-30.2976 -> V=1.0, theta=0.0
% INFO    : Bus 87354	: V=0.9898532, theta=-27.513619 -> V=1.0, theta=0.0
% INFO    : Bus 87355	: V=0.9904587, theta=-27.335229 -> V=1.0, theta=0.0
% INFO    : Bus 87356	: V=0.9749066, theta=-29.399503 -> V=1.0, theta=0.0
% INFO    : Bus 87357	: V=0.9637178, theta=-30.564323 -> V=1.0, theta=0.0
% INFO    : Bus 87358	: V=0.9915885, theta=-23.317328 -> V=1.0, theta=0.0
% INFO    : Bus 87359	: V=1.0050769, theta=-20.906634 -> V=1.0, theta=0.0
% INFO    : Bus 87360	: V=1.006505, theta=-21.481914 -> V=1.0, theta=0.0
% INFO    : Bus 87361	: V=0.9633844, theta=-44.775553 -> V=1.0, theta=0.0
% INFO    : Bus 87362	: V=0.9702097, theta=-43.448741 -> V=1.0, theta=0.0
% INFO    : Bus 87363	: V=0.9989985, theta=-24.44184 -> V=1.0, theta=0.0
% INFO    : Bus 87364	: V=1.0053584, theta=-23.322734 -> V=1.0, theta=0.0
% INFO    : Bus 87365	: V=1.0086715, theta=-23.35856 -> V=1.0, theta=0.0
% INFO    : Bus 87366	: V=1.0079136, theta=-23.275617 -> V=1.0, theta=0.0
% INFO    : Bus 87367	: V=1.0019364, theta=-39.665722 -> V=1.0, theta=0.0
% INFO    : Bus 87368	: V=0.9985093, theta=-40.026415 -> V=1.0, theta=0.0
% INFO    : Bus 87369	: V=0.9765176, theta=-43.158306 -> V=1.0, theta=0.0
% INFO    : Bus 87370	: V=0.9787493, theta=-43.043219 -> V=1.0, theta=0.0
% INFO    : Bus 87371	: V=0.9823146, theta=-42.688558 -> V=1.0, theta=0.0
% INFO    : Bus 87372	: V=0.9792262, theta=-43.160824 -> V=1.0, theta=0.0
% INFO    : Bus 87373	: V=0.977087, theta=-43.381034 -> V=1.0, theta=0.0
% INFO    : Bus 87374	: V=0.9896335, theta=-42.137131 -> V=1.0, theta=0.0
% INFO    : Bus 87375	: V=0.9910395, theta=-42.218996 -> V=1.0, theta=0.0
% INFO    : Bus 87376	: V=1.0095228, theta=-39.371072 -> V=1.0, theta=0.0
% INFO    : Bus 87377	: V=0.9823579, theta=-41.81212 -> V=1.0, theta=0.0
% INFO    : Bus 87378	: V=1.0073251, theta=-24.741914 -> V=1.0, theta=0.0
% INFO    : Bus 87379	: V=0.9657943, theta=-28.581618 -> V=1.0, theta=0.0
% INFO    : Bus 87380	: V=0.9600851, theta=-29.659275 -> V=1.0, theta=0.0
% INFO    : Bus 87381	: V=0.9654112, theta=-28.542599 -> V=1.0, theta=0.0
% INFO    : Bus 87382	: V=0.9567873, theta=-27.168146 -> V=1.0, theta=0.0
% INFO    : Bus 87383	: V=0.9715689, theta=-25.399943 -> V=1.0, theta=0.0
% INFO    : Bus 87384	: V=0.960198, theta=-26.634965 -> V=1.0, theta=0.0
% INFO    : Bus 87385	: V=0.9602495, theta=-26.631213 -> V=1.0, theta=0.0
% INFO    : Bus 87386	: V=0.960765, theta=-26.680634 -> V=1.0, theta=0.0
% INFO    : Bus 87387	: V=0.9649044, theta=-26.144837 -> V=1.0, theta=0.0
% INFO    : Bus 87388	: V=0.9650256, theta=-26.149601 -> V=1.0, theta=0.0
% INFO    : Bus 87389	: V=0.9701801, theta=-25.450643 -> V=1.0, theta=0.0
% INFO    : Bus 87390	: V=0.9697959, theta=-25.565148 -> V=1.0, theta=0.0
% INFO    : Bus 87391	: V=0.9727208, theta=-25.289355 -> V=1.0, theta=0.0
% INFO    : Bus 87392	: V=0.9645459, theta=-26.162773 -> V=1.0, theta=0.0
% INFO    : Bus 87393	: V=0.9592032, theta=-26.712311 -> V=1.0, theta=0.0
% INFO    : Bus 87394	: V=0.9675701, theta=-25.790705 -> V=1.0, theta=0.0
% INFO    : Bus 87395	: V=0.9676622, theta=-25.786106 -> V=1.0, theta=0.0
% INFO    : Bus 87396	: V=0.972787, theta=-25.230416 -> V=1.0, theta=0.0
% INFO    : Bus 87397	: V=0.9616004, theta=-26.469251 -> V=1.0, theta=0.0
% INFO    : Bus 87398	: V=0.9751714, theta=-25.024242 -> V=1.0, theta=0.0
% INFO    : Bus 87399	: V=0.9677561, theta=-25.793084 -> V=1.0, theta=0.0
% INFO    : Bus 87400	: V=0.9766894, theta=-24.626955 -> V=1.0, theta=0.0
% INFO    : Bus 87401	: V=0.9736236, theta=-24.965378 -> V=1.0, theta=0.0
% INFO    : Bus 87402	: V=0.9693925, theta=-25.187143 -> V=1.0, theta=0.0
% INFO    : Bus 87403	: V=0.9676747, theta=-26.029183 -> V=1.0, theta=0.0
% INFO    : Bus 87404	: V=0.9594632, theta=-26.717714 -> V=1.0, theta=0.0
% INFO    : Bus 87405	: V=0.9603357, theta=-26.609716 -> V=1.0, theta=0.0
% INFO    : Bus 87406	: V=0.9595294, theta=-26.842226 -> V=1.0, theta=0.0
% INFO    : Bus 87407	: V=0.9631048, theta=-26.414587 -> V=1.0, theta=0.0
% INFO    : Bus 87408	: V=0.9649625, theta=-27.037263 -> V=1.0, theta=0.0
% INFO    : Bus 87409	: V=0.9685814, theta=-26.334508 -> V=1.0, theta=0.0
% INFO    : Bus 87410	: V=0.9767637, theta=-25.664214 -> V=1.0, theta=0.0
% INFO    : Bus 87411	: V=0.9806124, theta=-25.402709 -> V=1.0, theta=0.0
% INFO    : Bus 87412	: V=0.955316, theta=-28.10547 -> V=1.0, theta=0.0
% INFO    : Bus 87413	: V=0.9580357, theta=-27.344549 -> V=1.0, theta=0.0
% INFO    : Bus 87414	: V=0.9552744, theta=-27.531824 -> V=1.0, theta=0.0
% INFO    : Bus 87415	: V=0.9768241, theta=-24.309938 -> V=1.0, theta=0.0
% INFO    : Bus 87416	: V=0.9760916, theta=-24.733885 -> V=1.0, theta=0.0
% INFO    : Bus 87417	: V=0.9714789, theta=-25.453363 -> V=1.0, theta=0.0
% INFO    : Bus 87418	: V=0.9585692, theta=-27.125721 -> V=1.0, theta=0.0
% INFO    : Bus 87419	: V=0.9721493, theta=-25.565984 -> V=1.0, theta=0.0
% INFO    : Bus 87420	: V=0.9764557, theta=-24.874074 -> V=1.0, theta=0.0
% INFO    : Bus 87421	: V=0.9634798, theta=-26.559862 -> V=1.0, theta=0.0
% INFO    : Bus 87422	: V=0.9736438, theta=-24.931538 -> V=1.0, theta=0.0
% INFO    : Bus 87423	: V=0.9454892, theta=-27.434562 -> V=1.0, theta=0.0
% INFO    : Bus 87424	: V=0.9638601, theta=-26.904698 -> V=1.0, theta=0.0
% INFO    : Bus 87425	: V=0.9635289, theta=-26.155779 -> V=1.0, theta=0.0
% INFO    : Bus 87426	: V=0.9635716, theta=-26.158674 -> V=1.0, theta=0.0
% INFO    : Bus 87427	: V=0.9545068, theta=-27.132725 -> V=1.0, theta=0.0
% INFO    : Bus 87428	: V=0.957398, theta=-27.026136 -> V=1.0, theta=0.0
% INFO    : Bus 87429	: V=0.981954, theta=-24.173048 -> V=1.0, theta=0.0
% INFO    : Bus 87430	: V=0.9804522, theta=-24.4738 -> V=1.0, theta=0.0
% INFO    : Bus 87431	: V=0.9741833, theta=-24.819142 -> V=1.0, theta=0.0
% INFO    : Bus 87432	: V=0.99501, theta=-22.894467 -> V=1.0, theta=0.0
% INFO    : Bus 87433	: V=0.9686488, theta=-25.814344 -> V=1.0, theta=0.0
% INFO    : Bus 87434	: V=0.9633002, theta=-26.485557 -> V=1.0, theta=0.0
% INFO    : Bus 87435	: V=1.0083412, theta=-21.444072 -> V=1.0, theta=0.0
% INFO    : Bus 87436	: V=1.0024279, theta=-22.126307 -> V=1.0, theta=0.0
% INFO    : Bus 87437	: V=1.0014334, theta=-20.796657 -> V=1.0, theta=0.0
% INFO    : Bus 87438	: V=1.0046905, theta=-20.137959 -> V=1.0, theta=0.0
% INFO    : Bus 87439	: V=1.0041618, theta=-19.739769 -> V=1.0, theta=0.0
% INFO    : Bus 87440	: V=1.0027924, theta=-19.41901 -> V=1.0, theta=0.0
% INFO    : Bus 87441	: V=1.0036372, theta=-21.552484 -> V=1.0, theta=0.0
% INFO    : Bus 87442	: V=0.9997327, theta=-21.932474 -> V=1.0, theta=0.0
% INFO    : Bus 87443	: V=0.9737879, theta=-29.60951 -> V=1.0, theta=0.0
% INFO    : Bus 87444	: V=0.9752669, theta=-30.007036 -> V=1.0, theta=0.0
% INFO    : Bus 87445	: V=0.9742716, theta=-29.678447 -> V=1.0, theta=0.0
% INFO    : Bus 87446	: V=0.9737229, theta=-29.812352 -> V=1.0, theta=0.0
% INFO    : Bus 87447	: V=0.977242, theta=-29.319732 -> V=1.0, theta=0.0
% INFO    : Bus 87448	: V=0.9709143, theta=-29.93208 -> V=1.0, theta=0.0
% INFO    : Bus 87449	: V=0.970224, theta=-30.007945 -> V=1.0, theta=0.0
% INFO    : Bus 87450	: V=0.9883443, theta=-27.931354 -> V=1.0, theta=0.0
% INFO    : Bus 87451	: V=1.0154207, theta=-26.194062 -> V=1.0, theta=0.0
% INFO    : Bus 87452	: V=1.0200669, theta=-25.56572 -> V=1.0, theta=0.0
% INFO    : Bus 87453	: V=1.0075984, theta=-27.329226 -> V=1.0, theta=0.0
% INFO    : Bus 87454	: V=0.9689899, theta=-25.42498 -> V=1.0, theta=0.0
% INFO    : Bus 87455	: V=1.0152444, theta=-17.628268 -> V=1.0, theta=0.0
% INFO    : Bus 87456	: V=1.013699, theta=-18.010486 -> V=1.0, theta=0.0
% INFO    : Bus 87457	: V=1.0110218, theta=-18.325266 -> V=1.0, theta=0.0
% INFO    : Bus 87458	: V=1.0050886, theta=-19.409849 -> V=1.0, theta=0.0
% INFO    : Bus 87459	: V=1.0049649, theta=-19.419687 -> V=1.0, theta=0.0
% INFO    : Bus 87460	: V=1.0031237, theta=-19.693535 -> V=1.0, theta=0.0
% INFO    : Bus 87461	: V=0.9974936, theta=-21.078144 -> V=1.0, theta=0.0
% INFO    : Bus 87462	: V=0.9759275, theta=-24.229265 -> V=1.0, theta=0.0
% INFO    : Bus 87463	: V=0.996196, theta=-21.181969 -> V=1.0, theta=0.0
% INFO    : Bus 87464	: V=0.9988221, theta=-20.586136 -> V=1.0, theta=0.0
% INFO    : Bus 87465	: V=1.0134459, theta=-18.393082 -> V=1.0, theta=0.0
% INFO    : Bus 87466	: V=0.9869539, theta=-29.440902 -> V=1.0, theta=0.0
% INFO    : Bus 87467	: V=0.9753494, theta=-30.464478 -> V=1.0, theta=0.0
% INFO    : Bus 87468	: V=0.9798934, theta=-30.002803 -> V=1.0, theta=0.0
% INFO    : Bus 87469	: V=0.9794977, theta=-30.031708 -> V=1.0, theta=0.0
% INFO    : Bus 87470	: V=0.9540482, theta=-28.313244 -> V=1.0, theta=0.0
% INFO    : Bus 87471	: V=0.9538788, theta=-28.304032 -> V=1.0, theta=0.0
% INFO    : Bus 87472	: V=0.9526012, theta=-27.9733 -> V=1.0, theta=0.0
% INFO    : Bus 87473	: V=0.9602583, theta=-26.795927 -> V=1.0, theta=0.0
% INFO    : Bus 87474	: V=0.9554529, theta=-27.782284 -> V=1.0, theta=0.0
% INFO    : Bus 87475	: V=0.9547544, theta=-28.139274 -> V=1.0, theta=0.0
% INFO    : Bus 87476	: V=0.9551762, theta=-27.847371 -> V=1.0, theta=0.0
% INFO    : Bus 87477	: V=0.9568027, theta=-27.688939 -> V=1.0, theta=0.0
% INFO    : Bus 87478	: V=0.9555616, theta=-27.96489 -> V=1.0, theta=0.0
% INFO    : Bus 87479	: V=0.9572449, theta=-27.498715 -> V=1.0, theta=0.0
% INFO    : Bus 87480	: V=0.9566094, theta=-27.478805 -> V=1.0, theta=0.0
% INFO    : Bus 87481	: V=0.9558056, theta=-27.677382 -> V=1.0, theta=0.0
% INFO    : Bus 87482	: V=0.9539859, theta=-27.819038 -> V=1.0, theta=0.0
% INFO    : Bus 87483	: V=0.9585927, theta=-29.482907 -> V=1.0, theta=0.0
% INFO    : Bus 87484	: V=0.9487653, theta=-30.455993 -> V=1.0, theta=0.0
% INFO    : Bus 87485	: V=0.9571317, theta=-27.713412 -> V=1.0, theta=0.0
% INFO    : Bus 87486	: V=0.9591846, theta=-26.945387 -> V=1.0, theta=0.0
% INFO    : Bus 87487	: V=0.95413, theta=-28.112392 -> V=1.0, theta=0.0
% INFO    : Bus 87488	: V=0.9630636, theta=-26.436718 -> V=1.0, theta=0.0
% INFO    : Bus 87489	: V=0.9651121, theta=-26.094756 -> V=1.0, theta=0.0
% INFO    : Bus 87490	: V=0.9652749, theta=-26.003182 -> V=1.0, theta=0.0
% INFO    : Bus 87491	: V=0.9633426, theta=-26.321708 -> V=1.0, theta=0.0
% INFO    : Bus 87492	: V=0.9710358, theta=-24.902126 -> V=1.0, theta=0.0
% INFO    : Bus 87493	: V=0.96306, theta=-27.790013 -> V=1.0, theta=0.0
% INFO    : Bus 87494	: V=0.9918296, theta=-31.463824 -> V=1.0, theta=0.0
% INFO    : Bus 87495	: V=1.0090912, theta=-36.22183 -> V=1.0, theta=0.0
% INFO    : Bus 87496	: V=1.0071163, theta=-21.467418 -> V=1.0, theta=0.0
% INFO    : Bus 87497	: V=1.005807, theta=-22.175087 -> V=1.0, theta=0.0
% INFO    : Bus 87498	: V=1.0154181, theta=-20.503698 -> V=1.0, theta=0.0
% INFO    : Bus 87499	: V=1.0143966, theta=-20.67952 -> V=1.0, theta=0.0
% INFO    : Bus 87500	: V=0.9989503, theta=-22.660209 -> V=1.0, theta=0.0
% INFO    : Bus 87501	: V=0.9640607, theta=-28.464276 -> V=1.0, theta=0.0
% INFO    : Bus 87502	: V=0.9635826, theta=-28.238712 -> V=1.0, theta=0.0
% INFO    : Bus 87503	: V=0.9594858, theta=-29.638782 -> V=1.0, theta=0.0
% INFO    : Bus 87504	: V=0.952782, theta=-30.839242 -> V=1.0, theta=0.0
% INFO    : Bus 87505	: V=0.9555614, theta=-30.640176 -> V=1.0, theta=0.0
% INFO    : Bus 87506	: V=0.9452248, theta=-32.389781 -> V=1.0, theta=0.0
% INFO    : Bus 87507	: V=0.9530444, theta=-30.481038 -> V=1.0, theta=0.0
% INFO    : Bus 87508	: V=0.9557634, theta=-29.883227 -> V=1.0, theta=0.0
% INFO    : Bus 87509	: V=0.976471, theta=-53.233031 -> V=1.0, theta=0.0
% INFO    : Bus 87510	: V=0.9803525, theta=-53.13507 -> V=1.0, theta=0.0
% INFO    : Bus 87511	: V=0.9815867, theta=-53.028298 -> V=1.0, theta=0.0
% INFO    : Bus 87512	: V=0.9778858, theta=-53.204152 -> V=1.0, theta=0.0
% INFO    : Bus 87513	: V=0.9871453, theta=-52.292818 -> V=1.0, theta=0.0
% INFO    : Bus 87514	: V=0.9776762, theta=-53.191485 -> V=1.0, theta=0.0
% INFO    : Bus 87515	: V=0.9769401, theta=-53.492418 -> V=1.0, theta=0.0
% INFO    : Bus 87516	: V=0.9770962, theta=-53.54931 -> V=1.0, theta=0.0
% INFO    : Bus 87517	: V=0.9820228, theta=-52.821971 -> V=1.0, theta=0.0
% INFO    : Bus 87518	: V=0.9746551, theta=-53.94081 -> V=1.0, theta=0.0
% INFO    : Bus 87519	: V=0.9788447, theta=-53.221416 -> V=1.0, theta=0.0
% INFO    : Bus 87520	: V=0.9755323, theta=-53.650862 -> V=1.0, theta=0.0
% INFO    : Bus 87521	: V=0.9783136, theta=-53.30496 -> V=1.0, theta=0.0
% INFO    : Bus 87522	: V=0.9804197, theta=-52.972328 -> V=1.0, theta=0.0
% INFO    : Bus 87523	: V=0.979219, theta=-53.216308 -> V=1.0, theta=0.0
% INFO    : Bus 87524	: V=0.9808777, theta=-53.026858 -> V=1.0, theta=0.0
% INFO    : Bus 87525	: V=0.9809527, theta=-52.954463 -> V=1.0, theta=0.0
% INFO    : Bus 87526	: V=0.9792101, theta=-53.064599 -> V=1.0, theta=0.0
% INFO    : Bus 87527	: V=0.9794623, theta=-53.241706 -> V=1.0, theta=0.0
% INFO    : Bus 87528	: V=0.9785213, theta=-53.275683 -> V=1.0, theta=0.0
% INFO    : Bus 87529	: V=0.9780574, theta=-53.303633 -> V=1.0, theta=0.0
% INFO    : Bus 87530	: V=0.9786169, theta=-53.30143 -> V=1.0, theta=0.0
% INFO    : Bus 87531	: V=0.9822073, theta=-53.142232 -> V=1.0, theta=0.0
% INFO    : Bus 87532	: V=1.0027162, theta=-48.71801 -> V=1.0, theta=0.0
% INFO    : Bus 87533	: V=0.9946757, theta=-50.058512 -> V=1.0, theta=0.0
% INFO    : Bus 87534	: V=0.9919724, theta=-50.570565 -> V=1.0, theta=0.0
% INFO    : Bus 87535	: V=0.9795174, theta=-53.309549 -> V=1.0, theta=0.0
% INFO    : Bus 87536	: V=0.9721234, theta=-54.451938 -> V=1.0, theta=0.0
% INFO    : Bus 87537	: V=0.9832293, theta=-52.658383 -> V=1.0, theta=0.0
% INFO    : Bus 87538	: V=0.9827489, theta=-52.681727 -> V=1.0, theta=0.0
% INFO    : Bus 87539	: V=0.9894115, theta=-51.618232 -> V=1.0, theta=0.0
% INFO    : Bus 87540	: V=0.9897519, theta=-51.063835 -> V=1.0, theta=0.0
% INFO    : Bus 87541	: V=1.0110608, theta=-46.434601 -> V=1.0, theta=0.0
% INFO    : Bus 87542	: V=1.0039755, theta=-48.050828 -> V=1.0, theta=0.0
% INFO    : Bus 87543	: V=1.0024219, theta=-48.004795 -> V=1.0, theta=0.0
% INFO    : Bus 87544	: V=0.9724026, theta=-53.693779 -> V=1.0, theta=0.0
% INFO    : Bus 87545	: V=0.9699252, theta=-54.333401 -> V=1.0, theta=0.0
% INFO    : Bus 87546	: V=0.9861182, theta=-52.496666 -> V=1.0, theta=0.0
% INFO    : Bus 87547	: V=0.9812818, theta=-53.127104 -> V=1.0, theta=0.0
% INFO    : Bus 87548	: V=0.9859711, theta=-52.48348 -> V=1.0, theta=0.0
% INFO    : Bus 87549	: V=0.9994354, theta=-51.481549 -> V=1.0, theta=0.0
% INFO    : Bus 87550	: V=0.9947208, theta=-52.445353 -> V=1.0, theta=0.0
% INFO    : Bus 87551	: V=0.9800429, theta=-53.436012 -> V=1.0, theta=0.0
% INFO    : Bus 87552	: V=0.9874237, theta=-52.41522 -> V=1.0, theta=0.0
% INFO    : Bus 87553	: V=0.9869511, theta=-52.894395 -> V=1.0, theta=0.0
% INFO    : Bus 87554	: V=1.0051706, theta=-50.404176 -> V=1.0, theta=0.0
% INFO    : Bus 87555	: V=1.008412, theta=-50.684186 -> V=1.0, theta=0.0
% INFO    : Bus 87556	: V=0.9767113, theta=-54.830182 -> V=1.0, theta=0.0
% INFO    : Bus 87557	: V=0.988481, theta=-52.320144 -> V=1.0, theta=0.0
% INFO    : Bus 87558	: V=0.9896382, theta=-52.403684 -> V=1.0, theta=0.0
% INFO    : Bus 87559	: V=0.9827703, theta=-52.925816 -> V=1.0, theta=0.0
% INFO    : Bus 87560	: V=0.9700323, theta=-54.593267 -> V=1.0, theta=0.0
% INFO    : Bus 87561	: V=1.005466, theta=-43.399979 -> V=1.0, theta=0.0
% INFO    : Bus 87562	: V=0.9696944, theta=-29.692582 -> V=1.0, theta=0.0
% INFO    : Bus 87563	: V=0.9759246, theta=-28.956958 -> V=1.0, theta=0.0
% INFO    : Bus 87564	: V=0.9681205, theta=-29.870313 -> V=1.0, theta=0.0
% INFO    : Bus 87565	: V=0.9714454, theta=-30.00289 -> V=1.0, theta=0.0
% INFO    : Bus 87566	: V=0.9610415, theta=-30.696395 -> V=1.0, theta=0.0
% INFO    : Bus 87567	: V=0.970218, theta=-29.366286 -> V=1.0, theta=0.0
% INFO    : Bus 87568	: V=0.9699073, theta=-30.1456 -> V=1.0, theta=0.0
% INFO    : Bus 87569	: V=0.9729379, theta=-30.120002 -> V=1.0, theta=0.0
% INFO    : Bus 87570	: V=0.9653841, theta=-30.622644 -> V=1.0, theta=0.0
% INFO    : Bus 87571	: V=0.9833303, theta=-28.751648 -> V=1.0, theta=0.0
% INFO    : Bus 87572	: V=0.9658986, theta=-30.43241 -> V=1.0, theta=0.0
% INFO    : Bus 87573	: V=0.9585932, theta=-31.518233 -> V=1.0, theta=0.0
% INFO    : Bus 87574	: V=0.9630796, theta=-31.096421 -> V=1.0, theta=0.0
% INFO    : Bus 87575	: V=0.983841, theta=-29.963082 -> V=1.0, theta=0.0
% INFO    : Bus 87576	: V=1.0087966, theta=-24.655111 -> V=1.0, theta=0.0
% INFO    : Bus 87577	: V=0.9743136, theta=-30.094397 -> V=1.0, theta=0.0
% INFO    : Bus 87578	: V=0.9972252, theta=-21.459368 -> V=1.0, theta=0.0
% INFO    : Bus 87579	: V=1.0004665, theta=-20.993598 -> V=1.0, theta=0.0
% INFO    : Bus 87580	: V=0.9717232, theta=-24.389461 -> V=1.0, theta=0.0
% INFO    : Bus 87581	: V=0.9949059, theta=-21.563765 -> V=1.0, theta=0.0
% INFO    : Bus 87582	: V=1.01704, theta=-18.120646 -> V=1.0, theta=0.0
% INFO    : Bus 87583	: V=1.0094475, theta=-19.200637 -> V=1.0, theta=0.0
% INFO    : Bus 87584	: V=1.0094042, theta=-19.216153 -> V=1.0, theta=0.0
% INFO    : Bus 87585	: V=0.9722233, theta=-25.098484 -> V=1.0, theta=0.0
% INFO    : Bus 87586	: V=0.9721231, theta=-24.332926 -> V=1.0, theta=0.0
% INFO    : Bus 87587	: V=0.9671785, theta=-24.847616 -> V=1.0, theta=0.0
% INFO    : Bus 87588	: V=0.9621027, theta=-25.579183 -> V=1.0, theta=0.0
% INFO    : Bus 87589	: V=1.0034378, theta=-28.83097 -> V=1.0, theta=0.0
% INFO    : Bus 87590	: V=0.9689188, theta=-40.899768 -> V=1.0, theta=0.0
% INFO    : Bus 87591	: V=0.9744859, theta=-40.304551 -> V=1.0, theta=0.0
% INFO    : Bus 87592	: V=0.994149, theta=-26.154552 -> V=1.0, theta=0.0
% INFO    : Bus 87593	: V=1.0040672, theta=-24.791413 -> V=1.0, theta=0.0
% INFO    : Bus 87594	: V=1.019664, theta=-26.20927 -> V=1.0, theta=0.0
% INFO    : Bus 87595	: V=1.0185207, theta=-26.193305 -> V=1.0, theta=0.0
% INFO    : Bus 87596	: V=1.0173784, theta=-26.270074 -> V=1.0, theta=0.0
% INFO    : Bus 87597	: V=1.0194947, theta=-26.283999 -> V=1.0, theta=0.0
% INFO    : Bus 87598	: V=1.0201498, theta=-26.382437 -> V=1.0, theta=0.0
% INFO    : Bus 87599	: V=1.019682, theta=-26.271558 -> V=1.0, theta=0.0
% INFO    : Bus 87600	: V=1.0201212, theta=-26.784793 -> V=1.0, theta=0.0
% INFO    : Bus 87601	: V=1.0144268, theta=-27.09901 -> V=1.0, theta=0.0
% INFO    : Bus 87602	: V=0.9623214, theta=-27.715247 -> V=1.0, theta=0.0
% INFO    : Bus 87603	: V=0.9731904, theta=-27.510356 -> V=1.0, theta=0.0
% INFO    : Bus 87604	: V=0.9503934, theta=-30.592114 -> V=1.0, theta=0.0
% INFO    : Bus 87605	: V=0.9571503, theta=-28.9981 -> V=1.0, theta=0.0
% INFO    : Bus 87606	: V=0.9746788, theta=-25.41849 -> V=1.0, theta=0.0
% INFO    : Bus 87607	: V=0.9586541, theta=-26.932741 -> V=1.0, theta=0.0
% INFO    : Bus 87608	: V=0.9651147, theta=-26.032903 -> V=1.0, theta=0.0
% INFO    : Bus 87609	: V=0.9550297, theta=-27.628127 -> V=1.0, theta=0.0
% INFO    : Bus 87610	: V=0.9748636, theta=-25.142277 -> V=1.0, theta=0.0
% INFO    : Bus 87611	: V=0.9770084, theta=-25.096561 -> V=1.0, theta=0.0
% INFO    : Bus 87612	: V=0.9776406, theta=-25.076507 -> V=1.0, theta=0.0
% INFO    : Bus 87613	: V=0.958995, theta=-27.007138 -> V=1.0, theta=0.0
% INFO    : Bus 87614	: V=0.9817919, theta=-24.540984 -> V=1.0, theta=0.0
% INFO    : Bus 87615	: V=0.9916628, theta=-23.907775 -> V=1.0, theta=0.0
% INFO    : Bus 87616	: V=0.9851338, theta=-24.497044 -> V=1.0, theta=0.0
% INFO    : Bus 87617	: V=0.9913103, theta=-23.722954 -> V=1.0, theta=0.0
% INFO    : Bus 87618	: V=0.9796461, theta=-24.599476 -> V=1.0, theta=0.0
% INFO    : Bus 87619	: V=0.9880971, theta=-23.879612 -> V=1.0, theta=0.0
% INFO    : Bus 87620	: V=0.9820968, theta=-24.517648 -> V=1.0, theta=0.0
% INFO    : Bus 87621	: V=0.9835822, theta=-24.327581 -> V=1.0, theta=0.0
% INFO    : Bus 87622	: V=0.9702138, theta=-26.167176 -> V=1.0, theta=0.0
% INFO    : Bus 87623	: V=0.9959698, theta=-23.380543 -> V=1.0, theta=0.0
% INFO    : Bus 87624	: V=1.0053208, theta=-21.885249 -> V=1.0, theta=0.0
% INFO    : Bus 87625	: V=1.0013325, theta=-22.765887 -> V=1.0, theta=0.0
% INFO    : Bus 87626	: V=0.9910017, theta=-25.098136 -> V=1.0, theta=0.0
% INFO    : Bus 87627	: V=0.9871982, theta=-34.727148 -> V=1.0, theta=0.0
% INFO    : Bus 87628	: V=0.9832959, theta=-26.829562 -> V=1.0, theta=0.0
% INFO    : Bus 87629	: V=1.0054126, theta=-24.615986 -> V=1.0, theta=0.0
% INFO    : Bus 87630	: V=1.005512, theta=-24.729429 -> V=1.0, theta=0.0
% INFO    : Bus 87631	: V=0.986589, theta=-25.220295 -> V=1.0, theta=0.0
% INFO    : Bus 87632	: V=1.0084039, theta=-22.782203 -> V=1.0, theta=0.0
% INFO    : Bus 87633	: V=0.9892084, theta=-24.627319 -> V=1.0, theta=0.0
% INFO    : Bus 87634	: V=0.9848698, theta=-25.08538 -> V=1.0, theta=0.0
% INFO    : Bus 87635	: V=0.9874472, theta=-24.128708 -> V=1.0, theta=0.0
% INFO    : Bus 87636	: V=0.9989791, theta=-23.421712 -> V=1.0, theta=0.0
% INFO    : Bus 87637	: V=0.9901343, theta=-24.554794 -> V=1.0, theta=0.0
% INFO    : Bus 87638	: V=0.9942915, theta=-23.723544 -> V=1.0, theta=0.0
% INFO    : Bus 87639	: V=0.9903802, theta=-24.301935 -> V=1.0, theta=0.0
% INFO    : Bus 87640	: V=0.9880879, theta=-24.391943 -> V=1.0, theta=0.0
% INFO    : Bus 87641	: V=0.9875489, theta=-24.723368 -> V=1.0, theta=0.0
% INFO    : Bus 87642	: V=0.9867108, theta=-24.757101 -> V=1.0, theta=0.0
% INFO    : Bus 87643	: V=0.9885178, theta=-24.682146 -> V=1.0, theta=0.0
% INFO    : Bus 87644	: V=0.9831273, theta=-24.905726 -> V=1.0, theta=0.0
% INFO    : Bus 87645	: V=0.9883131, theta=-24.542897 -> V=1.0, theta=0.0
% INFO    : Bus 87646	: V=0.9836215, theta=-25.26666 -> V=1.0, theta=0.0
% INFO    : Bus 87647	: V=0.9865765, theta=-24.715686 -> V=1.0, theta=0.0
% INFO    : Bus 87648	: V=1.0087615, theta=-22.141287 -> V=1.0, theta=0.0
% INFO    : Bus 87649	: V=1.003142, theta=-22.890817 -> V=1.0, theta=0.0
% INFO    : Bus 87650	: V=0.9790754, theta=-25.357797 -> V=1.0, theta=0.0
% INFO    : Bus 87651	: V=0.987495, theta=-24.571219 -> V=1.0, theta=0.0
% INFO    : Bus 87652	: V=0.9857666, theta=-23.639318 -> V=1.0, theta=0.0
% INFO    : Bus 87653	: V=0.9972942, theta=-43.459343 -> V=1.0, theta=0.0
% INFO    : Bus 87654	: V=1.0025243, theta=-42.676435 -> V=1.0, theta=0.0
% INFO    : Bus 87655	: V=1.017836, theta=-44.152362 -> V=1.0, theta=0.0
% INFO    : Bus 87656	: V=1.0161111, theta=-44.619552 -> V=1.0, theta=0.0
% INFO    : Bus 87657	: V=1.0069635, theta=-35.562391 -> V=1.0, theta=0.0
% INFO    : Bus 87658	: V=1.0009541, theta=-36.603997 -> V=1.0, theta=0.0
% INFO    : Bus 87659	: V=0.9793896, theta=-24.538995 -> V=1.0, theta=0.0
% INFO    : Bus 87660	: V=0.9894504, theta=-22.912713 -> V=1.0, theta=0.0
% INFO    : Bus 87661	: V=0.9736686, theta=-24.367331 -> V=1.0, theta=0.0
% INFO    : Bus 87662	: V=0.9716606, theta=-15.582876 -> V=1.0, theta=0.0
% INFO    : Bus 87663	: V=0.9620374, theta=-14.527393 -> V=1.0, theta=0.0
% INFO    : Bus 87664	: V=0.9738605, theta=-22.648843 -> V=1.0, theta=0.0
% INFO    : Bus 87665	: V=0.9761348, theta=-23.036487 -> V=1.0, theta=0.0
% INFO    : Bus 87666	: V=0.9739892, theta=-23.023697 -> V=1.0, theta=0.0
% INFO    : Bus 87667	: V=0.9775216, theta=-23.523263 -> V=1.0, theta=0.0
% INFO    : Bus 87668	: V=0.9694292, theta=-43.332143 -> V=1.0, theta=0.0
% INFO    : Bus 87669	: V=0.9625713, theta=-42.852424 -> V=1.0, theta=0.0
% INFO    : Bus 87670	: V=0.9730047, theta=-11.392157 -> V=1.0, theta=0.0
% INFO    : Bus 87671	: V=0.9826481, theta=-11.405737 -> V=1.0, theta=0.0
% INFO    : Bus 87672	: V=0.997359, theta=-11.641009 -> V=1.0, theta=0.0
% INFO    : Bus 87673	: V=0.9833362, theta=-12.079336 -> V=1.0, theta=0.0
% INFO    : Bus 87674	: V=0.9826591, theta=-12.038982 -> V=1.0, theta=0.0
% INFO    : Bus 87675	: V=0.9932282, theta=-11.204182 -> V=1.0, theta=0.0
% INFO    : Bus 87676	: V=0.9852842, theta=-11.48621 -> V=1.0, theta=0.0
% INFO    : Bus 87677	: V=0.9835914, theta=-11.349887 -> V=1.0, theta=0.0
% INFO    : Bus 87678	: V=0.983553, theta=-11.371117 -> V=1.0, theta=0.0
% INFO    : Bus 87679	: V=0.9740945, theta=-11.382098 -> V=1.0, theta=0.0
% INFO    : Bus 87680	: V=0.9782466, theta=-10.679324 -> V=1.0, theta=0.0
% INFO    : Bus 87681	: V=0.9864621, theta=-11.29496 -> V=1.0, theta=0.0
% INFO    : Bus 87682	: V=0.9833539, theta=-16.79631 -> V=1.0, theta=0.0
% INFO    : Bus 87683	: V=0.9734265, theta=-16.033184 -> V=1.0, theta=0.0
% INFO    : Bus 87684	: V=0.9655891, theta=-30.207354 -> V=1.0, theta=0.0
% INFO    : Bus 87685	: V=0.9758684, theta=-31.242975 -> V=1.0, theta=0.0
% INFO    : Bus 87686	: V=0.9999021, theta=-30.724251 -> V=1.0, theta=0.0
% INFO    : Bus 87687	: V=0.9951895, theta=-31.153524 -> V=1.0, theta=0.0
% INFO    : Bus 87688	: V=0.9928489, theta=-31.177935 -> V=1.0, theta=0.0
% INFO    : Bus 87689	: V=0.976074, theta=-19.771756 -> V=1.0, theta=0.0
% INFO    : Bus 87690	: V=0.9768673, theta=-19.679627 -> V=1.0, theta=0.0
% INFO    : Bus 87691	: V=0.9886607, theta=-14.187217 -> V=1.0, theta=0.0
% INFO    : Bus 87692	: V=0.9914186, theta=-14.316328 -> V=1.0, theta=0.0
% INFO    : Bus 87693	: V=1.0092382, theta=-8.687826 -> V=1.0, theta=0.0
% INFO    : Bus 87694	: V=1.0161489, theta=-8.942892 -> V=1.0, theta=0.0
% INFO    : Bus 87695	: V=1.0120927, theta=-9.250372 -> V=1.0, theta=0.0
% INFO    : Bus 87696	: V=1.0166892, theta=-8.178798 -> V=1.0, theta=0.0
% INFO    : Bus 87697	: V=1.0005408, theta=-9.594917 -> V=1.0, theta=0.0
% INFO    : Bus 87698	: V=0.9666654, theta=-9.604893 -> V=1.0, theta=0.0
% INFO    : Bus 87699	: V=0.9694338, theta=-9.557828 -> V=1.0, theta=0.0
% INFO    : Bus 87700	: V=0.9723086, theta=-9.068557 -> V=1.0, theta=0.0
% INFO    : Bus 87701	: V=0.9750305, theta=-9.407052 -> V=1.0, theta=0.0
% INFO    : Bus 87702	: V=1.0037732, theta=-10.658753 -> V=1.0, theta=0.0
% INFO    : Bus 87703	: V=1.0076249, theta=-9.927847 -> V=1.0, theta=0.0
% INFO    : Bus 87704	: V=1.0085394, theta=-11.88921 -> V=1.0, theta=0.0
% INFO    : Bus 87705	: V=1.008885, theta=-11.760277 -> V=1.0, theta=0.0
% INFO    : Bus 87706	: V=1.0092482, theta=-11.740259 -> V=1.0, theta=0.0
% INFO    : Bus 87707	: V=1.005094, theta=-12.263227 -> V=1.0, theta=0.0
% INFO    : Bus 87708	: V=0.9578463, theta=-11.763869 -> V=1.0, theta=0.0
% INFO    : Bus 87709	: V=0.9595375, theta=-12.735192 -> V=1.0, theta=0.0
% INFO    : Bus 87710	: V=0.9571785, theta=-11.768831 -> V=1.0, theta=0.0
% INFO    : Bus 87711	: V=0.956953, theta=-12.14998 -> V=1.0, theta=0.0
% INFO    : Bus 87712	: V=0.9570897, theta=-12.274274 -> V=1.0, theta=0.0
% INFO    : Bus 87713	: V=0.9583338, theta=-11.677152 -> V=1.0, theta=0.0
% INFO    : Bus 87714	: V=0.9592446, theta=-12.024623 -> V=1.0, theta=0.0
% INFO    : Bus 87715	: V=1.0136172, theta=-10.883674 -> V=1.0, theta=0.0
% INFO    : Bus 87716	: V=1.0101587, theta=-10.384704 -> V=1.0, theta=0.0
% INFO    : Bus 87717	: V=0.9820562, theta=-10.068734 -> V=1.0, theta=0.0
% INFO    : Bus 87718	: V=0.9900492, theta=-25.642035 -> V=1.0, theta=0.0
% INFO    : Bus 87719	: V=0.9884794, theta=-27.305966 -> V=1.0, theta=0.0
% INFO    : Bus 87720	: V=1.0008426, theta=-29.398194 -> V=1.0, theta=0.0
% INFO    : Bus 87721	: V=0.9543878, theta=-25.540905 -> V=1.0, theta=0.0
% INFO    : Bus 87722	: V=0.9866048, theta=-12.024524 -> V=1.0, theta=0.0
% INFO    : Bus 87723	: V=0.9960083, theta=-12.265355 -> V=1.0, theta=0.0
% INFO    : Bus 87724	: V=0.9936778, theta=-12.28627 -> V=1.0, theta=0.0
% INFO    : Bus 87725	: V=1.0062699, theta=-10.732366 -> V=1.0, theta=0.0
% INFO    : Bus 87726	: V=1.0005535, theta=-14.980198 -> V=1.0, theta=0.0
% INFO    : Bus 87727	: V=0.9985194, theta=-15.260547 -> V=1.0, theta=0.0
% INFO    : Bus 87728	: V=0.9978935, theta=-18.326343 -> V=1.0, theta=0.0
% INFO    : Bus 87729	: V=0.9998552, theta=-18.425415 -> V=1.0, theta=0.0
% INFO    : Bus 87730	: V=0.993335, theta=-18.300572 -> V=1.0, theta=0.0
% INFO    : Bus 87731	: V=1.0072965, theta=-19.390974 -> V=1.0, theta=0.0
% INFO    : Bus 87732	: V=0.9918682, theta=-17.821138 -> V=1.0, theta=0.0
% INFO    : Bus 87733	: V=0.9598852, theta=-36.708627 -> V=1.0, theta=0.0
% INFO    : Bus 87734	: V=0.9816207, theta=-28.599166 -> V=1.0, theta=0.0
% INFO    : Bus 87735	: V=0.9673729, theta=-30.870439 -> V=1.0, theta=0.0
% INFO    : Bus 87736	: V=1.0089042, theta=-7.902217 -> V=1.0, theta=0.0
% INFO    : Bus 87737	: V=1.0079696, theta=-7.897402 -> V=1.0, theta=0.0
% INFO    : Bus 87738	: V=1.0020078, theta=-6.921526 -> V=1.0, theta=0.0
% INFO    : Bus 87739	: V=1.0064223, theta=-6.955633 -> V=1.0, theta=0.0
% INFO    : Bus 87740	: V=0.9958223, theta=-6.94637 -> V=1.0, theta=0.0
% INFO    : Bus 87741	: V=1.0000176, theta=-6.902687 -> V=1.0, theta=0.0
% INFO    : Bus 87742	: V=1.0007911, theta=-6.881986 -> V=1.0, theta=0.0
% INFO    : Bus 87743	: V=0.9997475, theta=-6.843135 -> V=1.0, theta=0.0
% INFO    : Bus 87744	: V=1.0175911, theta=-6.890307 -> V=1.0, theta=0.0
% INFO    : Bus 87745	: V=1.0110408, theta=-7.605765 -> V=1.0, theta=0.0
% INFO    : Bus 87746	: V=0.9977481, theta=-6.984772 -> V=1.0, theta=0.0
% INFO    : Bus 87747	: V=0.9729556, theta=-14.584309 -> V=1.0, theta=0.0
% INFO    : Bus 87748	: V=0.9664092, theta=-14.708335 -> V=1.0, theta=0.0
% INFO    : Bus 87749	: V=0.9725466, theta=-21.579712 -> V=1.0, theta=0.0
% INFO    : Bus 87750	: V=0.9729803, theta=-17.139353 -> V=1.0, theta=0.0
% INFO    : Bus 87751	: V=0.9732028, theta=-17.191999 -> V=1.0, theta=0.0
% INFO    : Bus 87752	: V=0.9703409, theta=-17.208117 -> V=1.0, theta=0.0
% INFO    : Bus 87753	: V=0.9700177, theta=-17.173306 -> V=1.0, theta=0.0
% INFO    : Bus 87754	: V=0.9740064, theta=-17.132668 -> V=1.0, theta=0.0
% INFO    : Bus 87755	: V=0.97309, theta=-17.188063 -> V=1.0, theta=0.0
% INFO    : Bus 87756	: V=0.9717596, theta=-17.231075 -> V=1.0, theta=0.0
% INFO    : Bus 87757	: V=0.9710266, theta=-17.177934 -> V=1.0, theta=0.0
% INFO    : Bus 87758	: V=0.97925, theta=-17.098464 -> V=1.0, theta=0.0
% INFO    : Bus 87759	: V=0.978832, theta=-17.158716 -> V=1.0, theta=0.0
% INFO    : Bus 87760	: V=0.9839018, theta=-17.20211 -> V=1.0, theta=0.0
% INFO    : Bus 87761	: V=0.9774129, theta=-17.231411 -> V=1.0, theta=0.0
% INFO    : Bus 87762	: V=0.9754986, theta=-17.113004 -> V=1.0, theta=0.0
% INFO    : Bus 87763	: V=0.9714436, theta=-17.133183 -> V=1.0, theta=0.0
% INFO    : Bus 87764	: V=0.9698288, theta=-17.223765 -> V=1.0, theta=0.0
% INFO    : Bus 87765	: V=0.9719864, theta=-17.391786 -> V=1.0, theta=0.0
% INFO    : Bus 87766	: V=0.9748498, theta=-17.327055 -> V=1.0, theta=0.0
% INFO    : Bus 87767	: V=0.9554485, theta=-17.245187 -> V=1.0, theta=0.0
% INFO    : Bus 87768	: V=0.9783547, theta=-17.002791 -> V=1.0, theta=0.0
% INFO    : Bus 87769	: V=0.9689156, theta=-16.808855 -> V=1.0, theta=0.0
% INFO    : Bus 87770	: V=0.9704293, theta=-17.22757 -> V=1.0, theta=0.0
% INFO    : Bus 87771	: V=0.9818656, theta=-17.158214 -> V=1.0, theta=0.0
% INFO    : Bus 87772	: V=0.9845783, theta=-17.134658 -> V=1.0, theta=0.0
% INFO    : Bus 87773	: V=0.9716154, theta=-17.337997 -> V=1.0, theta=0.0
% INFO    : Bus 87774	: V=0.9721364, theta=-17.410182 -> V=1.0, theta=0.0
% INFO    : Bus 87775	: V=0.9828936, theta=-17.384 -> V=1.0, theta=0.0
% INFO    : Bus 87776	: V=0.9987408, theta=-17.347435 -> V=1.0, theta=0.0
% INFO    : Bus 87777	: V=0.9927128, theta=-17.378033 -> V=1.0, theta=0.0
% INFO    : Bus 87778	: V=0.992247, theta=-17.357485 -> V=1.0, theta=0.0
% INFO    : Bus 87779	: V=0.9761186, theta=-17.633393 -> V=1.0, theta=0.0
% INFO    : Bus 87780	: V=0.9840332, theta=-17.221115 -> V=1.0, theta=0.0
% INFO    : Bus 87781	: V=0.9800369, theta=-17.276648 -> V=1.0, theta=0.0
% INFO    : Bus 87782	: V=0.9747165, theta=-20.614938 -> V=1.0, theta=0.0
% INFO    : Bus 87783	: V=0.977124, theta=-35.435779 -> V=1.0, theta=0.0
% INFO    : Bus 87784	: V=0.983916, theta=-37.467872 -> V=1.0, theta=0.0
% INFO    : Bus 87785	: V=0.9812977, theta=-37.688107 -> V=1.0, theta=0.0
% INFO    : Bus 87786	: V=0.9852871, theta=-34.319201 -> V=1.0, theta=0.0
% INFO    : Bus 87787	: V=0.967036, theta=-14.995722 -> V=1.0, theta=0.0
% INFO    : Bus 87788	: V=0.9637509, theta=-14.622019 -> V=1.0, theta=0.0
% INFO    : Bus 87789	: V=0.9807126, theta=-14.592133 -> V=1.0, theta=0.0
% INFO    : Bus 87790	: V=1.0186366, theta=-13.568388 -> V=1.0, theta=0.0
% INFO    : Bus 87791	: V=1.0156737, theta=-13.525898 -> V=1.0, theta=0.0
% INFO    : Bus 87792	: V=1.0152911, theta=-10.464419 -> V=1.0, theta=0.0
% INFO    : Bus 87793	: V=1.0113777, theta=-10.784636 -> V=1.0, theta=0.0
% INFO    : Bus 87794	: V=0.9854124, theta=-18.850414 -> V=1.0, theta=0.0
% INFO    : Bus 87795	: V=0.9797643, theta=-11.79372 -> V=1.0, theta=0.0
% INFO    : Bus 87796	: V=0.9694752, theta=-12.797639 -> V=1.0, theta=0.0
% INFO    : Bus 87797	: V=1.0184859, theta=-11.635152 -> V=1.0, theta=0.0
% INFO    : Bus 87798	: V=1.0147026, theta=-11.835828 -> V=1.0, theta=0.0
% INFO    : Bus 87799	: V=1.0102352, theta=-11.875239 -> V=1.0, theta=0.0
% INFO    : Bus 87800	: V=1.0099297, theta=-11.582031 -> V=1.0, theta=0.0
% INFO    : Bus 87801	: V=1.0213021, theta=-12.064159 -> V=1.0, theta=0.0
% INFO    : Bus 87802	: V=1.013998, theta=-10.792217 -> V=1.0, theta=0.0
% INFO    : Bus 87803	: V=0.9655503, theta=-21.4677 -> V=1.0, theta=0.0
% INFO    : Bus 87804	: V=0.9673927, theta=-29.80986 -> V=1.0, theta=0.0
% INFO    : Bus 87805	: V=0.9670148, theta=-29.681404 -> V=1.0, theta=0.0
% INFO    : Bus 87806	: V=0.9652919, theta=-27.280464 -> V=1.0, theta=0.0
% INFO    : Bus 87807	: V=1.0186046, theta=-8.391155 -> V=1.0, theta=0.0
% INFO    : Bus 87808	: V=0.9953823, theta=-9.767812 -> V=1.0, theta=0.0
% INFO    : Bus 87809	: V=0.9935672, theta=-9.413038 -> V=1.0, theta=0.0
% INFO    : Bus 87810	: V=0.9780611, theta=-10.155779 -> V=1.0, theta=0.0
% INFO    : Bus 87811	: V=0.9871351, theta=-10.297561 -> V=1.0, theta=0.0
% INFO    : Bus 87812	: V=0.9842062, theta=-11.227197 -> V=1.0, theta=0.0
% INFO    : Bus 87813	: V=0.9863065, theta=-11.204905 -> V=1.0, theta=0.0
% INFO    : Bus 87814	: V=0.972332, theta=-11.755234 -> V=1.0, theta=0.0
% INFO    : Bus 87815	: V=0.9722658, theta=-45.188393 -> V=1.0, theta=0.0
% INFO    : Bus 87816	: V=0.9770296, theta=-43.248691 -> V=1.0, theta=0.0
% INFO    : Bus 87817	: V=0.9785582, theta=-43.627629 -> V=1.0, theta=0.0
% INFO    : Bus 87818	: V=0.9745946, theta=-44.95855 -> V=1.0, theta=0.0
% INFO    : Bus 87819	: V=0.9810376, theta=-16.330358 -> V=1.0, theta=0.0
% INFO    : Bus 87820	: V=0.9660887, theta=-16.031212 -> V=1.0, theta=0.0
% INFO    : Bus 87821	: V=0.9707513, theta=-18.801027 -> V=1.0, theta=0.0
% INFO    : Bus 87822	: V=0.9811041, theta=-7.367757 -> V=1.0, theta=0.0
% INFO    : Bus 87823	: V=0.9907075, theta=-7.334279 -> V=1.0, theta=0.0
% INFO    : Bus 87824	: V=0.9665238, theta=-10.153212 -> V=1.0, theta=0.0
% INFO    : Bus 87825	: V=1.0225239, theta=-12.216506 -> V=1.0, theta=0.0
% INFO    : Bus 87826	: V=1.003946, theta=-9.019462 -> V=1.0, theta=0.0
% INFO    : Bus 87827	: V=0.9982394, theta=-9.390755 -> V=1.0, theta=0.0
% INFO    : Bus 87828	: V=1.005548, theta=-10.021642 -> V=1.0, theta=0.0
% INFO    : Bus 87829	: V=0.9551167, theta=-34.902518 -> V=1.0, theta=0.0
% INFO    : Bus 87830	: V=0.9891801, theta=-8.398494 -> V=1.0, theta=0.0
% INFO    : Bus 87831	: V=0.9882045, theta=-8.339656 -> V=1.0, theta=0.0
% INFO    : Bus 87832	: V=0.986472, theta=-8.465795 -> V=1.0, theta=0.0
% INFO    : Bus 87833	: V=0.9989242, theta=-8.490104 -> V=1.0, theta=0.0
% INFO    : Bus 87834	: V=0.9846042, theta=-8.623935 -> V=1.0, theta=0.0
% INFO    : Bus 87835	: V=0.9843875, theta=-8.540176 -> V=1.0, theta=0.0
% INFO    : Bus 87836	: V=0.9838765, theta=-8.472648 -> V=1.0, theta=0.0
% INFO    : Bus 87837	: V=0.9815846, theta=-8.567 -> V=1.0, theta=0.0
% INFO    : Bus 87838	: V=0.9944216, theta=-8.515727 -> V=1.0, theta=0.0
% INFO    : Bus 87839	: V=0.9868483, theta=-8.55802 -> V=1.0, theta=0.0
% INFO    : Bus 87840	: V=0.9860885, theta=-8.587172 -> V=1.0, theta=0.0
% INFO    : Bus 87841	: V=0.994852, theta=-8.573433 -> V=1.0, theta=0.0
% INFO    : Bus 87842	: V=0.9848072, theta=-8.612488 -> V=1.0, theta=0.0
% INFO    : Bus 87843	: V=0.9725469, theta=-8.746984 -> V=1.0, theta=0.0
% INFO    : Bus 87844	: V=0.9825986, theta=-8.648387 -> V=1.0, theta=0.0
% INFO    : Bus 87845	: V=0.9853114, theta=-8.614949 -> V=1.0, theta=0.0
% INFO    : Bus 87846	: V=0.974475, theta=-8.705782 -> V=1.0, theta=0.0
% INFO    : Bus 87847	: V=0.9772266, theta=-8.69165 -> V=1.0, theta=0.0
% INFO    : Bus 87848	: V=0.9742401, theta=-8.677988 -> V=1.0, theta=0.0
% INFO    : Bus 87849	: V=0.9746114, theta=-8.687571 -> V=1.0, theta=0.0
% INFO    : Bus 87850	: V=0.9723188, theta=-8.73707 -> V=1.0, theta=0.0
% INFO    : Bus 87851	: V=0.973994, theta=-8.719795 -> V=1.0, theta=0.0
% INFO    : Bus 87852	: V=0.9764206, theta=-8.697876 -> V=1.0, theta=0.0
% INFO    : Bus 87853	: V=0.9871686, theta=-8.719566 -> V=1.0, theta=0.0
% INFO    : Bus 87854	: V=0.9867304, theta=-8.700346 -> V=1.0, theta=0.0
% INFO    : Bus 87855	: V=0.9787055, theta=-8.700464 -> V=1.0, theta=0.0
% INFO    : Bus 87856	: V=0.9778774, theta=-8.692544 -> V=1.0, theta=0.0
% INFO    : Bus 87857	: V=0.9737192, theta=-8.640442 -> V=1.0, theta=0.0
% INFO    : Bus 87858	: V=0.984578, theta=-8.702945 -> V=1.0, theta=0.0
% INFO    : Bus 87859	: V=0.9853784, theta=-8.791503 -> V=1.0, theta=0.0
% INFO    : Bus 87860	: V=0.9790985, theta=-8.721184 -> V=1.0, theta=0.0
% INFO    : Bus 87861	: V=0.9786445, theta=-8.702689 -> V=1.0, theta=0.0
% INFO    : Bus 87862	: V=0.9810314, theta=-8.72116 -> V=1.0, theta=0.0
% INFO    : Bus 87863	: V=0.9825828, theta=-8.74702 -> V=1.0, theta=0.0
% INFO    : Bus 87864	: V=0.9974558, theta=-8.635273 -> V=1.0, theta=0.0
% INFO    : Bus 87865	: V=0.9927733, theta=-8.753839 -> V=1.0, theta=0.0
% INFO    : Bus 87866	: V=0.9867243, theta=-8.751358 -> V=1.0, theta=0.0
% INFO    : Bus 87867	: V=0.9850207, theta=-8.859147 -> V=1.0, theta=0.0
% INFO    : Bus 87868	: V=0.9765465, theta=-8.711864 -> V=1.0, theta=0.0
% INFO    : Bus 87869	: V=0.9783505, theta=-8.717859 -> V=1.0, theta=0.0
% INFO    : Bus 87870	: V=0.9785464, theta=-8.730574 -> V=1.0, theta=0.0
% INFO    : Bus 87871	: V=0.9807837, theta=-8.735641 -> V=1.0, theta=0.0
% INFO    : Bus 87872	: V=0.9689689, theta=-8.826657 -> V=1.0, theta=0.0
% INFO    : Bus 87873	: V=0.9769462, theta=-9.013828 -> V=1.0, theta=0.0
% INFO    : Bus 87874	: V=0.9748811, theta=-8.773286 -> V=1.0, theta=0.0
% INFO    : Bus 87875	: V=0.9783463, theta=-8.737913 -> V=1.0, theta=0.0
% INFO    : Bus 87876	: V=0.9777208, theta=-8.746972 -> V=1.0, theta=0.0
% INFO    : Bus 87877	: V=0.9841781, theta=-8.66318 -> V=1.0, theta=0.0
% INFO    : Bus 87878	: V=0.9865884, theta=-8.66256 -> V=1.0, theta=0.0
% INFO    : Bus 87879	: V=0.9776142, theta=-8.726412 -> V=1.0, theta=0.0
% INFO    : Bus 87880	: V=0.9772973, theta=-8.752142 -> V=1.0, theta=0.0
% INFO    : Bus 87881	: V=0.9783605, theta=-8.745327 -> V=1.0, theta=0.0
% INFO    : Bus 87882	: V=0.9769043, theta=-8.7483 -> V=1.0, theta=0.0
% INFO    : Bus 87883	: V=0.9755743, theta=-8.739878 -> V=1.0, theta=0.0
% INFO    : Bus 87884	: V=0.9680261, theta=-9.053561 -> V=1.0, theta=0.0
% INFO    : Bus 87885	: V=0.9750828, theta=-9.07636 -> V=1.0, theta=0.0
% INFO    : Bus 87886	: V=0.9846807, theta=-8.654452 -> V=1.0, theta=0.0
% INFO    : Bus 87887	: V=0.9781184, theta=-8.729273 -> V=1.0, theta=0.0
% INFO    : Bus 87888	: V=0.9693834, theta=-9.011525 -> V=1.0, theta=0.0
% INFO    : Bus 87889	: V=1.0086021, theta=-8.693311 -> V=1.0, theta=0.0
% INFO    : Bus 87890	: V=1.0031878, theta=-8.485988 -> V=1.0, theta=0.0
% INFO    : Bus 87891	: V=0.9997902, theta=-8.514574 -> V=1.0, theta=0.0
% INFO    : Bus 87892	: V=1.0058594, theta=-8.368837 -> V=1.0, theta=0.0
% INFO    : Bus 87893	: V=0.9971471, theta=-8.569458 -> V=1.0, theta=0.0
% INFO    : Bus 87894	: V=1.0115653, theta=-8.381929 -> V=1.0, theta=0.0
% INFO    : Bus 87895	: V=1.0125433, theta=-8.370956 -> V=1.0, theta=0.0
% INFO    : Bus 87896	: V=1.0127269, theta=-8.369647 -> V=1.0, theta=0.0
% INFO    : Bus 87897	: V=1.0011113, theta=-8.483035 -> V=1.0, theta=0.0
% INFO    : Bus 87898	: V=1.0019646, theta=-8.487339 -> V=1.0, theta=0.0
% INFO    : Bus 87899	: V=0.9944239, theta=-8.533992 -> V=1.0, theta=0.0
% INFO    : Bus 87900	: V=0.9966418, theta=-8.502568 -> V=1.0, theta=0.0
% INFO    : Bus 87901	: V=0.9942874, theta=-8.526751 -> V=1.0, theta=0.0
% INFO    : Bus 87902	: V=1.0032043, theta=-8.405025 -> V=1.0, theta=0.0
% INFO    : Bus 87903	: V=1.0026842, theta=-8.175828 -> V=1.0, theta=0.0
% INFO    : Bus 87904	: V=1.0008485, theta=-8.468271 -> V=1.0, theta=0.0
% INFO    : Bus 87905	: V=0.9855921, theta=-8.447289 -> V=1.0, theta=0.0
% INFO    : Bus 87906	: V=0.9996261, theta=-8.518486 -> V=1.0, theta=0.0
% INFO    : Bus 87907	: V=0.9942033, theta=-8.599574 -> V=1.0, theta=0.0
% INFO    : Bus 87908	: V=0.9989045, theta=-17.69313 -> V=1.0, theta=0.0
% INFO    : Bus 87909	: V=0.9943626, theta=-17.646789 -> V=1.0, theta=0.0
% INFO    : Bus 87910	: V=0.9934374, theta=-17.722637 -> V=1.0, theta=0.0
% INFO    : Bus 87911	: V=0.9729438, theta=-17.834028 -> V=1.0, theta=0.0
% INFO    : Bus 87912	: V=0.9922174, theta=-31.353429 -> V=1.0, theta=0.0
% INFO    : Bus 87913	: V=0.9957355, theta=-32.646215 -> V=1.0, theta=0.0
% INFO    : Bus 87914	: V=0.9932137, theta=-32.530307 -> V=1.0, theta=0.0
% INFO    : Bus 87915	: V=0.9817813, theta=-35.05878 -> V=1.0, theta=0.0
% INFO    : Bus 87916	: V=0.9572615, theta=-11.636472 -> V=1.0, theta=0.0
% INFO    : Bus 87917	: V=0.9605711, theta=-11.889541 -> V=1.0, theta=0.0
% INFO    : Bus 87918	: V=0.9677287, theta=-11.925989 -> V=1.0, theta=0.0
% INFO    : Bus 87919	: V=0.9761803, theta=-11.43541 -> V=1.0, theta=0.0
% INFO    : Bus 87920	: V=0.9746654, theta=-11.445747 -> V=1.0, theta=0.0
% INFO    : Bus 87921	: V=0.9693828, theta=-11.725713 -> V=1.0, theta=0.0
% INFO    : Bus 87922	: V=0.9755773, theta=-11.44443 -> V=1.0, theta=0.0
% INFO    : Bus 87923	: V=0.9616987, theta=-11.745868 -> V=1.0, theta=0.0
% INFO    : Bus 87924	: V=0.9607596, theta=-11.781518 -> V=1.0, theta=0.0
% INFO    : Bus 87925	: V=0.9670571, theta=-11.525347 -> V=1.0, theta=0.0
% INFO    : Bus 87926	: V=0.9622736, theta=-12.428633 -> V=1.0, theta=0.0
% INFO    : Bus 87927	: V=0.9687127, theta=-11.506999 -> V=1.0, theta=0.0
% INFO    : Bus 87928	: V=0.9611449, theta=-11.63653 -> V=1.0, theta=0.0
% INFO    : Bus 87929	: V=0.9631368, theta=-37.874054 -> V=1.0, theta=0.0
% INFO    : Bus 87930	: V=0.9645083, theta=-40.551406 -> V=1.0, theta=0.0
% INFO    : Bus 87931	: V=0.9685484, theta=-12.957171 -> V=1.0, theta=0.0
% INFO    : Bus 87932	: V=0.9591238, theta=-36.438179 -> V=1.0, theta=0.0
% INFO    : Bus 87933	: V=0.9564447, theta=-35.890958 -> V=1.0, theta=0.0
% INFO    : Bus 87934	: V=0.9597479, theta=-36.508403 -> V=1.0, theta=0.0
% INFO    : Bus 87935	: V=0.9643979, theta=-37.007684 -> V=1.0, theta=0.0
% INFO    : Bus 87936	: V=0.9627021, theta=-36.741537 -> V=1.0, theta=0.0
% INFO    : Bus 87937	: V=0.9944503, theta=-30.737627 -> V=1.0, theta=0.0
% INFO    : Bus 87938	: V=1.0084626, theta=-31.04507 -> V=1.0, theta=0.0
% INFO    : Bus 87939	: V=1.0052719, theta=-31.11418 -> V=1.0, theta=0.0
% INFO    : Bus 87940	: V=0.9682374, theta=-40.9424 -> V=1.0, theta=0.0
% INFO    : Bus 87941	: V=0.9677916, theta=-43.845542 -> V=1.0, theta=0.0
% INFO    : Bus 87942	: V=0.9668412, theta=-44.222336 -> V=1.0, theta=0.0
% INFO    : Bus 87943	: V=0.9704667, theta=-44.12925 -> V=1.0, theta=0.0
% INFO    : Bus 87944	: V=0.9810668, theta=-23.361081 -> V=1.0, theta=0.0
% INFO    : Bus 87945	: V=0.9612122, theta=-21.297264 -> V=1.0, theta=0.0
% INFO    : Bus 87946	: V=0.9497139, theta=-26.361323 -> V=1.0, theta=0.0
% INFO    : Bus 87947	: V=1.0163103, theta=-8.543511 -> V=1.0, theta=0.0
% INFO    : Bus 87948	: V=1.010917, theta=-8.642417 -> V=1.0, theta=0.0
% INFO    : Bus 87949	: V=0.9840839, theta=-15.344521 -> V=1.0, theta=0.0
% INFO    : Bus 87950	: V=0.9793538, theta=-14.928743 -> V=1.0, theta=0.0
% INFO    : Bus 87951	: V=0.9883213, theta=-14.612761 -> V=1.0, theta=0.0
% INFO    : Bus 87952	: V=1.0115659, theta=-8.58208 -> V=1.0, theta=0.0
% INFO    : Bus 87953	: V=1.0149661, theta=-9.426808 -> V=1.0, theta=0.0
% INFO    : Bus 87954	: V=1.017417, theta=-7.827676 -> V=1.0, theta=0.0
% INFO    : Bus 87955	: V=1.0179094, theta=-8.172896 -> V=1.0, theta=0.0
% INFO    : Bus 87956	: V=1.0092664, theta=-8.572476 -> V=1.0, theta=0.0
% INFO    : Bus 87957	: V=1.0183283, theta=-8.331324 -> V=1.0, theta=0.0
% INFO    : Bus 87958	: V=1.0132035, theta=-8.724784 -> V=1.0, theta=0.0
% INFO    : Bus 87959	: V=1.0154058, theta=-8.363415 -> V=1.0, theta=0.0
% INFO    : Bus 87960	: V=1.0128234, theta=-8.571669 -> V=1.0, theta=0.0
% INFO    : Bus 87961	: V=1.0160682, theta=-8.361921 -> V=1.0, theta=0.0
% INFO    : Bus 87962	: V=1.0113873, theta=-8.462432 -> V=1.0, theta=0.0
% INFO    : Bus 87963	: V=0.9442248, theta=-9.012604 -> V=1.0, theta=0.0
% INFO    : Bus 87964	: V=1.0147465, theta=-9.899856 -> V=1.0, theta=0.0
% INFO    : Bus 87965	: V=0.9485125, theta=-37.135518 -> V=1.0, theta=0.0
% INFO    : Bus 87966	: V=1.0111692, theta=-7.531631 -> V=1.0, theta=0.0
% INFO    : Bus 87967	: V=0.9737268, theta=-19.326028 -> V=1.0, theta=0.0
% INFO    : Bus 87968	: V=0.9724811, theta=-19.368744 -> V=1.0, theta=0.0
% INFO    : Bus 87969	: V=0.9705156, theta=-19.389542 -> V=1.0, theta=0.0
% INFO    : Bus 87970	: V=0.9724916, theta=-19.58519 -> V=1.0, theta=0.0
% INFO    : Bus 87971	: V=0.978253, theta=-21.023315 -> V=1.0, theta=0.0
% INFO    : Bus 87972	: V=0.9772882, theta=-22.019138 -> V=1.0, theta=0.0
% INFO    : Bus 87973	: V=0.978068, theta=-31.771074 -> V=1.0, theta=0.0
% INFO    : Bus 87974	: V=0.973208, theta=-19.495149 -> V=1.0, theta=0.0
% INFO    : Bus 87975	: V=0.9986694, theta=-20.836594 -> V=1.0, theta=0.0
% INFO    : Bus 87976	: V=0.9965403, theta=-21.035521 -> V=1.0, theta=0.0
% INFO    : Bus 87977	: V=1.0157855, theta=-8.810051 -> V=1.0, theta=0.0
% INFO    : Bus 87978	: V=1.0112879, theta=-8.924103 -> V=1.0, theta=0.0
% INFO    : Bus 87979	: V=0.9985503, theta=-10.047568 -> V=1.0, theta=0.0
% INFO    : Bus 87980	: V=1.0086984, theta=-9.953392 -> V=1.0, theta=0.0
% INFO    : Bus 87981	: V=1.0054551, theta=-34.17453 -> V=1.0, theta=0.0
% INFO    : Bus 87982	: V=1.0030295, theta=-34.195601 -> V=1.0, theta=0.0
% INFO    : Bus 87983	: V=0.9718897, theta=-19.573326 -> V=1.0, theta=0.0
% INFO    : Bus 87984	: V=0.9955267, theta=-18.696994 -> V=1.0, theta=0.0
% INFO    : Bus 87985	: V=0.9895543, theta=-17.235231 -> V=1.0, theta=0.0
% INFO    : Bus 87986	: V=1.0078137, theta=-8.96743 -> V=1.0, theta=0.0
% INFO    : Bus 87987	: V=1.004573, theta=-9.159556 -> V=1.0, theta=0.0
% INFO    : Bus 87988	: V=1.0079961, theta=-9.349309 -> V=1.0, theta=0.0
% INFO    : Bus 87989	: V=1.0099099, theta=-9.012118 -> V=1.0, theta=0.0
% INFO    : Bus 87990	: V=0.9744238, theta=-18.245267 -> V=1.0, theta=0.0
% INFO    : Bus 87991	: V=0.9746581, theta=-23.285845 -> V=1.0, theta=0.0
% INFO    : Bus 87992	: V=0.9729548, theta=-25.218618 -> V=1.0, theta=0.0
% INFO    : Bus 87993	: V=0.9735514, theta=-24.436311 -> V=1.0, theta=0.0
% INFO    : Bus 87994	: V=0.9876241, theta=-31.309818 -> V=1.0, theta=0.0
% INFO    : Bus 87995	: V=0.9949994, theta=-32.654996 -> V=1.0, theta=0.0
% INFO    : Bus 87996	: V=0.9888269, theta=-18.701656 -> V=1.0, theta=0.0
% INFO    : Bus 87997	: V=0.9756809, theta=-19.434032 -> V=1.0, theta=0.0
% INFO    : Bus 87998	: V=0.975646, theta=-19.9261 -> V=1.0, theta=0.0
% INFO    : Bus 87999	: V=0.9700124, theta=-29.845033 -> V=1.0, theta=0.0
% INFO    : Bus 88000	: V=1.0110324, theta=-9.663509 -> V=1.0, theta=0.0
% INFO    : Bus 88001	: V=1.0161548, theta=-9.614979 -> V=1.0, theta=0.0
% INFO    : Bus 88002	: V=1.0172347, theta=-9.670827 -> V=1.0, theta=0.0
% INFO    : Bus 88003	: V=1.0100905, theta=-10.992162 -> V=1.0, theta=0.0
% INFO    : Bus 88004	: V=0.9992238, theta=-11.971154 -> V=1.0, theta=0.0
% INFO    : Bus 88005	: V=0.9626635, theta=-10.702598 -> V=1.0, theta=0.0
% INFO    : Bus 88006	: V=0.9634001, theta=-12.491261 -> V=1.0, theta=0.0
% INFO    : Bus 88007	: V=0.9622907, theta=-12.201075 -> V=1.0, theta=0.0
% INFO    : Bus 88008	: V=0.9602748, theta=-12.85841 -> V=1.0, theta=0.0
% INFO    : Bus 88009	: V=0.9761934, theta=-18.62177 -> V=1.0, theta=0.0
% INFO    : Bus 88010	: V=1.0152022, theta=-8.339259 -> V=1.0, theta=0.0
% INFO    : Bus 88011	: V=1.0123805, theta=-8.413203 -> V=1.0, theta=0.0
% INFO    : Bus 88012	: V=1.0116292, theta=-9.378335 -> V=1.0, theta=0.0
% INFO    : Bus 88013	: V=1.0066298, theta=-9.390471 -> V=1.0, theta=0.0
% INFO    : Bus 88014	: V=1.0074906, theta=-9.791811 -> V=1.0, theta=0.0
% INFO    : Bus 88015	: V=1.0171643, theta=-9.194367 -> V=1.0, theta=0.0
% INFO    : Bus 88016	: V=0.9869478, theta=-9.274381 -> V=1.0, theta=0.0
% INFO    : Bus 88017	: V=0.9908381, theta=-8.723524 -> V=1.0, theta=0.0
% INFO    : Bus 88018	: V=0.9858854, theta=-8.823619 -> V=1.0, theta=0.0
% INFO    : Bus 88019	: V=0.9836306, theta=-11.895976 -> V=1.0, theta=0.0
% INFO    : Bus 88020	: V=0.9662078, theta=-38.863459 -> V=1.0, theta=0.0
% INFO    : Bus 88021	: V=0.9666994, theta=-40.248909 -> V=1.0, theta=0.0
% INFO    : Bus 88022	: V=0.971173, theta=-41.265845 -> V=1.0, theta=0.0
% INFO    : Bus 88023	: V=0.972926, theta=-42.795042 -> V=1.0, theta=0.0
% INFO    : Bus 88024	: V=0.9849946, theta=-37.873774 -> V=1.0, theta=0.0
% INFO    : Bus 88025	: V=0.9799206, theta=-38.54951 -> V=1.0, theta=0.0
% INFO    : Bus 88026	: V=0.9670182, theta=-41.397731 -> V=1.0, theta=0.0
% INFO    : Bus 88027	: V=0.9880399, theta=-36.021352 -> V=1.0, theta=0.0
% INFO    : Bus 88028	: V=0.9368547, theta=-31.829352 -> V=1.0, theta=0.0
% INFO    : Bus 88029	: V=0.9381016, theta=-31.51911 -> V=1.0, theta=0.0
% INFO    : Bus 88030	: V=0.9392939, theta=-32.005131 -> V=1.0, theta=0.0
% INFO    : Bus 88031	: V=0.9478616, theta=-31.027719 -> V=1.0, theta=0.0
% INFO    : Bus 88032	: V=0.9650937, theta=-31.546774 -> V=1.0, theta=0.0
% INFO    : Bus 88033	: V=0.9396625, theta=-27.292617 -> V=1.0, theta=0.0
% INFO    : Bus 88034	: V=0.9736534, theta=-24.27035 -> V=1.0, theta=0.0
% INFO    : Bus 88035	: V=0.9662342, theta=-22.953017 -> V=1.0, theta=0.0
% INFO    : Bus 88036	: V=0.9680733, theta=-27.018117 -> V=1.0, theta=0.0
% INFO    : Bus 88037	: V=0.985144, theta=-24.382969 -> V=1.0, theta=0.0
% INFO    : Bus 88038	: V=0.9893468, theta=-24.653773 -> V=1.0, theta=0.0
% INFO    : Bus 88039	: V=0.9694807, theta=-27.181206 -> V=1.0, theta=0.0
% INFO    : Bus 88040	: V=0.9732938, theta=-15.435007 -> V=1.0, theta=0.0
% INFO    : Bus 88041	: V=0.9756768, theta=-15.67489 -> V=1.0, theta=0.0
% INFO    : Bus 88042	: V=0.9533403, theta=-15.3447 -> V=1.0, theta=0.0
% INFO    : Bus 88043	: V=0.9781487, theta=-10.967336 -> V=1.0, theta=0.0
% INFO    : Bus 88044	: V=0.9838782, theta=-10.676465 -> V=1.0, theta=0.0
% INFO    : Bus 88045	: V=0.9844041, theta=-10.560229 -> V=1.0, theta=0.0
% INFO    : Bus 88046	: V=0.9790187, theta=-9.805881 -> V=1.0, theta=0.0
% INFO    : Bus 88047	: V=0.9787289, theta=-18.568136 -> V=1.0, theta=0.0
% INFO    : Bus 88048	: V=0.9776089, theta=-17.891799 -> V=1.0, theta=0.0
% INFO    : Bus 88049	: V=0.9663563, theta=-10.6766 -> V=1.0, theta=0.0
% INFO    : Bus 88050	: V=0.9660319, theta=-10.487359 -> V=1.0, theta=0.0
% INFO    : Bus 88051	: V=0.9656753, theta=-21.501728 -> V=1.0, theta=0.0
% INFO    : Bus 88052	: V=0.969331, theta=-21.875623 -> V=1.0, theta=0.0
% INFO    : Bus 88053	: V=0.9686569, theta=-22.342094 -> V=1.0, theta=0.0
% INFO    : Bus 88054	: V=0.9742597, theta=-23.13658 -> V=1.0, theta=0.0
% INFO    : Bus 88055	: V=0.9993748, theta=-12.4983 -> V=1.0, theta=0.0
% INFO    : Bus 88056	: V=1.0030264, theta=-7.414031 -> V=1.0, theta=0.0
% INFO    : Bus 88057	: V=0.9959564, theta=-7.435332 -> V=1.0, theta=0.0
% INFO    : Bus 88058	: V=0.9851381, theta=-7.722825 -> V=1.0, theta=0.0
% INFO    : Bus 88059	: V=0.9696031, theta=-15.615331 -> V=1.0, theta=0.0
% INFO    : Bus 88060	: V=0.969326, theta=-15.606206 -> V=1.0, theta=0.0
% INFO    : Bus 88061	: V=0.9797418, theta=-15.761138 -> V=1.0, theta=0.0
% INFO    : Bus 88062	: V=0.9793381, theta=-16.080424 -> V=1.0, theta=0.0
% INFO    : Bus 88063	: V=0.9731001, theta=-14.333748 -> V=1.0, theta=0.0
% INFO    : Bus 88064	: V=0.9948154, theta=-14.989591 -> V=1.0, theta=0.0
% INFO    : Bus 88065	: V=0.9888984, theta=-15.061834 -> V=1.0, theta=0.0
% INFO    : Bus 88066	: V=0.9720156, theta=-17.467 -> V=1.0, theta=0.0
% INFO    : Bus 88067	: V=0.9530044, theta=-32.037379 -> V=1.0, theta=0.0
% INFO    : Bus 88068	: V=0.9515106, theta=-32.733932 -> V=1.0, theta=0.0
% INFO    : Bus 88069	: V=1.0060618, theta=-7.592089 -> V=1.0, theta=0.0
% INFO    : Bus 88070	: V=1.0082036, theta=-7.722639 -> V=1.0, theta=0.0
% INFO    : Bus 88071	: V=0.9624409, theta=-37.892214 -> V=1.0, theta=0.0
% INFO    : Bus 88072	: V=0.9583824, theta=-37.381504 -> V=1.0, theta=0.0
% INFO    : Bus 88073	: V=0.9568983, theta=-39.03397 -> V=1.0, theta=0.0
% INFO    : Bus 88074	: V=0.9682777, theta=-24.861964 -> V=1.0, theta=0.0
% INFO    : Bus 88075	: V=0.9903681, theta=-47.355404 -> V=1.0, theta=0.0
% INFO    : Bus 88076	: V=0.9661854, theta=-46.126097 -> V=1.0, theta=0.0
% INFO    : Bus 88077	: V=0.9963696, theta=-23.567144 -> V=1.0, theta=0.0
% INFO    : Bus 88078	: V=0.9899162, theta=-24.303053 -> V=1.0, theta=0.0
% INFO    : Bus 88079	: V=1.0069659, theta=-27.03304 -> V=1.0, theta=0.0
% INFO    : Bus 88080	: V=0.9985321, theta=-27.054469 -> V=1.0, theta=0.0
% INFO    : Bus 88081	: V=1.0143962, theta=-23.932189 -> V=1.0, theta=0.0
% INFO    : Bus 88082	: V=1.0187513, theta=-24.651424 -> V=1.0, theta=0.0
% INFO    : Bus 88083	: V=0.9792121, theta=-25.807966 -> V=1.0, theta=0.0
% INFO    : Bus 88084	: V=0.9868382, theta=-25.251668 -> V=1.0, theta=0.0
% INFO    : Bus 88085	: V=0.988802, theta=-26.730171 -> V=1.0, theta=0.0
% INFO    : Bus 88086	: V=0.992868, theta=-24.047316 -> V=1.0, theta=0.0
% INFO    : Bus 88087	: V=0.9943349, theta=-23.880432 -> V=1.0, theta=0.0
% INFO    : Bus 88088	: V=0.9830596, theta=-43.002128 -> V=1.0, theta=0.0
% INFO    : Bus 88089	: V=0.9828304, theta=-43.064012 -> V=1.0, theta=0.0
% INFO    : Bus 88090	: V=1.0020872, theta=-22.478968 -> V=1.0, theta=0.0
% INFO    : Bus 88091	: V=0.9597323, theta=-43.170514 -> V=1.0, theta=0.0
% INFO    : Bus 88092	: V=0.9596837, theta=-43.631855 -> V=1.0, theta=0.0
% INFO    : Bus 88093	: V=0.9846417, theta=-46.83974 -> V=1.0, theta=0.0
% INFO    : Bus 88094	: V=0.9949835, theta=-26.212698 -> V=1.0, theta=0.0
% INFO    : Bus 88095	: V=0.9950439, theta=-26.094087 -> V=1.0, theta=0.0
% INFO    : Bus 88096	: V=0.9957225, theta=-26.205686 -> V=1.0, theta=0.0
% INFO    : Bus 88097	: V=0.9949163, theta=-26.279559 -> V=1.0, theta=0.0
% INFO    : Bus 88098	: V=0.9930799, theta=-26.317736 -> V=1.0, theta=0.0
% INFO    : Bus 88099	: V=0.9912078, theta=-26.541338 -> V=1.0, theta=0.0
% INFO    : Bus 88100	: V=0.9705002, theta=-28.243314 -> V=1.0, theta=0.0
% INFO    : Bus 88101	: V=0.9766196, theta=-27.703954 -> V=1.0, theta=0.0
% INFO    : Bus 88102	: V=0.9905164, theta=-26.065029 -> V=1.0, theta=0.0
% INFO    : Bus 88103	: V=0.9615941, theta=-29.099841 -> V=1.0, theta=0.0
% INFO    : Bus 88104	: V=0.9677365, theta=-28.374446 -> V=1.0, theta=0.0
% INFO    : Bus 88105	: V=0.9544502, theta=-29.571699 -> V=1.0, theta=0.0
% INFO    : Bus 88106	: V=0.9940419, theta=-25.866092 -> V=1.0, theta=0.0
% INFO    : Bus 88107	: V=0.9947849, theta=-25.257147 -> V=1.0, theta=0.0
% INFO    : Bus 88108	: V=1.0079836, theta=-50.103521 -> V=1.0, theta=0.0
% INFO    : Bus 88109	: V=1.0094386, theta=-50.218036 -> V=1.0, theta=0.0
% INFO    : Bus 88110	: V=1.0075497, theta=-49.917796 -> V=1.0, theta=0.0
% INFO    : Bus 88111	: V=1.0075977, theta=-49.75414 -> V=1.0, theta=0.0
% INFO    : Bus 88112	: V=1.0094135, theta=-49.151146 -> V=1.0, theta=0.0
% INFO    : Bus 88113	: V=1.0046433, theta=-50.378478 -> V=1.0, theta=0.0
% INFO    : Bus 88114	: V=0.9933024, theta=-52.019408 -> V=1.0, theta=0.0
% INFO    : Bus 88115	: V=0.9510896, theta=-46.470862 -> V=1.0, theta=0.0
% INFO    : Bus 88116	: V=0.9905102, theta=-50.899943 -> V=1.0, theta=0.0
% INFO    : Bus 88117	: V=0.9827273, theta=-53.395924 -> V=1.0, theta=0.0
% INFO    : Bus 88118	: V=0.9766704, theta=-27.483781 -> V=1.0, theta=0.0
% INFO    : Bus 88119	: V=0.9603058, theta=-59.367774 -> V=1.0, theta=0.0
% INFO    : Bus 88120	: V=1.0009624, theta=-52.65406 -> V=1.0, theta=0.0
% INFO    : Bus 88121	: V=1.0012356, theta=-53.352338 -> V=1.0, theta=0.0
% INFO    : Bus 88122	: V=0.998185, theta=-53.575325 -> V=1.0, theta=0.0
% INFO    : Bus 88123	: V=1.0071476, theta=-53.338694 -> V=1.0, theta=0.0
% INFO    : Bus 88124	: V=1.0056706, theta=-53.274001 -> V=1.0, theta=0.0
% INFO    : Bus 88125	: V=0.991899, theta=-54.857243 -> V=1.0, theta=0.0
% INFO    : Bus 88126	: V=0.9857522, theta=-55.794046 -> V=1.0, theta=0.0
% INFO    : Bus 88127	: V=0.9726105, theta=-57.091573 -> V=1.0, theta=0.0
% INFO    : Bus 88128	: V=0.992842, theta=-54.586863 -> V=1.0, theta=0.0
% INFO    : Bus 88129	: V=1.0001934, theta=-53.600827 -> V=1.0, theta=0.0
% INFO    : Bus 88130	: V=1.0067384, theta=-53.739016 -> V=1.0, theta=0.0
% INFO    : Bus 88131	: V=0.9866019, theta=-54.907357 -> V=1.0, theta=0.0
% INFO    : Bus 88132	: V=0.9801853, theta=-55.123731 -> V=1.0, theta=0.0
% INFO    : Bus 88133	: V=0.9937502, theta=-39.031669 -> V=1.0, theta=0.0
% INFO    : Bus 88134	: V=0.9971588, theta=-38.062854 -> V=1.0, theta=0.0
% INFO    : Bus 88135	: V=1.0057464, theta=-38.147222 -> V=1.0, theta=0.0
% INFO    : Bus 88136	: V=0.9925671, theta=-39.138284 -> V=1.0, theta=0.0
% INFO    : Bus 88137	: V=0.9892154, theta=-39.215658 -> V=1.0, theta=0.0
% INFO    : Bus 88138	: V=0.9980598, theta=-38.720315 -> V=1.0, theta=0.0
% INFO    : Bus 88139	: V=1.006594, theta=-37.957981 -> V=1.0, theta=0.0
% INFO    : Bus 88140	: V=0.991267, theta=-39.104294 -> V=1.0, theta=0.0
% INFO    : Bus 88141	: V=0.9873829, theta=-39.189255 -> V=1.0, theta=0.0
% INFO    : Bus 88142	: V=0.988262, theta=-39.086051 -> V=1.0, theta=0.0
% INFO    : Bus 88143	: V=0.9827402, theta=-39.11441 -> V=1.0, theta=0.0
% INFO    : Bus 88144	: V=0.9972189, theta=-38.913925 -> V=1.0, theta=0.0
% INFO    : Bus 88145	: V=1.0045952, theta=-38.177112 -> V=1.0, theta=0.0
% INFO    : Bus 88146	: V=1.0046741, theta=-37.257912 -> V=1.0, theta=0.0
% INFO    : Bus 88147	: V=0.9955713, theta=-33.158877 -> V=1.0, theta=0.0
% INFO    : Bus 88148	: V=0.9890618, theta=-38.64173 -> V=1.0, theta=0.0
% INFO    : Bus 88149	: V=0.9954601, theta=-38.088588 -> V=1.0, theta=0.0
% INFO    : Bus 88150	: V=0.9872262, theta=-39.041343 -> V=1.0, theta=0.0
% INFO    : Bus 88151	: V=0.9828942, theta=-39.081071 -> V=1.0, theta=0.0
% INFO    : Bus 88152	: V=0.9800345, theta=-39.387818 -> V=1.0, theta=0.0
% INFO    : Bus 88153	: V=0.9855874, theta=-38.764077 -> V=1.0, theta=0.0
% INFO    : Bus 88154	: V=0.9852122, theta=-39.000954 -> V=1.0, theta=0.0
% INFO    : Bus 88155	: V=0.9759364, theta=-40.108427 -> V=1.0, theta=0.0
% INFO    : Bus 88156	: V=0.9964017, theta=-27.535304 -> V=1.0, theta=0.0
% INFO    : Bus 88157	: V=0.9874275, theta=-27.754297 -> V=1.0, theta=0.0
% INFO    : Bus 88158	: V=0.9947394, theta=-27.421743 -> V=1.0, theta=0.0
% INFO    : Bus 88159	: V=1.0127655, theta=-27.317423 -> V=1.0, theta=0.0
% INFO    : Bus 88160	: V=0.9816155, theta=-24.82604 -> V=1.0, theta=0.0
% INFO    : Bus 88161	: V=1.0057445, theta=-51.306848 -> V=1.0, theta=0.0
% INFO    : Bus 88162	: V=1.0031736, theta=-51.536138 -> V=1.0, theta=0.0
% INFO    : Bus 88163	: V=1.0028078, theta=-51.728937 -> V=1.0, theta=0.0
% INFO    : Bus 88164	: V=1.0049339, theta=-51.501454 -> V=1.0, theta=0.0
% INFO    : Bus 88165	: V=0.9884554, theta=-53.312437 -> V=1.0, theta=0.0
% INFO    : Bus 88166	: V=0.9885086, theta=-43.805178 -> V=1.0, theta=0.0
% INFO    : Bus 88167	: V=0.9927239, theta=-45.488602 -> V=1.0, theta=0.0
% INFO    : Bus 88168	: V=1.0080148, theta=-46.264754 -> V=1.0, theta=0.0
% INFO    : Bus 88169	: V=0.9900055, theta=-46.294997 -> V=1.0, theta=0.0
% INFO    : Bus 88170	: V=0.9781494, theta=-47.817425 -> V=1.0, theta=0.0
% INFO    : Bus 88171	: V=1.0033194, theta=-25.066767 -> V=1.0, theta=0.0
% INFO    : Bus 88172	: V=0.9895293, theta=-25.303322 -> V=1.0, theta=0.0
% INFO    : Bus 88173	: V=0.9870476, theta=-25.471831 -> V=1.0, theta=0.0
% INFO    : Bus 88174	: V=1.0058963, theta=-49.568724 -> V=1.0, theta=0.0
% INFO    : Bus 88175	: V=0.9991641, theta=-51.429896 -> V=1.0, theta=0.0
% INFO    : Bus 88176	: V=0.992234, theta=-50.733081 -> V=1.0, theta=0.0
% INFO    : Bus 88177	: V=0.9737545, theta=-39.58499 -> V=1.0, theta=0.0
% INFO    : Bus 88178	: V=0.9738825, theta=-34.902449 -> V=1.0, theta=0.0
% INFO    : Bus 88179	: V=0.9780155, theta=-38.731371 -> V=1.0, theta=0.0
% INFO    : Bus 88180	: V=0.971447, theta=-39.398455 -> V=1.0, theta=0.0
% INFO    : Bus 88181	: V=0.9736186, theta=-40.0053 -> V=1.0, theta=0.0
% INFO    : Bus 88182	: V=0.9852111, theta=-46.276365 -> V=1.0, theta=0.0
% INFO    : Bus 88183	: V=0.9843188, theta=-24.96179 -> V=1.0, theta=0.0
% INFO    : Bus 88184	: V=0.98863, theta=-24.32062 -> V=1.0, theta=0.0
% INFO    : Bus 88185	: V=0.9889692, theta=-24.388121 -> V=1.0, theta=0.0
% INFO    : Bus 88186	: V=0.9906095, theta=-24.170149 -> V=1.0, theta=0.0
% INFO    : Bus 88187	: V=0.9959236, theta=-23.718922 -> V=1.0, theta=0.0
% INFO    : Bus 88188	: V=0.9960684, theta=-23.795931 -> V=1.0, theta=0.0
% INFO    : Bus 88189	: V=0.9841665, theta=-27.675338 -> V=1.0, theta=0.0
% INFO    : Bus 88190	: V=0.9828572, theta=-28.198832 -> V=1.0, theta=0.0
% INFO    : Bus 88191	: V=0.9836616, theta=-28.202372 -> V=1.0, theta=0.0
% INFO    : Bus 88192	: V=1.0069898, theta=-21.860335 -> V=1.0, theta=0.0
% INFO    : Bus 88193	: V=1.0022958, theta=-22.199162 -> V=1.0, theta=0.0
% INFO    : Bus 88194	: V=0.9927957, theta=-24.608081 -> V=1.0, theta=0.0
% INFO    : Bus 88195	: V=1.0079261, theta=-22.596861 -> V=1.0, theta=0.0
% INFO    : Bus 88196	: V=1.0085248, theta=-22.66599 -> V=1.0, theta=0.0
% INFO    : Bus 88197	: V=1.014064, theta=-22.136829 -> V=1.0, theta=0.0
% INFO    : Bus 88198	: V=1.0103819, theta=-22.223626 -> V=1.0, theta=0.0
% INFO    : Bus 88199	: V=1.0122895, theta=-21.967497 -> V=1.0, theta=0.0
% INFO    : Bus 88200	: V=1.0129286, theta=-22.192692 -> V=1.0, theta=0.0
% INFO    : Bus 88201	: V=1.0001927, theta=-37.798992 -> V=1.0, theta=0.0
% INFO    : Bus 88202	: V=1.0039681, theta=-35.489679 -> V=1.0, theta=0.0
% INFO    : Bus 88203	: V=0.9995069, theta=-29.6848 -> V=1.0, theta=0.0
% INFO    : Bus 88204	: V=1.0015309, theta=-47.640854 -> V=1.0, theta=0.0
% INFO    : Bus 88205	: V=0.9853402, theta=-49.103403 -> V=1.0, theta=0.0
% INFO    : Bus 88206	: V=0.9769776, theta=-26.804475 -> V=1.0, theta=0.0
% INFO    : Bus 88207	: V=0.9841277, theta=-25.962933 -> V=1.0, theta=0.0
% INFO    : Bus 88208	: V=0.9746292, theta=-24.975629 -> V=1.0, theta=0.0
% INFO    : Bus 88209	: V=0.9757714, theta=-24.765468 -> V=1.0, theta=0.0
% INFO    : Bus 88210	: V=0.9966001, theta=-25.987394 -> V=1.0, theta=0.0
% INFO    : Bus 88211	: V=0.9795649, theta=-29.40413 -> V=1.0, theta=0.0
% INFO    : Bus 88212	: V=0.9654797, theta=-40.945295 -> V=1.0, theta=0.0
% INFO    : Bus 88213	: V=0.9954838, theta=-25.256207 -> V=1.0, theta=0.0
% INFO    : Bus 88214	: V=1.0142569, theta=-21.444916 -> V=1.0, theta=0.0
% INFO    : Bus 88215	: V=1.016857, theta=-21.054448 -> V=1.0, theta=0.0
% INFO    : Bus 88216	: V=1.0173631, theta=-20.908748 -> V=1.0, theta=0.0
% INFO    : Bus 88217	: V=1.0173833, theta=-20.923787 -> V=1.0, theta=0.0
% INFO    : Bus 88218	: V=1.0162144, theta=-21.243686 -> V=1.0, theta=0.0
% INFO    : Bus 88219	: V=1.0129787, theta=-21.610733 -> V=1.0, theta=0.0
% INFO    : Bus 88220	: V=0.9902051, theta=-24.922726 -> V=1.0, theta=0.0
% INFO    : Bus 88221	: V=1.0009311, theta=-24.41722 -> V=1.0, theta=0.0
% INFO    : Bus 88222	: V=0.9923735, theta=-23.909055 -> V=1.0, theta=0.0
% INFO    : Bus 88223	: V=1.017672, theta=-23.150774 -> V=1.0, theta=0.0
% INFO    : Bus 88224	: V=1.0172356, theta=-23.209919 -> V=1.0, theta=0.0
% INFO    : Bus 88225	: V=0.9725829, theta=-55.268569 -> V=1.0, theta=0.0
% INFO    : Bus 88226	: V=0.9487418, theta=-61.138398 -> V=1.0, theta=0.0
% INFO    : Bus 88227	: V=0.939005, theta=-49.287962 -> V=1.0, theta=0.0
% INFO    : Bus 88228	: V=0.9466384, theta=-49.519324 -> V=1.0, theta=0.0
% INFO    : Bus 88229	: V=0.990863, theta=-24.664495 -> V=1.0, theta=0.0
% INFO    : Bus 88230	: V=0.9795282, theta=-25.519962 -> V=1.0, theta=0.0
% INFO    : Bus 88231	: V=1.0069718, theta=-22.651627 -> V=1.0, theta=0.0
% INFO    : Bus 88232	: V=1.0123487, theta=-23.358016 -> V=1.0, theta=0.0
% INFO    : Bus 88233	: V=0.9609268, theta=-41.135911 -> V=1.0, theta=0.0
% INFO    : Bus 88234	: V=0.9814456, theta=-39.928584 -> V=1.0, theta=0.0
% INFO    : Bus 88235	: V=0.9715629, theta=-41.106669 -> V=1.0, theta=0.0
% INFO    : Bus 88236	: V=0.9753406, theta=-40.29493 -> V=1.0, theta=0.0
% INFO    : Bus 88237	: V=0.9678746, theta=-41.300709 -> V=1.0, theta=0.0
% INFO    : Bus 88238	: V=0.961499, theta=-42.564454 -> V=1.0, theta=0.0
% INFO    : Bus 88239	: V=1.0068227, theta=-27.154731 -> V=1.0, theta=0.0
% INFO    : Bus 88240	: V=0.9953345, theta=-45.109897 -> V=1.0, theta=0.0
% INFO    : Bus 88241	: V=0.9865884, theta=-46.000241 -> V=1.0, theta=0.0
% INFO    : Bus 88242	: V=0.9811386, theta=-53.824251 -> V=1.0, theta=0.0
% INFO    : Bus 88243	: V=1.0253367, theta=-24.407504 -> V=1.0, theta=0.0
% INFO    : Bus 88244	: V=1.0031047, theta=-26.034598 -> V=1.0, theta=0.0
% INFO    : Bus 88245	: V=0.9985713, theta=-26.904613 -> V=1.0, theta=0.0
% INFO    : Bus 88246	: V=0.9933232, theta=-25.61409 -> V=1.0, theta=0.0
% INFO    : Bus 88247	: V=1.0074892, theta=-21.731571 -> V=1.0, theta=0.0
% INFO    : Bus 88248	: V=0.9815999, theta=-25.555239 -> V=1.0, theta=0.0
% INFO    : Bus 88249	: V=1.0154125, theta=-22.303853 -> V=1.0, theta=0.0
% INFO    : Bus 88250	: V=0.9971211, theta=-24.421891 -> V=1.0, theta=0.0
% INFO    : Bus 88251	: V=1.0048565, theta=-23.575106 -> V=1.0, theta=0.0
% INFO    : Bus 88252	: V=1.016495, theta=-28.057888 -> V=1.0, theta=0.0
% INFO    : Bus 88253	: V=0.9806185, theta=-36.569059 -> V=1.0, theta=0.0
% INFO    : Bus 88254	: V=0.9859373, theta=-36.374342 -> V=1.0, theta=0.0
% INFO    : Bus 88255	: V=0.9965369, theta=-35.061295 -> V=1.0, theta=0.0
% INFO    : Bus 88256	: V=1.0044824, theta=-26.596273 -> V=1.0, theta=0.0
% INFO    : Bus 88257	: V=1.017486, theta=-24.091478 -> V=1.0, theta=0.0
% INFO    : Bus 88258	: V=1.0127096, theta=-24.765616 -> V=1.0, theta=0.0
% INFO    : Bus 88259	: V=0.9940373, theta=-25.743349 -> V=1.0, theta=0.0
% INFO    : Bus 88260	: V=1.0130584, theta=-24.700905 -> V=1.0, theta=0.0
% INFO    : Bus 88261	: V=1.012902, theta=-24.571911 -> V=1.0, theta=0.0
% INFO    : Bus 88262	: V=1.0015213, theta=-25.892596 -> V=1.0, theta=0.0
% INFO    : Bus 88263	: V=1.0142947, theta=-25.482558 -> V=1.0, theta=0.0
% INFO    : Bus 88264	: V=1.0049656, theta=-25.877791 -> V=1.0, theta=0.0
% INFO    : Bus 88265	: V=0.9995168, theta=-23.909193 -> V=1.0, theta=0.0
% INFO    : Bus 88266	: V=0.9990045, theta=-24.873906 -> V=1.0, theta=0.0
% INFO    : Bus 88267	: V=0.9875161, theta=-29.540229 -> V=1.0, theta=0.0
% INFO    : Bus 88268	: V=0.9909751, theta=-30.497971 -> V=1.0, theta=0.0
% INFO    : Bus 88269	: V=0.9695173, theta=-40.19075 -> V=1.0, theta=0.0
% INFO    : Bus 88270	: V=0.9853324, theta=-38.168526 -> V=1.0, theta=0.0
% INFO    : Bus 88271	: V=0.9801252, theta=-38.127878 -> V=1.0, theta=0.0
% INFO    : Bus 88272	: V=0.9704005, theta=-41.018103 -> V=1.0, theta=0.0
% INFO    : Bus 88273	: V=0.9998054, theta=-35.994472 -> V=1.0, theta=0.0
% INFO    : Bus 88274	: V=0.9944078, theta=-37.02688 -> V=1.0, theta=0.0
% INFO    : Bus 88275	: V=0.9933931, theta=-37.361452 -> V=1.0, theta=0.0
% INFO    : Bus 88276	: V=0.9525331, theta=-36.857846 -> V=1.0, theta=0.0
% INFO    : Bus 88277	: V=0.9580962, theta=-38.489141 -> V=1.0, theta=0.0
% INFO    : Bus 88278	: V=0.9572436, theta=-36.472067 -> V=1.0, theta=0.0
% INFO    : Bus 88279	: V=1.016831, theta=-13.934297 -> V=1.0, theta=0.0
% INFO    : Bus 88280	: V=0.9671239, theta=-42.582704 -> V=1.0, theta=0.0
% INFO    : Bus 88281	: V=0.9605519, theta=-42.992545 -> V=1.0, theta=0.0
% INFO    : Bus 88282	: V=0.962426, theta=-42.959436 -> V=1.0, theta=0.0
% INFO    : Bus 88283	: V=0.968011, theta=-42.504937 -> V=1.0, theta=0.0
% INFO    : Bus 88284	: V=0.9784624, theta=-40.64977 -> V=1.0, theta=0.0
% INFO    : Bus 88285	: V=0.9806961, theta=-40.271848 -> V=1.0, theta=0.0
% INFO    : Bus 88286	: V=0.9485243, theta=-35.570562 -> V=1.0, theta=0.0
% INFO    : Bus 88287	: V=0.9547891, theta=-34.912754 -> V=1.0, theta=0.0
% INFO    : Bus 88288	: V=0.9604729, theta=-33.590396 -> V=1.0, theta=0.0
% INFO    : Bus 88289	: V=0.9498049, theta=-39.237434 -> V=1.0, theta=0.0
% INFO    : Bus 88290	: V=0.9619941, theta=-39.825105 -> V=1.0, theta=0.0
% INFO    : Bus 88291	: V=0.9613436, theta=-40.690158 -> V=1.0, theta=0.0
% INFO    : Bus 88292	: V=0.9683886, theta=-38.810527 -> V=1.0, theta=0.0
% INFO    : Bus 88293	: V=0.9720993, theta=-20.856217 -> V=1.0, theta=0.0
% INFO    : Bus 88294	: V=0.9822419, theta=-20.225808 -> V=1.0, theta=0.0
% INFO    : Bus 88295	: V=0.9812726, theta=-20.543125 -> V=1.0, theta=0.0
% INFO    : Bus 88296	: V=0.9419514, theta=-60.231976 -> V=1.0, theta=0.0
% INFO    : Bus 88297	: V=0.9250357, theta=-58.995806 -> V=1.0, theta=0.0
% INFO    : Bus 88298	: V=0.9429125, theta=-59.386127 -> V=1.0, theta=0.0
% INFO    : Bus 88299	: V=0.9621778, theta=-27.770594 -> V=1.0, theta=0.0
% INFO    : Bus 88300	: V=0.969561, theta=-24.614844 -> V=1.0, theta=0.0
% INFO    : Bus 88301	: V=0.9552752, theta=-45.146104 -> V=1.0, theta=0.0
% INFO    : Bus 88302	: V=0.9541954, theta=-46.656229 -> V=1.0, theta=0.0
% INFO    : Bus 88303	: V=0.9514374, theta=-48.141496 -> V=1.0, theta=0.0
% INFO    : Bus 88304	: V=0.9594127, theta=-47.970382 -> V=1.0, theta=0.0
% INFO    : Bus 88305	: V=0.9600037, theta=-47.479745 -> V=1.0, theta=0.0
% INFO    : Bus 88306	: V=0.9709705, theta=-35.837198 -> V=1.0, theta=0.0
% INFO    : Bus 88307	: V=0.9807826, theta=-33.599358 -> V=1.0, theta=0.0
% INFO    : Bus 88308	: V=0.9807471, theta=-33.168044 -> V=1.0, theta=0.0
% INFO    : Bus 88309	: V=0.966276, theta=-32.611674 -> V=1.0, theta=0.0
% INFO    : Bus 88310	: V=0.9665356, theta=-32.367296 -> V=1.0, theta=0.0
% INFO    : Bus 88311	: V=0.9947194, theta=-28.97316 -> V=1.0, theta=0.0
% INFO    : Bus 88312	: V=0.9903748, theta=-29.510314 -> V=1.0, theta=0.0
% INFO    : Bus 88313	: V=0.9648775, theta=-24.095573 -> V=1.0, theta=0.0
% INFO    : Bus 88314	: V=0.9575019, theta=-40.91482 -> V=1.0, theta=0.0
% INFO    : Bus 88315	: V=0.9471777, theta=-41.116369 -> V=1.0, theta=0.0
% INFO    : Bus 88316	: V=0.9842964, theta=-34.247401 -> V=1.0, theta=0.0
% INFO    : Bus 88317	: V=0.9916341, theta=-32.819575 -> V=1.0, theta=0.0
% INFO    : Bus 88318	: V=0.99403, theta=-32.679138 -> V=1.0, theta=0.0
% INFO    : Bus 88319	: V=0.9892998, theta=-33.635678 -> V=1.0, theta=0.0
% INFO    : Bus 88320	: V=0.9858078, theta=-34.284635 -> V=1.0, theta=0.0
% INFO    : Bus 88321	: V=0.9859876, theta=-34.042438 -> V=1.0, theta=0.0
% INFO    : Bus 88322	: V=0.9851911, theta=-32.815197 -> V=1.0, theta=0.0
% INFO    : Bus 88323	: V=0.9827843, theta=-31.804333 -> V=1.0, theta=0.0
% INFO    : Bus 88324	: V=0.9891438, theta=-32.074832 -> V=1.0, theta=0.0
% INFO    : Bus 88325	: V=0.9885417, theta=-31.581297 -> V=1.0, theta=0.0
% INFO    : Bus 88326	: V=0.9850633, theta=-31.672027 -> V=1.0, theta=0.0
% INFO    : Bus 88327	: V=0.984148, theta=-30.376313 -> V=1.0, theta=0.0
% INFO    : Bus 88328	: V=0.9884709, theta=-28.349838 -> V=1.0, theta=0.0
% INFO    : Bus 88329	: V=0.9863568, theta=-29.737466 -> V=1.0, theta=0.0
% INFO    : Bus 88330	: V=0.9864944, theta=-27.937349 -> V=1.0, theta=0.0
% INFO    : Bus 88331	: V=0.9815425, theta=-29.587364 -> V=1.0, theta=0.0
% INFO    : Bus 88332	: V=0.9816632, theta=-29.642011 -> V=1.0, theta=0.0
% INFO    : Bus 88333	: V=0.9783263, theta=-30.468346 -> V=1.0, theta=0.0
% INFO    : Bus 88334	: V=0.9821212, theta=-30.245291 -> V=1.0, theta=0.0
% INFO    : Bus 88335	: V=0.9780154, theta=-32.774659 -> V=1.0, theta=0.0
% INFO    : Bus 88336	: V=0.983802, theta=-30.10862 -> V=1.0, theta=0.0
% INFO    : Bus 88337	: V=0.9827228, theta=-29.985421 -> V=1.0, theta=0.0
% INFO    : Bus 88338	: V=0.9841336, theta=-31.347481 -> V=1.0, theta=0.0
% INFO    : Bus 88339	: V=0.9841404, theta=-30.102659 -> V=1.0, theta=0.0
% INFO    : Bus 88340	: V=0.9859624, theta=-29.663828 -> V=1.0, theta=0.0
% INFO    : Bus 88341	: V=0.9893804, theta=-32.183437 -> V=1.0, theta=0.0
% INFO    : Bus 88342	: V=0.9878678, theta=-32.388969 -> V=1.0, theta=0.0
% INFO    : Bus 88343	: V=0.9864623, theta=-33.443685 -> V=1.0, theta=0.0
% INFO    : Bus 88344	: V=0.9877961, theta=-33.459508 -> V=1.0, theta=0.0
% INFO    : Bus 88345	: V=0.9873238, theta=-32.538286 -> V=1.0, theta=0.0
% INFO    : Bus 88346	: V=0.9762348, theta=-35.424506 -> V=1.0, theta=0.0
% INFO    : Bus 88347	: V=0.9846729, theta=-30.906721 -> V=1.0, theta=0.0
% INFO    : Bus 88348	: V=0.9777947, theta=-33.349353 -> V=1.0, theta=0.0
% INFO    : Bus 88349	: V=0.9777685, theta=-33.465251 -> V=1.0, theta=0.0
% INFO    : Bus 88350	: V=0.9734964, theta=-35.840368 -> V=1.0, theta=0.0
% INFO    : Bus 88351	: V=0.9709101, theta=-36.618596 -> V=1.0, theta=0.0
% INFO    : Bus 88352	: V=0.9708021, theta=-36.337571 -> V=1.0, theta=0.0
% INFO    : Bus 88353	: V=0.9660245, theta=-37.341914 -> V=1.0, theta=0.0
% INFO    : Bus 88354	: V=0.9882672, theta=-31.788502 -> V=1.0, theta=0.0
% INFO    : Bus 88355	: V=0.9828799, theta=-31.619061 -> V=1.0, theta=0.0
% INFO    : Bus 88356	: V=0.980742, theta=-32.084701 -> V=1.0, theta=0.0
% INFO    : Bus 88357	: V=0.9784197, theta=-35.046056 -> V=1.0, theta=0.0
% INFO    : Bus 88358	: V=0.9823649, theta=-31.32298 -> V=1.0, theta=0.0
% INFO    : Bus 88359	: V=0.9800209, theta=-30.653459 -> V=1.0, theta=0.0
% INFO    : Bus 88360	: V=0.9840537, theta=-30.992163 -> V=1.0, theta=0.0
% INFO    : Bus 88361	: V=0.9851696, theta=-31.436027 -> V=1.0, theta=0.0
% INFO    : Bus 88362	: V=0.9804645, theta=-33.057067 -> V=1.0, theta=0.0
% INFO    : Bus 88363	: V=0.9800445, theta=-33.106428 -> V=1.0, theta=0.0
% INFO    : Bus 88364	: V=0.9808019, theta=-34.711925 -> V=1.0, theta=0.0
% INFO    : Bus 88365	: V=0.9803387, theta=-32.663855 -> V=1.0, theta=0.0
% INFO    : Bus 88366	: V=0.9779657, theta=-34.590852 -> V=1.0, theta=0.0
% INFO    : Bus 88367	: V=0.9798062, theta=-33.104477 -> V=1.0, theta=0.0
% INFO    : Bus 88368	: V=0.9767781, theta=-32.100928 -> V=1.0, theta=0.0
% INFO    : Bus 88369	: V=0.9687009, theta=-32.373388 -> V=1.0, theta=0.0
% INFO    : Bus 88370	: V=0.9743182, theta=-31.890922 -> V=1.0, theta=0.0
% INFO    : Bus 88371	: V=0.9745377, theta=-31.795034 -> V=1.0, theta=0.0
% INFO    : Bus 88372	: V=0.976235, theta=-32.806898 -> V=1.0, theta=0.0
% INFO    : Bus 88373	: V=0.9698923, theta=-35.686686 -> V=1.0, theta=0.0
% INFO    : Bus 88374	: V=0.9761613, theta=-34.954263 -> V=1.0, theta=0.0
% INFO    : Bus 88375	: V=0.975794, theta=-35.1702 -> V=1.0, theta=0.0
% INFO    : Bus 88376	: V=0.972757, theta=-36.232304 -> V=1.0, theta=0.0
% INFO    : Bus 88377	: V=0.9777023, theta=-34.856377 -> V=1.0, theta=0.0
% INFO    : Bus 88378	: V=0.973459, theta=-35.006374 -> V=1.0, theta=0.0
% INFO    : Bus 88379	: V=0.9617553, theta=-37.133447 -> V=1.0, theta=0.0
% INFO    : Bus 88380	: V=0.9680464, theta=-35.814893 -> V=1.0, theta=0.0
% INFO    : Bus 88381	: V=0.9853637, theta=-30.569112 -> V=1.0, theta=0.0
% INFO    : Bus 88382	: V=0.9899495, theta=-31.322485 -> V=1.0, theta=0.0
% INFO    : Bus 88383	: V=0.9858333, theta=-29.738124 -> V=1.0, theta=0.0
% INFO    : Bus 88384	: V=1.0028386, theta=-29.250121 -> V=1.0, theta=0.0
% INFO    : Bus 88385	: V=0.9898627, theta=-29.903819 -> V=1.0, theta=0.0
% INFO    : Bus 88386	: V=0.9822916, theta=-31.351192 -> V=1.0, theta=0.0
% INFO    : Bus 88387	: V=0.9834645, theta=-31.796019 -> V=1.0, theta=0.0
% INFO    : Bus 88388	: V=0.9677693, theta=-43.58745 -> V=1.0, theta=0.0
% INFO    : Bus 88389	: V=0.957871, theta=-27.388161 -> V=1.0, theta=0.0
% INFO    : Bus 88390	: V=0.9618913, theta=-24.950107 -> V=1.0, theta=0.0
% INFO    : Bus 88391	: V=0.9823773, theta=-22.256835 -> V=1.0, theta=0.0
% INFO    : Bus 88392	: V=0.9817708, theta=-22.334372 -> V=1.0, theta=0.0
% INFO    : Bus 88393	: V=0.9809357, theta=-21.542645 -> V=1.0, theta=0.0
% INFO    : Bus 88394	: V=0.9860321, theta=-19.919951 -> V=1.0, theta=0.0
% INFO    : Bus 88395	: V=0.990099, theta=-19.249858 -> V=1.0, theta=0.0
% INFO    : Bus 88396	: V=1.0082465, theta=-16.642318 -> V=1.0, theta=0.0
% INFO    : Bus 88397	: V=1.0069471, theta=-17.004087 -> V=1.0, theta=0.0
% INFO    : Bus 88398	: V=1.0156399, theta=-16.067932 -> V=1.0, theta=0.0
% INFO    : Bus 88399	: V=1.0128472, theta=-16.402042 -> V=1.0, theta=0.0
% INFO    : Bus 88400	: V=0.9988803, theta=-17.080609 -> V=1.0, theta=0.0
% INFO    : Bus 88401	: V=0.969752, theta=-26.891852 -> V=1.0, theta=0.0
% INFO    : Bus 88402	: V=0.9767771, theta=-27.500698 -> V=1.0, theta=0.0
% INFO    : Bus 88403	: V=0.9544079, theta=-37.104396 -> V=1.0, theta=0.0
% INFO    : Bus 88404	: V=0.9684532, theta=-31.943738 -> V=1.0, theta=0.0
% INFO    : Bus 88405	: V=0.9851247, theta=-28.29847 -> V=1.0, theta=0.0
% INFO    : Bus 88406	: V=0.9806826, theta=-20.233592 -> V=1.0, theta=0.0
% INFO    : Bus 88407	: V=0.9594473, theta=-23.636967 -> V=1.0, theta=0.0
% INFO    : Bus 88408	: V=0.9750993, theta=-22.064131 -> V=1.0, theta=0.0
% INFO    : Bus 88409	: V=0.9620446, theta=-27.301861 -> V=1.0, theta=0.0
% INFO    : Bus 88410	: V=0.9711222, theta=-25.659789 -> V=1.0, theta=0.0
% INFO    : Bus 88411	: V=0.9625982, theta=-49.700043 -> V=1.0, theta=0.0
% INFO    : Bus 88412	: V=0.9752712, theta=-49.319884 -> V=1.0, theta=0.0
% INFO    : Bus 88413	: V=0.9749291, theta=-49.184079 -> V=1.0, theta=0.0
% INFO    : Bus 88414	: V=0.956601, theta=-51.470634 -> V=1.0, theta=0.0
% INFO    : Bus 88415	: V=0.959984, theta=-50.410725 -> V=1.0, theta=0.0
% INFO    : Bus 88416	: V=0.9558502, theta=-51.849056 -> V=1.0, theta=0.0
% INFO    : Bus 88417	: V=0.9689062, theta=-49.578284 -> V=1.0, theta=0.0
% INFO    : Bus 88418	: V=0.9769999, theta=-49.914312 -> V=1.0, theta=0.0
% INFO    : Bus 88419	: V=0.9486808, theta=-52.094612 -> V=1.0, theta=0.0
% INFO    : Bus 88420	: V=0.9454589, theta=-52.616411 -> V=1.0, theta=0.0
% INFO    : Bus 88421	: V=0.9514647, theta=-50.465335 -> V=1.0, theta=0.0
% INFO    : Bus 88422	: V=0.9755371, theta=-48.10439 -> V=1.0, theta=0.0
% INFO    : Bus 88423	: V=0.9773309, theta=-47.792951 -> V=1.0, theta=0.0
% INFO    : Bus 88424	: V=0.9739484, theta=-49.124534 -> V=1.0, theta=0.0
% INFO    : Bus 88425	: V=0.9622359, theta=-48.644347 -> V=1.0, theta=0.0
% INFO    : Bus 88426	: V=0.9780174, theta=-29.60516 -> V=1.0, theta=0.0
% INFO    : Bus 88427	: V=0.9987033, theta=-27.064849 -> V=1.0, theta=0.0
% INFO    : Bus 88428	: V=0.9974936, theta=-27.164401 -> V=1.0, theta=0.0
% INFO    : Bus 88429	: V=0.9784827, theta=-29.732145 -> V=1.0, theta=0.0
% INFO    : Bus 88430	: V=0.9624119, theta=-31.608763 -> V=1.0, theta=0.0
% INFO    : Bus 88431	: V=1.0006032, theta=-25.910857 -> V=1.0, theta=0.0
% INFO    : Bus 88432	: V=0.989581, theta=-28.012475 -> V=1.0, theta=0.0
% INFO    : Bus 88433	: V=0.9868924, theta=-28.38965 -> V=1.0, theta=0.0
% INFO    : Bus 88434	: V=0.9728078, theta=-29.857292 -> V=1.0, theta=0.0
% INFO    : Bus 88435	: V=0.9768207, theta=-29.877845 -> V=1.0, theta=0.0
% INFO    : Bus 88436	: V=0.9680457, theta=-31.418536 -> V=1.0, theta=0.0
% INFO    : Bus 88437	: V=0.9753818, theta=-32.287533 -> V=1.0, theta=0.0
% INFO    : Bus 88438	: V=0.9775298, theta=-32.355225 -> V=1.0, theta=0.0
% INFO    : Bus 88439	: V=0.9942329, theta=-28.102174 -> V=1.0, theta=0.0
% INFO    : Bus 88440	: V=0.9941161, theta=-27.970968 -> V=1.0, theta=0.0
% INFO    : Bus 88441	: V=0.9820225, theta=-29.843402 -> V=1.0, theta=0.0
% INFO    : Bus 88442	: V=0.9789451, theta=-30.185794 -> V=1.0, theta=0.0
% INFO    : Bus 88443	: V=0.9869419, theta=-29.322851 -> V=1.0, theta=0.0
% INFO    : Bus 88444	: V=0.986353, theta=-29.314471 -> V=1.0, theta=0.0
% INFO    : Bus 88445	: V=0.9945296, theta=-27.7289 -> V=1.0, theta=0.0
% INFO    : Bus 88446	: V=0.9932366, theta=-28.581187 -> V=1.0, theta=0.0
% INFO    : Bus 88447	: V=0.990027, theta=-27.988209 -> V=1.0, theta=0.0
% INFO    : Bus 88448	: V=1.0009082, theta=-26.749674 -> V=1.0, theta=0.0
% INFO    : Bus 88449	: V=0.9992601, theta=-26.909365 -> V=1.0, theta=0.0
% INFO    : Bus 88450	: V=0.9994496, theta=-26.956341 -> V=1.0, theta=0.0
% INFO    : Bus 88451	: V=0.9724031, theta=-30.327672 -> V=1.0, theta=0.0
% INFO    : Bus 88452	: V=0.9842914, theta=-29.348554 -> V=1.0, theta=0.0
% INFO    : Bus 88453	: V=0.9692109, theta=-30.509055 -> V=1.0, theta=0.0
% INFO    : Bus 88454	: V=1.0021517, theta=-26.335993 -> V=1.0, theta=0.0
% INFO    : Bus 88455	: V=0.9973198, theta=-27.31415 -> V=1.0, theta=0.0
% INFO    : Bus 88456	: V=0.9971601, theta=-46.412166 -> V=1.0, theta=0.0
% INFO    : Bus 88457	: V=0.9539623, theta=-28.855874 -> V=1.0, theta=0.0
% INFO    : Bus 88458	: V=0.9668525, theta=-25.428508 -> V=1.0, theta=0.0
% INFO    : Bus 88459	: V=0.9987165, theta=-24.658472 -> V=1.0, theta=0.0
% INFO    : Bus 88460	: V=1.0022898, theta=-45.747754 -> V=1.0, theta=0.0
% INFO    : Bus 88461	: V=0.9698919, theta=-51.035511 -> V=1.0, theta=0.0
% INFO    : Bus 88462	: V=0.9618577, theta=-51.483815 -> V=1.0, theta=0.0
% INFO    : Bus 88463	: V=0.9573968, theta=-51.703185 -> V=1.0, theta=0.0
% INFO    : Bus 88464	: V=0.9963838, theta=-20.793163 -> V=1.0, theta=0.0
% INFO    : Bus 88465	: V=0.9427371, theta=-26.776856 -> V=1.0, theta=0.0
% INFO    : Bus 88466	: V=0.9936165, theta=-15.395847 -> V=1.0, theta=0.0
% INFO    : Bus 88467	: V=1.0025638, theta=-16.0933 -> V=1.0, theta=0.0
% INFO    : Bus 88468	: V=1.0029919, theta=-14.962648 -> V=1.0, theta=0.0
% INFO    : Bus 88469	: V=0.9957213, theta=-15.628294 -> V=1.0, theta=0.0
% INFO    : Bus 88470	: V=1.0112725, theta=-14.283086 -> V=1.0, theta=0.0
% INFO    : Bus 88471	: V=0.9828754, theta=-19.9969 -> V=1.0, theta=0.0
% INFO    : Bus 88472	: V=1.0109371, theta=-15.937892 -> V=1.0, theta=0.0
% INFO    : Bus 88473	: V=1.008064, theta=-16.631937 -> V=1.0, theta=0.0
% INFO    : Bus 88474	: V=0.9637841, theta=-43.895322 -> V=1.0, theta=0.0
% INFO    : Bus 88475	: V=0.9592253, theta=-45.017575 -> V=1.0, theta=0.0
% INFO    : Bus 88476	: V=0.943792, theta=-46.880109 -> V=1.0, theta=0.0
% INFO    : Bus 88477	: V=0.951814, theta=-44.603104 -> V=1.0, theta=0.0
% INFO    : Bus 88478	: V=0.9522407, theta=-44.513965 -> V=1.0, theta=0.0
% INFO    : Bus 88479	: V=0.9495716, theta=-44.964193 -> V=1.0, theta=0.0
% INFO    : Bus 88480	: V=0.9497531, theta=-44.91862 -> V=1.0, theta=0.0
% INFO    : Bus 88481	: V=0.9626982, theta=-42.824238 -> V=1.0, theta=0.0
% INFO    : Bus 88482	: V=0.9745636, theta=-41.10714 -> V=1.0, theta=0.0
% INFO    : Bus 88483	: V=0.9742269, theta=-41.162985 -> V=1.0, theta=0.0
% INFO    : Bus 88484	: V=0.9530514, theta=-44.28652 -> V=1.0, theta=0.0
% INFO    : Bus 88485	: V=0.9678472, theta=-41.738801 -> V=1.0, theta=0.0
% INFO    : Bus 88486	: V=0.9653463, theta=-42.32279 -> V=1.0, theta=0.0
% INFO    : Bus 88487	: V=0.9807415, theta=-39.706203 -> V=1.0, theta=0.0
% INFO    : Bus 88488	: V=0.9822823, theta=-39.307576 -> V=1.0, theta=0.0
% INFO    : Bus 88489	: V=0.9742171, theta=-41.13553 -> V=1.0, theta=0.0
% INFO    : Bus 88490	: V=0.9757993, theta=-39.335605 -> V=1.0, theta=0.0
% INFO    : Bus 88491	: V=0.9776563, theta=-40.501175 -> V=1.0, theta=0.0
% INFO    : Bus 88492	: V=0.9703067, theta=-41.748338 -> V=1.0, theta=0.0
% INFO    : Bus 88493	: V=0.9735013, theta=-41.200477 -> V=1.0, theta=0.0
% INFO    : Bus 88494	: V=0.9599135, theta=-43.149429 -> V=1.0, theta=0.0
% INFO    : Bus 88495	: V=0.9489151, theta=-46.297998 -> V=1.0, theta=0.0
% INFO    : Bus 88496	: V=0.9519281, theta=-45.689509 -> V=1.0, theta=0.0
% INFO    : Bus 88497	: V=0.9495983, theta=-45.989094 -> V=1.0, theta=0.0
% INFO    : Bus 88498	: V=0.9690863, theta=-41.553889 -> V=1.0, theta=0.0
% INFO    : Bus 88499	: V=0.9699469, theta=-41.199544 -> V=1.0, theta=0.0
% INFO    : Bus 88500	: V=0.9742681, theta=-40.794903 -> V=1.0, theta=0.0
% INFO    : Bus 88501	: V=0.9771048, theta=-40.372816 -> V=1.0, theta=0.0
% INFO    : Bus 88502	: V=0.9815177, theta=-39.839824 -> V=1.0, theta=0.0
% INFO    : Bus 88503	: V=0.9809423, theta=-39.910924 -> V=1.0, theta=0.0
% INFO    : Bus 88504	: V=0.9760842, theta=-40.45753 -> V=1.0, theta=0.0
% INFO    : Bus 88505	: V=0.9791562, theta=-39.658066 -> V=1.0, theta=0.0
% INFO    : Bus 88506	: V=0.9932373, theta=-37.531309 -> V=1.0, theta=0.0
% INFO    : Bus 88507	: V=0.9905513, theta=-37.965162 -> V=1.0, theta=0.0
% INFO    : Bus 88508	: V=0.9532682, theta=-44.390926 -> V=1.0, theta=0.0
% INFO    : Bus 88509	: V=0.9447739, theta=-48.532578 -> V=1.0, theta=0.0
% INFO    : Bus 88510	: V=0.9528331, theta=-44.027562 -> V=1.0, theta=0.0
% INFO    : Bus 88511	: V=0.9917996, theta=-20.902484 -> V=1.0, theta=0.0
% INFO    : Bus 88512	: V=0.9628426, theta=-26.929775 -> V=1.0, theta=0.0
% INFO    : Bus 88513	: V=0.9758879, theta=-24.028699 -> V=1.0, theta=0.0
% INFO    : Bus 88514	: V=0.9618283, theta=-27.21582 -> V=1.0, theta=0.0
% INFO    : Bus 88515	: V=0.9793445, theta=-23.804019 -> V=1.0, theta=0.0
% INFO    : Bus 88516	: V=0.9821658, theta=-23.313649 -> V=1.0, theta=0.0
% INFO    : Bus 88517	: V=0.9520085, theta=-27.228529 -> V=1.0, theta=0.0
% INFO    : Bus 88518	: V=0.9485932, theta=-31.4571 -> V=1.0, theta=0.0
% INFO    : Bus 88519	: V=0.9493411, theta=-31.549379 -> V=1.0, theta=0.0
% INFO    : Bus 88520	: V=0.9497095, theta=-31.28093 -> V=1.0, theta=0.0
% INFO    : Bus 88521	: V=0.9851708, theta=-39.676909 -> V=1.0, theta=0.0
% INFO    : Bus 88522	: V=0.9812067, theta=-40.17592 -> V=1.0, theta=0.0
% INFO    : Bus 88523	: V=0.9943309, theta=-37.360952 -> V=1.0, theta=0.0
% INFO    : Bus 88524	: V=0.9971702, theta=-35.696207 -> V=1.0, theta=0.0
% INFO    : Bus 88525	: V=0.9794638, theta=-36.669735 -> V=1.0, theta=0.0
% INFO    : Bus 88526	: V=0.9677663, theta=-37.83076 -> V=1.0, theta=0.0
% INFO    : Bus 88527	: V=0.9574359, theta=-39.047377 -> V=1.0, theta=0.0
% INFO    : Bus 88528	: V=0.9739099, theta=-37.51458 -> V=1.0, theta=0.0
% INFO    : Bus 88529	: V=0.9750797, theta=-25.696723 -> V=1.0, theta=0.0
% INFO    : Bus 88530	: V=0.9859033, theta=-24.423128 -> V=1.0, theta=0.0
% INFO    : Bus 88531	: V=0.9959962, theta=-23.952524 -> V=1.0, theta=0.0
% INFO    : Bus 88532	: V=0.986969, theta=-36.407914 -> V=1.0, theta=0.0
% INFO    : Bus 88533	: V=0.9542551, theta=-24.899298 -> V=1.0, theta=0.0
% INFO    : Bus 88534	: V=0.9564591, theta=-25.297003 -> V=1.0, theta=0.0
% INFO    : Bus 88535	: V=0.9558423, theta=-25.533897 -> V=1.0, theta=0.0
% INFO    : Bus 88536	: V=0.955891, theta=-25.482525 -> V=1.0, theta=0.0
% INFO    : Bus 88537	: V=0.9736412, theta=-22.706256 -> V=1.0, theta=0.0
% INFO    : Bus 88538	: V=0.9549612, theta=-25.072018 -> V=1.0, theta=0.0
% INFO    : Bus 88539	: V=0.9620737, theta=-24.465785 -> V=1.0, theta=0.0
% INFO    : Bus 88540	: V=1.0139281, theta=-24.055413 -> V=1.0, theta=0.0
% INFO    : Bus 88541	: V=1.0111183, theta=-24.798503 -> V=1.0, theta=0.0
% INFO    : Bus 88542	: V=1.0092636, theta=-25.329794 -> V=1.0, theta=0.0
% INFO    : Bus 88543	: V=0.9552121, theta=-32.49191 -> V=1.0, theta=0.0
% INFO    : Bus 88544	: V=0.9523926, theta=-34.762639 -> V=1.0, theta=0.0
% INFO    : Bus 88545	: V=0.9559046, theta=-34.271038 -> V=1.0, theta=0.0
% INFO    : Bus 88546	: V=0.9690287, theta=-29.623006 -> V=1.0, theta=0.0
% INFO    : Bus 88547	: V=0.9696093, theta=-30.038454 -> V=1.0, theta=0.0
% INFO    : Bus 88548	: V=0.9610673, theta=-32.262415 -> V=1.0, theta=0.0
% INFO    : Bus 88549	: V=0.9868027, theta=-31.876899 -> V=1.0, theta=0.0
% INFO    : Bus 88550	: V=0.9907972, theta=-17.367125 -> V=1.0, theta=0.0
% INFO    : Bus 88551	: V=0.9986808, theta=-16.082312 -> V=1.0, theta=0.0
% INFO    : Bus 88552	: V=0.9958148, theta=-16.662833 -> V=1.0, theta=0.0
% INFO    : Bus 88553	: V=1.0069513, theta=-14.868156 -> V=1.0, theta=0.0
% INFO    : Bus 88554	: V=1.0054189, theta=-15.10094 -> V=1.0, theta=0.0
% INFO    : Bus 88555	: V=1.0022705, theta=-15.642091 -> V=1.0, theta=0.0
% INFO    : Bus 88556	: V=0.9978776, theta=-16.217758 -> V=1.0, theta=0.0
% INFO    : Bus 88557	: V=1.0079816, theta=-14.639068 -> V=1.0, theta=0.0
% INFO    : Bus 88558	: V=1.0076031, theta=-14.891489 -> V=1.0, theta=0.0
% INFO    : Bus 88559	: V=1.0067626, theta=-15.262543 -> V=1.0, theta=0.0
% INFO    : Bus 88560	: V=1.0035631, theta=-15.76589 -> V=1.0, theta=0.0
% INFO    : Bus 88561	: V=0.9933394, theta=-17.237288 -> V=1.0, theta=0.0
% INFO    : Bus 88562	: V=0.9900717, theta=-17.876292 -> V=1.0, theta=0.0
% INFO    : Bus 88563	: V=0.9981156, theta=-16.075648 -> V=1.0, theta=0.0
% INFO    : Bus 88564	: V=0.9972172, theta=-16.288274 -> V=1.0, theta=0.0
% INFO    : Bus 88565	: V=0.9972204, theta=-15.636872 -> V=1.0, theta=0.0
% INFO    : Bus 88566	: V=0.9973426, theta=-16.372259 -> V=1.0, theta=0.0
% INFO    : Bus 88567	: V=0.9661599, theta=-36.969821 -> V=1.0, theta=0.0
% INFO    : Bus 88568	: V=0.9763774, theta=-37.060043 -> V=1.0, theta=0.0
% INFO    : Bus 88569	: V=1.016904, theta=-15.119534 -> V=1.0, theta=0.0
% INFO    : Bus 88570	: V=1.0064314, theta=-15.411638 -> V=1.0, theta=0.0
% INFO    : Bus 88571	: V=1.0196258, theta=-13.612472 -> V=1.0, theta=0.0
% INFO    : Bus 88572	: V=1.0179429, theta=-14.413777 -> V=1.0, theta=0.0
% INFO    : Bus 88573	: V=0.9726041, theta=-37.036517 -> V=1.0, theta=0.0
% INFO    : Bus 88574	: V=0.9406966, theta=-47.624018 -> V=1.0, theta=0.0
% INFO    : Bus 88575	: V=0.9429248, theta=-48.139985 -> V=1.0, theta=0.0
% INFO    : Bus 88576	: V=0.9437514, theta=-47.329567 -> V=1.0, theta=0.0
% INFO    : Bus 88577	: V=0.9498777, theta=-45.994259 -> V=1.0, theta=0.0
% INFO    : Bus 88578	: V=0.9460993, theta=-46.676472 -> V=1.0, theta=0.0
% INFO    : Bus 88579	: V=0.9671571, theta=-36.098225 -> V=1.0, theta=0.0
% INFO    : Bus 88580	: V=1.0003018, theta=-36.633894 -> V=1.0, theta=0.0
% INFO    : Bus 88581	: V=1.005248, theta=-34.473027 -> V=1.0, theta=0.0
% INFO    : Bus 88582	: V=1.006918, theta=-34.404129 -> V=1.0, theta=0.0
% INFO    : Bus 88583	: V=0.9696259, theta=-37.040165 -> V=1.0, theta=0.0
% INFO    : Bus 88584	: V=1.0137064, theta=-33.432662 -> V=1.0, theta=0.0
% INFO    : Bus 88585	: V=1.0024181, theta=-35.421422 -> V=1.0, theta=0.0
% INFO    : Bus 88586	: V=0.9973955, theta=-36.186662 -> V=1.0, theta=0.0
% INFO    : Bus 88587	: V=0.9826074, theta=-21.948159 -> V=1.0, theta=0.0
% INFO    : Bus 88588	: V=0.9629422, theta=-24.878245 -> V=1.0, theta=0.0
% INFO    : Bus 88589	: V=0.9757443, theta=-23.128403 -> V=1.0, theta=0.0
% INFO    : Bus 88590	: V=0.9702424, theta=-24.598541 -> V=1.0, theta=0.0
% INFO    : Bus 88591	: V=0.9633769, theta=-39.896406 -> V=1.0, theta=0.0
% INFO    : Bus 88592	: V=0.9659138, theta=-37.753578 -> V=1.0, theta=0.0
% INFO    : Bus 88593	: V=0.9679611, theta=-37.031433 -> V=1.0, theta=0.0
% INFO    : Bus 88594	: V=0.9588865, theta=-42.064536 -> V=1.0, theta=0.0
% INFO    : Bus 88595	: V=0.9543738, theta=-38.755158 -> V=1.0, theta=0.0
% INFO    : Bus 88596	: V=0.9566399, theta=-38.548416 -> V=1.0, theta=0.0
% INFO    : Bus 88597	: V=0.9594259, theta=-40.153916 -> V=1.0, theta=0.0
% INFO    : Bus 88598	: V=0.9551386, theta=-40.256341 -> V=1.0, theta=0.0
% INFO    : Bus 88599	: V=0.9534513, theta=-40.696651 -> V=1.0, theta=0.0
% INFO    : Bus 88600	: V=0.9536615, theta=-40.314562 -> V=1.0, theta=0.0
% INFO    : Bus 88601	: V=0.9535879, theta=-40.426978 -> V=1.0, theta=0.0
% INFO    : Bus 88602	: V=0.9477482, theta=-42.843499 -> V=1.0, theta=0.0
% INFO    : Bus 88603	: V=0.9496173, theta=-42.358767 -> V=1.0, theta=0.0
% INFO    : Bus 88604	: V=0.9511598, theta=-42.345165 -> V=1.0, theta=0.0
% INFO    : Bus 88605	: V=0.9616342, theta=-41.078768 -> V=1.0, theta=0.0
% INFO    : Bus 88606	: V=0.9524214, theta=-41.787021 -> V=1.0, theta=0.0
% INFO    : Bus 88607	: V=0.9512721, theta=-38.023985 -> V=1.0, theta=0.0
% INFO    : Bus 88608	: V=0.9500715, theta=-37.578726 -> V=1.0, theta=0.0
% INFO    : Bus 88609	: V=0.958589, theta=-37.418717 -> V=1.0, theta=0.0
% INFO    : Bus 88610	: V=0.9704185, theta=-32.102169 -> V=1.0, theta=0.0
% INFO    : Bus 88611	: V=0.9707029, theta=-45.802844 -> V=1.0, theta=0.0
% INFO    : Bus 88612	: V=0.953673, theta=-46.962784 -> V=1.0, theta=0.0
% INFO    : Bus 88613	: V=0.9814795, theta=-42.77495 -> V=1.0, theta=0.0
% INFO    : Bus 88614	: V=0.9967413, theta=-40.883202 -> V=1.0, theta=0.0
% INFO    : Bus 88615	: V=0.9932107, theta=-41.731543 -> V=1.0, theta=0.0
% INFO    : Bus 88616	: V=0.9924203, theta=-41.938892 -> V=1.0, theta=0.0
% INFO    : Bus 88617	: V=0.9529308, theta=-31.484032 -> V=1.0, theta=0.0
% INFO    : Bus 88618	: V=0.9477495, theta=-32.087261 -> V=1.0, theta=0.0
% INFO    : Bus 88619	: V=0.9478215, theta=-32.119445 -> V=1.0, theta=0.0
% INFO    : Bus 88620	: V=0.9468859, theta=-32.095622 -> V=1.0, theta=0.0
% INFO    : Bus 88621	: V=0.9485505, theta=-32.009959 -> V=1.0, theta=0.0
% INFO    : Bus 88622	: V=0.9504856, theta=-31.791189 -> V=1.0, theta=0.0
% INFO    : Bus 88623	: V=0.9473522, theta=-32.044442 -> V=1.0, theta=0.0
% INFO    : Bus 88624	: V=0.9539561, theta=-31.351613 -> V=1.0, theta=0.0
% INFO    : Bus 88625	: V=0.9508307, theta=-31.727345 -> V=1.0, theta=0.0
% INFO    : Bus 88626	: V=0.9524455, theta=-31.569418 -> V=1.0, theta=0.0
% INFO    : Bus 88627	: V=0.9612957, theta=-30.424994 -> V=1.0, theta=0.0
% INFO    : Bus 88628	: V=0.9753647, theta=-28.346556 -> V=1.0, theta=0.0
% INFO    : Bus 88629	: V=0.9779646, theta=-27.934669 -> V=1.0, theta=0.0
% INFO    : Bus 88630	: V=0.954091, theta=-31.514945 -> V=1.0, theta=0.0
% INFO    : Bus 88631	: V=0.9552531, theta=-31.500321 -> V=1.0, theta=0.0
% INFO    : Bus 88632	: V=0.9579864, theta=-30.670613 -> V=1.0, theta=0.0
% INFO    : Bus 88633	: V=0.9579384, theta=-30.66733 -> V=1.0, theta=0.0
% INFO    : Bus 88634	: V=0.9503931, theta=-31.239103 -> V=1.0, theta=0.0
% INFO    : Bus 88635	: V=0.9656043, theta=-29.711758 -> V=1.0, theta=0.0
% INFO    : Bus 88636	: V=0.9694395, theta=-29.299787 -> V=1.0, theta=0.0
% INFO    : Bus 88637	: V=0.9539999, theta=-31.054886 -> V=1.0, theta=0.0
% INFO    : Bus 88638	: V=0.9594266, theta=-30.15391 -> V=1.0, theta=0.0
% INFO    : Bus 88639	: V=0.9489465, theta=-31.475241 -> V=1.0, theta=0.0
% INFO    : Bus 88640	: V=0.9483086, theta=-31.528462 -> V=1.0, theta=0.0
% INFO    : Bus 88641	: V=0.9438383, theta=-32.510313 -> V=1.0, theta=0.0
% INFO    : Bus 88642	: V=0.9482234, theta=-31.50787 -> V=1.0, theta=0.0
% INFO    : Bus 88643	: V=0.9526334, theta=-30.954482 -> V=1.0, theta=0.0
% INFO    : Bus 88644	: V=0.9396538, theta=-33.233065 -> V=1.0, theta=0.0
% INFO    : Bus 88645	: V=0.940686, theta=-33.13693 -> V=1.0, theta=0.0
% INFO    : Bus 88646	: V=0.9400958, theta=-33.670048 -> V=1.0, theta=0.0
% INFO    : Bus 88647	: V=0.9403697, theta=-33.212706 -> V=1.0, theta=0.0
% INFO    : Bus 88648	: V=0.9419131, theta=-32.533824 -> V=1.0, theta=0.0
% INFO    : Bus 88649	: V=0.9562086, theta=-30.902366 -> V=1.0, theta=0.0
% INFO    : Bus 88650	: V=0.9608944, theta=-30.06754 -> V=1.0, theta=0.0
% INFO    : Bus 88651	: V=0.9567118, theta=-30.314837 -> V=1.0, theta=0.0
% INFO    : Bus 88652	: V=0.9563989, theta=-30.372753 -> V=1.0, theta=0.0
% INFO    : Bus 88653	: V=0.9467129, theta=-32.309728 -> V=1.0, theta=0.0
% INFO    : Bus 88654	: V=0.9497931, theta=-31.916012 -> V=1.0, theta=0.0
% INFO    : Bus 88655	: V=0.9592765, theta=-30.421056 -> V=1.0, theta=0.0
% INFO    : Bus 88656	: V=0.9561663, theta=-31.186942 -> V=1.0, theta=0.0
% INFO    : Bus 88657	: V=0.9607694, theta=-29.600267 -> V=1.0, theta=0.0
% INFO    : Bus 88658	: V=0.9624557, theta=-30.042372 -> V=1.0, theta=0.0
% INFO    : Bus 88659	: V=0.9730726, theta=-28.543081 -> V=1.0, theta=0.0
% INFO    : Bus 88660	: V=0.9649369, theta=-30.068414 -> V=1.0, theta=0.0
% INFO    : Bus 88661	: V=0.9603976, theta=-30.062784 -> V=1.0, theta=0.0
% INFO    : Bus 88662	: V=0.9362762, theta=-33.309227 -> V=1.0, theta=0.0
% INFO    : Bus 88663	: V=0.9228804, theta=-35.828872 -> V=1.0, theta=0.0
% INFO    : Bus 88664	: V=0.9406933, theta=-33.080695 -> V=1.0, theta=0.0
% INFO    : Bus 88665	: V=0.9385241, theta=-33.101957 -> V=1.0, theta=0.0
% INFO    : Bus 88666	: V=0.9385983, theta=-33.014483 -> V=1.0, theta=0.0
% INFO    : Bus 88667	: V=0.9356132, theta=-32.573299 -> V=1.0, theta=0.0
% INFO    : Bus 88668	: V=0.9424776, theta=-32.207623 -> V=1.0, theta=0.0
% INFO    : Bus 88669	: V=0.9407485, theta=-32.222075 -> V=1.0, theta=0.0
% INFO    : Bus 88670	: V=0.9405676, theta=-32.235343 -> V=1.0, theta=0.0
% INFO    : Bus 88671	: V=0.9379425, theta=-32.599474 -> V=1.0, theta=0.0
% INFO    : Bus 88672	: V=0.9353265, theta=-32.901355 -> V=1.0, theta=0.0
% INFO    : Bus 88673	: V=0.9357698, theta=-32.789014 -> V=1.0, theta=0.0
% INFO    : Bus 88674	: V=0.9414908, theta=-32.360952 -> V=1.0, theta=0.0
% INFO    : Bus 88675	: V=0.9453845, theta=-31.029514 -> V=1.0, theta=0.0
% INFO    : Bus 88676	: V=0.9436635, theta=-31.845478 -> V=1.0, theta=0.0
% INFO    : Bus 88677	: V=0.9409889, theta=-31.968171 -> V=1.0, theta=0.0
% INFO    : Bus 88678	: V=0.9390345, theta=-31.344709 -> V=1.0, theta=0.0
% INFO    : Bus 88679	: V=0.9363718, theta=-32.408746 -> V=1.0, theta=0.0
% INFO    : Bus 88680	: V=0.9429922, theta=-32.157492 -> V=1.0, theta=0.0
% INFO    : Bus 88681	: V=0.9457513, theta=-31.985905 -> V=1.0, theta=0.0
% INFO    : Bus 88682	: V=0.9437343, theta=-31.65245 -> V=1.0, theta=0.0
% INFO    : Bus 88683	: V=0.9469458, theta=-31.741647 -> V=1.0, theta=0.0
% INFO    : Bus 88684	: V=0.9461172, theta=-31.9149 -> V=1.0, theta=0.0
% INFO    : Bus 88685	: V=0.9491684, theta=-31.308943 -> V=1.0, theta=0.0
% INFO    : Bus 88686	: V=0.9554678, theta=-30.22169 -> V=1.0, theta=0.0
% INFO    : Bus 88687	: V=0.9453064, theta=-31.503527 -> V=1.0, theta=0.0
% INFO    : Bus 88688	: V=0.9459356, theta=-31.994598 -> V=1.0, theta=0.0
% INFO    : Bus 88689	: V=0.9530007, theta=-30.862512 -> V=1.0, theta=0.0
% INFO    : Bus 88690	: V=0.9559151, theta=-30.134779 -> V=1.0, theta=0.0
% INFO    : Bus 88691	: V=0.9546963, theta=-30.24369 -> V=1.0, theta=0.0
% INFO    : Bus 88692	: V=0.9532559, theta=-30.715482 -> V=1.0, theta=0.0
% INFO    : Bus 88693	: V=0.9547778, theta=-30.602001 -> V=1.0, theta=0.0
% INFO    : Bus 88694	: V=0.9663035, theta=-28.322001 -> V=1.0, theta=0.0
% INFO    : Bus 88695	: V=0.9694516, theta=-28.222614 -> V=1.0, theta=0.0
% INFO    : Bus 88696	: V=0.9705974, theta=-28.033639 -> V=1.0, theta=0.0
% INFO    : Bus 88697	: V=0.964998, theta=-28.480637 -> V=1.0, theta=0.0
% INFO    : Bus 88698	: V=0.9594729, theta=-29.934951 -> V=1.0, theta=0.0
% INFO    : Bus 88699	: V=0.9556782, theta=-30.199725 -> V=1.0, theta=0.0
% INFO    : Bus 88700	: V=0.9590657, theta=-29.975098 -> V=1.0, theta=0.0
% INFO    : Bus 88701	: V=0.9560582, theta=-30.240965 -> V=1.0, theta=0.0
% INFO    : Bus 88702	: V=0.9552078, theta=-30.174076 -> V=1.0, theta=0.0
% INFO    : Bus 88703	: V=0.9835364, theta=-27.443644 -> V=1.0, theta=0.0
% INFO    : Bus 88704	: V=0.9936287, theta=-26.474965 -> V=1.0, theta=0.0
% INFO    : Bus 88705	: V=0.98509, theta=-27.682462 -> V=1.0, theta=0.0
% INFO    : Bus 88706	: V=0.9816619, theta=-27.849006 -> V=1.0, theta=0.0
% INFO    : Bus 88707	: V=0.9832458, theta=-27.727812 -> V=1.0, theta=0.0
% INFO    : Bus 88708	: V=0.9921309, theta=-25.781155 -> V=1.0, theta=0.0
% INFO    : Bus 88709	: V=0.9857388, theta=-26.967676 -> V=1.0, theta=0.0
% INFO    : Bus 88710	: V=1.0065564, theta=-24.013407 -> V=1.0, theta=0.0
% INFO    : Bus 88711	: V=0.9817181, theta=-27.598812 -> V=1.0, theta=0.0
% INFO    : Bus 88712	: V=0.9840789, theta=-27.277479 -> V=1.0, theta=0.0
% INFO    : Bus 88713	: V=0.9741455, theta=-27.839579 -> V=1.0, theta=0.0
% INFO    : Bus 88714	: V=0.9733019, theta=-28.05163 -> V=1.0, theta=0.0
% INFO    : Bus 88715	: V=1.0031736, theta=-24.427628 -> V=1.0, theta=0.0
% INFO    : Bus 88716	: V=0.9605617, theta=-29.271879 -> V=1.0, theta=0.0
% INFO    : Bus 88717	: V=0.9881399, theta=-26.033099 -> V=1.0, theta=0.0
% INFO    : Bus 88718	: V=0.9695792, theta=-29.052494 -> V=1.0, theta=0.0
% INFO    : Bus 88719	: V=0.9709062, theta=-29.0382 -> V=1.0, theta=0.0
% INFO    : Bus 88720	: V=1.0061576, theta=-36.620613 -> V=1.0, theta=0.0
% INFO    : Bus 88721	: V=0.9987174, theta=-37.115283 -> V=1.0, theta=0.0
% INFO    : Bus 88722	: V=0.98633, theta=-39.127657 -> V=1.0, theta=0.0
% INFO    : Bus 88723	: V=1.0070561, theta=-13.580311 -> V=1.0, theta=0.0
% INFO    : Bus 88724	: V=0.9991981, theta=-14.328062 -> V=1.0, theta=0.0
% INFO    : Bus 88725	: V=0.9761835, theta=-48.031621 -> V=1.0, theta=0.0
% INFO    : Bus 88726	: V=0.9610552, theta=-51.266055 -> V=1.0, theta=0.0
% INFO    : Bus 88727	: V=0.9624086, theta=-51.491475 -> V=1.0, theta=0.0
% INFO    : Bus 88728	: V=0.9398994, theta=-54.314908 -> V=1.0, theta=0.0
% INFO    : Bus 88729	: V=0.9367733, theta=-54.513547 -> V=1.0, theta=0.0
% INFO    : Bus 88730	: V=0.929494, theta=-61.252307 -> V=1.0, theta=0.0
% INFO    : Bus 88731	: V=0.935739, theta=-62.756059 -> V=1.0, theta=0.0
% INFO    : Bus 88732	: V=0.9355597, theta=-61.335189 -> V=1.0, theta=0.0
% INFO    : Bus 88733	: V=0.9260877, theta=-57.511169 -> V=1.0, theta=0.0
% INFO    : Bus 88734	: V=0.9746978, theta=-51.533933 -> V=1.0, theta=0.0
% INFO    : Bus 88735	: V=0.98674, theta=-31.965118 -> V=1.0, theta=0.0
% INFO    : Bus 88736	: V=0.9946207, theta=-33.540977 -> V=1.0, theta=0.0
% INFO    : Bus 88737	: V=0.9611164, theta=-39.306657 -> V=1.0, theta=0.0
% INFO    : Bus 88738	: V=0.9849525, theta=-32.379657 -> V=1.0, theta=0.0
% INFO    : Bus 88739	: V=0.983968, theta=-36.328841 -> V=1.0, theta=0.0
% INFO    : Bus 88740	: V=0.9961914, theta=-32.348592 -> V=1.0, theta=0.0
% INFO    : Bus 88741	: V=0.9912409, theta=-34.416326 -> V=1.0, theta=0.0
% INFO    : Bus 88742	: V=0.9854336, theta=-35.355683 -> V=1.0, theta=0.0
% INFO    : Bus 88743	: V=0.9873703, theta=-35.064625 -> V=1.0, theta=0.0
% INFO    : Bus 88744	: V=0.9861611, theta=-35.320885 -> V=1.0, theta=0.0
% INFO    : Bus 88745	: V=0.9873808, theta=-34.466436 -> V=1.0, theta=0.0
% INFO    : Bus 88746	: V=0.983741, theta=-37.113409 -> V=1.0, theta=0.0
% INFO    : Bus 88747	: V=0.9369371, theta=-32.566168 -> V=1.0, theta=0.0
% INFO    : Bus 88748	: V=0.9723819, theta=-25.451313 -> V=1.0, theta=0.0
% INFO    : Bus 88749	: V=0.9729009, theta=-25.368855 -> V=1.0, theta=0.0
% INFO    : Bus 88750	: V=0.9564142, theta=-45.067497 -> V=1.0, theta=0.0
% INFO    : Bus 88751	: V=0.970293, theta=-40.125818 -> V=1.0, theta=0.0
% INFO    : Bus 88752	: V=0.9704177, theta=-38.650099 -> V=1.0, theta=0.0
% INFO    : Bus 88753	: V=0.9676081, theta=-39.171935 -> V=1.0, theta=0.0
% INFO    : Bus 88754	: V=0.9492638, theta=-55.378084 -> V=1.0, theta=0.0
% INFO    : Bus 88755	: V=0.9479712, theta=-54.09011 -> V=1.0, theta=0.0
% INFO    : Bus 88756	: V=0.9474885, theta=-55.691684 -> V=1.0, theta=0.0
% INFO    : Bus 88757	: V=0.9326806, theta=-57.722773 -> V=1.0, theta=0.0
% INFO    : Bus 88758	: V=0.9686483, theta=-51.889419 -> V=1.0, theta=0.0
% INFO    : Bus 88759	: V=0.9612759, theta=-51.359412 -> V=1.0, theta=0.0
% INFO    : Bus 88760	: V=0.9526678, theta=-52.660009 -> V=1.0, theta=0.0
% INFO    : Bus 88761	: V=0.961668, theta=-51.769265 -> V=1.0, theta=0.0
% INFO    : Bus 88762	: V=0.9596307, theta=-51.98601 -> V=1.0, theta=0.0
% INFO    : Bus 88763	: V=0.9720547, theta=-26.199288 -> V=1.0, theta=0.0
% INFO    : Bus 88764	: V=0.9963474, theta=-17.677976 -> V=1.0, theta=0.0
% INFO    : Bus 88765	: V=0.9994133, theta=-17.161302 -> V=1.0, theta=0.0
% INFO    : Bus 88766	: V=0.9986971, theta=-17.840904 -> V=1.0, theta=0.0
% INFO    : Bus 88767	: V=0.9516555, theta=-44.646151 -> V=1.0, theta=0.0
% INFO    : Bus 88768	: V=0.9558524, theta=-43.078498 -> V=1.0, theta=0.0
% INFO    : Bus 88769	: V=0.9620578, theta=-42.767018 -> V=1.0, theta=0.0
% INFO    : Bus 88770	: V=0.969355, theta=-36.029151 -> V=1.0, theta=0.0
% INFO    : Bus 88771	: V=0.9697225, theta=-36.779747 -> V=1.0, theta=0.0
% INFO    : Bus 88772	: V=0.9716279, theta=-34.804336 -> V=1.0, theta=0.0
% INFO    : Bus 88773	: V=0.9722951, theta=-34.982604 -> V=1.0, theta=0.0
% INFO    : Bus 88774	: V=0.9791432, theta=-27.468574 -> V=1.0, theta=0.0
% INFO    : Bus 88775	: V=0.9785864, theta=-26.913246 -> V=1.0, theta=0.0
% INFO    : Bus 88776	: V=0.9754175, theta=-30.986685 -> V=1.0, theta=0.0
% INFO    : Bus 88777	: V=0.9760514, theta=-31.357385 -> V=1.0, theta=0.0
% INFO    : Bus 88778	: V=0.9781255, theta=-32.22729 -> V=1.0, theta=0.0
% INFO    : Bus 88779	: V=0.9783602, theta=-32.582072 -> V=1.0, theta=0.0
% INFO    : Bus 88780	: V=0.9787361, theta=-32.130944 -> V=1.0, theta=0.0
% INFO    : Bus 88781	: V=0.9740866, theta=-33.166555 -> V=1.0, theta=0.0
% INFO    : Bus 88782	: V=0.9723164, theta=-35.117452 -> V=1.0, theta=0.0
% INFO    : Bus 88783	: V=0.9602115, theta=-36.702671 -> V=1.0, theta=0.0
% INFO    : Bus 88784	: V=0.9815432, theta=-34.482656 -> V=1.0, theta=0.0
% INFO    : Bus 88785	: V=0.9961511, theta=-35.745303 -> V=1.0, theta=0.0
% INFO    : Bus 88786	: V=0.9948737, theta=-35.947297 -> V=1.0, theta=0.0
% INFO    : Bus 88787	: V=0.9749221, theta=-34.998711 -> V=1.0, theta=0.0
% INFO    : Bus 88788	: V=1.0193246, theta=29.63022 -> V=1.0, theta=0.0
% INFO    : Bus 88789	: V=1.0186566, theta=29.598498 -> V=1.0, theta=0.0
% INFO    : Bus 88790	: V=1.017027, theta=29.083198 -> V=1.0, theta=0.0
% INFO    : Bus 88791	: V=1.021026, theta=39.888405 -> V=1.0, theta=0.0
% INFO    : Bus 88792	: V=1.02, theta=33.714712 -> V=1.0, theta=0.0
% INFO    : Bus 88793	: V=1.02, theta=32.384482 -> V=1.0, theta=0.0
% INFO    : Bus 88794	: V=1.0195476, theta=31.854507 -> V=1.0, theta=0.0
% INFO    : Bus 88795	: V=1.0166276, theta=16.900774 -> V=1.0, theta=0.0
% INFO    : Bus 88796	: V=1.017342, theta=11.090609 -> V=1.0, theta=0.0
% INFO    : Bus 88797	: V=1.0199506, theta=35.901161 -> V=1.0, theta=0.0
% INFO    : Bus 88798	: V=1.015873, theta=35.754689 -> V=1.0, theta=0.0
% INFO    : Bus 88799	: V=1.0173988, theta=8.199237 -> V=1.0, theta=0.0
% INFO    : Bus 88800	: V=1.0117876, theta=17.247375 -> V=1.0, theta=0.0
% INFO    : Bus 88801	: V=1.02, theta=35.075504 -> V=1.0, theta=0.0
% INFO    : Bus 88802	: V=1.0210339, theta=34.755042 -> V=1.0, theta=0.0
% INFO    : Bus 88803	: V=1.0181621, theta=23.753455 -> V=1.0, theta=0.0
% INFO    : Bus 88804	: V=1.0125288, theta=24.646064 -> V=1.0, theta=0.0
% INFO    : Bus 88805	: V=1.02, theta=15.28052 -> V=1.0, theta=0.0
% INFO    : Bus 88806	: V=1.0166172, theta=26.051727 -> V=1.0, theta=0.0
% INFO    : Bus 88807	: V=1.019498, theta=26.87994 -> V=1.0, theta=0.0
% INFO    : Bus 88808	: V=1.0104787, theta=15.559966 -> V=1.0, theta=0.0
% INFO    : Bus 88809	: V=1.0143714, theta=32.937145 -> V=1.0, theta=0.0
% INFO    : Bus 88810	: V=1.02, theta=28.841114 -> V=1.0, theta=0.0
% INFO    : Bus 88811	: V=1.018575, theta=37.786542 -> V=1.0, theta=0.0
% INFO    : Bus 88812	: V=1.0199921, theta=22.288355 -> V=1.0, theta=0.0
% INFO    : Bus 88813	: V=1.02, theta=23.044374 -> V=1.0, theta=0.0
% INFO    : Bus 88814	: V=1.0173267, theta=33.481451 -> V=1.0, theta=0.0
% INFO    : Bus 88815	: V=1.0127136, theta=12.788681 -> V=1.0, theta=0.0
% INFO    : Bus 88816	: V=1.02, theta=18.731795 -> V=1.0, theta=0.0
% INFO    : Bus 88817	: V=1.0224231, theta=21.381858 -> V=1.0, theta=0.0
% INFO    : Bus 88818	: V=1.02, theta=16.131168 -> V=1.0, theta=0.0
% INFO    : Bus 88819	: V=1.0135898, theta=4.863988 -> V=1.0, theta=0.0
% INFO    : Bus 88820	: V=1.0116961, theta=4.625402 -> V=1.0, theta=0.0
% INFO    : Bus 88821	: V=1.0022456, theta=20.427151 -> V=1.0, theta=0.0
% INFO    : Bus 88822	: V=1.02, theta=38.518597 -> V=1.0, theta=0.0
% INFO    : Bus 88823	: V=1.0142456, theta=16.613669 -> V=1.0, theta=0.0
% INFO    : Bus 88824	: V=1.0138537, theta=38.645401 -> V=1.0, theta=0.0
% INFO    : Bus 88825	: V=1.0115482, theta=38.236119 -> V=1.0, theta=0.0
% INFO    : Bus 88826	: V=1.0153696, theta=20.869901 -> V=1.0, theta=0.0
% INFO    : Bus 88827	: V=1.0136656, theta=32.774102 -> V=1.0, theta=0.0
% INFO    : Bus 88828	: V=1.0107745, theta=26.507889 -> V=1.0, theta=0.0
% INFO    : Bus 88829	: V=1.0071459, theta=19.035883 -> V=1.0, theta=0.0
% INFO    : Bus 88830	: V=1.02, theta=30.428624 -> V=1.0, theta=0.0
% INFO    : Bus 88831	: V=1.0144407, theta=2.884127 -> V=1.0, theta=0.0
% INFO    : Bus 88832	: V=1.0141488, theta=21.136432 -> V=1.0, theta=0.0
% INFO    : Bus 88833	: V=1.0124499, theta=21.231053 -> V=1.0, theta=0.0
% INFO    : Bus 88834	: V=1.0170576, theta=33.419705 -> V=1.0, theta=0.0
% INFO    : Bus 88835	: V=1.0158987, theta=33.265778 -> V=1.0, theta=0.0
% INFO    : Bus 88836	: V=1.0185754, theta=24.883962 -> V=1.0, theta=0.0
% INFO    : Bus 88837	: V=1.0175506, theta=19.940834 -> V=1.0, theta=0.0
% INFO    : Bus 88838	: V=1.0169566, theta=19.724058 -> V=1.0, theta=0.0
% INFO    : Bus 88839	: V=1.0153103, theta=22.089391 -> V=1.0, theta=0.0
% INFO    : Bus 88840	: V=1.0145233, theta=21.87138 -> V=1.0, theta=0.0
% INFO    : Bus 88841	: V=1.0198998, theta=33.756306 -> V=1.0, theta=0.0
% INFO    : Bus 88842	: V=1.0164447, theta=25.062836 -> V=1.0, theta=0.0
% INFO    : Bus 88843	: V=1.0130666, theta=24.810252 -> V=1.0, theta=0.0
% INFO    : Bus 88844	: V=1.0112894, theta=24.604905 -> V=1.0, theta=0.0
% INFO    : Bus 88845	: V=1.0113693, theta=20.997475 -> V=1.0, theta=0.0
% INFO    : Bus 88846	: V=1.0069335, theta=20.970251 -> V=1.0, theta=0.0
% INFO    : Bus 88847	: V=1.0124005, theta=17.647915 -> V=1.0, theta=0.0
% INFO    : Bus 88848	: V=1.0162449, theta=1.757055 -> V=1.0, theta=0.0
% INFO    : Bus 88849	: V=1.0156127, theta=1.986074 -> V=1.0, theta=0.0
% INFO    : Bus 88850	: V=1.0157732, theta=5.069941 -> V=1.0, theta=0.0
% INFO    : Bus 88851	: V=1.0092484, theta=4.894457 -> V=1.0, theta=0.0
% INFO    : Bus 88852	: V=1.0138938, theta=21.079595 -> V=1.0, theta=0.0
% INFO    : Bus 88853	: V=1.0157618, theta=20.875452 -> V=1.0, theta=0.0
% INFO    : Bus 88854	: V=1.0134434, theta=24.699982 -> V=1.0, theta=0.0
% INFO    : Bus 88855	: V=1.0149754, theta=10.215019 -> V=1.0, theta=0.0
% INFO    : Bus 88856	: V=1.0017881, theta=8.237054 -> V=1.0, theta=0.0
% INFO    : Bus 88857	: V=1.00007, theta=8.185756 -> V=1.0, theta=0.0
% INFO    : Bus 88858	: V=0.9708585, theta=19.331682 -> V=1.0, theta=0.0
% INFO    : Bus 88859	: V=0.9654766, theta=19.111034 -> V=1.0, theta=0.0
% INFO    : Bus 88860	: V=1.0115752, theta=20.989853 -> V=1.0, theta=0.0
% INFO    : Bus 88861	: V=0.9914254, theta=25.47345 -> V=1.0, theta=0.0
% INFO    : Bus 88862	: V=0.9907009, theta=25.305182 -> V=1.0, theta=0.0
% INFO    : Bus 88863	: V=1.0166697, theta=20.300294 -> V=1.0, theta=0.0
% INFO    : Bus 88864	: V=0.9773909, theta=19.783005 -> V=1.0, theta=0.0
% INFO    : Bus 88865	: V=0.9685206, theta=19.41111 -> V=1.0, theta=0.0
% INFO    : Bus 88866	: V=0.9631364, theta=19.145775 -> V=1.0, theta=0.0
% INFO    : Bus 88867	: V=1.0186404, theta=1.787878 -> V=1.0, theta=0.0
% INFO    : Bus 88868	: V=1.0191588, theta=1.969277 -> V=1.0, theta=0.0
% INFO    : Bus 88869	: V=1.02, theta=26.381159 -> V=1.0, theta=0.0
% INFO    : Bus 88870	: V=1.0181958, theta=33.394982 -> V=1.0, theta=0.0
% INFO    : Bus 88871	: V=1.0178273, theta=21.797485 -> V=1.0, theta=0.0
% INFO    : Bus 88872	: V=1.0162797, theta=22.346625 -> V=1.0, theta=0.0
% INFO    : Bus 88873	: V=0.9960206, theta=26.624506 -> V=1.0, theta=0.0
% INFO    : Bus 88874	: V=0.9954327, theta=26.473816 -> V=1.0, theta=0.0
% INFO    : Bus 88875	: V=1.0134505, theta=19.503538 -> V=1.0, theta=0.0
% INFO    : Bus 88876	: V=1.0109891, theta=19.452653 -> V=1.0, theta=0.0
% INFO    : Bus 88877	: V=1.0072915, theta=20.17757 -> V=1.0, theta=0.0
% INFO    : Bus 88878	: V=0.9981118, theta=20.925478 -> V=1.0, theta=0.0
% INFO    : Bus 88879	: V=0.9978133, theta=20.938649 -> V=1.0, theta=0.0
% INFO    : Bus 88880	: V=1.0125929, theta=-2.776217 -> V=1.0, theta=0.0
% INFO    : Bus 88881	: V=1.0127099, theta=9.925747 -> V=1.0, theta=0.0
% INFO    : Bus 88882	: V=0.981156, theta=19.352265 -> V=1.0, theta=0.0
% INFO    : Bus 88883	: V=0.9795443, theta=19.452339 -> V=1.0, theta=0.0
% INFO    : Bus 88884	: V=1.0170725, theta=29.154945 -> V=1.0, theta=0.0
% INFO    : Bus 88885	: V=1.0134305, theta=19.08212 -> V=1.0, theta=0.0
% INFO    : Bus 88886	: V=1.0165786, theta=25.410074 -> V=1.0, theta=0.0
% INFO    : Bus 88887	: V=1.0145987, theta=25.509628 -> V=1.0, theta=0.0
% INFO    : Bus 88888	: V=1.012801, theta=18.036808 -> V=1.0, theta=0.0
% INFO    : Bus 88889	: V=1.0092413, theta=5.162458 -> V=1.0, theta=0.0
% INFO    : Bus 88890	: V=0.9641237, theta=22.72203 -> V=1.0, theta=0.0
% INFO    : Bus 88891	: V=1.015668, theta=5.7029 -> V=1.0, theta=0.0
% INFO    : Bus 88892	: V=1.0166285, theta=18.204719 -> V=1.0, theta=0.0
% INFO    : Bus 88893	: V=1.0159563, theta=18.319792 -> V=1.0, theta=0.0
% INFO    : Bus 88894	: V=1.0130789, theta=2.232961 -> V=1.0, theta=0.0
% INFO    : Bus 88895	: V=1.0100443, theta=2.123102 -> V=1.0, theta=0.0
% INFO    : Bus 88896	: V=1.0160658, theta=23.372639 -> V=1.0, theta=0.0
% INFO    : Bus 88897	: V=1.0155224, theta=32.053489 -> V=1.0, theta=0.0
% INFO    : Bus 88898	: V=1.0154932, theta=32.017742 -> V=1.0, theta=0.0
% INFO    : Bus 88899	: V=1.0036916, theta=34.088009 -> V=1.0, theta=0.0
% INFO    : Bus 88900	: V=1.0054427, theta=21.479873 -> V=1.0, theta=0.0
% INFO    : Bus 88901	: V=1.0101063, theta=18.568478 -> V=1.0, theta=0.0
% INFO    : Bus 88902	: V=1.0062925, theta=18.421604 -> V=1.0, theta=0.0
% INFO    : Bus 88903	: V=0.9998044, theta=18.699483 -> V=1.0, theta=0.0
% INFO    : Bus 88904	: V=1.000089, theta=18.560689 -> V=1.0, theta=0.0
% INFO    : Bus 88905	: V=1.0154887, theta=13.989872 -> V=1.0, theta=0.0
% INFO    : Bus 88906	: V=0.9827611, theta=22.098583 -> V=1.0, theta=0.0
% INFO    : Bus 88907	: V=0.9815047, theta=22.06006 -> V=1.0, theta=0.0
% INFO    : Bus 88908	: V=1.02, theta=18.139021 -> V=1.0, theta=0.0
% INFO    : Bus 88909	: V=1.0079479, theta=0.312324 -> V=1.0, theta=0.0
% INFO    : Bus 88910	: V=1.0093865, theta=7.490559 -> V=1.0, theta=0.0
% INFO    : Bus 88911	: V=0.9952597, theta=18.275411 -> V=1.0, theta=0.0
% INFO    : Bus 88912	: V=1.02, theta=-3.373298 -> V=1.0, theta=0.0
% INFO    : Bus 88913	: V=1.0166305, theta=-3.27868 -> V=1.0, theta=0.0
% INFO    : Bus 88914	: V=1.016004, theta=-3.301095 -> V=1.0, theta=0.0
% INFO    : Bus 88915	: V=0.9745498, theta=18.866486 -> V=1.0, theta=0.0
% INFO    : Bus 88916	: V=1.02, theta=24.890323 -> V=1.0, theta=0.0
% INFO    : Bus 88917	: V=1.0081159, theta=25.044997 -> V=1.0, theta=0.0
% INFO    : Bus 88918	: V=1.0107344, theta=13.443667 -> V=1.0, theta=0.0
% INFO    : Bus 88919	: V=1.0148829, theta=2.567929 -> V=1.0, theta=0.0
% INFO    : Bus 88920	: V=0.9556212, theta=23.611103 -> V=1.0, theta=0.0
% INFO    : Bus 88921	: V=1.0197704, theta=21.57672 -> V=1.0, theta=0.0
% INFO    : Bus 88922	: V=1.02, theta=22.460627 -> V=1.0, theta=0.0
% INFO    : Bus 88923	: V=1.0158962, theta=28.485787 -> V=1.0, theta=0.0
% INFO    : Bus 88924	: V=1.02, theta=-1.116579 -> V=1.0, theta=0.0
% INFO    : Bus 88925	: V=1.0179673, theta=-1.19999 -> V=1.0, theta=0.0
% INFO    : Bus 88926	: V=1.0161428, theta=18.455271 -> V=1.0, theta=0.0
% INFO    : Bus 88927	: V=1.0139279, theta=18.19194 -> V=1.0, theta=0.0
% INFO    : Bus 88928	: V=1.0136594, theta=18.949855 -> V=1.0, theta=0.0
% INFO    : Bus 88929	: V=1.0005688, theta=0.781748 -> V=1.0, theta=0.0
% INFO    : Bus 88930	: V=0.965037, theta=19.172828 -> V=1.0, theta=0.0
% INFO    : Bus 88931	: V=0.963431, theta=21.860052 -> V=1.0, theta=0.0
% INFO    : Bus 88932	: V=0.9958244, theta=11.556611 -> V=1.0, theta=0.0
% INFO    : Bus 88933	: V=1.0119778, theta=42.102343 -> V=1.0, theta=0.0
% INFO    : Bus 88934	: V=1.0053717, theta=41.157813 -> V=1.0, theta=0.0
% INFO    : Bus 88935	: V=1.0052104, theta=41.042398 -> V=1.0, theta=0.0
% INFO    : Bus 88936	: V=1.0087558, theta=44.792224 -> V=1.0, theta=0.0
% INFO    : Bus 88937	: V=1.0162704, theta=43.885605 -> V=1.0, theta=0.0
% INFO    : Bus 88938	: V=1.0155386, theta=43.80477 -> V=1.0, theta=0.0
% INFO    : Bus 88939	: V=1.0158719, theta=37.354739 -> V=1.0, theta=0.0
% INFO    : Bus 88940	: V=1.0128463, theta=37.530657 -> V=1.0, theta=0.0
% INFO    : Bus 88941	: V=1.0147479, theta=37.270166 -> V=1.0, theta=0.0
% INFO    : Bus 88942	: V=1.0254117, theta=29.712088 -> V=1.0, theta=0.0
% INFO    : Bus 88943	: V=1.0280237, theta=29.504039 -> V=1.0, theta=0.0
% INFO    : Bus 88944	: V=1.0134153, theta=42.49257 -> V=1.0, theta=0.0
% INFO    : Bus 88945	: V=1.021285, theta=24.106544 -> V=1.0, theta=0.0
% INFO    : Bus 88946	: V=0.9886318, theta=41.779031 -> V=1.0, theta=0.0
% INFO    : Bus 88947	: V=0.9834779, theta=41.625062 -> V=1.0, theta=0.0
% INFO    : Bus 88948	: V=0.9900282, theta=41.359581 -> V=1.0, theta=0.0
% INFO    : Bus 88949	: V=1.0110649, theta=42.937089 -> V=1.0, theta=0.0
% INFO    : Bus 88950	: V=1.0011775, theta=42.419846 -> V=1.0, theta=0.0
% INFO    : Bus 88951	: V=0.9971199, theta=42.357539 -> V=1.0, theta=0.0
% INFO    : Bus 88952	: V=1.0213092, theta=31.578643 -> V=1.0, theta=0.0
% INFO    : Bus 88953	: V=1.0199521, theta=41.403692 -> V=1.0, theta=0.0
% INFO    : Bus 88954	: V=1.0203671, theta=41.178852 -> V=1.0, theta=0.0
% INFO    : Bus 88955	: V=1.02, theta=20.944063 -> V=1.0, theta=0.0
% INFO    : Bus 88956	: V=1.0187595, theta=33.573172 -> V=1.0, theta=0.0
% INFO    : Bus 88957	: V=1.0168978, theta=24.7028 -> V=1.0, theta=0.0
% INFO    : Bus 88958	: V=1.02, theta=41.164762 -> V=1.0, theta=0.0
% INFO    : Bus 88959	: V=1.0201015, theta=41.184505 -> V=1.0, theta=0.0
% INFO    : Bus 88960	: V=1.0210883, theta=40.50019 -> V=1.0, theta=0.0
% INFO    : Bus 88961	: V=1.0152398, theta=41.814603 -> V=1.0, theta=0.0
% INFO    : Bus 88962	: V=1.015936, theta=40.086826 -> V=1.0, theta=0.0
% INFO    : Bus 88963	: V=1.0199225, theta=34.106306 -> V=1.0, theta=0.0
% INFO    : Bus 88964	: V=1.02, theta=27.293366 -> V=1.0, theta=0.0
% INFO    : Bus 88965	: V=1.0165909, theta=43.193044 -> V=1.0, theta=0.0
% INFO    : Bus 88966	: V=1.0160005, theta=42.067586 -> V=1.0, theta=0.0
% INFO    : Bus 88967	: V=1.0152739, theta=44.017692 -> V=1.0, theta=0.0
% INFO    : Bus 88968	: V=0.9912221, theta=39.804401 -> V=1.0, theta=0.0
% INFO    : Bus 88969	: V=1.02, theta=37.578796 -> V=1.0, theta=0.0
% INFO    : Bus 88970	: V=0.9991716, theta=23.521199 -> V=1.0, theta=0.0
% INFO    : Bus 88971	: V=0.9897397, theta=39.36421 -> V=1.0, theta=0.0
% INFO    : Bus 88972	: V=1.02, theta=46.494026 -> V=1.0, theta=0.0
% INFO    : Bus 88973	: V=1.0197214, theta=46.392661 -> V=1.0, theta=0.0
% INFO    : Bus 88974	: V=0.9885569, theta=40.640464 -> V=1.0, theta=0.0
% INFO    : Bus 88975	: V=1.0144833, theta=17.102163 -> V=1.0, theta=0.0
% INFO    : Bus 88976	: V=1.0123135, theta=29.800243 -> V=1.0, theta=0.0
% INFO    : Bus 88977	: V=1.02, theta=48.14415 -> V=1.0, theta=0.0
% INFO    : Bus 88978	: V=1.0196666, theta=48.062886 -> V=1.0, theta=0.0
% INFO    : Bus 88979	: V=1.0010857, theta=41.593078 -> V=1.0, theta=0.0
% INFO    : Bus 88980	: V=1.02, theta=43.935661 -> V=1.0, theta=0.0
% INFO    : Bus 88981	: V=1.02, theta=41.948652 -> V=1.0, theta=0.0
% INFO    : Bus 88982	: V=1.0172491, theta=40.78619 -> V=1.0, theta=0.0
% INFO    : Bus 88983	: V=1.0147644, theta=43.98625 -> V=1.0, theta=0.0
% INFO    : Bus 88984	: V=1.02, theta=33.472699 -> V=1.0, theta=0.0
% INFO    : Bus 88985	: V=1.02, theta=45.036626 -> V=1.0, theta=0.0
% INFO    : Bus 88986	: V=0.9919994, theta=40.481877 -> V=1.0, theta=0.0
% INFO    : Bus 88987	: V=0.985516, theta=18.210106 -> V=1.0, theta=0.0
% INFO    : Bus 88988	: V=1.0153127, theta=30.131381 -> V=1.0, theta=0.0
% INFO    : Bus 88989	: V=1.0141229, theta=29.967946 -> V=1.0, theta=0.0
% INFO    : Bus 88990	: V=1.0199461, theta=55.704571 -> V=1.0, theta=0.0
% INFO    : Bus 88991	: V=1.0048047, theta=27.66574 -> V=1.0, theta=0.0
% INFO    : Bus 88992	: V=1.0037171, theta=27.697647 -> V=1.0, theta=0.0
% INFO    : Bus 88993	: V=1.0035894, theta=27.672248 -> V=1.0, theta=0.0
% INFO    : Bus 88994	: V=1.0190105, theta=43.597733 -> V=1.0, theta=0.0
% INFO    : Bus 88995	: V=1.0182941, theta=43.536468 -> V=1.0, theta=0.0
% INFO    : Bus 88996	: V=1.0152313, theta=41.792048 -> V=1.0, theta=0.0
% INFO    : Bus 88997	: V=1.0151096, theta=30.094481 -> V=1.0, theta=0.0
% INFO    : Bus 88998	: V=1.0199362, theta=34.824562 -> V=1.0, theta=0.0
% INFO    : Bus 88999	: V=1.0163651, theta=34.882655 -> V=1.0, theta=0.0
% INFO    : Bus 89000	: V=1.0147748, theta=53.372535 -> V=1.0, theta=0.0
% INFO    : Bus 89001	: V=1.015903, theta=36.669778 -> V=1.0, theta=0.0
% INFO    : Bus 89002	: V=0.9967582, theta=49.860311 -> V=1.0, theta=0.0
% INFO    : Bus 89003	: V=1.0189773, theta=43.610856 -> V=1.0, theta=0.0
% INFO    : Bus 89004	: V=1.0183376, theta=43.556743 -> V=1.0, theta=0.0
% INFO    : Bus 89005	: V=1.0104996, theta=34.977885 -> V=1.0, theta=0.0
% INFO    : Bus 89006	: V=1.0129776, theta=36.881042 -> V=1.0, theta=0.0
% INFO    : Bus 89007	: V=1.0104535, theta=36.786337 -> V=1.0, theta=0.0
% INFO    : Bus 89008	: V=1.0158412, theta=32.947826 -> V=1.0, theta=0.0
% INFO    : Bus 89009	: V=1.0148159, theta=32.842509 -> V=1.0, theta=0.0
% INFO    : Bus 89010	: V=1.0170785, theta=39.109062 -> V=1.0, theta=0.0
% INFO    : Bus 89011	: V=1.0091121, theta=30.502715 -> V=1.0, theta=0.0
% INFO    : Bus 89012	: V=1.0195704, theta=53.41154 -> V=1.0, theta=0.0
% INFO    : Bus 89013	: V=1.0153728, theta=53.30158 -> V=1.0, theta=0.0
% INFO    : Bus 89014	: V=1.0167351, theta=35.251762 -> V=1.0, theta=0.0
% INFO    : Bus 89015	: V=1.0156806, theta=35.340389 -> V=1.0, theta=0.0
% INFO    : Bus 89016	: V=0.9976338, theta=28.73765 -> V=1.0, theta=0.0
% INFO    : Bus 89017	: V=1.015187, theta=32.398598 -> V=1.0, theta=0.0
% INFO    : Bus 89018	: V=1.0169983, theta=56.704048 -> V=1.0, theta=0.0
% INFO    : Bus 89019	: V=1.011841, theta=36.276951 -> V=1.0, theta=0.0
% INFO    : Bus 89020	: V=1.0103623, theta=36.232894 -> V=1.0, theta=0.0
% INFO    : Bus 89021	: V=1.02, theta=53.028659 -> V=1.0, theta=0.0
% INFO    : Bus 89022	: V=1.02, theta=55.894142 -> V=1.0, theta=0.0
% INFO    : Bus 89023	: V=1.02, theta=53.290735 -> V=1.0, theta=0.0
% INFO    : Bus 89024	: V=1.0093045, theta=50.682916 -> V=1.0, theta=0.0
% INFO    : Bus 89025	: V=1.0146935, theta=45.010583 -> V=1.0, theta=0.0
% INFO    : Bus 89026	: V=1.0169697, theta=56.705515 -> V=1.0, theta=0.0
% INFO    : Bus 89027	: V=1.02, theta=44.897957 -> V=1.0, theta=0.0
% INFO    : Bus 89028	: V=1.0124405, theta=34.419316 -> V=1.0, theta=0.0
% INFO    : Bus 89029	: V=1.0120988, theta=34.454832 -> V=1.0, theta=0.0
% INFO    : Bus 89030	: V=1.0074179, theta=45.289563 -> V=1.0, theta=0.0
% INFO    : Bus 89031	: V=1.0084794, theta=30.42205 -> V=1.0, theta=0.0
% INFO    : Bus 89032	: V=1.02, theta=50.996933 -> V=1.0, theta=0.0
% INFO    : Bus 89033	: V=1.0076014, theta=35.726894 -> V=1.0, theta=0.0
% INFO    : Bus 89034	: V=1.0139178, theta=34.094754 -> V=1.0, theta=0.0
% INFO    : Bus 89035	: V=0.9988187, theta=35.801546 -> V=1.0, theta=0.0
% INFO    : Bus 89036	: V=0.9983713, theta=11.629353 -> V=1.0, theta=0.0
% INFO    : Bus 89037	: V=0.9944586, theta=11.510604 -> V=1.0, theta=0.0
% INFO    : Bus 89038	: V=0.9862919, theta=11.886029 -> V=1.0, theta=0.0
% INFO    : Bus 89039	: V=0.9860459, theta=31.240287 -> V=1.0, theta=0.0
% INFO    : Bus 89040	: V=0.9982662, theta=31.302777 -> V=1.0, theta=0.0
% INFO    : Bus 89041	: V=0.9909261, theta=30.772079 -> V=1.0, theta=0.0
% INFO    : Bus 89042	: V=1.0057656, theta=30.227358 -> V=1.0, theta=0.0
% INFO    : Bus 89043	: V=1.0079492, theta=28.875718 -> V=1.0, theta=0.0
% INFO    : Bus 89044	: V=1.0096397, theta=28.275752 -> V=1.0, theta=0.0
% INFO    : Bus 89045	: V=1.0065922, theta=27.30382 -> V=1.0, theta=0.0
% INFO    : Bus 89046	: V=1.0115929, theta=28.789265 -> V=1.0, theta=0.0
% INFO    : Bus 89047	: V=1.0022828, theta=33.222724 -> V=1.0, theta=0.0
% INFO    : Bus 89048	: V=0.999162, theta=33.023253 -> V=1.0, theta=0.0
% INFO    : Bus 89049	: V=1.0118945, theta=33.276133 -> V=1.0, theta=0.0
% INFO    : Bus 89050	: V=0.9823012, theta=16.056928 -> V=1.0, theta=0.0
% INFO    : Bus 89051	: V=0.9815023, theta=15.645736 -> V=1.0, theta=0.0
% INFO    : Bus 89052	: V=0.9962619, theta=14.91172 -> V=1.0, theta=0.0
% INFO    : Bus 89053	: V=0.9964254, theta=14.736547 -> V=1.0, theta=0.0
% INFO    : Bus 89054	: V=0.9946119, theta=14.726568 -> V=1.0, theta=0.0
% INFO    : Bus 89055	: V=0.9948483, theta=14.573746 -> V=1.0, theta=0.0
% INFO    : Bus 89056	: V=0.9947072, theta=14.537222 -> V=1.0, theta=0.0
% INFO    : Bus 89057	: V=1.0003237, theta=14.810266 -> V=1.0, theta=0.0
% INFO    : Bus 89058	: V=0.9967071, theta=14.709045 -> V=1.0, theta=0.0
% INFO    : Bus 89059	: V=0.9917388, theta=14.643065 -> V=1.0, theta=0.0
% INFO    : Bus 89060	: V=0.9939414, theta=15.31596 -> V=1.0, theta=0.0
% INFO    : Bus 89061	: V=0.9977118, theta=16.750914 -> V=1.0, theta=0.0
% INFO    : Bus 89062	: V=1.0012856, theta=15.031256 -> V=1.0, theta=0.0
% INFO    : Bus 89063	: V=0.9953406, theta=14.569346 -> V=1.0, theta=0.0
% INFO    : Bus 89064	: V=0.9799814, theta=11.545068 -> V=1.0, theta=0.0
% INFO    : Bus 89065	: V=1.0147784, theta=17.946142 -> V=1.0, theta=0.0
% INFO    : Bus 89066	: V=0.9942683, theta=14.617243 -> V=1.0, theta=0.0
% INFO    : Bus 89067	: V=0.9649763, theta=5.387253 -> V=1.0, theta=0.0
% INFO    : Bus 89068	: V=0.9642683, theta=4.580326 -> V=1.0, theta=0.0
% INFO    : Bus 89069	: V=0.9744403, theta=5.815088 -> V=1.0, theta=0.0
% INFO    : Bus 89070	: V=1.0174919, theta=6.535151 -> V=1.0, theta=0.0
% INFO    : Bus 89071	: V=1.0172631, theta=7.032738 -> V=1.0, theta=0.0
% INFO    : Bus 89072	: V=1.0044821, theta=3.727666 -> V=1.0, theta=0.0
% INFO    : Bus 89073	: V=0.9876256, theta=3.565956 -> V=1.0, theta=0.0
% INFO    : Bus 89074	: V=0.9855832, theta=2.609432 -> V=1.0, theta=0.0
% INFO    : Bus 89075	: V=0.9936817, theta=1.541055 -> V=1.0, theta=0.0
% INFO    : Bus 89076	: V=0.9627827, theta=7.07971 -> V=1.0, theta=0.0
% INFO    : Bus 89077	: V=0.9719237, theta=7.585317 -> V=1.0, theta=0.0
% INFO    : Bus 89078	: V=0.964966, theta=6.930158 -> V=1.0, theta=0.0
% INFO    : Bus 89079	: V=0.9567108, theta=19.122505 -> V=1.0, theta=0.0
% INFO    : Bus 89080	: V=0.9567399, theta=19.226398 -> V=1.0, theta=0.0
% INFO    : Bus 89081	: V=0.9572908, theta=19.246858 -> V=1.0, theta=0.0
% INFO    : Bus 89082	: V=0.9567228, theta=19.144428 -> V=1.0, theta=0.0
% INFO    : Bus 89083	: V=0.9569001, theta=19.121268 -> V=1.0, theta=0.0
% INFO    : Bus 89084	: V=0.9561101, theta=19.135333 -> V=1.0, theta=0.0
% INFO    : Bus 89085	: V=0.9560866, theta=19.129759 -> V=1.0, theta=0.0
% INFO    : Bus 89086	: V=0.9560437, theta=19.171459 -> V=1.0, theta=0.0
% INFO    : Bus 89087	: V=0.9569118, theta=19.078447 -> V=1.0, theta=0.0
% INFO    : Bus 89088	: V=0.9591636, theta=19.120246 -> V=1.0, theta=0.0
% INFO    : Bus 89089	: V=0.9551104, theta=19.402297 -> V=1.0, theta=0.0
% INFO    : Bus 89090	: V=0.9549356, theta=19.42125 -> V=1.0, theta=0.0
% INFO    : Bus 89091	: V=0.9552177, theta=19.346084 -> V=1.0, theta=0.0
% INFO    : Bus 89092	: V=0.956463, theta=19.246517 -> V=1.0, theta=0.0
% INFO    : Bus 89093	: V=0.9512187, theta=19.610032 -> V=1.0, theta=0.0
% INFO    : Bus 89094	: V=0.9536443, theta=19.393118 -> V=1.0, theta=0.0
% INFO    : Bus 89095	: V=0.9554322, theta=19.339223 -> V=1.0, theta=0.0
% INFO    : Bus 89096	: V=0.9568402, theta=19.241639 -> V=1.0, theta=0.0
% INFO    : Bus 89097	: V=0.9555816, theta=19.339171 -> V=1.0, theta=0.0
% INFO    : Bus 89098	: V=0.9541636, theta=19.357785 -> V=1.0, theta=0.0
% INFO    : Bus 89099	: V=0.9541796, theta=19.343431 -> V=1.0, theta=0.0
% INFO    : Bus 89100	: V=0.952151, theta=19.479846 -> V=1.0, theta=0.0
% INFO    : Bus 89101	: V=0.9540107, theta=19.346603 -> V=1.0, theta=0.0
% INFO    : Bus 89102	: V=0.9608287, theta=19.481012 -> V=1.0, theta=0.0
% INFO    : Bus 89103	: V=0.9575877, theta=19.350219 -> V=1.0, theta=0.0
% INFO    : Bus 89104	: V=0.9565929, theta=19.230877 -> V=1.0, theta=0.0
% INFO    : Bus 89105	: V=0.956474, theta=19.258245 -> V=1.0, theta=0.0
% INFO    : Bus 89106	: V=0.9571421, theta=19.312225 -> V=1.0, theta=0.0
% INFO    : Bus 89107	: V=0.9569721, theta=19.299819 -> V=1.0, theta=0.0
% INFO    : Bus 89108	: V=0.9573327, theta=19.272894 -> V=1.0, theta=0.0
% INFO    : Bus 89109	: V=0.9571554, theta=19.304597 -> V=1.0, theta=0.0
% INFO    : Bus 89110	: V=0.956468, theta=19.365275 -> V=1.0, theta=0.0
% INFO    : Bus 89111	: V=0.957276, theta=19.279705 -> V=1.0, theta=0.0
% INFO    : Bus 89112	: V=0.9570341, theta=19.343408 -> V=1.0, theta=0.0
% INFO    : Bus 89113	: V=0.9566684, theta=19.216687 -> V=1.0, theta=0.0
% INFO    : Bus 89114	: V=0.9569439, theta=19.18685 -> V=1.0, theta=0.0
% INFO    : Bus 89115	: V=0.9569514, theta=19.207397 -> V=1.0, theta=0.0
% INFO    : Bus 89116	: V=0.9544268, theta=19.411371 -> V=1.0, theta=0.0
% INFO    : Bus 89117	: V=0.9564718, theta=19.50838 -> V=1.0, theta=0.0
% INFO    : Bus 89118	: V=0.9563688, theta=19.419795 -> V=1.0, theta=0.0
% INFO    : Bus 89119	: V=0.9555308, theta=19.414839 -> V=1.0, theta=0.0
% INFO    : Bus 89120	: V=0.9575281, theta=19.287637 -> V=1.0, theta=0.0
% INFO    : Bus 89121	: V=0.9567213, theta=19.441192 -> V=1.0, theta=0.0
% INFO    : Bus 89122	: V=0.9575829, theta=19.362421 -> V=1.0, theta=0.0
% INFO    : Bus 89123	: V=0.9597925, theta=19.409653 -> V=1.0, theta=0.0
% INFO    : Bus 89124	: V=0.958229, theta=19.276196 -> V=1.0, theta=0.0
% INFO    : Bus 89125	: V=0.9592467, theta=19.239643 -> V=1.0, theta=0.0
% INFO    : Bus 89126	: V=0.9595156, theta=19.242101 -> V=1.0, theta=0.0
% INFO    : Bus 89127	: V=0.9600131, theta=19.220215 -> V=1.0, theta=0.0
% INFO    : Bus 89128	: V=0.9603908, theta=19.172678 -> V=1.0, theta=0.0
% INFO    : Bus 89129	: V=0.9623512, theta=19.231753 -> V=1.0, theta=0.0
% INFO    : Bus 89130	: V=0.9625557, theta=19.216509 -> V=1.0, theta=0.0
% INFO    : Bus 89131	: V=0.9648249, theta=19.114322 -> V=1.0, theta=0.0
% INFO    : Bus 89132	: V=0.9582453, theta=19.101005 -> V=1.0, theta=0.0
% INFO    : Bus 89133	: V=0.9626813, theta=18.838805 -> V=1.0, theta=0.0
% INFO    : Bus 89134	: V=0.9715071, theta=18.83999 -> V=1.0, theta=0.0
% INFO    : Bus 89135	: V=0.966525, theta=18.783695 -> V=1.0, theta=0.0
% INFO    : Bus 89136	: V=0.9664518, theta=18.792454 -> V=1.0, theta=0.0
% INFO    : Bus 89137	: V=0.9712042, theta=18.827315 -> V=1.0, theta=0.0
% INFO    : Bus 89138	: V=0.9696336, theta=18.781544 -> V=1.0, theta=0.0
% INFO    : Bus 89139	: V=0.9639394, theta=18.722059 -> V=1.0, theta=0.0
% INFO    : Bus 89140	: V=0.9683841, theta=18.778929 -> V=1.0, theta=0.0
% INFO    : Bus 89141	: V=0.9708812, theta=18.792615 -> V=1.0, theta=0.0
% INFO    : Bus 89142	: V=0.9646745, theta=18.48241 -> V=1.0, theta=0.0
% INFO    : Bus 89143	: V=0.9725258, theta=18.840207 -> V=1.0, theta=0.0
% INFO    : Bus 89144	: V=0.9691716, theta=18.757563 -> V=1.0, theta=0.0
% INFO    : Bus 89145	: V=0.9744698, theta=18.884678 -> V=1.0, theta=0.0
% INFO    : Bus 89146	: V=0.9666649, theta=18.357068 -> V=1.0, theta=0.0
% INFO    : Bus 89147	: V=0.9671782, theta=18.46016 -> V=1.0, theta=0.0
% INFO    : Bus 89148	: V=0.9748918, theta=18.861103 -> V=1.0, theta=0.0
% INFO    : Bus 89149	: V=0.9668913, theta=18.95883 -> V=1.0, theta=0.0
% INFO    : Bus 89150	: V=0.9753078, theta=19.333397 -> V=1.0, theta=0.0
% INFO    : Bus 89151	: V=0.9619119, theta=19.057694 -> V=1.0, theta=0.0
% INFO    : Bus 89152	: V=0.9627426, theta=18.935738 -> V=1.0, theta=0.0
% INFO    : Bus 89153	: V=0.9591185, theta=19.010159 -> V=1.0, theta=0.0
% INFO    : Bus 89154	: V=0.964486, theta=19.069197 -> V=1.0, theta=0.0
% INFO    : Bus 89155	: V=0.9632057, theta=18.898912 -> V=1.0, theta=0.0
% INFO    : Bus 89156	: V=0.9657425, theta=18.849232 -> V=1.0, theta=0.0
% INFO    : Bus 89157	: V=0.9612654, theta=18.920495 -> V=1.0, theta=0.0
% INFO    : Bus 89158	: V=0.9628726, theta=18.828068 -> V=1.0, theta=0.0
% INFO    : Bus 89159	: V=0.9757572, theta=19.2627 -> V=1.0, theta=0.0
% INFO    : Bus 89160	: V=0.9609462, theta=19.371828 -> V=1.0, theta=0.0
% INFO    : Bus 89161	: V=0.9661374, theta=18.841025 -> V=1.0, theta=0.0
% INFO    : Bus 89162	: V=0.9659117, theta=18.825693 -> V=1.0, theta=0.0
% INFO    : Bus 89163	: V=0.9700235, theta=18.923016 -> V=1.0, theta=0.0
% INFO    : Bus 89164	: V=0.9655977, theta=18.731523 -> V=1.0, theta=0.0
% INFO    : Bus 89165	: V=0.964099, theta=18.789054 -> V=1.0, theta=0.0
% INFO    : Bus 89166	: V=0.9622979, theta=18.8227 -> V=1.0, theta=0.0
% INFO    : Bus 89167	: V=0.9621236, theta=18.767768 -> V=1.0, theta=0.0
% INFO    : Bus 89168	: V=0.9606014, theta=18.867757 -> V=1.0, theta=0.0
% INFO    : Bus 89169	: V=0.9634828, theta=18.740204 -> V=1.0, theta=0.0
% INFO    : Bus 89170	: V=0.9616437, theta=18.707241 -> V=1.0, theta=0.0
% INFO    : Bus 89171	: V=0.9607867, theta=18.611673 -> V=1.0, theta=0.0
% INFO    : Bus 89172	: V=0.9633396, theta=18.467857 -> V=1.0, theta=0.0
% INFO    : Bus 89173	: V=0.9621283, theta=18.301371 -> V=1.0, theta=0.0
% INFO    : Bus 89174	: V=0.9673353, theta=18.360056 -> V=1.0, theta=0.0
% INFO    : Bus 89175	: V=0.961708, theta=21.564938 -> V=1.0, theta=0.0
% INFO    : Bus 89176	: V=0.9570626, theta=21.189639 -> V=1.0, theta=0.0
% INFO    : Bus 89177	: V=0.9749561, theta=21.404671 -> V=1.0, theta=0.0
% INFO    : Bus 89178	: V=0.9673986, theta=21.135193 -> V=1.0, theta=0.0
% INFO    : Bus 89179	: V=0.9491116, theta=19.954128 -> V=1.0, theta=0.0
% INFO    : Bus 89180	: V=0.9505122, theta=19.810683 -> V=1.0, theta=0.0
% INFO    : Bus 89181	: V=0.9654681, theta=21.85418 -> V=1.0, theta=0.0
% INFO    : Bus 89182	: V=0.9650978, theta=22.166829 -> V=1.0, theta=0.0
% INFO    : Bus 89183	: V=0.967805, theta=22.25828 -> V=1.0, theta=0.0
% INFO    : Bus 89184	: V=0.9591927, theta=22.072384 -> V=1.0, theta=0.0
% INFO    : Bus 89185	: V=0.9666806, theta=21.994836 -> V=1.0, theta=0.0
% INFO    : Bus 89186	: V=0.9602176, theta=21.727317 -> V=1.0, theta=0.0
% INFO    : Bus 89187	: V=0.955067, theta=21.4474 -> V=1.0, theta=0.0
% INFO    : Bus 89188	: V=0.9556011, theta=22.848644 -> V=1.0, theta=0.0
% INFO    : Bus 89189	: V=0.9519422, theta=22.395931 -> V=1.0, theta=0.0
% INFO    : Bus 89190	: V=0.9561144, theta=23.746343 -> V=1.0, theta=0.0
% INFO    : Bus 89191	: V=0.9521097, theta=22.067681 -> V=1.0, theta=0.0
% INFO    : Bus 89192	: V=0.9547653, theta=22.402191 -> V=1.0, theta=0.0
% INFO    : Bus 89193	: V=0.9556889, theta=22.765897 -> V=1.0, theta=0.0
% INFO    : Bus 89194	: V=0.9594411, theta=22.126452 -> V=1.0, theta=0.0
% INFO    : Bus 89195	: V=0.9601036, theta=22.434172 -> V=1.0, theta=0.0
% INFO    : Bus 89196	: V=0.9528893, theta=23.138489 -> V=1.0, theta=0.0
% INFO    : Bus 89197	: V=0.9597656, theta=22.047056 -> V=1.0, theta=0.0
% INFO    : Bus 89198	: V=0.9618814, theta=22.044044 -> V=1.0, theta=0.0
% INFO    : Bus 89199	: V=0.9644716, theta=22.56225 -> V=1.0, theta=0.0
% INFO    : Bus 89200	: V=0.9596814, theta=22.067037 -> V=1.0, theta=0.0
% INFO    : Bus 89201	: V=0.9599862, theta=22.006704 -> V=1.0, theta=0.0
% INFO    : Bus 89202	: V=0.9736902, theta=22.128931 -> V=1.0, theta=0.0
% INFO    : Bus 89203	: V=0.9612664, theta=22.135825 -> V=1.0, theta=0.0
% INFO    : Bus 89204	: V=0.9563556, theta=22.257016 -> V=1.0, theta=0.0
% INFO    : Bus 89205	: V=0.957962, theta=21.955727 -> V=1.0, theta=0.0
% INFO    : Bus 89206	: V=0.9593507, theta=22.034436 -> V=1.0, theta=0.0
% INFO    : Bus 89207	: V=0.9595215, theta=22.13702 -> V=1.0, theta=0.0
% INFO    : Bus 89208	: V=0.9596372, theta=22.065156 -> V=1.0, theta=0.0
% INFO    : Bus 89209	: V=0.9586908, theta=22.015577 -> V=1.0, theta=0.0
% INFO    : Bus 89210	: V=0.9586714, theta=22.031847 -> V=1.0, theta=0.0
% INFO    : Bus 89211	: V=0.9590936, theta=21.801913 -> V=1.0, theta=0.0
% INFO    : Bus 89212	: V=0.9597043, theta=22.036395 -> V=1.0, theta=0.0
% INFO    : Bus 89213	: V=0.9592976, theta=22.040393 -> V=1.0, theta=0.0
% INFO    : Bus 89214	: V=0.9590578, theta=21.860329 -> V=1.0, theta=0.0
% INFO    : Bus 89215	: V=0.9584474, theta=21.85837 -> V=1.0, theta=0.0
% INFO    : Bus 89216	: V=0.9549424, theta=21.187363 -> V=1.0, theta=0.0
% INFO    : Bus 89217	: V=0.9535863, theta=22.059356 -> V=1.0, theta=0.0
% INFO    : Bus 89218	: V=0.9654122, theta=21.180334 -> V=1.0, theta=0.0
% INFO    : Bus 89219	: V=0.9572196, theta=21.141909 -> V=1.0, theta=0.0
% INFO    : Bus 89220	: V=0.9576612, theta=21.085958 -> V=1.0, theta=0.0
% INFO    : Bus 89221	: V=0.9558434, theta=20.602599 -> V=1.0, theta=0.0
% INFO    : Bus 89222	: V=0.9576848, theta=20.502246 -> V=1.0, theta=0.0
% INFO    : Bus 89223	: V=0.9558639, theta=20.942871 -> V=1.0, theta=0.0
% INFO    : Bus 89224	: V=0.9564424, theta=20.788147 -> V=1.0, theta=0.0
% INFO    : Bus 89225	: V=0.9571818, theta=20.726977 -> V=1.0, theta=0.0
% INFO    : Bus 89226	: V=0.9563035, theta=20.660763 -> V=1.0, theta=0.0
% INFO    : Bus 89227	: V=0.9559487, theta=20.567393 -> V=1.0, theta=0.0
% INFO    : Bus 89228	: V=0.9601965, theta=19.933849 -> V=1.0, theta=0.0
% INFO    : Bus 89229	: V=0.9607313, theta=19.914578 -> V=1.0, theta=0.0
% INFO    : Bus 89230	: V=0.9642672, theta=20.077504 -> V=1.0, theta=0.0
% INFO    : Bus 89231	: V=0.9625883, theta=19.968802 -> V=1.0, theta=0.0
% INFO    : Bus 89232	: V=0.9587243, theta=19.760641 -> V=1.0, theta=0.0
% INFO    : Bus 89233	: V=0.9587537, theta=19.351106 -> V=1.0, theta=0.0
% INFO    : Bus 89234	: V=0.9637229, theta=20.209188 -> V=1.0, theta=0.0
% INFO    : Bus 89235	: V=0.9534708, theta=19.961917 -> V=1.0, theta=0.0
% INFO    : Bus 89236	: V=0.9645888, theta=20.39246 -> V=1.0, theta=0.0
% INFO    : Bus 89237	: V=0.9591105, theta=20.232217 -> V=1.0, theta=0.0
% INFO    : Bus 89238	: V=0.9600278, theta=20.258709 -> V=1.0, theta=0.0
% INFO    : Bus 89239	: V=0.9591534, theta=19.389593 -> V=1.0, theta=0.0
% INFO    : Bus 89240	: V=0.9599258, theta=19.507223 -> V=1.0, theta=0.0
% INFO    : Bus 89241	: V=0.9501582, theta=19.762625 -> V=1.0, theta=0.0
% INFO    : Bus 89242	: V=0.9506869, theta=19.673654 -> V=1.0, theta=0.0
% INFO    : Bus 89243	: V=0.9544465, theta=19.703264 -> V=1.0, theta=0.0
% INFO    : Bus 89244	: V=0.9524517, theta=19.699691 -> V=1.0, theta=0.0
% INFO    : Bus 89245	: V=0.9561229, theta=19.592834 -> V=1.0, theta=0.0
% INFO    : Bus 89246	: V=0.9598748, theta=20.171358 -> V=1.0, theta=0.0
% INFO    : Bus 89247	: V=0.9637172, theta=20.005683 -> V=1.0, theta=0.0
% INFO    : Bus 89248	: V=0.9747269, theta=20.830822 -> V=1.0, theta=0.0
% INFO    : Bus 89249	: V=0.9632834, theta=20.406421 -> V=1.0, theta=0.0
% INFO    : Bus 89250	: V=0.9613367, theta=20.378277 -> V=1.0, theta=0.0
% INFO    : Bus 89251	: V=0.957239, theta=19.517278 -> V=1.0, theta=0.0
% INFO    : Bus 89252	: V=0.9575227, theta=19.515833 -> V=1.0, theta=0.0
% INFO    : Bus 89253	: V=0.9577417, theta=19.455352 -> V=1.0, theta=0.0
% INFO    : Bus 89254	: V=0.9574214, theta=19.487106 -> V=1.0, theta=0.0
% INFO    : Bus 89255	: V=0.958876, theta=19.459194 -> V=1.0, theta=0.0
% INFO    : Bus 89256	: V=0.959133, theta=19.410963 -> V=1.0, theta=0.0
% INFO    : Bus 89257	: V=0.9598967, theta=19.326137 -> V=1.0, theta=0.0
% INFO    : Bus 89258	: V=0.9601676, theta=19.353649 -> V=1.0, theta=0.0
% INFO    : Bus 89259	: V=0.9599402, theta=19.353755 -> V=1.0, theta=0.0
% INFO    : Bus 89260	: V=0.962061, theta=19.333029 -> V=1.0, theta=0.0
% INFO    : Bus 89261	: V=0.962409, theta=19.262392 -> V=1.0, theta=0.0
% INFO    : Bus 89262	: V=0.968812, theta=19.476347 -> V=1.0, theta=0.0
% INFO    : Bus 89263	: V=0.9646264, theta=19.361348 -> V=1.0, theta=0.0
% INFO    : Bus 89264	: V=0.9635293, theta=19.265388 -> V=1.0, theta=0.0
% INFO    : Bus 89265	: V=0.9618989, theta=19.338412 -> V=1.0, theta=0.0
% INFO    : Bus 89266	: V=0.9603542, theta=19.407561 -> V=1.0, theta=0.0
% INFO    : Bus 89267	: V=0.9602339, theta=19.388503 -> V=1.0, theta=0.0
% INFO    : Bus 89268	: V=0.9617756, theta=19.357048 -> V=1.0, theta=0.0
% INFO    : Bus 89269	: V=0.9612995, theta=19.508666 -> V=1.0, theta=0.0
% INFO    : Bus 89270	: V=0.9586784, theta=19.523398 -> V=1.0, theta=0.0
% INFO    : Bus 89271	: V=0.9573453, theta=19.803741 -> V=1.0, theta=0.0
% INFO    : Bus 89272	: V=0.9588891, theta=19.976761 -> V=1.0, theta=0.0
% INFO    : Bus 89273	: V=0.9599056, theta=20.131621 -> V=1.0, theta=0.0
% INFO    : Bus 89274	: V=0.9581332, theta=19.865181 -> V=1.0, theta=0.0
% INFO    : Bus 89275	: V=0.9579201, theta=19.737918 -> V=1.0, theta=0.0
% INFO    : Bus 89276	: V=0.9582002, theta=19.718488 -> V=1.0, theta=0.0
% INFO    : Bus 89277	: V=0.966007, theta=19.967152 -> V=1.0, theta=0.0
% INFO    : Bus 89278	: V=0.9642966, theta=19.915895 -> V=1.0, theta=0.0
% INFO    : Bus 89279	: V=0.9637365, theta=19.942972 -> V=1.0, theta=0.0
% INFO    : Bus 89280	: V=0.9636812, theta=20.116955 -> V=1.0, theta=0.0
% INFO    : Bus 89281	: V=0.9629668, theta=19.817919 -> V=1.0, theta=0.0
% INFO    : Bus 89282	: V=0.9634024, theta=19.577883 -> V=1.0, theta=0.0
% INFO    : Bus 89283	: V=0.9631811, theta=19.662905 -> V=1.0, theta=0.0
% INFO    : Bus 89284	: V=0.9633486, theta=19.716017 -> V=1.0, theta=0.0
% INFO    : Bus 89285	: V=0.9634624, theta=19.719217 -> V=1.0, theta=0.0
% INFO    : Bus 89286	: V=0.9673487, theta=20.116279 -> V=1.0, theta=0.0
% INFO    : Bus 89287	: V=0.9701923, theta=20.132439 -> V=1.0, theta=0.0
% INFO    : Bus 89288	: V=0.962866, theta=19.704042 -> V=1.0, theta=0.0
% INFO    : Bus 89289	: V=0.9819157, theta=19.865346 -> V=1.0, theta=0.0
% INFO    : Bus 89290	: V=0.9744971, theta=19.791316 -> V=1.0, theta=0.0
% INFO    : Bus 89291	: V=0.9731123, theta=19.79151 -> V=1.0, theta=0.0
% INFO    : Bus 89292	: V=0.9636942, theta=19.388016 -> V=1.0, theta=0.0
% INFO    : Bus 89293	: V=0.9822524, theta=19.607285 -> V=1.0, theta=0.0
% INFO    : Bus 89294	: V=0.9729388, theta=18.932608 -> V=1.0, theta=0.0
% INFO    : Bus 89295	: V=0.9789912, theta=19.728119 -> V=1.0, theta=0.0
% INFO    : Bus 89296	: V=0.9734464, theta=19.516654 -> V=1.0, theta=0.0
% INFO    : Bus 89297	: V=0.9734872, theta=19.455113 -> V=1.0, theta=0.0
% INFO    : Bus 89298	: V=0.9813503, theta=19.488764 -> V=1.0, theta=0.0
% INFO    : Bus 89299	: V=0.9746915, theta=19.08247 -> V=1.0, theta=0.0
% INFO    : Bus 89300	: V=0.9679061, theta=18.718939 -> V=1.0, theta=0.0
% INFO    : Bus 89301	: V=0.9716537, theta=18.832132 -> V=1.0, theta=0.0
% INFO    : Bus 89302	: V=0.9663898, theta=18.229166 -> V=1.0, theta=0.0
% INFO    : Bus 89303	: V=0.9667969, theta=18.395265 -> V=1.0, theta=0.0
% INFO    : Bus 89304	: V=0.9639506, theta=18.476982 -> V=1.0, theta=0.0
% INFO    : Bus 89305	: V=0.9677524, theta=18.570933 -> V=1.0, theta=0.0
% INFO    : Bus 89306	: V=0.9695917, theta=18.509926 -> V=1.0, theta=0.0
% INFO    : Bus 89307	: V=0.9674175, theta=18.428552 -> V=1.0, theta=0.0
% INFO    : Bus 89308	: V=0.9705521, theta=18.453518 -> V=1.0, theta=0.0
% INFO    : Bus 89309	: V=0.9753255, theta=18.120439 -> V=1.0, theta=0.0
% INFO    : Bus 89310	: V=0.9752177, theta=18.133532 -> V=1.0, theta=0.0
% INFO    : Bus 89311	: V=0.9725114, theta=18.090328 -> V=1.0, theta=0.0
% INFO    : Bus 89312	: V=0.9672955, theta=18.201869 -> V=1.0, theta=0.0
% INFO    : Bus 89313	: V=0.9731466, theta=18.071831 -> V=1.0, theta=0.0
% INFO    : Bus 89314	: V=0.983356, theta=19.071912 -> V=1.0, theta=0.0
% INFO    : Bus 89315	: V=0.9757113, theta=18.608484 -> V=1.0, theta=0.0
% INFO    : Bus 89316	: V=0.9841127, theta=18.447697 -> V=1.0, theta=0.0
% INFO    : Bus 89317	: V=0.9815592, theta=18.433617 -> V=1.0, theta=0.0
% INFO    : Bus 89318	: V=0.9870784, theta=20.140081 -> V=1.0, theta=0.0
% INFO    : Bus 89319	: V=0.9926836, theta=20.09602 -> V=1.0, theta=0.0
% INFO    : Bus 89320	: V=0.9884268, theta=20.212359 -> V=1.0, theta=0.0
% INFO    : Bus 89321	: V=0.9798472, theta=18.254379 -> V=1.0, theta=0.0
% INFO    : Bus 89322	: V=0.9855533, theta=18.501226 -> V=1.0, theta=0.0
% INFO    : Bus 89323	: V=0.9925045, theta=19.672403 -> V=1.0, theta=0.0
% INFO    : Bus 89324	: V=0.9913342, theta=19.573594 -> V=1.0, theta=0.0
% INFO    : Bus 89325	: V=0.989151, theta=18.98909 -> V=1.0, theta=0.0
% INFO    : Bus 89326	: V=0.9869764, theta=18.669396 -> V=1.0, theta=0.0
% INFO    : Bus 89327	: V=0.9909159, theta=19.410094 -> V=1.0, theta=0.0
% INFO    : Bus 89328	: V=0.9895989, theta=18.812005 -> V=1.0, theta=0.0
% INFO    : Bus 89329	: V=0.9796214, theta=18.218821 -> V=1.0, theta=0.0
% INFO    : Bus 89330	: V=0.9797158, theta=18.233631 -> V=1.0, theta=0.0
% INFO    : Bus 89331	: V=0.9699416, theta=18.139865 -> V=1.0, theta=0.0
% INFO    : Bus 89332	: V=0.9739171, theta=18.103103 -> V=1.0, theta=0.0
% INFO    : Bus 89333	: V=0.9770121, theta=18.172053 -> V=1.0, theta=0.0
% INFO    : Bus 89334	: V=0.9774941, theta=18.193993 -> V=1.0, theta=0.0
% INFO    : Bus 89335	: V=0.9763977, theta=18.153439 -> V=1.0, theta=0.0
% INFO    : Bus 89336	: V=0.9765112, theta=18.170496 -> V=1.0, theta=0.0
% INFO    : Bus 89337	: V=0.9724586, theta=18.105344 -> V=1.0, theta=0.0
% INFO    : Bus 89338	: V=0.97663, theta=18.169844 -> V=1.0, theta=0.0
% INFO    : Bus 89339	: V=0.9788075, theta=18.202799 -> V=1.0, theta=0.0
% INFO    : Bus 89340	: V=0.9721168, theta=18.702095 -> V=1.0, theta=0.0
% INFO    : Bus 89341	: V=0.9715804, theta=18.516823 -> V=1.0, theta=0.0
% INFO    : Bus 89342	: V=0.9721917, theta=18.710731 -> V=1.0, theta=0.0
% INFO    : Bus 89343	: V=0.9710493, theta=18.46108 -> V=1.0, theta=0.0
% INFO    : Bus 89344	: V=0.9690758, theta=18.492989 -> V=1.0, theta=0.0
% INFO    : Bus 89345	: V=0.9696585, theta=18.350077 -> V=1.0, theta=0.0
% INFO    : Bus 89346	: V=0.9699477, theta=18.348182 -> V=1.0, theta=0.0
% INFO    : Bus 89347	: V=0.9701062, theta=18.277103 -> V=1.0, theta=0.0
% INFO    : Bus 89348	: V=0.9689005, theta=18.197072 -> V=1.0, theta=0.0
% INFO    : Bus 89349	: V=0.9749428, theta=18.326958 -> V=1.0, theta=0.0
% INFO    : Bus 89350	: V=0.9743923, theta=18.342681 -> V=1.0, theta=0.0
% INFO    : Bus 89351	: V=0.968613, theta=18.348517 -> V=1.0, theta=0.0
% INFO    : Bus 89352	: V=0.9756687, theta=18.322422 -> V=1.0, theta=0.0
% INFO    : Bus 89353	: V=0.9749273, theta=18.352541 -> V=1.0, theta=0.0
% INFO    : Bus 89354	: V=0.971905, theta=18.376186 -> V=1.0, theta=0.0
% INFO    : Bus 89355	: V=0.9725844, theta=18.378743 -> V=1.0, theta=0.0
% INFO    : Bus 89356	: V=0.9720308, theta=18.55102 -> V=1.0, theta=0.0
% INFO    : Bus 89357	: V=0.9723055, theta=18.533672 -> V=1.0, theta=0.0
% INFO    : Bus 89358	: V=0.9740987, theta=18.433976 -> V=1.0, theta=0.0
% INFO    : Bus 89359	: V=0.9804434, theta=18.563875 -> V=1.0, theta=0.0
% INFO    : Bus 89360	: V=0.978186, theta=18.339233 -> V=1.0, theta=0.0
% INFO    : Bus 89361	: V=0.9846233, theta=18.437578 -> V=1.0, theta=0.0
% INFO    : Bus 89362	: V=0.9882093, theta=18.503188 -> V=1.0, theta=0.0
% INFO    : Bus 89363	: V=0.9858339, theta=18.392803 -> V=1.0, theta=0.0
% INFO    : Bus 89364	: V=0.9874263, theta=18.574638 -> V=1.0, theta=0.0
% INFO    : Bus 89365	: V=0.9762151, theta=18.142426 -> V=1.0, theta=0.0
% INFO    : Bus 89366	: V=0.98674, theta=18.330576 -> V=1.0, theta=0.0
% INFO    : Bus 89367	: V=0.9875216, theta=18.234236 -> V=1.0, theta=0.0
% INFO    : Bus 89368	: V=0.988081, theta=18.364915 -> V=1.0, theta=0.0
% INFO    : Bus 89369	: V=0.9869757, theta=18.367295 -> V=1.0, theta=0.0
% INFO    : Bus 89370	: V=0.9683546, theta=19.414849 -> V=1.0, theta=0.0
% INFO    : Bus 89371	: V=0.9540296, theta=19.350812 -> V=1.0, theta=0.0
% INFO    : Bus 89372	: V=0.9568277, theta=19.365572 -> V=1.0, theta=0.0
% INFO    : Bus 89373	: V=0.9595969, theta=19.363593 -> V=1.0, theta=0.0
% INFO    : Bus 89374	: V=0.952251, theta=19.458881 -> V=1.0, theta=0.0
% INFO    : Bus 89375	: V=0.9512081, theta=19.588067 -> V=1.0, theta=0.0
% INFO    : Bus 89376	: V=0.9568822, theta=19.36471 -> V=1.0, theta=0.0
% INFO    : Bus 89377	: V=0.9566391, theta=19.129119 -> V=1.0, theta=0.0
% INFO    : Bus 89378	: V=0.9637125, theta=19.44912 -> V=1.0, theta=0.0
% INFO    : Bus 89379	: V=0.9564495, theta=19.152033 -> V=1.0, theta=0.0
% INFO    : Bus 89380	: V=0.9594696, theta=19.144815 -> V=1.0, theta=0.0
% INFO    : Bus 89381	: V=0.9662186, theta=18.748835 -> V=1.0, theta=0.0
% INFO    : Bus 89382	: V=0.9610303, theta=18.829093 -> V=1.0, theta=0.0
% INFO    : Bus 89383	: V=0.9610895, theta=18.885358 -> V=1.0, theta=0.0
% INFO    : Bus 89384	: V=0.9616619, theta=18.96082 -> V=1.0, theta=0.0
% INFO    : Bus 89385	: V=0.9571111, theta=19.203531 -> V=1.0, theta=0.0
% INFO    : Bus 89386	: V=0.9591944, theta=19.228318 -> V=1.0, theta=0.0
% INFO    : Bus 89387	: V=0.958415, theta=19.185303 -> V=1.0, theta=0.0
% INFO    : Bus 89388	: V=0.9603683, theta=19.149177 -> V=1.0, theta=0.0
% INFO    : Bus 89389	: V=0.9752241, theta=19.072541 -> V=1.0, theta=0.0
% INFO    : Bus 89390	: V=0.9675465, theta=19.372455 -> V=1.0, theta=0.0
% INFO    : Bus 89391	: V=0.9609169, theta=19.153749 -> V=1.0, theta=0.0
% INFO    : Bus 89392	: V=0.9646281, theta=19.045719 -> V=1.0, theta=0.0
% INFO    : Bus 89393	: V=0.9620442, theta=18.999894 -> V=1.0, theta=0.0
% INFO    : Bus 89394	: V=0.9605308, theta=19.199039 -> V=1.0, theta=0.0
% INFO    : Bus 89395	: V=0.9636298, theta=19.122098 -> V=1.0, theta=0.0
% INFO    : Bus 89396	: V=0.9599365, theta=19.172935 -> V=1.0, theta=0.0
% INFO    : Bus 89397	: V=0.9605943, theta=19.20015 -> V=1.0, theta=0.0
% INFO    : Bus 89398	: V=0.964015, theta=19.198949 -> V=1.0, theta=0.0
% INFO    : Bus 89399	: V=0.9739514, theta=19.908171 -> V=1.0, theta=0.0
% INFO    : Bus 89400	: V=0.9619678, theta=19.476631 -> V=1.0, theta=0.0
% INFO    : Bus 89401	: V=0.9575977, theta=19.280872 -> V=1.0, theta=0.0
% INFO    : Bus 89402	: V=0.955628, theta=19.098192 -> V=1.0, theta=0.0
% INFO    : Bus 89403	: V=0.9683885, theta=19.42539 -> V=1.0, theta=0.0
% INFO    : Bus 89404	: V=0.9592655, theta=19.194833 -> V=1.0, theta=0.0
% INFO    : Bus 89405	: V=0.9696014, theta=19.213818 -> V=1.0, theta=0.0
% INFO    : Bus 89406	: V=0.9650684, theta=19.02195 -> V=1.0, theta=0.0
% INFO    : Bus 89407	: V=0.9606385, theta=18.96977 -> V=1.0, theta=0.0
% INFO    : Bus 89408	: V=0.9594188, theta=19.235867 -> V=1.0, theta=0.0
% INFO    : Bus 89409	: V=0.9712508, theta=19.340448 -> V=1.0, theta=0.0
% INFO    : Bus 89410	: V=0.9666743, theta=19.140226 -> V=1.0, theta=0.0
% INFO    : Bus 89411	: V=0.9596037, theta=19.103641 -> V=1.0, theta=0.0
% INFO    : Bus 89412	: V=0.9563636, theta=19.156091 -> V=1.0, theta=0.0
% INFO    : Bus 89413	: V=0.9621299, theta=18.924509 -> V=1.0, theta=0.0
% INFO    : Bus 89414	: V=0.9654044, theta=18.810371 -> V=1.0, theta=0.0
% INFO    : Bus 89415	: V=0.9662848, theta=18.882697 -> V=1.0, theta=0.0
% INFO    : Bus 89416	: V=0.9770279, theta=2.137535 -> V=1.0, theta=0.0
% INFO    : Bus 89417	: V=0.9797298, theta=2.504167 -> V=1.0, theta=0.0
% INFO    : Bus 89418	: V=0.990448, theta=6.246622 -> V=1.0, theta=0.0
% INFO    : Bus 89419	: V=0.9892879, theta=29.275414 -> V=1.0, theta=0.0
% INFO    : Bus 89420	: V=0.9943466, theta=29.912783 -> V=1.0, theta=0.0
% INFO    : Bus 89421	: V=0.9928871, theta=26.857807 -> V=1.0, theta=0.0
% INFO    : Bus 89422	: V=0.9915175, theta=27.390578 -> V=1.0, theta=0.0
% INFO    : Bus 89423	: V=0.9919755, theta=27.101146 -> V=1.0, theta=0.0
% INFO    : Bus 89424	: V=0.996507, theta=27.328431 -> V=1.0, theta=0.0
% INFO    : Bus 89425	: V=0.9966991, theta=27.154509 -> V=1.0, theta=0.0
% INFO    : Bus 89426	: V=0.9904703, theta=27.415676 -> V=1.0, theta=0.0
% INFO    : Bus 89427	: V=0.9896415, theta=27.261214 -> V=1.0, theta=0.0
% INFO    : Bus 89428	: V=0.9971971, theta=27.035851 -> V=1.0, theta=0.0
% INFO    : Bus 89429	: V=0.9939318, theta=26.946296 -> V=1.0, theta=0.0
% INFO    : Bus 89430	: V=1.0007709, theta=24.456458 -> V=1.0, theta=0.0
% INFO    : Bus 89431	: V=1.0052064, theta=19.093584 -> V=1.0, theta=0.0
% INFO    : Bus 89432	: V=0.9933679, theta=8.592045 -> V=1.0, theta=0.0
% INFO    : Bus 89433	: V=0.9855192, theta=8.464922 -> V=1.0, theta=0.0
% INFO    : Bus 89434	: V=0.9651189, theta=21.091134 -> V=1.0, theta=0.0
% INFO    : Bus 89435	: V=0.9601548, theta=21.070124 -> V=1.0, theta=0.0
% INFO    : Bus 89436	: V=0.9613568, theta=20.86755 -> V=1.0, theta=0.0
% INFO    : Bus 89437	: V=0.9588898, theta=21.10229 -> V=1.0, theta=0.0
% INFO    : Bus 89438	: V=0.9599147, theta=20.545475 -> V=1.0, theta=0.0
% INFO    : Bus 89439	: V=0.9639946, theta=21.101528 -> V=1.0, theta=0.0
% INFO    : Bus 89440	: V=0.9615885, theta=21.167511 -> V=1.0, theta=0.0
% INFO    : Bus 89441	: V=0.9602835, theta=21.493643 -> V=1.0, theta=0.0
% INFO    : Bus 89442	: V=0.9602379, theta=21.831752 -> V=1.0, theta=0.0
% INFO    : Bus 89443	: V=0.9602853, theta=21.791936 -> V=1.0, theta=0.0
% INFO    : Bus 89444	: V=0.9611295, theta=21.867746 -> V=1.0, theta=0.0
% INFO    : Bus 89445	: V=0.9615986, theta=21.312786 -> V=1.0, theta=0.0
% INFO    : Bus 89446	: V=0.963274, theta=21.318715 -> V=1.0, theta=0.0
% INFO    : Bus 89447	: V=0.9651211, theta=21.503844 -> V=1.0, theta=0.0
% INFO    : Bus 89448	: V=0.9643644, theta=21.286453 -> V=1.0, theta=0.0
% INFO    : Bus 89449	: V=0.9641312, theta=21.519374 -> V=1.0, theta=0.0
% INFO    : Bus 89450	: V=0.9638734, theta=21.403902 -> V=1.0, theta=0.0
% INFO    : Bus 89451	: V=0.9658035, theta=21.582479 -> V=1.0, theta=0.0
% INFO    : Bus 89452	: V=0.967276, theta=21.976413 -> V=1.0, theta=0.0
% INFO    : Bus 89453	: V=0.9649367, theta=21.564706 -> V=1.0, theta=0.0
% INFO    : Bus 89454	: V=0.9668878, theta=21.748114 -> V=1.0, theta=0.0
% INFO    : Bus 89455	: V=0.9726592, theta=22.009867 -> V=1.0, theta=0.0
% INFO    : Bus 89456	: V=0.9712215, theta=21.843154 -> V=1.0, theta=0.0
% INFO    : Bus 89457	: V=0.9672525, theta=21.18317 -> V=1.0, theta=0.0
% INFO    : Bus 89458	: V=0.9670092, theta=21.094778 -> V=1.0, theta=0.0
% INFO    : Bus 89459	: V=0.9658387, theta=20.961005 -> V=1.0, theta=0.0
% INFO    : Bus 89460	: V=0.9759764, theta=21.375503 -> V=1.0, theta=0.0
% INFO    : Bus 89461	: V=0.9717972, theta=21.110061 -> V=1.0, theta=0.0
% INFO    : Bus 89462	: V=0.9676489, theta=21.047234 -> V=1.0, theta=0.0
% INFO    : Bus 89463	: V=0.962451, theta=20.271454 -> V=1.0, theta=0.0
% INFO    : Bus 89464	: V=0.9644962, theta=20.792457 -> V=1.0, theta=0.0
% INFO    : Bus 89465	: V=0.9647474, theta=20.814375 -> V=1.0, theta=0.0
% INFO    : Bus 89466	: V=0.9652412, theta=20.824258 -> V=1.0, theta=0.0
% INFO    : Bus 89467	: V=0.9641059, theta=20.782327 -> V=1.0, theta=0.0
% INFO    : Bus 89468	: V=0.9624193, theta=20.270147 -> V=1.0, theta=0.0
% INFO    : Bus 89469	: V=0.9610105, theta=20.249387 -> V=1.0, theta=0.0
% INFO    : Bus 89470	: V=0.9648161, theta=20.572903 -> V=1.0, theta=0.0
% INFO    : Bus 89471	: V=0.9664996, theta=20.553999 -> V=1.0, theta=0.0
% INFO    : Bus 89472	: V=0.966926, theta=20.430727 -> V=1.0, theta=0.0
% INFO    : Bus 89473	: V=0.9662141, theta=20.409648 -> V=1.0, theta=0.0
% INFO    : Bus 89474	: V=0.9682625, theta=20.333439 -> V=1.0, theta=0.0
% INFO    : Bus 89475	: V=0.9641253, theta=20.160854 -> V=1.0, theta=0.0
% INFO    : Bus 89476	: V=0.9691048, theta=20.179765 -> V=1.0, theta=0.0
% INFO    : Bus 89477	: V=0.9747469, theta=20.319565 -> V=1.0, theta=0.0
% INFO    : Bus 89478	: V=0.9765592, theta=20.51718 -> V=1.0, theta=0.0
% INFO    : Bus 89479	: V=0.9765571, theta=20.546628 -> V=1.0, theta=0.0
% INFO    : Bus 89480	: V=0.9819029, theta=20.928031 -> V=1.0, theta=0.0
% INFO    : Bus 89481	: V=0.9808897, theta=20.708229 -> V=1.0, theta=0.0
% INFO    : Bus 89482	: V=0.9835098, theta=20.545164 -> V=1.0, theta=0.0
% INFO    : Bus 89483	: V=0.9807699, theta=20.634808 -> V=1.0, theta=0.0
% INFO    : Bus 89484	: V=0.9832829, theta=20.772234 -> V=1.0, theta=0.0
% INFO    : Bus 89485	: V=0.9727497, theta=20.153836 -> V=1.0, theta=0.0
% INFO    : Bus 89486	: V=0.9666754, theta=20.952674 -> V=1.0, theta=0.0
% INFO    : Bus 89487	: V=0.9751796, theta=21.234943 -> V=1.0, theta=0.0
% INFO    : Bus 89488	: V=0.9765712, theta=21.369255 -> V=1.0, theta=0.0
% INFO    : Bus 89489	: V=0.9841643, theta=21.309317 -> V=1.0, theta=0.0
% INFO    : Bus 89490	: V=0.9792905, theta=21.282657 -> V=1.0, theta=0.0
% INFO    : Bus 89491	: V=0.9817144, theta=21.313068 -> V=1.0, theta=0.0
% INFO    : Bus 89492	: V=0.9937737, theta=21.203232 -> V=1.0, theta=0.0
% INFO    : Bus 89493	: V=0.9886464, theta=21.212327 -> V=1.0, theta=0.0
% INFO    : Bus 89494	: V=0.9865112, theta=21.127143 -> V=1.0, theta=0.0
% INFO    : Bus 89495	: V=0.9918038, theta=21.272715 -> V=1.0, theta=0.0
% INFO    : Bus 89496	: V=0.9875188, theta=21.099096 -> V=1.0, theta=0.0
% INFO    : Bus 89497	: V=0.9931754, theta=21.267689 -> V=1.0, theta=0.0
% INFO    : Bus 89498	: V=0.9795845, theta=21.201872 -> V=1.0, theta=0.0
% INFO    : Bus 89499	: V=0.9799608, theta=21.637571 -> V=1.0, theta=0.0
% INFO    : Bus 89500	: V=0.9790716, theta=21.549799 -> V=1.0, theta=0.0
% INFO    : Bus 89501	: V=0.9820251, theta=21.905366 -> V=1.0, theta=0.0
% INFO    : Bus 89502	: V=0.9787777, theta=21.441695 -> V=1.0, theta=0.0
% INFO    : Bus 89503	: V=0.9833305, theta=21.840767 -> V=1.0, theta=0.0
% INFO    : Bus 89504	: V=0.9832045, theta=21.852833 -> V=1.0, theta=0.0
% INFO    : Bus 89505	: V=0.9791041, theta=21.493197 -> V=1.0, theta=0.0
% INFO    : Bus 89506	: V=0.9832866, theta=21.597812 -> V=1.0, theta=0.0
% INFO    : Bus 89507	: V=0.9613511, theta=20.828443 -> V=1.0, theta=0.0
% INFO    : Bus 89508	: V=0.9670747, theta=21.146661 -> V=1.0, theta=0.0
% INFO    : Bus 89509	: V=0.9631272, theta=21.010836 -> V=1.0, theta=0.0
% INFO    : Bus 89510	: V=0.9672251, theta=20.966745 -> V=1.0, theta=0.0
% INFO    : Bus 89511	: V=0.9650272, theta=20.874367 -> V=1.0, theta=0.0
% INFO    : Bus 89512	: V=0.9735416, theta=8.557011 -> V=1.0, theta=0.0
% INFO    : Bus 89513	: V=0.988615, theta=7.629515 -> V=1.0, theta=0.0
% INFO    : Bus 89514	: V=1.0047375, theta=7.352464 -> V=1.0, theta=0.0
% INFO    : Bus 89515	: V=0.9893657, theta=16.193955 -> V=1.0, theta=0.0
% INFO    : Bus 89516	: V=1.0070061, theta=-0.331321 -> V=1.0, theta=0.0
% INFO    : Bus 89517	: V=1.012465, theta=0.168368 -> V=1.0, theta=0.0
% INFO    : Bus 89518	: V=1.0114459, theta=-0.00108 -> V=1.0, theta=0.0
% INFO    : Bus 89519	: V=1.0096554, theta=-0.760089 -> V=1.0, theta=0.0
% INFO    : Bus 89520	: V=1.0037034, theta=-0.621094 -> V=1.0, theta=0.0
% INFO    : Bus 89521	: V=1.0036496, theta=-0.631937 -> V=1.0, theta=0.0
% INFO    : Bus 89522	: V=0.994709, theta=24.97014 -> V=1.0, theta=0.0
% INFO    : Bus 89523	: V=0.9964587, theta=24.627256 -> V=1.0, theta=0.0
% INFO    : Bus 89524	: V=1.0057996, theta=21.938312 -> V=1.0, theta=0.0
% INFO    : Bus 89525	: V=0.9969455, theta=8.194473 -> V=1.0, theta=0.0
% INFO    : Bus 89526	: V=1.0160273, theta=23.129408 -> V=1.0, theta=0.0
% INFO    : Bus 89527	: V=1.0133296, theta=23.030915 -> V=1.0, theta=0.0
% INFO    : Bus 89528	: V=1.0086379, theta=23.077871 -> V=1.0, theta=0.0
% INFO    : Bus 89529	: V=1.0036976, theta=22.870556 -> V=1.0, theta=0.0
% INFO    : Bus 89530	: V=1.0129086, theta=22.485577 -> V=1.0, theta=0.0
% INFO    : Bus 89531	: V=1.0151183, theta=21.280504 -> V=1.0, theta=0.0
% INFO    : Bus 89532	: V=0.9928447, theta=17.476909 -> V=1.0, theta=0.0
% INFO    : Bus 89533	: V=0.9853941, theta=17.020724 -> V=1.0, theta=0.0
% INFO    : Bus 89534	: V=0.9968844, theta=24.149603 -> V=1.0, theta=0.0
% INFO    : Bus 89535	: V=1.0057403, theta=30.757711 -> V=1.0, theta=0.0
% INFO    : Bus 89536	: V=1.0025605, theta=31.016427 -> V=1.0, theta=0.0
% INFO    : Bus 89537	: V=0.9983212, theta=29.527137 -> V=1.0, theta=0.0
% INFO    : Bus 89538	: V=0.991872, theta=29.017073 -> V=1.0, theta=0.0
% INFO    : Bus 89539	: V=0.9908669, theta=28.78332 -> V=1.0, theta=0.0
% INFO    : Bus 89540	: V=0.9748516, theta=17.087773 -> V=1.0, theta=0.0
% INFO    : Bus 89541	: V=0.9812938, theta=17.539937 -> V=1.0, theta=0.0
% INFO    : Bus 89542	: V=0.973649, theta=15.61823 -> V=1.0, theta=0.0
% INFO    : Bus 89543	: V=0.9807363, theta=17.436766 -> V=1.0, theta=0.0
% INFO    : Bus 89544	: V=1.0094813, theta=0.370287 -> V=1.0, theta=0.0
% INFO    : Bus 89545	: V=1.0089345, theta=1.141294 -> V=1.0, theta=0.0
% INFO    : Bus 89546	: V=1.0080841, theta=0.826123 -> V=1.0, theta=0.0
% INFO    : Bus 89547	: V=1.0070925, theta=0.117283 -> V=1.0, theta=0.0
% INFO    : Bus 89548	: V=0.9899573, theta=3.9202 -> V=1.0, theta=0.0
% INFO    : Bus 89549	: V=1.014069, theta=0.769919 -> V=1.0, theta=0.0
% INFO    : Bus 89550	: V=1.0119494, theta=-0.156818 -> V=1.0, theta=0.0
% INFO    : Bus 89551	: V=1.0021472, theta=0.445817 -> V=1.0, theta=0.0
% INFO    : Bus 89552	: V=1.0111376, theta=-0.205887 -> V=1.0, theta=0.0
% INFO    : Bus 89553	: V=1.0084507, theta=-0.209647 -> V=1.0, theta=0.0
% INFO    : Bus 89554	: V=0.9976253, theta=3.553293 -> V=1.0, theta=0.0
% INFO    : Bus 89555	: V=1.0038431, theta=3.904236 -> V=1.0, theta=0.0
% INFO    : Bus 89556	: V=1.0046138, theta=3.848144 -> V=1.0, theta=0.0
% INFO    : Bus 89557	: V=0.9972123, theta=34.118464 -> V=1.0, theta=0.0
% INFO    : Bus 89558	: V=0.9994496, theta=34.291378 -> V=1.0, theta=0.0
% INFO    : Bus 89559	: V=0.9974728, theta=33.750236 -> V=1.0, theta=0.0
% INFO    : Bus 89560	: V=1.0114736, theta=-1.406402 -> V=1.0, theta=0.0
% INFO    : Bus 89561	: V=1.0142265, theta=-2.497641 -> V=1.0, theta=0.0
% INFO    : Bus 89562	: V=1.0138355, theta=-2.566287 -> V=1.0, theta=0.0
% INFO    : Bus 89563	: V=0.9547385, theta=24.082707 -> V=1.0, theta=0.0
% INFO    : Bus 89564	: V=0.9529338, theta=23.666027 -> V=1.0, theta=0.0
% INFO    : Bus 89565	: V=0.9588122, theta=24.446365 -> V=1.0, theta=0.0
% INFO    : Bus 89566	: V=0.9632834, theta=24.641462 -> V=1.0, theta=0.0
% INFO    : Bus 89567	: V=0.9707562, theta=27.626506 -> V=1.0, theta=0.0
% INFO    : Bus 89568	: V=0.9823154, theta=26.732885 -> V=1.0, theta=0.0
% INFO    : Bus 89569	: V=0.9546056, theta=23.789112 -> V=1.0, theta=0.0
% INFO    : Bus 89570	: V=0.9537933, theta=23.16291 -> V=1.0, theta=0.0
% INFO    : Bus 89571	: V=0.9577283, theta=23.155309 -> V=1.0, theta=0.0
% INFO    : Bus 89572	: V=0.9672567, theta=22.147129 -> V=1.0, theta=0.0
% INFO    : Bus 89573	: V=0.9631952, theta=22.793255 -> V=1.0, theta=0.0
% INFO    : Bus 89574	: V=0.9660439, theta=22.695281 -> V=1.0, theta=0.0
% INFO    : Bus 89575	: V=0.9692735, theta=22.428773 -> V=1.0, theta=0.0
% INFO    : Bus 89576	: V=0.9672244, theta=23.065435 -> V=1.0, theta=0.0
% INFO    : Bus 89577	: V=0.991618, theta=25.090998 -> V=1.0, theta=0.0
% INFO    : Bus 89578	: V=0.990701, theta=24.650751 -> V=1.0, theta=0.0
% INFO    : Bus 89579	: V=0.9685309, theta=22.260164 -> V=1.0, theta=0.0
% INFO    : Bus 89580	: V=0.970149, theta=22.374877 -> V=1.0, theta=0.0
% INFO    : Bus 89581	: V=0.9728387, theta=22.469571 -> V=1.0, theta=0.0
% INFO    : Bus 89582	: V=0.9682835, theta=22.154912 -> V=1.0, theta=0.0
% INFO    : Bus 89583	: V=0.9668212, theta=22.168267 -> V=1.0, theta=0.0
% INFO    : Bus 89584	: V=0.9782851, theta=22.408055 -> V=1.0, theta=0.0
% INFO    : Bus 89585	: V=0.9797798, theta=22.436684 -> V=1.0, theta=0.0
% INFO    : Bus 89586	: V=0.9764829, theta=22.439064 -> V=1.0, theta=0.0
% INFO    : Bus 89587	: V=0.9825389, theta=22.26724 -> V=1.0, theta=0.0
% INFO    : Bus 89588	: V=0.9800016, theta=22.443111 -> V=1.0, theta=0.0
% INFO    : Bus 89589	: V=0.9913126, theta=22.871942 -> V=1.0, theta=0.0
% INFO    : Bus 89590	: V=0.9860872, theta=22.732061 -> V=1.0, theta=0.0
% INFO    : Bus 89591	: V=0.9832043, theta=22.396648 -> V=1.0, theta=0.0
% INFO    : Bus 89592	: V=0.9824368, theta=22.24727 -> V=1.0, theta=0.0
% INFO    : Bus 89593	: V=0.9822619, theta=22.100495 -> V=1.0, theta=0.0
% INFO    : Bus 89594	: V=0.9829518, theta=23.413512 -> V=1.0, theta=0.0
% INFO    : Bus 89595	: V=0.9534041, theta=23.28235 -> V=1.0, theta=0.0
% INFO    : Bus 89596	: V=0.9839999, theta=22.424288 -> V=1.0, theta=0.0
% INFO    : Bus 89597	: V=0.9841727, theta=22.38515 -> V=1.0, theta=0.0
% INFO    : Bus 89598	: V=0.9734887, theta=22.547563 -> V=1.0, theta=0.0
% INFO    : Bus 89599	: V=0.9566075, theta=22.958492 -> V=1.0, theta=0.0
% INFO    : Bus 89600	: V=0.9810303, theta=18.26335 -> V=1.0, theta=0.0
% INFO    : Bus 89601	: V=0.9790086, theta=17.734874 -> V=1.0, theta=0.0
% INFO    : Bus 89602	: V=0.9847473, theta=18.312507 -> V=1.0, theta=0.0
% INFO    : Bus 89603	: V=0.9833828, theta=18.308206 -> V=1.0, theta=0.0
% INFO    : Bus 89604	: V=0.9840137, theta=18.304658 -> V=1.0, theta=0.0
% INFO    : Bus 89605	: V=0.9857599, theta=18.3064 -> V=1.0, theta=0.0
% INFO    : Bus 89606	: V=0.9922973, theta=22.163457 -> V=1.0, theta=0.0
% INFO    : Bus 89607	: V=0.9886921, theta=22.066617 -> V=1.0, theta=0.0
% INFO    : Bus 89608	: V=0.9957376, theta=22.861437 -> V=1.0, theta=0.0
% INFO    : Bus 89609	: V=0.9994468, theta=23.966484 -> V=1.0, theta=0.0
% INFO    : Bus 89610	: V=1.0016848, theta=22.38225 -> V=1.0, theta=0.0
% INFO    : Bus 89611	: V=0.9894197, theta=27.769208 -> V=1.0, theta=0.0
% INFO    : Bus 89612	: V=0.9968156, theta=26.914202 -> V=1.0, theta=0.0
% INFO    : Bus 89613	: V=0.9969906, theta=26.795624 -> V=1.0, theta=0.0
% INFO    : Bus 89614	: V=1.001584, theta=27.051454 -> V=1.0, theta=0.0
% INFO    : Bus 89615	: V=0.9981249, theta=26.80762 -> V=1.0, theta=0.0
% INFO    : Bus 89616	: V=0.9968649, theta=26.77651 -> V=1.0, theta=0.0
% INFO    : Bus 89617	: V=0.9956015, theta=26.474104 -> V=1.0, theta=0.0
% INFO    : Bus 89618	: V=0.9952479, theta=26.168746 -> V=1.0, theta=0.0
% INFO    : Bus 89619	: V=0.99514, theta=26.163951 -> V=1.0, theta=0.0
% INFO    : Bus 89620	: V=0.9938871, theta=26.112105 -> V=1.0, theta=0.0
% INFO    : Bus 89621	: V=0.9941609, theta=26.204212 -> V=1.0, theta=0.0
% INFO    : Bus 89622	: V=0.9919906, theta=25.697038 -> V=1.0, theta=0.0
% INFO    : Bus 89623	: V=0.993508, theta=26.083719 -> V=1.0, theta=0.0
% INFO    : Bus 89624	: V=0.9872091, theta=27.407254 -> V=1.0, theta=0.0
% INFO    : Bus 89625	: V=0.9818862, theta=26.998931 -> V=1.0, theta=0.0
% INFO    : Bus 89626	: V=0.9787791, theta=26.271811 -> V=1.0, theta=0.0
% INFO    : Bus 89627	: V=0.9827884, theta=25.773818 -> V=1.0, theta=0.0
% INFO    : Bus 89628	: V=0.9854297, theta=26.146933 -> V=1.0, theta=0.0
% INFO    : Bus 89629	: V=0.9785708, theta=25.340941 -> V=1.0, theta=0.0
% INFO    : Bus 89630	: V=0.9794819, theta=25.741838 -> V=1.0, theta=0.0
% INFO    : Bus 89631	: V=0.9804946, theta=25.978322 -> V=1.0, theta=0.0
% INFO    : Bus 89632	: V=0.9879904, theta=25.283821 -> V=1.0, theta=0.0
% INFO    : Bus 89633	: V=0.9884195, theta=25.190755 -> V=1.0, theta=0.0
% INFO    : Bus 89634	: V=0.9867024, theta=24.887177 -> V=1.0, theta=0.0
% INFO    : Bus 89635	: V=0.9848798, theta=24.755697 -> V=1.0, theta=0.0
% INFO    : Bus 89636	: V=0.9792538, theta=25.150678 -> V=1.0, theta=0.0
% INFO    : Bus 89637	: V=0.9915797, theta=25.515182 -> V=1.0, theta=0.0
% INFO    : Bus 89638	: V=0.9879312, theta=24.986377 -> V=1.0, theta=0.0
% INFO    : Bus 89639	: V=0.9880349, theta=24.969219 -> V=1.0, theta=0.0
% INFO    : Bus 89640	: V=0.9892126, theta=25.115189 -> V=1.0, theta=0.0
% INFO    : Bus 89641	: V=0.9892413, theta=25.108982 -> V=1.0, theta=0.0
% INFO    : Bus 89642	: V=0.9861991, theta=24.631566 -> V=1.0, theta=0.0
% INFO    : Bus 89643	: V=0.9879457, theta=24.957933 -> V=1.0, theta=0.0
% INFO    : Bus 89644	: V=0.9877946, theta=24.956422 -> V=1.0, theta=0.0
% INFO    : Bus 89645	: V=0.9861313, theta=24.63438 -> V=1.0, theta=0.0
% INFO    : Bus 89646	: V=0.98614, theta=24.55374 -> V=1.0, theta=0.0
% INFO    : Bus 89647	: V=0.9845192, theta=24.302967 -> V=1.0, theta=0.0
% INFO    : Bus 89648	: V=0.9812891, theta=23.834281 -> V=1.0, theta=0.0
% INFO    : Bus 89649	: V=0.9798695, theta=23.499641 -> V=1.0, theta=0.0
% INFO    : Bus 89650	: V=0.9791106, theta=23.97228 -> V=1.0, theta=0.0
% INFO    : Bus 89651	: V=0.979158, theta=23.957281 -> V=1.0, theta=0.0
% INFO    : Bus 89652	: V=0.9802057, theta=23.993541 -> V=1.0, theta=0.0
% INFO    : Bus 89653	: V=0.9813018, theta=23.960515 -> V=1.0, theta=0.0
% INFO    : Bus 89654	: V=0.9763356, theta=23.693221 -> V=1.0, theta=0.0
% INFO    : Bus 89655	: V=0.9776993, theta=23.834772 -> V=1.0, theta=0.0
% INFO    : Bus 89656	: V=0.9709039, theta=23.693131 -> V=1.0, theta=0.0
% INFO    : Bus 89657	: V=0.9730701, theta=24.814751 -> V=1.0, theta=0.0
% INFO    : Bus 89658	: V=0.9739717, theta=24.331263 -> V=1.0, theta=0.0
% INFO    : Bus 89659	: V=0.9711289, theta=25.80049 -> V=1.0, theta=0.0
% INFO    : Bus 89660	: V=0.9711542, theta=24.921533 -> V=1.0, theta=0.0
% INFO    : Bus 89661	: V=0.9626263, theta=24.116296 -> V=1.0, theta=0.0
% INFO    : Bus 89662	: V=0.9665014, theta=22.30314 -> V=1.0, theta=0.0
% INFO    : Bus 89663	: V=0.9725374, theta=23.200562 -> V=1.0, theta=0.0
% INFO    : Bus 89664	: V=0.9778764, theta=23.272499 -> V=1.0, theta=0.0
% INFO    : Bus 89665	: V=0.9744317, theta=22.513578 -> V=1.0, theta=0.0
% INFO    : Bus 89666	: V=0.9726428, theta=22.340575 -> V=1.0, theta=0.0
% INFO    : Bus 89667	: V=0.9890121, theta=25.927335 -> V=1.0, theta=0.0
% INFO    : Bus 89668	: V=0.9748671, theta=22.948819 -> V=1.0, theta=0.0
% INFO    : Bus 89669	: V=1.0021291, theta=24.501361 -> V=1.0, theta=0.0
% INFO    : Bus 89670	: V=1.0011062, theta=26.2171 -> V=1.0, theta=0.0
% INFO    : Bus 89671	: V=1.0080076, theta=24.129557 -> V=1.0, theta=0.0
% INFO    : Bus 89672	: V=1.0061121, theta=25.369396 -> V=1.0, theta=0.0
% INFO    : Bus 89673	: V=1.0054855, theta=25.613597 -> V=1.0, theta=0.0
% INFO    : Bus 89674	: V=1.0090099, theta=26.915733 -> V=1.0, theta=0.0
% INFO    : Bus 89675	: V=1.0093612, theta=26.988915 -> V=1.0, theta=0.0
% INFO    : Bus 89676	: V=1.0134745, theta=24.182905 -> V=1.0, theta=0.0
% INFO    : Bus 89677	: V=1.0041851, theta=24.155311 -> V=1.0, theta=0.0
% INFO    : Bus 89678	: V=1.0018404, theta=24.582254 -> V=1.0, theta=0.0
% INFO    : Bus 89679	: V=0.9772583, theta=0.699255 -> V=1.0, theta=0.0
% INFO    : Bus 89680	: V=1.0179298, theta=21.405999 -> V=1.0, theta=0.0
% INFO    : Bus 89681	: V=1.0109357, theta=21.710697 -> V=1.0, theta=0.0
% INFO    : Bus 89682	: V=1.0088264, theta=21.673538 -> V=1.0, theta=0.0
% INFO    : Bus 89683	: V=1.0124264, theta=20.466067 -> V=1.0, theta=0.0
% INFO    : Bus 89684	: V=1.0092985, theta=19.704739 -> V=1.0, theta=0.0
% INFO    : Bus 89685	: V=0.9893723, theta=18.282723 -> V=1.0, theta=0.0
% INFO    : Bus 89686	: V=0.9951869, theta=19.783098 -> V=1.0, theta=0.0
% INFO    : Bus 89687	: V=0.9951174, theta=19.717429 -> V=1.0, theta=0.0
% INFO    : Bus 89688	: V=0.9860144, theta=21.558573 -> V=1.0, theta=0.0
% INFO    : Bus 89689	: V=0.98637, theta=20.143283 -> V=1.0, theta=0.0
% INFO    : Bus 89690	: V=0.9851009, theta=20.475041 -> V=1.0, theta=0.0
% INFO    : Bus 89691	: V=0.9859395, theta=20.025713 -> V=1.0, theta=0.0
% INFO    : Bus 89692	: V=0.9885229, theta=20.436266 -> V=1.0, theta=0.0
% INFO    : Bus 89693	: V=0.9830834, theta=18.523818 -> V=1.0, theta=0.0
% INFO    : Bus 89694	: V=0.9837261, theta=31.085243 -> V=1.0, theta=0.0
% INFO    : Bus 89695	: V=0.9818757, theta=30.87602 -> V=1.0, theta=0.0
% INFO    : Bus 89696	: V=0.9726356, theta=27.59691 -> V=1.0, theta=0.0
% INFO    : Bus 89697	: V=0.972027, theta=26.917158 -> V=1.0, theta=0.0
% INFO    : Bus 89698	: V=0.967122, theta=26.50767 -> V=1.0, theta=0.0
% INFO    : Bus 89699	: V=0.9672742, theta=25.923918 -> V=1.0, theta=0.0
% INFO    : Bus 89700	: V=0.9709495, theta=26.176286 -> V=1.0, theta=0.0
% INFO    : Bus 89701	: V=0.9845596, theta=29.218677 -> V=1.0, theta=0.0
% INFO    : Bus 89702	: V=0.9750403, theta=28.309068 -> V=1.0, theta=0.0
% INFO    : Bus 89703	: V=0.9847993, theta=29.761035 -> V=1.0, theta=0.0
% INFO    : Bus 89704	: V=0.9657278, theta=26.461499 -> V=1.0, theta=0.0
% INFO    : Bus 89705	: V=0.9807122, theta=28.163865 -> V=1.0, theta=0.0
% INFO    : Bus 89706	: V=0.9661812, theta=26.344035 -> V=1.0, theta=0.0
% INFO    : Bus 89707	: V=0.9659239, theta=26.154211 -> V=1.0, theta=0.0
% INFO    : Bus 89708	: V=0.9640806, theta=25.094842 -> V=1.0, theta=0.0
% INFO    : Bus 89709	: V=0.9618882, theta=25.831877 -> V=1.0, theta=0.0
% INFO    : Bus 89710	: V=0.9588634, theta=24.458398 -> V=1.0, theta=0.0
% INFO    : Bus 89711	: V=0.9898695, theta=29.80673 -> V=1.0, theta=0.0
% INFO    : Bus 89712	: V=0.9958363, theta=20.214442 -> V=1.0, theta=0.0
% INFO    : Bus 89713	: V=0.9978303, theta=19.934895 -> V=1.0, theta=0.0
% INFO    : Bus 89714	: V=1.0049289, theta=20.230149 -> V=1.0, theta=0.0
% INFO    : Bus 89715	: V=0.9988253, theta=19.827238 -> V=1.0, theta=0.0
% INFO    : Bus 89716	: V=0.9968226, theta=20.005935 -> V=1.0, theta=0.0
% INFO    : Bus 89717	: V=0.9999656, theta=20.24439 -> V=1.0, theta=0.0
% INFO    : Bus 89718	: V=0.9993666, theta=20.19635 -> V=1.0, theta=0.0
% INFO    : Bus 89719	: V=1.0075451, theta=20.28598 -> V=1.0, theta=0.0
% INFO    : Bus 89720	: V=1.0036251, theta=19.003125 -> V=1.0, theta=0.0
% INFO    : Bus 89721	: V=1.0034686, theta=20.231895 -> V=1.0, theta=0.0
% INFO    : Bus 89722	: V=1.0024471, theta=20.203574 -> V=1.0, theta=0.0
% INFO    : Bus 89723	: V=1.000973, theta=20.236673 -> V=1.0, theta=0.0
% INFO    : Bus 89724	: V=0.9960082, theta=20.499759 -> V=1.0, theta=0.0
% INFO    : Bus 89725	: V=1.01281, theta=18.141771 -> V=1.0, theta=0.0
% INFO    : Bus 89726	: V=1.0176843, theta=18.162498 -> V=1.0, theta=0.0
% INFO    : Bus 89727	: V=1.0105021, theta=17.941526 -> V=1.0, theta=0.0
% INFO    : Bus 89728	: V=1.0156544, theta=18.381788 -> V=1.0, theta=0.0
% INFO    : Bus 89729	: V=1.0130448, theta=18.164698 -> V=1.0, theta=0.0
% INFO    : Bus 89730	: V=1.0186456, theta=18.376181 -> V=1.0, theta=0.0
% INFO    : Bus 89731	: V=1.0148407, theta=18.220365 -> V=1.0, theta=0.0
% INFO    : Bus 89732	: V=1.0148351, theta=18.174091 -> V=1.0, theta=0.0
% INFO    : Bus 89733	: V=1.0152601, theta=18.218984 -> V=1.0, theta=0.0
% INFO    : Bus 89734	: V=1.0126534, theta=18.118763 -> V=1.0, theta=0.0
% INFO    : Bus 89735	: V=0.9860126, theta=10.375064 -> V=1.0, theta=0.0
% INFO    : Bus 89736	: V=0.994939, theta=3.967347 -> V=1.0, theta=0.0
% INFO    : Bus 89737	: V=0.9902678, theta=5.322967 -> V=1.0, theta=0.0
% INFO    : Bus 89738	: V=0.9898347, theta=4.607998 -> V=1.0, theta=0.0
% INFO    : Bus 89739	: V=1.0021352, theta=0.697847 -> V=1.0, theta=0.0
% INFO    : Bus 89740	: V=1.0019184, theta=0.732406 -> V=1.0, theta=0.0
% INFO    : Bus 89741	: V=1.0020549, theta=0.757543 -> V=1.0, theta=0.0
% INFO    : Bus 89742	: V=1.0022999, theta=0.865545 -> V=1.0, theta=0.0
% INFO    : Bus 89743	: V=1.0012958, theta=0.87031 -> V=1.0, theta=0.0
% INFO    : Bus 89744	: V=1.0024032, theta=1.938787 -> V=1.0, theta=0.0
% INFO    : Bus 89745	: V=1.0022866, theta=1.947573 -> V=1.0, theta=0.0
% INFO    : Bus 89746	: V=1.0073531, theta=2.184053 -> V=1.0, theta=0.0
% INFO    : Bus 89747	: V=1.0007704, theta=2.33737 -> V=1.0, theta=0.0
% INFO    : Bus 89748	: V=1.0051499, theta=2.88113 -> V=1.0, theta=0.0
% INFO    : Bus 89749	: V=1.0004315, theta=2.539064 -> V=1.0, theta=0.0
% INFO    : Bus 89750	: V=0.9968061, theta=1.190083 -> V=1.0, theta=0.0
% INFO    : Bus 89751	: V=0.999596, theta=2.569137 -> V=1.0, theta=0.0
% INFO    : Bus 89752	: V=1.0049921, theta=2.715927 -> V=1.0, theta=0.0
% INFO    : Bus 89753	: V=0.9993677, theta=3.204384 -> V=1.0, theta=0.0
% INFO    : Bus 89754	: V=0.9926535, theta=1.441767 -> V=1.0, theta=0.0
% INFO    : Bus 89755	: V=0.9941834, theta=1.457797 -> V=1.0, theta=0.0
% INFO    : Bus 89756	: V=0.9935197, theta=1.223559 -> V=1.0, theta=0.0
% INFO    : Bus 89757	: V=0.9896867, theta=0.638497 -> V=1.0, theta=0.0
% INFO    : Bus 89758	: V=0.9876972, theta=1.57226 -> V=1.0, theta=0.0
% INFO    : Bus 89759	: V=0.9933346, theta=1.188443 -> V=1.0, theta=0.0
% INFO    : Bus 89760	: V=0.9950509, theta=0.784876 -> V=1.0, theta=0.0
% INFO    : Bus 89761	: V=0.9824231, theta=2.791648 -> V=1.0, theta=0.0
% INFO    : Bus 89762	: V=1.0008981, theta=3.808843 -> V=1.0, theta=0.0
% INFO    : Bus 89763	: V=1.0053821, theta=2.196043 -> V=1.0, theta=0.0
% INFO    : Bus 89764	: V=0.9954393, theta=2.087857 -> V=1.0, theta=0.0
% INFO    : Bus 89765	: V=0.9952802, theta=2.404193 -> V=1.0, theta=0.0
% INFO    : Bus 89766	: V=1.0004114, theta=24.935565 -> V=1.0, theta=0.0
% INFO    : Bus 89767	: V=1.007245, theta=27.183719 -> V=1.0, theta=0.0
% INFO    : Bus 89768	: V=1.0029198, theta=24.282252 -> V=1.0, theta=0.0
% INFO    : Bus 89769	: V=1.0038322, theta=20.67721 -> V=1.0, theta=0.0
% INFO    : Bus 89770	: V=0.9995559, theta=19.599359 -> V=1.0, theta=0.0
% INFO    : Bus 89771	: V=0.9957159, theta=18.967398 -> V=1.0, theta=0.0
% INFO    : Bus 89772	: V=0.9889767, theta=28.906182 -> V=1.0, theta=0.0
% INFO    : Bus 89773	: V=0.9853083, theta=0.211603 -> V=1.0, theta=0.0
% INFO    : Bus 89774	: V=0.9926181, theta=0.701657 -> V=1.0, theta=0.0
% INFO    : Bus 89775	: V=0.9859245, theta=7.508346 -> V=1.0, theta=0.0
% INFO    : Bus 89776	: V=0.9908736, theta=8.148622 -> V=1.0, theta=0.0
% INFO    : Bus 89777	: V=0.98332, theta=12.705825 -> V=1.0, theta=0.0
% INFO    : Bus 89778	: V=0.9837926, theta=12.71329 -> V=1.0, theta=0.0
% INFO    : Bus 89779	: V=0.9851449, theta=11.827113 -> V=1.0, theta=0.0
% INFO    : Bus 89780	: V=0.9730854, theta=9.136389 -> V=1.0, theta=0.0
% INFO    : Bus 89781	: V=1.0147221, theta=32.870148 -> V=1.0, theta=0.0
% INFO    : Bus 89782	: V=1.010866, theta=32.879648 -> V=1.0, theta=0.0
% INFO    : Bus 89783	: V=1.0046055, theta=31.801337 -> V=1.0, theta=0.0
% INFO    : Bus 89784	: V=1.0032184, theta=29.382487 -> V=1.0, theta=0.0
% INFO    : Bus 89785	: V=1.0154252, theta=33.057046 -> V=1.0, theta=0.0
% INFO    : Bus 89786	: V=1.0126533, theta=32.990714 -> V=1.0, theta=0.0
% INFO    : Bus 89787	: V=1.0068253, theta=28.674612 -> V=1.0, theta=0.0
% INFO    : Bus 89788	: V=0.9973756, theta=28.67618 -> V=1.0, theta=0.0
% INFO    : Bus 89789	: V=1.0108413, theta=33.045497 -> V=1.0, theta=0.0
% INFO    : Bus 89790	: V=1.0050136, theta=25.027645 -> V=1.0, theta=0.0
% INFO    : Bus 89791	: V=1.005553, theta=25.029602 -> V=1.0, theta=0.0
% INFO    : Bus 89792	: V=1.0086539, theta=25.110416 -> V=1.0, theta=0.0
% INFO    : Bus 89793	: V=1.0071025, theta=25.031935 -> V=1.0, theta=0.0
% INFO    : Bus 89794	: V=1.0056634, theta=25.03722 -> V=1.0, theta=0.0
% INFO    : Bus 89795	: V=1.0030476, theta=24.823105 -> V=1.0, theta=0.0
% INFO    : Bus 89796	: V=1.0028971, theta=24.924461 -> V=1.0, theta=0.0
% INFO    : Bus 89797	: V=1.0045828, theta=25.018568 -> V=1.0, theta=0.0
% INFO    : Bus 89798	: V=1.0045327, theta=25.019066 -> V=1.0, theta=0.0
% INFO    : Bus 89799	: V=1.0042307, theta=25.016026 -> V=1.0, theta=0.0
% INFO    : Bus 89800	: V=1.0009459, theta=24.897889 -> V=1.0, theta=0.0
% INFO    : Bus 89801	: V=1.0006264, theta=24.930795 -> V=1.0, theta=0.0
% INFO    : Bus 89802	: V=0.9995322, theta=24.942671 -> V=1.0, theta=0.0
% INFO    : Bus 89803	: V=0.9986522, theta=24.932477 -> V=1.0, theta=0.0
% INFO    : Bus 89804	: V=0.9937322, theta=24.991209 -> V=1.0, theta=0.0
% INFO    : Bus 89805	: V=0.9967066, theta=25.145066 -> V=1.0, theta=0.0
% INFO    : Bus 89806	: V=0.9962239, theta=25.168256 -> V=1.0, theta=0.0
% INFO    : Bus 89807	: V=0.9886771, theta=26.608696 -> V=1.0, theta=0.0
% INFO    : Bus 89808	: V=0.9991545, theta=25.050252 -> V=1.0, theta=0.0
% INFO    : Bus 89809	: V=1.0153787, theta=25.305061 -> V=1.0, theta=0.0
% INFO    : Bus 89810	: V=1.0105726, theta=25.189295 -> V=1.0, theta=0.0
% INFO    : Bus 89811	: V=1.0023438, theta=25.118135 -> V=1.0, theta=0.0
% INFO    : Bus 89812	: V=1.0044781, theta=24.618669 -> V=1.0, theta=0.0
% INFO    : Bus 89813	: V=1.0153495, theta=2.147649 -> V=1.0, theta=0.0
% INFO    : Bus 89814	: V=1.0173699, theta=1.929133 -> V=1.0, theta=0.0
% INFO    : Bus 89815	: V=1.0142378, theta=0.702907 -> V=1.0, theta=0.0
% INFO    : Bus 89816	: V=1.009276, theta=18.017546 -> V=1.0, theta=0.0
% INFO    : Bus 89817	: V=1.00356, theta=18.066585 -> V=1.0, theta=0.0
% INFO    : Bus 89818	: V=0.9818585, theta=11.371902 -> V=1.0, theta=0.0
% INFO    : Bus 89819	: V=0.9876455, theta=9.894625 -> V=1.0, theta=0.0
% INFO    : Bus 89820	: V=0.9994799, theta=-1.919585 -> V=1.0, theta=0.0
% INFO    : Bus 89821	: V=1.0133139, theta=27.631814 -> V=1.0, theta=0.0
% INFO    : Bus 89822	: V=1.0003796, theta=26.329022 -> V=1.0, theta=0.0
% INFO    : Bus 89823	: V=1.0135491, theta=1.222582 -> V=1.0, theta=0.0
% INFO    : Bus 89824	: V=1.0143584, theta=0.850573 -> V=1.0, theta=0.0
% INFO    : Bus 89825	: V=1.0102983, theta=-0.43631 -> V=1.0, theta=0.0
% INFO    : Bus 89826	: V=0.9846283, theta=3.044004 -> V=1.0, theta=0.0
% INFO    : Bus 89827	: V=1.0009164, theta=30.537745 -> V=1.0, theta=0.0
% INFO    : Bus 89828	: V=0.9975169, theta=30.504551 -> V=1.0, theta=0.0
% INFO    : Bus 89829	: V=0.9942752, theta=30.50773 -> V=1.0, theta=0.0
% INFO    : Bus 89830	: V=0.9963175, theta=30.484778 -> V=1.0, theta=0.0
% INFO    : Bus 89831	: V=0.9985254, theta=30.433929 -> V=1.0, theta=0.0
% INFO    : Bus 89832	: V=0.9986802, theta=30.416933 -> V=1.0, theta=0.0
% INFO    : Bus 89833	: V=0.9954095, theta=30.155201 -> V=1.0, theta=0.0
% INFO    : Bus 89834	: V=0.9950489, theta=30.279532 -> V=1.0, theta=0.0
% INFO    : Bus 89835	: V=1.0052344, theta=30.661744 -> V=1.0, theta=0.0
% INFO    : Bus 89836	: V=1.0002223, theta=30.488741 -> V=1.0, theta=0.0
% INFO    : Bus 89837	: V=0.995089, theta=-0.488763 -> V=1.0, theta=0.0
% INFO    : Bus 89838	: V=0.9949378, theta=-0.751476 -> V=1.0, theta=0.0
% INFO    : Bus 89839	: V=0.994423, theta=-0.461203 -> V=1.0, theta=0.0
% INFO    : Bus 89840	: V=0.9917799, theta=-0.10591 -> V=1.0, theta=0.0
% INFO    : Bus 89841	: V=0.9882221, theta=-0.051752 -> V=1.0, theta=0.0
% INFO    : Bus 89842	: V=0.9793403, theta=0.215454 -> V=1.0, theta=0.0
% INFO    : Bus 89843	: V=0.9840031, theta=0.04099 -> V=1.0, theta=0.0
% INFO    : Bus 89844	: V=0.9800754, theta=0.204345 -> V=1.0, theta=0.0
% INFO    : Bus 89845	: V=1.0041325, theta=-0.59237 -> V=1.0, theta=0.0
% INFO    : Bus 89846	: V=1.00096, theta=-0.534194 -> V=1.0, theta=0.0
% INFO    : Bus 89847	: V=0.9915253, theta=-0.109143 -> V=1.0, theta=0.0
% INFO    : Bus 89848	: V=0.9921156, theta=-0.552606 -> V=1.0, theta=0.0
% INFO    : Bus 89849	: V=0.9823035, theta=0.305115 -> V=1.0, theta=0.0
% INFO    : Bus 89850	: V=1.0083512, theta=1.168506 -> V=1.0, theta=0.0
% INFO    : Bus 89851	: V=1.0010142, theta=1.218382 -> V=1.0, theta=0.0
% INFO    : Bus 89852	: V=0.989758, theta=0.68851 -> V=1.0, theta=0.0
% INFO    : Bus 89853	: V=0.9871274, theta=0.276634 -> V=1.0, theta=0.0
% INFO    : Bus 89854	: V=1.0019985, theta=0.534994 -> V=1.0, theta=0.0
% INFO    : Bus 89855	: V=0.9890232, theta=1.326235 -> V=1.0, theta=0.0
% INFO    : Bus 89856	: V=0.9955551, theta=1.00566 -> V=1.0, theta=0.0
% INFO    : Bus 89857	: V=0.9870564, theta=0.435886 -> V=1.0, theta=0.0
% INFO    : Bus 89858	: V=1.0023695, theta=-0.825508 -> V=1.0, theta=0.0
% INFO    : Bus 89859	: V=0.9989905, theta=-0.948926 -> V=1.0, theta=0.0
% INFO    : Bus 89860	: V=0.9861217, theta=-1.789239 -> V=1.0, theta=0.0
% INFO    : Bus 89861	: V=0.9996235, theta=18.789243 -> V=1.0, theta=0.0
% INFO    : Bus 89862	: V=1.0028933, theta=18.6591 -> V=1.0, theta=0.0
% INFO    : Bus 89863	: V=1.0034954, theta=18.697099 -> V=1.0, theta=0.0
% INFO    : Bus 89864	: V=1.011741, theta=19.001126 -> V=1.0, theta=0.0
% INFO    : Bus 89865	: V=1.01075, theta=18.893093 -> V=1.0, theta=0.0
% INFO    : Bus 89866	: V=1.008591, theta=18.810093 -> V=1.0, theta=0.0
% INFO    : Bus 89867	: V=1.0049833, theta=18.620574 -> V=1.0, theta=0.0
% INFO    : Bus 89868	: V=1.014713, theta=19.256143 -> V=1.0, theta=0.0
% INFO    : Bus 89869	: V=1.0072595, theta=18.699646 -> V=1.0, theta=0.0
% INFO    : Bus 89870	: V=0.9992702, theta=18.290466 -> V=1.0, theta=0.0
% INFO    : Bus 89871	: V=1.0137291, theta=19.149979 -> V=1.0, theta=0.0
% INFO    : Bus 89872	: V=1.0033816, theta=18.485481 -> V=1.0, theta=0.0
% INFO    : Bus 89873	: V=1.004586, theta=18.402329 -> V=1.0, theta=0.0
% INFO    : Bus 89874	: V=1.0021847, theta=17.960233 -> V=1.0, theta=0.0
% INFO    : Bus 89875	: V=0.9988228, theta=17.824127 -> V=1.0, theta=0.0
% INFO    : Bus 89876	: V=1.0017107, theta=15.615044 -> V=1.0, theta=0.0
% INFO    : Bus 89877	: V=0.9941094, theta=14.75532 -> V=1.0, theta=0.0
% INFO    : Bus 89878	: V=1.013986, theta=18.991439 -> V=1.0, theta=0.0
% INFO    : Bus 89879	: V=1.0067656, theta=18.135279 -> V=1.0, theta=0.0
% INFO    : Bus 89880	: V=0.9893201, theta=16.14872 -> V=1.0, theta=0.0
% INFO    : Bus 89881	: V=0.9887332, theta=16.837865 -> V=1.0, theta=0.0
% INFO    : Bus 89882	: V=0.9956155, theta=11.055361 -> V=1.0, theta=0.0
% INFO    : Bus 89883	: V=1.000628, theta=8.479984 -> V=1.0, theta=0.0
% INFO    : Bus 89884	: V=1.003467, theta=34.075217 -> V=1.0, theta=0.0
% INFO    : Bus 89885	: V=0.9918503, theta=33.202471 -> V=1.0, theta=0.0
% INFO    : Bus 89886	: V=0.9900753, theta=33.191022 -> V=1.0, theta=0.0
% INFO    : Bus 89887	: V=0.9897595, theta=33.14643 -> V=1.0, theta=0.0
% INFO    : Bus 89888	: V=0.9855733, theta=33.095103 -> V=1.0, theta=0.0
% INFO    : Bus 89889	: V=1.0025345, theta=24.70422 -> V=1.0, theta=0.0
% INFO    : Bus 89890	: V=1.0105724, theta=25.084563 -> V=1.0, theta=0.0
% INFO    : Bus 89891	: V=1.0161376, theta=25.288358 -> V=1.0, theta=0.0
% INFO    : Bus 89892	: V=1.009399, theta=24.843551 -> V=1.0, theta=0.0
% INFO    : Bus 89893	: V=0.9987735, theta=24.724168 -> V=1.0, theta=0.0
% INFO    : Bus 89894	: V=1.010245, theta=24.4434 -> V=1.0, theta=0.0
% INFO    : Bus 89895	: V=1.008762, theta=24.295624 -> V=1.0, theta=0.0
% INFO    : Bus 89896	: V=1.0110641, theta=24.231543 -> V=1.0, theta=0.0
% INFO    : Bus 89897	: V=1.0079369, theta=24.04326 -> V=1.0, theta=0.0
% INFO    : Bus 89898	: V=1.0023633, theta=23.230542 -> V=1.0, theta=0.0
% INFO    : Bus 89899	: V=1.0120226, theta=23.686897 -> V=1.0, theta=0.0
% INFO    : Bus 89900	: V=0.9977912, theta=21.364513 -> V=1.0, theta=0.0
% INFO    : Bus 89901	: V=1.0018797, theta=24.523326 -> V=1.0, theta=0.0
% INFO    : Bus 89902	: V=0.9994753, theta=-0.501494 -> V=1.0, theta=0.0
% INFO    : Bus 89903	: V=1.007566, theta=13.480099 -> V=1.0, theta=0.0
% INFO    : Bus 89904	: V=1.008419, theta=13.461242 -> V=1.0, theta=0.0
% INFO    : Bus 89905	: V=1.0090123, theta=13.525712 -> V=1.0, theta=0.0
% INFO    : Bus 89906	: V=0.9856858, theta=14.854253 -> V=1.0, theta=0.0
% INFO    : Bus 89907	: V=0.9867717, theta=14.759061 -> V=1.0, theta=0.0
% INFO    : Bus 89908	: V=1.00045, theta=14.327264 -> V=1.0, theta=0.0
% INFO    : Bus 89909	: V=1.0080293, theta=14.196882 -> V=1.0, theta=0.0
% INFO    : Bus 89910	: V=0.9785531, theta=0.107841 -> V=1.0, theta=0.0
% INFO    : Bus 89911	: V=0.9876083, theta=24.953517 -> V=1.0, theta=0.0
% INFO    : Bus 89912	: V=0.9890879, theta=0.503643 -> V=1.0, theta=0.0
% INFO    : Bus 89913	: V=0.9837396, theta=-0.977146 -> V=1.0, theta=0.0
% INFO    : Bus 89914	: V=1.0050595, theta=32.273988 -> V=1.0, theta=0.0
% INFO    : Bus 89915	: V=1.0169918, theta=33.218303 -> V=1.0, theta=0.0
% INFO    : Bus 89916	: V=1.0158038, theta=33.458213 -> V=1.0, theta=0.0
% INFO    : Bus 89917	: V=1.0155081, theta=32.790095 -> V=1.0, theta=0.0
% INFO    : Bus 89918	: V=1.0122689, theta=32.350772 -> V=1.0, theta=0.0
% INFO    : Bus 89919	: V=1.0049644, theta=32.067014 -> V=1.0, theta=0.0
% INFO    : Bus 89920	: V=1.0061533, theta=32.019789 -> V=1.0, theta=0.0
% INFO    : Bus 89921	: V=1.0087281, theta=31.93221 -> V=1.0, theta=0.0
% INFO    : Bus 89922	: V=0.9916217, theta=21.128156 -> V=1.0, theta=0.0
% INFO    : Bus 89923	: V=0.9887212, theta=20.990838 -> V=1.0, theta=0.0
% INFO    : Bus 89924	: V=0.9900408, theta=21.0031 -> V=1.0, theta=0.0
% INFO    : Bus 89925	: V=0.9947541, theta=21.139029 -> V=1.0, theta=0.0
% INFO    : Bus 89926	: V=0.986966, theta=21.078818 -> V=1.0, theta=0.0
% INFO    : Bus 89927	: V=0.9866738, theta=21.216117 -> V=1.0, theta=0.0
% INFO    : Bus 89928	: V=0.9965799, theta=20.875695 -> V=1.0, theta=0.0
% INFO    : Bus 89929	: V=0.9967603, theta=20.977505 -> V=1.0, theta=0.0
% INFO    : Bus 89930	: V=0.9962508, theta=21.043414 -> V=1.0, theta=0.0
% INFO    : Bus 89931	: V=0.9871173, theta=21.321904 -> V=1.0, theta=0.0
% INFO    : Bus 89932	: V=0.9841389, theta=21.669702 -> V=1.0, theta=0.0
% INFO    : Bus 89933	: V=0.9930231, theta=22.058699 -> V=1.0, theta=0.0
% INFO    : Bus 89934	: V=0.9891709, theta=21.994831 -> V=1.0, theta=0.0
% INFO    : Bus 89935	: V=0.9844831, theta=21.837931 -> V=1.0, theta=0.0
% INFO    : Bus 89936	: V=1.0087812, theta=21.763691 -> V=1.0, theta=0.0
% INFO    : Bus 89937	: V=1.0006198, theta=21.257259 -> V=1.0, theta=0.0
% INFO    : Bus 89938	: V=1.0031517, theta=21.160973 -> V=1.0, theta=0.0
% INFO    : Bus 89939	: V=1.004437, theta=21.363521 -> V=1.0, theta=0.0
% INFO    : Bus 89940	: V=1.003119, theta=21.293623 -> V=1.0, theta=0.0
% INFO    : Bus 89941	: V=1.0094696, theta=22.022476 -> V=1.0, theta=0.0
% INFO    : Bus 89942	: V=1.0077859, theta=21.679548 -> V=1.0, theta=0.0
% INFO    : Bus 89943	: V=1.0056242, theta=21.533654 -> V=1.0, theta=0.0
% INFO    : Bus 89944	: V=1.0085304, theta=21.804089 -> V=1.0, theta=0.0
% INFO    : Bus 89945	: V=1.000203, theta=20.474525 -> V=1.0, theta=0.0
% INFO    : Bus 89946	: V=1.0015214, theta=21.168753 -> V=1.0, theta=0.0
% INFO    : Bus 89947	: V=0.9892246, theta=19.833875 -> V=1.0, theta=0.0
% INFO    : Bus 89948	: V=0.992549, theta=19.663325 -> V=1.0, theta=0.0
% INFO    : Bus 89949	: V=0.9952294, theta=19.978115 -> V=1.0, theta=0.0
% INFO    : Bus 89950	: V=0.9904172, theta=19.727897 -> V=1.0, theta=0.0
% INFO    : Bus 89951	: V=0.9981497, theta=19.480749 -> V=1.0, theta=0.0
% INFO    : Bus 89952	: V=0.9971957, theta=19.621809 -> V=1.0, theta=0.0
% INFO    : Bus 89953	: V=1.0002954, theta=20.486878 -> V=1.0, theta=0.0
% INFO    : Bus 89954	: V=1.0003499, theta=20.594956 -> V=1.0, theta=0.0
% INFO    : Bus 89955	: V=1.0004806, theta=20.640529 -> V=1.0, theta=0.0
% INFO    : Bus 89956	: V=1.002284, theta=20.937931 -> V=1.0, theta=0.0
% INFO    : Bus 89957	: V=1.0023379, theta=20.956425 -> V=1.0, theta=0.0
% INFO    : Bus 89958	: V=1.0017056, theta=20.801992 -> V=1.0, theta=0.0
% INFO    : Bus 89959	: V=1.0004594, theta=20.583056 -> V=1.0, theta=0.0
% INFO    : Bus 89960	: V=1.0013124, theta=20.383054 -> V=1.0, theta=0.0
% INFO    : Bus 89961	: V=1.0038928, theta=20.758614 -> V=1.0, theta=0.0
% INFO    : Bus 89962	: V=0.9997915, theta=20.604903 -> V=1.0, theta=0.0
% INFO    : Bus 89963	: V=1.003321, theta=21.172006 -> V=1.0, theta=0.0
% INFO    : Bus 89964	: V=1.0102083, theta=20.931411 -> V=1.0, theta=0.0
% INFO    : Bus 89965	: V=1.0054997, theta=20.890687 -> V=1.0, theta=0.0
% INFO    : Bus 89966	: V=1.0066686, theta=20.598829 -> V=1.0, theta=0.0
% INFO    : Bus 89967	: V=1.0009676, theta=20.268197 -> V=1.0, theta=0.0
% INFO    : Bus 89968	: V=1.0044578, theta=21.253826 -> V=1.0, theta=0.0
% INFO    : Bus 89969	: V=1.0048864, theta=21.26577 -> V=1.0, theta=0.0
% INFO    : Bus 89970	: V=1.0052581, theta=21.269186 -> V=1.0, theta=0.0
% INFO    : Bus 89971	: V=1.0078155, theta=21.350826 -> V=1.0, theta=0.0
% INFO    : Bus 89972	: V=1.0112855, theta=21.758752 -> V=1.0, theta=0.0
% INFO    : Bus 89973	: V=1.0080922, theta=21.558084 -> V=1.0, theta=0.0
% INFO    : Bus 89974	: V=1.0087274, theta=21.683996 -> V=1.0, theta=0.0
% INFO    : Bus 89975	: V=1.0174803, theta=21.816617 -> V=1.0, theta=0.0
% INFO    : Bus 89976	: V=1.0102654, theta=21.530203 -> V=1.0, theta=0.0
% INFO    : Bus 89977	: V=1.0148955, theta=21.482319 -> V=1.0, theta=0.0
% INFO    : Bus 89978	: V=0.9879573, theta=17.72468 -> V=1.0, theta=0.0
% INFO    : Bus 89979	: V=0.987978, theta=18.238426 -> V=1.0, theta=0.0
% INFO    : Bus 89980	: V=0.9982161, theta=17.874229 -> V=1.0, theta=0.0
% INFO    : Bus 89981	: V=0.9837849, theta=18.199284 -> V=1.0, theta=0.0
% INFO    : Bus 89982	: V=0.9823847, theta=18.219301 -> V=1.0, theta=0.0
% INFO    : Bus 89983	: V=0.9874504, theta=18.611189 -> V=1.0, theta=0.0
% INFO    : Bus 89984	: V=0.9893532, theta=18.929386 -> V=1.0, theta=0.0
% INFO    : Bus 89985	: V=0.9860115, theta=18.512787 -> V=1.0, theta=0.0
% INFO    : Bus 89986	: V=0.9852552, theta=18.406587 -> V=1.0, theta=0.0
% INFO    : Bus 89987	: V=0.994299, theta=18.392261 -> V=1.0, theta=0.0
% INFO    : Bus 89988	: V=0.9907172, theta=18.440288 -> V=1.0, theta=0.0
% INFO    : Bus 89989	: V=0.9918606, theta=18.370059 -> V=1.0, theta=0.0
% INFO    : Bus 89990	: V=0.994965, theta=18.651377 -> V=1.0, theta=0.0
% INFO    : Bus 89991	: V=0.9973856, theta=18.782351 -> V=1.0, theta=0.0
% INFO    : Bus 89992	: V=0.9942769, theta=18.570576 -> V=1.0, theta=0.0
% INFO    : Bus 89993	: V=0.9891247, theta=18.485324 -> V=1.0, theta=0.0
% INFO    : Bus 89994	: V=1.0028735, theta=20.85847 -> V=1.0, theta=0.0
% INFO    : Bus 89995	: V=1.0116024, theta=-0.630841 -> V=1.0, theta=0.0
% INFO    : Bus 89996	: V=1.0140135, theta=-0.526091 -> V=1.0, theta=0.0
% INFO    : Bus 89997	: V=0.9993368, theta=-1.62883 -> V=1.0, theta=0.0
% INFO    : Bus 89998	: V=1.0173444, theta=-0.857576 -> V=1.0, theta=0.0
% INFO    : Bus 89999	: V=1.0139632, theta=-0.827398 -> V=1.0, theta=0.0
% INFO    : Bus 90000	: V=1.018016, theta=-0.945164 -> V=1.0, theta=0.0
% INFO    : Bus 90001	: V=1.0146467, theta=-0.971017 -> V=1.0, theta=0.0
% INFO    : Bus 90002	: V=1.0195535, theta=-1.104135 -> V=1.0, theta=0.0
% INFO    : Bus 90003	: V=0.9890306, theta=32.749893 -> V=1.0, theta=0.0
% INFO    : Bus 90004	: V=0.9887996, theta=32.718068 -> V=1.0, theta=0.0
% INFO    : Bus 90005	: V=0.9904209, theta=32.71779 -> V=1.0, theta=0.0
% INFO    : Bus 90006	: V=0.9951986, theta=32.67727 -> V=1.0, theta=0.0
% INFO    : Bus 90007	: V=0.9932263, theta=32.649237 -> V=1.0, theta=0.0
% INFO    : Bus 90008	: V=0.9951193, theta=32.81098 -> V=1.0, theta=0.0
% INFO    : Bus 90009	: V=0.9965891, theta=32.808474 -> V=1.0, theta=0.0
% INFO    : Bus 90010	: V=0.9997825, theta=32.820856 -> V=1.0, theta=0.0
% INFO    : Bus 90011	: V=1.0011362, theta=32.867531 -> V=1.0, theta=0.0
% INFO    : Bus 90012	: V=0.9997548, theta=32.816526 -> V=1.0, theta=0.0
% INFO    : Bus 90013	: V=0.9931157, theta=32.889558 -> V=1.0, theta=0.0
% INFO    : Bus 90014	: V=0.9937858, theta=32.846441 -> V=1.0, theta=0.0
% INFO    : Bus 90015	: V=0.9933628, theta=32.87995 -> V=1.0, theta=0.0
% INFO    : Bus 90016	: V=0.999136, theta=32.58812 -> V=1.0, theta=0.0
% INFO    : Bus 90017	: V=0.9941644, theta=32.646891 -> V=1.0, theta=0.0
% INFO    : Bus 90018	: V=0.9970151, theta=33.225034 -> V=1.0, theta=0.0
% INFO    : Bus 90019	: V=0.9919534, theta=32.928158 -> V=1.0, theta=0.0
% INFO    : Bus 90020	: V=0.987711, theta=32.71012 -> V=1.0, theta=0.0
% INFO    : Bus 90021	: V=0.9897974, theta=32.830333 -> V=1.0, theta=0.0
% INFO    : Bus 90022	: V=1.0073555, theta=33.84963 -> V=1.0, theta=0.0
% INFO    : Bus 90023	: V=1.006266, theta=33.7008 -> V=1.0, theta=0.0
% INFO    : Bus 90024	: V=0.9986122, theta=33.617776 -> V=1.0, theta=0.0
% INFO    : Bus 90025	: V=0.9967547, theta=33.760595 -> V=1.0, theta=0.0
% INFO    : Bus 90026	: V=1.0042637, theta=33.315411 -> V=1.0, theta=0.0
% INFO    : Bus 90027	: V=0.9986396, theta=33.065529 -> V=1.0, theta=0.0
% INFO    : Bus 90028	: V=1.0060079, theta=32.978173 -> V=1.0, theta=0.0
% INFO    : Bus 90029	: V=1.0016509, theta=32.823036 -> V=1.0, theta=0.0
% INFO    : Bus 90030	: V=1.0089403, theta=22.716372 -> V=1.0, theta=0.0
% INFO    : Bus 90031	: V=1.0073354, theta=22.723061 -> V=1.0, theta=0.0
% INFO    : Bus 90032	: V=1.003535, theta=22.902495 -> V=1.0, theta=0.0
% INFO    : Bus 90033	: V=0.9996153, theta=24.393337 -> V=1.0, theta=0.0
% INFO    : Bus 90034	: V=0.9957438, theta=22.383892 -> V=1.0, theta=0.0
% INFO    : Bus 90035	: V=1.0022579, theta=7.697699 -> V=1.0, theta=0.0
% INFO    : Bus 90036	: V=0.974036, theta=35.463242 -> V=1.0, theta=0.0
% INFO    : Bus 90037	: V=1.0097622, theta=17.798913 -> V=1.0, theta=0.0
% INFO    : Bus 90038	: V=1.0105676, theta=18.205294 -> V=1.0, theta=0.0
% INFO    : Bus 90039	: V=1.0119602, theta=28.137189 -> V=1.0, theta=0.0
% INFO    : Bus 90040	: V=1.0101875, theta=28.883787 -> V=1.0, theta=0.0
% INFO    : Bus 90041	: V=1.0084921, theta=26.575056 -> V=1.0, theta=0.0
% INFO    : Bus 90042	: V=1.0075275, theta=28.540177 -> V=1.0, theta=0.0
% INFO    : Bus 90043	: V=1.0080938, theta=28.556112 -> V=1.0, theta=0.0
% INFO    : Bus 90044	: V=1.0093507, theta=28.497764 -> V=1.0, theta=0.0
% INFO    : Bus 90045	: V=1.0097871, theta=28.505453 -> V=1.0, theta=0.0
% INFO    : Bus 90046	: V=1.0083322, theta=28.711628 -> V=1.0, theta=0.0
% INFO    : Bus 90047	: V=1.0048816, theta=28.55408 -> V=1.0, theta=0.0
% INFO    : Bus 90048	: V=1.001214, theta=28.385447 -> V=1.0, theta=0.0
% INFO    : Bus 90049	: V=1.0061192, theta=28.334304 -> V=1.0, theta=0.0
% INFO    : Bus 90050	: V=1.0089216, theta=28.605331 -> V=1.0, theta=0.0
% INFO    : Bus 90051	: V=1.0115201, theta=28.396994 -> V=1.0, theta=0.0
% INFO    : Bus 90052	: V=1.0101267, theta=28.16705 -> V=1.0, theta=0.0
% INFO    : Bus 90053	: V=0.983913, theta=19.166583 -> V=1.0, theta=0.0
% INFO    : Bus 90054	: V=0.9859261, theta=19.207363 -> V=1.0, theta=0.0
% INFO    : Bus 90055	: V=1.0019863, theta=30.035921 -> V=1.0, theta=0.0
% INFO    : Bus 90056	: V=0.9996826, theta=31.203783 -> V=1.0, theta=0.0
% INFO    : Bus 90057	: V=1.010257, theta=29.307221 -> V=1.0, theta=0.0
% INFO    : Bus 90058	: V=0.9926893, theta=31.372543 -> V=1.0, theta=0.0
% INFO    : Bus 90059	: V=1.0054302, theta=29.018241 -> V=1.0, theta=0.0
% INFO    : Bus 90060	: V=1.0035557, theta=29.280372 -> V=1.0, theta=0.0
% INFO    : Bus 90061	: V=1.0092054, theta=20.105377 -> V=1.0, theta=0.0
% INFO    : Bus 90062	: V=1.0188193, theta=19.547193 -> V=1.0, theta=0.0
% INFO    : Bus 90063	: V=1.008381, theta=17.521985 -> V=1.0, theta=0.0
% INFO    : Bus 90064	: V=1.0114903, theta=17.786407 -> V=1.0, theta=0.0
% INFO    : Bus 90065	: V=1.0084028, theta=20.60493 -> V=1.0, theta=0.0
% INFO    : Bus 90066	: V=1.0031181, theta=16.35537 -> V=1.0, theta=0.0
% INFO    : Bus 90067	: V=1.0068903, theta=15.733739 -> V=1.0, theta=0.0
% INFO    : Bus 90068	: V=1.017058, theta=9.824247 -> V=1.0, theta=0.0
% INFO    : Bus 90069	: V=1.0039797, theta=29.867344 -> V=1.0, theta=0.0
% INFO    : Bus 90070	: V=0.9995723, theta=29.1279 -> V=1.0, theta=0.0
% INFO    : Bus 90071	: V=1.0054603, theta=36.009488 -> V=1.0, theta=0.0
% INFO    : Bus 90072	: V=1.0086108, theta=36.828376 -> V=1.0, theta=0.0
% INFO    : Bus 90073	: V=1.011712, theta=36.032215 -> V=1.0, theta=0.0
% INFO    : Bus 90074	: V=1.0088205, theta=18.581665 -> V=1.0, theta=0.0
% INFO    : Bus 90075	: V=0.9905024, theta=32.598393 -> V=1.0, theta=0.0
% INFO    : Bus 90076	: V=0.9838116, theta=32.572182 -> V=1.0, theta=0.0
% INFO    : Bus 90077	: V=0.9970788, theta=13.108173 -> V=1.0, theta=0.0
% INFO    : Bus 90078	: V=1.016321, theta=23.268665 -> V=1.0, theta=0.0
% INFO    : Bus 90079	: V=0.9842733, theta=34.17852 -> V=1.0, theta=0.0
% INFO    : Bus 90080	: V=0.9861079, theta=33.447746 -> V=1.0, theta=0.0
% INFO    : Bus 90081	: V=1.0195213, theta=33.616132 -> V=1.0, theta=0.0
% INFO    : Bus 90082	: V=1.0187014, theta=33.572051 -> V=1.0, theta=0.0
% INFO    : Bus 90083	: V=1.0175817, theta=33.653507 -> V=1.0, theta=0.0
% INFO    : Bus 90084	: V=1.0150435, theta=33.536428 -> V=1.0, theta=0.0
% INFO    : Bus 90085	: V=1.0153789, theta=33.489585 -> V=1.0, theta=0.0
% INFO    : Bus 90086	: V=1.0154859, theta=33.533004 -> V=1.0, theta=0.0
% INFO    : Bus 90087	: V=1.0063578, theta=32.129541 -> V=1.0, theta=0.0
% INFO    : Bus 90088	: V=1.0015441, theta=12.149482 -> V=1.0, theta=0.0
% INFO    : Bus 90089	: V=0.9999366, theta=12.207088 -> V=1.0, theta=0.0
% INFO    : Bus 90090	: V=0.9958823, theta=14.870924 -> V=1.0, theta=0.0
% INFO    : Bus 90091	: V=0.9966009, theta=14.075172 -> V=1.0, theta=0.0
% INFO    : Bus 90092	: V=0.9914027, theta=14.443291 -> V=1.0, theta=0.0
% INFO    : Bus 90093	: V=0.9883156, theta=14.803886 -> V=1.0, theta=0.0
% INFO    : Bus 90094	: V=0.9904513, theta=14.871829 -> V=1.0, theta=0.0
% INFO    : Bus 90095	: V=0.9814783, theta=30.58237 -> V=1.0, theta=0.0
% INFO    : Bus 90096	: V=1.0137028, theta=22.995303 -> V=1.0, theta=0.0
% INFO    : Bus 90097	: V=1.0159638, theta=23.01371 -> V=1.0, theta=0.0
% INFO    : Bus 90098	: V=1.0186667, theta=23.021804 -> V=1.0, theta=0.0
% INFO    : Bus 90099	: V=1.0057062, theta=20.905951 -> V=1.0, theta=0.0
% INFO    : Bus 90100	: V=1.0191645, theta=26.693561 -> V=1.0, theta=0.0
% INFO    : Bus 90101	: V=1.0135457, theta=27.731896 -> V=1.0, theta=0.0
% INFO    : Bus 90102	: V=1.0092589, theta=34.994596 -> V=1.0, theta=0.0
% INFO    : Bus 90103	: V=1.0055011, theta=34.662385 -> V=1.0, theta=0.0
% INFO    : Bus 90104	: V=1.0039533, theta=34.698174 -> V=1.0, theta=0.0
% INFO    : Bus 90105	: V=1.0037063, theta=34.665383 -> V=1.0, theta=0.0
% INFO    : Bus 90106	: V=1.003354, theta=34.634831 -> V=1.0, theta=0.0
% INFO    : Bus 90107	: V=1.0027666, theta=34.782432 -> V=1.0, theta=0.0
% INFO    : Bus 90108	: V=0.9958897, theta=33.652619 -> V=1.0, theta=0.0
% INFO    : Bus 90109	: V=1.009537, theta=27.332868 -> V=1.0, theta=0.0
% INFO    : Bus 90110	: V=0.9934214, theta=30.024074 -> V=1.0, theta=0.0
% INFO    : Bus 90111	: V=0.9972155, theta=32.843016 -> V=1.0, theta=0.0
% INFO    : Bus 90112	: V=0.9983913, theta=32.707862 -> V=1.0, theta=0.0
% INFO    : Bus 90113	: V=1.016841, theta=33.527737 -> V=1.0, theta=0.0
% INFO    : Bus 90114	: V=1.0113374, theta=32.762888 -> V=1.0, theta=0.0
% INFO    : Bus 90115	: V=1.001196, theta=1.908961 -> V=1.0, theta=0.0
% INFO    : Bus 90116	: V=0.9930297, theta=17.10659 -> V=1.0, theta=0.0
% INFO    : Bus 90117	: V=0.9991826, theta=12.623847 -> V=1.0, theta=0.0
% INFO    : Bus 90118	: V=1.0117406, theta=24.853449 -> V=1.0, theta=0.0
% INFO    : Bus 90119	: V=1.0062557, theta=24.098578 -> V=1.0, theta=0.0
% INFO    : Bus 90120	: V=1.0078419, theta=34.421777 -> V=1.0, theta=0.0
% INFO    : Bus 90121	: V=1.0133653, theta=28.855711 -> V=1.0, theta=0.0
% INFO    : Bus 90122	: V=1.0032423, theta=25.795294 -> V=1.0, theta=0.0
% INFO    : Bus 90123	: V=1.0083728, theta=6.904068 -> V=1.0, theta=0.0
% INFO    : Bus 90124	: V=1.0109958, theta=6.459002 -> V=1.0, theta=0.0
% INFO    : Bus 90125	: V=0.9968498, theta=20.920705 -> V=1.0, theta=0.0
% INFO    : Bus 90126	: V=0.9858965, theta=24.077333 -> V=1.0, theta=0.0
% INFO    : Bus 90127	: V=1.0015068, theta=24.469786 -> V=1.0, theta=0.0
% INFO    : Bus 90128	: V=1.0020884, theta=33.605639 -> V=1.0, theta=0.0
% INFO    : Bus 90129	: V=1.0051448, theta=32.612788 -> V=1.0, theta=0.0
% INFO    : Bus 90130	: V=1.004873, theta=22.792262 -> V=1.0, theta=0.0
% INFO    : Bus 90131	: V=1.0017725, theta=19.555896 -> V=1.0, theta=0.0
% INFO    : Bus 90132	: V=0.9961012, theta=20.127263 -> V=1.0, theta=0.0
% INFO    : Bus 90133	: V=0.9971662, theta=27.701468 -> V=1.0, theta=0.0
% INFO    : Bus 90134	: V=1.011519, theta=28.31506 -> V=1.0, theta=0.0
% INFO    : Bus 90135	: V=1.0059725, theta=27.907503 -> V=1.0, theta=0.0
% INFO    : Bus 90136	: V=1.0057858, theta=27.85309 -> V=1.0, theta=0.0
% INFO    : Bus 90137	: V=0.997007, theta=26.868535 -> V=1.0, theta=0.0
% INFO    : Bus 90138	: V=1.0035343, theta=31.397186 -> V=1.0, theta=0.0
% INFO    : Bus 90139	: V=1.0026379, theta=31.25756 -> V=1.0, theta=0.0
% INFO    : Bus 90140	: V=0.9960392, theta=29.69962 -> V=1.0, theta=0.0
% INFO    : Bus 90141	: V=0.9921828, theta=28.003602 -> V=1.0, theta=0.0
% INFO    : Bus 90142	: V=0.9917878, theta=19.595476 -> V=1.0, theta=0.0
% INFO    : Bus 90143	: V=0.9971093, theta=19.888977 -> V=1.0, theta=0.0
% INFO    : Bus 90144	: V=1.0082989, theta=15.582467 -> V=1.0, theta=0.0
% INFO    : Bus 90145	: V=1.0131677, theta=15.017476 -> V=1.0, theta=0.0
% INFO    : Bus 90146	: V=1.0026927, theta=28.711238 -> V=1.0, theta=0.0
% INFO    : Bus 90147	: V=1.0088782, theta=28.674198 -> V=1.0, theta=0.0
% INFO    : Bus 90148	: V=1.0038571, theta=28.685875 -> V=1.0, theta=0.0
% INFO    : Bus 90149	: V=1.0098318, theta=28.73375 -> V=1.0, theta=0.0
% INFO    : Bus 90150	: V=1.0086604, theta=28.702612 -> V=1.0, theta=0.0
% INFO    : Bus 90151	: V=1.0071372, theta=28.664627 -> V=1.0, theta=0.0
% INFO    : Bus 90152	: V=1.0092308, theta=28.680058 -> V=1.0, theta=0.0
% INFO    : Bus 90153	: V=1.0139111, theta=28.697585 -> V=1.0, theta=0.0
% INFO    : Bus 90154	: V=1.0167419, theta=28.770591 -> V=1.0, theta=0.0
% INFO    : Bus 90155	: V=1.014853, theta=28.588951 -> V=1.0, theta=0.0
% INFO    : Bus 90156	: V=1.010752, theta=28.377452 -> V=1.0, theta=0.0
% INFO    : Bus 90157	: V=1.0135772, theta=28.465246 -> V=1.0, theta=0.0
% INFO    : Bus 90158	: V=1.0089445, theta=28.390324 -> V=1.0, theta=0.0
% INFO    : Bus 90159	: V=1.0074812, theta=28.348932 -> V=1.0, theta=0.0
% INFO    : Bus 90160	: V=1.0135573, theta=28.444968 -> V=1.0, theta=0.0
% INFO    : Bus 90161	: V=1.004812, theta=28.985306 -> V=1.0, theta=0.0
% INFO    : Bus 90162	: V=1.0134886, theta=24.888452 -> V=1.0, theta=0.0
% INFO    : Bus 90163	: V=1.0024075, theta=15.074259 -> V=1.0, theta=0.0
% INFO    : Bus 90164	: V=0.99303, theta=18.230408 -> V=1.0, theta=0.0
% INFO    : Bus 90165	: V=0.983609, theta=16.39899 -> V=1.0, theta=0.0
% INFO    : Bus 90166	: V=0.9916083, theta=13.483516 -> V=1.0, theta=0.0
% INFO    : Bus 90167	: V=1.0026332, theta=19.418991 -> V=1.0, theta=0.0
% INFO    : Bus 90168	: V=0.9989544, theta=17.695133 -> V=1.0, theta=0.0
% INFO    : Bus 90169	: V=1.0100422, theta=26.191282 -> V=1.0, theta=0.0
% INFO    : Bus 90170	: V=1.0103503, theta=25.782428 -> V=1.0, theta=0.0
% INFO    : Bus 90171	: V=1.0101369, theta=25.940343 -> V=1.0, theta=0.0
% INFO    : Bus 90172	: V=1.0019905, theta=3.147925 -> V=1.0, theta=0.0
% INFO    : Bus 90173	: V=1.0246831, theta=37.852094 -> V=1.0, theta=0.0
% INFO    : Bus 90174	: V=1.0061002, theta=8.346869 -> V=1.0, theta=0.0
% INFO    : Bus 90175	: V=1.0066147, theta=6.971974 -> V=1.0, theta=0.0
% INFO    : Bus 90176	: V=1.0062842, theta=7.518401 -> V=1.0, theta=0.0
% INFO    : Bus 90177	: V=1.0051876, theta=8.049613 -> V=1.0, theta=0.0
% INFO    : Bus 90178	: V=1.0046383, theta=17.117573 -> V=1.0, theta=0.0
% INFO    : Bus 90179	: V=1.0073242, theta=17.091417 -> V=1.0, theta=0.0
% INFO    : Bus 90180	: V=1.0010947, theta=5.304151 -> V=1.0, theta=0.0
% INFO    : Bus 90181	: V=1.0129525, theta=29.023367 -> V=1.0, theta=0.0
% INFO    : Bus 90182	: V=1.0108029, theta=28.92737 -> V=1.0, theta=0.0
% INFO    : Bus 90183	: V=1.0102073, theta=29.706944 -> V=1.0, theta=0.0
% INFO    : Bus 90184	: V=1.0061252, theta=29.303042 -> V=1.0, theta=0.0
% INFO    : Bus 90185	: V=1.0127721, theta=24.430741 -> V=1.0, theta=0.0
% INFO    : Bus 90186	: V=1.0124548, theta=23.962739 -> V=1.0, theta=0.0
% INFO    : Bus 90187	: V=1.0019936, theta=4.579846 -> V=1.0, theta=0.0
% INFO    : Bus 90188	: V=1.0063034, theta=24.468126 -> V=1.0, theta=0.0
% INFO    : Bus 90189	: V=0.9992059, theta=15.148063 -> V=1.0, theta=0.0
% INFO    : Bus 90190	: V=1.0125427, theta=14.099491 -> V=1.0, theta=0.0
% INFO    : Bus 90191	: V=1.0027215, theta=22.59378 -> V=1.0, theta=0.0
% INFO    : Bus 90192	: V=0.9948368, theta=15.606187 -> V=1.0, theta=0.0
% INFO    : Bus 90193	: V=0.9997798, theta=15.510245 -> V=1.0, theta=0.0
% INFO    : Bus 90194	: V=0.9954025, theta=15.462809 -> V=1.0, theta=0.0
% INFO    : Bus 90195	: V=0.9939472, theta=15.313306 -> V=1.0, theta=0.0
% INFO    : Bus 90196	: V=0.9912215, theta=15.065504 -> V=1.0, theta=0.0
% INFO    : Bus 90197	: V=0.9895535, theta=15.211902 -> V=1.0, theta=0.0
% INFO    : Bus 90198	: V=0.9920867, theta=15.175834 -> V=1.0, theta=0.0
% INFO    : Bus 90199	: V=0.9969577, theta=15.654503 -> V=1.0, theta=0.0
% INFO    : Bus 90200	: V=0.9910737, theta=15.301139 -> V=1.0, theta=0.0
% INFO    : Bus 90201	: V=0.9905144, theta=15.234114 -> V=1.0, theta=0.0
% INFO    : Bus 90202	: V=1.0039048, theta=15.938406 -> V=1.0, theta=0.0
% INFO    : Bus 90203	: V=1.017137, theta=16.9341 -> V=1.0, theta=0.0
% INFO    : Bus 90204	: V=0.9901626, theta=15.27624 -> V=1.0, theta=0.0
% INFO    : Bus 90205	: V=0.9940791, theta=15.408669 -> V=1.0, theta=0.0
% INFO    : Bus 90206	: V=0.9932979, theta=15.441529 -> V=1.0, theta=0.0
% INFO    : Bus 90207	: V=0.9936346, theta=15.349959 -> V=1.0, theta=0.0
% INFO    : Bus 90208	: V=0.9958404, theta=15.377514 -> V=1.0, theta=0.0
% INFO    : Bus 90209	: V=0.9925966, theta=15.39036 -> V=1.0, theta=0.0
% INFO    : Bus 90210	: V=0.9810509, theta=15.550804 -> V=1.0, theta=0.0
% INFO    : Bus 90211	: V=0.9820918, theta=15.792142 -> V=1.0, theta=0.0
% INFO    : Bus 90212	: V=0.9806699, theta=15.485017 -> V=1.0, theta=0.0
% INFO    : Bus 90213	: V=0.9854231, theta=14.886797 -> V=1.0, theta=0.0
% INFO    : Bus 90214	: V=0.9953962, theta=15.033634 -> V=1.0, theta=0.0
% INFO    : Bus 90215	: V=0.9946214, theta=15.097619 -> V=1.0, theta=0.0
% INFO    : Bus 90216	: V=0.9921367, theta=15.712782 -> V=1.0, theta=0.0
% INFO    : Bus 90217	: V=0.9938804, theta=16.355022 -> V=1.0, theta=0.0
% INFO    : Bus 90218	: V=0.9930031, theta=16.069426 -> V=1.0, theta=0.0
% INFO    : Bus 90219	: V=1.0085559, theta=16.208143 -> V=1.0, theta=0.0
% INFO    : Bus 90220	: V=0.9984497, theta=16.253695 -> V=1.0, theta=0.0
% INFO    : Bus 90221	: V=0.9889261, theta=15.012418 -> V=1.0, theta=0.0
% INFO    : Bus 90222	: V=0.9883591, theta=14.952547 -> V=1.0, theta=0.0
% INFO    : Bus 90223	: V=0.9884522, theta=14.881883 -> V=1.0, theta=0.0
% INFO    : Bus 90224	: V=0.987857, theta=14.930652 -> V=1.0, theta=0.0
% INFO    : Bus 90225	: V=0.9904405, theta=14.925376 -> V=1.0, theta=0.0
% INFO    : Bus 90226	: V=1.0043339, theta=4.633002 -> V=1.0, theta=0.0
% INFO    : Bus 90227	: V=1.0059929, theta=4.810753 -> V=1.0, theta=0.0
% INFO    : Bus 90228	: V=1.0043653, theta=4.608053 -> V=1.0, theta=0.0
% INFO    : Bus 90229	: V=1.0089477, theta=4.5592 -> V=1.0, theta=0.0
% INFO    : Bus 90230	: V=1.0018395, theta=4.25092 -> V=1.0, theta=0.0
% INFO    : Bus 90231	: V=1.009236, theta=5.037512 -> V=1.0, theta=0.0
% INFO    : Bus 90232	: V=1.0050672, theta=4.685797 -> V=1.0, theta=0.0
% INFO    : Bus 90233	: V=1.0110703, theta=18.84875 -> V=1.0, theta=0.0
% INFO    : Bus 90234	: V=1.0103167, theta=32.016609 -> V=1.0, theta=0.0
% INFO    : Bus 90235	: V=1.0094375, theta=31.229018 -> V=1.0, theta=0.0
% INFO    : Bus 90236	: V=1.0049464, theta=31.253359 -> V=1.0, theta=0.0
% INFO    : Bus 90237	: V=0.9964879, theta=30.176824 -> V=1.0, theta=0.0
% INFO    : Bus 90238	: V=0.9983209, theta=30.477013 -> V=1.0, theta=0.0
% INFO    : Bus 90239	: V=0.9979034, theta=30.291659 -> V=1.0, theta=0.0
% INFO    : Bus 90240	: V=0.9985165, theta=30.40363 -> V=1.0, theta=0.0
% INFO    : Bus 90241	: V=0.9971866, theta=30.367214 -> V=1.0, theta=0.0
% INFO    : Bus 90242	: V=0.9986345, theta=30.293474 -> V=1.0, theta=0.0
% INFO    : Bus 90243	: V=0.9956277, theta=30.444859 -> V=1.0, theta=0.0
% INFO    : Bus 90244	: V=1.0001262, theta=30.531773 -> V=1.0, theta=0.0
% INFO    : Bus 90245	: V=0.9983463, theta=30.630991 -> V=1.0, theta=0.0
% INFO    : Bus 90246	: V=0.9975045, theta=30.595148 -> V=1.0, theta=0.0
% INFO    : Bus 90247	: V=1.0010624, theta=30.829063 -> V=1.0, theta=0.0
% INFO    : Bus 90248	: V=1.0058951, theta=19.241265 -> V=1.0, theta=0.0
% INFO    : Bus 90249	: V=0.9999426, theta=14.687734 -> V=1.0, theta=0.0
% INFO    : Bus 90250	: V=1.0040786, theta=16.151036 -> V=1.0, theta=0.0
% INFO    : Bus 90251	: V=1.0062704, theta=17.109463 -> V=1.0, theta=0.0
% INFO    : Bus 90252	: V=1.0035797, theta=17.261617 -> V=1.0, theta=0.0
% INFO    : Bus 90253	: V=1.0005364, theta=16.721029 -> V=1.0, theta=0.0
% INFO    : Bus 90254	: V=1.003923, theta=20.712176 -> V=1.0, theta=0.0
% INFO    : Bus 90255	: V=1.0003428, theta=20.385334 -> V=1.0, theta=0.0
% INFO    : Bus 90256	: V=0.9962997, theta=20.152026 -> V=1.0, theta=0.0
% INFO    : Bus 90257	: V=0.9988404, theta=21.053153 -> V=1.0, theta=0.0
% INFO    : Bus 90258	: V=1.0050031, theta=26.963948 -> V=1.0, theta=0.0
% INFO    : Bus 90259	: V=1.0027759, theta=7.257964 -> V=1.0, theta=0.0
% INFO    : Bus 90260	: V=1.0045012, theta=10.526634 -> V=1.0, theta=0.0
% INFO    : Bus 90261	: V=0.9962394, theta=17.440158 -> V=1.0, theta=0.0
% INFO    : Bus 90262	: V=1.0029225, theta=17.79775 -> V=1.0, theta=0.0
% INFO    : Bus 90263	: V=1.0146103, theta=16.258322 -> V=1.0, theta=0.0
% INFO    : Bus 90264	: V=0.9986449, theta=23.258003 -> V=1.0, theta=0.0
% INFO    : Bus 90265	: V=0.997997, theta=16.490818 -> V=1.0, theta=0.0
% INFO    : Bus 90266	: V=0.9813984, theta=21.358824 -> V=1.0, theta=0.0
% INFO    : Bus 90267	: V=0.9879597, theta=19.59472 -> V=1.0, theta=0.0
% INFO    : Bus 90268	: V=1.0128072, theta=35.862612 -> V=1.0, theta=0.0
% INFO    : Bus 90269	: V=1.0061483, theta=10.497383 -> V=1.0, theta=0.0
% INFO    : Bus 90270	: V=1.0025015, theta=10.281021 -> V=1.0, theta=0.0
% INFO    : Bus 90271	: V=0.9985097, theta=9.885774 -> V=1.0, theta=0.0
% INFO    : Bus 90272	: V=1.0006908, theta=10.037056 -> V=1.0, theta=0.0
% INFO    : Bus 90273	: V=1.0111271, theta=10.868836 -> V=1.0, theta=0.0
% INFO    : Bus 90274	: V=1.0150215, theta=37.94395 -> V=1.0, theta=0.0
% INFO    : Bus 90275	: V=1.0165205, theta=37.921704 -> V=1.0, theta=0.0
% INFO    : Bus 90276	: V=0.9983617, theta=40.200108 -> V=1.0, theta=0.0
% INFO    : Bus 90277	: V=0.9844107, theta=41.35406 -> V=1.0, theta=0.0
% INFO    : Bus 90278	: V=0.9886163, theta=41.515647 -> V=1.0, theta=0.0
% INFO    : Bus 90279	: V=0.9744793, theta=40.989925 -> V=1.0, theta=0.0
% INFO    : Bus 90280	: V=0.9864586, theta=41.272928 -> V=1.0, theta=0.0
% INFO    : Bus 90281	: V=0.9674701, theta=40.615347 -> V=1.0, theta=0.0
% INFO    : Bus 90282	: V=0.9612999, theta=40.754483 -> V=1.0, theta=0.0
% INFO    : Bus 90283	: V=0.963075, theta=40.657965 -> V=1.0, theta=0.0
% INFO    : Bus 90284	: V=0.9616927, theta=40.845265 -> V=1.0, theta=0.0
% INFO    : Bus 90285	: V=0.9619053, theta=40.768833 -> V=1.0, theta=0.0
% INFO    : Bus 90286	: V=0.9572051, theta=41.104526 -> V=1.0, theta=0.0
% INFO    : Bus 90287	: V=0.9903674, theta=41.668907 -> V=1.0, theta=0.0
% INFO    : Bus 90288	: V=0.9711148, theta=41.047414 -> V=1.0, theta=0.0
% INFO    : Bus 90289	: V=0.9660368, theta=40.824753 -> V=1.0, theta=0.0
% INFO    : Bus 90290	: V=0.9662057, theta=40.846078 -> V=1.0, theta=0.0
% INFO    : Bus 90291	: V=0.9685429, theta=40.953696 -> V=1.0, theta=0.0
% INFO    : Bus 90292	: V=0.9889954, theta=34.011359 -> V=1.0, theta=0.0
% INFO    : Bus 90293	: V=1.0034623, theta=40.53005 -> V=1.0, theta=0.0
% INFO    : Bus 90294	: V=0.9899186, theta=39.761413 -> V=1.0, theta=0.0
% INFO    : Bus 90295	: V=1.0130984, theta=37.602246 -> V=1.0, theta=0.0
% INFO    : Bus 90296	: V=1.0122377, theta=37.501107 -> V=1.0, theta=0.0
% INFO    : Bus 90297	: V=1.0131222, theta=37.467189 -> V=1.0, theta=0.0
% INFO    : Bus 90298	: V=1.0118107, theta=37.368335 -> V=1.0, theta=0.0
% INFO    : Bus 90299	: V=1.01114, theta=37.406552 -> V=1.0, theta=0.0
% INFO    : Bus 90300	: V=1.0098617, theta=37.386745 -> V=1.0, theta=0.0
% INFO    : Bus 90301	: V=1.0093739, theta=37.384601 -> V=1.0, theta=0.0
% INFO    : Bus 90302	: V=1.0143749, theta=37.184914 -> V=1.0, theta=0.0
% INFO    : Bus 90303	: V=1.0125807, theta=36.754801 -> V=1.0, theta=0.0
% INFO    : Bus 90304	: V=1.0090745, theta=37.378728 -> V=1.0, theta=0.0
% INFO    : Bus 90305	: V=1.0136548, theta=33.671603 -> V=1.0, theta=0.0
% INFO    : Bus 90306	: V=1.0076122, theta=30.631784 -> V=1.0, theta=0.0
% INFO    : Bus 90307	: V=1.0077176, theta=43.69866 -> V=1.0, theta=0.0
% INFO    : Bus 90308	: V=1.0005533, theta=43.381809 -> V=1.0, theta=0.0
% INFO    : Bus 90309	: V=0.9983551, theta=43.006802 -> V=1.0, theta=0.0
% INFO    : Bus 90310	: V=1.0113452, theta=43.865655 -> V=1.0, theta=0.0
% INFO    : Bus 90311	: V=0.9744305, theta=39.984685 -> V=1.0, theta=0.0
% INFO    : Bus 90312	: V=0.9798138, theta=39.764737 -> V=1.0, theta=0.0
% INFO    : Bus 90313	: V=0.9966339, theta=39.035768 -> V=1.0, theta=0.0
% INFO    : Bus 90314	: V=0.9901831, theta=39.212109 -> V=1.0, theta=0.0
% INFO    : Bus 90315	: V=0.9945443, theta=36.807216 -> V=1.0, theta=0.0
% INFO    : Bus 90316	: V=0.9916955, theta=36.860248 -> V=1.0, theta=0.0
% INFO    : Bus 90317	: V=0.9892171, theta=23.598129 -> V=1.0, theta=0.0
% INFO    : Bus 90318	: V=0.9727785, theta=42.82519 -> V=1.0, theta=0.0
% INFO    : Bus 90319	: V=0.9512967, theta=2.323423 -> V=1.0, theta=0.0
% INFO    : Bus 90320	: V=0.949901, theta=2.415758 -> V=1.0, theta=0.0
% INFO    : Bus 90321	: V=1.0108569, theta=49.832302 -> V=1.0, theta=0.0
% INFO    : Bus 90322	: V=1.0103283, theta=27.323037 -> V=1.0, theta=0.0
% INFO    : Bus 90323	: V=1.0125689, theta=28.293211 -> V=1.0, theta=0.0
% INFO    : Bus 90324	: V=1.0124486, theta=30.490477 -> V=1.0, theta=0.0
% INFO    : Bus 90325	: V=0.9880646, theta=37.615183 -> V=1.0, theta=0.0
% INFO    : Bus 90326	: V=0.9878395, theta=37.567481 -> V=1.0, theta=0.0
% INFO    : Bus 90327	: V=0.9865598, theta=41.636356 -> V=1.0, theta=0.0
% INFO    : Bus 90328	: V=0.9839073, theta=41.679626 -> V=1.0, theta=0.0
% INFO    : Bus 90329	: V=0.9853445, theta=41.725645 -> V=1.0, theta=0.0
% INFO    : Bus 90330	: V=0.9848188, theta=41.729145 -> V=1.0, theta=0.0
% INFO    : Bus 90331	: V=0.9955039, theta=42.104288 -> V=1.0, theta=0.0
% INFO    : Bus 90332	: V=0.9954925, theta=42.043315 -> V=1.0, theta=0.0
% INFO    : Bus 90333	: V=0.9912168, theta=41.857772 -> V=1.0, theta=0.0
% INFO    : Bus 90334	: V=0.9899885, theta=41.735675 -> V=1.0, theta=0.0
% INFO    : Bus 90335	: V=0.9860727, theta=41.584263 -> V=1.0, theta=0.0
% INFO    : Bus 90336	: V=0.9840678, theta=41.362651 -> V=1.0, theta=0.0
% INFO    : Bus 90337	: V=0.9843615, theta=41.598292 -> V=1.0, theta=0.0
% INFO    : Bus 90338	: V=0.984528, theta=41.068856 -> V=1.0, theta=0.0
% INFO    : Bus 90339	: V=0.9848773, theta=41.173469 -> V=1.0, theta=0.0
% INFO    : Bus 90340	: V=0.9844956, theta=41.099592 -> V=1.0, theta=0.0
% INFO    : Bus 90341	: V=0.9882484, theta=41.348166 -> V=1.0, theta=0.0
% INFO    : Bus 90342	: V=0.9880184, theta=41.088076 -> V=1.0, theta=0.0
% INFO    : Bus 90343	: V=0.9872258, theta=41.150819 -> V=1.0, theta=0.0
% INFO    : Bus 90344	: V=0.9870888, theta=41.281108 -> V=1.0, theta=0.0
% INFO    : Bus 90345	: V=0.9892059, theta=41.095293 -> V=1.0, theta=0.0
% INFO    : Bus 90346	: V=0.988841, theta=41.325614 -> V=1.0, theta=0.0
% INFO    : Bus 90347	: V=0.9924202, theta=41.71932 -> V=1.0, theta=0.0
% INFO    : Bus 90348	: V=0.9875386, theta=41.303621 -> V=1.0, theta=0.0
% INFO    : Bus 90349	: V=0.9936653, theta=41.411732 -> V=1.0, theta=0.0
% INFO    : Bus 90350	: V=0.9991905, theta=41.93168 -> V=1.0, theta=0.0
% INFO    : Bus 90351	: V=0.9980129, theta=41.855656 -> V=1.0, theta=0.0
% INFO    : Bus 90352	: V=0.9927913, theta=41.73421 -> V=1.0, theta=0.0
% INFO    : Bus 90353	: V=0.9937135, theta=41.730707 -> V=1.0, theta=0.0
% INFO    : Bus 90354	: V=1.0118071, theta=43.012705 -> V=1.0, theta=0.0
% INFO    : Bus 90355	: V=1.0117825, theta=43.081552 -> V=1.0, theta=0.0
% INFO    : Bus 90356	: V=1.0126854, theta=43.016186 -> V=1.0, theta=0.0
% INFO    : Bus 90357	: V=1.0116843, theta=43.083833 -> V=1.0, theta=0.0
% INFO    : Bus 90358	: V=1.0082907, theta=43.076929 -> V=1.0, theta=0.0
% INFO    : Bus 90359	: V=1.0112665, theta=40.842355 -> V=1.0, theta=0.0
% INFO    : Bus 90360	: V=1.0056517, theta=40.362944 -> V=1.0, theta=0.0
% INFO    : Bus 90361	: V=1.0123395, theta=40.77551 -> V=1.0, theta=0.0
% INFO    : Bus 90362	: V=0.9697028, theta=26.823854 -> V=1.0, theta=0.0
% INFO    : Bus 90363	: V=0.981933, theta=25.314794 -> V=1.0, theta=0.0
% INFO    : Bus 90364	: V=0.9805624, theta=24.728146 -> V=1.0, theta=0.0
% INFO    : Bus 90365	: V=1.0030654, theta=33.90669 -> V=1.0, theta=0.0
% INFO    : Bus 90366	: V=0.995256, theta=33.244732 -> V=1.0, theta=0.0
% INFO    : Bus 90367	: V=1.0114648, theta=41.170895 -> V=1.0, theta=0.0
% INFO    : Bus 90368	: V=1.0115508, theta=41.0481 -> V=1.0, theta=0.0
% INFO    : Bus 90369	: V=1.0102924, theta=40.704803 -> V=1.0, theta=0.0
% INFO    : Bus 90370	: V=1.0058825, theta=37.580651 -> V=1.0, theta=0.0
% INFO    : Bus 90371	: V=1.0113011, theta=37.571315 -> V=1.0, theta=0.0
% INFO    : Bus 90372	: V=1.0075585, theta=37.548792 -> V=1.0, theta=0.0
% INFO    : Bus 90373	: V=1.0068978, theta=37.460889 -> V=1.0, theta=0.0
% INFO    : Bus 90374	: V=1.0140116, theta=38.605049 -> V=1.0, theta=0.0
% INFO    : Bus 90375	: V=1.0169373, theta=43.86074 -> V=1.0, theta=0.0
% INFO    : Bus 90376	: V=1.007021, theta=43.734115 -> V=1.0, theta=0.0
% INFO    : Bus 90377	: V=1.0070495, theta=42.333389 -> V=1.0, theta=0.0
% INFO    : Bus 90378	: V=1.0099248, theta=41.391525 -> V=1.0, theta=0.0
% INFO    : Bus 90379	: V=1.0187688, theta=42.318598 -> V=1.0, theta=0.0
% INFO    : Bus 90380	: V=0.9987762, theta=20.40613 -> V=1.0, theta=0.0
% INFO    : Bus 90381	: V=0.9649442, theta=40.752226 -> V=1.0, theta=0.0
% INFO    : Bus 90382	: V=0.9659413, theta=40.786229 -> V=1.0, theta=0.0
% INFO    : Bus 90383	: V=0.9724656, theta=40.876028 -> V=1.0, theta=0.0
% INFO    : Bus 90384	: V=0.9741377, theta=40.97373 -> V=1.0, theta=0.0
% INFO    : Bus 90385	: V=0.9750849, theta=40.950661 -> V=1.0, theta=0.0
% INFO    : Bus 90386	: V=0.9824077, theta=41.175551 -> V=1.0, theta=0.0
% INFO    : Bus 90387	: V=0.9862411, theta=41.232196 -> V=1.0, theta=0.0
% INFO    : Bus 90388	: V=0.9643731, theta=40.762928 -> V=1.0, theta=0.0
% INFO    : Bus 90389	: V=0.9659301, theta=40.784101 -> V=1.0, theta=0.0
% INFO    : Bus 90390	: V=0.9677278, theta=40.576116 -> V=1.0, theta=0.0
% INFO    : Bus 90391	: V=0.9672874, theta=40.493159 -> V=1.0, theta=0.0
% INFO    : Bus 90392	: V=0.9702554, theta=40.401477 -> V=1.0, theta=0.0
% INFO    : Bus 90393	: V=0.9767161, theta=40.630634 -> V=1.0, theta=0.0
% INFO    : Bus 90394	: V=0.9846634, theta=41.211249 -> V=1.0, theta=0.0
% INFO    : Bus 90395	: V=0.9850718, theta=41.205575 -> V=1.0, theta=0.0
% INFO    : Bus 90396	: V=0.9872883, theta=41.219532 -> V=1.0, theta=0.0
% INFO    : Bus 90397	: V=0.9878088, theta=41.227593 -> V=1.0, theta=0.0
% INFO    : Bus 90398	: V=0.9908281, theta=41.212226 -> V=1.0, theta=0.0
% INFO    : Bus 90399	: V=0.9885925, theta=41.248512 -> V=1.0, theta=0.0
% INFO    : Bus 90400	: V=0.9900298, theta=41.263005 -> V=1.0, theta=0.0
% INFO    : Bus 90401	: V=0.9804708, theta=40.934197 -> V=1.0, theta=0.0
% INFO    : Bus 90402	: V=0.987083, theta=41.055411 -> V=1.0, theta=0.0
% INFO    : Bus 90403	: V=0.9826428, theta=40.771549 -> V=1.0, theta=0.0
% INFO    : Bus 90404	: V=0.9842227, theta=40.916848 -> V=1.0, theta=0.0
% INFO    : Bus 90405	: V=0.9744216, theta=40.332925 -> V=1.0, theta=0.0
% INFO    : Bus 90406	: V=0.9824228, theta=40.616573 -> V=1.0, theta=0.0
% INFO    : Bus 90407	: V=0.9766733, theta=40.459406 -> V=1.0, theta=0.0
% INFO    : Bus 90408	: V=0.9739426, theta=40.167127 -> V=1.0, theta=0.0
% INFO    : Bus 90409	: V=0.9818802, theta=40.478579 -> V=1.0, theta=0.0
% INFO    : Bus 90410	: V=0.9848274, theta=40.587486 -> V=1.0, theta=0.0
% INFO    : Bus 90411	: V=0.9696817, theta=40.327921 -> V=1.0, theta=0.0
% INFO    : Bus 90412	: V=0.9635425, theta=40.348998 -> V=1.0, theta=0.0
% INFO    : Bus 90413	: V=0.9753241, theta=40.69909 -> V=1.0, theta=0.0
% INFO    : Bus 90414	: V=0.9644416, theta=40.390494 -> V=1.0, theta=0.0
% INFO    : Bus 90415	: V=0.9621634, theta=40.533362 -> V=1.0, theta=0.0
% INFO    : Bus 90416	: V=0.9663388, theta=40.557343 -> V=1.0, theta=0.0
% INFO    : Bus 90417	: V=0.9640082, theta=40.445291 -> V=1.0, theta=0.0
% INFO    : Bus 90418	: V=0.9634276, theta=40.45412 -> V=1.0, theta=0.0
% INFO    : Bus 90419	: V=0.9666691, theta=40.456636 -> V=1.0, theta=0.0
% INFO    : Bus 90420	: V=0.9607372, theta=40.520298 -> V=1.0, theta=0.0
% INFO    : Bus 90421	: V=0.9616037, theta=40.604941 -> V=1.0, theta=0.0
% INFO    : Bus 90422	: V=0.9642752, theta=40.725515 -> V=1.0, theta=0.0
% INFO    : Bus 90423	: V=0.9652111, theta=40.762229 -> V=1.0, theta=0.0
% INFO    : Bus 90424	: V=0.9628769, theta=40.702404 -> V=1.0, theta=0.0
% INFO    : Bus 90425	: V=0.9673795, theta=40.60231 -> V=1.0, theta=0.0
% INFO    : Bus 90426	: V=0.9693544, theta=40.443045 -> V=1.0, theta=0.0
% INFO    : Bus 90427	: V=0.9757179, theta=39.859628 -> V=1.0, theta=0.0
% INFO    : Bus 90428	: V=0.9794669, theta=39.771165 -> V=1.0, theta=0.0
% INFO    : Bus 90429	: V=0.9862981, theta=39.876116 -> V=1.0, theta=0.0
% INFO    : Bus 90430	: V=0.9649098, theta=40.75186 -> V=1.0, theta=0.0
% INFO    : Bus 90431	: V=0.9660825, theta=40.804933 -> V=1.0, theta=0.0
% INFO    : Bus 90432	: V=0.9669931, theta=40.826923 -> V=1.0, theta=0.0
% INFO    : Bus 90433	: V=0.9718278, theta=40.992784 -> V=1.0, theta=0.0
% INFO    : Bus 90434	: V=0.9713052, theta=40.940271 -> V=1.0, theta=0.0
% INFO    : Bus 90435	: V=0.9799606, theta=41.246413 -> V=1.0, theta=0.0
% INFO    : Bus 90436	: V=0.9744713, theta=41.021833 -> V=1.0, theta=0.0
% INFO    : Bus 90437	: V=0.9670458, theta=40.784485 -> V=1.0, theta=0.0
% INFO    : Bus 90438	: V=0.967712, theta=40.815723 -> V=1.0, theta=0.0
% INFO    : Bus 90439	: V=0.9738701, theta=41.037481 -> V=1.0, theta=0.0
% INFO    : Bus 90440	: V=0.9737876, theta=41.023986 -> V=1.0, theta=0.0
% INFO    : Bus 90441	: V=0.9665611, theta=40.58988 -> V=1.0, theta=0.0
% INFO    : Bus 90442	: V=0.9700215, theta=40.852951 -> V=1.0, theta=0.0
% INFO    : Bus 90443	: V=0.9757649, theta=41.08322 -> V=1.0, theta=0.0
% INFO    : Bus 90444	: V=0.9764575, theta=41.037423 -> V=1.0, theta=0.0
% INFO    : Bus 90445	: V=0.9773991, theta=41.12833 -> V=1.0, theta=0.0
% INFO    : Bus 90446	: V=0.9747779, theta=40.982629 -> V=1.0, theta=0.0
% INFO    : Bus 90447	: V=0.9763108, theta=40.92028 -> V=1.0, theta=0.0
% INFO    : Bus 90448	: V=0.9766062, theta=40.931126 -> V=1.0, theta=0.0
% INFO    : Bus 90449	: V=0.9672221, theta=40.467189 -> V=1.0, theta=0.0
% INFO    : Bus 90450	: V=0.9905401, theta=41.300537 -> V=1.0, theta=0.0
% INFO    : Bus 90451	: V=0.981785, theta=41.065131 -> V=1.0, theta=0.0
% INFO    : Bus 90452	: V=0.974188, theta=41.017709 -> V=1.0, theta=0.0
% INFO    : Bus 90453	: V=0.9665074, theta=40.797511 -> V=1.0, theta=0.0
% INFO    : Bus 90454	: V=1.0030915, theta=40.982945 -> V=1.0, theta=0.0
% INFO    : Bus 90455	: V=1.0174657, theta=41.182765 -> V=1.0, theta=0.0
% INFO    : Bus 90456	: V=1.0149735, theta=41.16452 -> V=1.0, theta=0.0
% INFO    : Bus 90457	: V=0.9791015, theta=41.500135 -> V=1.0, theta=0.0
% INFO    : Bus 90458	: V=1.0118467, theta=41.415205 -> V=1.0, theta=0.0
% INFO    : Bus 90459	: V=1.0115876, theta=42.506764 -> V=1.0, theta=0.0
% INFO    : Bus 90460	: V=1.0201185, theta=44.523941 -> V=1.0, theta=0.0
% INFO    : Bus 90461	: V=1.0188255, theta=44.084255 -> V=1.0, theta=0.0
% INFO    : Bus 90462	: V=1.0132303, theta=43.153877 -> V=1.0, theta=0.0
% INFO    : Bus 90463	: V=1.0178834, theta=29.419418 -> V=1.0, theta=0.0
% INFO    : Bus 90464	: V=1.0183849, theta=30.676756 -> V=1.0, theta=0.0
% INFO    : Bus 90465	: V=0.9809223, theta=29.795443 -> V=1.0, theta=0.0
% INFO    : Bus 90466	: V=0.9817556, theta=28.210778 -> V=1.0, theta=0.0
% INFO    : Bus 90467	: V=0.9784534, theta=28.928792 -> V=1.0, theta=0.0
% INFO    : Bus 90468	: V=0.9798939, theta=28.976707 -> V=1.0, theta=0.0
% INFO    : Bus 90469	: V=0.9854959, theta=30.142108 -> V=1.0, theta=0.0
% INFO    : Bus 90470	: V=0.9837336, theta=28.04811 -> V=1.0, theta=0.0
% INFO    : Bus 90471	: V=0.9571327, theta=13.850956 -> V=1.0, theta=0.0
% INFO    : Bus 90472	: V=1.0126568, theta=41.249508 -> V=1.0, theta=0.0
% INFO    : Bus 90473	: V=1.0129015, theta=41.155367 -> V=1.0, theta=0.0
% INFO    : Bus 90474	: V=1.0072683, theta=38.142234 -> V=1.0, theta=0.0
% INFO    : Bus 90475	: V=0.9891662, theta=22.191304 -> V=1.0, theta=0.0
% INFO    : Bus 90476	: V=1.0185595, theta=46.038029 -> V=1.0, theta=0.0
% INFO    : Bus 90477	: V=1.0164532, theta=46.04621 -> V=1.0, theta=0.0
% INFO    : Bus 90478	: V=0.999167, theta=39.386938 -> V=1.0, theta=0.0
% INFO    : Bus 90479	: V=0.9933143, theta=25.359889 -> V=1.0, theta=0.0
% INFO    : Bus 90480	: V=1.009085, theta=24.654155 -> V=1.0, theta=0.0
% INFO    : Bus 90481	: V=1.0074056, theta=36.479081 -> V=1.0, theta=0.0
% INFO    : Bus 90482	: V=1.0128869, theta=38.737503 -> V=1.0, theta=0.0
% INFO    : Bus 90483	: V=0.9958857, theta=30.832708 -> V=1.0, theta=0.0
% INFO    : Bus 90484	: V=0.9756074, theta=34.9236 -> V=1.0, theta=0.0
% INFO    : Bus 90485	: V=0.9793449, theta=40.526816 -> V=1.0, theta=0.0
% INFO    : Bus 90486	: V=0.9803221, theta=40.628747 -> V=1.0, theta=0.0
% INFO    : Bus 90487	: V=1.0019649, theta=38.345709 -> V=1.0, theta=0.0
% INFO    : Bus 90488	: V=0.9902964, theta=37.765495 -> V=1.0, theta=0.0
% INFO    : Bus 90489	: V=0.9928947, theta=36.996211 -> V=1.0, theta=0.0
% INFO    : Bus 90490	: V=0.9933319, theta=36.154438 -> V=1.0, theta=0.0
% INFO    : Bus 90491	: V=1.0173938, theta=40.569379 -> V=1.0, theta=0.0
% INFO    : Bus 90492	: V=1.0196364, theta=39.695386 -> V=1.0, theta=0.0
% INFO    : Bus 90493	: V=1.0114526, theta=25.487731 -> V=1.0, theta=0.0
% INFO    : Bus 90494	: V=1.0037507, theta=37.284777 -> V=1.0, theta=0.0
% INFO    : Bus 90495	: V=0.9638972, theta=8.988134 -> V=1.0, theta=0.0
% INFO    : Bus 90496	: V=1.0133249, theta=41.818866 -> V=1.0, theta=0.0
% INFO    : Bus 90497	: V=1.012449, theta=41.783035 -> V=1.0, theta=0.0
% INFO    : Bus 90498	: V=1.0123093, theta=41.740281 -> V=1.0, theta=0.0
% INFO    : Bus 90499	: V=1.0125819, theta=41.650685 -> V=1.0, theta=0.0
% INFO    : Bus 90500	: V=1.0110646, theta=41.752804 -> V=1.0, theta=0.0
% INFO    : Bus 90501	: V=1.0126512, theta=41.739669 -> V=1.0, theta=0.0
% INFO    : Bus 90502	: V=1.0192568, theta=42.152615 -> V=1.0, theta=0.0
% INFO    : Bus 90503	: V=1.0186665, theta=42.184366 -> V=1.0, theta=0.0
% INFO    : Bus 90504	: V=1.0127895, theta=41.649116 -> V=1.0, theta=0.0
% INFO    : Bus 90505	: V=1.0157054, theta=41.848277 -> V=1.0, theta=0.0
% INFO    : Bus 90506	: V=1.0145214, theta=41.970084 -> V=1.0, theta=0.0
% INFO    : Bus 90507	: V=1.0133526, theta=42.144984 -> V=1.0, theta=0.0
% INFO    : Bus 90508	: V=1.011929, theta=40.955235 -> V=1.0, theta=0.0
% INFO    : Bus 90509	: V=1.0142067, theta=41.507552 -> V=1.0, theta=0.0
% INFO    : Bus 90510	: V=0.9910749, theta=17.504451 -> V=1.0, theta=0.0
% INFO    : Bus 90511	: V=0.963188, theta=27.84667 -> V=1.0, theta=0.0
% INFO    : Bus 90512	: V=0.9639857, theta=27.296151 -> V=1.0, theta=0.0
% INFO    : Bus 90513	: V=0.9607523, theta=28.096091 -> V=1.0, theta=0.0
% INFO    : Bus 90514	: V=0.9985107, theta=18.610348 -> V=1.0, theta=0.0
% INFO    : Bus 90515	: V=0.9686026, theta=27.232812 -> V=1.0, theta=0.0
% INFO    : Bus 90516	: V=0.979598, theta=26.150588 -> V=1.0, theta=0.0
% INFO    : Bus 90517	: V=0.9787862, theta=24.831609 -> V=1.0, theta=0.0
% INFO    : Bus 90518	: V=0.9915687, theta=43.260614 -> V=1.0, theta=0.0
% INFO    : Bus 90519	: V=1.0193391, theta=25.504237 -> V=1.0, theta=0.0
% INFO    : Bus 90520	: V=0.9533062, theta=16.998207 -> V=1.0, theta=0.0
% INFO    : Bus 90521	: V=0.9606932, theta=17.284103 -> V=1.0, theta=0.0
% INFO    : Bus 90522	: V=0.9775279, theta=24.80255 -> V=1.0, theta=0.0
% INFO    : Bus 90523	: V=0.9773621, theta=25.676926 -> V=1.0, theta=0.0
% INFO    : Bus 90524	: V=0.9831779, theta=41.506592 -> V=1.0, theta=0.0
% INFO    : Bus 90525	: V=0.9756437, theta=41.560527 -> V=1.0, theta=0.0
% INFO    : Bus 90526	: V=0.9950348, theta=41.92653 -> V=1.0, theta=0.0
% INFO    : Bus 90527	: V=0.9868216, theta=41.598364 -> V=1.0, theta=0.0
% INFO    : Bus 90528	: V=0.9789513, theta=41.481077 -> V=1.0, theta=0.0
% INFO    : Bus 90529	: V=0.9779441, theta=41.598418 -> V=1.0, theta=0.0
% INFO    : Bus 90530	: V=0.9814031, theta=41.464633 -> V=1.0, theta=0.0
% INFO    : Bus 90531	: V=0.9801624, theta=41.475019 -> V=1.0, theta=0.0
% INFO    : Bus 90532	: V=0.9800999, theta=41.536184 -> V=1.0, theta=0.0
% INFO    : Bus 90533	: V=0.9812554, theta=41.463786 -> V=1.0, theta=0.0
% INFO    : Bus 90534	: V=0.9815018, theta=41.466898 -> V=1.0, theta=0.0
% INFO    : Bus 90535	: V=0.9809351, theta=41.479564 -> V=1.0, theta=0.0
% INFO    : Bus 90536	: V=0.9810825, theta=41.537585 -> V=1.0, theta=0.0
% INFO    : Bus 90537	: V=0.9801174, theta=41.601009 -> V=1.0, theta=0.0
% INFO    : Bus 90538	: V=0.9811652, theta=41.404051 -> V=1.0, theta=0.0
% INFO    : Bus 90539	: V=0.9820996, theta=41.485679 -> V=1.0, theta=0.0
% INFO    : Bus 90540	: V=0.9826101, theta=41.551147 -> V=1.0, theta=0.0
% INFO    : Bus 90541	: V=0.9810132, theta=41.715785 -> V=1.0, theta=0.0
% INFO    : Bus 90542	: V=0.9790948, theta=41.256343 -> V=1.0, theta=0.0
% INFO    : Bus 90543	: V=0.9827583, theta=42.522309 -> V=1.0, theta=0.0
% INFO    : Bus 90544	: V=0.9811637, theta=42.426125 -> V=1.0, theta=0.0
% INFO    : Bus 90545	: V=0.9752662, theta=41.209025 -> V=1.0, theta=0.0
% INFO    : Bus 90546	: V=0.9794323, theta=41.220977 -> V=1.0, theta=0.0
% INFO    : Bus 90547	: V=0.9924558, theta=41.756874 -> V=1.0, theta=0.0
% INFO    : Bus 90548	: V=0.9829736, theta=41.335779 -> V=1.0, theta=0.0
% INFO    : Bus 90549	: V=0.9817527, theta=41.516598 -> V=1.0, theta=0.0
% INFO    : Bus 90550	: V=0.9931075, theta=41.804463 -> V=1.0, theta=0.0
% INFO    : Bus 90551	: V=0.9820401, theta=41.332721 -> V=1.0, theta=0.0
% INFO    : Bus 90552	: V=0.9763065, theta=41.177391 -> V=1.0, theta=0.0
% INFO    : Bus 90553	: V=0.9740741, theta=41.588185 -> V=1.0, theta=0.0
% INFO    : Bus 90554	: V=0.9763213, theta=41.528554 -> V=1.0, theta=0.0
% INFO    : Bus 90555	: V=0.978488, theta=41.81598 -> V=1.0, theta=0.0
% INFO    : Bus 90556	: V=0.9786874, theta=41.783766 -> V=1.0, theta=0.0
% INFO    : Bus 90557	: V=0.9796206, theta=42.236518 -> V=1.0, theta=0.0
% INFO    : Bus 90558	: V=0.9810421, theta=41.50671 -> V=1.0, theta=0.0
% INFO    : Bus 90559	: V=0.9785993, theta=41.181986 -> V=1.0, theta=0.0
% INFO    : Bus 90560	: V=0.9839743, theta=41.702026 -> V=1.0, theta=0.0
% INFO    : Bus 90561	: V=1.0046878, theta=30.745998 -> V=1.0, theta=0.0
% INFO    : Bus 90562	: V=0.9852837, theta=28.798253 -> V=1.0, theta=0.0
% INFO    : Bus 90563	: V=1.0020102, theta=27.972786 -> V=1.0, theta=0.0
% INFO    : Bus 90564	: V=0.9896354, theta=33.571664 -> V=1.0, theta=0.0
% INFO    : Bus 90565	: V=0.9987707, theta=41.390353 -> V=1.0, theta=0.0
% INFO    : Bus 90566	: V=1.0063954, theta=41.278254 -> V=1.0, theta=0.0
% INFO    : Bus 90567	: V=1.0019323, theta=41.245525 -> V=1.0, theta=0.0
% INFO    : Bus 90568	: V=0.9909464, theta=18.704227 -> V=1.0, theta=0.0
% INFO    : Bus 90569	: V=0.9842901, theta=24.271236 -> V=1.0, theta=0.0
% INFO    : Bus 90570	: V=0.9924404, theta=44.885032 -> V=1.0, theta=0.0
% INFO    : Bus 90571	: V=1.0042489, theta=45.135263 -> V=1.0, theta=0.0
% INFO    : Bus 90572	: V=1.0033193, theta=45.160114 -> V=1.0, theta=0.0
% INFO    : Bus 90573	: V=1.0036367, theta=45.064177 -> V=1.0, theta=0.0
% INFO    : Bus 90574	: V=1.0040456, theta=45.079659 -> V=1.0, theta=0.0
% INFO    : Bus 90575	: V=1.0028126, theta=45.037166 -> V=1.0, theta=0.0
% INFO    : Bus 90576	: V=1.0007048, theta=44.989912 -> V=1.0, theta=0.0
% INFO    : Bus 90577	: V=0.99787, theta=44.888349 -> V=1.0, theta=0.0
% INFO    : Bus 90578	: V=1.0072206, theta=44.663678 -> V=1.0, theta=0.0
% INFO    : Bus 90579	: V=1.0076231, theta=44.296785 -> V=1.0, theta=0.0
% INFO    : Bus 90580	: V=1.0102577, theta=43.923978 -> V=1.0, theta=0.0
% INFO    : Bus 90581	: V=1.0173164, theta=43.957356 -> V=1.0, theta=0.0
% INFO    : Bus 90582	: V=1.0162092, theta=44.006755 -> V=1.0, theta=0.0
% INFO    : Bus 90583	: V=1.0164827, theta=44.983175 -> V=1.0, theta=0.0
% INFO    : Bus 90584	: V=1.0194747, theta=46.215629 -> V=1.0, theta=0.0
% INFO    : Bus 90585	: V=1.0153269, theta=47.005508 -> V=1.0, theta=0.0
% INFO    : Bus 90586	: V=1.0080478, theta=46.668952 -> V=1.0, theta=0.0
% INFO    : Bus 90587	: V=0.9964347, theta=44.802014 -> V=1.0, theta=0.0
% INFO    : Bus 90588	: V=1.0002283, theta=44.730403 -> V=1.0, theta=0.0
% INFO    : Bus 90589	: V=0.9803935, theta=40.798791 -> V=1.0, theta=0.0
% INFO    : Bus 90590	: V=0.9829579, theta=40.672609 -> V=1.0, theta=0.0
% INFO    : Bus 90591	: V=0.9963813, theta=40.773611 -> V=1.0, theta=0.0
% INFO    : Bus 90592	: V=0.9868234, theta=40.583091 -> V=1.0, theta=0.0
% INFO    : Bus 90593	: V=0.9872192, theta=40.676603 -> V=1.0, theta=0.0
% INFO    : Bus 90594	: V=0.985761, theta=40.752073 -> V=1.0, theta=0.0
% INFO    : Bus 90595	: V=0.9880752, theta=40.910477 -> V=1.0, theta=0.0
% INFO    : Bus 90596	: V=0.9860678, theta=38.703947 -> V=1.0, theta=0.0
% INFO    : Bus 90597	: V=0.9877488, theta=41.014363 -> V=1.0, theta=0.0
% INFO    : Bus 90598	: V=0.9959531, theta=41.035072 -> V=1.0, theta=0.0
% INFO    : Bus 90599	: V=0.9958797, theta=40.859804 -> V=1.0, theta=0.0
% INFO    : Bus 90600	: V=1.0037502, theta=41.607319 -> V=1.0, theta=0.0
% INFO    : Bus 90601	: V=0.9880523, theta=39.724401 -> V=1.0, theta=0.0
% INFO    : Bus 90602	: V=0.9834853, theta=39.165107 -> V=1.0, theta=0.0
% INFO    : Bus 90603	: V=0.9850786, theta=39.541881 -> V=1.0, theta=0.0
% INFO    : Bus 90604	: V=0.9848765, theta=39.162645 -> V=1.0, theta=0.0
% INFO    : Bus 90605	: V=0.9789454, theta=32.234777 -> V=1.0, theta=0.0
% INFO    : Bus 90606	: V=0.9825267, theta=38.887125 -> V=1.0, theta=0.0
% INFO    : Bus 90607	: V=0.9913908, theta=37.964696 -> V=1.0, theta=0.0
% INFO    : Bus 90608	: V=0.9914259, theta=37.169491 -> V=1.0, theta=0.0
% INFO    : Bus 90609	: V=1.0000619, theta=39.642439 -> V=1.0, theta=0.0
% INFO    : Bus 90610	: V=1.0044311, theta=39.633322 -> V=1.0, theta=0.0
% INFO    : Bus 90611	: V=1.0063709, theta=38.54743 -> V=1.0, theta=0.0
% INFO    : Bus 90612	: V=0.9863539, theta=16.603622 -> V=1.0, theta=0.0
% INFO    : Bus 90613	: V=0.9831355, theta=18.569702 -> V=1.0, theta=0.0
% INFO    : Bus 90614	: V=0.992571, theta=23.438591 -> V=1.0, theta=0.0
% INFO    : Bus 90615	: V=0.9875743, theta=19.589411 -> V=1.0, theta=0.0
% INFO    : Bus 90616	: V=1.0125344, theta=43.17671 -> V=1.0, theta=0.0
% INFO    : Bus 90617	: V=1.0072772, theta=43.49758 -> V=1.0, theta=0.0
% INFO    : Bus 90618	: V=1.0072259, theta=42.468205 -> V=1.0, theta=0.0
% INFO    : Bus 90619	: V=0.9970458, theta=38.774257 -> V=1.0, theta=0.0
% INFO    : Bus 90620	: V=0.977773, theta=42.838929 -> V=1.0, theta=0.0
% INFO    : Bus 90621	: V=0.9930617, theta=43.310462 -> V=1.0, theta=0.0
% INFO    : Bus 90622	: V=1.0048494, theta=44.386598 -> V=1.0, theta=0.0
% INFO    : Bus 90623	: V=1.002005, theta=44.187447 -> V=1.0, theta=0.0
% INFO    : Bus 90624	: V=1.0056536, theta=44.457112 -> V=1.0, theta=0.0
% INFO    : Bus 90625	: V=0.9894776, theta=43.130473 -> V=1.0, theta=0.0
% INFO    : Bus 90626	: V=0.9902087, theta=43.274824 -> V=1.0, theta=0.0
% INFO    : Bus 90627	: V=0.9784699, theta=41.741645 -> V=1.0, theta=0.0
% INFO    : Bus 90628	: V=0.9818346, theta=41.79286 -> V=1.0, theta=0.0
% INFO    : Bus 90629	: V=0.9951621, theta=42.27415 -> V=1.0, theta=0.0
% INFO    : Bus 90630	: V=0.9973157, theta=42.30143 -> V=1.0, theta=0.0
% INFO    : Bus 90631	: V=0.9952209, theta=42.327218 -> V=1.0, theta=0.0
% INFO    : Bus 90632	: V=0.9990942, theta=42.276025 -> V=1.0, theta=0.0
% INFO    : Bus 90633	: V=1.0089343, theta=42.839717 -> V=1.0, theta=0.0
% INFO    : Bus 90634	: V=0.9971336, theta=42.271148 -> V=1.0, theta=0.0
% INFO    : Bus 90635	: V=1.010142, theta=32.886405 -> V=1.0, theta=0.0
% INFO    : Bus 90636	: V=0.9828612, theta=41.242037 -> V=1.0, theta=0.0
% INFO    : Bus 90637	: V=0.9788335, theta=41.301587 -> V=1.0, theta=0.0
% INFO    : Bus 90638	: V=1.0054673, theta=41.084661 -> V=1.0, theta=0.0
% INFO    : Bus 90639	: V=0.9967505, theta=41.394041 -> V=1.0, theta=0.0
% INFO    : Bus 90640	: V=0.992394, theta=40.982195 -> V=1.0, theta=0.0
% INFO    : Bus 90641	: V=1.0015842, theta=40.715403 -> V=1.0, theta=0.0
% INFO    : Bus 90642	: V=1.0009089, theta=40.91725 -> V=1.0, theta=0.0
% INFO    : Bus 90643	: V=0.9887876, theta=41.075864 -> V=1.0, theta=0.0
% INFO    : Bus 90644	: V=0.9923066, theta=40.339456 -> V=1.0, theta=0.0
% INFO    : Bus 90645	: V=0.9972901, theta=39.302572 -> V=1.0, theta=0.0
% INFO    : Bus 90646	: V=1.0019013, theta=38.003158 -> V=1.0, theta=0.0
% INFO    : Bus 90647	: V=0.9713161, theta=43.695983 -> V=1.0, theta=0.0
% INFO    : Bus 90648	: V=0.9713956, theta=43.934542 -> V=1.0, theta=0.0
% INFO    : Bus 90649	: V=1.0098508, theta=47.269141 -> V=1.0, theta=0.0
% INFO    : Bus 90650	: V=1.0157654, theta=48.777968 -> V=1.0, theta=0.0
% INFO    : Bus 90651	: V=1.0035556, theta=52.927143 -> V=1.0, theta=0.0
% INFO    : Bus 90652	: V=1.0069029, theta=53.190655 -> V=1.0, theta=0.0
% INFO    : Bus 90653	: V=1.0155522, theta=53.484177 -> V=1.0, theta=0.0
% INFO    : Bus 90654	: V=1.0101722, theta=53.283278 -> V=1.0, theta=0.0
% INFO    : Bus 90655	: V=1.0086193, theta=53.349872 -> V=1.0, theta=0.0
% INFO    : Bus 90656	: V=1.0078003, theta=53.248888 -> V=1.0, theta=0.0
% INFO    : Bus 90657	: V=1.0054817, theta=52.860246 -> V=1.0, theta=0.0
% INFO    : Bus 90658	: V=0.9985872, theta=52.825849 -> V=1.0, theta=0.0
% INFO    : Bus 90659	: V=1.0073279, theta=53.45441 -> V=1.0, theta=0.0
% INFO    : Bus 90660	: V=1.0147807, theta=53.339417 -> V=1.0, theta=0.0
% INFO    : Bus 90661	: V=1.0150101, theta=53.372699 -> V=1.0, theta=0.0
% INFO    : Bus 90662	: V=1.0176889, theta=53.334886 -> V=1.0, theta=0.0
% INFO    : Bus 90663	: V=1.0096266, theta=53.188733 -> V=1.0, theta=0.0
% INFO    : Bus 90664	: V=1.0125214, theta=53.562482 -> V=1.0, theta=0.0
% INFO    : Bus 90665	: V=0.994111, theta=52.748665 -> V=1.0, theta=0.0
% INFO    : Bus 90666	: V=1.0042589, theta=53.11713 -> V=1.0, theta=0.0
% INFO    : Bus 90667	: V=1.0106135, theta=43.723303 -> V=1.0, theta=0.0
% INFO    : Bus 90668	: V=1.0124233, theta=44.063636 -> V=1.0, theta=0.0
% INFO    : Bus 90669	: V=1.0135425, theta=43.640001 -> V=1.0, theta=0.0
% INFO    : Bus 90670	: V=1.0182556, theta=43.633137 -> V=1.0, theta=0.0
% INFO    : Bus 90671	: V=1.01587, theta=43.472397 -> V=1.0, theta=0.0
% INFO    : Bus 90672	: V=1.0143225, theta=53.613479 -> V=1.0, theta=0.0
% INFO    : Bus 90673	: V=1.0073465, theta=52.338492 -> V=1.0, theta=0.0
% INFO    : Bus 90674	: V=1.0105016, theta=44.909889 -> V=1.0, theta=0.0
% INFO    : Bus 90675	: V=1.0103774, theta=44.802415 -> V=1.0, theta=0.0
% INFO    : Bus 90676	: V=0.9935336, theta=47.320418 -> V=1.0, theta=0.0
% INFO    : Bus 90677	: V=0.9975211, theta=46.575443 -> V=1.0, theta=0.0
% INFO    : Bus 90678	: V=0.9697719, theta=37.791899 -> V=1.0, theta=0.0
% INFO    : Bus 90679	: V=0.9721679, theta=38.105351 -> V=1.0, theta=0.0
% INFO    : Bus 90680	: V=0.9820225, theta=36.289363 -> V=1.0, theta=0.0
% INFO    : Bus 90681	: V=0.9886213, theta=36.228666 -> V=1.0, theta=0.0
% INFO    : Bus 90682	: V=0.989184, theta=35.829133 -> V=1.0, theta=0.0
% INFO    : Bus 90683	: V=0.9908538, theta=35.772309 -> V=1.0, theta=0.0
% INFO    : Bus 90684	: V=0.9964344, theta=35.735152 -> V=1.0, theta=0.0
% INFO    : Bus 90685	: V=0.9919226, theta=35.804529 -> V=1.0, theta=0.0
% INFO    : Bus 90686	: V=0.9932191, theta=35.811049 -> V=1.0, theta=0.0
% INFO    : Bus 90687	: V=0.9941979, theta=35.827047 -> V=1.0, theta=0.0
% INFO    : Bus 90688	: V=0.9962144, theta=35.818128 -> V=1.0, theta=0.0
% INFO    : Bus 90689	: V=0.9948081, theta=35.821547 -> V=1.0, theta=0.0
% INFO    : Bus 90690	: V=0.9929977, theta=35.806518 -> V=1.0, theta=0.0
% INFO    : Bus 90691	: V=0.9975805, theta=35.797902 -> V=1.0, theta=0.0
% INFO    : Bus 90692	: V=0.9982922, theta=35.8005 -> V=1.0, theta=0.0
% INFO    : Bus 90693	: V=0.9973658, theta=35.86763 -> V=1.0, theta=0.0
% INFO    : Bus 90694	: V=0.996042, theta=35.912901 -> V=1.0, theta=0.0
% INFO    : Bus 90695	: V=1.0007965, theta=36.332623 -> V=1.0, theta=0.0
% INFO    : Bus 90696	: V=0.9952905, theta=36.03341 -> V=1.0, theta=0.0
% INFO    : Bus 90697	: V=0.9945588, theta=35.98995 -> V=1.0, theta=0.0
% INFO    : Bus 90698	: V=0.9932631, theta=36.020732 -> V=1.0, theta=0.0
% INFO    : Bus 90699	: V=1.0026045, theta=36.165031 -> V=1.0, theta=0.0
% INFO    : Bus 90700	: V=0.9989222, theta=36.08604 -> V=1.0, theta=0.0
% INFO    : Bus 90701	: V=0.99646, theta=35.921906 -> V=1.0, theta=0.0
% INFO    : Bus 90702	: V=0.9935111, theta=35.730363 -> V=1.0, theta=0.0
% INFO    : Bus 90703	: V=0.9869, theta=35.83255 -> V=1.0, theta=0.0
% INFO    : Bus 90704	: V=0.983388, theta=36.05548 -> V=1.0, theta=0.0
% INFO    : Bus 90705	: V=0.9919016, theta=36.207524 -> V=1.0, theta=0.0
% INFO    : Bus 90706	: V=1.0056091, theta=36.547866 -> V=1.0, theta=0.0
% INFO    : Bus 90707	: V=1.005907, theta=36.661371 -> V=1.0, theta=0.0
% INFO    : Bus 90708	: V=1.0041868, theta=36.053548 -> V=1.0, theta=0.0
% INFO    : Bus 90709	: V=0.9999793, theta=35.862164 -> V=1.0, theta=0.0
% INFO    : Bus 90710	: V=0.996361, theta=35.767053 -> V=1.0, theta=0.0
% INFO    : Bus 90711	: V=0.9848514, theta=36.263507 -> V=1.0, theta=0.0
% INFO    : Bus 90712	: V=0.9920245, theta=35.681184 -> V=1.0, theta=0.0
% INFO    : Bus 90713	: V=0.9950155, theta=35.916274 -> V=1.0, theta=0.0
% INFO    : Bus 90714	: V=1.0089594, theta=36.11514 -> V=1.0, theta=0.0
% INFO    : Bus 90715	: V=1.0069551, theta=36.46927 -> V=1.0, theta=0.0
% INFO    : Bus 90716	: V=0.9800128, theta=37.394423 -> V=1.0, theta=0.0
% INFO    : Bus 90717	: V=0.9930353, theta=36.486997 -> V=1.0, theta=0.0
% INFO    : Bus 90718	: V=0.9923709, theta=36.326412 -> V=1.0, theta=0.0
% INFO    : Bus 90719	: V=0.9956297, theta=35.854508 -> V=1.0, theta=0.0
% INFO    : Bus 90720	: V=1.0044142, theta=55.455492 -> V=1.0, theta=0.0
% INFO    : Bus 90721	: V=1.0049465, theta=55.562336 -> V=1.0, theta=0.0
% INFO    : Bus 90722	: V=1.010562, theta=45.428704 -> V=1.0, theta=0.0
% INFO    : Bus 90723	: V=1.006438, theta=45.141494 -> V=1.0, theta=0.0
% INFO    : Bus 90724	: V=0.9987858, theta=44.824304 -> V=1.0, theta=0.0
% INFO    : Bus 90725	: V=1.0084643, theta=44.682617 -> V=1.0, theta=0.0
% INFO    : Bus 90726	: V=1.0009298, theta=44.184069 -> V=1.0, theta=0.0
% INFO    : Bus 90727	: V=0.990842, theta=44.096413 -> V=1.0, theta=0.0
% INFO    : Bus 90728	: V=1.0135962, theta=44.110163 -> V=1.0, theta=0.0
% INFO    : Bus 90729	: V=1.0075892, theta=44.423035 -> V=1.0, theta=0.0
% INFO    : Bus 90730	: V=1.0044529, theta=44.347992 -> V=1.0, theta=0.0
% INFO    : Bus 90731	: V=1.0108387, theta=44.965042 -> V=1.0, theta=0.0
% INFO    : Bus 90732	: V=1.0043681, theta=44.541752 -> V=1.0, theta=0.0
% INFO    : Bus 90733	: V=1.0038493, theta=44.457275 -> V=1.0, theta=0.0
% INFO    : Bus 90734	: V=1.0017543, theta=44.437325 -> V=1.0, theta=0.0
% INFO    : Bus 90735	: V=1.0034057, theta=44.526357 -> V=1.0, theta=0.0
% INFO    : Bus 90736	: V=1.0061572, theta=44.472726 -> V=1.0, theta=0.0
% INFO    : Bus 90737	: V=1.0113995, theta=44.250007 -> V=1.0, theta=0.0
% INFO    : Bus 90738	: V=1.0023791, theta=44.492032 -> V=1.0, theta=0.0
% INFO    : Bus 90739	: V=1.0076298, theta=38.80483 -> V=1.0, theta=0.0
% INFO    : Bus 90740	: V=1.0144333, theta=39.849629 -> V=1.0, theta=0.0
% INFO    : Bus 90741	: V=1.0170483, theta=39.171686 -> V=1.0, theta=0.0
% INFO    : Bus 90742	: V=1.0100925, theta=38.863348 -> V=1.0, theta=0.0
% INFO    : Bus 90743	: V=0.9930535, theta=38.88801 -> V=1.0, theta=0.0
% INFO    : Bus 90744	: V=0.9928762, theta=51.559444 -> V=1.0, theta=0.0
% INFO    : Bus 90745	: V=0.9899876, theta=36.415667 -> V=1.0, theta=0.0
% INFO    : Bus 90746	: V=0.9969785, theta=35.695189 -> V=1.0, theta=0.0
% INFO    : Bus 90747	: V=1.0062769, theta=35.718003 -> V=1.0, theta=0.0
% INFO    : Bus 90748	: V=1.0002914, theta=34.923621 -> V=1.0, theta=0.0
% INFO    : Bus 90749	: V=0.9996675, theta=34.97534 -> V=1.0, theta=0.0
% INFO    : Bus 90750	: V=1.0031205, theta=35.032375 -> V=1.0, theta=0.0
% INFO    : Bus 90751	: V=0.9978752, theta=34.943923 -> V=1.0, theta=0.0
% INFO    : Bus 90752	: V=0.9950271, theta=34.869254 -> V=1.0, theta=0.0
% INFO    : Bus 90753	: V=0.9954676, theta=34.381424 -> V=1.0, theta=0.0
% INFO    : Bus 90754	: V=0.9981756, theta=34.13477 -> V=1.0, theta=0.0
% INFO    : Bus 90755	: V=0.9944151, theta=34.146777 -> V=1.0, theta=0.0
% INFO    : Bus 90756	: V=0.9669476, theta=42.747814 -> V=1.0, theta=0.0
% INFO    : Bus 90757	: V=0.9943257, theta=44.454249 -> V=1.0, theta=0.0
% INFO    : Bus 90758	: V=0.9958099, theta=43.85413 -> V=1.0, theta=0.0
% INFO    : Bus 90759	: V=0.9973368, theta=44.012247 -> V=1.0, theta=0.0
% INFO    : Bus 90760	: V=1.010032, theta=35.3308 -> V=1.0, theta=0.0
% INFO    : Bus 90761	: V=1.0078431, theta=35.82414 -> V=1.0, theta=0.0
% INFO    : Bus 90762	: V=1.0088577, theta=35.592118 -> V=1.0, theta=0.0
% INFO    : Bus 90763	: V=1.0086433, theta=35.604288 -> V=1.0, theta=0.0
% INFO    : Bus 90764	: V=1.0086183, theta=35.619752 -> V=1.0, theta=0.0
% INFO    : Bus 90765	: V=1.0088741, theta=35.414442 -> V=1.0, theta=0.0
% INFO    : Bus 90766	: V=1.0029104, theta=34.585897 -> V=1.0, theta=0.0
% INFO    : Bus 90767	: V=0.9736479, theta=39.421216 -> V=1.0, theta=0.0
% INFO    : Bus 90768	: V=1.0102006, theta=28.436057 -> V=1.0, theta=0.0
% INFO    : Bus 90769	: V=1.0011712, theta=28.170413 -> V=1.0, theta=0.0
% INFO    : Bus 90770	: V=1.0082307, theta=27.89044 -> V=1.0, theta=0.0
% INFO    : Bus 90771	: V=1.0057056, theta=27.85325 -> V=1.0, theta=0.0
% INFO    : Bus 90772	: V=1.005176, theta=27.793689 -> V=1.0, theta=0.0
% INFO    : Bus 90773	: V=1.0041299, theta=27.781627 -> V=1.0, theta=0.0
% INFO    : Bus 90774	: V=1.0011762, theta=27.557779 -> V=1.0, theta=0.0
% INFO    : Bus 90775	: V=1.0040816, theta=27.558548 -> V=1.0, theta=0.0
% INFO    : Bus 90776	: V=1.0033699, theta=27.628297 -> V=1.0, theta=0.0
% INFO    : Bus 90777	: V=1.0023126, theta=27.46762 -> V=1.0, theta=0.0
% INFO    : Bus 90778	: V=0.992097, theta=27.515565 -> V=1.0, theta=0.0
% INFO    : Bus 90779	: V=0.9892459, theta=28.085482 -> V=1.0, theta=0.0
% INFO    : Bus 90780	: V=0.9910559, theta=27.638819 -> V=1.0, theta=0.0
% INFO    : Bus 90781	: V=1.0096835, theta=54.767196 -> V=1.0, theta=0.0
% INFO    : Bus 90782	: V=0.9873335, theta=41.491789 -> V=1.0, theta=0.0
% INFO    : Bus 90783	: V=0.9996241, theta=41.756111 -> V=1.0, theta=0.0
% INFO    : Bus 90784	: V=0.9960109, theta=41.570897 -> V=1.0, theta=0.0
% INFO    : Bus 90785	: V=0.9903873, theta=41.478837 -> V=1.0, theta=0.0
% INFO    : Bus 90786	: V=0.990552, theta=41.632074 -> V=1.0, theta=0.0
% INFO    : Bus 90787	: V=0.9893074, theta=50.114543 -> V=1.0, theta=0.0
% INFO    : Bus 90788	: V=0.9869309, theta=49.83981 -> V=1.0, theta=0.0
% INFO    : Bus 90789	: V=1.0122732, theta=55.589502 -> V=1.0, theta=0.0
% INFO    : Bus 90790	: V=1.0165006, theta=55.691752 -> V=1.0, theta=0.0
% INFO    : Bus 90791	: V=1.0165188, theta=55.693255 -> V=1.0, theta=0.0
% INFO    : Bus 90792	: V=1.0177377, theta=55.688804 -> V=1.0, theta=0.0
% INFO    : Bus 90793	: V=1.0168599, theta=55.884237 -> V=1.0, theta=0.0
% INFO    : Bus 90794	: V=1.011257, theta=55.642641 -> V=1.0, theta=0.0
% INFO    : Bus 90795	: V=1.0123025, theta=55.711242 -> V=1.0, theta=0.0
% INFO    : Bus 90796	: V=1.0044001, theta=54.581875 -> V=1.0, theta=0.0
% INFO    : Bus 90797	: V=0.9931663, theta=50.165131 -> V=1.0, theta=0.0
% INFO    : Bus 90798	: V=0.9953677, theta=50.233655 -> V=1.0, theta=0.0
% INFO    : Bus 90799	: V=0.9952269, theta=50.241787 -> V=1.0, theta=0.0
% INFO    : Bus 90800	: V=1.0076752, theta=50.674839 -> V=1.0, theta=0.0
% INFO    : Bus 90801	: V=1.0001146, theta=50.399387 -> V=1.0, theta=0.0
% INFO    : Bus 90802	: V=0.9903031, theta=50.417575 -> V=1.0, theta=0.0
% INFO    : Bus 90803	: V=0.9958829, theta=50.383385 -> V=1.0, theta=0.0
% INFO    : Bus 90804	: V=1.0026605, theta=50.28192 -> V=1.0, theta=0.0
% INFO    : Bus 90805	: V=0.9990852, theta=49.785152 -> V=1.0, theta=0.0
% INFO    : Bus 90806	: V=0.9970946, theta=49.870341 -> V=1.0, theta=0.0
% INFO    : Bus 90807	: V=0.9901188, theta=50.035657 -> V=1.0, theta=0.0
% INFO    : Bus 90808	: V=1.0067999, theta=54.403831 -> V=1.0, theta=0.0
% INFO    : Bus 90809	: V=0.9957355, theta=52.788799 -> V=1.0, theta=0.0
% INFO    : Bus 90810	: V=1.0094106, theta=55.896338 -> V=1.0, theta=0.0
% INFO    : Bus 90811	: V=1.0122156, theta=56.570818 -> V=1.0, theta=0.0
% INFO    : Bus 90812	: V=1.0120998, theta=31.32052 -> V=1.0, theta=0.0
% INFO    : Bus 90813	: V=1.0117357, theta=31.497202 -> V=1.0, theta=0.0
% INFO    : Bus 90814	: V=1.0134908, theta=31.780424 -> V=1.0, theta=0.0
% INFO    : Bus 90815	: V=1.0130301, theta=31.761058 -> V=1.0, theta=0.0
% INFO    : Bus 90816	: V=1.0104022, theta=31.349913 -> V=1.0, theta=0.0
% INFO    : Bus 90817	: V=1.0100515, theta=31.248878 -> V=1.0, theta=0.0
% INFO    : Bus 90818	: V=1.0102597, theta=31.180225 -> V=1.0, theta=0.0
% INFO    : Bus 90819	: V=1.0103172, theta=31.072631 -> V=1.0, theta=0.0
% INFO    : Bus 90820	: V=1.0096567, theta=30.971978 -> V=1.0, theta=0.0
% INFO    : Bus 90821	: V=1.0099802, theta=31.094101 -> V=1.0, theta=0.0
% INFO    : Bus 90822	: V=1.0093572, theta=30.940544 -> V=1.0, theta=0.0
% INFO    : Bus 90823	: V=1.0101215, theta=30.967212 -> V=1.0, theta=0.0
% INFO    : Bus 90824	: V=1.0104438, theta=31.016092 -> V=1.0, theta=0.0
% INFO    : Bus 90825	: V=1.0096192, theta=30.933405 -> V=1.0, theta=0.0
% INFO    : Bus 90826	: V=1.0094182, theta=30.933531 -> V=1.0, theta=0.0
% INFO    : Bus 90827	: V=1.0100401, theta=30.747672 -> V=1.0, theta=0.0
% INFO    : Bus 90828	: V=1.0104695, theta=30.79531 -> V=1.0, theta=0.0
% INFO    : Bus 90829	: V=1.010403, theta=30.885292 -> V=1.0, theta=0.0
% INFO    : Bus 90830	: V=1.0106085, theta=30.878227 -> V=1.0, theta=0.0
% INFO    : Bus 90831	: V=1.0105517, theta=30.794365 -> V=1.0, theta=0.0
% INFO    : Bus 90832	: V=1.0105638, theta=30.841048 -> V=1.0, theta=0.0
% INFO    : Bus 90833	: V=1.0105274, theta=30.839389 -> V=1.0, theta=0.0
% INFO    : Bus 90834	: V=1.0105689, theta=30.81785 -> V=1.0, theta=0.0
% INFO    : Bus 90835	: V=1.0103419, theta=30.707627 -> V=1.0, theta=0.0
% INFO    : Bus 90836	: V=1.0091695, theta=30.582834 -> V=1.0, theta=0.0
% INFO    : Bus 90837	: V=1.0103451, theta=30.697927 -> V=1.0, theta=0.0
% INFO    : Bus 90838	: V=1.0103853, theta=30.725312 -> V=1.0, theta=0.0
% INFO    : Bus 90839	: V=1.0103034, theta=30.816122 -> V=1.0, theta=0.0
% INFO    : Bus 90840	: V=1.0100636, theta=30.670177 -> V=1.0, theta=0.0
% INFO    : Bus 90841	: V=1.0093535, theta=30.574706 -> V=1.0, theta=0.0
% INFO    : Bus 90842	: V=1.010026, theta=30.663725 -> V=1.0, theta=0.0
% INFO    : Bus 90843	: V=1.0112043, theta=30.798256 -> V=1.0, theta=0.0
% INFO    : Bus 90844	: V=1.0100192, theta=30.678322 -> V=1.0, theta=0.0
% INFO    : Bus 90845	: V=1.0089344, theta=30.631238 -> V=1.0, theta=0.0
% INFO    : Bus 90846	: V=1.0093568, theta=30.580308 -> V=1.0, theta=0.0
% INFO    : Bus 90847	: V=1.0089728, theta=30.539439 -> V=1.0, theta=0.0
% INFO    : Bus 90848	: V=1.0086169, theta=30.472688 -> V=1.0, theta=0.0
% INFO    : Bus 90849	: V=1.0085107, theta=30.424599 -> V=1.0, theta=0.0
% INFO    : Bus 90850	: V=1.0085887, theta=30.434369 -> V=1.0, theta=0.0
% INFO    : Bus 90851	: V=1.0086212, theta=30.426938 -> V=1.0, theta=0.0
% INFO    : Bus 90852	: V=1.0087312, theta=30.265436 -> V=1.0, theta=0.0
% INFO    : Bus 90853	: V=1.0082401, theta=30.253591 -> V=1.0, theta=0.0
% INFO    : Bus 90854	: V=1.0085934, theta=30.415662 -> V=1.0, theta=0.0
% INFO    : Bus 90855	: V=1.0085078, theta=30.285644 -> V=1.0, theta=0.0
% INFO    : Bus 90856	: V=1.0080931, theta=30.321645 -> V=1.0, theta=0.0
% INFO    : Bus 90857	: V=1.0085943, theta=30.250759 -> V=1.0, theta=0.0
% INFO    : Bus 90858	: V=1.0091301, theta=30.287198 -> V=1.0, theta=0.0
% INFO    : Bus 90859	: V=1.0089426, theta=30.324233 -> V=1.0, theta=0.0
% INFO    : Bus 90860	: V=1.0087157, theta=30.310125 -> V=1.0, theta=0.0
% INFO    : Bus 90861	: V=1.0102304, theta=30.427038 -> V=1.0, theta=0.0
% INFO    : Bus 90862	: V=1.0088937, theta=30.290917 -> V=1.0, theta=0.0
% INFO    : Bus 90863	: V=1.0123503, theta=31.231061 -> V=1.0, theta=0.0
% INFO    : Bus 90864	: V=1.0109729, theta=31.218885 -> V=1.0, theta=0.0
% INFO    : Bus 90865	: V=1.0097953, theta=30.645535 -> V=1.0, theta=0.0
% INFO    : Bus 90866	: V=1.0111852, theta=30.735373 -> V=1.0, theta=0.0
% INFO    : Bus 90867	: V=1.0104678, theta=30.68193 -> V=1.0, theta=0.0
% INFO    : Bus 90868	: V=1.0101996, theta=30.893194 -> V=1.0, theta=0.0
% INFO    : Bus 90869	: V=1.0115437, theta=31.023522 -> V=1.0, theta=0.0
% INFO    : Bus 90870	: V=1.0058556, theta=31.397421 -> V=1.0, theta=0.0
% INFO    : Bus 90871	: V=1.0102012, theta=30.807964 -> V=1.0, theta=0.0
% INFO    : Bus 90872	: V=1.0095629, theta=30.699881 -> V=1.0, theta=0.0
% INFO    : Bus 90873	: V=1.0086844, theta=30.616161 -> V=1.0, theta=0.0
% INFO    : Bus 90874	: V=1.0079856, theta=30.440632 -> V=1.0, theta=0.0
% INFO    : Bus 90875	: V=1.0085025, theta=30.626241 -> V=1.0, theta=0.0
% INFO    : Bus 90876	: V=1.0071508, theta=31.23167 -> V=1.0, theta=0.0
% INFO    : Bus 90877	: V=1.0084464, theta=30.435308 -> V=1.0, theta=0.0
% INFO    : Bus 90878	: V=1.006002, theta=30.64838 -> V=1.0, theta=0.0
% INFO    : Bus 90879	: V=1.00684, theta=30.301253 -> V=1.0, theta=0.0
% INFO    : Bus 90880	: V=1.0072519, theta=30.148118 -> V=1.0, theta=0.0
% INFO    : Bus 90881	: V=1.0117432, theta=30.252916 -> V=1.0, theta=0.0
% INFO    : Bus 90882	: V=1.0095166, theta=29.960643 -> V=1.0, theta=0.0
% INFO    : Bus 90883	: V=1.0102361, theta=29.767708 -> V=1.0, theta=0.0
% INFO    : Bus 90884	: V=1.0100116, theta=29.893461 -> V=1.0, theta=0.0
% INFO    : Bus 90885	: V=1.0098733, theta=29.844703 -> V=1.0, theta=0.0
% INFO    : Bus 90886	: V=1.0091539, theta=29.922206 -> V=1.0, theta=0.0
% INFO    : Bus 90887	: V=1.0098272, theta=29.927374 -> V=1.0, theta=0.0
% INFO    : Bus 90888	: V=1.0082692, theta=30.217976 -> V=1.0, theta=0.0
% INFO    : Bus 90889	: V=1.0098925, theta=30.792463 -> V=1.0, theta=0.0
% INFO    : Bus 90890	: V=1.0086657, theta=30.554666 -> V=1.0, theta=0.0
% INFO    : Bus 90891	: V=1.0090078, theta=30.552931 -> V=1.0, theta=0.0
% INFO    : Bus 90892	: V=1.0084841, theta=30.506313 -> V=1.0, theta=0.0
% INFO    : Bus 90893	: V=1.0083828, theta=30.42295 -> V=1.0, theta=0.0
% INFO    : Bus 90894	: V=1.0102936, theta=30.649929 -> V=1.0, theta=0.0
% INFO    : Bus 90895	: V=1.0091986, theta=30.523945 -> V=1.0, theta=0.0
% INFO    : Bus 90896	: V=1.0026869, theta=29.99169 -> V=1.0, theta=0.0
% INFO    : Bus 90897	: V=1.0082575, theta=30.43653 -> V=1.0, theta=0.0
% INFO    : Bus 90898	: V=1.0068864, theta=43.179516 -> V=1.0, theta=0.0
% INFO    : Bus 90899	: V=0.9889116, theta=41.964653 -> V=1.0, theta=0.0
% INFO    : Bus 90900	: V=0.9747291, theta=41.217634 -> V=1.0, theta=0.0
% INFO    : Bus 90901	: V=0.9926743, theta=54.486777 -> V=1.0, theta=0.0
% INFO    : Bus 90902	: V=0.9953163, theta=50.144902 -> V=1.0, theta=0.0
% INFO    : Bus 90903	: V=1.0070029, theta=50.731263 -> V=1.0, theta=0.0
% INFO    : Bus 90904	: V=0.9994617, theta=50.507553 -> V=1.0, theta=0.0
% INFO    : Bus 90905	: V=1.0037759, theta=51.805541 -> V=1.0, theta=0.0
% INFO    : Bus 90906	: V=1.0059193, theta=51.926729 -> V=1.0, theta=0.0
% INFO    : Bus 90907	: V=1.0006318, theta=51.420705 -> V=1.0, theta=0.0
% INFO    : Bus 90908	: V=0.9927265, theta=50.905653 -> V=1.0, theta=0.0
% INFO    : Bus 90909	: V=0.9960377, theta=51.289564 -> V=1.0, theta=0.0
% INFO    : Bus 90910	: V=1.0037841, theta=51.841708 -> V=1.0, theta=0.0
% INFO    : Bus 90911	: V=1.0058112, theta=51.936821 -> V=1.0, theta=0.0
% INFO    : Bus 90912	: V=1.0059468, theta=52.098715 -> V=1.0, theta=0.0
% INFO    : Bus 90913	: V=1.0153409, theta=52.834052 -> V=1.0, theta=0.0
% INFO    : Bus 90914	: V=1.0186867, theta=53.424407 -> V=1.0, theta=0.0
% INFO    : Bus 90915	: V=0.9922879, theta=50.702034 -> V=1.0, theta=0.0
% INFO    : Bus 90916	: V=1.0163286, theta=53.417335 -> V=1.0, theta=0.0
% INFO    : Bus 90917	: V=1.0193509, theta=32.82191 -> V=1.0, theta=0.0
% INFO    : Bus 90918	: V=1.0192247, theta=32.99226 -> V=1.0, theta=0.0
% INFO    : Bus 90919	: V=1.0166064, theta=33.230926 -> V=1.0, theta=0.0
% INFO    : Bus 90920	: V=1.011758, theta=32.36196 -> V=1.0, theta=0.0
% INFO    : Bus 90921	: V=1.015944, theta=32.559619 -> V=1.0, theta=0.0
% INFO    : Bus 90922	: V=1.0149389, theta=31.98232 -> V=1.0, theta=0.0
% INFO    : Bus 90923	: V=1.0124395, theta=31.833271 -> V=1.0, theta=0.0
% INFO    : Bus 90924	: V=1.0094409, theta=44.078279 -> V=1.0, theta=0.0
% INFO    : Bus 90925	: V=0.9996429, theta=44.102588 -> V=1.0, theta=0.0
% INFO    : Bus 90926	: V=0.9932031, theta=49.783697 -> V=1.0, theta=0.0
% INFO    : Bus 90927	: V=0.9867229, theta=50.01156 -> V=1.0, theta=0.0
% INFO    : Bus 90928	: V=0.9869761, theta=49.860437 -> V=1.0, theta=0.0
% INFO    : Bus 90929	: V=0.9950772, theta=50.104951 -> V=1.0, theta=0.0
% INFO    : Bus 90930	: V=0.9808946, theta=48.141217 -> V=1.0, theta=0.0
% INFO    : Bus 90931	: V=1.0079677, theta=28.710529 -> V=1.0, theta=0.0
% INFO    : Bus 90932	: V=1.0079279, theta=28.709474 -> V=1.0, theta=0.0
% INFO    : Bus 90933	: V=1.0091291, theta=28.857872 -> V=1.0, theta=0.0
% INFO    : Bus 90934	: V=1.0083475, theta=28.71527 -> V=1.0, theta=0.0
% INFO    : Bus 90935	: V=1.0090981, theta=28.871645 -> V=1.0, theta=0.0
% INFO    : Bus 90936	: V=1.0100969, theta=29.039146 -> V=1.0, theta=0.0
% INFO    : Bus 90937	: V=1.0101033, theta=29.002626 -> V=1.0, theta=0.0
% INFO    : Bus 90938	: V=1.0103483, theta=29.02846 -> V=1.0, theta=0.0
% INFO    : Bus 90939	: V=1.0106919, theta=29.054649 -> V=1.0, theta=0.0
% INFO    : Bus 90940	: V=1.0100371, theta=29.070538 -> V=1.0, theta=0.0
% INFO    : Bus 90941	: V=1.0116245, theta=29.164781 -> V=1.0, theta=0.0
% INFO    : Bus 90942	: V=1.0071822, theta=28.833974 -> V=1.0, theta=0.0
% INFO    : Bus 90943	: V=1.0076506, theta=28.923718 -> V=1.0, theta=0.0
% INFO    : Bus 90944	: V=1.0081074, theta=28.821888 -> V=1.0, theta=0.0
% INFO    : Bus 90945	: V=0.9958012, theta=29.020458 -> V=1.0, theta=0.0
% INFO    : Bus 90946	: V=0.9916331, theta=29.282794 -> V=1.0, theta=0.0
% INFO    : Bus 90947	: V=0.9819828, theta=38.684684 -> V=1.0, theta=0.0
% INFO    : Bus 90948	: V=0.980773, theta=37.950903 -> V=1.0, theta=0.0
% INFO    : Bus 90949	: V=0.9776505, theta=37.943718 -> V=1.0, theta=0.0
% INFO    : Bus 90950	: V=1.0018114, theta=34.808412 -> V=1.0, theta=0.0
% INFO    : Bus 90951	: V=1.0042039, theta=34.699164 -> V=1.0, theta=0.0
% INFO    : Bus 90952	: V=0.9988624, theta=34.824139 -> V=1.0, theta=0.0
% INFO    : Bus 90953	: V=1.0049418, theta=34.943401 -> V=1.0, theta=0.0
% INFO    : Bus 90954	: V=1.0040247, theta=34.711928 -> V=1.0, theta=0.0
% INFO    : Bus 90955	: V=1.0071243, theta=34.566137 -> V=1.0, theta=0.0
% INFO    : Bus 90956	: V=1.0105028, theta=34.12894 -> V=1.0, theta=0.0
% INFO    : Bus 90957	: V=1.010922, theta=34.118436 -> V=1.0, theta=0.0
% INFO    : Bus 90958	: V=1.0083516, theta=35.483682 -> V=1.0, theta=0.0
% INFO    : Bus 90959	: V=1.0075582, theta=35.271187 -> V=1.0, theta=0.0
% INFO    : Bus 90960	: V=0.9997547, theta=44.75437 -> V=1.0, theta=0.0
% INFO    : Bus 90961	: V=1.009527, theta=45.039522 -> V=1.0, theta=0.0
% INFO    : Bus 90962	: V=0.9945272, theta=44.251186 -> V=1.0, theta=0.0
% INFO    : Bus 90963	: V=1.0040356, theta=44.288317 -> V=1.0, theta=0.0
% INFO    : Bus 90964	: V=0.9740973, theta=37.356542 -> V=1.0, theta=0.0
% INFO    : Bus 90965	: V=0.969868, theta=37.877509 -> V=1.0, theta=0.0
% INFO    : Bus 90966	: V=1.0054724, theta=36.441131 -> V=1.0, theta=0.0
% INFO    : Bus 90967	: V=1.0065151, theta=37.087992 -> V=1.0, theta=0.0
% INFO    : Bus 90968	: V=1.0074541, theta=37.249408 -> V=1.0, theta=0.0
% INFO    : Bus 90969	: V=1.0107763, theta=36.908324 -> V=1.0, theta=0.0
% INFO    : Bus 90970	: V=1.0143723, theta=36.686773 -> V=1.0, theta=0.0
% INFO    : Bus 90971	: V=1.0095259, theta=36.638851 -> V=1.0, theta=0.0
% INFO    : Bus 90972	: V=1.0038046, theta=36.866491 -> V=1.0, theta=0.0
% INFO    : Bus 90973	: V=1.0160659, theta=36.308815 -> V=1.0, theta=0.0
% INFO    : Bus 90974	: V=1.0120463, theta=36.175017 -> V=1.0, theta=0.0
% INFO    : Bus 90975	: V=1.0097135, theta=36.394168 -> V=1.0, theta=0.0
% INFO    : Bus 90976	: V=1.0045171, theta=35.661795 -> V=1.0, theta=0.0
% INFO    : Bus 90977	: V=1.0158996, theta=35.727561 -> V=1.0, theta=0.0
% INFO    : Bus 90978	: V=1.0140734, theta=35.706934 -> V=1.0, theta=0.0
% INFO    : Bus 90979	: V=0.9781098, theta=48.563764 -> V=1.0, theta=0.0
% INFO    : Bus 90980	: V=0.9819505, theta=39.316152 -> V=1.0, theta=0.0
% INFO    : Bus 90981	: V=0.9925336, theta=40.571955 -> V=1.0, theta=0.0
% INFO    : Bus 90982	: V=1.0020208, theta=40.116499 -> V=1.0, theta=0.0
% INFO    : Bus 90983	: V=0.9942378, theta=33.460334 -> V=1.0, theta=0.0
% INFO    : Bus 90984	: V=1.0059438, theta=34.289181 -> V=1.0, theta=0.0
% INFO    : Bus 90985	: V=1.0091486, theta=34.905978 -> V=1.0, theta=0.0
% INFO    : Bus 90986	: V=0.9940435, theta=32.719288 -> V=1.0, theta=0.0
% INFO    : Bus 90987	: V=0.9889518, theta=32.166224 -> V=1.0, theta=0.0
% INFO    : Bus 90988	: V=0.988943, theta=31.445792 -> V=1.0, theta=0.0
% INFO    : Bus 90989	: V=0.987839, theta=31.539134 -> V=1.0, theta=0.0
% INFO    : Bus 90990	: V=0.9844571, theta=30.874566 -> V=1.0, theta=0.0
% INFO    : Bus 90991	: V=0.9731736, theta=44.16407 -> V=1.0, theta=0.0
% INFO    : Bus 90992	: V=1.0071485, theta=34.123323 -> V=1.0, theta=0.0
% INFO    : Bus 90993	: V=1.0111803, theta=34.655459 -> V=1.0, theta=0.0
% INFO    : Bus 90994	: V=1.0068652, theta=34.317392 -> V=1.0, theta=0.0
% INFO    : Bus 90995	: V=1.0079814, theta=34.179292 -> V=1.0, theta=0.0
% INFO    : Bus 90996	: V=1.0076428, theta=34.10802 -> V=1.0, theta=0.0
% INFO    : Bus 90997	: V=1.0094039, theta=33.910203 -> V=1.0, theta=0.0
% INFO    : Bus 90998	: V=1.0082998, theta=34.074336 -> V=1.0, theta=0.0
% INFO    : Bus 90999	: V=1.011717, theta=33.611649 -> V=1.0, theta=0.0
% INFO    : Bus 91000	: V=1.0092191, theta=33.969941 -> V=1.0, theta=0.0
% INFO    : Bus 91001	: V=1.0098607, theta=33.544786 -> V=1.0, theta=0.0
% INFO    : Bus 91002	: V=1.0139102, theta=32.023292 -> V=1.0, theta=0.0
% INFO    : Bus 91003	: V=1.0077204, theta=32.552493 -> V=1.0, theta=0.0
% INFO    : Bus 91004	: V=1.0098369, theta=31.627143 -> V=1.0, theta=0.0
% INFO    : Bus 91005	: V=1.0126437, theta=31.166181 -> V=1.0, theta=0.0
% INFO    : Bus 91006	: V=1.0067421, theta=31.542713 -> V=1.0, theta=0.0
% INFO    : Bus 91007	: V=1.0085414, theta=31.673938 -> V=1.0, theta=0.0
% INFO    : Bus 91008	: V=1.0056837, theta=31.479262 -> V=1.0, theta=0.0
% INFO    : Bus 91009	: V=1.0070449, theta=31.560929 -> V=1.0, theta=0.0
% INFO    : Bus 91010	: V=1.0078112, theta=31.316924 -> V=1.0, theta=0.0
% INFO    : Bus 91011	: V=1.0064887, theta=31.011777 -> V=1.0, theta=0.0
% INFO    : Bus 91012	: V=1.0055366, theta=32.270227 -> V=1.0, theta=0.0
% INFO    : Bus 91013	: V=1.0064346, theta=32.068764 -> V=1.0, theta=0.0
% INFO    : Bus 91014	: V=1.0068485, theta=31.938866 -> V=1.0, theta=0.0
% INFO    : Bus 91015	: V=1.0055851, theta=32.191904 -> V=1.0, theta=0.0
% INFO    : Bus 91016	: V=1.0061658, theta=32.635413 -> V=1.0, theta=0.0
% INFO    : Bus 91017	: V=1.0047598, theta=33.226694 -> V=1.0, theta=0.0
% INFO    : Bus 91018	: V=1.0064996, theta=32.750393 -> V=1.0, theta=0.0
% INFO    : Bus 91019	: V=1.0090206, theta=32.50756 -> V=1.0, theta=0.0
% INFO    : Bus 91020	: V=1.0105529, theta=33.224863 -> V=1.0, theta=0.0
% INFO    : Bus 91021	: V=1.0091512, theta=33.36409 -> V=1.0, theta=0.0
% INFO    : Bus 91022	: V=1.0051659, theta=33.0413 -> V=1.0, theta=0.0
% INFO    : Bus 91023	: V=1.0054407, theta=32.88801 -> V=1.0, theta=0.0
% INFO    : Bus 91024	: V=1.0033402, theta=32.644658 -> V=1.0, theta=0.0
% INFO    : Bus 91025	: V=1.0047105, theta=33.686019 -> V=1.0, theta=0.0
% INFO    : Bus 91026	: V=1.0090497, theta=34.117481 -> V=1.0, theta=0.0
% INFO    : Bus 91027	: V=1.0077691, theta=33.806707 -> V=1.0, theta=0.0
% INFO    : Bus 91028	: V=1.011175, theta=34.131057 -> V=1.0, theta=0.0
% INFO    : Bus 91029	: V=0.9886057, theta=50.160519 -> V=1.0, theta=0.0
% INFO    : Bus 91030	: V=0.9893703, theta=49.968491 -> V=1.0, theta=0.0
% INFO    : Bus 91031	: V=0.9804821, theta=45.377784 -> V=1.0, theta=0.0
% INFO    : Bus 91032	: V=0.9796404, theta=45.32683 -> V=1.0, theta=0.0
% INFO    : Bus 91033	: V=0.9793469, theta=45.094405 -> V=1.0, theta=0.0
% INFO    : Bus 91034	: V=0.9782146, theta=44.982444 -> V=1.0, theta=0.0
% INFO    : Bus 91035	: V=0.9819736, theta=45.678487 -> V=1.0, theta=0.0
% INFO    : Bus 91036	: V=0.9913258, theta=43.675799 -> V=1.0, theta=0.0
% INFO    : Bus 91037	: V=0.9704857, theta=44.207312 -> V=1.0, theta=0.0
% INFO    : Bus 91038	: V=0.9898419, theta=50.668535 -> V=1.0, theta=0.0
% INFO    : Bus 91039	: V=0.992691, theta=50.182293 -> V=1.0, theta=0.0
% INFO    : Bus 91040	: V=0.9929487, theta=49.948955 -> V=1.0, theta=0.0
% INFO    : Bus 91041	: V=1.0047526, theta=49.186191 -> V=1.0, theta=0.0
% INFO    : Bus 91042	: V=0.994914, theta=49.455796 -> V=1.0, theta=0.0
% INFO    : Bus 91043	: V=1.0031788, theta=48.730328 -> V=1.0, theta=0.0
% INFO    : Bus 91044	: V=0.9881032, theta=48.617514 -> V=1.0, theta=0.0
% INFO    : Bus 91045	: V=0.9678416, theta=47.133011 -> V=1.0, theta=0.0
% INFO    : Bus 91046	: V=1.020433, theta=-24.151681 -> V=1.0, theta=0.0
% INFO    : Bus 91047	: V=1.0169164, theta=-25.3204 -> V=1.0, theta=0.0
% INFO    : Bus 91048	: V=1.0162012, theta=-25.448428 -> V=1.0, theta=0.0
% INFO    : Bus 91049	: V=1.0200051, theta=-29.821347 -> V=1.0, theta=0.0
% INFO    : Bus 91050	: V=1.019553, theta=-29.94145 -> V=1.0, theta=0.0
% INFO    : Bus 91051	: V=1.0222241, theta=-19.683329 -> V=1.0, theta=0.0
% INFO    : Bus 91052	: V=1.0197037, theta=-20.446191 -> V=1.0, theta=0.0
% INFO    : Bus 91053	: V=1.0184086, theta=-20.692821 -> V=1.0, theta=0.0
% INFO    : Bus 91054	: V=1.017642, theta=-20.964746 -> V=1.0, theta=0.0
% INFO    : Bus 91055	: V=1.0152817, theta=-18.969669 -> V=1.0, theta=0.0
% INFO    : Bus 91056	: V=1.0148323, theta=-19.42018 -> V=1.0, theta=0.0
% INFO    : Bus 91057	: V=1.014222, theta=-19.512937 -> V=1.0, theta=0.0
% INFO    : Bus 91058	: V=1.0011904, theta=-28.7368 -> V=1.0, theta=0.0
% INFO    : Bus 91059	: V=1.0194595, theta=-22.981605 -> V=1.0, theta=0.0
% INFO    : Bus 91060	: V=1.0192099, theta=-22.673103 -> V=1.0, theta=0.0
% INFO    : Bus 91061	: V=1.0178019, theta=-32.476081 -> V=1.0, theta=0.0
% INFO    : Bus 91062	: V=1.0164481, theta=-33.018105 -> V=1.0, theta=0.0
% INFO    : Bus 91063	: V=1.014128, theta=-33.351003 -> V=1.0, theta=0.0
% INFO    : Bus 91064	: V=1.0187393, theta=-16.666557 -> V=1.0, theta=0.0
% INFO    : Bus 91065	: V=1.0199822, theta=-16.213682 -> V=1.0, theta=0.0
% INFO    : Bus 91066	: V=1.0162473, theta=-34.275184 -> V=1.0, theta=0.0
% INFO    : Bus 91067	: V=1.0151836, theta=-34.370322 -> V=1.0, theta=0.0
% INFO    : Bus 91068	: V=1.02, theta=-29.240945 -> V=1.0, theta=0.0
% INFO    : Bus 91069	: V=1.0192166, theta=-29.761956 -> V=1.0, theta=0.0
% INFO    : Bus 91070	: V=1.010198, theta=-36.612016 -> V=1.0, theta=0.0
% INFO    : Bus 91071	: V=1.0011287, theta=-38.855151 -> V=1.0, theta=0.0
% INFO    : Bus 91072	: V=1.0005046, theta=-38.873389 -> V=1.0, theta=0.0
% INFO    : Bus 91073	: V=1.0072132, theta=-46.09725 -> V=1.0, theta=0.0
% INFO    : Bus 91074	: V=1.0122163, theta=-36.235642 -> V=1.0, theta=0.0
% INFO    : Bus 91075	: V=1.0195159, theta=-26.528466 -> V=1.0, theta=0.0
% INFO    : Bus 91076	: V=1.02, theta=-27.236709 -> V=1.0, theta=0.0
% INFO    : Bus 91077	: V=1.0123702, theta=-23.374234 -> V=1.0, theta=0.0
% INFO    : Bus 91078	: V=1.0004625, theta=-29.25669 -> V=1.0, theta=0.0
% INFO    : Bus 91079	: V=1.0000686, theta=-29.369219 -> V=1.0, theta=0.0
% INFO    : Bus 91080	: V=1.0066476, theta=-31.623905 -> V=1.0, theta=0.0
% INFO    : Bus 91081	: V=1.0068599, theta=-31.359429 -> V=1.0, theta=0.0
% INFO    : Bus 91082	: V=1.0187706, theta=-21.040156 -> V=1.0, theta=0.0
% INFO    : Bus 91083	: V=0.9851116, theta=-27.055007 -> V=1.0, theta=0.0
% INFO    : Bus 91084	: V=1.0165648, theta=-30.363066 -> V=1.0, theta=0.0
% INFO    : Bus 91085	: V=1.0129145, theta=-30.87142 -> V=1.0, theta=0.0
% INFO    : Bus 91086	: V=1.0119937, theta=-31.017674 -> V=1.0, theta=0.0
% INFO    : Bus 91087	: V=0.9865223, theta=-27.888039 -> V=1.0, theta=0.0
% INFO    : Bus 91088	: V=1.02, theta=-47.739371 -> V=1.0, theta=0.0
% INFO    : Bus 91089	: V=1.0131586, theta=-23.262277 -> V=1.0, theta=0.0
% INFO    : Bus 91090	: V=1.02, theta=-25.198584 -> V=1.0, theta=0.0
% INFO    : Bus 91091	: V=1.0165991, theta=-33.270079 -> V=1.0, theta=0.0
% INFO    : Bus 91092	: V=1.0159188, theta=-33.295901 -> V=1.0, theta=0.0
% INFO    : Bus 91093	: V=1.0162959, theta=-33.518127 -> V=1.0, theta=0.0
% INFO    : Bus 91094	: V=1.0136178, theta=-36.092817 -> V=1.0, theta=0.0
% INFO    : Bus 91095	: V=1.0124924, theta=-22.204571 -> V=1.0, theta=0.0
% INFO    : Bus 91096	: V=1.0124299, theta=-22.46548 -> V=1.0, theta=0.0
% INFO    : Bus 91097	: V=1.0102018, theta=-35.247969 -> V=1.0, theta=0.0
% INFO    : Bus 91098	: V=0.9907405, theta=-30.175661 -> V=1.0, theta=0.0
% INFO    : Bus 91099	: V=1.0139091, theta=-34.069424 -> V=1.0, theta=0.0
% INFO    : Bus 91100	: V=1.016723, theta=-47.332703 -> V=1.0, theta=0.0
% INFO    : Bus 91101	: V=1.0047074, theta=-41.258459 -> V=1.0, theta=0.0
% INFO    : Bus 91102	: V=1.02, theta=-38.759421 -> V=1.0, theta=0.0
% INFO    : Bus 91103	: V=0.9901893, theta=-32.428506 -> V=1.0, theta=0.0
% INFO    : Bus 91104	: V=1.02, theta=-28.893457 -> V=1.0, theta=0.0
% INFO    : Bus 91105	: V=1.02, theta=-17.380296 -> V=1.0, theta=0.0
% INFO    : Bus 91106	: V=1.0188081, theta=-17.566111 -> V=1.0, theta=0.0
% INFO    : Bus 91107	: V=1.0194932, theta=-26.553588 -> V=1.0, theta=0.0
% INFO    : Bus 91108	: V=1.02, theta=-27.158873 -> V=1.0, theta=0.0
% INFO    : Bus 91109	: V=1.02, theta=-30.086828 -> V=1.0, theta=0.0
% INFO    : Bus 91110	: V=1.019511, theta=-30.115445 -> V=1.0, theta=0.0
% INFO    : Bus 91111	: V=1.0199306, theta=-60.754586 -> V=1.0, theta=0.0
% INFO    : Bus 91112	: V=1.0147856, theta=-58.929733 -> V=1.0, theta=0.0
% INFO    : Bus 91113	: V=1.0096856, theta=-57.084693 -> V=1.0, theta=0.0
% INFO    : Bus 91114	: V=1.0089834, theta=-57.189017 -> V=1.0, theta=0.0
% INFO    : Bus 91115	: V=1.0198964, theta=-59.344897 -> V=1.0, theta=0.0
% INFO    : Bus 91116	: V=1.0153138, theta=-64.984242 -> V=1.0, theta=0.0
% INFO    : Bus 91117	: V=1.0098909, theta=-65.618166 -> V=1.0, theta=0.0
% INFO    : Bus 91118	: V=1.0155926, theta=-54.794628 -> V=1.0, theta=0.0
% INFO    : Bus 91119	: V=1.0127526, theta=-55.081962 -> V=1.0, theta=0.0
% INFO    : Bus 91120	: V=1.0193739, theta=-60.85565 -> V=1.0, theta=0.0
% INFO    : Bus 91121	: V=1.0188881, theta=-61.006013 -> V=1.0, theta=0.0
% INFO    : Bus 91122	: V=1.0195619, theta=-60.742977 -> V=1.0, theta=0.0
% INFO    : Bus 91123	: V=1.0193386, theta=-60.853691 -> V=1.0, theta=0.0
% INFO    : Bus 91124	: V=1.0140276, theta=-64.429579 -> V=1.0, theta=0.0
% INFO    : Bus 91125	: V=1.0138611, theta=-64.45576 -> V=1.0, theta=0.0
% INFO    : Bus 91126	: V=1.0143569, theta=-40.625602 -> V=1.0, theta=0.0
% INFO    : Bus 91127	: V=1.0111317, theta=-40.269191 -> V=1.0, theta=0.0
% INFO    : Bus 91128	: V=1.012468, theta=-62.294713 -> V=1.0, theta=0.0
% INFO    : Bus 91129	: V=1.0034265, theta=-63.284118 -> V=1.0, theta=0.0
% INFO    : Bus 91130	: V=1.0141506, theta=-65.557923 -> V=1.0, theta=0.0
% INFO    : Bus 91131	: V=1.0012706, theta=-60.99908 -> V=1.0, theta=0.0
% INFO    : Bus 91132	: V=0.9975239, theta=-61.461097 -> V=1.0, theta=0.0
% INFO    : Bus 91133	: V=0.9887202, theta=-59.887486 -> V=1.0, theta=0.0
% INFO    : Bus 91134	: V=1.0190143, theta=-38.282977 -> V=1.0, theta=0.0
% INFO    : Bus 91135	: V=1.0194977, theta=-60.915175 -> V=1.0, theta=0.0
% INFO    : Bus 91136	: V=1.0181386, theta=-65.352432 -> V=1.0, theta=0.0
% INFO    : Bus 91137	: V=1.0168423, theta=-65.454282 -> V=1.0, theta=0.0
% INFO    : Bus 91138	: V=1.0143533, theta=-61.731238 -> V=1.0, theta=0.0
% INFO    : Bus 91139	: V=1.0088558, theta=-62.438575 -> V=1.0, theta=0.0
% INFO    : Bus 91140	: V=0.9996498, theta=-63.496681 -> V=1.0, theta=0.0
% INFO    : Bus 91141	: V=1.0191467, theta=-59.540877 -> V=1.0, theta=0.0
% INFO    : Bus 91142	: V=1.0179465, theta=-59.681476 -> V=1.0, theta=0.0
% INFO    : Bus 91143	: V=1.0066397, theta=-64.04026 -> V=1.0, theta=0.0
% INFO    : Bus 91144	: V=1.0195069, theta=-61.016069 -> V=1.0, theta=0.0
% INFO    : Bus 91145	: V=0.9945088, theta=-60.465292 -> V=1.0, theta=0.0
% INFO    : Bus 91146	: V=1.0115885, theta=-62.298243 -> V=1.0, theta=0.0
% INFO    : Bus 91147	: V=1.0092135, theta=-62.635172 -> V=1.0, theta=0.0
% INFO    : Bus 91148	: V=1.02, theta=-64.260178 -> V=1.0, theta=0.0
% INFO    : Bus 91149	: V=1.0123116, theta=-65.07311 -> V=1.0, theta=0.0
% INFO    : Bus 91150	: V=1.0085694, theta=-65.402192 -> V=1.0, theta=0.0
% INFO    : Bus 91151	: V=1.02, theta=-61.655393 -> V=1.0, theta=0.0
% INFO    : Bus 91152	: V=1.0006636, theta=-64.415759 -> V=1.0, theta=0.0
% INFO    : Bus 91153	: V=1.0019757, theta=-64.308983 -> V=1.0, theta=0.0
% INFO    : Bus 91154	: V=1.02, theta=-58.212045 -> V=1.0, theta=0.0
% INFO    : Bus 91155	: V=1.0119179, theta=-62.297321 -> V=1.0, theta=0.0
% INFO    : Bus 91156	: V=1.0071883, theta=-62.881316 -> V=1.0, theta=0.0
% INFO    : Bus 91157	: V=1.0066761, theta=-62.989858 -> V=1.0, theta=0.0
% INFO    : Bus 91158	: V=1.0200844, theta=-39.369369 -> V=1.0, theta=0.0
% INFO    : Bus 91159	: V=1.0188486, theta=-38.411284 -> V=1.0, theta=0.0
% INFO    : Bus 91160	: V=1.0183015, theta=-38.474085 -> V=1.0, theta=0.0
% INFO    : Bus 91161	: V=0.9908089, theta=-70.359515 -> V=1.0, theta=0.0
% INFO    : Bus 91162	: V=0.9968588, theta=-57.855765 -> V=1.0, theta=0.0
% INFO    : Bus 91163	: V=0.9783864, theta=-68.194554 -> V=1.0, theta=0.0
% INFO    : Bus 91164	: V=0.976399, theta=-68.850408 -> V=1.0, theta=0.0
% INFO    : Bus 91165	: V=1.0129681, theta=-65.680207 -> V=1.0, theta=0.0
% INFO    : Bus 91166	: V=1.0150661, theta=-65.481324 -> V=1.0, theta=0.0
% INFO    : Bus 91167	: V=0.9725897, theta=-69.184617 -> V=1.0, theta=0.0
% INFO    : Bus 91168	: V=0.9735516, theta=-69.6702 -> V=1.0, theta=0.0
% INFO    : Bus 91169	: V=1.02, theta=-43.145482 -> V=1.0, theta=0.0
% INFO    : Bus 91170	: V=1.02, theta=-56.962873 -> V=1.0, theta=0.0
% INFO    : Bus 91171	: V=1.02, theta=-62.674853 -> V=1.0, theta=0.0
% INFO    : Bus 91172	: V=0.9936636, theta=-65.050013 -> V=1.0, theta=0.0
% INFO    : Bus 91173	: V=1.019267, theta=-59.255784 -> V=1.0, theta=0.0
% INFO    : Bus 91174	: V=1.0131086, theta=-59.811653 -> V=1.0, theta=0.0
% INFO    : Bus 91175	: V=0.9986291, theta=-64.227162 -> V=1.0, theta=0.0
% INFO    : Bus 91176	: V=1.0091514, theta=3.556679 -> V=1.0, theta=0.0
% INFO    : Bus 91177	: V=1.003177, theta=1.590991 -> V=1.0, theta=0.0
% INFO    : Bus 91178	: V=1.0027164, theta=1.457639 -> V=1.0, theta=0.0
% INFO    : Bus 91179	: V=1.0091545, theta=-4.372779 -> V=1.0, theta=0.0
% INFO    : Bus 91180	: V=1.0092286, theta=-4.956454 -> V=1.0, theta=0.0
% INFO    : Bus 91181	: V=1.0208956, theta=-11.818 -> V=1.0, theta=0.0
% INFO    : Bus 91182	: V=1.0206337, theta=-11.693048 -> V=1.0, theta=0.0
% INFO    : Bus 91183	: V=1.0162038, theta=-4.893913 -> V=1.0, theta=0.0
% INFO    : Bus 91184	: V=1.0143385, theta=-4.964545 -> V=1.0, theta=0.0
% INFO    : Bus 91185	: V=1.006423, theta=-7.649507 -> V=1.0, theta=0.0
% INFO    : Bus 91186	: V=1.0106199, theta=-7.429499 -> V=1.0, theta=0.0
% INFO    : Bus 91187	: V=1.0097645, theta=-1.386993 -> V=1.0, theta=0.0
% INFO    : Bus 91188	: V=1.0092442, theta=-1.577277 -> V=1.0, theta=0.0
% INFO    : Bus 91189	: V=1.0071611, theta=-0.563979 -> V=1.0, theta=0.0
% INFO    : Bus 91190	: V=1.0114867, theta=0.109812 -> V=1.0, theta=0.0
% INFO    : Bus 91191	: V=1.0108745, theta=-7.191016 -> V=1.0, theta=0.0
% INFO    : Bus 91192	: V=1.0025689, theta=-7.96016 -> V=1.0, theta=0.0
% INFO    : Bus 91193	: V=1.0201112, theta=-9.870253 -> V=1.0, theta=0.0
% INFO    : Bus 91194	: V=1.02, theta=-9.55829 -> V=1.0, theta=0.0
% INFO    : Bus 91195	: V=1.0195116, theta=-9.595036 -> V=1.0, theta=0.0
% INFO    : Bus 91196	: V=1.0229201, theta=-11.705013 -> V=1.0, theta=0.0
% INFO    : Bus 91197	: V=1.0228577, theta=-11.928689 -> V=1.0, theta=0.0
% INFO    : Bus 91198	: V=1.0220622, theta=-12.019598 -> V=1.0, theta=0.0
% INFO    : Bus 91199	: V=1.0216444, theta=-12.047829 -> V=1.0, theta=0.0
% INFO    : Bus 91200	: V=0.9954038, theta=-19.044698 -> V=1.0, theta=0.0
% INFO    : Bus 91201	: V=1.0095907, theta=-8.839365 -> V=1.0, theta=0.0
% INFO    : Bus 91202	: V=1.0066015, theta=-9.236773 -> V=1.0, theta=0.0
% INFO    : Bus 91203	: V=1.0135984, theta=-22.446683 -> V=1.0, theta=0.0
% INFO    : Bus 91204	: V=1.016757, theta=-5.296527 -> V=1.0, theta=0.0
% INFO    : Bus 91205	: V=1.0157665, theta=-4.848611 -> V=1.0, theta=0.0
% INFO    : Bus 91206	: V=0.9887461, theta=-23.259697 -> V=1.0, theta=0.0
% INFO    : Bus 91207	: V=1.0130643, theta=-6.703663 -> V=1.0, theta=0.0
% INFO    : Bus 91208	: V=1.0120228, theta=-7.407556 -> V=1.0, theta=0.0
% INFO    : Bus 91209	: V=1.008039, theta=-7.824097 -> V=1.0, theta=0.0
% INFO    : Bus 91210	: V=1.017152, theta=8.033723 -> V=1.0, theta=0.0
% INFO    : Bus 91211	: V=1.0164525, theta=7.622424 -> V=1.0, theta=0.0
% INFO    : Bus 91212	: V=1.0161697, theta=0.673132 -> V=1.0, theta=0.0
% INFO    : Bus 91213	: V=1.0165781, theta=-1.053807 -> V=1.0, theta=0.0
% INFO    : Bus 91214	: V=1.010205, theta=-3.152009 -> V=1.0, theta=0.0
% INFO    : Bus 91215	: V=1.0025282, theta=-3.765956 -> V=1.0, theta=0.0
% INFO    : Bus 91216	: V=1.0001567, theta=-4.069333 -> V=1.0, theta=0.0
% INFO    : Bus 91217	: V=1.0140315, theta=-10.044532 -> V=1.0, theta=0.0
% INFO    : Bus 91218	: V=1.0119796, theta=-7.99527 -> V=1.0, theta=0.0
% INFO    : Bus 91219	: V=1.0163716, theta=7.117608 -> V=1.0, theta=0.0
% INFO    : Bus 91220	: V=1.0167392, theta=7.053189 -> V=1.0, theta=0.0
% INFO    : Bus 91221	: V=1.001097, theta=-4.142331 -> V=1.0, theta=0.0
% INFO    : Bus 91222	: V=1.0061859, theta=-8.070966 -> V=1.0, theta=0.0
% INFO    : Bus 91223	: V=1.010967, theta=5.138264 -> V=1.0, theta=0.0
% INFO    : Bus 91224	: V=1.0163223, theta=0.531435 -> V=1.0, theta=0.0
% INFO    : Bus 91225	: V=1.0082232, theta=0.608313 -> V=1.0, theta=0.0
% INFO    : Bus 91226	: V=0.9966463, theta=-15.293629 -> V=1.0, theta=0.0
% INFO    : Bus 91227	: V=1.02, theta=-1.587702 -> V=1.0, theta=0.0
% INFO    : Bus 91228	: V=1.0125389, theta=-6.694699 -> V=1.0, theta=0.0
% INFO    : Bus 91229	: V=1.0213607, theta=-23.475718 -> V=1.0, theta=0.0
% INFO    : Bus 91230	: V=1.02, theta=-23.375389 -> V=1.0, theta=0.0
% INFO    : Bus 91231	: V=1.0193245, theta=-23.419037 -> V=1.0, theta=0.0
% INFO    : Bus 91232	: V=0.9855935, theta=-4.980902 -> V=1.0, theta=0.0
% INFO    : Bus 91233	: V=1.0006678, theta=-0.470927 -> V=1.0, theta=0.0
% INFO    : Bus 91234	: V=1.0096427, theta=-22.30741 -> V=1.0, theta=0.0
% INFO    : Bus 91235	: V=1.02, theta=-11.945488 -> V=1.0, theta=0.0
% INFO    : Bus 91236	: V=1.0103684, theta=1.216677 -> V=1.0, theta=0.0
% INFO    : Bus 91237	: V=1.0065903, theta=-2.57478 -> V=1.0, theta=0.0
% INFO    : Bus 91238	: V=0.9944307, theta=-6.129453 -> V=1.0, theta=0.0
% INFO    : Bus 91239	: V=0.9888371, theta=-7.483767 -> V=1.0, theta=0.0
% INFO    : Bus 91240	: V=1.02, theta=-7.411978 -> V=1.0, theta=0.0
% INFO    : Bus 91241	: V=1.0078833, theta=-7.449047 -> V=1.0, theta=0.0
% INFO    : Bus 91242	: V=1.0096233, theta=0.79231 -> V=1.0, theta=0.0
% INFO    : Bus 91243	: V=1.0170106, theta=-22.277404 -> V=1.0, theta=0.0
% INFO    : Bus 91244	: V=1.0092233, theta=-22.621193 -> V=1.0, theta=0.0
% INFO    : Bus 91245	: V=1.0076501, theta=-22.716246 -> V=1.0, theta=0.0
% INFO    : Bus 91246	: V=1.02, theta=-20.03772 -> V=1.0, theta=0.0
% INFO    : Bus 91247	: V=1.0021234, theta=-12.301497 -> V=1.0, theta=0.0
% INFO    : Bus 91248	: V=1.0276155, theta=-25.541023 -> V=1.0, theta=0.0
% INFO    : Bus 91249	: V=1.0263303, theta=-25.786837 -> V=1.0, theta=0.0
% INFO    : Bus 91250	: V=1.0254395, theta=-26.096803 -> V=1.0, theta=0.0
% INFO    : Bus 91251	: V=1.0249988, theta=-26.124334 -> V=1.0, theta=0.0
% INFO    : Bus 91252	: V=0.986425, theta=-30.275931 -> V=1.0, theta=0.0
% INFO    : Bus 91253	: V=1.0088372, theta=-28.589664 -> V=1.0, theta=0.0
% INFO    : Bus 91254	: V=1.0028174, theta=-30.759008 -> V=1.0, theta=0.0
% INFO    : Bus 91255	: V=1.0038239, theta=-23.549312 -> V=1.0, theta=0.0
% INFO    : Bus 91256	: V=0.9996128, theta=-23.639069 -> V=1.0, theta=0.0
% INFO    : Bus 91257	: V=1.0017125, theta=-23.480184 -> V=1.0, theta=0.0
% INFO    : Bus 91258	: V=0.9976871, theta=-23.667798 -> V=1.0, theta=0.0
% INFO    : Bus 91259	: V=0.9666615, theta=-31.134273 -> V=1.0, theta=0.0
% INFO    : Bus 91260	: V=0.9587141, theta=-31.554702 -> V=1.0, theta=0.0
% INFO    : Bus 91261	: V=0.9681758, theta=-31.148015 -> V=1.0, theta=0.0
% INFO    : Bus 91262	: V=0.9643009, theta=-31.230308 -> V=1.0, theta=0.0
% INFO    : Bus 91263	: V=0.9601761, theta=-31.17671 -> V=1.0, theta=0.0
% INFO    : Bus 91264	: V=0.9644816, theta=-30.674172 -> V=1.0, theta=0.0
% INFO    : Bus 91265	: V=0.9773251, theta=-30.161216 -> V=1.0, theta=0.0
% INFO    : Bus 91266	: V=1.0125277, theta=-28.312071 -> V=1.0, theta=0.0
% INFO    : Bus 91267	: V=1.0085463, theta=-28.787242 -> V=1.0, theta=0.0
% INFO    : Bus 91268	: V=0.9733392, theta=-30.42712 -> V=1.0, theta=0.0
% INFO    : Bus 91269	: V=0.9791007, theta=-29.188046 -> V=1.0, theta=0.0
% INFO    : Bus 91270	: V=0.9762774, theta=-29.827527 -> V=1.0, theta=0.0
% INFO    : Bus 91271	: V=0.9875967, theta=-25.318403 -> V=1.0, theta=0.0
% INFO    : Bus 91272	: V=1.0068851, theta=-35.20152 -> V=1.0, theta=0.0
% INFO    : Bus 91273	: V=1.0074232, theta=-36.838966 -> V=1.0, theta=0.0
% INFO    : Bus 91274	: V=1.0217242, theta=-33.856195 -> V=1.0, theta=0.0
% INFO    : Bus 91275	: V=1.0206953, theta=-34.154386 -> V=1.0, theta=0.0
% INFO    : Bus 91276	: V=1.0197722, theta=-34.305849 -> V=1.0, theta=0.0
% INFO    : Bus 91277	: V=0.9830675, theta=-26.420745 -> V=1.0, theta=0.0
% INFO    : Bus 91278	: V=0.9691686, theta=-40.191959 -> V=1.0, theta=0.0
% INFO    : Bus 91279	: V=1.0083784, theta=-36.969768 -> V=1.0, theta=0.0
% INFO    : Bus 91280	: V=1.0049527, theta=-37.207035 -> V=1.0, theta=0.0
% INFO    : Bus 91281	: V=0.9964839, theta=-39.110452 -> V=1.0, theta=0.0
% INFO    : Bus 91282	: V=1.024655, theta=-14.75077 -> V=1.0, theta=0.0
% INFO    : Bus 91283	: V=1.0209306, theta=-13.747756 -> V=1.0, theta=0.0
% INFO    : Bus 91284	: V=1.0202239, theta=-13.865524 -> V=1.0, theta=0.0
% INFO    : Bus 91285	: V=1.0265095, theta=-12.830068 -> V=1.0, theta=0.0
% INFO    : Bus 91286	: V=1.0255136, theta=-13.043142 -> V=1.0, theta=0.0
% INFO    : Bus 91287	: V=0.977627, theta=-29.947542 -> V=1.0, theta=0.0
% INFO    : Bus 91288	: V=1.0189813, theta=-32.894941 -> V=1.0, theta=0.0
% INFO    : Bus 91289	: V=1.0171544, theta=-32.703766 -> V=1.0, theta=0.0
% INFO    : Bus 91290	: V=0.9866528, theta=-49.573024 -> V=1.0, theta=0.0
% INFO    : Bus 91291	: V=0.9732958, theta=-30.213796 -> V=1.0, theta=0.0
% INFO    : Bus 91292	: V=0.9954476, theta=-29.99784 -> V=1.0, theta=0.0
% INFO    : Bus 91293	: V=1.0039254, theta=-18.819123 -> V=1.0, theta=0.0
% INFO    : Bus 91294	: V=1.0199968, theta=-17.468614 -> V=1.0, theta=0.0
% INFO    : Bus 91295	: V=1.0169101, theta=-17.767819 -> V=1.0, theta=0.0
% INFO    : Bus 91296	: V=1.0079666, theta=-18.025223 -> V=1.0, theta=0.0
% INFO    : Bus 91297	: V=1.0216067, theta=-17.851872 -> V=1.0, theta=0.0
% INFO    : Bus 91298	: V=1.0221567, theta=-17.849942 -> V=1.0, theta=0.0
% INFO    : Bus 91299	: V=1.0063159, theta=-30.611305 -> V=1.0, theta=0.0
% INFO    : Bus 91300	: V=0.9915916, theta=-32.946665 -> V=1.0, theta=0.0
% INFO    : Bus 91301	: V=0.9791998, theta=-34.977994 -> V=1.0, theta=0.0
% INFO    : Bus 91302	: V=0.9903863, theta=-32.806936 -> V=1.0, theta=0.0
% INFO    : Bus 91303	: V=0.9864424, theta=-24.716037 -> V=1.0, theta=0.0
% INFO    : Bus 91304	: V=0.9811336, theta=-25.688131 -> V=1.0, theta=0.0
% INFO    : Bus 91305	: V=0.9902854, theta=-24.633414 -> V=1.0, theta=0.0
% INFO    : Bus 91306	: V=0.9879732, theta=-25.060756 -> V=1.0, theta=0.0
% INFO    : Bus 91307	: V=1.0061818, theta=-23.562219 -> V=1.0, theta=0.0
% INFO    : Bus 91308	: V=0.9912436, theta=-24.507324 -> V=1.0, theta=0.0
% INFO    : Bus 91309	: V=0.990937, theta=-24.77787 -> V=1.0, theta=0.0
% INFO    : Bus 91310	: V=0.9888076, theta=-24.530753 -> V=1.0, theta=0.0
% INFO    : Bus 91311	: V=1.0276139, theta=-19.821942 -> V=1.0, theta=0.0
% INFO    : Bus 91312	: V=1.0270938, theta=-19.805645 -> V=1.0, theta=0.0
% INFO    : Bus 91313	: V=1.0255917, theta=-19.947791 -> V=1.0, theta=0.0
% INFO    : Bus 91314	: V=1.0273596, theta=-19.969784 -> V=1.0, theta=0.0
% INFO    : Bus 91315	: V=1.0266259, theta=-20.108445 -> V=1.0, theta=0.0
% INFO    : Bus 91316	: V=1.0173504, theta=-33.116234 -> V=1.0, theta=0.0
% INFO    : Bus 91317	: V=1.0154407, theta=-33.619973 -> V=1.0, theta=0.0
% INFO    : Bus 91318	: V=0.9841808, theta=-33.419551 -> V=1.0, theta=0.0
% INFO    : Bus 91319	: V=0.9881703, theta=-33.918339 -> V=1.0, theta=0.0
% INFO    : Bus 91320	: V=0.9786849, theta=-36.622114 -> V=1.0, theta=0.0
% INFO    : Bus 91321	: V=0.9891915, theta=-36.621758 -> V=1.0, theta=0.0
% INFO    : Bus 91322	: V=0.9861414, theta=-36.741914 -> V=1.0, theta=0.0
% INFO    : Bus 91323	: V=0.9947309, theta=-36.171672 -> V=1.0, theta=0.0
% INFO    : Bus 91324	: V=0.9662881, theta=-32.210676 -> V=1.0, theta=0.0
% INFO    : Bus 91325	: V=0.9652223, theta=-32.27122 -> V=1.0, theta=0.0
% INFO    : Bus 91326	: V=0.9676134, theta=-32.048981 -> V=1.0, theta=0.0
% INFO    : Bus 91327	: V=0.9646645, theta=-32.202928 -> V=1.0, theta=0.0
% INFO    : Bus 91328	: V=0.9683244, theta=-32.229437 -> V=1.0, theta=0.0
% INFO    : Bus 91329	: V=0.9710609, theta=-32.233019 -> V=1.0, theta=0.0
% INFO    : Bus 91330	: V=1.0171519, theta=-27.526132 -> V=1.0, theta=0.0
% INFO    : Bus 91331	: V=1.0161674, theta=-27.510988 -> V=1.0, theta=0.0
% INFO    : Bus 91332	: V=1.0172031, theta=-32.060544 -> V=1.0, theta=0.0
% INFO    : Bus 91333	: V=1.0165891, theta=-32.722699 -> V=1.0, theta=0.0
% INFO    : Bus 91334	: V=1.017561, theta=-32.286563 -> V=1.0, theta=0.0
% INFO    : Bus 91335	: V=1.009209, theta=-34.365323 -> V=1.0, theta=0.0
% INFO    : Bus 91336	: V=1.0083065, theta=-34.500688 -> V=1.0, theta=0.0
% INFO    : Bus 91337	: V=1.0041452, theta=-36.931151 -> V=1.0, theta=0.0
% INFO    : Bus 91338	: V=1.0112077, theta=-34.112398 -> V=1.0, theta=0.0
% INFO    : Bus 91339	: V=1.0076327, theta=-34.51759 -> V=1.0, theta=0.0
% INFO    : Bus 91340	: V=1.016533, theta=-34.760245 -> V=1.0, theta=0.0
% INFO    : Bus 91341	: V=1.0105837, theta=-34.08588 -> V=1.0, theta=0.0
% INFO    : Bus 91342	: V=1.016775, theta=-31.36114 -> V=1.0, theta=0.0
% INFO    : Bus 91343	: V=1.01648, theta=-31.256619 -> V=1.0, theta=0.0
% INFO    : Bus 91344	: V=1.0018943, theta=-33.211817 -> V=1.0, theta=0.0
% INFO    : Bus 91345	: V=1.0059507, theta=-32.725678 -> V=1.0, theta=0.0
% INFO    : Bus 91346	: V=1.0276429, theta=-14.503682 -> V=1.0, theta=0.0
% INFO    : Bus 91347	: V=1.0279995, theta=-14.558646 -> V=1.0, theta=0.0
% INFO    : Bus 91348	: V=1.0221528, theta=-16.200607 -> V=1.0, theta=0.0
% INFO    : Bus 91349	: V=1.0199129, theta=-16.378918 -> V=1.0, theta=0.0
% INFO    : Bus 91350	: V=1.0170227, theta=-16.542786 -> V=1.0, theta=0.0
% INFO    : Bus 91351	: V=1.0239949, theta=-16.139099 -> V=1.0, theta=0.0
% INFO    : Bus 91352	: V=1.0235542, theta=-16.058853 -> V=1.0, theta=0.0
% INFO    : Bus 91353	: V=1.0242644, theta=-15.672304 -> V=1.0, theta=0.0
% INFO    : Bus 91354	: V=0.9957116, theta=-44.675831 -> V=1.0, theta=0.0
% INFO    : Bus 91355	: V=1.0169632, theta=-32.663661 -> V=1.0, theta=0.0
% INFO    : Bus 91356	: V=1.0142511, theta=-32.924981 -> V=1.0, theta=0.0
% INFO    : Bus 91357	: V=1.0176257, theta=-32.635164 -> V=1.0, theta=0.0
% INFO    : Bus 91358	: V=1.0142214, theta=-34.9953 -> V=1.0, theta=0.0
% INFO    : Bus 91359	: V=1.0046263, theta=-36.753755 -> V=1.0, theta=0.0
% INFO    : Bus 91360	: V=0.9949803, theta=-45.71657 -> V=1.0, theta=0.0
% INFO    : Bus 91361	: V=0.9964653, theta=-44.896075 -> V=1.0, theta=0.0
% INFO    : Bus 91362	: V=1.010817, theta=-21.475323 -> V=1.0, theta=0.0
% INFO    : Bus 91363	: V=1.0087808, theta=-21.985455 -> V=1.0, theta=0.0
% INFO    : Bus 91364	: V=1.0062755, theta=-22.191336 -> V=1.0, theta=0.0
% INFO    : Bus 91365	: V=1.0228309, theta=-18.261115 -> V=1.0, theta=0.0
% INFO    : Bus 91366	: V=1.021656, theta=-19.268072 -> V=1.0, theta=0.0
% INFO    : Bus 91367	: V=1.0200502, theta=-19.189485 -> V=1.0, theta=0.0
% INFO    : Bus 91368	: V=0.9998233, theta=-23.64539 -> V=1.0, theta=0.0
% INFO    : Bus 91369	: V=1.0090268, theta=-20.865196 -> V=1.0, theta=0.0
% INFO    : Bus 91370	: V=1.0091355, theta=-20.362419 -> V=1.0, theta=0.0
% INFO    : Bus 91371	: V=1.0133375, theta=-31.82836 -> V=1.0, theta=0.0
% INFO    : Bus 91372	: V=1.0153012, theta=-30.615221 -> V=1.0, theta=0.0
% INFO    : Bus 91373	: V=1.0142065, theta=-30.752099 -> V=1.0, theta=0.0
% INFO    : Bus 91374	: V=1.0120418, theta=-31.111656 -> V=1.0, theta=0.0
% INFO    : Bus 91375	: V=1.01044, theta=-31.168367 -> V=1.0, theta=0.0
% INFO    : Bus 91376	: V=1.0104124, theta=-31.162955 -> V=1.0, theta=0.0
% INFO    : Bus 91377	: V=1.010556, theta=-30.778145 -> V=1.0, theta=0.0
% INFO    : Bus 91378	: V=1.0096408, theta=-31.232544 -> V=1.0, theta=0.0
% INFO    : Bus 91379	: V=1.0152413, theta=-31.440838 -> V=1.0, theta=0.0
% INFO    : Bus 91380	: V=1.0103991, theta=-30.319052 -> V=1.0, theta=0.0
% INFO    : Bus 91381	: V=1.0204392, theta=-30.362505 -> V=1.0, theta=0.0
% INFO    : Bus 91382	: V=1.0195129, theta=-30.337183 -> V=1.0, theta=0.0
% INFO    : Bus 91383	: V=1.0123253, theta=-31.314938 -> V=1.0, theta=0.0
% INFO    : Bus 91384	: V=1.0112036, theta=-31.416685 -> V=1.0, theta=0.0
% INFO    : Bus 91385	: V=1.0205676, theta=-25.769504 -> V=1.0, theta=0.0
% INFO    : Bus 91386	: V=1.0199027, theta=-25.809425 -> V=1.0, theta=0.0
% INFO    : Bus 91387	: V=1.017698, theta=-25.516021 -> V=1.0, theta=0.0
% INFO    : Bus 91388	: V=1.0151912, theta=-25.904586 -> V=1.0, theta=0.0
% INFO    : Bus 91389	: V=1.0187042, theta=-25.33065 -> V=1.0, theta=0.0
% INFO    : Bus 91390	: V=1.0234617, theta=-23.807973 -> V=1.0, theta=0.0
% INFO    : Bus 91391	: V=1.0229275, theta=-24.003065 -> V=1.0, theta=0.0
% INFO    : Bus 91392	: V=1.0178717, theta=-16.980885 -> V=1.0, theta=0.0
% INFO    : Bus 91393	: V=1.0040143, theta=-20.273826 -> V=1.0, theta=0.0
% INFO    : Bus 91394	: V=1.0202193, theta=-22.525709 -> V=1.0, theta=0.0
% INFO    : Bus 91395	: V=1.0217559, theta=-22.573784 -> V=1.0, theta=0.0
% INFO    : Bus 91396	: V=1.0194842, theta=-22.673428 -> V=1.0, theta=0.0
% INFO    : Bus 91397	: V=0.9862939, theta=-32.000591 -> V=1.0, theta=0.0
% INFO    : Bus 91398	: V=0.9764958, theta=-31.92284 -> V=1.0, theta=0.0
% INFO    : Bus 91399	: V=0.982675, theta=-31.674999 -> V=1.0, theta=0.0
% INFO    : Bus 91400	: V=0.9803149, theta=-29.628277 -> V=1.0, theta=0.0
% INFO    : Bus 91401	: V=0.9863993, theta=-50.077189 -> V=1.0, theta=0.0
% INFO    : Bus 91402	: V=0.9843363, theta=-51.219143 -> V=1.0, theta=0.0
% INFO    : Bus 91403	: V=0.9836413, theta=-51.350485 -> V=1.0, theta=0.0
% INFO    : Bus 91404	: V=0.9820306, theta=-53.186505 -> V=1.0, theta=0.0
% INFO    : Bus 91405	: V=1.016352, theta=-16.742448 -> V=1.0, theta=0.0
% INFO    : Bus 91406	: V=1.0135302, theta=-16.967566 -> V=1.0, theta=0.0
% INFO    : Bus 91407	: V=1.0185561, theta=-16.698242 -> V=1.0, theta=0.0
% INFO    : Bus 91408	: V=1.0160719, theta=-16.890498 -> V=1.0, theta=0.0
% INFO    : Bus 91409	: V=1.014125, theta=-16.846934 -> V=1.0, theta=0.0
% INFO    : Bus 91410	: V=1.0104971, theta=-24.712001 -> V=1.0, theta=0.0
% INFO    : Bus 91411	: V=0.9915659, theta=-41.673058 -> V=1.0, theta=0.0
% INFO    : Bus 91412	: V=1.0294572, theta=-22.503411 -> V=1.0, theta=0.0
% INFO    : Bus 91413	: V=1.0273393, theta=-22.563681 -> V=1.0, theta=0.0
% INFO    : Bus 91414	: V=1.0277757, theta=-23.320622 -> V=1.0, theta=0.0
% INFO    : Bus 91415	: V=1.0269977, theta=-23.404195 -> V=1.0, theta=0.0
% INFO    : Bus 91416	: V=1.0077403, theta=-36.098409 -> V=1.0, theta=0.0
% INFO    : Bus 91417	: V=1.0184881, theta=-22.674574 -> V=1.0, theta=0.0
% INFO    : Bus 91418	: V=1.0168442, theta=-25.349579 -> V=1.0, theta=0.0
% INFO    : Bus 91419	: V=1.0184052, theta=-18.057745 -> V=1.0, theta=0.0
% INFO    : Bus 91420	: V=1.0172924, theta=-18.696458 -> V=1.0, theta=0.0
% INFO    : Bus 91421	: V=1.0166743, theta=-17.9149 -> V=1.0, theta=0.0
% INFO    : Bus 91422	: V=1.0269294, theta=-18.570832 -> V=1.0, theta=0.0
% INFO    : Bus 91423	: V=1.0258553, theta=-18.579723 -> V=1.0, theta=0.0
% INFO    : Bus 91424	: V=1.025455, theta=-18.659164 -> V=1.0, theta=0.0
% INFO    : Bus 91425	: V=1.010529, theta=-20.097036 -> V=1.0, theta=0.0
% INFO    : Bus 91426	: V=0.9796905, theta=-38.315014 -> V=1.0, theta=0.0
% INFO    : Bus 91427	: V=0.9814332, theta=-38.352513 -> V=1.0, theta=0.0
% INFO    : Bus 91428	: V=0.9961932, theta=-28.029879 -> V=1.0, theta=0.0
% INFO    : Bus 91429	: V=1.0069072, theta=-26.803018 -> V=1.0, theta=0.0
% INFO    : Bus 91430	: V=1.0183936, theta=-25.143947 -> V=1.0, theta=0.0
% INFO    : Bus 91431	: V=1.0190409, theta=-25.209752 -> V=1.0, theta=0.0
% INFO    : Bus 91432	: V=1.0174383, theta=-25.372469 -> V=1.0, theta=0.0
% INFO    : Bus 91433	: V=1.01222, theta=-26.891218 -> V=1.0, theta=0.0
% INFO    : Bus 91434	: V=1.0111515, theta=-26.632315 -> V=1.0, theta=0.0
% INFO    : Bus 91435	: V=0.9886175, theta=-29.263762 -> V=1.0, theta=0.0
% INFO    : Bus 91436	: V=0.9966968, theta=-31.919664 -> V=1.0, theta=0.0
% INFO    : Bus 91437	: V=0.9898654, theta=-32.545599 -> V=1.0, theta=0.0
% INFO    : Bus 91438	: V=0.990289, theta=-32.489966 -> V=1.0, theta=0.0
% INFO    : Bus 91439	: V=0.9888249, theta=-32.601905 -> V=1.0, theta=0.0
% INFO    : Bus 91440	: V=1.0164145, theta=-29.956148 -> V=1.0, theta=0.0
% INFO    : Bus 91441	: V=1.0118472, theta=-30.589244 -> V=1.0, theta=0.0
% INFO    : Bus 91442	: V=1.0015297, theta=-31.673857 -> V=1.0, theta=0.0
% INFO    : Bus 91443	: V=0.9958039, theta=-32.195255 -> V=1.0, theta=0.0
% INFO    : Bus 91444	: V=0.9900683, theta=-32.540335 -> V=1.0, theta=0.0
% INFO    : Bus 91445	: V=0.9874208, theta=-32.625252 -> V=1.0, theta=0.0
% INFO    : Bus 91446	: V=0.9854113, theta=-32.756031 -> V=1.0, theta=0.0
% INFO    : Bus 91447	: V=0.9846268, theta=-32.768513 -> V=1.0, theta=0.0
% INFO    : Bus 91448	: V=0.974122, theta=-32.152659 -> V=1.0, theta=0.0
% INFO    : Bus 91449	: V=0.9724613, theta=-32.954542 -> V=1.0, theta=0.0
% INFO    : Bus 91450	: V=0.9741492, theta=-33.246911 -> V=1.0, theta=0.0
% INFO    : Bus 91451	: V=0.9786763, theta=-32.731214 -> V=1.0, theta=0.0
% INFO    : Bus 91452	: V=0.9819806, theta=-31.987317 -> V=1.0, theta=0.0
% INFO    : Bus 91453	: V=0.9795635, theta=-32.772546 -> V=1.0, theta=0.0
% INFO    : Bus 91454	: V=0.9794321, theta=-32.731773 -> V=1.0, theta=0.0
% INFO    : Bus 91455	: V=0.9826837, theta=-32.642854 -> V=1.0, theta=0.0
% INFO    : Bus 91456	: V=0.9935603, theta=-31.345565 -> V=1.0, theta=0.0
% INFO    : Bus 91457	: V=1.000154, theta=-31.23457 -> V=1.0, theta=0.0
% INFO    : Bus 91458	: V=1.0174402, theta=-30.094902 -> V=1.0, theta=0.0
% INFO    : Bus 91459	: V=1.016119, theta=-30.440839 -> V=1.0, theta=0.0
% INFO    : Bus 91460	: V=1.0141845, theta=-30.713284 -> V=1.0, theta=0.0
% INFO    : Bus 91461	: V=1.0145677, theta=-30.499932 -> V=1.0, theta=0.0
% INFO    : Bus 91462	: V=1.0055726, theta=-31.45357 -> V=1.0, theta=0.0
% INFO    : Bus 91463	: V=0.9964483, theta=-32.106719 -> V=1.0, theta=0.0
% INFO    : Bus 91464	: V=0.9996445, theta=-32.189987 -> V=1.0, theta=0.0
% INFO    : Bus 91465	: V=1.0169038, theta=-30.032708 -> V=1.0, theta=0.0
% INFO    : Bus 91466	: V=1.0065273, theta=-31.450024 -> V=1.0, theta=0.0
% INFO    : Bus 91467	: V=0.98185, theta=-32.710785 -> V=1.0, theta=0.0
% INFO    : Bus 91468	: V=0.9888944, theta=-32.546693 -> V=1.0, theta=0.0
% INFO    : Bus 91469	: V=0.9966133, theta=-32.137585 -> V=1.0, theta=0.0
% INFO    : Bus 91470	: V=0.9789234, theta=-32.981574 -> V=1.0, theta=0.0
% INFO    : Bus 91471	: V=0.9799813, theta=-32.780635 -> V=1.0, theta=0.0
% INFO    : Bus 91472	: V=0.9834833, theta=-32.897466 -> V=1.0, theta=0.0
% INFO    : Bus 91473	: V=0.9930649, theta=-32.397383 -> V=1.0, theta=0.0
% INFO    : Bus 91474	: V=0.9929454, theta=-32.297121 -> V=1.0, theta=0.0
% INFO    : Bus 91475	: V=0.9875275, theta=-32.624742 -> V=1.0, theta=0.0
% INFO    : Bus 91476	: V=1.0289979, theta=-15.392169 -> V=1.0, theta=0.0
% INFO    : Bus 91477	: V=1.0273369, theta=-15.925604 -> V=1.0, theta=0.0
% INFO    : Bus 91478	: V=1.025994, theta=-16.156854 -> V=1.0, theta=0.0
% INFO    : Bus 91479	: V=1.0183728, theta=-21.318904 -> V=1.0, theta=0.0
% INFO    : Bus 91480	: V=1.0264576, theta=-21.018879 -> V=1.0, theta=0.0
% INFO    : Bus 91481	: V=1.0240279, theta=-20.894361 -> V=1.0, theta=0.0
% INFO    : Bus 91482	: V=0.9834248, theta=-33.328278 -> V=1.0, theta=0.0
% INFO    : Bus 91483	: V=0.9977705, theta=-32.303642 -> V=1.0, theta=0.0
% INFO    : Bus 91484	: V=1.0153181, theta=-31.688403 -> V=1.0, theta=0.0
% INFO    : Bus 91485	: V=1.0087424, theta=-32.167616 -> V=1.0, theta=0.0
% INFO    : Bus 91486	: V=1.0084004, theta=-32.204596 -> V=1.0, theta=0.0
% INFO    : Bus 91487	: V=1.0143528, theta=-30.887566 -> V=1.0, theta=0.0
% INFO    : Bus 91488	: V=1.0144066, theta=-31.010128 -> V=1.0, theta=0.0
% INFO    : Bus 91489	: V=0.9929987, theta=-32.398987 -> V=1.0, theta=0.0
% INFO    : Bus 91490	: V=0.9761109, theta=-35.430731 -> V=1.0, theta=0.0
% INFO    : Bus 91491	: V=1.0077825, theta=-24.376247 -> V=1.0, theta=0.0
% INFO    : Bus 91492	: V=1.0078874, theta=-24.154305 -> V=1.0, theta=0.0
% INFO    : Bus 91493	: V=0.974741, theta=-35.440224 -> V=1.0, theta=0.0
% INFO    : Bus 91494	: V=0.9762797, theta=-35.705568 -> V=1.0, theta=0.0
% INFO    : Bus 91495	: V=0.9737998, theta=-36.073236 -> V=1.0, theta=0.0
% INFO    : Bus 91496	: V=0.9740908, theta=-36.204767 -> V=1.0, theta=0.0
% INFO    : Bus 91497	: V=0.9736577, theta=-36.561171 -> V=1.0, theta=0.0
% INFO    : Bus 91498	: V=0.9768963, theta=-35.77938 -> V=1.0, theta=0.0
% INFO    : Bus 91499	: V=0.9716729, theta=-37.036589 -> V=1.0, theta=0.0
% INFO    : Bus 91500	: V=0.9750401, theta=-36.979647 -> V=1.0, theta=0.0
% INFO    : Bus 91501	: V=0.9895067, theta=-44.844004 -> V=1.0, theta=0.0
% INFO    : Bus 91502	: V=0.9953835, theta=-19.788214 -> V=1.0, theta=0.0
% INFO    : Bus 91503	: V=0.9965645, theta=-25.399657 -> V=1.0, theta=0.0
% INFO    : Bus 91504	: V=0.9873016, theta=-26.144103 -> V=1.0, theta=0.0
% INFO    : Bus 91505	: V=1.0125238, theta=-37.306055 -> V=1.0, theta=0.0
% INFO    : Bus 91506	: V=1.0134384, theta=-37.543028 -> V=1.0, theta=0.0
% INFO    : Bus 91507	: V=0.9943316, theta=-37.823301 -> V=1.0, theta=0.0
% INFO    : Bus 91508	: V=0.9835827, theta=-45.21654 -> V=1.0, theta=0.0
% INFO    : Bus 91509	: V=0.9668734, theta=-42.138418 -> V=1.0, theta=0.0
% INFO    : Bus 91510	: V=0.9941091, theta=-26.187816 -> V=1.0, theta=0.0
% INFO    : Bus 91511	: V=0.9718621, theta=-30.190138 -> V=1.0, theta=0.0
% INFO    : Bus 91512	: V=0.9810085, theta=-30.998034 -> V=1.0, theta=0.0
% INFO    : Bus 91513	: V=0.9817463, theta=-30.988528 -> V=1.0, theta=0.0
% INFO    : Bus 91514	: V=0.972748, theta=-31.374447 -> V=1.0, theta=0.0
% INFO    : Bus 91515	: V=0.9750195, theta=-31.237353 -> V=1.0, theta=0.0
% INFO    : Bus 91516	: V=1.0149901, theta=-28.512918 -> V=1.0, theta=0.0
% INFO    : Bus 91517	: V=0.9846176, theta=-30.641817 -> V=1.0, theta=0.0
% INFO    : Bus 91518	: V=0.9827871, theta=-30.89234 -> V=1.0, theta=0.0
% INFO    : Bus 91519	: V=1.0077093, theta=-29.343425 -> V=1.0, theta=0.0
% INFO    : Bus 91520	: V=1.0084095, theta=-30.055513 -> V=1.0, theta=0.0
% INFO    : Bus 91521	: V=1.0063837, theta=-30.504454 -> V=1.0, theta=0.0
% INFO    : Bus 91522	: V=0.9903002, theta=-30.582772 -> V=1.0, theta=0.0
% INFO    : Bus 91523	: V=0.9950711, theta=-26.665585 -> V=1.0, theta=0.0
% INFO    : Bus 91524	: V=0.9912335, theta=-26.497063 -> V=1.0, theta=0.0
% INFO    : Bus 91525	: V=0.9811811, theta=-30.4253 -> V=1.0, theta=0.0
% INFO    : Bus 91526	: V=0.9881849, theta=-27.04781 -> V=1.0, theta=0.0
% INFO    : Bus 91527	: V=0.9782939, theta=-31.090406 -> V=1.0, theta=0.0
% INFO    : Bus 91528	: V=1.0157672, theta=-27.551461 -> V=1.0, theta=0.0
% INFO    : Bus 91529	: V=1.0052514, theta=-29.327744 -> V=1.0, theta=0.0
% INFO    : Bus 91530	: V=1.0029266, theta=-65.512111 -> V=1.0, theta=0.0
% INFO    : Bus 91531	: V=0.9784831, theta=-68.521782 -> V=1.0, theta=0.0
% INFO    : Bus 91532	: V=0.973615, theta=-69.431276 -> V=1.0, theta=0.0
% INFO    : Bus 91533	: V=0.9796801, theta=-68.091324 -> V=1.0, theta=0.0
% INFO    : Bus 91534	: V=0.9784129, theta=-68.167095 -> V=1.0, theta=0.0
% INFO    : Bus 91535	: V=0.9697557, theta=-63.764539 -> V=1.0, theta=0.0
% INFO    : Bus 91536	: V=0.9911232, theta=-64.820637 -> V=1.0, theta=0.0
% INFO    : Bus 91537	: V=0.9706836, theta=-67.1921 -> V=1.0, theta=0.0
% INFO    : Bus 91538	: V=0.961022, theta=-68.383088 -> V=1.0, theta=0.0
% INFO    : Bus 91539	: V=0.9781284, theta=-67.947166 -> V=1.0, theta=0.0
% INFO    : Bus 91540	: V=0.9565963, theta=-70.174069 -> V=1.0, theta=0.0
% INFO    : Bus 91541	: V=0.9613308, theta=-69.637001 -> V=1.0, theta=0.0
% INFO    : Bus 91542	: V=0.9542367, theta=-71.694014 -> V=1.0, theta=0.0
% INFO    : Bus 91543	: V=0.9702074, theta=-61.859743 -> V=1.0, theta=0.0
% INFO    : Bus 91544	: V=0.9677042, theta=-62.610207 -> V=1.0, theta=0.0
% INFO    : Bus 91545	: V=0.9792251, theta=-62.230752 -> V=1.0, theta=0.0
% INFO    : Bus 91546	: V=1.0043569, theta=-62.981024 -> V=1.0, theta=0.0
% INFO    : Bus 91547	: V=0.983777, theta=-65.049128 -> V=1.0, theta=0.0
% INFO    : Bus 91548	: V=0.9755971, theta=-50.05812 -> V=1.0, theta=0.0
% INFO    : Bus 91549	: V=0.976896, theta=-50.140406 -> V=1.0, theta=0.0
% INFO    : Bus 91550	: V=0.9797933, theta=-57.377072 -> V=1.0, theta=0.0
% INFO    : Bus 91551	: V=0.9910356, theta=-53.604101 -> V=1.0, theta=0.0
% INFO    : Bus 91552	: V=0.975332, theta=-60.727037 -> V=1.0, theta=0.0
% INFO    : Bus 91553	: V=0.9680461, theta=-60.001948 -> V=1.0, theta=0.0
% INFO    : Bus 91554	: V=0.9787614, theta=-57.766491 -> V=1.0, theta=0.0
% INFO    : Bus 91555	: V=0.9781718, theta=-57.901686 -> V=1.0, theta=0.0
% INFO    : Bus 91556	: V=0.9548859, theta=-58.089701 -> V=1.0, theta=0.0
% INFO    : Bus 91557	: V=0.9640232, theta=-62.553995 -> V=1.0, theta=0.0
% INFO    : Bus 91558	: V=0.9762483, theta=-61.266881 -> V=1.0, theta=0.0
% INFO    : Bus 91559	: V=0.9800557, theta=-60.565695 -> V=1.0, theta=0.0
% INFO    : Bus 91560	: V=0.9871964, theta=-60.549429 -> V=1.0, theta=0.0
% INFO    : Bus 91561	: V=0.9872176, theta=-60.015357 -> V=1.0, theta=0.0
% INFO    : Bus 91562	: V=0.9844265, theta=-60.468301 -> V=1.0, theta=0.0
% INFO    : Bus 91563	: V=0.9770539, theta=-60.322745 -> V=1.0, theta=0.0
% INFO    : Bus 91564	: V=0.9667887, theta=-60.35486 -> V=1.0, theta=0.0
% INFO    : Bus 91565	: V=0.9747313, theta=-62.420057 -> V=1.0, theta=0.0
% INFO    : Bus 91566	: V=0.9754734, theta=-60.492802 -> V=1.0, theta=0.0
% INFO    : Bus 91567	: V=0.9763945, theta=-60.425447 -> V=1.0, theta=0.0
% INFO    : Bus 91568	: V=0.9765436, theta=-60.206309 -> V=1.0, theta=0.0
% INFO    : Bus 91569	: V=0.9738222, theta=-60.89795 -> V=1.0, theta=0.0
% INFO    : Bus 91570	: V=0.9738445, theta=-60.954965 -> V=1.0, theta=0.0
% INFO    : Bus 91571	: V=0.9719087, theta=-60.89733 -> V=1.0, theta=0.0
% INFO    : Bus 91572	: V=0.9681574, theta=-62.202342 -> V=1.0, theta=0.0
% INFO    : Bus 91573	: V=0.9612665, theta=-62.467142 -> V=1.0, theta=0.0
% INFO    : Bus 91574	: V=0.9768681, theta=-60.986722 -> V=1.0, theta=0.0
% INFO    : Bus 91575	: V=0.9968508, theta=-66.703503 -> V=1.0, theta=0.0
% INFO    : Bus 91576	: V=0.9932589, theta=-67.331111 -> V=1.0, theta=0.0
% INFO    : Bus 91577	: V=0.984377, theta=-67.868623 -> V=1.0, theta=0.0
% INFO    : Bus 91578	: V=1.0068069, theta=-66.007558 -> V=1.0, theta=0.0
% INFO    : Bus 91579	: V=1.0039854, theta=-66.385067 -> V=1.0, theta=0.0
% INFO    : Bus 91580	: V=0.9855196, theta=-67.847184 -> V=1.0, theta=0.0
% INFO    : Bus 91581	: V=0.9939049, theta=-66.938808 -> V=1.0, theta=0.0
% INFO    : Bus 91582	: V=0.9903907, theta=-67.019138 -> V=1.0, theta=0.0
% INFO    : Bus 91583	: V=0.9864649, theta=-67.790997 -> V=1.0, theta=0.0
% INFO    : Bus 91584	: V=0.9903681, theta=-67.180155 -> V=1.0, theta=0.0
% INFO    : Bus 91585	: V=1.0078382, theta=-64.428541 -> V=1.0, theta=0.0
% INFO    : Bus 91586	: V=1.0178228, theta=-65.035966 -> V=1.0, theta=0.0
% INFO    : Bus 91587	: V=1.0127099, theta=-65.604666 -> V=1.0, theta=0.0
% INFO    : Bus 91588	: V=1.0110699, theta=-65.775952 -> V=1.0, theta=0.0
% INFO    : Bus 91589	: V=1.0135202, theta=-65.116903 -> V=1.0, theta=0.0
% INFO    : Bus 91590	: V=1.0011116, theta=-66.47822 -> V=1.0, theta=0.0
% INFO    : Bus 91591	: V=0.9908539, theta=-67.489117 -> V=1.0, theta=0.0
% INFO    : Bus 91592	: V=0.9825525, theta=-68.291696 -> V=1.0, theta=0.0
% INFO    : Bus 91593	: V=1.0030415, theta=-66.445422 -> V=1.0, theta=0.0
% INFO    : Bus 91594	: V=1.0124857, theta=-65.659072 -> V=1.0, theta=0.0
% INFO    : Bus 91595	: V=0.9786443, theta=-69.364792 -> V=1.0, theta=0.0
% INFO    : Bus 91596	: V=1.0076804, theta=-66.203568 -> V=1.0, theta=0.0
% INFO    : Bus 91597	: V=0.9662029, theta=-50.810121 -> V=1.0, theta=0.0
% INFO    : Bus 91598	: V=0.9693744, theta=-56.419399 -> V=1.0, theta=0.0
% INFO    : Bus 91599	: V=0.9706192, theta=-50.710519 -> V=1.0, theta=0.0
% INFO    : Bus 91600	: V=0.9547719, theta=-55.909299 -> V=1.0, theta=0.0
% INFO    : Bus 91601	: V=0.9595932, theta=-57.399449 -> V=1.0, theta=0.0
% INFO    : Bus 91602	: V=1.0074778, theta=-57.344922 -> V=1.0, theta=0.0
% INFO    : Bus 91603	: V=1.006793, theta=-57.46593 -> V=1.0, theta=0.0
% INFO    : Bus 91604	: V=0.9991709, theta=-58.06189 -> V=1.0, theta=0.0
% INFO    : Bus 91605	: V=0.9919149, theta=-65.199145 -> V=1.0, theta=0.0
% INFO    : Bus 91606	: V=0.9840792, theta=-65.698727 -> V=1.0, theta=0.0
% INFO    : Bus 91607	: V=0.981111, theta=-65.753232 -> V=1.0, theta=0.0
% INFO    : Bus 91608	: V=0.9852777, theta=-65.6062 -> V=1.0, theta=0.0
% INFO    : Bus 91609	: V=0.9573101, theta=-67.596136 -> V=1.0, theta=0.0
% INFO    : Bus 91610	: V=0.9781085, theta=-65.894166 -> V=1.0, theta=0.0
% INFO    : Bus 91611	: V=0.9844381, theta=-65.633917 -> V=1.0, theta=0.0
% INFO    : Bus 91612	: V=0.9524589, theta=-67.769668 -> V=1.0, theta=0.0
% INFO    : Bus 91613	: V=0.962509, theta=-66.975384 -> V=1.0, theta=0.0
% INFO    : Bus 91614	: V=0.9647966, theta=-66.826806 -> V=1.0, theta=0.0
% INFO    : Bus 91615	: V=0.9598477, theta=-66.522065 -> V=1.0, theta=0.0
% INFO    : Bus 91616	: V=0.9564495, theta=-66.900557 -> V=1.0, theta=0.0
% INFO    : Bus 91617	: V=0.976382, theta=-65.353163 -> V=1.0, theta=0.0
% INFO    : Bus 91618	: V=0.981701, theta=-63.78551 -> V=1.0, theta=0.0
% INFO    : Bus 91619	: V=0.9900682, theta=-65.245748 -> V=1.0, theta=0.0
% INFO    : Bus 91620	: V=0.9746945, theta=-65.730436 -> V=1.0, theta=0.0
% INFO    : Bus 91621	: V=0.9777497, theta=-65.564 -> V=1.0, theta=0.0
% INFO    : Bus 91622	: V=0.9747685, theta=-65.818534 -> V=1.0, theta=0.0
% INFO    : Bus 91623	: V=0.9604343, theta=-66.696158 -> V=1.0, theta=0.0
% INFO    : Bus 91624	: V=0.9769835, theta=-65.24312 -> V=1.0, theta=0.0
% INFO    : Bus 91625	: V=0.9725218, theta=-66.183934 -> V=1.0, theta=0.0
% INFO    : Bus 91626	: V=0.9678512, theta=-66.319556 -> V=1.0, theta=0.0
% INFO    : Bus 91627	: V=0.9715819, theta=-65.993888 -> V=1.0, theta=0.0
% INFO    : Bus 91628	: V=0.9933202, theta=-64.079954 -> V=1.0, theta=0.0
% INFO    : Bus 91629	: V=0.9867585, theta=-64.72536 -> V=1.0, theta=0.0
% INFO    : Bus 91630	: V=0.9904128, theta=-64.494291 -> V=1.0, theta=0.0
% INFO    : Bus 91631	: V=0.9720331, theta=-66.173315 -> V=1.0, theta=0.0
% INFO    : Bus 91632	: V=0.9818981, theta=-65.328575 -> V=1.0, theta=0.0
% INFO    : Bus 91633	: V=0.9815336, theta=-63.848143 -> V=1.0, theta=0.0
% INFO    : Bus 91634	: V=0.9760989, theta=-65.265681 -> V=1.0, theta=0.0
% INFO    : Bus 91635	: V=0.9710886, theta=-66.220082 -> V=1.0, theta=0.0
% INFO    : Bus 91636	: V=0.9980259, theta=-61.84223 -> V=1.0, theta=0.0
% INFO    : Bus 91637	: V=1.0029961, theta=-61.599836 -> V=1.0, theta=0.0
% INFO    : Bus 91638	: V=0.9941654, theta=-62.735106 -> V=1.0, theta=0.0
% INFO    : Bus 91639	: V=0.9677686, theta=-66.168567 -> V=1.0, theta=0.0
% INFO    : Bus 91640	: V=0.97535, theta=-65.984857 -> V=1.0, theta=0.0
% INFO    : Bus 91641	: V=0.9601698, theta=-67.067394 -> V=1.0, theta=0.0
% INFO    : Bus 91642	: V=0.9612878, theta=-44.038562 -> V=1.0, theta=0.0
% INFO    : Bus 91643	: V=0.987713, theta=-61.903562 -> V=1.0, theta=0.0
% INFO    : Bus 91644	: V=1.0036429, theta=-61.001144 -> V=1.0, theta=0.0
% INFO    : Bus 91645	: V=0.987864, theta=-65.143153 -> V=1.0, theta=0.0
% INFO    : Bus 91646	: V=0.9990011, theta=-63.857101 -> V=1.0, theta=0.0
% INFO    : Bus 91647	: V=0.9959194, theta=-64.234964 -> V=1.0, theta=0.0
% INFO    : Bus 91648	: V=0.956663, theta=-50.133435 -> V=1.0, theta=0.0
% INFO    : Bus 91649	: V=0.9620709, theta=-51.598991 -> V=1.0, theta=0.0
% INFO    : Bus 91650	: V=0.9999572, theta=-55.700162 -> V=1.0, theta=0.0
% INFO    : Bus 91651	: V=0.9635964, theta=-71.754918 -> V=1.0, theta=0.0
% INFO    : Bus 91652	: V=0.9663368, theta=-71.75712 -> V=1.0, theta=0.0
% INFO    : Bus 91653	: V=0.9611525, theta=-71.89431 -> V=1.0, theta=0.0
% INFO    : Bus 91654	: V=0.9854668, theta=-68.720639 -> V=1.0, theta=0.0
% INFO    : Bus 91655	: V=0.9819166, theta=-69.121041 -> V=1.0, theta=0.0
% INFO    : Bus 91656	: V=1.0117109, theta=-61.257767 -> V=1.0, theta=0.0
% INFO    : Bus 91657	: V=1.0021001, theta=-62.981611 -> V=1.0, theta=0.0
% INFO    : Bus 91658	: V=1.0015117, theta=-63.108123 -> V=1.0, theta=0.0
% INFO    : Bus 91659	: V=1.0147382, theta=-62.12029 -> V=1.0, theta=0.0
% INFO    : Bus 91660	: V=1.0029417, theta=-63.533221 -> V=1.0, theta=0.0
% INFO    : Bus 91661	: V=1.0176191, theta=-61.660734 -> V=1.0, theta=0.0
% INFO    : Bus 91662	: V=1.0178188, theta=-61.60927 -> V=1.0, theta=0.0
% INFO    : Bus 91663	: V=0.9770318, theta=-50.877033 -> V=1.0, theta=0.0
% INFO    : Bus 91664	: V=0.9711766, theta=-65.861528 -> V=1.0, theta=0.0
% INFO    : Bus 91665	: V=0.9645797, theta=-66.334289 -> V=1.0, theta=0.0
% INFO    : Bus 91666	: V=0.9672804, theta=-66.12936 -> V=1.0, theta=0.0
% INFO    : Bus 91667	: V=0.9586792, theta=-66.731215 -> V=1.0, theta=0.0
% INFO    : Bus 91668	: V=0.9814813, theta=-64.607066 -> V=1.0, theta=0.0
% INFO    : Bus 91669	: V=0.9681298, theta=-66.058755 -> V=1.0, theta=0.0
% INFO    : Bus 91670	: V=0.9680417, theta=-66.078024 -> V=1.0, theta=0.0
% INFO    : Bus 91671	: V=0.9656737, theta=-66.277635 -> V=1.0, theta=0.0
% INFO    : Bus 91672	: V=0.9736331, theta=-65.799403 -> V=1.0, theta=0.0
% INFO    : Bus 91673	: V=0.9731961, theta=-65.785786 -> V=1.0, theta=0.0
% INFO    : Bus 91674	: V=0.9761377, theta=-65.741565 -> V=1.0, theta=0.0
% INFO    : Bus 91675	: V=0.977763, theta=-65.629812 -> V=1.0, theta=0.0
% INFO    : Bus 91676	: V=0.9773374, theta=-65.659747 -> V=1.0, theta=0.0
% INFO    : Bus 91677	: V=0.9669274, theta=-66.147028 -> V=1.0, theta=0.0
% INFO    : Bus 91678	: V=0.9673734, theta=-66.284267 -> V=1.0, theta=0.0
% INFO    : Bus 91679	: V=0.9707385, theta=-66.18661 -> V=1.0, theta=0.0
% INFO    : Bus 91680	: V=0.9853468, theta=-64.760951 -> V=1.0, theta=0.0
% INFO    : Bus 91681	: V=0.9788661, theta=-65.541185 -> V=1.0, theta=0.0
% INFO    : Bus 91682	: V=0.9755138, theta=-65.759699 -> V=1.0, theta=0.0
% INFO    : Bus 91683	: V=0.9787758, theta=-65.620827 -> V=1.0, theta=0.0
% INFO    : Bus 91684	: V=1.0064156, theta=-62.889149 -> V=1.0, theta=0.0
% INFO    : Bus 91685	: V=0.9911828, theta=-64.378919 -> V=1.0, theta=0.0
% INFO    : Bus 91686	: V=0.9879919, theta=-64.701754 -> V=1.0, theta=0.0
% INFO    : Bus 91687	: V=0.9926025, theta=-64.2016 -> V=1.0, theta=0.0
% INFO    : Bus 91688	: V=0.9918733, theta=-64.248541 -> V=1.0, theta=0.0
% INFO    : Bus 91689	: V=0.9891865, theta=-64.345843 -> V=1.0, theta=0.0
% INFO    : Bus 91690	: V=0.9899348, theta=-64.396986 -> V=1.0, theta=0.0
% INFO    : Bus 91691	: V=0.9758374, theta=-65.603402 -> V=1.0, theta=0.0
% INFO    : Bus 91692	: V=0.976982, theta=-65.557522 -> V=1.0, theta=0.0
% INFO    : Bus 91693	: V=0.9810893, theta=-65.045658 -> V=1.0, theta=0.0
% INFO    : Bus 91694	: V=0.9829707, theta=-64.987847 -> V=1.0, theta=0.0
% INFO    : Bus 91695	: V=0.9840834, theta=-64.991168 -> V=1.0, theta=0.0
% INFO    : Bus 91696	: V=0.9782983, theta=-65.235359 -> V=1.0, theta=0.0
% INFO    : Bus 91697	: V=0.9714257, theta=-65.979322 -> V=1.0, theta=0.0
% INFO    : Bus 91698	: V=0.9473033, theta=-68.802298 -> V=1.0, theta=0.0
% INFO    : Bus 91699	: V=1.0024949, theta=-63.349763 -> V=1.0, theta=0.0
% INFO    : Bus 91700	: V=1.0019004, theta=-63.418526 -> V=1.0, theta=0.0
% INFO    : Bus 91701	: V=0.9669237, theta=-66.124332 -> V=1.0, theta=0.0
% INFO    : Bus 91702	: V=1.0071176, theta=-65.725982 -> V=1.0, theta=0.0
% INFO    : Bus 91703	: V=0.9733446, theta=-68.803507 -> V=1.0, theta=0.0
% INFO    : Bus 91704	: V=0.9894157, theta=-67.023523 -> V=1.0, theta=0.0
% INFO    : Bus 91705	: V=0.9710782, theta=-69.692315 -> V=1.0, theta=0.0
% INFO    : Bus 91706	: V=0.9696753, theta=-69.691358 -> V=1.0, theta=0.0
% INFO    : Bus 91707	: V=0.9663739, theta=-70.480578 -> V=1.0, theta=0.0
% INFO    : Bus 91708	: V=0.9695513, theta=-70.011734 -> V=1.0, theta=0.0
% INFO    : Bus 91709	: V=0.977342, theta=-68.268534 -> V=1.0, theta=0.0
% INFO    : Bus 91710	: V=0.9763555, theta=-68.590387 -> V=1.0, theta=0.0
% INFO    : Bus 91711	: V=0.9686982, theta=-69.302059 -> V=1.0, theta=0.0
% INFO    : Bus 91712	: V=0.9718221, theta=-69.287149 -> V=1.0, theta=0.0
% INFO    : Bus 91713	: V=0.9662258, theta=-69.859852 -> V=1.0, theta=0.0
% INFO    : Bus 91714	: V=0.9630208, theta=-71.621811 -> V=1.0, theta=0.0
% INFO    : Bus 91715	: V=0.959169, theta=-71.892354 -> V=1.0, theta=0.0
% INFO    : Bus 91716	: V=0.9597907, theta=-71.864402 -> V=1.0, theta=0.0
% INFO    : Bus 91717	: V=0.9673544, theta=-71.748434 -> V=1.0, theta=0.0
% INFO    : Bus 91718	: V=0.9688817, theta=-69.754358 -> V=1.0, theta=0.0
% INFO    : Bus 91719	: V=0.9608992, theta=-71.22226 -> V=1.0, theta=0.0
% INFO    : Bus 91720	: V=0.9686793, theta=-69.16803 -> V=1.0, theta=0.0
% INFO    : Bus 91721	: V=0.962856, theta=-69.856987 -> V=1.0, theta=0.0
% INFO    : Bus 91722	: V=0.9647469, theta=-69.602406 -> V=1.0, theta=0.0
% INFO    : Bus 91723	: V=0.9713366, theta=-72.257688 -> V=1.0, theta=0.0
% INFO    : Bus 91724	: V=0.9578626, theta=-71.616627 -> V=1.0, theta=0.0
% INFO    : Bus 91725	: V=0.9451766, theta=-75.735474 -> V=1.0, theta=0.0
% INFO    : Bus 91726	: V=0.9659998, theta=-55.811446 -> V=1.0, theta=0.0
% INFO    : Bus 91727	: V=0.9665476, theta=-50.378056 -> V=1.0, theta=0.0
% INFO    : Bus 91728	: V=0.9769085, theta=-48.016031 -> V=1.0, theta=0.0
% INFO    : Bus 91729	: V=0.9846162, theta=-48.294907 -> V=1.0, theta=0.0
% INFO    : Bus 91730	: V=0.9801346, theta=-47.979004 -> V=1.0, theta=0.0
% INFO    : Bus 91731	: V=0.971372, theta=-49.503336 -> V=1.0, theta=0.0
% INFO    : Bus 91732	: V=0.9967571, theta=-62.88227 -> V=1.0, theta=0.0
% INFO    : Bus 91733	: V=0.9705004, theta=-65.713805 -> V=1.0, theta=0.0
% INFO    : Bus 91734	: V=0.9797265, theta=-64.497154 -> V=1.0, theta=0.0
% INFO    : Bus 91735	: V=0.9914738, theta=-63.876313 -> V=1.0, theta=0.0
% INFO    : Bus 91736	: V=0.9834946, theta=-64.744282 -> V=1.0, theta=0.0
% INFO    : Bus 91737	: V=0.9879839, theta=-64.21489 -> V=1.0, theta=0.0
% INFO    : Bus 91738	: V=0.983568, theta=-64.674061 -> V=1.0, theta=0.0
% INFO    : Bus 91739	: V=0.9973627, theta=-62.741954 -> V=1.0, theta=0.0
% INFO    : Bus 91740	: V=1.0004077, theta=-62.526156 -> V=1.0, theta=0.0
% INFO    : Bus 91741	: V=0.9591566, theta=-49.637056 -> V=1.0, theta=0.0
% INFO    : Bus 91742	: V=0.9779827, theta=-42.471168 -> V=1.0, theta=0.0
% INFO    : Bus 91743	: V=1.0004634, theta=-40.256003 -> V=1.0, theta=0.0
% INFO    : Bus 91744	: V=0.9921863, theta=-41.53708 -> V=1.0, theta=0.0
% INFO    : Bus 91745	: V=0.9890995, theta=-42.225108 -> V=1.0, theta=0.0
% INFO    : Bus 91746	: V=0.9878351, theta=-57.174518 -> V=1.0, theta=0.0
% INFO    : Bus 91747	: V=0.9894229, theta=-57.851113 -> V=1.0, theta=0.0
% INFO    : Bus 91748	: V=0.9837294, theta=-65.107906 -> V=1.0, theta=0.0
% INFO    : Bus 91749	: V=0.9924587, theta=-64.181853 -> V=1.0, theta=0.0
% INFO    : Bus 91750	: V=0.9913502, theta=-64.311721 -> V=1.0, theta=0.0
% INFO    : Bus 91751	: V=0.9858318, theta=-64.941581 -> V=1.0, theta=0.0
% INFO    : Bus 91752	: V=0.991612, theta=-64.397131 -> V=1.0, theta=0.0
% INFO    : Bus 91753	: V=0.9921447, theta=-64.405021 -> V=1.0, theta=0.0
% INFO    : Bus 91754	: V=0.9902322, theta=-64.386012 -> V=1.0, theta=0.0
% INFO    : Bus 91755	: V=1.0083353, theta=-62.771601 -> V=1.0, theta=0.0
% INFO    : Bus 91756	: V=0.9966896, theta=-63.829719 -> V=1.0, theta=0.0
% INFO    : Bus 91757	: V=0.9972119, theta=-63.794623 -> V=1.0, theta=0.0
% INFO    : Bus 91758	: V=1.0087991, theta=-62.755202 -> V=1.0, theta=0.0
% INFO    : Bus 91759	: V=1.008531, theta=-62.730033 -> V=1.0, theta=0.0
% INFO    : Bus 91760	: V=1.0061158, theta=-62.713014 -> V=1.0, theta=0.0
% INFO    : Bus 91761	: V=1.0087238, theta=-62.061272 -> V=1.0, theta=0.0
% INFO    : Bus 91762	: V=1.0117138, theta=-61.779742 -> V=1.0, theta=0.0
% INFO    : Bus 91763	: V=1.0151599, theta=-61.182353 -> V=1.0, theta=0.0
% INFO    : Bus 91764	: V=1.0130139, theta=-61.393347 -> V=1.0, theta=0.0
% INFO    : Bus 91765	: V=1.0062893, theta=-62.64355 -> V=1.0, theta=0.0
% INFO    : Bus 91766	: V=1.0054683, theta=-62.589368 -> V=1.0, theta=0.0
% INFO    : Bus 91767	: V=1.0063493, theta=-62.120075 -> V=1.0, theta=0.0
% INFO    : Bus 91768	: V=1.0165101, theta=-61.293339 -> V=1.0, theta=0.0
% INFO    : Bus 91769	: V=1.0133117, theta=-61.730924 -> V=1.0, theta=0.0
% INFO    : Bus 91770	: V=1.0152632, theta=-61.475309 -> V=1.0, theta=0.0
% INFO    : Bus 91771	: V=1.0097056, theta=-62.376616 -> V=1.0, theta=0.0
% INFO    : Bus 91772	: V=1.0072238, theta=-62.797025 -> V=1.0, theta=0.0
% INFO    : Bus 91773	: V=1.0065967, theta=-62.59215 -> V=1.0, theta=0.0
% INFO    : Bus 91774	: V=0.9891419, theta=-64.440564 -> V=1.0, theta=0.0
% INFO    : Bus 91775	: V=0.9883411, theta=-64.486175 -> V=1.0, theta=0.0
% INFO    : Bus 91776	: V=0.9887619, theta=-64.468712 -> V=1.0, theta=0.0
% INFO    : Bus 91777	: V=0.993045, theta=-64.155017 -> V=1.0, theta=0.0
% INFO    : Bus 91778	: V=1.0065717, theta=-62.912729 -> V=1.0, theta=0.0
% INFO    : Bus 91779	: V=1.0025676, theta=-63.419108 -> V=1.0, theta=0.0
% INFO    : Bus 91780	: V=0.9886605, theta=-64.486594 -> V=1.0, theta=0.0
% INFO    : Bus 91781	: V=0.9870993, theta=-64.706814 -> V=1.0, theta=0.0
% INFO    : Bus 91782	: V=0.9893833, theta=-64.547643 -> V=1.0, theta=0.0
% INFO    : Bus 91783	: V=0.9867527, theta=-64.702082 -> V=1.0, theta=0.0
% INFO    : Bus 91784	: V=0.9789786, theta=-65.555442 -> V=1.0, theta=0.0
% INFO    : Bus 91785	: V=0.986707, theta=-64.761178 -> V=1.0, theta=0.0
% INFO    : Bus 91786	: V=0.9933706, theta=-64.040959 -> V=1.0, theta=0.0
% INFO    : Bus 91787	: V=0.9821033, theta=-65.094325 -> V=1.0, theta=0.0
% INFO    : Bus 91788	: V=0.9851402, theta=-65.002417 -> V=1.0, theta=0.0
% INFO    : Bus 91789	: V=0.9957516, theta=-63.906012 -> V=1.0, theta=0.0
% INFO    : Bus 91790	: V=0.9850821, theta=-64.995335 -> V=1.0, theta=0.0
% INFO    : Bus 91791	: V=0.9781852, theta=-65.426198 -> V=1.0, theta=0.0
% INFO    : Bus 91792	: V=0.9898647, theta=-64.470233 -> V=1.0, theta=0.0
% INFO    : Bus 91793	: V=0.9900293, theta=-64.467129 -> V=1.0, theta=0.0
% INFO    : Bus 91794	: V=0.9878128, theta=-64.638615 -> V=1.0, theta=0.0
% INFO    : Bus 91795	: V=0.9830379, theta=-65.126994 -> V=1.0, theta=0.0
% INFO    : Bus 91796	: V=0.9876083, theta=-64.668063 -> V=1.0, theta=0.0
% INFO    : Bus 91797	: V=0.9849735, theta=-64.877037 -> V=1.0, theta=0.0
% INFO    : Bus 91798	: V=0.9929027, theta=-64.154604 -> V=1.0, theta=0.0
% INFO    : Bus 91799	: V=0.9888619, theta=-64.600728 -> V=1.0, theta=0.0
% INFO    : Bus 91800	: V=1.0064524, theta=-62.935498 -> V=1.0, theta=0.0
% INFO    : Bus 91801	: V=0.9971279, theta=-63.881059 -> V=1.0, theta=0.0
% INFO    : Bus 91802	: V=0.9935351, theta=-64.232633 -> V=1.0, theta=0.0
% INFO    : Bus 91803	: V=0.9869588, theta=-64.863656 -> V=1.0, theta=0.0
% INFO    : Bus 91804	: V=0.997188, theta=-63.874228 -> V=1.0, theta=0.0
% INFO    : Bus 91805	: V=0.9974652, theta=-64.040458 -> V=1.0, theta=0.0
% INFO    : Bus 91806	: V=0.9862467, theta=-64.873846 -> V=1.0, theta=0.0
% INFO    : Bus 91807	: V=0.9916378, theta=-64.253997 -> V=1.0, theta=0.0
% INFO    : Bus 91808	: V=0.9944795, theta=-63.987308 -> V=1.0, theta=0.0
% INFO    : Bus 91809	: V=0.9897997, theta=-64.474317 -> V=1.0, theta=0.0
% INFO    : Bus 91810	: V=0.989112, theta=-64.499407 -> V=1.0, theta=0.0
% INFO    : Bus 91811	: V=0.9783786, theta=-65.440558 -> V=1.0, theta=0.0
% INFO    : Bus 91812	: V=0.9868686, theta=-64.702479 -> V=1.0, theta=0.0
% INFO    : Bus 91813	: V=0.990807, theta=-64.345935 -> V=1.0, theta=0.0
% INFO    : Bus 91814	: V=0.9953312, theta=-43.863807 -> V=1.0, theta=0.0
% INFO    : Bus 91815	: V=0.9914392, theta=-43.751185 -> V=1.0, theta=0.0
% INFO    : Bus 91816	: V=0.9876963, theta=-43.571759 -> V=1.0, theta=0.0
% INFO    : Bus 91817	: V=0.9891995, theta=-43.791788 -> V=1.0, theta=0.0
% INFO    : Bus 91818	: V=0.9986164, theta=-42.966493 -> V=1.0, theta=0.0
% INFO    : Bus 91819	: V=0.9998132, theta=-43.331582 -> V=1.0, theta=0.0
% INFO    : Bus 91820	: V=0.9963999, theta=-43.987249 -> V=1.0, theta=0.0
% INFO    : Bus 91821	: V=0.9929756, theta=-42.736443 -> V=1.0, theta=0.0
% INFO    : Bus 91822	: V=0.9607861, theta=-45.63817 -> V=1.0, theta=0.0
% INFO    : Bus 91823	: V=0.994185, theta=-43.307471 -> V=1.0, theta=0.0
% INFO    : Bus 91824	: V=1.0173001, theta=-38.734478 -> V=1.0, theta=0.0
% INFO    : Bus 91825	: V=1.0161924, theta=-39.49657 -> V=1.0, theta=0.0
% INFO    : Bus 91826	: V=1.0070046, theta=-41.122653 -> V=1.0, theta=0.0
% INFO    : Bus 91827	: V=1.0066696, theta=-41.327511 -> V=1.0, theta=0.0
% INFO    : Bus 91828	: V=0.9660079, theta=-46.417266 -> V=1.0, theta=0.0
% INFO    : Bus 91829	: V=0.975017, theta=-47.332915 -> V=1.0, theta=0.0
% INFO    : Bus 91830	: V=0.9900638, theta=-44.091173 -> V=1.0, theta=0.0
% INFO    : Bus 91831	: V=0.9964742, theta=-44.149527 -> V=1.0, theta=0.0
% INFO    : Bus 91832	: V=0.992635, theta=-44.369895 -> V=1.0, theta=0.0
% INFO    : Bus 91833	: V=0.9846758, theta=-67.32643 -> V=1.0, theta=0.0
% INFO    : Bus 91834	: V=0.9949189, theta=-61.773833 -> V=1.0, theta=0.0
% INFO    : Bus 91835	: V=0.9638314, theta=-59.544409 -> V=1.0, theta=0.0
% INFO    : Bus 91836	: V=1.0021557, theta=-55.693123 -> V=1.0, theta=0.0
% INFO    : Bus 91837	: V=0.9985095, theta=-56.257829 -> V=1.0, theta=0.0
% INFO    : Bus 91838	: V=0.9961826, theta=-57.279168 -> V=1.0, theta=0.0
% INFO    : Bus 91839	: V=0.9869106, theta=-57.896863 -> V=1.0, theta=0.0
% INFO    : Bus 91840	: V=0.9872732, theta=-57.190992 -> V=1.0, theta=0.0
% INFO    : Bus 91841	: V=0.9855593, theta=-57.751704 -> V=1.0, theta=0.0
% INFO    : Bus 91842	: V=0.9923921, theta=-57.815713 -> V=1.0, theta=0.0
% INFO    : Bus 91843	: V=0.9897746, theta=-58.036807 -> V=1.0, theta=0.0
% INFO    : Bus 91844	: V=0.9828463, theta=-58.468066 -> V=1.0, theta=0.0
% INFO    : Bus 91845	: V=0.968267, theta=-60.006016 -> V=1.0, theta=0.0
% INFO    : Bus 91846	: V=0.9651528, theta=-60.606365 -> V=1.0, theta=0.0
% INFO    : Bus 91847	: V=0.9694726, theta=-59.705001 -> V=1.0, theta=0.0
% INFO    : Bus 91848	: V=0.9697591, theta=-60.989157 -> V=1.0, theta=0.0
% INFO    : Bus 91849	: V=0.9685911, theta=-61.968214 -> V=1.0, theta=0.0
% INFO    : Bus 91850	: V=0.9894884, theta=-58.304536 -> V=1.0, theta=0.0
% INFO    : Bus 91851	: V=0.9846984, theta=-57.955205 -> V=1.0, theta=0.0
% INFO    : Bus 91852	: V=0.984773, theta=-59.035396 -> V=1.0, theta=0.0
% INFO    : Bus 91853	: V=0.9613981, theta=-48.455297 -> V=1.0, theta=0.0
% INFO    : Bus 91854	: V=0.9859957, theta=-60.228307 -> V=1.0, theta=0.0
% INFO    : Bus 91855	: V=0.9856517, theta=-60.199436 -> V=1.0, theta=0.0
% INFO    : Bus 91856	: V=0.9790514, theta=-60.412669 -> V=1.0, theta=0.0
% INFO    : Bus 91857	: V=0.98886, theta=-64.880366 -> V=1.0, theta=0.0
% INFO    : Bus 91858	: V=0.9725307, theta=-65.808226 -> V=1.0, theta=0.0
% INFO    : Bus 91859	: V=0.9935246, theta=-64.379335 -> V=1.0, theta=0.0
% INFO    : Bus 91860	: V=1.0035295, theta=-63.02819 -> V=1.0, theta=0.0
% INFO    : Bus 91861	: V=0.9927333, theta=-64.219104 -> V=1.0, theta=0.0
% INFO    : Bus 91862	: V=0.9950855, theta=-64.314318 -> V=1.0, theta=0.0
% INFO    : Bus 91863	: V=0.9899358, theta=-64.804315 -> V=1.0, theta=0.0
% INFO    : Bus 91864	: V=0.9852959, theta=-65.138146 -> V=1.0, theta=0.0
% INFO    : Bus 91865	: V=1.0164856, theta=-61.062802 -> V=1.0, theta=0.0
% INFO    : Bus 91866	: V=0.9744205, theta=-68.162825 -> V=1.0, theta=0.0
% INFO    : Bus 91867	: V=0.9809561, theta=-68.766261 -> V=1.0, theta=0.0
% INFO    : Bus 91868	: V=1.0086784, theta=-61.906192 -> V=1.0, theta=0.0
% INFO    : Bus 91869	: V=0.9750209, theta=-65.011382 -> V=1.0, theta=0.0
% INFO    : Bus 91870	: V=0.9716009, theta=-67.616662 -> V=1.0, theta=0.0
% INFO    : Bus 91871	: V=1.0002511, theta=-65.290314 -> V=1.0, theta=0.0
% INFO    : Bus 91872	: V=0.9643219, theta=-69.206197 -> V=1.0, theta=0.0
% INFO    : Bus 91873	: V=0.9655487, theta=-69.268434 -> V=1.0, theta=0.0
% INFO    : Bus 91874	: V=0.968186, theta=-68.916177 -> V=1.0, theta=0.0
% INFO    : Bus 91875	: V=0.9693108, theta=-68.815084 -> V=1.0, theta=0.0
% INFO    : Bus 91876	: V=0.9702608, theta=-68.87747 -> V=1.0, theta=0.0
% INFO    : Bus 91877	: V=0.968711, theta=-68.892659 -> V=1.0, theta=0.0
% INFO    : Bus 91878	: V=0.9668023, theta=-69.610045 -> V=1.0, theta=0.0
% INFO    : Bus 91879	: V=0.9580322, theta=-72.3471 -> V=1.0, theta=0.0
% INFO    : Bus 91880	: V=0.9725781, theta=-72.292963 -> V=1.0, theta=0.0
% INFO    : Bus 91881	: V=1.0127552, theta=-69.269496 -> V=1.0, theta=0.0
% INFO    : Bus 91882	: V=1.0029108, theta=-70.149978 -> V=1.0, theta=0.0
% INFO    : Bus 91883	: V=0.9786936, theta=-64.726261 -> V=1.0, theta=0.0
% INFO    : Bus 91884	: V=0.997928, theta=-62.159049 -> V=1.0, theta=0.0
% INFO    : Bus 91885	: V=0.993822, theta=-62.673576 -> V=1.0, theta=0.0
% INFO    : Bus 91886	: V=0.9862752, theta=-63.496328 -> V=1.0, theta=0.0
% INFO    : Bus 91887	: V=0.9969219, theta=-62.459206 -> V=1.0, theta=0.0
% INFO    : Bus 91888	: V=0.9936388, theta=-62.891896 -> V=1.0, theta=0.0
% INFO    : Bus 91889	: V=0.9904089, theta=-63.26233 -> V=1.0, theta=0.0
% INFO    : Bus 91890	: V=0.9751236, theta=-64.440322 -> V=1.0, theta=0.0
% INFO    : Bus 91891	: V=0.9888191, theta=-63.185697 -> V=1.0, theta=0.0
% INFO    : Bus 91892	: V=0.9808199, theta=-64.096374 -> V=1.0, theta=0.0
% INFO    : Bus 91893	: V=0.962163, theta=-65.84265 -> V=1.0, theta=0.0
% INFO    : Bus 91894	: V=0.9591108, theta=-65.472063 -> V=1.0, theta=0.0
% INFO    : Bus 91895	: V=0.9650934, theta=-65.173824 -> V=1.0, theta=0.0
% INFO    : Bus 91896	: V=0.9697014, theta=-64.781818 -> V=1.0, theta=0.0
% INFO    : Bus 91897	: V=0.9658534, theta=-65.163717 -> V=1.0, theta=0.0
% INFO    : Bus 91898	: V=1.005991, theta=-60.957082 -> V=1.0, theta=0.0
% INFO    : Bus 91899	: V=0.9925442, theta=-62.499508 -> V=1.0, theta=0.0
% INFO    : Bus 91900	: V=0.9874462, theta=-63.07283 -> V=1.0, theta=0.0
% INFO    : Bus 91901	: V=0.992116, theta=-62.846429 -> V=1.0, theta=0.0
% INFO    : Bus 91902	: V=0.9611539, theta=-65.329074 -> V=1.0, theta=0.0
% INFO    : Bus 91903	: V=0.9752221, theta=-63.945377 -> V=1.0, theta=0.0
% INFO    : Bus 91904	: V=1.0118212, theta=-60.775579 -> V=1.0, theta=0.0
% INFO    : Bus 91905	: V=0.9963156, theta=-62.89071 -> V=1.0, theta=0.0
% INFO    : Bus 91906	: V=0.9880236, theta=-63.587613 -> V=1.0, theta=0.0
% INFO    : Bus 91907	: V=0.9903052, theta=-63.522018 -> V=1.0, theta=0.0
% INFO    : Bus 91908	: V=0.9908204, theta=-63.47948 -> V=1.0, theta=0.0
% INFO    : Bus 91909	: V=0.9722711, theta=-65.434803 -> V=1.0, theta=0.0
% INFO    : Bus 91910	: V=0.9733069, theta=-65.436248 -> V=1.0, theta=0.0
% INFO    : Bus 91911	: V=0.9931697, theta=-63.138973 -> V=1.0, theta=0.0
% INFO    : Bus 91912	: V=0.9859017, theta=-63.854432 -> V=1.0, theta=0.0
% INFO    : Bus 91913	: V=1.0015315, theta=-62.335002 -> V=1.0, theta=0.0
% INFO    : Bus 91914	: V=0.9999615, theta=-62.540833 -> V=1.0, theta=0.0
% INFO    : Bus 91915	: V=0.9480286, theta=-76.531766 -> V=1.0, theta=0.0
% INFO    : Bus 91916	: V=1.0172882, theta=-38.294437 -> V=1.0, theta=0.0
% INFO    : Bus 91917	: V=1.0105039, theta=-39.298562 -> V=1.0, theta=0.0
% INFO    : Bus 91918	: V=0.9924269, theta=-42.072838 -> V=1.0, theta=0.0
% INFO    : Bus 91919	: V=0.9975221, theta=-43.075258 -> V=1.0, theta=0.0
% INFO    : Bus 91920	: V=0.9645303, theta=-70.13004 -> V=1.0, theta=0.0
% INFO    : Bus 91921	: V=0.9660326, theta=-70.004511 -> V=1.0, theta=0.0
% INFO    : Bus 91922	: V=0.9610879, theta=-72.344258 -> V=1.0, theta=0.0
% INFO    : Bus 91923	: V=0.9572532, theta=-71.745466 -> V=1.0, theta=0.0
% INFO    : Bus 91924	: V=0.9578076, theta=-72.801276 -> V=1.0, theta=0.0
% INFO    : Bus 91925	: V=0.980923, theta=-62.137352 -> V=1.0, theta=0.0
% INFO    : Bus 91926	: V=0.9715681, theta=-63.021355 -> V=1.0, theta=0.0
% INFO    : Bus 91927	: V=0.9732695, theta=-60.845245 -> V=1.0, theta=0.0
% INFO    : Bus 91928	: V=0.9744613, theta=-62.830421 -> V=1.0, theta=0.0
% INFO    : Bus 91929	: V=1.0033844, theta=-63.022583 -> V=1.0, theta=0.0
% INFO    : Bus 91930	: V=1.0061056, theta=-62.473625 -> V=1.0, theta=0.0
% INFO    : Bus 91931	: V=1.0067747, theta=-62.369149 -> V=1.0, theta=0.0
% INFO    : Bus 91932	: V=1.0063281, theta=-62.419183 -> V=1.0, theta=0.0
% INFO    : Bus 91933	: V=0.981055, theta=-64.516733 -> V=1.0, theta=0.0
% INFO    : Bus 91934	: V=1.0085882, theta=-62.027633 -> V=1.0, theta=0.0
% INFO    : Bus 91935	: V=1.0033677, theta=-62.885827 -> V=1.0, theta=0.0
% INFO    : Bus 91936	: V=1.0013451, theta=-63.098972 -> V=1.0, theta=0.0
% INFO    : Bus 91937	: V=0.9711823, theta=-51.645038 -> V=1.0, theta=0.0
% INFO    : Bus 91938	: V=0.9633976, theta=-52.23063 -> V=1.0, theta=0.0
% INFO    : Bus 91939	: V=0.9658423, theta=-53.561664 -> V=1.0, theta=0.0
% INFO    : Bus 91940	: V=0.9635502, theta=-56.271394 -> V=1.0, theta=0.0
% INFO    : Bus 91941	: V=0.9864904, theta=-64.913754 -> V=1.0, theta=0.0
% INFO    : Bus 91942	: V=0.965219, theta=-43.47521 -> V=1.0, theta=0.0
% INFO    : Bus 91943	: V=1.0144674, theta=-59.615704 -> V=1.0, theta=0.0
% INFO    : Bus 91944	: V=1.0115427, theta=-60.126785 -> V=1.0, theta=0.0
% INFO    : Bus 91945	: V=1.013544, theta=-59.566391 -> V=1.0, theta=0.0
% INFO    : Bus 91946	: V=0.9672843, theta=-52.397458 -> V=1.0, theta=0.0
% INFO    : Bus 91947	: V=0.9764471, theta=-56.079242 -> V=1.0, theta=0.0
% INFO    : Bus 91948	: V=0.9772697, theta=-54.844575 -> V=1.0, theta=0.0
% INFO    : Bus 91949	: V=0.996534, theta=5.02431 -> V=1.0, theta=0.0
% INFO    : Bus 91950	: V=0.99798, theta=-0.475721 -> V=1.0, theta=0.0
% INFO    : Bus 91951	: V=1.0069239, theta=-0.79442 -> V=1.0, theta=0.0
% INFO    : Bus 91952	: V=1.0053913, theta=4.403639 -> V=1.0, theta=0.0
% INFO    : Bus 91953	: V=1.0043471, theta=2.410958 -> V=1.0, theta=0.0
% INFO    : Bus 91954	: V=0.9796987, theta=-24.994981 -> V=1.0, theta=0.0
% INFO    : Bus 91955	: V=0.9756783, theta=-26.94717 -> V=1.0, theta=0.0
% INFO    : Bus 91956	: V=0.9895292, theta=-16.754815 -> V=1.0, theta=0.0
% INFO    : Bus 91957	: V=0.9716711, theta=-20.538301 -> V=1.0, theta=0.0
% INFO    : Bus 91958	: V=0.9933801, theta=-9.959148 -> V=1.0, theta=0.0
% INFO    : Bus 91959	: V=0.9841077, theta=-8.402609 -> V=1.0, theta=0.0
% INFO    : Bus 91960	: V=0.981783, theta=-9.502041 -> V=1.0, theta=0.0
% INFO    : Bus 91961	: V=0.9786917, theta=-10.438067 -> V=1.0, theta=0.0
% INFO    : Bus 91962	: V=1.0166715, theta=-8.159639 -> V=1.0, theta=0.0
% INFO    : Bus 91963	: V=1.0148491, theta=-7.977873 -> V=1.0, theta=0.0
% INFO    : Bus 91964	: V=1.0078494, theta=0.746124 -> V=1.0, theta=0.0
% INFO    : Bus 91965	: V=1.0022704, theta=0.416278 -> V=1.0, theta=0.0
% INFO    : Bus 91966	: V=0.9914586, theta=-1.561001 -> V=1.0, theta=0.0
% INFO    : Bus 91967	: V=0.9990346, theta=0.65769 -> V=1.0, theta=0.0
% INFO    : Bus 91968	: V=1.0053826, theta=1.266518 -> V=1.0, theta=0.0
% INFO    : Bus 91969	: V=0.9995997, theta=0.857614 -> V=1.0, theta=0.0
% INFO    : Bus 91970	: V=1.0028217, theta=0.842255 -> V=1.0, theta=0.0
% INFO    : Bus 91971	: V=1.0048762, theta=0.966134 -> V=1.0, theta=0.0
% INFO    : Bus 91972	: V=1.005298, theta=0.895846 -> V=1.0, theta=0.0
% INFO    : Bus 91973	: V=1.0015493, theta=2.350048 -> V=1.0, theta=0.0
% INFO    : Bus 91974	: V=0.978938, theta=-6.628636 -> V=1.0, theta=0.0
% INFO    : Bus 91975	: V=0.9888635, theta=-6.632037 -> V=1.0, theta=0.0
% INFO    : Bus 91976	: V=0.9908151, theta=-6.578227 -> V=1.0, theta=0.0
% INFO    : Bus 91977	: V=0.99539, theta=-6.23175 -> V=1.0, theta=0.0
% INFO    : Bus 91978	: V=0.9825744, theta=-6.724946 -> V=1.0, theta=0.0
% INFO    : Bus 91979	: V=1.0290017, theta=-12.184209 -> V=1.0, theta=0.0
% INFO    : Bus 91980	: V=1.0274499, theta=-12.321497 -> V=1.0, theta=0.0
% INFO    : Bus 91981	: V=1.026673, theta=-12.408005 -> V=1.0, theta=0.0
% INFO    : Bus 91982	: V=1.0167868, theta=-12.937973 -> V=1.0, theta=0.0
% INFO    : Bus 91983	: V=1.0042426, theta=-13.729122 -> V=1.0, theta=0.0
% INFO    : Bus 91984	: V=1.0191975, theta=-13.184936 -> V=1.0, theta=0.0
% INFO    : Bus 91985	: V=1.0219588, theta=-12.912821 -> V=1.0, theta=0.0
% INFO    : Bus 91986	: V=1.015968, theta=-13.317913 -> V=1.0, theta=0.0
% INFO    : Bus 91987	: V=1.0146213, theta=-13.465681 -> V=1.0, theta=0.0
% INFO    : Bus 91988	: V=0.9970656, theta=0.490976 -> V=1.0, theta=0.0
% INFO    : Bus 91989	: V=0.9966278, theta=0.134311 -> V=1.0, theta=0.0
% INFO    : Bus 91990	: V=0.9946328, theta=-13.52553 -> V=1.0, theta=0.0
% INFO    : Bus 91991	: V=0.9919162, theta=-14.634167 -> V=1.0, theta=0.0
% INFO    : Bus 91992	: V=0.981289, theta=-11.242447 -> V=1.0, theta=0.0
% INFO    : Bus 91993	: V=1.0070651, theta=-5.633439 -> V=1.0, theta=0.0
% INFO    : Bus 91994	: V=1.0165736, theta=-6.197325 -> V=1.0, theta=0.0
% INFO    : Bus 91995	: V=1.0134067, theta=-6.454443 -> V=1.0, theta=0.0
% INFO    : Bus 91996	: V=1.0141554, theta=-6.715129 -> V=1.0, theta=0.0
% INFO    : Bus 91997	: V=1.0118778, theta=-6.769537 -> V=1.0, theta=0.0
% INFO    : Bus 91998	: V=1.0038809, theta=-8.072236 -> V=1.0, theta=0.0
% INFO    : Bus 91999	: V=0.9977401, theta=-8.047909 -> V=1.0, theta=0.0
% INFO    : Bus 92000	: V=1.0137281, theta=-7.537425 -> V=1.0, theta=0.0
% INFO    : Bus 92001	: V=1.0107049, theta=-7.79433 -> V=1.0, theta=0.0
% INFO    : Bus 92002	: V=1.0087769, theta=-7.957939 -> V=1.0, theta=0.0
% INFO    : Bus 92003	: V=0.985423, theta=-3.909147 -> V=1.0, theta=0.0
% INFO    : Bus 92004	: V=0.9769147, theta=-4.670349 -> V=1.0, theta=0.0
% INFO    : Bus 92005	: V=1.0047807, theta=-8.028404 -> V=1.0, theta=0.0
% INFO    : Bus 92006	: V=1.0034623, theta=-8.860556 -> V=1.0, theta=0.0
% INFO    : Bus 92007	: V=1.0042164, theta=-8.495641 -> V=1.0, theta=0.0
% INFO    : Bus 92008	: V=1.0070062, theta=-8.331841 -> V=1.0, theta=0.0
% INFO    : Bus 92009	: V=1.0128805, theta=-7.886628 -> V=1.0, theta=0.0
% INFO    : Bus 92010	: V=0.9931917, theta=-12.394671 -> V=1.0, theta=0.0
% INFO    : Bus 92011	: V=0.9943461, theta=0.092493 -> V=1.0, theta=0.0
% INFO    : Bus 92012	: V=1.0094645, theta=3.696872 -> V=1.0, theta=0.0
% INFO    : Bus 92013	: V=1.0037488, theta=2.595877 -> V=1.0, theta=0.0
% INFO    : Bus 92014	: V=0.9960781, theta=-23.514405 -> V=1.0, theta=0.0
% INFO    : Bus 92015	: V=1.0005842, theta=-23.353402 -> V=1.0, theta=0.0
% INFO    : Bus 92016	: V=1.0033448, theta=-23.218495 -> V=1.0, theta=0.0
% INFO    : Bus 92017	: V=1.0176161, theta=-22.739519 -> V=1.0, theta=0.0
% INFO    : Bus 92018	: V=1.0156994, theta=-22.818151 -> V=1.0, theta=0.0
% INFO    : Bus 92019	: V=1.0171073, theta=-22.639367 -> V=1.0, theta=0.0
% INFO    : Bus 92020	: V=1.0132204, theta=-22.904457 -> V=1.0, theta=0.0
% INFO    : Bus 92021	: V=1.0065457, theta=-23.250626 -> V=1.0, theta=0.0
% INFO    : Bus 92022	: V=1.0024325, theta=-23.254345 -> V=1.0, theta=0.0
% INFO    : Bus 92023	: V=1.0004525, theta=10.804811 -> V=1.0, theta=0.0
% INFO    : Bus 92024	: V=0.9866123, theta=-8.623288 -> V=1.0, theta=0.0
% INFO    : Bus 92025	: V=0.9855459, theta=-8.670958 -> V=1.0, theta=0.0
% INFO    : Bus 92026	: V=0.9870085, theta=-8.590075 -> V=1.0, theta=0.0
% INFO    : Bus 92027	: V=0.9840349, theta=-8.642199 -> V=1.0, theta=0.0
% INFO    : Bus 92028	: V=0.9785404, theta=-9.000931 -> V=1.0, theta=0.0
% INFO    : Bus 92029	: V=0.9773713, theta=-9.133381 -> V=1.0, theta=0.0
% INFO    : Bus 92030	: V=0.9804574, theta=-8.615553 -> V=1.0, theta=0.0
% INFO    : Bus 92031	: V=0.9815166, theta=-7.399074 -> V=1.0, theta=0.0
% INFO    : Bus 92032	: V=1.0187777, theta=-6.207745 -> V=1.0, theta=0.0
% INFO    : Bus 92033	: V=1.0082024, theta=-7.257759 -> V=1.0, theta=0.0
% INFO    : Bus 92034	: V=0.9968679, theta=-8.194416 -> V=1.0, theta=0.0
% INFO    : Bus 92035	: V=0.9965722, theta=-8.258949 -> V=1.0, theta=0.0
% INFO    : Bus 92036	: V=0.9895085, theta=-8.414018 -> V=1.0, theta=0.0
% INFO    : Bus 92037	: V=0.9891684, theta=-3.561221 -> V=1.0, theta=0.0
% INFO    : Bus 92038	: V=0.9963285, theta=-3.865699 -> V=1.0, theta=0.0
% INFO    : Bus 92039	: V=0.9941268, theta=-4.166809 -> V=1.0, theta=0.0
% INFO    : Bus 92040	: V=0.9939964, theta=-4.110218 -> V=1.0, theta=0.0
% INFO    : Bus 92041	: V=0.9980585, theta=-2.453312 -> V=1.0, theta=0.0
% INFO    : Bus 92042	: V=0.9972716, theta=-2.017828 -> V=1.0, theta=0.0
% INFO    : Bus 92043	: V=0.9892994, theta=-4.638481 -> V=1.0, theta=0.0
% INFO    : Bus 92044	: V=0.9965416, theta=-3.731269 -> V=1.0, theta=0.0
% INFO    : Bus 92045	: V=0.9832647, theta=-2.757284 -> V=1.0, theta=0.0
% INFO    : Bus 92046	: V=0.9760219, theta=-7.592852 -> V=1.0, theta=0.0
% INFO    : Bus 92047	: V=0.9770099, theta=-7.708916 -> V=1.0, theta=0.0
% INFO    : Bus 92048	: V=0.972852, theta=-9.746614 -> V=1.0, theta=0.0
% INFO    : Bus 92049	: V=0.9735539, theta=-8.882749 -> V=1.0, theta=0.0
% INFO    : Bus 92050	: V=0.9821834, theta=-20.352089 -> V=1.0, theta=0.0
% INFO    : Bus 92051	: V=0.9891139, theta=-17.069308 -> V=1.0, theta=0.0
% INFO    : Bus 92052	: V=1.0042952, theta=-0.148703 -> V=1.0, theta=0.0
% INFO    : Bus 92053	: V=0.9791712, theta=-13.513415 -> V=1.0, theta=0.0
% INFO    : Bus 92054	: V=0.9770246, theta=-22.194238 -> V=1.0, theta=0.0
% INFO    : Bus 92055	: V=1.0203416, theta=-14.104992 -> V=1.0, theta=0.0
% INFO    : Bus 92056	: V=0.9942704, theta=-2.911052 -> V=1.0, theta=0.0
% INFO    : Bus 92057	: V=0.9942537, theta=-2.754887 -> V=1.0, theta=0.0
% INFO    : Bus 92058	: V=1.0040776, theta=-1.094482 -> V=1.0, theta=0.0
% INFO    : Bus 92059	: V=0.9964158, theta=-2.359813 -> V=1.0, theta=0.0
% INFO    : Bus 92060	: V=0.9886626, theta=-2.80264 -> V=1.0, theta=0.0
% INFO    : Bus 92061	: V=0.984214, theta=-4.048973 -> V=1.0, theta=0.0
% INFO    : Bus 92062	: V=0.985222, theta=-3.538657 -> V=1.0, theta=0.0
% INFO    : Bus 92063	: V=0.9737925, theta=-5.006663 -> V=1.0, theta=0.0
% INFO    : Bus 92064	: V=0.9799554, theta=-5.154561 -> V=1.0, theta=0.0
% INFO    : Bus 92065	: V=0.9762118, theta=-7.033796 -> V=1.0, theta=0.0
% INFO    : Bus 92066	: V=0.978206, theta=-4.863979 -> V=1.0, theta=0.0
% INFO    : Bus 92067	: V=0.9771339, theta=-5.141742 -> V=1.0, theta=0.0
% INFO    : Bus 92068	: V=1.0116866, theta=1.237277 -> V=1.0, theta=0.0
% INFO    : Bus 92069	: V=0.9897242, theta=-23.530296 -> V=1.0, theta=0.0
% INFO    : Bus 92070	: V=0.988706, theta=-23.547841 -> V=1.0, theta=0.0
% INFO    : Bus 92071	: V=0.9911918, theta=-23.46405 -> V=1.0, theta=0.0
% INFO    : Bus 92072	: V=0.9868756, theta=-23.600078 -> V=1.0, theta=0.0
% INFO    : Bus 92073	: V=0.9905732, theta=-23.522459 -> V=1.0, theta=0.0
% INFO    : Bus 92074	: V=0.9918736, theta=-23.481893 -> V=1.0, theta=0.0
% INFO    : Bus 92075	: V=0.9937104, theta=-23.408854 -> V=1.0, theta=0.0
% INFO    : Bus 92076	: V=1.0026864, theta=-22.374155 -> V=1.0, theta=0.0
% INFO    : Bus 92077	: V=0.9949496, theta=-23.211879 -> V=1.0, theta=0.0
% INFO    : Bus 92078	: V=1.0034066, theta=-22.788915 -> V=1.0, theta=0.0
% INFO    : Bus 92079	: V=0.9916301, theta=-23.438188 -> V=1.0, theta=0.0
% INFO    : Bus 92080	: V=0.9866523, theta=-23.515491 -> V=1.0, theta=0.0
% INFO    : Bus 92081	: V=0.9830531, theta=-23.318622 -> V=1.0, theta=0.0
% INFO    : Bus 92082	: V=1.0006982, theta=-22.958922 -> V=1.0, theta=0.0
% INFO    : Bus 92083	: V=0.9991373, theta=-23.14537 -> V=1.0, theta=0.0
% INFO    : Bus 92084	: V=0.9847467, theta=-23.301081 -> V=1.0, theta=0.0
% INFO    : Bus 92085	: V=1.0004251, theta=-22.743202 -> V=1.0, theta=0.0
% INFO    : Bus 92086	: V=1.0041125, theta=-22.213719 -> V=1.0, theta=0.0
% INFO    : Bus 92087	: V=1.0012983, theta=-23.33801 -> V=1.0, theta=0.0
% INFO    : Bus 92088	: V=0.98833, theta=-21.300841 -> V=1.0, theta=0.0
% INFO    : Bus 92089	: V=0.9928296, theta=-23.373744 -> V=1.0, theta=0.0
% INFO    : Bus 92090	: V=0.9925251, theta=-23.49292 -> V=1.0, theta=0.0
% INFO    : Bus 92091	: V=0.9936515, theta=-0.652135 -> V=1.0, theta=0.0
% INFO    : Bus 92092	: V=0.9872049, theta=2.026126 -> V=1.0, theta=0.0
% INFO    : Bus 92093	: V=1.0066552, theta=-5.596647 -> V=1.0, theta=0.0
% INFO    : Bus 92094	: V=1.0038755, theta=-5.908761 -> V=1.0, theta=0.0
% INFO    : Bus 92095	: V=0.9807681, theta=-12.930187 -> V=1.0, theta=0.0
% INFO    : Bus 92096	: V=0.9930423, theta=2.272507 -> V=1.0, theta=0.0
% INFO    : Bus 92097	: V=0.9905747, theta=-19.279013 -> V=1.0, theta=0.0
% INFO    : Bus 92098	: V=1.0075742, theta=-20.403739 -> V=1.0, theta=0.0
% INFO    : Bus 92099	: V=1.0089507, theta=-20.254568 -> V=1.0, theta=0.0
% INFO    : Bus 92100	: V=1.0059792, theta=-20.199538 -> V=1.0, theta=0.0
% INFO    : Bus 92101	: V=1.0099122, theta=-20.055194 -> V=1.0, theta=0.0
% INFO    : Bus 92102	: V=1.0059877, theta=-20.137663 -> V=1.0, theta=0.0
% INFO    : Bus 92103	: V=0.9989186, theta=-8.912228 -> V=1.0, theta=0.0
% INFO    : Bus 92104	: V=1.01443, theta=-9.276703 -> V=1.0, theta=0.0
% INFO    : Bus 92105	: V=0.9928255, theta=-8.547786 -> V=1.0, theta=0.0
% INFO    : Bus 92106	: V=0.9982501, theta=-8.194514 -> V=1.0, theta=0.0
% INFO    : Bus 92107	: V=0.9961145, theta=-8.428089 -> V=1.0, theta=0.0
% INFO    : Bus 92108	: V=0.9925715, theta=-8.557891 -> V=1.0, theta=0.0
% INFO    : Bus 92109	: V=0.9908024, theta=-8.694429 -> V=1.0, theta=0.0
% INFO    : Bus 92110	: V=0.9878245, theta=-8.916819 -> V=1.0, theta=0.0
% INFO    : Bus 92111	: V=0.9881474, theta=-8.788327 -> V=1.0, theta=0.0
% INFO    : Bus 92112	: V=0.9872271, theta=-8.855394 -> V=1.0, theta=0.0
% INFO    : Bus 92113	: V=0.9862959, theta=-8.888057 -> V=1.0, theta=0.0
% INFO    : Bus 92114	: V=0.9860869, theta=-8.920567 -> V=1.0, theta=0.0
% INFO    : Bus 92115	: V=0.9826112, theta=-9.291221 -> V=1.0, theta=0.0
% INFO    : Bus 92116	: V=0.979017, theta=-9.492315 -> V=1.0, theta=0.0
% INFO    : Bus 92117	: V=0.9802808, theta=-9.421825 -> V=1.0, theta=0.0
% INFO    : Bus 92118	: V=0.9803002, theta=-9.419563 -> V=1.0, theta=0.0
% INFO    : Bus 92119	: V=0.9786572, theta=-9.504928 -> V=1.0, theta=0.0
% INFO    : Bus 92120	: V=0.9743108, theta=-9.706421 -> V=1.0, theta=0.0
% INFO    : Bus 92121	: V=0.976369, theta=-9.616007 -> V=1.0, theta=0.0
% INFO    : Bus 92122	: V=0.9724995, theta=-9.843216 -> V=1.0, theta=0.0
% INFO    : Bus 92123	: V=0.9718865, theta=-9.855267 -> V=1.0, theta=0.0
% INFO    : Bus 92124	: V=0.9727876, theta=-9.786128 -> V=1.0, theta=0.0
% INFO    : Bus 92125	: V=0.9750246, theta=-9.775828 -> V=1.0, theta=0.0
% INFO    : Bus 92126	: V=0.9781194, theta=-9.325923 -> V=1.0, theta=0.0
% INFO    : Bus 92127	: V=0.9966449, theta=-8.348905 -> V=1.0, theta=0.0
% INFO    : Bus 92128	: V=0.9991749, theta=-8.251504 -> V=1.0, theta=0.0
% INFO    : Bus 92129	: V=0.9986055, theta=-8.390105 -> V=1.0, theta=0.0
% INFO    : Bus 92130	: V=0.9941207, theta=-8.485412 -> V=1.0, theta=0.0
% INFO    : Bus 92131	: V=0.9911171, theta=-8.621498 -> V=1.0, theta=0.0
% INFO    : Bus 92132	: V=0.9984197, theta=-8.347936 -> V=1.0, theta=0.0
% INFO    : Bus 92133	: V=1.0022765, theta=-8.060521 -> V=1.0, theta=0.0
% INFO    : Bus 92134	: V=0.9835191, theta=-9.125885 -> V=1.0, theta=0.0
% INFO    : Bus 92135	: V=0.9738171, theta=-9.483961 -> V=1.0, theta=0.0
% INFO    : Bus 92136	: V=0.974928, theta=-9.76341 -> V=1.0, theta=0.0
% INFO    : Bus 92137	: V=0.9830468, theta=-9.027548 -> V=1.0, theta=0.0
% INFO    : Bus 92138	: V=0.9868699, theta=-8.750445 -> V=1.0, theta=0.0
% INFO    : Bus 92139	: V=0.98796, theta=-8.720183 -> V=1.0, theta=0.0
% INFO    : Bus 92140	: V=0.9999367, theta=-7.969343 -> V=1.0, theta=0.0
% INFO    : Bus 92141	: V=0.9877542, theta=-8.818829 -> V=1.0, theta=0.0
% INFO    : Bus 92142	: V=0.9973282, theta=-8.182627 -> V=1.0, theta=0.0
% INFO    : Bus 92143	: V=0.9917716, theta=-8.461721 -> V=1.0, theta=0.0
% INFO    : Bus 92144	: V=0.99054, theta=-8.197391 -> V=1.0, theta=0.0
% INFO    : Bus 92145	: V=0.9748582, theta=-9.515971 -> V=1.0, theta=0.0
% INFO    : Bus 92146	: V=0.9983394, theta=-7.846373 -> V=1.0, theta=0.0
% INFO    : Bus 92147	: V=1.0089372, theta=-7.201967 -> V=1.0, theta=0.0
% INFO    : Bus 92148	: V=0.9949032, theta=-8.219807 -> V=1.0, theta=0.0
% INFO    : Bus 92149	: V=0.9869098, theta=-8.933528 -> V=1.0, theta=0.0
% INFO    : Bus 92150	: V=0.9975492, theta=-8.248726 -> V=1.0, theta=0.0
% INFO    : Bus 92151	: V=0.998198, theta=-8.208667 -> V=1.0, theta=0.0
% INFO    : Bus 92152	: V=0.9957009, theta=-8.354581 -> V=1.0, theta=0.0
% INFO    : Bus 92153	: V=0.9952539, theta=-8.467176 -> V=1.0, theta=0.0
% INFO    : Bus 92154	: V=0.9890866, theta=-8.80088 -> V=1.0, theta=0.0
% INFO    : Bus 92155	: V=0.9895977, theta=-8.790136 -> V=1.0, theta=0.0
% INFO    : Bus 92156	: V=0.992279, theta=-8.57448 -> V=1.0, theta=0.0
% INFO    : Bus 92157	: V=0.9894477, theta=-8.750435 -> V=1.0, theta=0.0
% INFO    : Bus 92158	: V=0.9887482, theta=-8.804368 -> V=1.0, theta=0.0
% INFO    : Bus 92159	: V=0.9807925, theta=-9.463305 -> V=1.0, theta=0.0
% INFO    : Bus 92160	: V=0.9832373, theta=-9.055996 -> V=1.0, theta=0.0
% INFO    : Bus 92161	: V=1.0045165, theta=-7.499203 -> V=1.0, theta=0.0
% INFO    : Bus 92162	: V=0.9623164, theta=-23.571798 -> V=1.0, theta=0.0
% INFO    : Bus 92163	: V=0.9656923, theta=-23.41703 -> V=1.0, theta=0.0
% INFO    : Bus 92164	: V=0.980405, theta=-22.649898 -> V=1.0, theta=0.0
% INFO    : Bus 92165	: V=0.977596, theta=-22.870187 -> V=1.0, theta=0.0
% INFO    : Bus 92166	: V=0.9682615, theta=-23.521419 -> V=1.0, theta=0.0
% INFO    : Bus 92167	: V=0.9773271, theta=-23.79999 -> V=1.0, theta=0.0
% INFO    : Bus 92168	: V=0.9749196, theta=-23.966568 -> V=1.0, theta=0.0
% INFO    : Bus 92169	: V=0.9984181, theta=-23.134623 -> V=1.0, theta=0.0
% INFO    : Bus 92170	: V=0.9821564, theta=-5.070599 -> V=1.0, theta=0.0
% INFO    : Bus 92171	: V=0.982678, theta=-5.035622 -> V=1.0, theta=0.0
% INFO    : Bus 92172	: V=0.9855689, theta=-4.8201 -> V=1.0, theta=0.0
% INFO    : Bus 92173	: V=0.9817837, theta=-4.961727 -> V=1.0, theta=0.0
% INFO    : Bus 92174	: V=0.9893914, theta=-4.302417 -> V=1.0, theta=0.0
% INFO    : Bus 92175	: V=0.9897658, theta=-4.420392 -> V=1.0, theta=0.0
% INFO    : Bus 92176	: V=0.9771053, theta=-5.688282 -> V=1.0, theta=0.0
% INFO    : Bus 92177	: V=0.9974611, theta=-4.624737 -> V=1.0, theta=0.0
% INFO    : Bus 92178	: V=0.9929958, theta=-4.749603 -> V=1.0, theta=0.0
% INFO    : Bus 92179	: V=1.0114555, theta=-3.712451 -> V=1.0, theta=0.0
% INFO    : Bus 92180	: V=1.007678, theta=-4.207753 -> V=1.0, theta=0.0
% INFO    : Bus 92181	: V=1.0033892, theta=-4.513023 -> V=1.0, theta=0.0
% INFO    : Bus 92182	: V=0.999539, theta=-4.880118 -> V=1.0, theta=0.0
% INFO    : Bus 92183	: V=1.0108651, theta=-4.208065 -> V=1.0, theta=0.0
% INFO    : Bus 92184	: V=1.0062496, theta=-4.577402 -> V=1.0, theta=0.0
% INFO    : Bus 92185	: V=1.0032966, theta=-4.969719 -> V=1.0, theta=0.0
% INFO    : Bus 92186	: V=1.0099636, theta=-5.291057 -> V=1.0, theta=0.0
% INFO    : Bus 92187	: V=1.0058223, theta=-5.332225 -> V=1.0, theta=0.0
% INFO    : Bus 92188	: V=1.0032235, theta=-5.518934 -> V=1.0, theta=0.0
% INFO    : Bus 92189	: V=1.0006816, theta=-5.605899 -> V=1.0, theta=0.0
% INFO    : Bus 92190	: V=0.9932707, theta=-5.674435 -> V=1.0, theta=0.0
% INFO    : Bus 92191	: V=0.9767283, theta=-8.400717 -> V=1.0, theta=0.0
% INFO    : Bus 92192	: V=0.9953153, theta=-8.021344 -> V=1.0, theta=0.0
% INFO    : Bus 92193	: V=0.9910261, theta=-7.894248 -> V=1.0, theta=0.0
% INFO    : Bus 92194	: V=0.9902658, theta=-8.154785 -> V=1.0, theta=0.0
% INFO    : Bus 92195	: V=0.9841042, theta=-8.506038 -> V=1.0, theta=0.0
% INFO    : Bus 92196	: V=0.9769847, theta=-9.24725 -> V=1.0, theta=0.0
% INFO    : Bus 92197	: V=0.990638, theta=-16.542443 -> V=1.0, theta=0.0
% INFO    : Bus 92198	: V=0.9886575, theta=-16.609333 -> V=1.0, theta=0.0
% INFO    : Bus 92199	: V=0.9860843, theta=-16.606832 -> V=1.0, theta=0.0
% INFO    : Bus 92200	: V=0.9846685, theta=-17.498821 -> V=1.0, theta=0.0
% INFO    : Bus 92201	: V=0.9896825, theta=-6.815135 -> V=1.0, theta=0.0
% INFO    : Bus 92202	: V=0.9792978, theta=-8.057022 -> V=1.0, theta=0.0
% INFO    : Bus 92203	: V=0.9810536, theta=-22.725072 -> V=1.0, theta=0.0
% INFO    : Bus 92204	: V=0.9938003, theta=-24.07745 -> V=1.0, theta=0.0
% INFO    : Bus 92205	: V=0.9727834, theta=-24.413394 -> V=1.0, theta=0.0
% INFO    : Bus 92206	: V=0.994209, theta=2.524475 -> V=1.0, theta=0.0
% INFO    : Bus 92207	: V=0.9842361, theta=0.690102 -> V=1.0, theta=0.0
% INFO    : Bus 92208	: V=0.9829859, theta=-0.390514 -> V=1.0, theta=0.0
% INFO    : Bus 92209	: V=1.0011562, theta=-2.545668 -> V=1.0, theta=0.0
% INFO    : Bus 92210	: V=0.959329, theta=-28.521094 -> V=1.0, theta=0.0
% INFO    : Bus 92211	: V=0.9723187, theta=-28.857364 -> V=1.0, theta=0.0
% INFO    : Bus 92212	: V=0.9700684, theta=-27.687133 -> V=1.0, theta=0.0
% INFO    : Bus 92213	: V=0.9994611, theta=6.631244 -> V=1.0, theta=0.0
% INFO    : Bus 92214	: V=1.0012657, theta=7.033441 -> V=1.0, theta=0.0
% INFO    : Bus 92215	: V=1.0151097, theta=-8.528939 -> V=1.0, theta=0.0
% INFO    : Bus 92216	: V=1.011563, theta=-8.802226 -> V=1.0, theta=0.0
% INFO    : Bus 92217	: V=0.9859235, theta=6.371909 -> V=1.0, theta=0.0
% INFO    : Bus 92218	: V=0.9941792, theta=-10.98515 -> V=1.0, theta=0.0
% INFO    : Bus 92219	: V=0.9981918, theta=-12.555756 -> V=1.0, theta=0.0
% INFO    : Bus 92220	: V=0.9963966, theta=-10.69173 -> V=1.0, theta=0.0
% INFO    : Bus 92221	: V=0.9838507, theta=-5.119726 -> V=1.0, theta=0.0
% INFO    : Bus 92222	: V=0.9825282, theta=-6.12303 -> V=1.0, theta=0.0
% INFO    : Bus 92223	: V=0.9861043, theta=1.785327 -> V=1.0, theta=0.0
% INFO    : Bus 92224	: V=1.019842, theta=-10.34542 -> V=1.0, theta=0.0
% INFO    : Bus 92225	: V=1.0155959, theta=-10.663 -> V=1.0, theta=0.0
% INFO    : Bus 92226	: V=1.0202512, theta=-11.388822 -> V=1.0, theta=0.0
% INFO    : Bus 92227	: V=1.0157898, theta=-11.7314 -> V=1.0, theta=0.0
% INFO    : Bus 92228	: V=1.0215261, theta=-11.549422 -> V=1.0, theta=0.0
% INFO    : Bus 92229	: V=1.0217348, theta=-11.71181 -> V=1.0, theta=0.0
% INFO    : Bus 92230	: V=1.0216325, theta=-11.740127 -> V=1.0, theta=0.0
% INFO    : Bus 92231	: V=1.0211304, theta=-11.756726 -> V=1.0, theta=0.0
% INFO    : Bus 92232	: V=0.972631, theta=-26.054751 -> V=1.0, theta=0.0
% INFO    : Bus 92233	: V=0.9762595, theta=-24.987747 -> V=1.0, theta=0.0
% INFO    : Bus 92234	: V=0.9668861, theta=-26.552152 -> V=1.0, theta=0.0
% INFO    : Bus 92235	: V=1.0060197, theta=1.241862 -> V=1.0, theta=0.0
% INFO    : Bus 92236	: V=1.008428, theta=1.714297 -> V=1.0, theta=0.0
% INFO    : Bus 92237	: V=0.990738, theta=-17.022521 -> V=1.0, theta=0.0
% INFO    : Bus 92238	: V=1.000279, theta=-19.427676 -> V=1.0, theta=0.0
% INFO    : Bus 92239	: V=0.992372, theta=-5.799086 -> V=1.0, theta=0.0
% INFO    : Bus 92240	: V=0.9984369, theta=-21.635261 -> V=1.0, theta=0.0
% INFO    : Bus 92241	: V=1.021727, theta=-13.177517 -> V=1.0, theta=0.0
% INFO    : Bus 92242	: V=1.0220331, theta=-13.809993 -> V=1.0, theta=0.0
% INFO    : Bus 92243	: V=1.0195864, theta=-13.775721 -> V=1.0, theta=0.0
% INFO    : Bus 92244	: V=1.017494, theta=-13.923002 -> V=1.0, theta=0.0
% INFO    : Bus 92245	: V=1.0137381, theta=-4.366005 -> V=1.0, theta=0.0
% INFO    : Bus 92246	: V=1.0126209, theta=-4.621955 -> V=1.0, theta=0.0
% INFO    : Bus 92247	: V=1.0119544, theta=-4.837478 -> V=1.0, theta=0.0
% INFO    : Bus 92248	: V=0.9960139, theta=-5.46857 -> V=1.0, theta=0.0
% INFO    : Bus 92249	: V=0.9727069, theta=-9.340479 -> V=1.0, theta=0.0
% INFO    : Bus 92250	: V=0.9684777, theta=-9.905345 -> V=1.0, theta=0.0
% INFO    : Bus 92251	: V=0.9686956, theta=-11.892161 -> V=1.0, theta=0.0
% INFO    : Bus 92252	: V=0.9681623, theta=-11.86393 -> V=1.0, theta=0.0
% INFO    : Bus 92253	: V=0.9808727, theta=-14.639928 -> V=1.0, theta=0.0
% INFO    : Bus 92254	: V=0.9915507, theta=3.794813 -> V=1.0, theta=0.0
% INFO    : Bus 92255	: V=0.981386, theta=-8.634691 -> V=1.0, theta=0.0
% INFO    : Bus 92256	: V=0.9834611, theta=-7.992748 -> V=1.0, theta=0.0
% INFO    : Bus 92257	: V=0.993012, theta=-6.623791 -> V=1.0, theta=0.0
% INFO    : Bus 92258	: V=0.9878851, theta=-6.436285 -> V=1.0, theta=0.0
% INFO    : Bus 92259	: V=0.9894065, theta=-16.96933 -> V=1.0, theta=0.0
% INFO    : Bus 92260	: V=0.988659, theta=-17.542718 -> V=1.0, theta=0.0
% INFO    : Bus 92261	: V=0.984527, theta=-13.594277 -> V=1.0, theta=0.0
% INFO    : Bus 92262	: V=0.9805215, theta=-15.624932 -> V=1.0, theta=0.0
% INFO    : Bus 92263	: V=0.9795094, theta=-15.09795 -> V=1.0, theta=0.0
% INFO    : Bus 92264	: V=0.9801794, theta=-16.056974 -> V=1.0, theta=0.0
% INFO    : Bus 92265	: V=1.0109147, theta=8.401481 -> V=1.0, theta=0.0
% INFO    : Bus 92266	: V=1.0010062, theta=4.752068 -> V=1.0, theta=0.0
% INFO    : Bus 92267	: V=1.0053354, theta=4.67897 -> V=1.0, theta=0.0
% INFO    : Bus 92268	: V=0.9852748, theta=-7.715104 -> V=1.0, theta=0.0
% INFO    : Bus 92269	: V=1.0311284, theta=-12.923401 -> V=1.0, theta=0.0
% INFO    : Bus 92270	: V=1.0314028, theta=-13.088374 -> V=1.0, theta=0.0
% INFO    : Bus 92271	: V=1.0300815, theta=-13.196222 -> V=1.0, theta=0.0
% INFO    : Bus 92272	: V=0.9778292, theta=-4.305708 -> V=1.0, theta=0.0
% INFO    : Bus 92273	: V=0.9791292, theta=-4.162758 -> V=1.0, theta=0.0
% INFO    : Bus 92274	: V=0.9786213, theta=-4.152173 -> V=1.0, theta=0.0
% INFO    : Bus 92275	: V=0.9777644, theta=-4.467105 -> V=1.0, theta=0.0
% INFO    : Bus 92276	: V=0.9772008, theta=-4.628526 -> V=1.0, theta=0.0
% INFO    : Bus 92277	: V=0.9813249, theta=-3.209128 -> V=1.0, theta=0.0
% INFO    : Bus 92278	: V=0.978447, theta=-3.974526 -> V=1.0, theta=0.0
% INFO    : Bus 92279	: V=0.9788405, theta=-4.104403 -> V=1.0, theta=0.0
% INFO    : Bus 92280	: V=0.9778228, theta=-4.203418 -> V=1.0, theta=0.0
% INFO    : Bus 92281	: V=0.9785785, theta=-3.844647 -> V=1.0, theta=0.0
% INFO    : Bus 92282	: V=0.9789619, theta=-3.406547 -> V=1.0, theta=0.0
% INFO    : Bus 92283	: V=0.9800303, theta=-3.206938 -> V=1.0, theta=0.0
% INFO    : Bus 92284	: V=0.9799151, theta=-3.189358 -> V=1.0, theta=0.0
% INFO    : Bus 92285	: V=0.9844877, theta=-1.966649 -> V=1.0, theta=0.0
% INFO    : Bus 92286	: V=0.9828536, theta=-2.354271 -> V=1.0, theta=0.0
% INFO    : Bus 92287	: V=0.9814971, theta=-1.709824 -> V=1.0, theta=0.0
% INFO    : Bus 92288	: V=0.9940197, theta=-2.327426 -> V=1.0, theta=0.0
% INFO    : Bus 92289	: V=0.9784596, theta=-3.85635 -> V=1.0, theta=0.0
% INFO    : Bus 92290	: V=1.0048582, theta=-9.124384 -> V=1.0, theta=0.0
% INFO    : Bus 92291	: V=1.0049415, theta=-6.623513 -> V=1.0, theta=0.0
% INFO    : Bus 92292	: V=1.0085214, theta=-6.421385 -> V=1.0, theta=0.0
% INFO    : Bus 92293	: V=1.0044205, theta=-6.507155 -> V=1.0, theta=0.0
% INFO    : Bus 92294	: V=0.9926939, theta=-7.736772 -> V=1.0, theta=0.0
% INFO    : Bus 92295	: V=0.9923998, theta=-8.412904 -> V=1.0, theta=0.0
% INFO    : Bus 92296	: V=1.0009526, theta=-7.995338 -> V=1.0, theta=0.0
% INFO    : Bus 92297	: V=0.991594, theta=-8.34778 -> V=1.0, theta=0.0
% INFO    : Bus 92298	: V=0.98033, theta=-4.828483 -> V=1.0, theta=0.0
% INFO    : Bus 92299	: V=0.9817379, theta=-4.462145 -> V=1.0, theta=0.0
% INFO    : Bus 92300	: V=0.9808448, theta=-4.727266 -> V=1.0, theta=0.0
% INFO    : Bus 92301	: V=0.9855769, theta=-3.725643 -> V=1.0, theta=0.0
% INFO    : Bus 92302	: V=0.9879249, theta=-3.418399 -> V=1.0, theta=0.0
% INFO    : Bus 92303	: V=0.9862416, theta=-3.45374 -> V=1.0, theta=0.0
% INFO    : Bus 92304	: V=0.9901122, theta=-2.561061 -> V=1.0, theta=0.0
% INFO    : Bus 92305	: V=0.9931968, theta=-1.906163 -> V=1.0, theta=0.0
% INFO    : Bus 92306	: V=0.9858265, theta=-2.89332 -> V=1.0, theta=0.0
% INFO    : Bus 92307	: V=0.9960443, theta=-1.563591 -> V=1.0, theta=0.0
% INFO    : Bus 92308	: V=0.9914072, theta=-2.170404 -> V=1.0, theta=0.0
% INFO    : Bus 92309	: V=0.9862113, theta=-2.957544 -> V=1.0, theta=0.0
% INFO    : Bus 92310	: V=0.9875457, theta=-2.915217 -> V=1.0, theta=0.0
% INFO    : Bus 92311	: V=0.9861049, theta=-3.130101 -> V=1.0, theta=0.0
% INFO    : Bus 92312	: V=0.9839242, theta=-3.50521 -> V=1.0, theta=0.0
% INFO    : Bus 92313	: V=0.9835095, theta=-3.620351 -> V=1.0, theta=0.0
% INFO    : Bus 92314	: V=0.978021, theta=-5.293375 -> V=1.0, theta=0.0
% INFO    : Bus 92315	: V=0.9822981, theta=-4.345953 -> V=1.0, theta=0.0
% INFO    : Bus 92316	: V=0.9847475, theta=-3.513232 -> V=1.0, theta=0.0
% INFO    : Bus 92317	: V=0.9853879, theta=-3.550632 -> V=1.0, theta=0.0
% INFO    : Bus 92318	: V=0.9806461, theta=-4.899448 -> V=1.0, theta=0.0
% INFO    : Bus 92319	: V=0.9797482, theta=-4.978677 -> V=1.0, theta=0.0
% INFO    : Bus 92320	: V=0.9784453, theta=-5.529367 -> V=1.0, theta=0.0
% INFO    : Bus 92321	: V=0.9830898, theta=-4.691758 -> V=1.0, theta=0.0
% INFO    : Bus 92322	: V=0.9836397, theta=-4.646765 -> V=1.0, theta=0.0
% INFO    : Bus 92323	: V=0.980421, theta=-5.094507 -> V=1.0, theta=0.0
% INFO    : Bus 92324	: V=0.9807941, theta=-5.003399 -> V=1.0, theta=0.0
% INFO    : Bus 92325	: V=0.9784858, theta=-5.102138 -> V=1.0, theta=0.0
% INFO    : Bus 92326	: V=0.9775538, theta=-4.646017 -> V=1.0, theta=0.0
% INFO    : Bus 92327	: V=0.9765575, theta=-5.530621 -> V=1.0, theta=0.0
% INFO    : Bus 92328	: V=0.9829688, theta=-4.991309 -> V=1.0, theta=0.0
% INFO    : Bus 92329	: V=0.9766602, theta=-5.577473 -> V=1.0, theta=0.0
% INFO    : Bus 92330	: V=0.9947821, theta=-3.657383 -> V=1.0, theta=0.0
% INFO    : Bus 92331	: V=0.9841018, theta=-4.630086 -> V=1.0, theta=0.0
% INFO    : Bus 92332	: V=0.9824614, theta=-4.891267 -> V=1.0, theta=0.0
% INFO    : Bus 92333	: V=0.9778348, theta=-5.405396 -> V=1.0, theta=0.0
% INFO    : Bus 92334	: V=0.9780841, theta=-5.503261 -> V=1.0, theta=0.0
% INFO    : Bus 92335	: V=0.9752309, theta=-5.837454 -> V=1.0, theta=0.0
% INFO    : Bus 92336	: V=0.978464, theta=-5.57559 -> V=1.0, theta=0.0
% INFO    : Bus 92337	: V=0.9777836, theta=-5.633595 -> V=1.0, theta=0.0
% INFO    : Bus 92338	: V=0.9753894, theta=-5.76823 -> V=1.0, theta=0.0
% INFO    : Bus 92339	: V=0.9783647, theta=-5.203094 -> V=1.0, theta=0.0
% INFO    : Bus 92340	: V=0.9809925, theta=-4.729614 -> V=1.0, theta=0.0
% INFO    : Bus 92341	: V=0.9789969, theta=-5.17495 -> V=1.0, theta=0.0
% INFO    : Bus 92342	: V=0.977339, theta=-5.587704 -> V=1.0, theta=0.0
% INFO    : Bus 92343	: V=0.9805396, theta=-4.907249 -> V=1.0, theta=0.0
% INFO    : Bus 92344	: V=0.9763302, theta=-5.622874 -> V=1.0, theta=0.0
% INFO    : Bus 92345	: V=0.9767516, theta=-5.594455 -> V=1.0, theta=0.0
% INFO    : Bus 92346	: V=0.9761415, theta=-5.785694 -> V=1.0, theta=0.0
% INFO    : Bus 92347	: V=0.9752924, theta=-5.74993 -> V=1.0, theta=0.0
% INFO    : Bus 92348	: V=0.9776548, theta=-5.637966 -> V=1.0, theta=0.0
% INFO    : Bus 92349	: V=0.9784295, theta=-5.510747 -> V=1.0, theta=0.0
% INFO    : Bus 92350	: V=0.9787455, theta=-5.590661 -> V=1.0, theta=0.0
% INFO    : Bus 92351	: V=0.9894862, theta=-4.363849 -> V=1.0, theta=0.0
% INFO    : Bus 92352	: V=0.9827788, theta=-4.960679 -> V=1.0, theta=0.0
% INFO    : Bus 92353	: V=0.9992451, theta=-3.376551 -> V=1.0, theta=0.0
% INFO    : Bus 92354	: V=0.9882164, theta=-4.505819 -> V=1.0, theta=0.0
% INFO    : Bus 92355	: V=0.9818297, theta=-5.082406 -> V=1.0, theta=0.0
% INFO    : Bus 92356	: V=0.9910264, theta=-4.517241 -> V=1.0, theta=0.0
% INFO    : Bus 92357	: V=0.9775323, theta=-5.61509 -> V=1.0, theta=0.0
% INFO    : Bus 92358	: V=0.9769898, theta=-5.586475 -> V=1.0, theta=0.0
% INFO    : Bus 92359	: V=0.9760643, theta=-5.78672 -> V=1.0, theta=0.0
% INFO    : Bus 92360	: V=0.9783583, theta=-5.314119 -> V=1.0, theta=0.0
% INFO    : Bus 92361	: V=0.9812445, theta=-5.127804 -> V=1.0, theta=0.0
% INFO    : Bus 92362	: V=0.9811251, theta=-5.370455 -> V=1.0, theta=0.0
% INFO    : Bus 92363	: V=0.9844674, theta=-4.217281 -> V=1.0, theta=0.0
% INFO    : Bus 92364	: V=0.9861864, theta=-4.231235 -> V=1.0, theta=0.0
% INFO    : Bus 92365	: V=0.9826201, theta=-4.370649 -> V=1.0, theta=0.0
% INFO    : Bus 92366	: V=0.9876853, theta=-3.698119 -> V=1.0, theta=0.0
% INFO    : Bus 92367	: V=0.9810205, theta=-4.921368 -> V=1.0, theta=0.0
% INFO    : Bus 92368	: V=0.9862574, theta=-3.835675 -> V=1.0, theta=0.0
% INFO    : Bus 92369	: V=0.9876923, theta=-3.678559 -> V=1.0, theta=0.0
% INFO    : Bus 92370	: V=0.9829284, theta=-5.590869 -> V=1.0, theta=0.0
% INFO    : Bus 92371	: V=1.0038102, theta=-8.82905 -> V=1.0, theta=0.0
% INFO    : Bus 92372	: V=1.0046278, theta=-9.333047 -> V=1.0, theta=0.0
% INFO    : Bus 92373	: V=1.0201135, theta=-9.875777 -> V=1.0, theta=0.0
% INFO    : Bus 92374	: V=1.0077671, theta=-10.109456 -> V=1.0, theta=0.0
% INFO    : Bus 92375	: V=0.9957227, theta=-16.971939 -> V=1.0, theta=0.0
% INFO    : Bus 92376	: V=0.9998638, theta=7.658148 -> V=1.0, theta=0.0
% INFO    : Bus 92377	: V=1.0041843, theta=-9.892198 -> V=1.0, theta=0.0
% INFO    : Bus 92378	: V=1.0196836, theta=-10.134998 -> V=1.0, theta=0.0
% INFO    : Bus 92379	: V=1.0084099, theta=-11.564835 -> V=1.0, theta=0.0
% INFO    : Bus 92380	: V=1.0221319, theta=-11.331246 -> V=1.0, theta=0.0
% INFO    : Bus 92381	: V=1.0194373, theta=-11.116735 -> V=1.0, theta=0.0
% INFO    : Bus 92382	: V=0.9944652, theta=-24.171388 -> V=1.0, theta=0.0
% INFO    : Bus 92383	: V=0.9943511, theta=-25.563387 -> V=1.0, theta=0.0
% INFO    : Bus 92384	: V=1.0086367, theta=-24.023026 -> V=1.0, theta=0.0
% INFO    : Bus 92385	: V=1.020173, theta=-23.241926 -> V=1.0, theta=0.0
% INFO    : Bus 92386	: V=1.0190244, theta=-23.321918 -> V=1.0, theta=0.0
% INFO    : Bus 92387	: V=1.0038133, theta=-24.102107 -> V=1.0, theta=0.0
% INFO    : Bus 92388	: V=0.9879568, theta=-25.012618 -> V=1.0, theta=0.0
% INFO    : Bus 92389	: V=0.9888513, theta=-15.588125 -> V=1.0, theta=0.0
% INFO    : Bus 92390	: V=0.9905645, theta=-19.47734 -> V=1.0, theta=0.0
% INFO    : Bus 92391	: V=0.9846327, theta=-14.032137 -> V=1.0, theta=0.0
% INFO    : Bus 92392	: V=0.9844926, theta=-14.067423 -> V=1.0, theta=0.0
% INFO    : Bus 92393	: V=0.9828956, theta=-0.959476 -> V=1.0, theta=0.0
% INFO    : Bus 92394	: V=0.981438, theta=-1.554978 -> V=1.0, theta=0.0
% INFO    : Bus 92395	: V=0.9829413, theta=-2.02503 -> V=1.0, theta=0.0
% INFO    : Bus 92396	: V=1.007707, theta=-6.89887 -> V=1.0, theta=0.0
% INFO    : Bus 92397	: V=0.9976821, theta=-6.813388 -> V=1.0, theta=0.0
% INFO    : Bus 92398	: V=0.991364, theta=-7.106695 -> V=1.0, theta=0.0
% INFO    : Bus 92399	: V=0.9830636, theta=-8.737272 -> V=1.0, theta=0.0
% INFO    : Bus 92400	: V=1.0248293, theta=-10.517354 -> V=1.0, theta=0.0
% INFO    : Bus 92401	: V=1.0244342, theta=-10.744455 -> V=1.0, theta=0.0
% INFO    : Bus 92402	: V=1.0233358, theta=-10.816913 -> V=1.0, theta=0.0
% INFO    : Bus 92403	: V=0.9819548, theta=-21.075173 -> V=1.0, theta=0.0
% INFO    : Bus 92404	: V=0.9869853, theta=-21.530573 -> V=1.0, theta=0.0
% INFO    : Bus 92405	: V=0.9774197, theta=-21.835132 -> V=1.0, theta=0.0
% INFO    : Bus 92406	: V=0.9986119, theta=-18.806323 -> V=1.0, theta=0.0
% INFO    : Bus 92407	: V=0.9844598, theta=-20.366618 -> V=1.0, theta=0.0
% INFO    : Bus 92408	: V=0.9829594, theta=-21.411183 -> V=1.0, theta=0.0
% INFO    : Bus 92409	: V=0.9809873, theta=-5.051362 -> V=1.0, theta=0.0
% INFO    : Bus 92410	: V=0.9770707, theta=-5.239846 -> V=1.0, theta=0.0
% INFO    : Bus 92411	: V=0.9963382, theta=-3.644618 -> V=1.0, theta=0.0
% INFO    : Bus 92412	: V=0.985181, theta=-4.753626 -> V=1.0, theta=0.0
% INFO    : Bus 92413	: V=0.9835274, theta=-4.939832 -> V=1.0, theta=0.0
% INFO    : Bus 92414	: V=0.9797826, theta=-5.352093 -> V=1.0, theta=0.0
% INFO    : Bus 92415	: V=0.979697, theta=-5.115186 -> V=1.0, theta=0.0
% INFO    : Bus 92416	: V=0.9808065, theta=-5.315245 -> V=1.0, theta=0.0
% INFO    : Bus 92417	: V=0.9791677, theta=-5.454879 -> V=1.0, theta=0.0
% INFO    : Bus 92418	: V=0.977861, theta=-5.429327 -> V=1.0, theta=0.0
% INFO    : Bus 92419	: V=0.9782923, theta=-5.547198 -> V=1.0, theta=0.0
% INFO    : Bus 92420	: V=0.9773462, theta=-5.390695 -> V=1.0, theta=0.0
% INFO    : Bus 92421	: V=0.9769619, theta=-5.686991 -> V=1.0, theta=0.0
% INFO    : Bus 92422	: V=0.9768315, theta=-5.688002 -> V=1.0, theta=0.0
% INFO    : Bus 92423	: V=0.9782096, theta=-5.522611 -> V=1.0, theta=0.0
% INFO    : Bus 92424	: V=0.9781231, theta=-5.503532 -> V=1.0, theta=0.0
% INFO    : Bus 92425	: V=0.9810694, theta=-5.172748 -> V=1.0, theta=0.0
% INFO    : Bus 92426	: V=0.9769918, theta=-5.592246 -> V=1.0, theta=0.0
% INFO    : Bus 92427	: V=0.9797503, theta=-5.130774 -> V=1.0, theta=0.0
% INFO    : Bus 92428	: V=0.97949, theta=-5.185565 -> V=1.0, theta=0.0
% INFO    : Bus 92429	: V=0.9789944, theta=-5.407613 -> V=1.0, theta=0.0
% INFO    : Bus 92430	: V=0.9774831, theta=-5.599886 -> V=1.0, theta=0.0
% INFO    : Bus 92431	: V=0.975917, theta=-5.770305 -> V=1.0, theta=0.0
% INFO    : Bus 92432	: V=0.9761261, theta=-5.7918 -> V=1.0, theta=0.0
% INFO    : Bus 92433	: V=0.9790529, theta=-5.439071 -> V=1.0, theta=0.0
% INFO    : Bus 92434	: V=0.9797509, theta=-5.205837 -> V=1.0, theta=0.0
% INFO    : Bus 92435	: V=0.9823687, theta=-5.016284 -> V=1.0, theta=0.0
% INFO    : Bus 92436	: V=0.9822882, theta=-5.090732 -> V=1.0, theta=0.0
% INFO    : Bus 92437	: V=0.9784105, theta=-5.312517 -> V=1.0, theta=0.0
% INFO    : Bus 92438	: V=0.97997, theta=-4.87569 -> V=1.0, theta=0.0
% INFO    : Bus 92439	: V=0.9769633, theta=-5.707891 -> V=1.0, theta=0.0
% INFO    : Bus 92440	: V=0.9849493, theta=-4.696408 -> V=1.0, theta=0.0
% INFO    : Bus 92441	: V=0.9842084, theta=-4.857752 -> V=1.0, theta=0.0
% INFO    : Bus 92442	: V=0.9775295, theta=-5.597488 -> V=1.0, theta=0.0
% INFO    : Bus 92443	: V=0.9794087, theta=-5.491151 -> V=1.0, theta=0.0
% INFO    : Bus 92444	: V=0.9758465, theta=-5.800387 -> V=1.0, theta=0.0
% INFO    : Bus 92445	: V=1.0137618, theta=-20.152222 -> V=1.0, theta=0.0
% INFO    : Bus 92446	: V=1.0135241, theta=-20.173566 -> V=1.0, theta=0.0
% INFO    : Bus 92447	: V=1.0140779, theta=-14.817726 -> V=1.0, theta=0.0
% INFO    : Bus 92448	: V=1.0130103, theta=-15.008617 -> V=1.0, theta=0.0
% INFO    : Bus 92449	: V=1.0162766, theta=-8.517671 -> V=1.0, theta=0.0
% INFO    : Bus 92450	: V=1.0176492, theta=-9.158824 -> V=1.0, theta=0.0
% INFO    : Bus 92451	: V=1.0139503, theta=-53.572261 -> V=1.0, theta=0.0
% INFO    : Bus 92452	: V=1.0110447, theta=-53.944923 -> V=1.0, theta=0.0
% INFO    : Bus 92453	: V=0.992712, theta=-25.646633 -> V=1.0, theta=0.0
% INFO    : Bus 92454	: V=0.9911542, theta=-25.740974 -> V=1.0, theta=0.0
% INFO    : Bus 92455	: V=0.9991271, theta=-8.269716 -> V=1.0, theta=0.0
% INFO    : Bus 92456	: V=0.9981249, theta=-8.586676 -> V=1.0, theta=0.0
% INFO    : Bus 92457	: V=1.0007728, theta=-31.133357 -> V=1.0, theta=0.0
% INFO    : Bus 92458	: V=1.0113333, theta=-51.417962 -> V=1.0, theta=0.0
% INFO    : Bus 92459	: V=1.0152996, theta=-34.344537 -> V=1.0, theta=0.0
% INFO    : Bus 92460	: V=1.0136066, theta=-51.855274 -> V=1.0, theta=0.0
% INFO    : Bus 92461	: V=1.0132448, theta=-34.062483 -> V=1.0, theta=0.0
% INFO    : Bus 92462	: V=1.0140559, theta=-50.963116 -> V=1.0, theta=0.0
% INFO    : Bus 92463	: V=1.0050115, theta=-36.626788 -> V=1.0, theta=0.0
% INFO    : Bus 92464	: V=1.0046637, theta=-36.659524 -> V=1.0, theta=0.0
% INFO    : Bus 92465	: V=1.0122977, theta=-32.298779 -> V=1.0, theta=0.0
% INFO    : Bus 92466	: V=1.0119554, theta=-11.364149 -> V=1.0, theta=0.0
% INFO    : Bus 92467	: V=1.010111, theta=-11.975883 -> V=1.0, theta=0.0
% INFO    : Bus 92468	: V=1.0148408, theta=-35.749207 -> V=1.0, theta=0.0
% INFO    : Bus 92469	: V=0.996545, theta=-27.146148 -> V=1.0, theta=0.0
% INFO    : Bus 92470	: V=1.0022146, theta=-15.106582 -> V=1.0, theta=0.0
% INFO    : Bus 92471	: V=1.0067688, theta=-45.246032 -> V=1.0, theta=0.0
% INFO    : Bus 92472	: V=0.9973195, theta=-8.235192 -> V=1.0, theta=0.0
% INFO    : Bus 92473	: V=1.0005942, theta=-28.419931 -> V=1.0, theta=0.0
% INFO    : Bus 92474	: V=1.0098485, theta=-44.342183 -> V=1.0, theta=0.0
% INFO    : Bus 92475	: V=1.02, theta=-52.743359 -> V=1.0, theta=0.0
% INFO    : Bus 92476	: V=1.0141209, theta=-53.137486 -> V=1.0, theta=0.0
% INFO    : Bus 92477	: V=0.9908685, theta=-25.582861 -> V=1.0, theta=0.0
% INFO    : Bus 92478	: V=1.0112567, theta=-20.08835 -> V=1.0, theta=0.0
% INFO    : Bus 92479	: V=0.991613, theta=-8.883698 -> V=1.0, theta=0.0
% INFO    : Bus 92480	: V=0.993264, theta=-45.809655 -> V=1.0, theta=0.0
% INFO    : Bus 92481	: V=0.9954013, theta=-46.497407 -> V=1.0, theta=0.0
% INFO    : Bus 92482	: V=1.0133036, theta=-12.705427 -> V=1.0, theta=0.0
% INFO    : Bus 92483	: V=1.0164575, theta=-50.144251 -> V=1.0, theta=0.0
% INFO    : Bus 92484	: V=0.9978222, theta=-11.309293 -> V=1.0, theta=0.0
% INFO    : Bus 92485	: V=1.019231, theta=23.314037 -> V=1.0, theta=0.0
% INFO    : Bus 92486	: V=1.0189705, theta=22.716586 -> V=1.0, theta=0.0
% INFO    : Bus 92487	: V=1.0212198, theta=23.926523 -> V=1.0, theta=0.0
% INFO    : Bus 92488	: V=1.018968, theta=20.841592 -> V=1.0, theta=0.0
% INFO    : Bus 92489	: V=1.0189617, theta=20.793851 -> V=1.0, theta=0.0
% INFO    : Bus 92490	: V=1.0180739, theta=2.076692 -> V=1.0, theta=0.0
% INFO    : Bus 92491	: V=1.0031983, theta=1.287434 -> V=1.0, theta=0.0
% INFO    : Bus 92492	: V=0.9999239, theta=8.821641 -> V=1.0, theta=0.0
% INFO    : Bus 92493	: V=1.016071, theta=18.10164 -> V=1.0, theta=0.0
% INFO    : Bus 92494	: V=1.0172742, theta=16.719185 -> V=1.0, theta=0.0
% INFO    : Bus 92495	: V=1.0191529, theta=16.580325 -> V=1.0, theta=0.0
% INFO    : Bus 92496	: V=1.0199302, theta=1.808445 -> V=1.0, theta=0.0
% INFO    : Bus 92497	: V=1.0089469, theta=1.928776 -> V=1.0, theta=0.0
% INFO    : Bus 92498	: V=1.0086846, theta=-1.921598 -> V=1.0, theta=0.0
% INFO    : Bus 92499	: V=1.0085999, theta=-1.922023 -> V=1.0, theta=0.0
% INFO    : Bus 92500	: V=1.0092474, theta=15.80834 -> V=1.0, theta=0.0
% INFO    : Bus 92501	: V=1.0186674, theta=-39.478544 -> V=1.0, theta=0.0
% INFO    : Bus 92502	: V=1.0177272, theta=-39.400804 -> V=1.0, theta=0.0
% INFO    : Bus 92503	: V=1.009999, theta=1.659482 -> V=1.0, theta=0.0
% INFO    : Bus 92504	: V=1.0018917, theta=1.690823 -> V=1.0, theta=0.0
% INFO    : Bus 92505	: V=0.9995678, theta=1.19058 -> V=1.0, theta=0.0
% INFO    : Bus 92506	: V=1.02, theta=-18.023586 -> V=1.0, theta=0.0
% INFO    : Bus 92507	: V=1.0183054, theta=-33.911374 -> V=1.0, theta=0.0
% INFO    : Bus 92508	: V=1.0026397, theta=4.493504 -> V=1.0, theta=0.0
% INFO    : Bus 92509	: V=1.0005068, theta=4.242683 -> V=1.0, theta=0.0
% INFO    : Bus 92510	: V=1.0057998, theta=-12.423901 -> V=1.0, theta=0.0
% INFO    : Bus 92511	: V=0.9899314, theta=-10.72025 -> V=1.0, theta=0.0
% INFO    : Bus 92512	: V=1.02, theta=4.562825 -> V=1.0, theta=0.0
% INFO    : Bus 92513	: V=1.0156315, theta=-30.392702 -> V=1.0, theta=0.0
% INFO    : Bus 92514	: V=1.0026521, theta=-11.312706 -> V=1.0, theta=0.0
% INFO    : Bus 92515	: V=1.02, theta=-24.009865 -> V=1.0, theta=0.0
% INFO    : Bus 92516	: V=1.019968, theta=-24.118735 -> V=1.0, theta=0.0
% INFO    : Bus 92517	: V=0.9985704, theta=3.488013 -> V=1.0, theta=0.0
% INFO    : Bus 92518	: V=1.0154283, theta=-0.905698 -> V=1.0, theta=0.0
% INFO    : Bus 92519	: V=1.0014899, theta=2.575974 -> V=1.0, theta=0.0
% INFO    : Bus 92520	: V=1.0155262, theta=-34.704025 -> V=1.0, theta=0.0
% INFO    : Bus 92521	: V=1.0172063, theta=-42.570149 -> V=1.0, theta=0.0
% INFO    : Bus 92522	: V=1.0174321, theta=-33.498753 -> V=1.0, theta=0.0
% INFO    : Bus 92523	: V=1.0093789, theta=-42.043729 -> V=1.0, theta=0.0
% INFO    : Bus 92524	: V=1.0042261, theta=-34.529034 -> V=1.0, theta=0.0
% INFO    : Bus 92525	: V=1.0039155, theta=-34.550509 -> V=1.0, theta=0.0
% INFO    : Bus 92526	: V=1.0165903, theta=-48.550601 -> V=1.0, theta=0.0
% INFO    : Bus 92527	: V=1.0119576, theta=-48.577175 -> V=1.0, theta=0.0
% INFO    : Bus 92528	: V=1.014697, theta=-46.588769 -> V=1.0, theta=0.0
% INFO    : Bus 92529	: V=1.0133455, theta=-46.607717 -> V=1.0, theta=0.0
% INFO    : Bus 92530	: V=1.0051469, theta=-37.535758 -> V=1.0, theta=0.0
% INFO    : Bus 92531	: V=1.005886, theta=-37.502079 -> V=1.0, theta=0.0
% INFO    : Bus 92532	: V=0.990198, theta=-53.55724 -> V=1.0, theta=0.0
% INFO    : Bus 92533	: V=1.0174151, theta=-31.739907 -> V=1.0, theta=0.0
% INFO    : Bus 92534	: V=1.0138174, theta=-35.541686 -> V=1.0, theta=0.0
% INFO    : Bus 92535	: V=1.0069041, theta=-36.091645 -> V=1.0, theta=0.0
% INFO    : Bus 92536	: V=1.0027482, theta=-36.350025 -> V=1.0, theta=0.0
% INFO    : Bus 92537	: V=1.0119184, theta=-38.962582 -> V=1.0, theta=0.0
% INFO    : Bus 92538	: V=1.02, theta=-60.147554 -> V=1.0, theta=0.0
% INFO    : Bus 92539	: V=1.02, theta=-51.777111 -> V=1.0, theta=0.0
% INFO    : Bus 92540	: V=1.01718, theta=-52.322364 -> V=1.0, theta=0.0
% INFO    : Bus 92541	: V=1.0154602, theta=-54.853903 -> V=1.0, theta=0.0
% INFO    : Bus 92542	: V=0.98468, theta=-55.48219 -> V=1.0, theta=0.0
% INFO    : Bus 92543	: V=1.0046608, theta=-62.021143 -> V=1.0, theta=0.0
% INFO    : Bus 92544	: V=1.0144991, theta=-53.482098 -> V=1.0, theta=0.0
% INFO    : Bus 92545	: V=0.9867636, theta=-38.548417 -> V=1.0, theta=0.0
% INFO    : Bus 92546	: V=1.02, theta=-51.572542 -> V=1.0, theta=0.0
% INFO    : Bus 92547	: V=1.0178281, theta=-56.520222 -> V=1.0, theta=0.0
% INFO    : Bus 92548	: V=1.0173115, theta=-36.852689 -> V=1.0, theta=0.0
% INFO    : Bus 92549	: V=1.0076269, theta=-37.510538 -> V=1.0, theta=0.0
% INFO    : Bus 92550	: V=1.0154841, theta=-59.931451 -> V=1.0, theta=0.0
% INFO    : Bus 92551	: V=1.0136937, theta=-56.855571 -> V=1.0, theta=0.0
% INFO    : Bus 92552	: V=1.0090702, theta=-51.081483 -> V=1.0, theta=0.0
% INFO    : Bus 92553	: V=1.0013825, theta=-39.849635 -> V=1.0, theta=0.0
% INFO    : Bus 92554	: V=1.02, theta=-47.390361 -> V=1.0, theta=0.0
% INFO    : Bus 92555	: V=0.9943782, theta=-49.03989 -> V=1.0, theta=0.0
% INFO    : Bus 92556	: V=1.0148, theta=-56.82219 -> V=1.0, theta=0.0
% INFO    : Bus 92557	: V=1.0154396, theta=-31.54006 -> V=1.0, theta=0.0
% INFO    : Bus 92558	: V=0.978176, theta=-53.461615 -> V=1.0, theta=0.0
% INFO    : Bus 92559	: V=0.9990053, theta=-36.536349 -> V=1.0, theta=0.0
% INFO    : Bus 92560	: V=1.02, theta=-39.571267 -> V=1.0, theta=0.0
% INFO    : Bus 92561	: V=0.9970035, theta=-39.554454 -> V=1.0, theta=0.0
% INFO    : Bus 92562	: V=1.0019169, theta=-38.224919 -> V=1.0, theta=0.0
% INFO    : Bus 92563	: V=1.0090242, theta=-49.708326 -> V=1.0, theta=0.0
% INFO    : Bus 92564	: V=1.0064652, theta=-50.060551 -> V=1.0, theta=0.0
% INFO    : Bus 92565	: V=1.0089075, theta=-52.48406 -> V=1.0, theta=0.0
% INFO    : Bus 92566	: V=0.9983734, theta=-52.087346 -> V=1.0, theta=0.0
% INFO    : Bus 92567	: V=1.0157987, theta=-31.276562 -> V=1.0, theta=0.0
% INFO    : Bus 92568	: V=1.0088633, theta=-37.28588 -> V=1.0, theta=0.0
% INFO    : Bus 92569	: V=1.0210199, theta=-4.234035 -> V=1.0, theta=0.0
% INFO    : Bus 92570	: V=1.0215434, theta=-4.310955 -> V=1.0, theta=0.0
% INFO    : Bus 92571	: V=1.0214629, theta=-4.308336 -> V=1.0, theta=0.0
% INFO    : Bus 92572	: V=1.0144263, theta=3.740234 -> V=1.0, theta=0.0
% INFO    : Bus 92573	: V=0.994637, theta=4.509754 -> V=1.0, theta=0.0
% INFO    : Bus 92574	: V=1.0207893, theta=-4.296691 -> V=1.0, theta=0.0
% INFO    : Bus 92575	: V=1.020746, theta=-4.742922 -> V=1.0, theta=0.0
% INFO    : Bus 92576	: V=1.0152258, theta=-2.776373 -> V=1.0, theta=0.0
% INFO    : Bus 92577	: V=1.0147596, theta=-2.931257 -> V=1.0, theta=0.0
% INFO    : Bus 92578	: V=1.0146377, theta=-3.593672 -> V=1.0, theta=0.0
% INFO    : Bus 92579	: V=1.0174995, theta=-3.389993 -> V=1.0, theta=0.0
% INFO    : Bus 92580	: V=1.02, theta=-4.215956 -> V=1.0, theta=0.0
% INFO    : Bus 92581	: V=1.012153, theta=-61.259217 -> V=1.0, theta=0.0
% INFO    : Bus 92582	: V=1.0100492, theta=-61.462912 -> V=1.0, theta=0.0
% INFO    : Bus 92583	: V=1.0171452, theta=-62.978263 -> V=1.0, theta=0.0
% INFO    : Bus 92584	: V=1.0178517, theta=-68.07189 -> V=1.0, theta=0.0
% INFO    : Bus 92585	: V=1.0174997, theta=-68.100556 -> V=1.0, theta=0.0
% INFO    : Bus 92586	: V=1.0174951, theta=-68.065714 -> V=1.0, theta=0.0
% INFO    : Bus 92587	: V=1.0181663, theta=-65.313275 -> V=1.0, theta=0.0
% INFO    : Bus 92588	: V=1.0146338, theta=-66.300333 -> V=1.0, theta=0.0
% INFO    : Bus 92589	: V=1.0136005, theta=-66.593762 -> V=1.0, theta=0.0
% INFO    : Bus 92590	: V=1.0161413, theta=-57.172636 -> V=1.0, theta=0.0
% INFO    : Bus 92591	: V=1.0152731, theta=-57.260169 -> V=1.0, theta=0.0
% INFO    : Bus 92592	: V=1.0110184, theta=-74.880897 -> V=1.0, theta=0.0
% INFO    : Bus 92593	: V=1.0155645, theta=-55.626369 -> V=1.0, theta=0.0
% INFO    : Bus 92594	: V=1.015617, theta=-55.592749 -> V=1.0, theta=0.0
% INFO    : Bus 92595	: V=1.0119452, theta=-60.195843 -> V=1.0, theta=0.0
% INFO    : Bus 92596	: V=1.0102582, theta=-60.256003 -> V=1.0, theta=0.0
% INFO    : Bus 92597	: V=1.015993, theta=-65.55711 -> V=1.0, theta=0.0
% INFO    : Bus 92598	: V=1.0101717, theta=-66.744497 -> V=1.0, theta=0.0
% INFO    : Bus 92599	: V=1.0070741, theta=-67.201013 -> V=1.0, theta=0.0
% INFO    : Bus 92600	: V=1.0187779, theta=-60.50396 -> V=1.0, theta=0.0
% INFO    : Bus 92601	: V=1.0186743, theta=-60.627458 -> V=1.0, theta=0.0
% INFO    : Bus 92602	: V=1.0093717, theta=-68.773251 -> V=1.0, theta=0.0
% INFO    : Bus 92603	: V=1.0068554, theta=-69.295346 -> V=1.0, theta=0.0
% INFO    : Bus 92604	: V=1.0060856, theta=-69.435416 -> V=1.0, theta=0.0
% INFO    : Bus 92605	: V=1.0167157, theta=-67.21132 -> V=1.0, theta=0.0
% INFO    : Bus 92606	: V=1.0163243, theta=-66.170302 -> V=1.0, theta=0.0
% INFO    : Bus 92607	: V=1.0126408, theta=-66.492733 -> V=1.0, theta=0.0
% INFO    : Bus 92608	: V=1.0122561, theta=-66.586124 -> V=1.0, theta=0.0
% INFO    : Bus 92609	: V=1.013326, theta=-55.788831 -> V=1.0, theta=0.0
% INFO    : Bus 92610	: V=1.0131308, theta=-55.812929 -> V=1.0, theta=0.0
% INFO    : Bus 92611	: V=1.014106, theta=-65.53124 -> V=1.0, theta=0.0
% INFO    : Bus 92612	: V=1.0100749, theta=-66.73708 -> V=1.0, theta=0.0
% INFO    : Bus 92613	: V=1.0082178, theta=-67.152587 -> V=1.0, theta=0.0
% INFO    : Bus 92614	: V=1.0154852, theta=-55.223117 -> V=1.0, theta=0.0
% INFO    : Bus 92615	: V=1.0138656, theta=-55.452219 -> V=1.0, theta=0.0
% INFO    : Bus 92616	: V=1.0098268, theta=-68.105272 -> V=1.0, theta=0.0
% INFO    : Bus 92617	: V=1.0149495, theta=-54.335289 -> V=1.0, theta=0.0
% INFO    : Bus 92618	: V=1.0159657, theta=-68.857739 -> V=1.0, theta=0.0
% INFO    : Bus 92619	: V=1.0127544, theta=-69.238544 -> V=1.0, theta=0.0
% INFO    : Bus 92620	: V=1.0122959, theta=-69.290451 -> V=1.0, theta=0.0
% INFO    : Bus 92621	: V=1.014626, theta=-69.703727 -> V=1.0, theta=0.0
% INFO    : Bus 92622	: V=0.9957301, theta=-76.947897 -> V=1.0, theta=0.0
% INFO    : Bus 92623	: V=0.9765833, theta=-80.351513 -> V=1.0, theta=0.0
% INFO    : Bus 92624	: V=1.0093161, theta=-68.179661 -> V=1.0, theta=0.0
% INFO    : Bus 92625	: V=1.0118145, theta=-67.870437 -> V=1.0, theta=0.0
% INFO    : Bus 92626	: V=1.0148604, theta=-67.520686 -> V=1.0, theta=0.0
% INFO    : Bus 92627	: V=1.0096284, theta=-66.898897 -> V=1.0, theta=0.0
% INFO    : Bus 92628	: V=1.0087367, theta=-67.049829 -> V=1.0, theta=0.0
% INFO    : Bus 92629	: V=0.9878641, theta=-73.716774 -> V=1.0, theta=0.0
% INFO    : Bus 92630	: V=0.9973318, theta=-72.319845 -> V=1.0, theta=0.0
% INFO    : Bus 92631	: V=0.9972578, theta=-72.336517 -> V=1.0, theta=0.0
% INFO    : Bus 92632	: V=1.0109618, theta=-56.566692 -> V=1.0, theta=0.0
% INFO    : Bus 92633	: V=1.0025948, theta=-57.567477 -> V=1.0, theta=0.0
% INFO    : Bus 92634	: V=1.0001839, theta=-57.926228 -> V=1.0, theta=0.0
% INFO    : Bus 92635	: V=0.9940579, theta=-74.49821 -> V=1.0, theta=0.0
% INFO    : Bus 92636	: V=1.0201031, theta=-58.085796 -> V=1.0, theta=0.0
% INFO    : Bus 92637	: V=1.0191176, theta=-57.772876 -> V=1.0, theta=0.0
% INFO    : Bus 92638	: V=1.0133324, theta=-57.543826 -> V=1.0, theta=0.0
% INFO    : Bus 92639	: V=1.0101275, theta=-58.033855 -> V=1.0, theta=0.0
% INFO    : Bus 92640	: V=1.018179, theta=-61.930524 -> V=1.0, theta=0.0
% INFO    : Bus 92641	: V=1.0072208, theta=-62.96964 -> V=1.0, theta=0.0
% INFO    : Bus 92642	: V=1.0062494, theta=-63.064759 -> V=1.0, theta=0.0
% INFO    : Bus 92643	: V=1.0214931, theta=-44.935073 -> V=1.0, theta=0.0
% INFO    : Bus 92644	: V=1.0061217, theta=-58.316257 -> V=1.0, theta=0.0
% INFO    : Bus 92645	: V=1.0151148, theta=-57.235898 -> V=1.0, theta=0.0
% INFO    : Bus 92646	: V=1.0143218, theta=-63.89371 -> V=1.0, theta=0.0
% INFO    : Bus 92647	: V=1.0124185, theta=-64.984806 -> V=1.0, theta=0.0
% INFO    : Bus 92648	: V=1.0140283, theta=-64.696268 -> V=1.0, theta=0.0
% INFO    : Bus 92649	: V=1.005255, theta=-68.306023 -> V=1.0, theta=0.0
% INFO    : Bus 92650	: V=0.990316, theta=-70.208969 -> V=1.0, theta=0.0
% INFO    : Bus 92651	: V=0.9873496, theta=-70.661288 -> V=1.0, theta=0.0
% INFO    : Bus 92652	: V=1.0148515, theta=-68.197461 -> V=1.0, theta=0.0
% INFO    : Bus 92653	: V=1.0129377, theta=-68.670388 -> V=1.0, theta=0.0
% INFO    : Bus 92654	: V=1.0148121, theta=-67.767775 -> V=1.0, theta=0.0
% INFO    : Bus 92655	: V=1.02, theta=-42.739099 -> V=1.0, theta=0.0
% INFO    : Bus 92656	: V=0.9780195, theta=-78.036166 -> V=1.0, theta=0.0
% INFO    : Bus 92657	: V=1.0192707, theta=-44.608654 -> V=1.0, theta=0.0
% INFO    : Bus 92658	: V=1.017325, theta=-44.249799 -> V=1.0, theta=0.0
% INFO    : Bus 92659	: V=1.0164382, theta=-44.345839 -> V=1.0, theta=0.0
% INFO    : Bus 92660	: V=1.0157219, theta=-74.614747 -> V=1.0, theta=0.0
% INFO    : Bus 92661	: V=1.0152378, theta=-74.718353 -> V=1.0, theta=0.0
% INFO    : Bus 92662	: V=1.0198137, theta=-44.542664 -> V=1.0, theta=0.0
% INFO    : Bus 92663	: V=1.0133411, theta=-68.322762 -> V=1.0, theta=0.0
% INFO    : Bus 92664	: V=1.02, theta=-56.90979 -> V=1.0, theta=0.0
% INFO    : Bus 92665	: V=1.0087777, theta=-69.130092 -> V=1.0, theta=0.0
% INFO    : Bus 92666	: V=1.0184336, theta=-50.526501 -> V=1.0, theta=0.0
% INFO    : Bus 92667	: V=1.0139805, theta=-49.241506 -> V=1.0, theta=0.0
% INFO    : Bus 92668	: V=1.0196107, theta=-48.378546 -> V=1.0, theta=0.0
% INFO    : Bus 92669	: V=1.0208153, theta=-49.054101 -> V=1.0, theta=0.0
% INFO    : Bus 92670	: V=1.0085766, theta=-61.906434 -> V=1.0, theta=0.0
% INFO    : Bus 92671	: V=1.0047712, theta=-62.34562 -> V=1.0, theta=0.0
% INFO    : Bus 92672	: V=1.0095508, theta=-58.859828 -> V=1.0, theta=0.0
% INFO    : Bus 92673	: V=1.01526, theta=-66.963983 -> V=1.0, theta=0.0
% INFO    : Bus 92674	: V=1.0149476, theta=-67.006974 -> V=1.0, theta=0.0
% INFO    : Bus 92675	: V=1.0076598, theta=-69.667594 -> V=1.0, theta=0.0
% INFO    : Bus 92676	: V=1.0107966, theta=-69.494321 -> V=1.0, theta=0.0
% INFO    : Bus 92677	: V=1.0161582, theta=-61.023394 -> V=1.0, theta=0.0
% INFO    : Bus 92678	: V=1.01443, theta=-67.594671 -> V=1.0, theta=0.0
% INFO    : Bus 92679	: V=1.0087798, theta=-68.429219 -> V=1.0, theta=0.0
% INFO    : Bus 92680	: V=1.0066742, theta=-68.644439 -> V=1.0, theta=0.0
% INFO    : Bus 92681	: V=1.0111561, theta=-75.517841 -> V=1.0, theta=0.0
% INFO    : Bus 92682	: V=1.0089986, theta=-75.719064 -> V=1.0, theta=0.0
% INFO    : Bus 92683	: V=1.0166424, theta=-58.133739 -> V=1.0, theta=0.0
% INFO    : Bus 92684	: V=1.0154606, theta=-58.405626 -> V=1.0, theta=0.0
% INFO    : Bus 92685	: V=1.0023214, theta=-58.998115 -> V=1.0, theta=0.0
% INFO    : Bus 92686	: V=1.0062573, theta=-68.568407 -> V=1.0, theta=0.0
% INFO    : Bus 92687	: V=1.0032896, theta=-68.834967 -> V=1.0, theta=0.0
% INFO    : Bus 92688	: V=1.0111155, theta=-69.078849 -> V=1.0, theta=0.0
% INFO    : Bus 92689	: V=1.0057287, theta=-69.708226 -> V=1.0, theta=0.0
% INFO    : Bus 92690	: V=1.006847, theta=-75.953008 -> V=1.0, theta=0.0
% INFO    : Bus 92691	: V=1.0105338, theta=-75.636863 -> V=1.0, theta=0.0
% INFO    : Bus 92692	: V=1.0119521, theta=-71.313592 -> V=1.0, theta=0.0
% INFO    : Bus 92693	: V=1.0115197, theta=-71.34464 -> V=1.0, theta=0.0
% INFO    : Bus 92694	: V=1.0092062, theta=-59.86919 -> V=1.0, theta=0.0
% INFO    : Bus 92695	: V=1.00899, theta=-59.890489 -> V=1.0, theta=0.0
% INFO    : Bus 92696	: V=1.0178506, theta=-54.822852 -> V=1.0, theta=0.0
% INFO    : Bus 92697	: V=1.0134447, theta=-54.856233 -> V=1.0, theta=0.0
% INFO    : Bus 92698	: V=1.0026399, theta=-75.997661 -> V=1.0, theta=0.0
% INFO    : Bus 92699	: V=0.9965886, theta=-76.808099 -> V=1.0, theta=0.0
% INFO    : Bus 92700	: V=1.0078749, theta=-69.543481 -> V=1.0, theta=0.0
% INFO    : Bus 92701	: V=1.02, theta=-56.457048 -> V=1.0, theta=0.0
% INFO    : Bus 92702	: V=1.0174727, theta=-56.672914 -> V=1.0, theta=0.0
% INFO    : Bus 92703	: V=0.9955957, theta=-68.166226 -> V=1.0, theta=0.0
% INFO    : Bus 92704	: V=0.9922217, theta=-68.907694 -> V=1.0, theta=0.0
% INFO    : Bus 92705	: V=1.0086495, theta=-60.016332 -> V=1.0, theta=0.0
% INFO    : Bus 92706	: V=0.9990792, theta=-62.073427 -> V=1.0, theta=0.0
% INFO    : Bus 92707	: V=0.9968929, theta=-62.511688 -> V=1.0, theta=0.0
% INFO    : Bus 92708	: V=1.0083791, theta=-63.008789 -> V=1.0, theta=0.0
% INFO    : Bus 92709	: V=1.011045, theta=-55.879102 -> V=1.0, theta=0.0
% INFO    : Bus 92710	: V=1.0121784, theta=-68.138119 -> V=1.0, theta=0.0
% INFO    : Bus 92711	: V=1.0093104, theta=-68.573412 -> V=1.0, theta=0.0
% INFO    : Bus 92712	: V=1.0195576, theta=-67.673932 -> V=1.0, theta=0.0
% INFO    : Bus 92713	: V=1.0198246, theta=-55.060761 -> V=1.0, theta=0.0
% INFO    : Bus 92714	: V=1.0171443, theta=-55.490413 -> V=1.0, theta=0.0
% INFO    : Bus 92715	: V=1.0133768, theta=-62.418714 -> V=1.0, theta=0.0
% INFO    : Bus 92716	: V=1.017026, theta=-55.410186 -> V=1.0, theta=0.0
% INFO    : Bus 92717	: V=1.0171505, theta=-55.010084 -> V=1.0, theta=0.0
% INFO    : Bus 92718	: V=1.0063281, theta=-68.491991 -> V=1.0, theta=0.0
% INFO    : Bus 92719	: V=0.9988103, theta=-69.302334 -> V=1.0, theta=0.0
% INFO    : Bus 92720	: V=0.9960819, theta=-69.66555 -> V=1.0, theta=0.0
% INFO    : Bus 92721	: V=1.0105706, theta=-58.462033 -> V=1.0, theta=0.0
% INFO    : Bus 92722	: V=1.012056, theta=-58.294399 -> V=1.0, theta=0.0
% INFO    : Bus 92723	: V=1.0138412, theta=-57.120865 -> V=1.0, theta=0.0
% INFO    : Bus 92724	: V=1.0115598, theta=-57.269017 -> V=1.0, theta=0.0
% INFO    : Bus 92725	: V=1.0191548, theta=-63.268064 -> V=1.0, theta=0.0
% INFO    : Bus 92726	: V=1.0165809, theta=-63.3428 -> V=1.0, theta=0.0
% INFO    : Bus 92727	: V=1.0153139, theta=-56.720825 -> V=1.0, theta=0.0
% INFO    : Bus 92728	: V=1.0136482, theta=-56.63871 -> V=1.0, theta=0.0
% INFO    : Bus 92729	: V=1.0008084, theta=-72.875214 -> V=1.0, theta=0.0
% INFO    : Bus 92730	: V=0.9992074, theta=-72.925758 -> V=1.0, theta=0.0
% INFO    : Bus 92731	: V=1.0219437, theta=-42.525683 -> V=1.0, theta=0.0
% INFO    : Bus 92732	: V=1.0178971, theta=-60.83978 -> V=1.0, theta=0.0
% INFO    : Bus 92733	: V=1.02, theta=-60.896849 -> V=1.0, theta=0.0
% INFO    : Bus 92734	: V=1.0155704, theta=-66.424258 -> V=1.0, theta=0.0
% INFO    : Bus 92735	: V=1.0172013, theta=-66.369025 -> V=1.0, theta=0.0
% INFO    : Bus 92736	: V=1.0196337, theta=-57.574359 -> V=1.0, theta=0.0
% INFO    : Bus 92737	: V=1.0191289, theta=-57.710853 -> V=1.0, theta=0.0
% INFO    : Bus 92738	: V=1.0193366, theta=-52.846203 -> V=1.0, theta=0.0
% INFO    : Bus 92739	: V=1.0107961, theta=-56.995488 -> V=1.0, theta=0.0
% INFO    : Bus 92740	: V=1.0087118, theta=-57.286375 -> V=1.0, theta=0.0
% INFO    : Bus 92741	: V=1.0214524, theta=-50.807843 -> V=1.0, theta=0.0
% INFO    : Bus 92742	: V=1.0095355, theta=-66.735646 -> V=1.0, theta=0.0
% INFO    : Bus 92743	: V=1.012399, theta=-66.372036 -> V=1.0, theta=0.0
% INFO    : Bus 92744	: V=0.9856327, theta=-72.077073 -> V=1.0, theta=0.0
% INFO    : Bus 92745	: V=1.02, theta=-43.057916 -> V=1.0, theta=0.0
% INFO    : Bus 92746	: V=1.02, theta=-56.891737 -> V=1.0, theta=0.0
% INFO    : Bus 92747	: V=1.0189334, theta=-56.975073 -> V=1.0, theta=0.0
% INFO    : Bus 92748	: V=1.02, theta=-58.827506 -> V=1.0, theta=0.0
% INFO    : Bus 92749	: V=1.0091291, theta=-57.623525 -> V=1.0, theta=0.0
% INFO    : Bus 92750	: V=1.0169917, theta=-65.978203 -> V=1.0, theta=0.0
% INFO    : Bus 92751	: V=1.0150544, theta=-65.873209 -> V=1.0, theta=0.0
% INFO    : Bus 92752	: V=1.0090184, theta=-68.393529 -> V=1.0, theta=0.0
% INFO    : Bus 92753	: V=0.9903023, theta=-73.523386 -> V=1.0, theta=0.0
% INFO    : Bus 92754	: V=0.9844387, theta=-74.70818 -> V=1.0, theta=0.0
% INFO    : Bus 92755	: V=0.9843317, theta=-74.732825 -> V=1.0, theta=0.0
% INFO    : Bus 92756	: V=1.0068442, theta=-69.172423 -> V=1.0, theta=0.0
% INFO    : Bus 92757	: V=0.9941169, theta=-70.183362 -> V=1.0, theta=0.0
% INFO    : Bus 92758	: V=1.0120356, theta=-54.235718 -> V=1.0, theta=0.0
% INFO    : Bus 92759	: V=1.0065441, theta=-54.541047 -> V=1.0, theta=0.0
% INFO    : Bus 92760	: V=1.0180389, theta=-59.936031 -> V=1.0, theta=0.0
% INFO    : Bus 92761	: V=1.0175435, theta=-59.994816 -> V=1.0, theta=0.0
% INFO    : Bus 92762	: V=1.0052197, theta=-57.268138 -> V=1.0, theta=0.0
% INFO    : Bus 92763	: V=1.0069604, theta=-69.521925 -> V=1.0, theta=0.0
% INFO    : Bus 92764	: V=0.9994648, theta=-75.64302 -> V=1.0, theta=0.0
% INFO    : Bus 92765	: V=1.018405, theta=-61.739854 -> V=1.0, theta=0.0
% INFO    : Bus 92766	: V=1.0057125, theta=-68.203531 -> V=1.0, theta=0.0
% INFO    : Bus 92767	: V=1.02, theta=-68.640903 -> V=1.0, theta=0.0
% INFO    : Bus 92768	: V=1.02, theta=-44.818941 -> V=1.0, theta=0.0
% INFO    : Bus 92769	: V=0.9942091, theta=-70.802718 -> V=1.0, theta=0.0
% INFO    : Bus 92770	: V=0.9959458, theta=-70.336333 -> V=1.0, theta=0.0
% INFO    : Bus 92771	: V=1.0080929, theta=-69.530803 -> V=1.0, theta=0.0
% INFO    : Bus 92772	: V=1.0184194, theta=-43.014329 -> V=1.0, theta=0.0
% INFO    : Bus 92773	: V=1.0223456, theta=-43.888942 -> V=1.0, theta=0.0
% INFO    : Bus 92774	: V=1.0246188, theta=-44.728571 -> V=1.0, theta=0.0
% INFO    : Bus 92775	: V=1.0260734, theta=-44.862022 -> V=1.0, theta=0.0
% INFO    : Bus 92776	: V=1.0066319, theta=-58.53065 -> V=1.0, theta=0.0
% INFO    : Bus 92777	: V=1.0130238, theta=-64.117387 -> V=1.0, theta=0.0
% INFO    : Bus 92778	: V=1.0130958, theta=-55.9531 -> V=1.0, theta=0.0
% INFO    : Bus 92779	: V=1.0104348, theta=-70.137415 -> V=1.0, theta=0.0
% INFO    : Bus 92780	: V=1.0182954, theta=-71.824887 -> V=1.0, theta=0.0
% INFO    : Bus 92781	: V=0.9861642, theta=-74.480396 -> V=1.0, theta=0.0
% INFO    : Bus 92782	: V=1.0077052, theta=-76.355995 -> V=1.0, theta=0.0
% INFO    : Bus 92783	: V=1.0113416, theta=-75.511592 -> V=1.0, theta=0.0
% INFO    : Bus 92784	: V=1.0051949, theta=-76.283961 -> V=1.0, theta=0.0
% INFO    : Bus 92785	: V=0.9890367, theta=-69.982585 -> V=1.0, theta=0.0
% INFO    : Bus 92786	: V=1.0072214, theta=-69.316527 -> V=1.0, theta=0.0
% INFO    : Bus 92787	: V=1.004974, theta=-69.625343 -> V=1.0, theta=0.0
% INFO    : Bus 92788	: V=1.0035291, theta=-69.804892 -> V=1.0, theta=0.0
% INFO    : Bus 92789	: V=1.0017729, theta=-74.544133 -> V=1.0, theta=0.0
% INFO    : Bus 92790	: V=1.02, theta=-56.275981 -> V=1.0, theta=0.0
% INFO    : Bus 92791	: V=1.0153899, theta=-56.144521 -> V=1.0, theta=0.0
% INFO    : Bus 92792	: V=1.0082079, theta=-69.510802 -> V=1.0, theta=0.0
% INFO    : Bus 92793	: V=1.0157634, theta=-74.695093 -> V=1.0, theta=0.0
% INFO    : Bus 92794	: V=0.980657, theta=-78.726861 -> V=1.0, theta=0.0
% INFO    : Bus 92795	: V=0.9875642, theta=-77.850875 -> V=1.0, theta=0.0
% INFO    : Bus 92796	: V=1.0100015, theta=-55.609239 -> V=1.0, theta=0.0
% INFO    : Bus 92797	: V=1.0100231, theta=-55.866761 -> V=1.0, theta=0.0
% INFO    : Bus 92798	: V=1.0006022, theta=-76.242944 -> V=1.0, theta=0.0
% INFO    : Bus 92799	: V=0.9868306, theta=-77.557153 -> V=1.0, theta=0.0
% INFO    : Bus 92800	: V=1.0175851, theta=-48.024421 -> V=1.0, theta=0.0
% INFO    : Bus 92801	: V=1.0030188, theta=-62.548336 -> V=1.0, theta=0.0
% INFO    : Bus 92802	: V=1.0120481, theta=-71.701766 -> V=1.0, theta=0.0
% INFO    : Bus 92803	: V=1.0122513, theta=-68.128494 -> V=1.0, theta=0.0
% INFO    : Bus 92804	: V=1.02, theta=-68.231883 -> V=1.0, theta=0.0
% INFO    : Bus 92805	: V=1.02, theta=-59.216215 -> V=1.0, theta=0.0
% INFO    : Bus 92806	: V=1.0037972, theta=-76.199838 -> V=1.0, theta=0.0
% INFO    : Bus 92807	: V=0.9502661, theta=-82.311846 -> V=1.0, theta=0.0
% INFO    : Bus 92808	: V=0.990503, theta=-71.854521 -> V=1.0, theta=0.0
% INFO    : Bus 92809	: V=0.9889196, theta=-76.727368 -> V=1.0, theta=0.0
% INFO    : Bus 92810	: V=0.9855418, theta=-67.801913 -> V=1.0, theta=0.0
% INFO    : Bus 92811	: V=0.9897821, theta=-74.882643 -> V=1.0, theta=0.0
% INFO    : Bus 92812	: V=0.9820212, theta=-75.957182 -> V=1.0, theta=0.0
% INFO    : Bus 92813	: V=1.0016997, theta=-59.32218 -> V=1.0, theta=0.0
% INFO    : Bus 92814	: V=1.0186579, theta=-67.704647 -> V=1.0, theta=0.0
% INFO    : Bus 92815	: V=1.0068288, theta=-71.175141 -> V=1.0, theta=0.0
% INFO    : Bus 92816	: V=1.02, theta=-56.986578 -> V=1.0, theta=0.0
% INFO    : Bus 92817	: V=1.0130723, theta=-56.159103 -> V=1.0, theta=0.0
% INFO    : Bus 92818	: V=1.0123464, theta=-56.315797 -> V=1.0, theta=0.0
% INFO    : Bus 92819	: V=1.0017577, theta=-61.071212 -> V=1.0, theta=0.0
% INFO    : Bus 92820	: V=1.001653, theta=-73.469432 -> V=1.0, theta=0.0
% INFO    : Bus 92821	: V=1.0000264, theta=-60.932591 -> V=1.0, theta=0.0
% INFO    : Bus 92822	: V=0.9938885, theta=-62.64442 -> V=1.0, theta=0.0
% INFO    : Bus 92823	: V=1.01826, theta=-55.366526 -> V=1.0, theta=0.0
% INFO    : Bus 92824	: V=1.0133495, theta=-75.546778 -> V=1.0, theta=0.0
% INFO    : Bus 92825	: V=1.0136663, theta=-75.515244 -> V=1.0, theta=0.0
% INFO    : Bus 92826	: V=1.0068955, theta=-69.820229 -> V=1.0, theta=0.0
% INFO    : Bus 92827	: V=1.004359, theta=-70.063519 -> V=1.0, theta=0.0
% INFO    : Bus 92828	: V=1.0028401, theta=-70.319209 -> V=1.0, theta=0.0
% INFO    : Bus 92829	: V=1.0165981, theta=-56.522868 -> V=1.0, theta=0.0
% INFO    : Bus 92830	: V=1.0155785, theta=-57.018537 -> V=1.0, theta=0.0
% INFO    : Bus 92831	: V=1.0090721, theta=-69.490022 -> V=1.0, theta=0.0
% INFO    : Bus 92832	: V=1.0195924, theta=-43.50939 -> V=1.0, theta=0.0
% INFO    : Bus 92833	: V=1.0023171, theta=-67.111937 -> V=1.0, theta=0.0
% INFO    : Bus 92834	: V=1.02, theta=-63.723555 -> V=1.0, theta=0.0
% INFO    : Bus 92835	: V=1.0066433, theta=-60.262935 -> V=1.0, theta=0.0
% INFO    : Bus 92836	: V=1.0084633, theta=-75.698789 -> V=1.0, theta=0.0
% INFO    : Bus 92837	: V=1.0194784, theta=-57.544563 -> V=1.0, theta=0.0
% INFO    : Bus 92838	: V=1.0187841, theta=-57.751649 -> V=1.0, theta=0.0
% INFO    : Bus 92839	: V=1.02, theta=-57.742193 -> V=1.0, theta=0.0
% INFO    : Bus 92840	: V=1.0185139, theta=-66.376971 -> V=1.0, theta=0.0
% INFO    : Bus 92841	: V=1.0105639, theta=-71.126128 -> V=1.0, theta=0.0
% INFO    : Bus 92842	: V=1.0147516, theta=-58.371853 -> V=1.0, theta=0.0
% INFO    : Bus 92843	: V=0.9838556, theta=-64.682542 -> V=1.0, theta=0.0
% INFO    : Bus 92844	: V=0.9791341, theta=-20.077963 -> V=1.0, theta=0.0
% INFO    : Bus 92845	: V=0.9814963, theta=-19.915654 -> V=1.0, theta=0.0
% INFO    : Bus 92846	: V=1.0121259, theta=-7.54961 -> V=1.0, theta=0.0
% INFO    : Bus 92847	: V=1.0125556, theta=-8.468832 -> V=1.0, theta=0.0
% INFO    : Bus 92848	: V=1.012254, theta=-7.155449 -> V=1.0, theta=0.0
% INFO    : Bus 92849	: V=1.0016544, theta=-6.942033 -> V=1.0, theta=0.0
% INFO    : Bus 92850	: V=0.9957889, theta=-7.40369 -> V=1.0, theta=0.0
% INFO    : Bus 92851	: V=0.9880185, theta=-47.315884 -> V=1.0, theta=0.0
% INFO    : Bus 92852	: V=0.9945423, theta=-45.034412 -> V=1.0, theta=0.0
% INFO    : Bus 92853	: V=1.0063143, theta=-44.881479 -> V=1.0, theta=0.0
% INFO    : Bus 92854	: V=0.9796019, theta=-15.62653 -> V=1.0, theta=0.0
% INFO    : Bus 92855	: V=1.008481, theta=-7.757413 -> V=1.0, theta=0.0
% INFO    : Bus 92856	: V=1.0057267, theta=-8.268604 -> V=1.0, theta=0.0
% INFO    : Bus 92857	: V=0.9781214, theta=-36.170431 -> V=1.0, theta=0.0
% INFO    : Bus 92858	: V=0.9703959, theta=-37.615086 -> V=1.0, theta=0.0
% INFO    : Bus 92859	: V=0.9710856, theta=-34.543653 -> V=1.0, theta=0.0
% INFO    : Bus 92860	: V=0.9794667, theta=-36.639119 -> V=1.0, theta=0.0
% INFO    : Bus 92861	: V=0.993382, theta=-24.98281 -> V=1.0, theta=0.0
% INFO    : Bus 92862	: V=0.9903596, theta=-24.979464 -> V=1.0, theta=0.0
% INFO    : Bus 92863	: V=0.983083, theta=-26.307243 -> V=1.0, theta=0.0
% INFO    : Bus 92864	: V=0.9834965, theta=-25.892263 -> V=1.0, theta=0.0
% INFO    : Bus 92865	: V=1.0130782, theta=-19.350589 -> V=1.0, theta=0.0
% INFO    : Bus 92866	: V=0.9948114, theta=-36.01622 -> V=1.0, theta=0.0
% INFO    : Bus 92867	: V=0.9928997, theta=-36.19831 -> V=1.0, theta=0.0
% INFO    : Bus 92868	: V=1.009102, theta=-35.391642 -> V=1.0, theta=0.0
% INFO    : Bus 92869	: V=0.9984416, theta=-37.855853 -> V=1.0, theta=0.0
% INFO    : Bus 92870	: V=0.9991951, theta=-37.94279 -> V=1.0, theta=0.0
% INFO    : Bus 92871	: V=0.9951675, theta=-38.281955 -> V=1.0, theta=0.0
% INFO    : Bus 92872	: V=0.9721643, theta=-19.878771 -> V=1.0, theta=0.0
% INFO    : Bus 92873	: V=0.977216, theta=-20.3293 -> V=1.0, theta=0.0
% INFO    : Bus 92874	: V=0.982598, theta=-20.056229 -> V=1.0, theta=0.0
% INFO    : Bus 92875	: V=0.9800248, theta=-21.684392 -> V=1.0, theta=0.0
% INFO    : Bus 92876	: V=1.0016812, theta=-29.433734 -> V=1.0, theta=0.0
% INFO    : Bus 92877	: V=1.0026591, theta=-13.019177 -> V=1.0, theta=0.0
% INFO    : Bus 92878	: V=1.0077498, theta=-12.879359 -> V=1.0, theta=0.0
% INFO    : Bus 92879	: V=1.0071235, theta=-12.923273 -> V=1.0, theta=0.0
% INFO    : Bus 92880	: V=0.9972179, theta=-12.70939 -> V=1.0, theta=0.0
% INFO    : Bus 92881	: V=0.9930136, theta=-50.243492 -> V=1.0, theta=0.0
% INFO    : Bus 92882	: V=1.000334, theta=-44.464452 -> V=1.0, theta=0.0
% INFO    : Bus 92883	: V=1.0066502, theta=-44.399064 -> V=1.0, theta=0.0
% INFO    : Bus 92884	: V=0.997964, theta=-44.931968 -> V=1.0, theta=0.0
% INFO    : Bus 92885	: V=0.9989609, theta=-51.894033 -> V=1.0, theta=0.0
% INFO    : Bus 92886	: V=0.9721937, theta=-23.188175 -> V=1.0, theta=0.0
% INFO    : Bus 92887	: V=0.9831761, theta=-51.576249 -> V=1.0, theta=0.0
% INFO    : Bus 92888	: V=1.0093123, theta=-54.275587 -> V=1.0, theta=0.0
% INFO    : Bus 92889	: V=1.0140542, theta=-52.563805 -> V=1.0, theta=0.0
% INFO    : Bus 92890	: V=0.9783836, theta=-55.108434 -> V=1.0, theta=0.0
% INFO    : Bus 92891	: V=0.9915639, theta=-28.939181 -> V=1.0, theta=0.0
% INFO    : Bus 92892	: V=0.9934649, theta=-30.813829 -> V=1.0, theta=0.0
% INFO    : Bus 92893	: V=0.9824729, theta=-56.923584 -> V=1.0, theta=0.0
% INFO    : Bus 92894	: V=0.9723536, theta=-46.696406 -> V=1.0, theta=0.0
% INFO    : Bus 92895	: V=0.9991507, theta=-34.882123 -> V=1.0, theta=0.0
% INFO    : Bus 92896	: V=1.0012797, theta=-35.382518 -> V=1.0, theta=0.0
% INFO    : Bus 92897	: V=1.0126475, theta=-49.326155 -> V=1.0, theta=0.0
% INFO    : Bus 92898	: V=1.0063443, theta=-12.347909 -> V=1.0, theta=0.0
% INFO    : Bus 92899	: V=1.0026854, theta=-12.770304 -> V=1.0, theta=0.0
% INFO    : Bus 92900	: V=0.9767949, theta=-10.119116 -> V=1.0, theta=0.0
% INFO    : Bus 92901	: V=0.9749243, theta=-9.98635 -> V=1.0, theta=0.0
% INFO    : Bus 92902	: V=0.9751378, theta=-10.416381 -> V=1.0, theta=0.0
% INFO    : Bus 92903	: V=0.973628, theta=-10.599651 -> V=1.0, theta=0.0
% INFO    : Bus 92904	: V=0.9746606, theta=-10.304661 -> V=1.0, theta=0.0
% INFO    : Bus 92905	: V=0.9817043, theta=-9.674653 -> V=1.0, theta=0.0
% INFO    : Bus 92906	: V=0.9816914, theta=-9.630966 -> V=1.0, theta=0.0
% INFO    : Bus 92907	: V=0.9730844, theta=-10.819585 -> V=1.0, theta=0.0
% INFO    : Bus 92908	: V=0.9758327, theta=-11.042461 -> V=1.0, theta=0.0
% INFO    : Bus 92909	: V=0.990372, theta=-11.666221 -> V=1.0, theta=0.0
% INFO    : Bus 92910	: V=0.9842942, theta=-11.428223 -> V=1.0, theta=0.0
% INFO    : Bus 92911	: V=0.9717149, theta=-11.168755 -> V=1.0, theta=0.0
% INFO    : Bus 92912	: V=0.9766831, theta=-11.330675 -> V=1.0, theta=0.0
% INFO    : Bus 92913	: V=0.9717468, theta=-11.089994 -> V=1.0, theta=0.0
% INFO    : Bus 92914	: V=0.9720941, theta=-10.891614 -> V=1.0, theta=0.0
% INFO    : Bus 92915	: V=0.9759064, theta=-10.828638 -> V=1.0, theta=0.0
% INFO    : Bus 92916	: V=0.9765737, theta=-10.831842 -> V=1.0, theta=0.0
% INFO    : Bus 92917	: V=0.9805839, theta=-10.636764 -> V=1.0, theta=0.0
% INFO    : Bus 92918	: V=0.9782287, theta=-10.842416 -> V=1.0, theta=0.0
% INFO    : Bus 92919	: V=0.9762737, theta=-11.014485 -> V=1.0, theta=0.0
% INFO    : Bus 92920	: V=0.9787739, theta=-11.126018 -> V=1.0, theta=0.0
% INFO    : Bus 92921	: V=0.9819926, theta=-11.333541 -> V=1.0, theta=0.0
% INFO    : Bus 92922	: V=0.978077, theta=-11.307508 -> V=1.0, theta=0.0
% INFO    : Bus 92923	: V=0.9848461, theta=-11.392954 -> V=1.0, theta=0.0
% INFO    : Bus 92924	: V=1.0034058, theta=-11.386015 -> V=1.0, theta=0.0
% INFO    : Bus 92925	: V=0.9984035, theta=-11.535554 -> V=1.0, theta=0.0
% INFO    : Bus 92926	: V=0.992063, theta=-10.190798 -> V=1.0, theta=0.0
% INFO    : Bus 92927	: V=0.993334, theta=-10.260757 -> V=1.0, theta=0.0
% INFO    : Bus 92928	: V=0.9733516, theta=-10.901087 -> V=1.0, theta=0.0
% INFO    : Bus 92929	: V=0.9955741, theta=-51.489602 -> V=1.0, theta=0.0
% INFO    : Bus 92930	: V=0.9829917, theta=-26.089668 -> V=1.0, theta=0.0
% INFO    : Bus 92931	: V=0.9823513, theta=-26.203374 -> V=1.0, theta=0.0
% INFO    : Bus 92932	: V=0.9852983, theta=-29.182484 -> V=1.0, theta=0.0
% INFO    : Bus 92933	: V=0.982511, theta=-26.301875 -> V=1.0, theta=0.0
% INFO    : Bus 92934	: V=1.0028429, theta=-7.89533 -> V=1.0, theta=0.0
% INFO    : Bus 92935	: V=0.9946382, theta=-7.630221 -> V=1.0, theta=0.0
% INFO    : Bus 92936	: V=1.0105125, theta=-7.770863 -> V=1.0, theta=0.0
% INFO    : Bus 92937	: V=0.9907217, theta=-10.523165 -> V=1.0, theta=0.0
% INFO    : Bus 92938	: V=0.9975478, theta=-10.876227 -> V=1.0, theta=0.0
% INFO    : Bus 92939	: V=0.9963711, theta=-11.178833 -> V=1.0, theta=0.0
% INFO    : Bus 92940	: V=1.0021725, theta=-6.723593 -> V=1.0, theta=0.0
% INFO    : Bus 92941	: V=1.0120821, theta=-33.552297 -> V=1.0, theta=0.0
% INFO    : Bus 92942	: V=0.9962556, theta=-13.64094 -> V=1.0, theta=0.0
% INFO    : Bus 92943	: V=0.9765471, theta=-51.795262 -> V=1.0, theta=0.0
% INFO    : Bus 92944	: V=0.9910754, theta=-22.659772 -> V=1.0, theta=0.0
% INFO    : Bus 92945	: V=0.9998971, theta=-20.486563 -> V=1.0, theta=0.0
% INFO    : Bus 92946	: V=0.9994958, theta=-23.358536 -> V=1.0, theta=0.0
% INFO    : Bus 92947	: V=0.9962348, theta=-34.280638 -> V=1.0, theta=0.0
% INFO    : Bus 92948	: V=1.0079206, theta=-33.777268 -> V=1.0, theta=0.0
% INFO    : Bus 92949	: V=1.0028661, theta=-34.033298 -> V=1.0, theta=0.0
% INFO    : Bus 92950	: V=0.9804121, theta=-28.675302 -> V=1.0, theta=0.0
% INFO    : Bus 92951	: V=0.9843168, theta=-30.852743 -> V=1.0, theta=0.0
% INFO    : Bus 92952	: V=1.0036767, theta=-20.027052 -> V=1.0, theta=0.0
% INFO    : Bus 92953	: V=1.0017602, theta=-19.961136 -> V=1.0, theta=0.0
% INFO    : Bus 92954	: V=0.9993016, theta=-55.088148 -> V=1.0, theta=0.0
% INFO    : Bus 92955	: V=1.0090682, theta=-54.051133 -> V=1.0, theta=0.0
% INFO    : Bus 92956	: V=1.0111332, theta=-8.514878 -> V=1.0, theta=0.0
% INFO    : Bus 92957	: V=1.0085467, theta=-9.080726 -> V=1.0, theta=0.0
% INFO    : Bus 92958	: V=1.0093886, theta=-12.390305 -> V=1.0, theta=0.0
% INFO    : Bus 92959	: V=1.0019864, theta=-36.065459 -> V=1.0, theta=0.0
% INFO    : Bus 92960	: V=0.9727395, theta=-31.753771 -> V=1.0, theta=0.0
% INFO    : Bus 92961	: V=0.9693418, theta=-33.319971 -> V=1.0, theta=0.0
% INFO    : Bus 92962	: V=0.9698898, theta=-33.341706 -> V=1.0, theta=0.0
% INFO    : Bus 92963	: V=0.9825116, theta=-33.92337 -> V=1.0, theta=0.0
% INFO    : Bus 92964	: V=0.9666555, theta=-34.645894 -> V=1.0, theta=0.0
% INFO    : Bus 92965	: V=0.9994193, theta=-13.852368 -> V=1.0, theta=0.0
% INFO    : Bus 92966	: V=0.9869016, theta=-21.085966 -> V=1.0, theta=0.0
% INFO    : Bus 92967	: V=0.9862785, theta=-20.804394 -> V=1.0, theta=0.0
% INFO    : Bus 92968	: V=0.9885806, theta=-21.374197 -> V=1.0, theta=0.0
% INFO    : Bus 92969	: V=0.9942503, theta=-23.802951 -> V=1.0, theta=0.0
% INFO    : Bus 92970	: V=0.9979081, theta=-44.993753 -> V=1.0, theta=0.0
% INFO    : Bus 92971	: V=0.9967701, theta=-18.780698 -> V=1.0, theta=0.0
% INFO    : Bus 92972	: V=0.9982344, theta=-39.887548 -> V=1.0, theta=0.0
% INFO    : Bus 92973	: V=0.9825297, theta=-33.000332 -> V=1.0, theta=0.0
% INFO    : Bus 92974	: V=1.000313, theta=-43.297868 -> V=1.0, theta=0.0
% INFO    : Bus 92975	: V=0.9903101, theta=-19.29407 -> V=1.0, theta=0.0
% INFO    : Bus 92976	: V=1.0116928, theta=-17.434866 -> V=1.0, theta=0.0
% INFO    : Bus 92977	: V=0.9818623, theta=-47.973562 -> V=1.0, theta=0.0
% INFO    : Bus 92978	: V=1.0062769, theta=-36.279056 -> V=1.0, theta=0.0
% INFO    : Bus 92979	: V=1.0036668, theta=-36.403679 -> V=1.0, theta=0.0
% INFO    : Bus 92980	: V=1.0152686, theta=-35.576008 -> V=1.0, theta=0.0
% INFO    : Bus 92981	: V=1.0060965, theta=-36.285928 -> V=1.0, theta=0.0
% INFO    : Bus 92982	: V=1.004924, theta=-37.33098 -> V=1.0, theta=0.0
% INFO    : Bus 92983	: V=0.999504, theta=-37.529476 -> V=1.0, theta=0.0
% INFO    : Bus 92984	: V=1.0027246, theta=-37.42014 -> V=1.0, theta=0.0
% INFO    : Bus 92985	: V=0.9729204, theta=-21.570288 -> V=1.0, theta=0.0
% INFO    : Bus 92986	: V=0.9813762, theta=-20.359453 -> V=1.0, theta=0.0
% INFO    : Bus 92987	: V=0.9728099, theta=-21.516774 -> V=1.0, theta=0.0
% INFO    : Bus 92988	: V=0.9760968, theta=-23.28354 -> V=1.0, theta=0.0
% INFO    : Bus 92989	: V=0.9866929, theta=-47.058622 -> V=1.0, theta=0.0
% INFO    : Bus 92990	: V=1.0094568, theta=-40.930732 -> V=1.0, theta=0.0
% INFO    : Bus 92991	: V=1.0068307, theta=-41.039784 -> V=1.0, theta=0.0
% INFO    : Bus 92992	: V=1.0052335, theta=-40.502555 -> V=1.0, theta=0.0
% INFO    : Bus 92993	: V=0.9929957, theta=-30.954153 -> V=1.0, theta=0.0
% INFO    : Bus 92994	: V=0.9807694, theta=-31.249937 -> V=1.0, theta=0.0
% INFO    : Bus 92995	: V=1.0035746, theta=-32.522767 -> V=1.0, theta=0.0
% INFO    : Bus 92996	: V=0.9986806, theta=-32.550366 -> V=1.0, theta=0.0
% INFO    : Bus 92997	: V=1.0104743, theta=-51.028075 -> V=1.0, theta=0.0
% INFO    : Bus 92998	: V=0.9735327, theta=-39.325723 -> V=1.0, theta=0.0
% INFO    : Bus 92999	: V=0.9726256, theta=-39.419995 -> V=1.0, theta=0.0
% INFO    : Bus 93000	: V=0.968979, theta=-39.671512 -> V=1.0, theta=0.0
% INFO    : Bus 93001	: V=0.9755117, theta=-39.494257 -> V=1.0, theta=0.0
% INFO    : Bus 93002	: V=0.9728861, theta=-39.517632 -> V=1.0, theta=0.0
% INFO    : Bus 93003	: V=0.9791808, theta=-39.825926 -> V=1.0, theta=0.0
% INFO    : Bus 93004	: V=0.9676954, theta=-39.635349 -> V=1.0, theta=0.0
% INFO    : Bus 93005	: V=0.9702144, theta=-39.162609 -> V=1.0, theta=0.0
% INFO    : Bus 93006	: V=0.965161, theta=-39.717438 -> V=1.0, theta=0.0
% INFO    : Bus 93007	: V=0.9856517, theta=-38.602323 -> V=1.0, theta=0.0
% INFO    : Bus 93008	: V=0.9837265, theta=-38.737949 -> V=1.0, theta=0.0
% INFO    : Bus 93009	: V=0.9784338, theta=-39.129888 -> V=1.0, theta=0.0
% INFO    : Bus 93010	: V=0.9791253, theta=-39.232586 -> V=1.0, theta=0.0
% INFO    : Bus 93011	: V=0.9819063, theta=-39.384332 -> V=1.0, theta=0.0
% INFO    : Bus 93012	: V=0.9822786, theta=-38.847709 -> V=1.0, theta=0.0
% INFO    : Bus 93013	: V=0.9853154, theta=-38.598897 -> V=1.0, theta=0.0
% INFO    : Bus 93014	: V=0.9912585, theta=-38.558255 -> V=1.0, theta=0.0
% INFO    : Bus 93015	: V=0.9917615, theta=-39.102417 -> V=1.0, theta=0.0
% INFO    : Bus 93016	: V=0.9650075, theta=-40.220515 -> V=1.0, theta=0.0
% INFO    : Bus 93017	: V=0.9702261, theta=-38.74004 -> V=1.0, theta=0.0
% INFO    : Bus 93018	: V=0.9683834, theta=-39.417342 -> V=1.0, theta=0.0
% INFO    : Bus 93019	: V=0.9772459, theta=-39.066363 -> V=1.0, theta=0.0
% INFO    : Bus 93020	: V=0.989934, theta=-38.108376 -> V=1.0, theta=0.0
% INFO    : Bus 93021	: V=0.9975021, theta=-57.1314 -> V=1.0, theta=0.0
% INFO    : Bus 93022	: V=0.9747004, theta=-58.240072 -> V=1.0, theta=0.0
% INFO    : Bus 93023	: V=0.989991, theta=-15.781569 -> V=1.0, theta=0.0
% INFO    : Bus 93024	: V=0.9900398, theta=-15.756103 -> V=1.0, theta=0.0
% INFO    : Bus 93025	: V=0.9937365, theta=-15.574514 -> V=1.0, theta=0.0
% INFO    : Bus 93026	: V=0.9917023, theta=-15.945303 -> V=1.0, theta=0.0
% INFO    : Bus 93027	: V=0.9785305, theta=-48.956496 -> V=1.0, theta=0.0
% INFO    : Bus 93028	: V=0.9676222, theta=-52.935561 -> V=1.0, theta=0.0
% INFO    : Bus 93029	: V=1.0134961, theta=-37.763467 -> V=1.0, theta=0.0
% INFO    : Bus 93030	: V=0.9800331, theta=-44.294532 -> V=1.0, theta=0.0
% INFO    : Bus 93031	: V=0.9981375, theta=-56.240593 -> V=1.0, theta=0.0
% INFO    : Bus 93032	: V=0.9943136, theta=-56.668924 -> V=1.0, theta=0.0
% INFO    : Bus 93033	: V=0.9895949, theta=-41.852873 -> V=1.0, theta=0.0
% INFO    : Bus 93034	: V=0.9684746, theta=-51.572805 -> V=1.0, theta=0.0
% INFO    : Bus 93035	: V=0.9867325, theta=-47.230981 -> V=1.0, theta=0.0
% INFO    : Bus 93036	: V=0.9955799, theta=-24.762382 -> V=1.0, theta=0.0
% INFO    : Bus 93037	: V=0.9964103, theta=-25.081728 -> V=1.0, theta=0.0
% INFO    : Bus 93038	: V=0.9798854, theta=-23.183786 -> V=1.0, theta=0.0
% INFO    : Bus 93039	: V=0.9778701, theta=-23.773633 -> V=1.0, theta=0.0
% INFO    : Bus 93040	: V=0.9754625, theta=-27.240538 -> V=1.0, theta=0.0
% INFO    : Bus 93041	: V=0.9911725, theta=-22.556899 -> V=1.0, theta=0.0
% INFO    : Bus 93042	: V=0.9950782, theta=-8.426047 -> V=1.0, theta=0.0
% INFO    : Bus 93043	: V=0.9979192, theta=-8.224155 -> V=1.0, theta=0.0
% INFO    : Bus 93044	: V=0.9938387, theta=-8.553613 -> V=1.0, theta=0.0
% INFO    : Bus 93045	: V=0.9928577, theta=-8.663173 -> V=1.0, theta=0.0
% INFO    : Bus 93046	: V=0.9927827, theta=-8.637184 -> V=1.0, theta=0.0
% INFO    : Bus 93047	: V=0.9923383, theta=-8.610297 -> V=1.0, theta=0.0
% INFO    : Bus 93048	: V=0.9877538, theta=-8.86412 -> V=1.0, theta=0.0
% INFO    : Bus 93049	: V=0.9881858, theta=-8.850413 -> V=1.0, theta=0.0
% INFO    : Bus 93050	: V=0.9849064, theta=-9.337776 -> V=1.0, theta=0.0
% INFO    : Bus 93051	: V=0.9941339, theta=-8.60477 -> V=1.0, theta=0.0
% INFO    : Bus 93052	: V=0.9880899, theta=-9.183251 -> V=1.0, theta=0.0
% INFO    : Bus 93053	: V=0.9839072, theta=-9.827169 -> V=1.0, theta=0.0
% INFO    : Bus 93054	: V=0.9897521, theta=-9.287762 -> V=1.0, theta=0.0
% INFO    : Bus 93055	: V=0.990005, theta=-9.236041 -> V=1.0, theta=0.0
% INFO    : Bus 93056	: V=0.993092, theta=-9.028197 -> V=1.0, theta=0.0
% INFO    : Bus 93057	: V=0.9814858, theta=-10.037926 -> V=1.0, theta=0.0
% INFO    : Bus 93058	: V=0.9789447, theta=-10.308801 -> V=1.0, theta=0.0
% INFO    : Bus 93059	: V=0.9814366, theta=-9.52345 -> V=1.0, theta=0.0
% INFO    : Bus 93060	: V=1.0117485, theta=-34.400125 -> V=1.0, theta=0.0
% INFO    : Bus 93061	: V=1.0158592, theta=-34.133306 -> V=1.0, theta=0.0
% INFO    : Bus 93062	: V=1.0176907, theta=-34.432376 -> V=1.0, theta=0.0
% INFO    : Bus 93063	: V=0.977954, theta=-30.559942 -> V=1.0, theta=0.0
% INFO    : Bus 93064	: V=1.0145018, theta=-31.994782 -> V=1.0, theta=0.0
% INFO    : Bus 93065	: V=1.0018988, theta=-32.613743 -> V=1.0, theta=0.0
% INFO    : Bus 93066	: V=1.0064804, theta=-33.270037 -> V=1.0, theta=0.0
% INFO    : Bus 93067	: V=1.0099229, theta=-34.350312 -> V=1.0, theta=0.0
% INFO    : Bus 93068	: V=1.0132106, theta=-37.296306 -> V=1.0, theta=0.0
% INFO    : Bus 93069	: V=1.0097042, theta=-37.289004 -> V=1.0, theta=0.0
% INFO    : Bus 93070	: V=0.9820344, theta=2.770573 -> V=1.0, theta=0.0
% INFO    : Bus 93071	: V=0.9819619, theta=3.92691 -> V=1.0, theta=0.0
% INFO    : Bus 93072	: V=0.982984, theta=-12.935576 -> V=1.0, theta=0.0
% INFO    : Bus 93073	: V=1.0141958, theta=-16.744774 -> V=1.0, theta=0.0
% INFO    : Bus 93074	: V=1.0132715, theta=-16.178133 -> V=1.0, theta=0.0
% INFO    : Bus 93075	: V=0.9822068, theta=-41.551094 -> V=1.0, theta=0.0
% INFO    : Bus 93076	: V=1.0133538, theta=-33.464599 -> V=1.0, theta=0.0
% INFO    : Bus 93077	: V=1.0108318, theta=-33.627925 -> V=1.0, theta=0.0
% INFO    : Bus 93078	: V=0.9755042, theta=-4.7201 -> V=1.0, theta=0.0
% INFO    : Bus 93079	: V=0.9690955, theta=-5.241538 -> V=1.0, theta=0.0
% INFO    : Bus 93080	: V=0.9788297, theta=1.618243 -> V=1.0, theta=0.0
% INFO    : Bus 93081	: V=1.0298984, theta=-28.965206 -> V=1.0, theta=0.0
% INFO    : Bus 93082	: V=1.0283661, theta=-29.477385 -> V=1.0, theta=0.0
% INFO    : Bus 93083	: V=1.0286322, theta=-31.903716 -> V=1.0, theta=0.0
% INFO    : Bus 93084	: V=0.9902706, theta=-20.645576 -> V=1.0, theta=0.0
% INFO    : Bus 93085	: V=1.0124564, theta=-42.192922 -> V=1.0, theta=0.0
% INFO    : Bus 93086	: V=1.0152489, theta=-43.056798 -> V=1.0, theta=0.0
% INFO    : Bus 93087	: V=1.0125582, theta=-42.645875 -> V=1.0, theta=0.0
% INFO    : Bus 93088	: V=0.9779187, theta=1.287437 -> V=1.0, theta=0.0
% INFO    : Bus 93089	: V=0.9924185, theta=2.285432 -> V=1.0, theta=0.0
% INFO    : Bus 93090	: V=0.997354, theta=2.063552 -> V=1.0, theta=0.0
% INFO    : Bus 93091	: V=0.9970236, theta=1.70706 -> V=1.0, theta=0.0
% INFO    : Bus 93092	: V=1.0017778, theta=4.403772 -> V=1.0, theta=0.0
% INFO    : Bus 93093	: V=0.9952265, theta=3.950203 -> V=1.0, theta=0.0
% INFO    : Bus 93094	: V=0.9930256, theta=3.785397 -> V=1.0, theta=0.0
% INFO    : Bus 93095	: V=0.9922505, theta=3.587098 -> V=1.0, theta=0.0
% INFO    : Bus 93096	: V=0.9951908, theta=3.823884 -> V=1.0, theta=0.0
% INFO    : Bus 93097	: V=0.9931966, theta=3.69827 -> V=1.0, theta=0.0
% INFO    : Bus 93098	: V=1.0064858, theta=4.105833 -> V=1.0, theta=0.0
% INFO    : Bus 93099	: V=0.9999471, theta=3.787313 -> V=1.0, theta=0.0
% INFO    : Bus 93100	: V=0.9984654, theta=3.743267 -> V=1.0, theta=0.0
% INFO    : Bus 93101	: V=0.9886015, theta=3.467072 -> V=1.0, theta=0.0
% INFO    : Bus 93102	: V=0.9903974, theta=3.552652 -> V=1.0, theta=0.0
% INFO    : Bus 93103	: V=0.9903264, theta=3.673812 -> V=1.0, theta=0.0
% INFO    : Bus 93104	: V=0.992117, theta=3.776493 -> V=1.0, theta=0.0
% INFO    : Bus 93105	: V=0.9917677, theta=3.720305 -> V=1.0, theta=0.0
% INFO    : Bus 93106	: V=0.9895302, theta=3.596674 -> V=1.0, theta=0.0
% INFO    : Bus 93107	: V=0.9841861, theta=2.977733 -> V=1.0, theta=0.0
% INFO    : Bus 93108	: V=0.9844223, theta=2.823218 -> V=1.0, theta=0.0
% INFO    : Bus 93109	: V=0.986582, theta=3.210576 -> V=1.0, theta=0.0
% INFO    : Bus 93110	: V=0.9883734, theta=3.206011 -> V=1.0, theta=0.0
% INFO    : Bus 93111	: V=0.9896083, theta=3.097038 -> V=1.0, theta=0.0
% INFO    : Bus 93112	: V=0.987189, theta=3.447462 -> V=1.0, theta=0.0
% INFO    : Bus 93113	: V=0.9892343, theta=3.574518 -> V=1.0, theta=0.0
% INFO    : Bus 93114	: V=0.9909293, theta=3.665081 -> V=1.0, theta=0.0
% INFO    : Bus 93115	: V=0.9851302, theta=3.283941 -> V=1.0, theta=0.0
% INFO    : Bus 93116	: V=0.9904899, theta=3.710268 -> V=1.0, theta=0.0
% INFO    : Bus 93117	: V=0.9867649, theta=3.405241 -> V=1.0, theta=0.0
% INFO    : Bus 93118	: V=0.9759684, theta=2.613647 -> V=1.0, theta=0.0
% INFO    : Bus 93119	: V=0.9821919, theta=2.895918 -> V=1.0, theta=0.0
% INFO    : Bus 93120	: V=0.9859586, theta=2.735372 -> V=1.0, theta=0.0
% INFO    : Bus 93121	: V=0.9807932, theta=2.402026 -> V=1.0, theta=0.0
% INFO    : Bus 93122	: V=0.9870573, theta=3.405709 -> V=1.0, theta=0.0
% INFO    : Bus 93123	: V=0.9843958, theta=3.220462 -> V=1.0, theta=0.0
% INFO    : Bus 93124	: V=0.9807689, theta=2.926395 -> V=1.0, theta=0.0
% INFO    : Bus 93125	: V=0.9846046, theta=3.212512 -> V=1.0, theta=0.0
% INFO    : Bus 93126	: V=0.9882067, theta=2.995157 -> V=1.0, theta=0.0
% INFO    : Bus 93127	: V=0.9751179, theta=2.145622 -> V=1.0, theta=0.0
% INFO    : Bus 93128	: V=0.9888388, theta=3.016556 -> V=1.0, theta=0.0
% INFO    : Bus 93129	: V=1.0227151, theta=-40.69159 -> V=1.0, theta=0.0
% INFO    : Bus 93130	: V=1.0004403, theta=-19.964278 -> V=1.0, theta=0.0
% INFO    : Bus 93131	: V=0.9981669, theta=-19.669364 -> V=1.0, theta=0.0
% INFO    : Bus 93132	: V=1.0096971, theta=-32.68338 -> V=1.0, theta=0.0
% INFO    : Bus 93133	: V=1.0140678, theta=-30.354693 -> V=1.0, theta=0.0
% INFO    : Bus 93134	: V=1.0153072, theta=-30.71048 -> V=1.0, theta=0.0
% INFO    : Bus 93135	: V=1.0027326, theta=-30.063166 -> V=1.0, theta=0.0
% INFO    : Bus 93136	: V=1.0171696, theta=-40.232842 -> V=1.0, theta=0.0
% INFO    : Bus 93137	: V=0.9970401, theta=-45.146786 -> V=1.0, theta=0.0
% INFO    : Bus 93138	: V=0.9952739, theta=-44.988457 -> V=1.0, theta=0.0
% INFO    : Bus 93139	: V=1.0066709, theta=-10.750967 -> V=1.0, theta=0.0
% INFO    : Bus 93140	: V=1.0017885, theta=-8.481332 -> V=1.0, theta=0.0
% INFO    : Bus 93141	: V=1.0212639, theta=-33.607962 -> V=1.0, theta=0.0
% INFO    : Bus 93142	: V=1.0148725, theta=-37.403285 -> V=1.0, theta=0.0
% INFO    : Bus 93143	: V=1.0163082, theta=-38.472686 -> V=1.0, theta=0.0
% INFO    : Bus 93144	: V=1.0149536, theta=-38.601537 -> V=1.0, theta=0.0
% INFO    : Bus 93145	: V=0.9884243, theta=-11.844906 -> V=1.0, theta=0.0
% INFO    : Bus 93146	: V=0.9927849, theta=-12.817435 -> V=1.0, theta=0.0
% INFO    : Bus 93147	: V=0.9946867, theta=-12.592014 -> V=1.0, theta=0.0
% INFO    : Bus 93148	: V=0.9928226, theta=-12.808241 -> V=1.0, theta=0.0
% INFO    : Bus 93149	: V=0.9878861, theta=-11.904927 -> V=1.0, theta=0.0
% INFO    : Bus 93150	: V=0.9955057, theta=-12.444844 -> V=1.0, theta=0.0
% INFO    : Bus 93151	: V=0.9919504, theta=-13.305785 -> V=1.0, theta=0.0
% INFO    : Bus 93152	: V=0.9930713, theta=-13.19981 -> V=1.0, theta=0.0
% INFO    : Bus 93153	: V=0.9901131, theta=-13.618855 -> V=1.0, theta=0.0
% INFO    : Bus 93154	: V=0.994208, theta=-12.922486 -> V=1.0, theta=0.0
% INFO    : Bus 93155	: V=0.9944977, theta=-12.821081 -> V=1.0, theta=0.0
% INFO    : Bus 93156	: V=0.9907059, theta=-13.363506 -> V=1.0, theta=0.0
% INFO    : Bus 93157	: V=0.9880656, theta=-13.605168 -> V=1.0, theta=0.0
% INFO    : Bus 93158	: V=0.9895556, theta=-13.474446 -> V=1.0, theta=0.0
% INFO    : Bus 93159	: V=0.9993787, theta=-12.499105 -> V=1.0, theta=0.0
% INFO    : Bus 93160	: V=1.0036063, theta=-12.43062 -> V=1.0, theta=0.0
% INFO    : Bus 93161	: V=1.0004434, theta=-12.481937 -> V=1.0, theta=0.0
% INFO    : Bus 93162	: V=0.9920676, theta=-11.90694 -> V=1.0, theta=0.0
% INFO    : Bus 93163	: V=0.9996217, theta=-11.784229 -> V=1.0, theta=0.0
% INFO    : Bus 93164	: V=1.0003875, theta=-11.709324 -> V=1.0, theta=0.0
% INFO    : Bus 93165	: V=0.9974615, theta=-12.271276 -> V=1.0, theta=0.0
% INFO    : Bus 93166	: V=0.9992969, theta=-12.431427 -> V=1.0, theta=0.0
% INFO    : Bus 93167	: V=1.0007058, theta=-10.70043 -> V=1.0, theta=0.0
% INFO    : Bus 93168	: V=0.9844917, theta=-11.269487 -> V=1.0, theta=0.0
% INFO    : Bus 93169	: V=1.0009058, theta=-40.414246 -> V=1.0, theta=0.0
% INFO    : Bus 93170	: V=1.0033167, theta=-40.78197 -> V=1.0, theta=0.0
% INFO    : Bus 93171	: V=1.0091937, theta=-41.192334 -> V=1.0, theta=0.0
% INFO    : Bus 93172	: V=0.9869229, theta=-1.021934 -> V=1.0, theta=0.0
% INFO    : Bus 93173	: V=0.9922277, theta=0.008667 -> V=1.0, theta=0.0
% INFO    : Bus 93174	: V=0.9914275, theta=-0.482577 -> V=1.0, theta=0.0
% INFO    : Bus 93175	: V=0.9857072, theta=-5.333118 -> V=1.0, theta=0.0
% INFO    : Bus 93176	: V=1.0068582, theta=-6.7235 -> V=1.0, theta=0.0
% INFO    : Bus 93177	: V=0.9996529, theta=-6.651032 -> V=1.0, theta=0.0
% INFO    : Bus 93178	: V=1.0079287, theta=-32.813316 -> V=1.0, theta=0.0
% INFO    : Bus 93179	: V=1.0146917, theta=-1.182677 -> V=1.0, theta=0.0
% INFO    : Bus 93180	: V=1.0101701, theta=-1.217558 -> V=1.0, theta=0.0
% INFO    : Bus 93181	: V=1.0148969, theta=-1.169776 -> V=1.0, theta=0.0
% INFO    : Bus 93182	: V=1.0035336, theta=-41.659901 -> V=1.0, theta=0.0
% INFO    : Bus 93183	: V=0.9991674, theta=-42.375229 -> V=1.0, theta=0.0
% INFO    : Bus 93184	: V=0.9925823, theta=-11.472262 -> V=1.0, theta=0.0
% INFO    : Bus 93185	: V=0.9923144, theta=-11.359328 -> V=1.0, theta=0.0
% INFO    : Bus 93186	: V=0.9933888, theta=-11.646903 -> V=1.0, theta=0.0
% INFO    : Bus 93187	: V=0.9917168, theta=-11.402253 -> V=1.0, theta=0.0
% INFO    : Bus 93188	: V=0.98948, theta=-11.855347 -> V=1.0, theta=0.0
% INFO    : Bus 93189	: V=0.9934403, theta=-46.656554 -> V=1.0, theta=0.0
% INFO    : Bus 93190	: V=1.0103646, theta=-6.729592 -> V=1.0, theta=0.0
% INFO    : Bus 93191	: V=0.9983912, theta=-17.286254 -> V=1.0, theta=0.0
% INFO    : Bus 93192	: V=1.0055366, theta=-18.83966 -> V=1.0, theta=0.0
% INFO    : Bus 93193	: V=1.0010128, theta=3.771789 -> V=1.0, theta=0.0
% INFO    : Bus 93194	: V=0.9966051, theta=3.345832 -> V=1.0, theta=0.0
% INFO    : Bus 93195	: V=0.9968854, theta=3.302119 -> V=1.0, theta=0.0
% INFO    : Bus 93196	: V=1.0028542, theta=3.600601 -> V=1.0, theta=0.0
% INFO    : Bus 93197	: V=0.9965407, theta=3.253415 -> V=1.0, theta=0.0
% INFO    : Bus 93198	: V=0.9958836, theta=3.404095 -> V=1.0, theta=0.0
% INFO    : Bus 93199	: V=0.9984, theta=3.562137 -> V=1.0, theta=0.0
% INFO    : Bus 93200	: V=0.9933364, theta=3.289466 -> V=1.0, theta=0.0
% INFO    : Bus 93201	: V=0.985985, theta=2.856524 -> V=1.0, theta=0.0
% INFO    : Bus 93202	: V=0.9686221, theta=1.268024 -> V=1.0, theta=0.0
% INFO    : Bus 93203	: V=0.9714151, theta=-2.872068 -> V=1.0, theta=0.0
% INFO    : Bus 93204	: V=0.9639746, theta=-0.349527 -> V=1.0, theta=0.0
% INFO    : Bus 93205	: V=0.9780956, theta=-4.428626 -> V=1.0, theta=0.0
% INFO    : Bus 93206	: V=0.9735814, theta=-38.988021 -> V=1.0, theta=0.0
% INFO    : Bus 93207	: V=0.9872968, theta=-17.699657 -> V=1.0, theta=0.0
% INFO    : Bus 93208	: V=1.0015085, theta=-22.133647 -> V=1.0, theta=0.0
% INFO    : Bus 93209	: V=0.9863287, theta=-26.121489 -> V=1.0, theta=0.0
% INFO    : Bus 93210	: V=0.9760005, theta=-2.287141 -> V=1.0, theta=0.0
% INFO    : Bus 93211	: V=1.0071217, theta=-31.668591 -> V=1.0, theta=0.0
% INFO    : Bus 93212	: V=1.0176596, theta=-34.905361 -> V=1.0, theta=0.0
% INFO    : Bus 93213	: V=0.9763487, theta=2.99592 -> V=1.0, theta=0.0
% INFO    : Bus 93214	: V=1.0089239, theta=5.943672 -> V=1.0, theta=0.0
% INFO    : Bus 93215	: V=0.9871801, theta=1.947428 -> V=1.0, theta=0.0
% INFO    : Bus 93216	: V=0.9849191, theta=-21.315359 -> V=1.0, theta=0.0
% INFO    : Bus 93217	: V=0.9856596, theta=-22.732866 -> V=1.0, theta=0.0
% INFO    : Bus 93218	: V=0.9882175, theta=8.215878 -> V=1.0, theta=0.0
% INFO    : Bus 93219	: V=0.9933452, theta=14.460708 -> V=1.0, theta=0.0
% INFO    : Bus 93220	: V=0.9971766, theta=14.61112 -> V=1.0, theta=0.0
% INFO    : Bus 93221	: V=0.9926885, theta=14.221063 -> V=1.0, theta=0.0
% INFO    : Bus 93222	: V=1.0044706, theta=14.773411 -> V=1.0, theta=0.0
% INFO    : Bus 93223	: V=0.9517478, theta=0.862954 -> V=1.0, theta=0.0
% INFO    : Bus 93224	: V=0.952345, theta=0.895 -> V=1.0, theta=0.0
% INFO    : Bus 93225	: V=0.9539538, theta=0.721746 -> V=1.0, theta=0.0
% INFO    : Bus 93226	: V=0.9533203, theta=0.794293 -> V=1.0, theta=0.0
% INFO    : Bus 93227	: V=0.9550185, theta=0.632765 -> V=1.0, theta=0.0
% INFO    : Bus 93228	: V=0.9565493, theta=0.508491 -> V=1.0, theta=0.0
% INFO    : Bus 93229	: V=0.9538277, theta=1.509324 -> V=1.0, theta=0.0
% INFO    : Bus 93230	: V=0.9740286, theta=0.840236 -> V=1.0, theta=0.0
% INFO    : Bus 93231	: V=1.0035395, theta=7.782912 -> V=1.0, theta=0.0
% INFO    : Bus 93232	: V=0.9948629, theta=4.664493 -> V=1.0, theta=0.0
% INFO    : Bus 93233	: V=0.9822684, theta=5.313258 -> V=1.0, theta=0.0
% INFO    : Bus 93234	: V=0.9729315, theta=6.112231 -> V=1.0, theta=0.0
% INFO    : Bus 93235	: V=0.9766276, theta=2.006116 -> V=1.0, theta=0.0
% INFO    : Bus 93236	: V=1.0076228, theta=2.399618 -> V=1.0, theta=0.0
% INFO    : Bus 93237	: V=0.9901078, theta=2.482541 -> V=1.0, theta=0.0
% INFO    : Bus 93238	: V=0.9839873, theta=7.669991 -> V=1.0, theta=0.0
% INFO    : Bus 93239	: V=1.0182217, theta=19.952389 -> V=1.0, theta=0.0
% INFO    : Bus 93240	: V=1.017548, theta=20.05725 -> V=1.0, theta=0.0
% INFO    : Bus 93241	: V=1.0209507, theta=21.029871 -> V=1.0, theta=0.0
% INFO    : Bus 93242	: V=1.0183701, theta=20.400483 -> V=1.0, theta=0.0
% INFO    : Bus 93243	: V=1.0071724, theta=15.647574 -> V=1.0, theta=0.0
% INFO    : Bus 93244	: V=1.0040266, theta=15.107048 -> V=1.0, theta=0.0
% INFO    : Bus 93245	: V=1.0098903, theta=8.224472 -> V=1.0, theta=0.0
% INFO    : Bus 93246	: V=0.9918948, theta=0.598005 -> V=1.0, theta=0.0
% INFO    : Bus 93247	: V=0.9825913, theta=-2.539183 -> V=1.0, theta=0.0
% INFO    : Bus 93248	: V=0.9799934, theta=-2.472686 -> V=1.0, theta=0.0
% INFO    : Bus 93249	: V=0.9617205, theta=3.192361 -> V=1.0, theta=0.0
% INFO    : Bus 93250	: V=0.9704661, theta=1.292469 -> V=1.0, theta=0.0
% INFO    : Bus 93251	: V=0.9719454, theta=1.25154 -> V=1.0, theta=0.0
% INFO    : Bus 93252	: V=0.9774006, theta=1.479332 -> V=1.0, theta=0.0
% INFO    : Bus 93253	: V=0.9705023, theta=7.72065 -> V=1.0, theta=0.0
% INFO    : Bus 93254	: V=0.9642166, theta=4.019126 -> V=1.0, theta=0.0
% INFO    : Bus 93255	: V=0.9782512, theta=1.182924 -> V=1.0, theta=0.0
% INFO    : Bus 93256	: V=1.0051472, theta=11.227615 -> V=1.0, theta=0.0
% INFO    : Bus 93257	: V=1.0133794, theta=16.054716 -> V=1.0, theta=0.0
% INFO    : Bus 93258	: V=1.0092798, theta=15.540355 -> V=1.0, theta=0.0
% INFO    : Bus 93259	: V=0.9798484, theta=11.508584 -> V=1.0, theta=0.0
% INFO    : Bus 93260	: V=0.9801662, theta=10.088031 -> V=1.0, theta=0.0
% INFO    : Bus 93261	: V=1.0075962, theta=7.085912 -> V=1.0, theta=0.0
% INFO    : Bus 93262	: V=0.9746175, theta=3.465467 -> V=1.0, theta=0.0
% INFO    : Bus 93263	: V=0.9576053, theta=-0.901156 -> V=1.0, theta=0.0
% INFO    : Bus 93264	: V=0.9756615, theta=-1.047956 -> V=1.0, theta=0.0
% INFO    : Bus 93265	: V=0.9737945, theta=6.742583 -> V=1.0, theta=0.0
% INFO    : Bus 93266	: V=0.9738688, theta=6.730797 -> V=1.0, theta=0.0
% INFO    : Bus 93267	: V=0.9737, theta=7.376522 -> V=1.0, theta=0.0
% INFO    : Bus 93268	: V=0.9791038, theta=7.583661 -> V=1.0, theta=0.0
% INFO    : Bus 93269	: V=0.9984739, theta=9.319975 -> V=1.0, theta=0.0
% INFO    : Bus 93270	: V=1.0038385, theta=9.437208 -> V=1.0, theta=0.0
% INFO    : Bus 93271	: V=0.9656524, theta=-35.011266 -> V=1.0, theta=0.0
% INFO    : Bus 93272	: V=0.9564418, theta=-37.28712 -> V=1.0, theta=0.0
% INFO    : Bus 93273	: V=0.9781865, theta=-49.230136 -> V=1.0, theta=0.0
% INFO    : Bus 93274	: V=0.9784362, theta=-50.551293 -> V=1.0, theta=0.0
% INFO    : Bus 93275	: V=0.9757563, theta=-52.692534 -> V=1.0, theta=0.0
% INFO    : Bus 93276	: V=1.01335, theta=-47.643453 -> V=1.0, theta=0.0
% INFO    : Bus 93277	: V=1.0131997, theta=-47.348343 -> V=1.0, theta=0.0
% INFO    : Bus 93278	: V=1.0015146, theta=-50.114508 -> V=1.0, theta=0.0
% INFO    : Bus 93279	: V=0.9973613, theta=-53.668709 -> V=1.0, theta=0.0
% INFO    : Bus 93280	: V=1.0005559, theta=-56.69599 -> V=1.0, theta=0.0
% INFO    : Bus 93281	: V=1.0012817, theta=-57.049728 -> V=1.0, theta=0.0
% INFO    : Bus 93282	: V=0.9927266, theta=-54.5684 -> V=1.0, theta=0.0
% INFO    : Bus 93283	: V=0.9842464, theta=-56.31672 -> V=1.0, theta=0.0
% INFO    : Bus 93284	: V=0.9774022, theta=-56.59839 -> V=1.0, theta=0.0
% INFO    : Bus 93285	: V=0.9959733, theta=-58.53204 -> V=1.0, theta=0.0
% INFO    : Bus 93286	: V=0.9974131, theta=-56.66051 -> V=1.0, theta=0.0
% INFO    : Bus 93287	: V=1.003305, theta=-60.602663 -> V=1.0, theta=0.0
% INFO    : Bus 93288	: V=0.9864739, theta=-59.856055 -> V=1.0, theta=0.0
% INFO    : Bus 93289	: V=0.9971963, theta=-59.431125 -> V=1.0, theta=0.0
% INFO    : Bus 93290	: V=1.0030274, theta=-61.430566 -> V=1.0, theta=0.0
% INFO    : Bus 93291	: V=0.9996817, theta=-61.474158 -> V=1.0, theta=0.0
% INFO    : Bus 93292	: V=0.9868658, theta=-58.843818 -> V=1.0, theta=0.0
% INFO    : Bus 93293	: V=1.0144115, theta=-57.801245 -> V=1.0, theta=0.0
% INFO    : Bus 93294	: V=0.9709166, theta=-54.747269 -> V=1.0, theta=0.0
% INFO    : Bus 93295	: V=0.966926, theta=-55.67583 -> V=1.0, theta=0.0
% INFO    : Bus 93296	: V=0.9853222, theta=-54.34219 -> V=1.0, theta=0.0
% INFO    : Bus 93297	: V=0.9826513, theta=-54.445353 -> V=1.0, theta=0.0
% INFO    : Bus 93298	: V=0.9670026, theta=-54.608466 -> V=1.0, theta=0.0
% INFO    : Bus 93299	: V=0.9655511, theta=-54.619408 -> V=1.0, theta=0.0
% INFO    : Bus 93300	: V=0.9638809, theta=-54.742923 -> V=1.0, theta=0.0
% INFO    : Bus 93301	: V=0.9634606, theta=-54.753517 -> V=1.0, theta=0.0
% INFO    : Bus 93302	: V=0.9626873, theta=-54.727799 -> V=1.0, theta=0.0
% INFO    : Bus 93303	: V=0.9703407, theta=-54.588989 -> V=1.0, theta=0.0
% INFO    : Bus 93304	: V=0.9650182, theta=-55.11802 -> V=1.0, theta=0.0
% INFO    : Bus 93305	: V=0.9663722, theta=-54.683528 -> V=1.0, theta=0.0
% INFO    : Bus 93306	: V=0.9962096, theta=-56.183751 -> V=1.0, theta=0.0
% INFO    : Bus 93307	: V=0.9903338, theta=-56.629882 -> V=1.0, theta=0.0
% INFO    : Bus 93308	: V=0.989977, theta=-57.333321 -> V=1.0, theta=0.0
% INFO    : Bus 93309	: V=0.9611713, theta=-64.02834 -> V=1.0, theta=0.0
% INFO    : Bus 93310	: V=0.9659691, theta=-67.056133 -> V=1.0, theta=0.0
% INFO    : Bus 93311	: V=0.9636189, theta=-65.560063 -> V=1.0, theta=0.0
% INFO    : Bus 93312	: V=0.9742521, theta=-63.302578 -> V=1.0, theta=0.0
% INFO    : Bus 93313	: V=0.9925094, theta=-57.148579 -> V=1.0, theta=0.0
% INFO    : Bus 93314	: V=0.9806145, theta=-60.327804 -> V=1.0, theta=0.0
% INFO    : Bus 93315	: V=0.9770115, theta=-61.295813 -> V=1.0, theta=0.0
% INFO    : Bus 93316	: V=0.9732836, theta=-62.230892 -> V=1.0, theta=0.0
% INFO    : Bus 93317	: V=0.9694271, theta=-35.368759 -> V=1.0, theta=0.0
% INFO    : Bus 93318	: V=0.9733819, theta=-35.643883 -> V=1.0, theta=0.0
% INFO    : Bus 93319	: V=0.9982253, theta=-51.872757 -> V=1.0, theta=0.0
% INFO    : Bus 93320	: V=0.9758182, theta=-53.868967 -> V=1.0, theta=0.0
% INFO    : Bus 93321	: V=0.9815497, theta=-53.298807 -> V=1.0, theta=0.0
% INFO    : Bus 93322	: V=0.9701133, theta=-54.403628 -> V=1.0, theta=0.0
% INFO    : Bus 93323	: V=0.9831725, theta=-53.407286 -> V=1.0, theta=0.0
% INFO    : Bus 93324	: V=0.9715666, theta=-54.274833 -> V=1.0, theta=0.0
% INFO    : Bus 93325	: V=0.97997, theta=-53.739589 -> V=1.0, theta=0.0
% INFO    : Bus 93326	: V=0.9738846, theta=-54.218791 -> V=1.0, theta=0.0
% INFO    : Bus 93327	: V=0.963662, theta=-53.952329 -> V=1.0, theta=0.0
% INFO    : Bus 93328	: V=0.9731622, theta=-53.5735 -> V=1.0, theta=0.0
% INFO    : Bus 93329	: V=0.979213, theta=-53.675355 -> V=1.0, theta=0.0
% INFO    : Bus 93330	: V=0.9708912, theta=-53.705508 -> V=1.0, theta=0.0
% INFO    : Bus 93331	: V=0.9704368, theta=-53.490743 -> V=1.0, theta=0.0
% INFO    : Bus 93332	: V=0.9665178, theta=-53.620984 -> V=1.0, theta=0.0
% INFO    : Bus 93333	: V=0.9689269, theta=-53.349787 -> V=1.0, theta=0.0
% INFO    : Bus 93334	: V=0.9761092, theta=-53.380218 -> V=1.0, theta=0.0
% INFO    : Bus 93335	: V=0.9698693, theta=-53.279199 -> V=1.0, theta=0.0
% INFO    : Bus 93336	: V=0.9815676, theta=-52.935811 -> V=1.0, theta=0.0
% INFO    : Bus 93337	: V=0.9757857, theta=-53.473452 -> V=1.0, theta=0.0
% INFO    : Bus 93338	: V=0.9749037, theta=-53.590154 -> V=1.0, theta=0.0
% INFO    : Bus 93339	: V=0.982759, theta=-52.507506 -> V=1.0, theta=0.0
% INFO    : Bus 93340	: V=0.9811043, theta=-54.077432 -> V=1.0, theta=0.0
% INFO    : Bus 93341	: V=0.9853289, theta=-50.775897 -> V=1.0, theta=0.0
% INFO    : Bus 93342	: V=0.9871198, theta=-63.021252 -> V=1.0, theta=0.0
% INFO    : Bus 93343	: V=0.9817733, theta=-63.446733 -> V=1.0, theta=0.0
% INFO    : Bus 93344	: V=0.9758198, theta=-63.925232 -> V=1.0, theta=0.0
% INFO    : Bus 93345	: V=0.982311, theta=-64.182277 -> V=1.0, theta=0.0
% INFO    : Bus 93346	: V=0.9926074, theta=-63.656312 -> V=1.0, theta=0.0
% INFO    : Bus 93347	: V=0.9851612, theta=-64.068434 -> V=1.0, theta=0.0
% INFO    : Bus 93348	: V=1.0032957, theta=-61.448906 -> V=1.0, theta=0.0
% INFO    : Bus 93349	: V=0.9949852, theta=-63.286845 -> V=1.0, theta=0.0
% INFO    : Bus 93350	: V=0.9814827, theta=-63.634305 -> V=1.0, theta=0.0
% INFO    : Bus 93351	: V=0.9725551, theta=-64.955287 -> V=1.0, theta=0.0
% INFO    : Bus 93352	: V=0.9749668, theta=-30.451354 -> V=1.0, theta=0.0
% INFO    : Bus 93353	: V=0.9824664, theta=-32.295867 -> V=1.0, theta=0.0
% INFO    : Bus 93354	: V=0.9939785, theta=-38.633249 -> V=1.0, theta=0.0
% INFO    : Bus 93355	: V=0.9717678, theta=-42.344937 -> V=1.0, theta=0.0
% INFO    : Bus 93356	: V=0.9675101, theta=-43.43614 -> V=1.0, theta=0.0
% INFO    : Bus 93357	: V=0.9708207, theta=-42.936015 -> V=1.0, theta=0.0
% INFO    : Bus 93358	: V=0.9851886, theta=-40.258935 -> V=1.0, theta=0.0
% INFO    : Bus 93359	: V=0.9936017, theta=-39.125552 -> V=1.0, theta=0.0
% INFO    : Bus 93360	: V=0.9945531, theta=-39.031187 -> V=1.0, theta=0.0
% INFO    : Bus 93361	: V=0.9852012, theta=-58.637297 -> V=1.0, theta=0.0
% INFO    : Bus 93362	: V=0.9828618, theta=-58.550081 -> V=1.0, theta=0.0
% INFO    : Bus 93363	: V=0.9858646, theta=-58.383325 -> V=1.0, theta=0.0
% INFO    : Bus 93364	: V=0.9850917, theta=-57.513066 -> V=1.0, theta=0.0
% INFO    : Bus 93365	: V=0.9817594, theta=-56.704147 -> V=1.0, theta=0.0
% INFO    : Bus 93366	: V=0.9668286, theta=-30.760002 -> V=1.0, theta=0.0
% INFO    : Bus 93367	: V=0.9750068, theta=-31.582966 -> V=1.0, theta=0.0
% INFO    : Bus 93368	: V=0.9719268, theta=-32.245161 -> V=1.0, theta=0.0
% INFO    : Bus 93369	: V=0.9848991, theta=-49.423221 -> V=1.0, theta=0.0
% INFO    : Bus 93370	: V=0.9765779, theta=-49.913425 -> V=1.0, theta=0.0
% INFO    : Bus 93371	: V=0.9880229, theta=-47.197068 -> V=1.0, theta=0.0
% INFO    : Bus 93372	: V=0.9859271, theta=-47.196813 -> V=1.0, theta=0.0
% INFO    : Bus 93373	: V=0.9962634, theta=-53.93425 -> V=1.0, theta=0.0
% INFO    : Bus 93374	: V=0.9904519, theta=-54.71799 -> V=1.0, theta=0.0
% INFO    : Bus 93375	: V=0.9872936, theta=-55.297434 -> V=1.0, theta=0.0
% INFO    : Bus 93376	: V=0.9711956, theta=-59.248115 -> V=1.0, theta=0.0
% INFO    : Bus 93377	: V=0.9805031, theta=-59.987841 -> V=1.0, theta=0.0
% INFO    : Bus 93378	: V=0.9720955, theta=-57.62177 -> V=1.0, theta=0.0
% INFO    : Bus 93379	: V=0.9715233, theta=-55.507888 -> V=1.0, theta=0.0
% INFO    : Bus 93380	: V=0.9770599, theta=-47.167785 -> V=1.0, theta=0.0
% INFO    : Bus 93381	: V=0.9699697, theta=-44.949773 -> V=1.0, theta=0.0
% INFO    : Bus 93382	: V=0.9811708, theta=-59.547771 -> V=1.0, theta=0.0
% INFO    : Bus 93383	: V=1.0145567, theta=-51.814654 -> V=1.0, theta=0.0
% INFO    : Bus 93384	: V=0.999088, theta=-39.096289 -> V=1.0, theta=0.0
% INFO    : Bus 93385	: V=0.9698268, theta=-50.237498 -> V=1.0, theta=0.0
% INFO    : Bus 93386	: V=0.9780864, theta=-50.047352 -> V=1.0, theta=0.0
% INFO    : Bus 93387	: V=0.978754, theta=-60.765554 -> V=1.0, theta=0.0
% INFO    : Bus 93388	: V=0.9988027, theta=-59.753716 -> V=1.0, theta=0.0
% INFO    : Bus 93389	: V=0.9943226, theta=-59.941235 -> V=1.0, theta=0.0
% INFO    : Bus 93390	: V=0.970927, theta=-66.866832 -> V=1.0, theta=0.0
% INFO    : Bus 93391	: V=0.9853216, theta=-56.959629 -> V=1.0, theta=0.0
% INFO    : Bus 93392	: V=0.9638512, theta=-42.645071 -> V=1.0, theta=0.0
% INFO    : Bus 93393	: V=0.964629, theta=-42.709081 -> V=1.0, theta=0.0
% INFO    : Bus 93394	: V=0.9357643, theta=-47.369489 -> V=1.0, theta=0.0
% INFO    : Bus 93395	: V=0.9717949, theta=-53.108582 -> V=1.0, theta=0.0
% INFO    : Bus 93396	: V=0.9850996, theta=-59.489392 -> V=1.0, theta=0.0
% INFO    : Bus 93397	: V=0.9757651, theta=-41.953613 -> V=1.0, theta=0.0
% INFO    : Bus 93398	: V=0.9759031, theta=-44.004431 -> V=1.0, theta=0.0
% INFO    : Bus 93399	: V=0.9860887, theta=-44.059352 -> V=1.0, theta=0.0
% INFO    : Bus 93400	: V=0.9943833, theta=-40.543768 -> V=1.0, theta=0.0
% INFO    : Bus 93401	: V=0.9824369, theta=-39.780713 -> V=1.0, theta=0.0
% INFO    : Bus 93402	: V=0.9848479, theta=-44.374062 -> V=1.0, theta=0.0
% INFO    : Bus 93403	: V=0.9948505, theta=-47.557878 -> V=1.0, theta=0.0
% INFO    : Bus 93404	: V=0.9909014, theta=-48.913797 -> V=1.0, theta=0.0
% INFO    : Bus 93405	: V=1.0059063, theta=-49.683168 -> V=1.0, theta=0.0
% INFO    : Bus 93406	: V=0.9617572, theta=-67.564004 -> V=1.0, theta=0.0
% INFO    : Bus 93407	: V=0.9943038, theta=-53.536236 -> V=1.0, theta=0.0
% INFO    : Bus 93408	: V=0.9875853, theta=-54.528118 -> V=1.0, theta=0.0
% INFO    : Bus 93409	: V=0.9943934, theta=-44.515335 -> V=1.0, theta=0.0
% INFO    : Bus 93410	: V=0.9950355, theta=-45.645584 -> V=1.0, theta=0.0
% INFO    : Bus 93411	: V=0.9799437, theta=-39.245487 -> V=1.0, theta=0.0
% INFO    : Bus 93412	: V=0.9808939, theta=-41.308323 -> V=1.0, theta=0.0
% INFO    : Bus 93413	: V=0.9908854, theta=-39.600949 -> V=1.0, theta=0.0
% INFO    : Bus 93414	: V=0.9830132, theta=-54.996281 -> V=1.0, theta=0.0
% INFO    : Bus 93415	: V=0.9778976, theta=-54.495506 -> V=1.0, theta=0.0
% INFO    : Bus 93416	: V=0.9718755, theta=-62.529986 -> V=1.0, theta=0.0
% INFO    : Bus 93417	: V=0.9756541, theta=-62.022725 -> V=1.0, theta=0.0
% INFO    : Bus 93418	: V=1.0040163, theta=-32.527269 -> V=1.0, theta=0.0
% INFO    : Bus 93419	: V=1.014641, theta=-32.367993 -> V=1.0, theta=0.0
% INFO    : Bus 93420	: V=1.0013085, theta=-32.444488 -> V=1.0, theta=0.0
% INFO    : Bus 93421	: V=1.0040571, theta=-34.657083 -> V=1.0, theta=0.0
% INFO    : Bus 93422	: V=1.0172091, theta=-33.649556 -> V=1.0, theta=0.0
% INFO    : Bus 93423	: V=1.0158648, theta=-33.764656 -> V=1.0, theta=0.0
% INFO    : Bus 93424	: V=1.016042, theta=-34.267284 -> V=1.0, theta=0.0
% INFO    : Bus 93425	: V=1.012241, theta=-34.549117 -> V=1.0, theta=0.0
% INFO    : Bus 93426	: V=1.0171336, theta=-33.879255 -> V=1.0, theta=0.0
% INFO    : Bus 93427	: V=1.0186471, theta=-33.999809 -> V=1.0, theta=0.0
% INFO    : Bus 93428	: V=0.9954764, theta=-35.590216 -> V=1.0, theta=0.0
% INFO    : Bus 93429	: V=0.9939628, theta=-39.13491 -> V=1.0, theta=0.0
% INFO    : Bus 93430	: V=0.9903592, theta=-45.402845 -> V=1.0, theta=0.0
% INFO    : Bus 93431	: V=0.9830182, theta=-36.024656 -> V=1.0, theta=0.0
% INFO    : Bus 93432	: V=0.9696593, theta=-47.23761 -> V=1.0, theta=0.0
% INFO    : Bus 93433	: V=0.9642958, theta=-47.129833 -> V=1.0, theta=0.0
% INFO    : Bus 93434	: V=0.9666529, theta=-46.083587 -> V=1.0, theta=0.0
% INFO    : Bus 93435	: V=0.9697731, theta=-53.120314 -> V=1.0, theta=0.0
% INFO    : Bus 93436	: V=0.9615416, theta=-53.90493 -> V=1.0, theta=0.0
% INFO    : Bus 93437	: V=0.9634884, theta=-53.876893 -> V=1.0, theta=0.0
% INFO    : Bus 93438	: V=0.9606861, theta=-53.860863 -> V=1.0, theta=0.0
% INFO    : Bus 93439	: V=0.9622917, theta=-54.020437 -> V=1.0, theta=0.0
% INFO    : Bus 93440	: V=0.9649292, theta=-54.296924 -> V=1.0, theta=0.0
% INFO    : Bus 93441	: V=0.9645955, theta=-53.777776 -> V=1.0, theta=0.0
% INFO    : Bus 93442	: V=0.9773811, theta=-52.831219 -> V=1.0, theta=0.0
% INFO    : Bus 93443	: V=0.971146, theta=-53.427634 -> V=1.0, theta=0.0
% INFO    : Bus 93444	: V=0.9679123, theta=-53.668539 -> V=1.0, theta=0.0
% INFO    : Bus 93445	: V=0.968868, theta=-53.466711 -> V=1.0, theta=0.0
% INFO    : Bus 93446	: V=0.9768677, theta=-52.437385 -> V=1.0, theta=0.0
% INFO    : Bus 93447	: V=0.9705568, theta=-53.087002 -> V=1.0, theta=0.0
% INFO    : Bus 93448	: V=0.9810431, theta=-52.420852 -> V=1.0, theta=0.0
% INFO    : Bus 93449	: V=0.9759242, theta=-52.908651 -> V=1.0, theta=0.0
% INFO    : Bus 93450	: V=0.961618, theta=-53.971243 -> V=1.0, theta=0.0
% INFO    : Bus 93451	: V=0.9700883, theta=-52.937907 -> V=1.0, theta=0.0
% INFO    : Bus 93452	: V=0.9693416, theta=-53.018512 -> V=1.0, theta=0.0
% INFO    : Bus 93453	: V=0.9695676, theta=-53.031215 -> V=1.0, theta=0.0
% INFO    : Bus 93454	: V=0.9688751, theta=-53.085204 -> V=1.0, theta=0.0
% INFO    : Bus 93455	: V=0.9684784, theta=-53.070902 -> V=1.0, theta=0.0
% INFO    : Bus 93456	: V=0.969238, theta=-53.078187 -> V=1.0, theta=0.0
% INFO    : Bus 93457	: V=0.9614013, theta=-53.917638 -> V=1.0, theta=0.0
% INFO    : Bus 93458	: V=0.9644337, theta=-53.733383 -> V=1.0, theta=0.0
% INFO    : Bus 93459	: V=0.9645706, theta=-53.608062 -> V=1.0, theta=0.0
% INFO    : Bus 93460	: V=0.9617129, theta=-54.048703 -> V=1.0, theta=0.0
% INFO    : Bus 93461	: V=0.9609464, theta=-54.041089 -> V=1.0, theta=0.0
% INFO    : Bus 93462	: V=0.9618672, theta=-54.16369 -> V=1.0, theta=0.0
% INFO    : Bus 93463	: V=0.9631413, theta=-54.018918 -> V=1.0, theta=0.0
% INFO    : Bus 93464	: V=0.9702765, theta=-53.771788 -> V=1.0, theta=0.0
% INFO    : Bus 93465	: V=0.9786894, theta=-53.179167 -> V=1.0, theta=0.0
% INFO    : Bus 93466	: V=0.9637269, theta=-54.089609 -> V=1.0, theta=0.0
% INFO    : Bus 93467	: V=0.9633561, theta=-54.098554 -> V=1.0, theta=0.0
% INFO    : Bus 93468	: V=0.9688586, theta=-53.712694 -> V=1.0, theta=0.0
% INFO    : Bus 93469	: V=0.9680201, theta=-53.662546 -> V=1.0, theta=0.0
% INFO    : Bus 93470	: V=0.9708539, theta=-53.676444 -> V=1.0, theta=0.0
% INFO    : Bus 93471	: V=0.9689623, theta=-53.689279 -> V=1.0, theta=0.0
% INFO    : Bus 93472	: V=0.9696244, theta=-53.389359 -> V=1.0, theta=0.0
% INFO    : Bus 93473	: V=0.9804787, theta=-52.355272 -> V=1.0, theta=0.0
% INFO    : Bus 93474	: V=0.9819097, theta=-52.395286 -> V=1.0, theta=0.0
% INFO    : Bus 93475	: V=0.9830377, theta=-52.385741 -> V=1.0, theta=0.0
% INFO    : Bus 93476	: V=0.990842, theta=-51.606777 -> V=1.0, theta=0.0
% INFO    : Bus 93477	: V=0.9859125, theta=-51.987584 -> V=1.0, theta=0.0
% INFO    : Bus 93478	: V=0.9732616, theta=-52.811934 -> V=1.0, theta=0.0
% INFO    : Bus 93479	: V=0.9692178, theta=-52.855952 -> V=1.0, theta=0.0
% INFO    : Bus 93480	: V=0.9715764, theta=-52.847321 -> V=1.0, theta=0.0
% INFO    : Bus 93481	: V=0.9735443, theta=-52.881441 -> V=1.0, theta=0.0
% INFO    : Bus 93482	: V=0.9908555, theta=-51.360989 -> V=1.0, theta=0.0
% INFO    : Bus 93483	: V=0.9805114, theta=-52.265153 -> V=1.0, theta=0.0
% INFO    : Bus 93484	: V=0.9759153, theta=-52.655764 -> V=1.0, theta=0.0
% INFO    : Bus 93485	: V=0.9671318, theta=-52.989476 -> V=1.0, theta=0.0
% INFO    : Bus 93486	: V=0.9914856, theta=-50.519494 -> V=1.0, theta=0.0
% INFO    : Bus 93487	: V=0.9862153, theta=-51.227986 -> V=1.0, theta=0.0
% INFO    : Bus 93488	: V=0.9891507, theta=-50.844976 -> V=1.0, theta=0.0
% INFO    : Bus 93489	: V=0.9663015, theta=-52.433555 -> V=1.0, theta=0.0
% INFO    : Bus 93490	: V=0.98242, theta=-51.300806 -> V=1.0, theta=0.0
% INFO    : Bus 93491	: V=0.9770274, theta=-51.843859 -> V=1.0, theta=0.0
% INFO    : Bus 93492	: V=0.9784336, theta=-51.804238 -> V=1.0, theta=0.0
% INFO    : Bus 93493	: V=0.9682734, theta=-53.066504 -> V=1.0, theta=0.0
% INFO    : Bus 93494	: V=0.9733548, theta=-52.597229 -> V=1.0, theta=0.0
% INFO    : Bus 93495	: V=0.9871342, theta=-51.162213 -> V=1.0, theta=0.0
% INFO    : Bus 93496	: V=0.9817318, theta=-51.64928 -> V=1.0, theta=0.0
% INFO    : Bus 93497	: V=0.9782422, theta=-52.289805 -> V=1.0, theta=0.0
% INFO    : Bus 93498	: V=0.9769659, theta=-52.302218 -> V=1.0, theta=0.0
% INFO    : Bus 93499	: V=0.9690565, theta=-53.070606 -> V=1.0, theta=0.0
% INFO    : Bus 93500	: V=0.9648975, theta=-53.888056 -> V=1.0, theta=0.0
% INFO    : Bus 93501	: V=0.9642519, theta=-53.868374 -> V=1.0, theta=0.0
% INFO    : Bus 93502	: V=0.9644721, theta=-53.966824 -> V=1.0, theta=0.0
% INFO    : Bus 93503	: V=0.9680996, theta=-53.637256 -> V=1.0, theta=0.0
% INFO    : Bus 93504	: V=0.9654415, theta=-54.0396 -> V=1.0, theta=0.0
% INFO    : Bus 93505	: V=0.9750855, theta=-52.597733 -> V=1.0, theta=0.0
% INFO    : Bus 93506	: V=0.981563, theta=-51.952287 -> V=1.0, theta=0.0
% INFO    : Bus 93507	: V=1.0128969, theta=-48.514082 -> V=1.0, theta=0.0
% INFO    : Bus 93508	: V=0.9978066, theta=-50.387525 -> V=1.0, theta=0.0
% INFO    : Bus 93509	: V=0.964503, theta=-42.825037 -> V=1.0, theta=0.0
% INFO    : Bus 93510	: V=0.9641417, theta=-42.941678 -> V=1.0, theta=0.0
% INFO    : Bus 93511	: V=0.97195, theta=-40.133601 -> V=1.0, theta=0.0
% INFO    : Bus 93512	: V=0.9756366, theta=-38.931317 -> V=1.0, theta=0.0
% INFO    : Bus 93513	: V=0.9739575, theta=-37.458741 -> V=1.0, theta=0.0
% INFO    : Bus 93514	: V=0.9727816, theta=-29.227553 -> V=1.0, theta=0.0
% INFO    : Bus 93515	: V=0.9664754, theta=-30.077976 -> V=1.0, theta=0.0
% INFO    : Bus 93516	: V=0.9677653, theta=-29.739736 -> V=1.0, theta=0.0
% INFO    : Bus 93517	: V=0.9658117, theta=-29.845425 -> V=1.0, theta=0.0
% INFO    : Bus 93518	: V=0.9689574, theta=-30.86209 -> V=1.0, theta=0.0
% INFO    : Bus 93519	: V=0.9715087, theta=-41.403948 -> V=1.0, theta=0.0
% INFO    : Bus 93520	: V=0.9971112, theta=-45.324435 -> V=1.0, theta=0.0
% INFO    : Bus 93521	: V=0.9950903, theta=-45.475922 -> V=1.0, theta=0.0
% INFO    : Bus 93522	: V=1.0020605, theta=-45.563352 -> V=1.0, theta=0.0
% INFO    : Bus 93523	: V=0.9958061, theta=-45.457495 -> V=1.0, theta=0.0
% INFO    : Bus 93524	: V=0.9866899, theta=-46.03641 -> V=1.0, theta=0.0
% INFO    : Bus 93525	: V=0.987671, theta=-46.061316 -> V=1.0, theta=0.0
% INFO    : Bus 93526	: V=0.970689, theta=-44.511804 -> V=1.0, theta=0.0
% INFO    : Bus 93527	: V=0.9783539, theta=-42.273707 -> V=1.0, theta=0.0
% INFO    : Bus 93528	: V=0.9728341, theta=-47.118967 -> V=1.0, theta=0.0
% INFO    : Bus 93529	: V=0.9638269, theta=-45.644297 -> V=1.0, theta=0.0
% INFO    : Bus 93530	: V=0.9642621, theta=-46.030554 -> V=1.0, theta=0.0
% INFO    : Bus 93531	: V=0.9953691, theta=-45.388923 -> V=1.0, theta=0.0
% INFO    : Bus 93532	: V=0.9655352, theta=-54.092979 -> V=1.0, theta=0.0
% INFO    : Bus 93533	: V=0.9679965, theta=-54.285298 -> V=1.0, theta=0.0
% INFO    : Bus 93534	: V=0.9932418, theta=-53.687544 -> V=1.0, theta=0.0
% INFO    : Bus 93535	: V=0.9963713, theta=-50.565674 -> V=1.0, theta=0.0
% INFO    : Bus 93536	: V=0.9882173, theta=-51.423332 -> V=1.0, theta=0.0
% INFO    : Bus 93537	: V=0.9740229, theta=-50.884348 -> V=1.0, theta=0.0
% INFO    : Bus 93538	: V=1.0047236, theta=-49.27764 -> V=1.0, theta=0.0
% INFO    : Bus 93539	: V=0.9992206, theta=-50.020568 -> V=1.0, theta=0.0
% INFO    : Bus 93540	: V=0.9965259, theta=-50.241967 -> V=1.0, theta=0.0
% INFO    : Bus 93541	: V=0.992747, theta=-51.483731 -> V=1.0, theta=0.0
% INFO    : Bus 93542	: V=0.9792236, theta=-52.595572 -> V=1.0, theta=0.0
% INFO    : Bus 93543	: V=0.9834912, theta=-54.112746 -> V=1.0, theta=0.0
% INFO    : Bus 93544	: V=0.9889788, theta=-50.548691 -> V=1.0, theta=0.0
% INFO    : Bus 93545	: V=0.989653, theta=-35.168136 -> V=1.0, theta=0.0
% INFO    : Bus 93546	: V=0.9935107, theta=-34.46941 -> V=1.0, theta=0.0
% INFO    : Bus 93547	: V=0.9934861, theta=-34.423225 -> V=1.0, theta=0.0
% INFO    : Bus 93548	: V=0.9981244, theta=-35.396216 -> V=1.0, theta=0.0
% INFO    : Bus 93549	: V=0.9855661, theta=-36.873835 -> V=1.0, theta=0.0
% INFO    : Bus 93550	: V=0.9616292, theta=-38.22323 -> V=1.0, theta=0.0
% INFO    : Bus 93551	: V=0.9988711, theta=-33.670573 -> V=1.0, theta=0.0
% INFO    : Bus 93552	: V=1.0017481, theta=-34.493642 -> V=1.0, theta=0.0
% INFO    : Bus 93553	: V=1.0000056, theta=-34.816765 -> V=1.0, theta=0.0
% INFO    : Bus 93554	: V=0.9985857, theta=-35.070535 -> V=1.0, theta=0.0
% INFO    : Bus 93555	: V=0.9925951, theta=-35.565299 -> V=1.0, theta=0.0
% INFO    : Bus 93556	: V=0.9691536, theta=-50.232614 -> V=1.0, theta=0.0
% INFO    : Bus 93557	: V=0.9655898, theta=-51.701963 -> V=1.0, theta=0.0
% INFO    : Bus 93558	: V=0.9711273, theta=-50.425724 -> V=1.0, theta=0.0
% INFO    : Bus 93559	: V=0.9752264, theta=-51.271171 -> V=1.0, theta=0.0
% INFO    : Bus 93560	: V=0.9756348, theta=-38.087396 -> V=1.0, theta=0.0
% INFO    : Bus 93561	: V=0.9848508, theta=-38.129339 -> V=1.0, theta=0.0
% INFO    : Bus 93562	: V=0.9922544, theta=-37.825589 -> V=1.0, theta=0.0
% INFO    : Bus 93563	: V=0.9797443, theta=-39.490875 -> V=1.0, theta=0.0
% INFO    : Bus 93564	: V=0.9803801, theta=-66.352785 -> V=1.0, theta=0.0
% INFO    : Bus 93565	: V=0.9739372, theta=-66.422645 -> V=1.0, theta=0.0
% INFO    : Bus 93566	: V=0.9801761, theta=-57.956771 -> V=1.0, theta=0.0
% INFO    : Bus 93567	: V=1.0154019, theta=-57.706533 -> V=1.0, theta=0.0
% INFO    : Bus 93568	: V=0.9727636, theta=-38.885509 -> V=1.0, theta=0.0
% INFO    : Bus 93569	: V=0.9724757, theta=-38.898535 -> V=1.0, theta=0.0
% INFO    : Bus 93570	: V=0.9786444, theta=-38.678267 -> V=1.0, theta=0.0
% INFO    : Bus 93571	: V=0.9762644, theta=-38.928065 -> V=1.0, theta=0.0
% INFO    : Bus 93572	: V=0.9786275, theta=-38.723492 -> V=1.0, theta=0.0
% INFO    : Bus 93573	: V=0.9762563, theta=-38.790367 -> V=1.0, theta=0.0
% INFO    : Bus 93574	: V=0.9693108, theta=-39.035159 -> V=1.0, theta=0.0
% INFO    : Bus 93575	: V=0.9741908, theta=-38.913417 -> V=1.0, theta=0.0
% INFO    : Bus 93576	: V=0.9779, theta=-38.99457 -> V=1.0, theta=0.0
% INFO    : Bus 93577	: V=0.9743976, theta=-39.301083 -> V=1.0, theta=0.0
% INFO    : Bus 93578	: V=0.9772849, theta=-38.970171 -> V=1.0, theta=0.0
% INFO    : Bus 93579	: V=0.9761148, theta=-38.894578 -> V=1.0, theta=0.0
% INFO    : Bus 93580	: V=0.9757664, theta=-38.887125 -> V=1.0, theta=0.0
% INFO    : Bus 93581	: V=0.9721742, theta=-38.973034 -> V=1.0, theta=0.0
% INFO    : Bus 93582	: V=0.9743773, theta=-38.841049 -> V=1.0, theta=0.0
% INFO    : Bus 93583	: V=0.9830801, theta=-38.479674 -> V=1.0, theta=0.0
% INFO    : Bus 93584	: V=0.9749349, theta=-38.899238 -> V=1.0, theta=0.0
% INFO    : Bus 93585	: V=0.9829759, theta=-38.522615 -> V=1.0, theta=0.0
% INFO    : Bus 93586	: V=0.9848757, theta=-38.634421 -> V=1.0, theta=0.0
% INFO    : Bus 93587	: V=0.9847318, theta=-38.822864 -> V=1.0, theta=0.0
% INFO    : Bus 93588	: V=0.9885754, theta=-38.578284 -> V=1.0, theta=0.0
% INFO    : Bus 93589	: V=0.9831135, theta=-38.557459 -> V=1.0, theta=0.0
% INFO    : Bus 93590	: V=0.9805681, theta=-38.46064 -> V=1.0, theta=0.0
% INFO    : Bus 93591	: V=0.9808287, theta=-38.154933 -> V=1.0, theta=0.0
% INFO    : Bus 93592	: V=0.9712179, theta=-36.997527 -> V=1.0, theta=0.0
% INFO    : Bus 93593	: V=0.9785005, theta=-38.115787 -> V=1.0, theta=0.0
% INFO    : Bus 93594	: V=0.9751859, theta=-37.579512 -> V=1.0, theta=0.0
% INFO    : Bus 93595	: V=0.9665397, theta=-38.005198 -> V=1.0, theta=0.0
% INFO    : Bus 93596	: V=0.9811804, theta=-37.333612 -> V=1.0, theta=0.0
% INFO    : Bus 93597	: V=0.9784619, theta=-39.53077 -> V=1.0, theta=0.0
% INFO    : Bus 93598	: V=1.0028434, theta=-37.832263 -> V=1.0, theta=0.0
% INFO    : Bus 93599	: V=0.9834044, theta=-38.921544 -> V=1.0, theta=0.0
% INFO    : Bus 93600	: V=0.9809475, theta=-39.112559 -> V=1.0, theta=0.0
% INFO    : Bus 93601	: V=0.9878532, theta=-38.699555 -> V=1.0, theta=0.0
% INFO    : Bus 93602	: V=1.0034596, theta=-37.858693 -> V=1.0, theta=0.0
% INFO    : Bus 93603	: V=1.0124862, theta=-37.225572 -> V=1.0, theta=0.0
% INFO    : Bus 93604	: V=1.0062097, theta=-37.696847 -> V=1.0, theta=0.0
% INFO    : Bus 93605	: V=1.0040369, theta=-37.835567 -> V=1.0, theta=0.0
% INFO    : Bus 93606	: V=0.9807443, theta=-38.849199 -> V=1.0, theta=0.0
% INFO    : Bus 93607	: V=0.9861966, theta=-37.841917 -> V=1.0, theta=0.0
% INFO    : Bus 93608	: V=0.9837125, theta=-38.153299 -> V=1.0, theta=0.0
% INFO    : Bus 93609	: V=0.9716435, theta=-38.764648 -> V=1.0, theta=0.0
% INFO    : Bus 93610	: V=0.9714376, theta=-38.485954 -> V=1.0, theta=0.0
% INFO    : Bus 93611	: V=1.0044068, theta=-36.285742 -> V=1.0, theta=0.0
% INFO    : Bus 93612	: V=1.012331, theta=-35.890917 -> V=1.0, theta=0.0
% INFO    : Bus 93613	: V=1.0100272, theta=-36.10993 -> V=1.0, theta=0.0
% INFO    : Bus 93614	: V=0.9865203, theta=-37.936161 -> V=1.0, theta=0.0
% INFO    : Bus 93615	: V=0.9884367, theta=-37.813089 -> V=1.0, theta=0.0
% INFO    : Bus 93616	: V=1.0116314, theta=-36.096438 -> V=1.0, theta=0.0
% INFO    : Bus 93617	: V=1.007943, theta=-36.383953 -> V=1.0, theta=0.0
% INFO    : Bus 93618	: V=1.0047022, theta=-36.544507 -> V=1.0, theta=0.0
% INFO    : Bus 93619	: V=0.9922936, theta=-37.367793 -> V=1.0, theta=0.0
% INFO    : Bus 93620	: V=0.9957179, theta=-37.067302 -> V=1.0, theta=0.0
% INFO    : Bus 93621	: V=0.9927443, theta=-37.534144 -> V=1.0, theta=0.0
% INFO    : Bus 93622	: V=0.9765024, theta=-39.139408 -> V=1.0, theta=0.0
% INFO    : Bus 93623	: V=0.9843731, theta=-38.742099 -> V=1.0, theta=0.0
% INFO    : Bus 93624	: V=0.9834621, theta=-38.32388 -> V=1.0, theta=0.0
% INFO    : Bus 93625	: V=0.984315, theta=-38.165028 -> V=1.0, theta=0.0
% INFO    : Bus 93626	: V=0.9845911, theta=-38.301308 -> V=1.0, theta=0.0
% INFO    : Bus 93627	: V=0.9845995, theta=-38.470701 -> V=1.0, theta=0.0
% INFO    : Bus 93628	: V=0.9846225, theta=-38.266158 -> V=1.0, theta=0.0
% INFO    : Bus 93629	: V=0.9856947, theta=-38.282431 -> V=1.0, theta=0.0
% INFO    : Bus 93630	: V=0.998291, theta=-37.572965 -> V=1.0, theta=0.0
% INFO    : Bus 93631	: V=0.9778047, theta=-38.150418 -> V=1.0, theta=0.0
% INFO    : Bus 93632	: V=0.9739587, theta=-38.425184 -> V=1.0, theta=0.0
% INFO    : Bus 93633	: V=0.981181, theta=-38.133733 -> V=1.0, theta=0.0
% INFO    : Bus 93634	: V=0.9744328, theta=-38.694317 -> V=1.0, theta=0.0
% INFO    : Bus 93635	: V=0.9638577, theta=-39.269716 -> V=1.0, theta=0.0
% INFO    : Bus 93636	: V=0.9809743, theta=-38.829552 -> V=1.0, theta=0.0
% INFO    : Bus 93637	: V=0.9913486, theta=-37.326493 -> V=1.0, theta=0.0
% INFO    : Bus 93638	: V=0.9878665, theta=-37.573722 -> V=1.0, theta=0.0
% INFO    : Bus 93639	: V=0.9849698, theta=-37.702191 -> V=1.0, theta=0.0
% INFO    : Bus 93640	: V=0.9709319, theta=-38.594915 -> V=1.0, theta=0.0
% INFO    : Bus 93641	: V=0.9841454, theta=-39.272658 -> V=1.0, theta=0.0
% INFO    : Bus 93642	: V=0.984426, theta=-39.646612 -> V=1.0, theta=0.0
% INFO    : Bus 93643	: V=0.9788201, theta=-39.800336 -> V=1.0, theta=0.0
% INFO    : Bus 93644	: V=0.9831299, theta=-37.934692 -> V=1.0, theta=0.0
% INFO    : Bus 93645	: V=0.9819096, theta=-38.071747 -> V=1.0, theta=0.0
% INFO    : Bus 93646	: V=1.0025763, theta=-34.601866 -> V=1.0, theta=0.0
% INFO    : Bus 93647	: V=1.0048857, theta=-36.331317 -> V=1.0, theta=0.0
% INFO    : Bus 93648	: V=0.9763392, theta=-37.967942 -> V=1.0, theta=0.0
% INFO    : Bus 93649	: V=1.0141149, theta=-35.208209 -> V=1.0, theta=0.0
% INFO    : Bus 93650	: V=1.0107839, theta=-35.452922 -> V=1.0, theta=0.0
% INFO    : Bus 93651	: V=1.0075726, theta=-35.782235 -> V=1.0, theta=0.0
% INFO    : Bus 93652	: V=1.0175224, theta=-34.443007 -> V=1.0, theta=0.0
% INFO    : Bus 93653	: V=0.9788023, theta=-36.719308 -> V=1.0, theta=0.0
% INFO    : Bus 93654	: V=0.9763941, theta=-36.633812 -> V=1.0, theta=0.0
% INFO    : Bus 93655	: V=0.9767051, theta=-36.928257 -> V=1.0, theta=0.0
% INFO    : Bus 93656	: V=0.9785664, theta=-36.737513 -> V=1.0, theta=0.0
% INFO    : Bus 93657	: V=0.9705192, theta=-34.918042 -> V=1.0, theta=0.0
% INFO    : Bus 93658	: V=0.9959367, theta=-35.611749 -> V=1.0, theta=0.0
% INFO    : Bus 93659	: V=0.9874899, theta=-56.035572 -> V=1.0, theta=0.0
% INFO    : Bus 93660	: V=0.9849472, theta=-58.961348 -> V=1.0, theta=0.0
% INFO    : Bus 93661	: V=0.9988056, theta=-49.951 -> V=1.0, theta=0.0
% INFO    : Bus 93662	: V=0.9955719, theta=-50.088427 -> V=1.0, theta=0.0
% INFO    : Bus 93663	: V=0.987187, theta=-53.599976 -> V=1.0, theta=0.0
% INFO    : Bus 93664	: V=1.0165978, theta=-54.468068 -> V=1.0, theta=0.0
% INFO    : Bus 93665	: V=1.0117553, theta=-54.217455 -> V=1.0, theta=0.0
% INFO    : Bus 93666	: V=1.0038211, theta=-1.185384 -> V=1.0, theta=0.0
% INFO    : Bus 93667	: V=1.0045439, theta=-0.951684 -> V=1.0, theta=0.0
% INFO    : Bus 93668	: V=0.9875854, theta=-1.943659 -> V=1.0, theta=0.0
% INFO    : Bus 93669	: V=1.006571, theta=8.79127 -> V=1.0, theta=0.0
% INFO    : Bus 93670	: V=1.0016353, theta=9.515848 -> V=1.0, theta=0.0
% INFO    : Bus 93671	: V=1.0020103, theta=10.534411 -> V=1.0, theta=0.0
% INFO    : Bus 93672	: V=1.0005941, theta=9.954897 -> V=1.0, theta=0.0
% INFO    : Bus 93673	: V=0.9875194, theta=-0.173396 -> V=1.0, theta=0.0
% INFO    : Bus 93674	: V=0.9898393, theta=0.878291 -> V=1.0, theta=0.0
% INFO    : Bus 93675	: V=0.9964317, theta=0.733375 -> V=1.0, theta=0.0
% INFO    : Bus 93676	: V=1.021319, theta=-3.91075 -> V=1.0, theta=0.0
% INFO    : Bus 93677	: V=1.0190202, theta=-3.001951 -> V=1.0, theta=0.0
% INFO    : Bus 93678	: V=1.0011201, theta=2.253912 -> V=1.0, theta=0.0
% INFO    : Bus 93679	: V=0.9927921, theta=4.413846 -> V=1.0, theta=0.0
% INFO    : Bus 93680	: V=0.9921913, theta=4.51857 -> V=1.0, theta=0.0
% INFO    : Bus 93681	: V=0.989783, theta=4.519056 -> V=1.0, theta=0.0
% INFO    : Bus 93682	: V=0.9928722, theta=3.864685 -> V=1.0, theta=0.0
% INFO    : Bus 93683	: V=1.0137725, theta=6.729981 -> V=1.0, theta=0.0
% INFO    : Bus 93684	: V=0.9980427, theta=-8.320463 -> V=1.0, theta=0.0
% INFO    : Bus 93685	: V=0.9841883, theta=-3.614254 -> V=1.0, theta=0.0
% INFO    : Bus 93686	: V=0.9972195, theta=12.35701 -> V=1.0, theta=0.0
% INFO    : Bus 93687	: V=1.0062605, theta=3.839007 -> V=1.0, theta=0.0
% INFO    : Bus 93688	: V=1.0001144, theta=-0.236114 -> V=1.0, theta=0.0
% INFO    : Bus 93689	: V=0.9990623, theta=7.33046 -> V=1.0, theta=0.0
% INFO    : Bus 93690	: V=1.0236265, theta=-2.957082 -> V=1.0, theta=0.0
% INFO    : Bus 93691	: V=1.0074494, theta=-1.872138 -> V=1.0, theta=0.0
% INFO    : Bus 93692	: V=1.0204251, theta=-4.090481 -> V=1.0, theta=0.0
% INFO    : Bus 93693	: V=1.0202255, theta=-4.08096 -> V=1.0, theta=0.0
% INFO    : Bus 93694	: V=1.0178023, theta=-4.32798 -> V=1.0, theta=0.0
% INFO    : Bus 93695	: V=1.0128328, theta=-5.20345 -> V=1.0, theta=0.0
% INFO    : Bus 93696	: V=1.0211434, theta=-4.032749 -> V=1.0, theta=0.0
% INFO    : Bus 93697	: V=1.0205878, theta=-4.007847 -> V=1.0, theta=0.0
% INFO    : Bus 93698	: V=1.0201026, theta=-4.066331 -> V=1.0, theta=0.0
% INFO    : Bus 93699	: V=0.9828962, theta=-0.285672 -> V=1.0, theta=0.0
% INFO    : Bus 93700	: V=1.0050528, theta=-7.287757 -> V=1.0, theta=0.0
% INFO    : Bus 93701	: V=1.002783, theta=4.358694 -> V=1.0, theta=0.0
% INFO    : Bus 93702	: V=1.0029387, theta=1.723219 -> V=1.0, theta=0.0
% INFO    : Bus 93703	: V=1.0151903, theta=-3.245065 -> V=1.0, theta=0.0
% INFO    : Bus 93704	: V=0.9870948, theta=8.547209 -> V=1.0, theta=0.0
% INFO    : Bus 93705	: V=0.9863696, theta=7.332529 -> V=1.0, theta=0.0
% INFO    : Bus 93706	: V=0.9720306, theta=9.503228 -> V=1.0, theta=0.0
% INFO    : Bus 93707	: V=0.9975734, theta=-5.500109 -> V=1.0, theta=0.0
% INFO    : Bus 93708	: V=1.0201851, theta=-1.321924 -> V=1.0, theta=0.0
% INFO    : Bus 93709	: V=1.0198747, theta=-1.860549 -> V=1.0, theta=0.0
% INFO    : Bus 93710	: V=1.0241707, theta=2.05494 -> V=1.0, theta=0.0
% INFO    : Bus 93711	: V=0.9929406, theta=2.762958 -> V=1.0, theta=0.0
% INFO    : Bus 93712	: V=0.9860417, theta=7.304694 -> V=1.0, theta=0.0
% INFO    : Bus 93713	: V=0.9931109, theta=8.406216 -> V=1.0, theta=0.0
% INFO    : Bus 93714	: V=0.9895005, theta=8.981654 -> V=1.0, theta=0.0
% INFO    : Bus 93715	: V=0.9921309, theta=8.535507 -> V=1.0, theta=0.0
% INFO    : Bus 93716	: V=0.991279, theta=8.388645 -> V=1.0, theta=0.0
% INFO    : Bus 93717	: V=0.9839777, theta=6.928391 -> V=1.0, theta=0.0
% INFO    : Bus 93718	: V=0.9891864, theta=8.37543 -> V=1.0, theta=0.0
% INFO    : Bus 93719	: V=0.9904781, theta=8.335565 -> V=1.0, theta=0.0
% INFO    : Bus 93720	: V=0.9892639, theta=8.426162 -> V=1.0, theta=0.0
% INFO    : Bus 93721	: V=0.9920189, theta=9.403555 -> V=1.0, theta=0.0
% INFO    : Bus 93722	: V=0.9992262, theta=9.079352 -> V=1.0, theta=0.0
% INFO    : Bus 93723	: V=0.9885041, theta=6.869091 -> V=1.0, theta=0.0
% INFO    : Bus 93724	: V=0.9924375, theta=11.052548 -> V=1.0, theta=0.0
% INFO    : Bus 93725	: V=0.9939129, theta=8.430983 -> V=1.0, theta=0.0
% INFO    : Bus 93726	: V=0.9875716, theta=7.97353 -> V=1.0, theta=0.0
% INFO    : Bus 93727	: V=0.9920429, theta=8.908855 -> V=1.0, theta=0.0
% INFO    : Bus 93728	: V=1.01536, theta=-3.778001 -> V=1.0, theta=0.0
% INFO    : Bus 93729	: V=1.0140175, theta=-4.218868 -> V=1.0, theta=0.0
% INFO    : Bus 93730	: V=1.0082535, theta=-4.73846 -> V=1.0, theta=0.0
% INFO    : Bus 93731	: V=1.0097755, theta=-4.868172 -> V=1.0, theta=0.0
% INFO    : Bus 93732	: V=1.0084578, theta=-4.909702 -> V=1.0, theta=0.0
% INFO    : Bus 93733	: V=1.008729, theta=-4.828011 -> V=1.0, theta=0.0
% INFO    : Bus 93734	: V=1.0095265, theta=-4.795267 -> V=1.0, theta=0.0
% INFO    : Bus 93735	: V=0.9822537, theta=5.614344 -> V=1.0, theta=0.0
% INFO    : Bus 93736	: V=0.9932842, theta=-1.046971 -> V=1.0, theta=0.0
% INFO    : Bus 93737	: V=1.0079131, theta=-11.260053 -> V=1.0, theta=0.0
% INFO    : Bus 93738	: V=1.0056374, theta=-11.773603 -> V=1.0, theta=0.0
% INFO    : Bus 93739	: V=0.9929057, theta=-0.875472 -> V=1.0, theta=0.0
% INFO    : Bus 93740	: V=1.0200324, theta=-3.994945 -> V=1.0, theta=0.0
% INFO    : Bus 93741	: V=1.0030166, theta=-14.721031 -> V=1.0, theta=0.0
% INFO    : Bus 93742	: V=1.0022047, theta=-15.24708 -> V=1.0, theta=0.0
% INFO    : Bus 93743	: V=0.9840781, theta=4.077946 -> V=1.0, theta=0.0
% INFO    : Bus 93744	: V=0.9860409, theta=4.655528 -> V=1.0, theta=0.0
% INFO    : Bus 93745	: V=0.9912409, theta=8.827602 -> V=1.0, theta=0.0
% INFO    : Bus 93746	: V=0.9899468, theta=8.355653 -> V=1.0, theta=0.0
% INFO    : Bus 93747	: V=1.0160364, theta=2.467693 -> V=1.0, theta=0.0
% INFO    : Bus 93748	: V=1.0070353, theta=4.732627 -> V=1.0, theta=0.0
% INFO    : Bus 93749	: V=0.9793074, theta=1.392193 -> V=1.0, theta=0.0
% INFO    : Bus 93750	: V=0.9815231, theta=-0.1051 -> V=1.0, theta=0.0
% INFO    : Bus 93751	: V=0.979201, theta=0.428638 -> V=1.0, theta=0.0
% INFO    : Bus 93752	: V=0.9927259, theta=-68.249178 -> V=1.0, theta=0.0
% INFO    : Bus 93753	: V=0.9692107, theta=-68.579743 -> V=1.0, theta=0.0
% INFO    : Bus 93754	: V=0.9820226, theta=-67.764643 -> V=1.0, theta=0.0
% INFO    : Bus 93755	: V=0.9968417, theta=-57.15814 -> V=1.0, theta=0.0
% INFO    : Bus 93756	: V=0.9934431, theta=-57.455057 -> V=1.0, theta=0.0
% INFO    : Bus 93757	: V=0.9885147, theta=-57.877658 -> V=1.0, theta=0.0
% INFO    : Bus 93758	: V=0.9594335, theta=-69.85889 -> V=1.0, theta=0.0
% INFO    : Bus 93759	: V=0.9466181, theta=-73.017754 -> V=1.0, theta=0.0
% INFO    : Bus 93760	: V=0.974971, theta=-68.770184 -> V=1.0, theta=0.0
% INFO    : Bus 93761	: V=0.971368, theta=-69.583759 -> V=1.0, theta=0.0
% INFO    : Bus 93762	: V=0.982195, theta=-61.382939 -> V=1.0, theta=0.0
% INFO    : Bus 93763	: V=0.9833126, theta=-70.766807 -> V=1.0, theta=0.0
% INFO    : Bus 93764	: V=0.9837482, theta=-69.972453 -> V=1.0, theta=0.0
% INFO    : Bus 93765	: V=0.9999113, theta=-70.449094 -> V=1.0, theta=0.0
% INFO    : Bus 93766	: V=0.9958177, theta=-70.902443 -> V=1.0, theta=0.0
% INFO    : Bus 93767	: V=0.9808676, theta=-73.453994 -> V=1.0, theta=0.0
% INFO    : Bus 93768	: V=0.9769922, theta=-71.49293 -> V=1.0, theta=0.0
% INFO    : Bus 93769	: V=0.9834288, theta=-70.986241 -> V=1.0, theta=0.0
% INFO    : Bus 93770	: V=0.999071, theta=-69.52032 -> V=1.0, theta=0.0
% INFO    : Bus 93771	: V=0.9935709, theta=-58.29832 -> V=1.0, theta=0.0
% INFO    : Bus 93772	: V=0.9698512, theta=-65.227732 -> V=1.0, theta=0.0
% INFO    : Bus 93773	: V=0.9532855, theta=-74.752511 -> V=1.0, theta=0.0
% INFO    : Bus 93774	: V=0.9544555, theta=-74.739201 -> V=1.0, theta=0.0
% INFO    : Bus 93775	: V=0.9510519, theta=-74.953091 -> V=1.0, theta=0.0
% INFO    : Bus 93776	: V=0.9525494, theta=-75.391849 -> V=1.0, theta=0.0
% INFO    : Bus 93777	: V=0.9537081, theta=-75.151993 -> V=1.0, theta=0.0
% INFO    : Bus 93778	: V=0.9568606, theta=-74.216944 -> V=1.0, theta=0.0
% INFO    : Bus 93779	: V=0.956038, theta=-72.999739 -> V=1.0, theta=0.0
% INFO    : Bus 93780	: V=0.9628503, theta=-71.143958 -> V=1.0, theta=0.0
% INFO    : Bus 93781	: V=0.9624584, theta=-70.784011 -> V=1.0, theta=0.0
% INFO    : Bus 93782	: V=0.96405, theta=-70.501562 -> V=1.0, theta=0.0
% INFO    : Bus 93783	: V=0.9720141, theta=-69.166477 -> V=1.0, theta=0.0
% INFO    : Bus 93784	: V=0.9820265, theta=-67.939646 -> V=1.0, theta=0.0
% INFO    : Bus 93785	: V=0.9746889, theta=-68.94087 -> V=1.0, theta=0.0
% INFO    : Bus 93786	: V=0.969547, theta=-69.441174 -> V=1.0, theta=0.0
% INFO    : Bus 93787	: V=0.9720746, theta=-68.880649 -> V=1.0, theta=0.0
% INFO    : Bus 93788	: V=0.9670573, theta=-69.975254 -> V=1.0, theta=0.0
% INFO    : Bus 93789	: V=0.9687989, theta=-69.464441 -> V=1.0, theta=0.0
% INFO    : Bus 93790	: V=0.964331, theta=-73.741926 -> V=1.0, theta=0.0
% INFO    : Bus 93791	: V=0.9683698, theta=-73.03845 -> V=1.0, theta=0.0
% INFO    : Bus 93792	: V=0.9624921, theta=-73.964607 -> V=1.0, theta=0.0
% INFO    : Bus 93793	: V=0.97462, theta=-72.305021 -> V=1.0, theta=0.0
% INFO    : Bus 93794	: V=0.9698935, theta=-73.053644 -> V=1.0, theta=0.0
% INFO    : Bus 93795	: V=0.9629698, theta=-73.484126 -> V=1.0, theta=0.0
% INFO    : Bus 93796	: V=0.9588548, theta=-74.305561 -> V=1.0, theta=0.0
% INFO    : Bus 93797	: V=0.9640079, theta=-73.867214 -> V=1.0, theta=0.0
% INFO    : Bus 93798	: V=0.9788069, theta=-71.540667 -> V=1.0, theta=0.0
% INFO    : Bus 93799	: V=0.9934411, theta=-69.724836 -> V=1.0, theta=0.0
% INFO    : Bus 93800	: V=0.9905328, theta=-70.345443 -> V=1.0, theta=0.0
% INFO    : Bus 93801	: V=0.9680649, theta=-73.081191 -> V=1.0, theta=0.0
% INFO    : Bus 93802	: V=0.9742935, theta=-71.855801 -> V=1.0, theta=0.0
% INFO    : Bus 93803	: V=0.97523, theta=-71.937872 -> V=1.0, theta=0.0
% INFO    : Bus 93804	: V=0.9609147, theta=-74.27178 -> V=1.0, theta=0.0
% INFO    : Bus 93805	: V=0.9789003, theta=-71.739548 -> V=1.0, theta=0.0
% INFO    : Bus 93806	: V=0.9715398, theta=-72.770554 -> V=1.0, theta=0.0
% INFO    : Bus 93807	: V=0.9930841, theta=-69.792592 -> V=1.0, theta=0.0
% INFO    : Bus 93808	: V=0.9811572, theta=-71.442962 -> V=1.0, theta=0.0
% INFO    : Bus 93809	: V=0.9738944, theta=-72.50733 -> V=1.0, theta=0.0
% INFO    : Bus 93810	: V=0.9876303, theta=-70.531441 -> V=1.0, theta=0.0
% INFO    : Bus 93811	: V=0.9960719, theta=-69.771373 -> V=1.0, theta=0.0
% INFO    : Bus 93812	: V=0.9977204, theta=-69.629945 -> V=1.0, theta=0.0
% INFO    : Bus 93813	: V=0.9658632, theta=-71.740695 -> V=1.0, theta=0.0
% INFO    : Bus 93814	: V=0.986647, theta=-70.651409 -> V=1.0, theta=0.0
% INFO    : Bus 93815	: V=0.9779563, theta=-71.707423 -> V=1.0, theta=0.0
% INFO    : Bus 93816	: V=0.9744679, theta=-72.410696 -> V=1.0, theta=0.0
% INFO    : Bus 93817	: V=0.981055, theta=-71.43034 -> V=1.0, theta=0.0
% INFO    : Bus 93818	: V=0.9858146, theta=-71.315576 -> V=1.0, theta=0.0
% INFO    : Bus 93819	: V=0.9901782, theta=-70.441059 -> V=1.0, theta=0.0
% INFO    : Bus 93820	: V=0.967224, theta=-73.506137 -> V=1.0, theta=0.0
% INFO    : Bus 93821	: V=0.9772192, theta=-72.223528 -> V=1.0, theta=0.0
% INFO    : Bus 93822	: V=0.9811751, theta=-72.012511 -> V=1.0, theta=0.0
% INFO    : Bus 93823	: V=0.9820046, theta=-71.897883 -> V=1.0, theta=0.0
% INFO    : Bus 93824	: V=0.9851905, theta=-71.702463 -> V=1.0, theta=0.0
% INFO    : Bus 93825	: V=0.9915563, theta=-69.982769 -> V=1.0, theta=0.0
% INFO    : Bus 93826	: V=0.996326, theta=-69.912876 -> V=1.0, theta=0.0
% INFO    : Bus 93827	: V=0.96884, theta=-73.19143 -> V=1.0, theta=0.0
% INFO    : Bus 93828	: V=0.9665794, theta=-73.318346 -> V=1.0, theta=0.0
% INFO    : Bus 93829	: V=0.9671181, theta=-73.882956 -> V=1.0, theta=0.0
% INFO    : Bus 93830	: V=0.9731832, theta=-72.726097 -> V=1.0, theta=0.0
% INFO    : Bus 93831	: V=0.9727066, theta=-72.383893 -> V=1.0, theta=0.0
% INFO    : Bus 93832	: V=0.9669288, theta=-73.532137 -> V=1.0, theta=0.0
% INFO    : Bus 93833	: V=0.9791339, theta=-72.520818 -> V=1.0, theta=0.0
% INFO    : Bus 93834	: V=0.9684026, theta=-74.095039 -> V=1.0, theta=0.0
% INFO    : Bus 93835	: V=0.969002, theta=-73.712103 -> V=1.0, theta=0.0
% INFO    : Bus 93836	: V=0.9693797, theta=-73.379546 -> V=1.0, theta=0.0
% INFO    : Bus 93837	: V=0.966574, theta=-73.460283 -> V=1.0, theta=0.0
% INFO    : Bus 93838	: V=0.967503, theta=-73.644808 -> V=1.0, theta=0.0
% INFO    : Bus 93839	: V=0.9660015, theta=-73.814867 -> V=1.0, theta=0.0
% INFO    : Bus 93840	: V=0.9713646, theta=-73.307809 -> V=1.0, theta=0.0
% INFO    : Bus 93841	: V=0.9634267, theta=-75.026593 -> V=1.0, theta=0.0
% INFO    : Bus 93842	: V=0.9577355, theta=-75.578513 -> V=1.0, theta=0.0
% INFO    : Bus 93843	: V=0.9545513, theta=-75.953212 -> V=1.0, theta=0.0
% INFO    : Bus 93844	: V=0.959705, theta=-75.170995 -> V=1.0, theta=0.0
% INFO    : Bus 93845	: V=0.9625954, theta=-74.211107 -> V=1.0, theta=0.0
% INFO    : Bus 93846	: V=0.9553357, theta=-75.640028 -> V=1.0, theta=0.0
% INFO    : Bus 93847	: V=0.9611144, theta=-74.110726 -> V=1.0, theta=0.0
% INFO    : Bus 93848	: V=0.9552814, theta=-75.736759 -> V=1.0, theta=0.0
% INFO    : Bus 93849	: V=0.9560115, theta=-75.689621 -> V=1.0, theta=0.0
% INFO    : Bus 93850	: V=0.9559558, theta=-75.723614 -> V=1.0, theta=0.0
% INFO    : Bus 93851	: V=0.9614061, theta=-74.442343 -> V=1.0, theta=0.0
% INFO    : Bus 93852	: V=0.9534205, theta=-76.152534 -> V=1.0, theta=0.0
% INFO    : Bus 93853	: V=0.9554139, theta=-75.72186 -> V=1.0, theta=0.0
% INFO    : Bus 93854	: V=0.9550628, theta=-75.728775 -> V=1.0, theta=0.0
% INFO    : Bus 93855	: V=0.9555654, theta=-75.820653 -> V=1.0, theta=0.0
% INFO    : Bus 93856	: V=0.9629744, theta=-74.341913 -> V=1.0, theta=0.0
% INFO    : Bus 93857	: V=0.9573297, theta=-75.615025 -> V=1.0, theta=0.0
% INFO    : Bus 93858	: V=0.9675852, theta=-73.100297 -> V=1.0, theta=0.0
% INFO    : Bus 93859	: V=0.9613571, theta=-73.972505 -> V=1.0, theta=0.0
% INFO    : Bus 93860	: V=0.9501578, theta=-75.551917 -> V=1.0, theta=0.0
% INFO    : Bus 93861	: V=0.9636, theta=-74.184576 -> V=1.0, theta=0.0
% INFO    : Bus 93862	: V=0.9800539, theta=-71.628214 -> V=1.0, theta=0.0
% INFO    : Bus 93863	: V=0.9545795, theta=-75.582177 -> V=1.0, theta=0.0
% INFO    : Bus 93864	: V=0.9772665, theta=-72.003221 -> V=1.0, theta=0.0
% INFO    : Bus 93865	: V=0.9587852, theta=-74.668907 -> V=1.0, theta=0.0
% INFO    : Bus 93866	: V=0.9564427, theta=-76.329125 -> V=1.0, theta=0.0
% INFO    : Bus 93867	: V=0.9723241, theta=-73.825554 -> V=1.0, theta=0.0
% INFO    : Bus 93868	: V=0.9678971, theta=-73.05427 -> V=1.0, theta=0.0
% INFO    : Bus 93869	: V=0.9621643, theta=-74.277494 -> V=1.0, theta=0.0
% INFO    : Bus 93870	: V=0.9810857, theta=-72.047488 -> V=1.0, theta=0.0
% INFO    : Bus 93871	: V=0.9867541, theta=-70.655503 -> V=1.0, theta=0.0
% INFO    : Bus 93872	: V=0.9920396, theta=-66.468327 -> V=1.0, theta=0.0
% INFO    : Bus 93873	: V=0.9623344, theta=-55.364378 -> V=1.0, theta=0.0
% INFO    : Bus 93874	: V=0.9790253, theta=-50.894096 -> V=1.0, theta=0.0
% INFO    : Bus 93875	: V=0.9840906, theta=-51.454273 -> V=1.0, theta=0.0
% INFO    : Bus 93876	: V=0.9870697, theta=-49.779543 -> V=1.0, theta=0.0
% INFO    : Bus 93877	: V=0.9900394, theta=-53.147154 -> V=1.0, theta=0.0
% INFO    : Bus 93878	: V=0.9504893, theta=-78.927711 -> V=1.0, theta=0.0
% INFO    : Bus 93879	: V=0.951229, theta=-78.09837 -> V=1.0, theta=0.0
% INFO    : Bus 93880	: V=0.9482001, theta=-79.746439 -> V=1.0, theta=0.0
% INFO    : Bus 93881	: V=0.9537699, theta=-77.90335 -> V=1.0, theta=0.0
% INFO    : Bus 93882	: V=0.9658959, theta=-74.935577 -> V=1.0, theta=0.0
% INFO    : Bus 93883	: V=0.9483025, theta=-78.188301 -> V=1.0, theta=0.0
% INFO    : Bus 93884	: V=0.9701105, theta=-75.337101 -> V=1.0, theta=0.0
% INFO    : Bus 93885	: V=0.9614357, theta=-75.853838 -> V=1.0, theta=0.0
% INFO    : Bus 93886	: V=0.9790118, theta=-75.22334 -> V=1.0, theta=0.0
% INFO    : Bus 93887	: V=0.998812, theta=-73.435855 -> V=1.0, theta=0.0
% INFO    : Bus 93888	: V=0.9991809, theta=-73.507108 -> V=1.0, theta=0.0
% INFO    : Bus 93889	: V=1.0087236, theta=-66.977511 -> V=1.0, theta=0.0
% INFO    : Bus 93890	: V=0.9980896, theta=-69.105953 -> V=1.0, theta=0.0
% INFO    : Bus 93891	: V=1.0118696, theta=-66.062551 -> V=1.0, theta=0.0
% INFO    : Bus 93892	: V=0.9987863, theta=-68.162379 -> V=1.0, theta=0.0
% INFO    : Bus 93893	: V=1.0060259, theta=-69.295572 -> V=1.0, theta=0.0
% INFO    : Bus 93894	: V=1.0039535, theta=-69.706232 -> V=1.0, theta=0.0
% INFO    : Bus 93895	: V=1.0013286, theta=-69.872558 -> V=1.0, theta=0.0
% INFO    : Bus 93896	: V=1.0068182, theta=-69.210701 -> V=1.0, theta=0.0
% INFO    : Bus 93897	: V=1.0056886, theta=-69.637584 -> V=1.0, theta=0.0
% INFO    : Bus 93898	: V=1.0065458, theta=-69.684493 -> V=1.0, theta=0.0
% INFO    : Bus 93899	: V=0.9901582, theta=-71.24345 -> V=1.0, theta=0.0
% INFO    : Bus 93900	: V=0.9420541, theta=-79.154136 -> V=1.0, theta=0.0
% INFO    : Bus 93901	: V=0.9950416, theta=-70.320314 -> V=1.0, theta=0.0
% INFO    : Bus 93902	: V=1.0005682, theta=-67.926023 -> V=1.0, theta=0.0
% INFO    : Bus 93903	: V=1.0098569, theta=-69.567696 -> V=1.0, theta=0.0
% INFO    : Bus 93904	: V=1.0104967, theta=-69.735227 -> V=1.0, theta=0.0
% INFO    : Bus 93905	: V=1.0122523, theta=-70.065914 -> V=1.0, theta=0.0
% INFO    : Bus 93906	: V=1.0050863, theta=-70.945021 -> V=1.0, theta=0.0
% INFO    : Bus 93907	: V=0.993613, theta=-71.80507 -> V=1.0, theta=0.0
% INFO    : Bus 93908	: V=0.9999058, theta=-71.146976 -> V=1.0, theta=0.0
% INFO    : Bus 93909	: V=0.9988912, theta=-71.225143 -> V=1.0, theta=0.0
% INFO    : Bus 93910	: V=0.9996693, theta=-71.102423 -> V=1.0, theta=0.0
% INFO    : Bus 93911	: V=0.9990588, theta=-71.107804 -> V=1.0, theta=0.0
% INFO    : Bus 93912	: V=0.9996139, theta=-70.729462 -> V=1.0, theta=0.0
% INFO    : Bus 93913	: V=1.0088827, theta=-70.392987 -> V=1.0, theta=0.0
% INFO    : Bus 93914	: V=1.0073844, theta=-70.559405 -> V=1.0, theta=0.0
% INFO    : Bus 93915	: V=1.0004333, theta=-71.184687 -> V=1.0, theta=0.0
% INFO    : Bus 93916	: V=1.0007376, theta=-71.166247 -> V=1.0, theta=0.0
% INFO    : Bus 93917	: V=0.9684751, theta=-65.916942 -> V=1.0, theta=0.0
% INFO    : Bus 93918	: V=1.0104349, theta=-53.398589 -> V=1.0, theta=0.0
% INFO    : Bus 93919	: V=1.009252, theta=-53.530299 -> V=1.0, theta=0.0
% INFO    : Bus 93920	: V=1.0100022, theta=-53.964858 -> V=1.0, theta=0.0
% INFO    : Bus 93921	: V=1.0089213, theta=-54.141295 -> V=1.0, theta=0.0
% INFO    : Bus 93922	: V=1.0080616, theta=-54.167506 -> V=1.0, theta=0.0
% INFO    : Bus 93923	: V=1.0071489, theta=-54.256145 -> V=1.0, theta=0.0
% INFO    : Bus 93924	: V=1.007448, theta=-54.267816 -> V=1.0, theta=0.0
% INFO    : Bus 93925	: V=1.0066367, theta=-54.521853 -> V=1.0, theta=0.0
% INFO    : Bus 93926	: V=1.0073734, theta=-54.369344 -> V=1.0, theta=0.0
% INFO    : Bus 93927	: V=0.9969952, theta=-70.320693 -> V=1.0, theta=0.0
% INFO    : Bus 93928	: V=1.0046513, theta=-69.237799 -> V=1.0, theta=0.0
% INFO    : Bus 93929	: V=1.002317, theta=-69.474213 -> V=1.0, theta=0.0
% INFO    : Bus 93930	: V=1.0054741, theta=-67.39209 -> V=1.0, theta=0.0
% INFO    : Bus 93931	: V=1.007115, theta=-67.530152 -> V=1.0, theta=0.0
% INFO    : Bus 93932	: V=1.0144643, theta=-61.42592 -> V=1.0, theta=0.0
% INFO    : Bus 93933	: V=1.0150078, theta=-61.378561 -> V=1.0, theta=0.0
% INFO    : Bus 93934	: V=1.0152107, theta=-50.229526 -> V=1.0, theta=0.0
% INFO    : Bus 93935	: V=1.0162287, theta=-51.553902 -> V=1.0, theta=0.0
% INFO    : Bus 93936	: V=0.987539, theta=-67.144679 -> V=1.0, theta=0.0
% INFO    : Bus 93937	: V=0.9621663, theta=-68.760419 -> V=1.0, theta=0.0
% INFO    : Bus 93938	: V=0.9912529, theta=-65.907946 -> V=1.0, theta=0.0
% INFO    : Bus 93939	: V=0.9896674, theta=-66.377463 -> V=1.0, theta=0.0
% INFO    : Bus 93940	: V=0.9620584, theta=-68.813145 -> V=1.0, theta=0.0
% INFO    : Bus 93941	: V=0.9826409, theta=-66.866474 -> V=1.0, theta=0.0
% INFO    : Bus 93942	: V=0.9779842, theta=-67.649863 -> V=1.0, theta=0.0
% INFO    : Bus 93943	: V=0.965784, theta=-68.400058 -> V=1.0, theta=0.0
% INFO    : Bus 93944	: V=0.9681098, theta=-67.4594 -> V=1.0, theta=0.0
% INFO    : Bus 93945	: V=0.9982009, theta=-70.145133 -> V=1.0, theta=0.0
% INFO    : Bus 93946	: V=0.99399, theta=-72.100682 -> V=1.0, theta=0.0
% INFO    : Bus 93947	: V=0.9840959, theta=-70.924806 -> V=1.0, theta=0.0
% INFO    : Bus 93948	: V=1.0050846, theta=-71.669284 -> V=1.0, theta=0.0
% INFO    : Bus 93949	: V=0.9847824, theta=-66.506849 -> V=1.0, theta=0.0
% INFO    : Bus 93950	: V=1.0126822, theta=-56.293503 -> V=1.0, theta=0.0
% INFO    : Bus 93951	: V=1.007171, theta=-57.376472 -> V=1.0, theta=0.0
% INFO    : Bus 93952	: V=0.9850676, theta=-54.76858 -> V=1.0, theta=0.0
% INFO    : Bus 93953	: V=0.9828815, theta=-55.401742 -> V=1.0, theta=0.0
% INFO    : Bus 93954	: V=0.9838521, theta=-58.834371 -> V=1.0, theta=0.0
% INFO    : Bus 93955	: V=0.9973269, theta=-76.121858 -> V=1.0, theta=0.0
% INFO    : Bus 93956	: V=1.0008176, theta=-75.478547 -> V=1.0, theta=0.0
% INFO    : Bus 93957	: V=1.0112078, theta=-74.771626 -> V=1.0, theta=0.0
% INFO    : Bus 93958	: V=1.0004308, theta=-73.901309 -> V=1.0, theta=0.0
% INFO    : Bus 93959	: V=0.9938847, theta=-61.875518 -> V=1.0, theta=0.0
% INFO    : Bus 93960	: V=0.9692144, theta=-65.902843 -> V=1.0, theta=0.0
% INFO    : Bus 93961	: V=0.9728323, theta=-65.533542 -> V=1.0, theta=0.0
% INFO    : Bus 93962	: V=0.9800235, theta=-64.711687 -> V=1.0, theta=0.0
% INFO    : Bus 93963	: V=0.9979808, theta=-56.874801 -> V=1.0, theta=0.0
% INFO    : Bus 93964	: V=0.9977895, theta=-51.847366 -> V=1.0, theta=0.0
% INFO    : Bus 93965	: V=0.9968324, theta=-52.357444 -> V=1.0, theta=0.0
% INFO    : Bus 93966	: V=0.9796305, theta=-69.18223 -> V=1.0, theta=0.0
% INFO    : Bus 93967	: V=0.9772352, theta=-71.643408 -> V=1.0, theta=0.0
% INFO    : Bus 93968	: V=0.9660639, theta=-75.267943 -> V=1.0, theta=0.0
% INFO    : Bus 93969	: V=0.9698373, theta=-73.822522 -> V=1.0, theta=0.0
% INFO    : Bus 93970	: V=0.9653689, theta=-75.681924 -> V=1.0, theta=0.0
% INFO    : Bus 93971	: V=0.9650564, theta=-76.563982 -> V=1.0, theta=0.0
% INFO    : Bus 93972	: V=0.9674659, theta=-75.062791 -> V=1.0, theta=0.0
% INFO    : Bus 93973	: V=0.9709129, theta=-73.920801 -> V=1.0, theta=0.0
% INFO    : Bus 93974	: V=0.9840023, theta=-71.470258 -> V=1.0, theta=0.0
% INFO    : Bus 93975	: V=0.9945649, theta=-70.437809 -> V=1.0, theta=0.0
% INFO    : Bus 93976	: V=0.9874131, theta=-72.472594 -> V=1.0, theta=0.0
% INFO    : Bus 93977	: V=0.9865909, theta=-72.510441 -> V=1.0, theta=0.0
% INFO    : Bus 93978	: V=0.9828089, theta=-73.532535 -> V=1.0, theta=0.0
% INFO    : Bus 93979	: V=0.990636, theta=-71.699157 -> V=1.0, theta=0.0
% INFO    : Bus 93980	: V=0.9886042, theta=-72.295848 -> V=1.0, theta=0.0
% INFO    : Bus 93981	: V=0.9833503, theta=-73.194627 -> V=1.0, theta=0.0
% INFO    : Bus 93982	: V=0.984067, theta=-73.181041 -> V=1.0, theta=0.0
% INFO    : Bus 93983	: V=0.9838162, theta=-73.36455 -> V=1.0, theta=0.0
% INFO    : Bus 93984	: V=0.9816438, theta=-72.15724 -> V=1.0, theta=0.0
% INFO    : Bus 93985	: V=0.983547, theta=-72.661392 -> V=1.0, theta=0.0
% INFO    : Bus 93986	: V=0.9825159, theta=-72.940336 -> V=1.0, theta=0.0
% INFO    : Bus 93987	: V=0.9781615, theta=-73.470062 -> V=1.0, theta=0.0
% INFO    : Bus 93988	: V=0.9786529, theta=-73.833872 -> V=1.0, theta=0.0
% INFO    : Bus 93989	: V=0.9753072, theta=-74.755112 -> V=1.0, theta=0.0
% INFO    : Bus 93990	: V=0.9701182, theta=-76.108513 -> V=1.0, theta=0.0
% INFO    : Bus 93991	: V=0.9727096, theta=-75.778516 -> V=1.0, theta=0.0
% INFO    : Bus 93992	: V=0.9690982, theta=-76.583129 -> V=1.0, theta=0.0
% INFO    : Bus 93993	: V=0.965879, theta=-76.891867 -> V=1.0, theta=0.0
% INFO    : Bus 93994	: V=0.9610859, theta=-78.706676 -> V=1.0, theta=0.0
% INFO    : Bus 93995	: V=0.9635434, theta=-77.860681 -> V=1.0, theta=0.0
% INFO    : Bus 93996	: V=0.9677708, theta=-76.694854 -> V=1.0, theta=0.0
% INFO    : Bus 93997	: V=0.9721969, theta=-75.841087 -> V=1.0, theta=0.0
% INFO    : Bus 93998	: V=0.9745799, theta=-74.924368 -> V=1.0, theta=0.0
% INFO    : Bus 93999	: V=0.9771717, theta=-74.737297 -> V=1.0, theta=0.0
% INFO    : Bus 94000	: V=0.9809496, theta=-73.711994 -> V=1.0, theta=0.0
% INFO    : Bus 94001	: V=0.9823937, theta=-73.546146 -> V=1.0, theta=0.0
% INFO    : Bus 94002	: V=0.9708909, theta=-75.835842 -> V=1.0, theta=0.0
% INFO    : Bus 94003	: V=0.9902698, theta=-69.895706 -> V=1.0, theta=0.0
% INFO    : Bus 94004	: V=0.9990879, theta=-69.224786 -> V=1.0, theta=0.0
% INFO    : Bus 94005	: V=0.9973005, theta=-69.479012 -> V=1.0, theta=0.0
% INFO    : Bus 94006	: V=0.9947409, theta=-69.720678 -> V=1.0, theta=0.0
% INFO    : Bus 94007	: V=0.9881727, theta=-70.751854 -> V=1.0, theta=0.0
% INFO    : Bus 94008	: V=0.9858085, theta=-71.166145 -> V=1.0, theta=0.0
% INFO    : Bus 94009	: V=1.0062591, theta=-68.42698 -> V=1.0, theta=0.0
% INFO    : Bus 94010	: V=0.9971488, theta=-69.667851 -> V=1.0, theta=0.0
% INFO    : Bus 94011	: V=1.0083941, theta=-57.597652 -> V=1.0, theta=0.0
% INFO    : Bus 94012	: V=0.9897067, theta=-58.618312 -> V=1.0, theta=0.0
% INFO    : Bus 94013	: V=0.9565748, theta=-71.128837 -> V=1.0, theta=0.0
% INFO    : Bus 94014	: V=0.9691357, theta=-69.676696 -> V=1.0, theta=0.0
% INFO    : Bus 94015	: V=0.9723563, theta=-68.11233 -> V=1.0, theta=0.0
% INFO    : Bus 94016	: V=0.960766, theta=-71.196379 -> V=1.0, theta=0.0
% INFO    : Bus 94017	: V=0.9649581, theta=-69.880406 -> V=1.0, theta=0.0
% INFO    : Bus 94018	: V=0.9753124, theta=-75.755638 -> V=1.0, theta=0.0
% INFO    : Bus 94019	: V=0.9685589, theta=-76.584428 -> V=1.0, theta=0.0
% INFO    : Bus 94020	: V=0.963908, theta=-77.173614 -> V=1.0, theta=0.0
% INFO    : Bus 94021	: V=0.9830022, theta=-73.995652 -> V=1.0, theta=0.0
% INFO    : Bus 94022	: V=0.9810133, theta=-74.631996 -> V=1.0, theta=0.0
% INFO    : Bus 94023	: V=0.9674869, theta=-76.977839 -> V=1.0, theta=0.0
% INFO    : Bus 94024	: V=0.9664882, theta=-76.988994 -> V=1.0, theta=0.0
% INFO    : Bus 94025	: V=0.9703356, theta=-76.4685 -> V=1.0, theta=0.0
% INFO    : Bus 94026	: V=0.9704661, theta=-76.4594 -> V=1.0, theta=0.0
% INFO    : Bus 94027	: V=0.971284, theta=-76.697868 -> V=1.0, theta=0.0
% INFO    : Bus 94028	: V=0.9755243, theta=-75.738484 -> V=1.0, theta=0.0
% INFO    : Bus 94029	: V=0.9741479, theta=-75.918164 -> V=1.0, theta=0.0
% INFO    : Bus 94030	: V=0.9695572, theta=-76.758092 -> V=1.0, theta=0.0
% INFO    : Bus 94031	: V=0.9667519, theta=-77.017754 -> V=1.0, theta=0.0
% INFO    : Bus 94032	: V=0.9739501, theta=-75.923946 -> V=1.0, theta=0.0
% INFO    : Bus 94033	: V=0.9721569, theta=-76.386163 -> V=1.0, theta=0.0
% INFO    : Bus 94034	: V=0.9748886, theta=-75.863738 -> V=1.0, theta=0.0
% INFO    : Bus 94035	: V=0.9714727, theta=-76.441606 -> V=1.0, theta=0.0
% INFO    : Bus 94036	: V=0.9652025, theta=-77.621272 -> V=1.0, theta=0.0
% INFO    : Bus 94037	: V=0.9649176, theta=-77.73434 -> V=1.0, theta=0.0
% INFO    : Bus 94038	: V=0.9712481, theta=-76.837019 -> V=1.0, theta=0.0
% INFO    : Bus 94039	: V=0.9722779, theta=-77.041032 -> V=1.0, theta=0.0
% INFO    : Bus 94040	: V=0.9719894, theta=-76.56079 -> V=1.0, theta=0.0
% INFO    : Bus 94041	: V=0.9707104, theta=-76.589647 -> V=1.0, theta=0.0
% INFO    : Bus 94042	: V=0.9715072, theta=-76.272415 -> V=1.0, theta=0.0
% INFO    : Bus 94043	: V=0.9716713, theta=-76.164542 -> V=1.0, theta=0.0
% INFO    : Bus 94044	: V=0.9700072, theta=-76.429989 -> V=1.0, theta=0.0
% INFO    : Bus 94045	: V=0.976605, theta=-75.755157 -> V=1.0, theta=0.0
% INFO    : Bus 94046	: V=0.9672627, theta=-77.351454 -> V=1.0, theta=0.0
% INFO    : Bus 94047	: V=0.9664105, theta=-77.518041 -> V=1.0, theta=0.0
% INFO    : Bus 94048	: V=0.9775434, theta=-75.683171 -> V=1.0, theta=0.0
% INFO    : Bus 94049	: V=0.9795485, theta=-75.230769 -> V=1.0, theta=0.0
% INFO    : Bus 94050	: V=0.9777908, theta=-75.622397 -> V=1.0, theta=0.0
% INFO    : Bus 94051	: V=0.9774644, theta=-75.650005 -> V=1.0, theta=0.0
% INFO    : Bus 94052	: V=0.9721559, theta=-76.641145 -> V=1.0, theta=0.0
% INFO    : Bus 94053	: V=0.9658563, theta=-77.143271 -> V=1.0, theta=0.0
% INFO    : Bus 94054	: V=0.9673693, theta=-77.626565 -> V=1.0, theta=0.0
% INFO    : Bus 94055	: V=0.9697832, theta=-76.885813 -> V=1.0, theta=0.0
% INFO    : Bus 94056	: V=0.9656414, theta=-77.592627 -> V=1.0, theta=0.0
% INFO    : Bus 94057	: V=0.9663318, theta=-77.329272 -> V=1.0, theta=0.0
% INFO    : Bus 94058	: V=0.9714893, theta=-76.190165 -> V=1.0, theta=0.0
% INFO    : Bus 94059	: V=0.9729733, theta=-75.872618 -> V=1.0, theta=0.0
% INFO    : Bus 94060	: V=0.9707269, theta=-76.520807 -> V=1.0, theta=0.0
% INFO    : Bus 94061	: V=0.9822013, theta=-74.005416 -> V=1.0, theta=0.0
% INFO    : Bus 94062	: V=0.9720959, theta=-76.033647 -> V=1.0, theta=0.0
% INFO    : Bus 94063	: V=0.9713635, theta=-76.351639 -> V=1.0, theta=0.0
% INFO    : Bus 94064	: V=0.975043, theta=-75.693076 -> V=1.0, theta=0.0
% INFO    : Bus 94065	: V=0.971885, theta=-76.568196 -> V=1.0, theta=0.0
% INFO    : Bus 94066	: V=0.9741119, theta=-76.482855 -> V=1.0, theta=0.0
% INFO    : Bus 94067	: V=0.9687138, theta=-77.294443 -> V=1.0, theta=0.0
% INFO    : Bus 94068	: V=0.9657663, theta=-78.334944 -> V=1.0, theta=0.0
% INFO    : Bus 94069	: V=0.9618183, theta=-78.368663 -> V=1.0, theta=0.0
% INFO    : Bus 94070	: V=0.9753067, theta=-76.119745 -> V=1.0, theta=0.0
% INFO    : Bus 94071	: V=0.9879581, theta=-73.748621 -> V=1.0, theta=0.0
% INFO    : Bus 94072	: V=0.9835319, theta=-74.58932 -> V=1.0, theta=0.0
% INFO    : Bus 94073	: V=0.9811091, theta=-75.197466 -> V=1.0, theta=0.0
% INFO    : Bus 94074	: V=0.9825838, theta=-74.714433 -> V=1.0, theta=0.0
% INFO    : Bus 94075	: V=0.9829957, theta=-74.633228 -> V=1.0, theta=0.0
% INFO    : Bus 94076	: V=0.9763076, theta=-75.721795 -> V=1.0, theta=0.0
% INFO    : Bus 94077	: V=0.9809213, theta=-74.812426 -> V=1.0, theta=0.0
% INFO    : Bus 94078	: V=0.9841918, theta=-74.346367 -> V=1.0, theta=0.0
% INFO    : Bus 94079	: V=0.9849766, theta=-73.979564 -> V=1.0, theta=0.0
% INFO    : Bus 94080	: V=0.9777067, theta=-75.494448 -> V=1.0, theta=0.0
% INFO    : Bus 94081	: V=0.9663522, theta=-77.234218 -> V=1.0, theta=0.0
% INFO    : Bus 94082	: V=0.9636197, theta=-78.427859 -> V=1.0, theta=0.0
% INFO    : Bus 94083	: V=0.9601524, theta=-78.826553 -> V=1.0, theta=0.0
% INFO    : Bus 94084	: V=0.9609953, theta=-78.942577 -> V=1.0, theta=0.0
% INFO    : Bus 94085	: V=0.966649, theta=-77.76353 -> V=1.0, theta=0.0
% INFO    : Bus 94086	: V=0.9661212, theta=-76.921661 -> V=1.0, theta=0.0
% INFO    : Bus 94087	: V=0.9651244, theta=-78.252767 -> V=1.0, theta=0.0
% INFO    : Bus 94088	: V=0.9605659, theta=-78.901897 -> V=1.0, theta=0.0
% INFO    : Bus 94089	: V=0.962825, theta=-77.853235 -> V=1.0, theta=0.0
% INFO    : Bus 94090	: V=0.9679517, theta=-77.044454 -> V=1.0, theta=0.0
% INFO    : Bus 94091	: V=0.9664731, theta=-77.359944 -> V=1.0, theta=0.0
% INFO    : Bus 94092	: V=0.966667, theta=-76.964375 -> V=1.0, theta=0.0
% INFO    : Bus 94093	: V=0.9778081, theta=-75.420039 -> V=1.0, theta=0.0
% INFO    : Bus 94094	: V=0.9789121, theta=-75.473082 -> V=1.0, theta=0.0
% INFO    : Bus 94095	: V=0.9701896, theta=-76.77952 -> V=1.0, theta=0.0
% INFO    : Bus 94096	: V=0.9635689, theta=-77.650806 -> V=1.0, theta=0.0
% INFO    : Bus 94097	: V=0.9633842, theta=-77.995528 -> V=1.0, theta=0.0
% INFO    : Bus 94098	: V=0.9729074, theta=-76.987218 -> V=1.0, theta=0.0
% INFO    : Bus 94099	: V=0.9705997, theta=-77.375362 -> V=1.0, theta=0.0
% INFO    : Bus 94100	: V=0.9629556, theta=-79.100364 -> V=1.0, theta=0.0
% INFO    : Bus 94101	: V=0.9615324, theta=-77.177184 -> V=1.0, theta=0.0
% INFO    : Bus 94102	: V=0.9627539, theta=-79.010527 -> V=1.0, theta=0.0
% INFO    : Bus 94103	: V=0.9613523, theta=-77.202137 -> V=1.0, theta=0.0
% INFO    : Bus 94104	: V=0.9655515, theta=-78.262521 -> V=1.0, theta=0.0
% INFO    : Bus 94105	: V=0.9652569, theta=-78.378325 -> V=1.0, theta=0.0
% INFO    : Bus 94106	: V=0.9654119, theta=-78.271346 -> V=1.0, theta=0.0
% INFO    : Bus 94107	: V=0.9649092, theta=-78.718408 -> V=1.0, theta=0.0
% INFO    : Bus 94108	: V=0.9618965, theta=-78.976629 -> V=1.0, theta=0.0
% INFO    : Bus 94109	: V=0.981096, theta=-75.544143 -> V=1.0, theta=0.0
% INFO    : Bus 94110	: V=0.981308, theta=-75.507479 -> V=1.0, theta=0.0
% INFO    : Bus 94111	: V=0.9891268, theta=-74.185641 -> V=1.0, theta=0.0
% INFO    : Bus 94112	: V=0.9862814, theta=-74.747553 -> V=1.0, theta=0.0
% INFO    : Bus 94113	: V=0.9874089, theta=-74.363079 -> V=1.0, theta=0.0
% INFO    : Bus 94114	: V=0.9868852, theta=-74.194624 -> V=1.0, theta=0.0
% INFO    : Bus 94115	: V=0.985372, theta=-74.581178 -> V=1.0, theta=0.0
% INFO    : Bus 94116	: V=0.9879756, theta=-74.263076 -> V=1.0, theta=0.0
% INFO    : Bus 94117	: V=0.980595, theta=-75.090585 -> V=1.0, theta=0.0
% INFO    : Bus 94118	: V=0.9882799, theta=-73.835115 -> V=1.0, theta=0.0
% INFO    : Bus 94119	: V=0.9865996, theta=-74.1981 -> V=1.0, theta=0.0
% INFO    : Bus 94120	: V=0.9860397, theta=-74.448485 -> V=1.0, theta=0.0
% INFO    : Bus 94121	: V=0.9816869, theta=-74.999195 -> V=1.0, theta=0.0
% INFO    : Bus 94122	: V=0.9964246, theta=-74.213704 -> V=1.0, theta=0.0
% INFO    : Bus 94123	: V=0.9941483, theta=-72.801405 -> V=1.0, theta=0.0
% INFO    : Bus 94124	: V=0.9978883, theta=-72.116513 -> V=1.0, theta=0.0
% INFO    : Bus 94125	: V=0.9923163, theta=-73.002151 -> V=1.0, theta=0.0
% INFO    : Bus 94126	: V=0.9875891, theta=-73.893324 -> V=1.0, theta=0.0
% INFO    : Bus 94127	: V=0.9895695, theta=-73.635334 -> V=1.0, theta=0.0
% INFO    : Bus 94128	: V=0.9852857, theta=-73.435642 -> V=1.0, theta=0.0
% INFO    : Bus 94129	: V=0.9892644, theta=-72.788702 -> V=1.0, theta=0.0
% INFO    : Bus 94130	: V=0.9918086, theta=-73.069579 -> V=1.0, theta=0.0
% INFO    : Bus 94131	: V=0.9839177, theta=-73.637599 -> V=1.0, theta=0.0
% INFO    : Bus 94132	: V=0.9881565, theta=-73.330895 -> V=1.0, theta=0.0
% INFO    : Bus 94133	: V=0.9917881, theta=-73.018309 -> V=1.0, theta=0.0
% INFO    : Bus 94134	: V=0.9903149, theta=-73.42434 -> V=1.0, theta=0.0
% INFO    : Bus 94135	: V=0.9826123, theta=-74.288614 -> V=1.0, theta=0.0
% INFO    : Bus 94136	: V=0.9784276, theta=-75.2383 -> V=1.0, theta=0.0
% INFO    : Bus 94137	: V=0.9813109, theta=-74.5584 -> V=1.0, theta=0.0
% INFO    : Bus 94138	: V=0.9781764, theta=-75.390992 -> V=1.0, theta=0.0
% INFO    : Bus 94139	: V=0.9797392, theta=-74.228786 -> V=1.0, theta=0.0
% INFO    : Bus 94140	: V=0.9732267, theta=-75.37294 -> V=1.0, theta=0.0
% INFO    : Bus 94141	: V=0.9691025, theta=-76.181157 -> V=1.0, theta=0.0
% INFO    : Bus 94142	: V=0.9750846, theta=-75.299741 -> V=1.0, theta=0.0
% INFO    : Bus 94143	: V=0.9729188, theta=-76.066099 -> V=1.0, theta=0.0
% INFO    : Bus 94144	: V=0.9680649, theta=-76.613708 -> V=1.0, theta=0.0
% INFO    : Bus 94145	: V=0.9663861, theta=-77.40977 -> V=1.0, theta=0.0
% INFO    : Bus 94146	: V=0.972285, theta=-76.09203 -> V=1.0, theta=0.0
% INFO    : Bus 94147	: V=0.9695587, theta=-76.679022 -> V=1.0, theta=0.0
% INFO    : Bus 94148	: V=0.9639446, theta=-77.496752 -> V=1.0, theta=0.0
% INFO    : Bus 94149	: V=0.9746429, theta=-76.193292 -> V=1.0, theta=0.0
% INFO    : Bus 94150	: V=0.9648372, theta=-77.29893 -> V=1.0, theta=0.0
% INFO    : Bus 94151	: V=0.9618748, theta=-78.705738 -> V=1.0, theta=0.0
% INFO    : Bus 94152	: V=0.9763658, theta=-75.430429 -> V=1.0, theta=0.0
% INFO    : Bus 94153	: V=0.9769128, theta=-75.556188 -> V=1.0, theta=0.0
% INFO    : Bus 94154	: V=0.9824297, theta=-58.89334 -> V=1.0, theta=0.0
% INFO    : Bus 94155	: V=0.9634627, theta=-74.244291 -> V=1.0, theta=0.0
% INFO    : Bus 94156	: V=0.9644581, theta=-75.677215 -> V=1.0, theta=0.0
% INFO    : Bus 94157	: V=0.9633019, theta=-76.372005 -> V=1.0, theta=0.0
% INFO    : Bus 94158	: V=0.9661303, theta=-75.484629 -> V=1.0, theta=0.0
% INFO    : Bus 94159	: V=0.9671408, theta=-74.829647 -> V=1.0, theta=0.0
% INFO    : Bus 94160	: V=0.9796191, theta=-73.147872 -> V=1.0, theta=0.0
% INFO    : Bus 94161	: V=0.9620403, theta=-74.05354 -> V=1.0, theta=0.0
% INFO    : Bus 94162	: V=0.96151, theta=-74.426798 -> V=1.0, theta=0.0
% INFO    : Bus 94163	: V=0.9703125, theta=-72.406693 -> V=1.0, theta=0.0
% INFO    : Bus 94164	: V=0.9690886, theta=-72.774629 -> V=1.0, theta=0.0
% INFO    : Bus 94165	: V=0.9626618, theta=-74.395834 -> V=1.0, theta=0.0
% INFO    : Bus 94166	: V=0.9610024, theta=-75.13609 -> V=1.0, theta=0.0
% INFO    : Bus 94167	: V=0.962283, theta=-74.666595 -> V=1.0, theta=0.0
% INFO    : Bus 94168	: V=0.9654623, theta=-74.489126 -> V=1.0, theta=0.0
% INFO    : Bus 94169	: V=0.9662439, theta=-74.418448 -> V=1.0, theta=0.0
% INFO    : Bus 94170	: V=0.9647119, theta=-76.830436 -> V=1.0, theta=0.0
% INFO    : Bus 94171	: V=0.9629435, theta=-74.848479 -> V=1.0, theta=0.0
% INFO    : Bus 94172	: V=0.9629084, theta=-74.969638 -> V=1.0, theta=0.0
% INFO    : Bus 94173	: V=0.9658543, theta=-75.658666 -> V=1.0, theta=0.0
% INFO    : Bus 94174	: V=0.9647982, theta=-77.230315 -> V=1.0, theta=0.0
% INFO    : Bus 94175	: V=0.964143, theta=-75.583707 -> V=1.0, theta=0.0
% INFO    : Bus 94176	: V=0.964439, theta=-75.544839 -> V=1.0, theta=0.0
% INFO    : Bus 94177	: V=0.96583, theta=-76.118108 -> V=1.0, theta=0.0
% INFO    : Bus 94178	: V=0.9613876, theta=-78.093817 -> V=1.0, theta=0.0
% INFO    : Bus 94179	: V=0.9646898, theta=-77.175003 -> V=1.0, theta=0.0
% INFO    : Bus 94180	: V=0.9650895, theta=-77.026521 -> V=1.0, theta=0.0
% INFO    : Bus 94181	: V=0.9648505, theta=-77.242066 -> V=1.0, theta=0.0
% INFO    : Bus 94182	: V=0.963484, theta=-77.725508 -> V=1.0, theta=0.0
% INFO    : Bus 94183	: V=0.9638408, theta=-78.325368 -> V=1.0, theta=0.0
% INFO    : Bus 94184	: V=0.9655146, theta=-76.977004 -> V=1.0, theta=0.0
% INFO    : Bus 94185	: V=1.0070353, theta=-63.685507 -> V=1.0, theta=0.0
% INFO    : Bus 94186	: V=1.0047369, theta=-63.948025 -> V=1.0, theta=0.0
% INFO    : Bus 94187	: V=0.9825854, theta=-70.855228 -> V=1.0, theta=0.0
% INFO    : Bus 94188	: V=1.0174248, theta=-56.806204 -> V=1.0, theta=0.0
% INFO    : Bus 94189	: V=1.0163257, theta=-56.967506 -> V=1.0, theta=0.0
% INFO    : Bus 94190	: V=1.0121186, theta=-54.592612 -> V=1.0, theta=0.0
% INFO    : Bus 94191	: V=1.0078446, theta=-56.074719 -> V=1.0, theta=0.0
% INFO    : Bus 94192	: V=1.0023908, theta=-56.638149 -> V=1.0, theta=0.0
% INFO    : Bus 94193	: V=1.0015382, theta=-57.093906 -> V=1.0, theta=0.0
% INFO    : Bus 94194	: V=1.0046593, theta=-56.413561 -> V=1.0, theta=0.0
% INFO    : Bus 94195	: V=1.0097866, theta=-55.911181 -> V=1.0, theta=0.0
% INFO    : Bus 94196	: V=1.0057684, theta=-56.542691 -> V=1.0, theta=0.0
% INFO    : Bus 94197	: V=1.0013811, theta=-56.654212 -> V=1.0, theta=0.0
% INFO    : Bus 94198	: V=1.008944, theta=-56.087245 -> V=1.0, theta=0.0
% INFO    : Bus 94199	: V=1.0006042, theta=-56.972604 -> V=1.0, theta=0.0
% INFO    : Bus 94200	: V=1.0095764, theta=-56.238813 -> V=1.0, theta=0.0
% INFO    : Bus 94201	: V=0.9887772, theta=-57.317822 -> V=1.0, theta=0.0
% INFO    : Bus 94202	: V=1.0092581, theta=-56.062964 -> V=1.0, theta=0.0
% INFO    : Bus 94203	: V=1.0065314, theta=-56.424064 -> V=1.0, theta=0.0
% INFO    : Bus 94204	: V=0.9638581, theta=-78.287834 -> V=1.0, theta=0.0
% INFO    : Bus 94205	: V=0.9656874, theta=-78.132214 -> V=1.0, theta=0.0
% INFO    : Bus 94206	: V=0.9694949, theta=-77.05648 -> V=1.0, theta=0.0
% INFO    : Bus 94207	: V=0.9688302, theta=-76.532582 -> V=1.0, theta=0.0
% INFO    : Bus 94208	: V=0.9694891, theta=-76.117316 -> V=1.0, theta=0.0
% INFO    : Bus 94209	: V=0.9664314, theta=-76.212642 -> V=1.0, theta=0.0
% INFO    : Bus 94210	: V=0.9647896, theta=-77.392953 -> V=1.0, theta=0.0
% INFO    : Bus 94211	: V=0.969665, theta=-75.138163 -> V=1.0, theta=0.0
% INFO    : Bus 94212	: V=1.0113281, theta=-73.223359 -> V=1.0, theta=0.0
% INFO    : Bus 94213	: V=1.0091833, theta=-73.589671 -> V=1.0, theta=0.0
% INFO    : Bus 94214	: V=1.0092274, theta=-73.53 -> V=1.0, theta=0.0
% INFO    : Bus 94215	: V=1.0059212, theta=-74.029509 -> V=1.0, theta=0.0
% INFO    : Bus 94216	: V=1.004112, theta=-74.57467 -> V=1.0, theta=0.0
% INFO    : Bus 94217	: V=1.0066689, theta=-73.920919 -> V=1.0, theta=0.0
% INFO    : Bus 94218	: V=1.0018116, theta=-74.849208 -> V=1.0, theta=0.0
% INFO    : Bus 94219	: V=1.0017704, theta=-75.465439 -> V=1.0, theta=0.0
% INFO    : Bus 94220	: V=0.9999262, theta=-75.641395 -> V=1.0, theta=0.0
% INFO    : Bus 94221	: V=0.996258, theta=-75.485215 -> V=1.0, theta=0.0
% INFO    : Bus 94222	: V=1.0003649, theta=-73.644951 -> V=1.0, theta=0.0
% INFO    : Bus 94223	: V=1.0000125, theta=-74.644075 -> V=1.0, theta=0.0
% INFO    : Bus 94224	: V=0.9988626, theta=-74.818788 -> V=1.0, theta=0.0
% INFO    : Bus 94225	: V=0.9983579, theta=-73.846351 -> V=1.0, theta=0.0
% INFO    : Bus 94226	: V=0.9989275, theta=-74.366181 -> V=1.0, theta=0.0
% INFO    : Bus 94227	: V=0.9998921, theta=-74.472597 -> V=1.0, theta=0.0
% INFO    : Bus 94228	: V=0.989519, theta=-75.969696 -> V=1.0, theta=0.0
% INFO    : Bus 94229	: V=0.9908148, theta=-74.948767 -> V=1.0, theta=0.0
% INFO    : Bus 94230	: V=0.9907035, theta=-74.953262 -> V=1.0, theta=0.0
% INFO    : Bus 94231	: V=0.9958292, theta=-75.258067 -> V=1.0, theta=0.0
% INFO    : Bus 94232	: V=0.9955562, theta=-75.051462 -> V=1.0, theta=0.0
% INFO    : Bus 94233	: V=0.9919946, theta=-75.737911 -> V=1.0, theta=0.0
% INFO    : Bus 94234	: V=0.9923805, theta=-75.559448 -> V=1.0, theta=0.0
% INFO    : Bus 94235	: V=1.0025861, theta=-73.231943 -> V=1.0, theta=0.0
% INFO    : Bus 94236	: V=1.015548, theta=-72.669305 -> V=1.0, theta=0.0
% INFO    : Bus 94237	: V=1.0094445, theta=-74.126485 -> V=1.0, theta=0.0
% INFO    : Bus 94238	: V=0.9917254, theta=-75.741916 -> V=1.0, theta=0.0
% INFO    : Bus 94239	: V=0.9905396, theta=-75.85734 -> V=1.0, theta=0.0
% INFO    : Bus 94240	: V=0.9910937, theta=-73.84651 -> V=1.0, theta=0.0
% INFO    : Bus 94241	: V=0.9900105, theta=-74.417975 -> V=1.0, theta=0.0
% INFO    : Bus 94242	: V=0.9902715, theta=-74.017141 -> V=1.0, theta=0.0
% INFO    : Bus 94243	: V=0.986065, theta=-76.260233 -> V=1.0, theta=0.0
% INFO    : Bus 94244	: V=0.9863467, theta=-73.064463 -> V=1.0, theta=0.0
% INFO    : Bus 94245	: V=0.9873555, theta=-76.903543 -> V=1.0, theta=0.0
% INFO    : Bus 94246	: V=1.0144114, theta=-59.742602 -> V=1.0, theta=0.0
% INFO    : Bus 94247	: V=1.0109023, theta=-60.144542 -> V=1.0, theta=0.0
% INFO    : Bus 94248	: V=1.0128372, theta=-60.117601 -> V=1.0, theta=0.0
% INFO    : Bus 94249	: V=0.9959354, theta=-62.758874 -> V=1.0, theta=0.0
% INFO    : Bus 94250	: V=0.9905981, theta=-63.06009 -> V=1.0, theta=0.0
% INFO    : Bus 94251	: V=0.9885188, theta=-62.984584 -> V=1.0, theta=0.0
% INFO    : Bus 94252	: V=1.0017681, theta=-70.03136 -> V=1.0, theta=0.0
% INFO    : Bus 94253	: V=0.9907176, theta=-70.302388 -> V=1.0, theta=0.0
% INFO    : Bus 94254	: V=0.9902453, theta=-71.11383 -> V=1.0, theta=0.0
% INFO    : Bus 94255	: V=1.0055941, theta=-59.364319 -> V=1.0, theta=0.0
% INFO    : Bus 94256	: V=0.9777616, theta=-73.142829 -> V=1.0, theta=0.0
% INFO    : Bus 94257	: V=0.9752386, theta=-73.055402 -> V=1.0, theta=0.0
% INFO    : Bus 94258	: V=0.9784961, theta=-72.775756 -> V=1.0, theta=0.0
% INFO    : Bus 94259	: V=0.973327, theta=-73.112042 -> V=1.0, theta=0.0
% INFO    : Bus 94260	: V=0.9897397, theta=-71.813443 -> V=1.0, theta=0.0
% INFO    : Bus 94261	: V=0.9894054, theta=-72.011586 -> V=1.0, theta=0.0
% INFO    : Bus 94262	: V=0.9826168, theta=-71.950025 -> V=1.0, theta=0.0
% INFO    : Bus 94263	: V=0.9882297, theta=-71.91269 -> V=1.0, theta=0.0
% INFO    : Bus 94264	: V=0.9712122, theta=-74.228004 -> V=1.0, theta=0.0
% INFO    : Bus 94265	: V=0.9682494, theta=-75.686442 -> V=1.0, theta=0.0
% INFO    : Bus 94266	: V=0.9735278, theta=-74.298151 -> V=1.0, theta=0.0
% INFO    : Bus 94267	: V=0.9642424, theta=-74.737095 -> V=1.0, theta=0.0
% INFO    : Bus 94268	: V=0.9646534, theta=-76.192663 -> V=1.0, theta=0.0
% INFO    : Bus 94269	: V=0.9603174, theta=-75.066983 -> V=1.0, theta=0.0
% INFO    : Bus 94270	: V=0.9658956, theta=-75.375758 -> V=1.0, theta=0.0
% INFO    : Bus 94271	: V=0.9784594, theta=-72.573777 -> V=1.0, theta=0.0
% INFO    : Bus 94272	: V=0.9828714, theta=-71.813342 -> V=1.0, theta=0.0
% INFO    : Bus 94273	: V=0.9925664, theta=-71.192385 -> V=1.0, theta=0.0
% INFO    : Bus 94274	: V=0.9891954, theta=-71.572562 -> V=1.0, theta=0.0
% INFO    : Bus 94275	: V=0.9904913, theta=-71.43434 -> V=1.0, theta=0.0
% INFO    : Bus 94276	: V=0.99092, theta=-71.261796 -> V=1.0, theta=0.0
% INFO    : Bus 94277	: V=0.9998254, theta=-70.113891 -> V=1.0, theta=0.0
% INFO    : Bus 94278	: V=0.9993191, theta=-70.224503 -> V=1.0, theta=0.0
% INFO    : Bus 94279	: V=0.9937598, theta=-70.767032 -> V=1.0, theta=0.0
% INFO    : Bus 94280	: V=0.9873102, theta=-71.358258 -> V=1.0, theta=0.0
% INFO    : Bus 94281	: V=0.9889261, theta=-70.372435 -> V=1.0, theta=0.0
% INFO    : Bus 94282	: V=0.9796027, theta=-71.92965 -> V=1.0, theta=0.0
% INFO    : Bus 94283	: V=0.9870955, theta=-70.475573 -> V=1.0, theta=0.0
% INFO    : Bus 94284	: V=0.9971158, theta=-70.026746 -> V=1.0, theta=0.0
% INFO    : Bus 94285	: V=0.9957354, theta=-70.001974 -> V=1.0, theta=0.0
% INFO    : Bus 94286	: V=0.9943381, theta=-69.636965 -> V=1.0, theta=0.0
% INFO    : Bus 94287	: V=0.9718421, theta=-71.391465 -> V=1.0, theta=0.0
% INFO    : Bus 94288	: V=1.0014343, theta=-57.857319 -> V=1.0, theta=0.0
% INFO    : Bus 94289	: V=1.0095353, theta=-57.597787 -> V=1.0, theta=0.0
% INFO    : Bus 94290	: V=1.0142497, theta=-66.44652 -> V=1.0, theta=0.0
% INFO    : Bus 94291	: V=1.0076146, theta=-67.196456 -> V=1.0, theta=0.0
% INFO    : Bus 94292	: V=1.003664, theta=-67.291304 -> V=1.0, theta=0.0
% INFO    : Bus 94293	: V=0.9971804, theta=-69.634829 -> V=1.0, theta=0.0
% INFO    : Bus 94294	: V=0.9933182, theta=-57.4286 -> V=1.0, theta=0.0
% INFO    : Bus 94295	: V=0.9538022, theta=-79.670379 -> V=1.0, theta=0.0
% INFO    : Bus 94296	: V=0.9508443, theta=-79.478059 -> V=1.0, theta=0.0
% INFO    : Bus 94297	: V=0.9488598, theta=-78.803175 -> V=1.0, theta=0.0
% INFO    : Bus 94298	: V=0.9500951, theta=-79.768554 -> V=1.0, theta=0.0
% INFO    : Bus 94299	: V=0.9701751, theta=-79.128482 -> V=1.0, theta=0.0
% INFO    : Bus 94300	: V=0.9532908, theta=-80.311643 -> V=1.0, theta=0.0
% INFO    : Bus 94301	: V=0.9710524, theta=-79.41201 -> V=1.0, theta=0.0
% INFO    : Bus 94302	: V=0.975855, theta=-78.395098 -> V=1.0, theta=0.0
% INFO    : Bus 94303	: V=1.0021874, theta=-75.978879 -> V=1.0, theta=0.0
% INFO    : Bus 94304	: V=0.9864507, theta=-76.887405 -> V=1.0, theta=0.0
% INFO    : Bus 94305	: V=0.963493, theta=-78.356146 -> V=1.0, theta=0.0
% INFO    : Bus 94306	: V=0.9847293, theta=-75.40163 -> V=1.0, theta=0.0
% INFO    : Bus 94307	: V=1.0017171, theta=-76.36987 -> V=1.0, theta=0.0
% INFO    : Bus 94308	: V=1.0009316, theta=-75.695859 -> V=1.0, theta=0.0
% INFO    : Bus 94309	: V=0.9978666, theta=-76.040547 -> V=1.0, theta=0.0
% INFO    : Bus 94310	: V=0.9930571, theta=-76.21515 -> V=1.0, theta=0.0
% INFO    : Bus 94311	: V=0.9882864, theta=-76.883241 -> V=1.0, theta=0.0
% INFO    : Bus 94312	: V=1.0016967, theta=-75.653724 -> V=1.0, theta=0.0
% INFO    : Bus 94313	: V=0.9979486, theta=-75.997244 -> V=1.0, theta=0.0
% INFO    : Bus 94314	: V=0.998738, theta=-76.727752 -> V=1.0, theta=0.0
% INFO    : Bus 94315	: V=0.9534003, theta=-74.092871 -> V=1.0, theta=0.0
% INFO    : Bus 94316	: V=1.000818, theta=-57.797682 -> V=1.0, theta=0.0
% INFO    : Bus 94317	: V=1.0058043, theta=-61.729502 -> V=1.0, theta=0.0
% INFO    : Bus 94318	: V=0.993422, theta=-62.40038 -> V=1.0, theta=0.0
% INFO    : Bus 94319	: V=0.9825753, theta=-63.613979 -> V=1.0, theta=0.0
% INFO    : Bus 94320	: V=0.9848591, theta=-63.412458 -> V=1.0, theta=0.0
% INFO    : Bus 94321	: V=0.9968832, theta=-62.3892 -> V=1.0, theta=0.0
% INFO    : Bus 94322	: V=0.9833878, theta=-63.53393 -> V=1.0, theta=0.0
% INFO    : Bus 94323	: V=0.9795822, theta=-64.046237 -> V=1.0, theta=0.0
% INFO    : Bus 94324	: V=0.9847249, theta=-63.877986 -> V=1.0, theta=0.0
% INFO    : Bus 94325	: V=0.9794803, theta=-64.458221 -> V=1.0, theta=0.0
% INFO    : Bus 94326	: V=0.9897601, theta=-65.371897 -> V=1.0, theta=0.0
% INFO    : Bus 94327	: V=0.9912394, theta=-65.135499 -> V=1.0, theta=0.0
% INFO    : Bus 94328	: V=0.9909952, theta=-66.310004 -> V=1.0, theta=0.0
% INFO    : Bus 94329	: V=0.9969483, theta=-58.160959 -> V=1.0, theta=0.0
% INFO    : Bus 94330	: V=0.9843301, theta=-59.81821 -> V=1.0, theta=0.0
% INFO    : Bus 94331	: V=0.9907541, theta=-59.531685 -> V=1.0, theta=0.0
% INFO    : Bus 94332	: V=1.0010941, theta=-58.217617 -> V=1.0, theta=0.0
% INFO    : Bus 94333	: V=1.0047313, theta=-58.195215 -> V=1.0, theta=0.0
% INFO    : Bus 94334	: V=1.0069058, theta=-57.85462 -> V=1.0, theta=0.0
% INFO    : Bus 94335	: V=1.0066378, theta=-57.844368 -> V=1.0, theta=0.0
% INFO    : Bus 94336	: V=0.9922148, theta=-58.82395 -> V=1.0, theta=0.0
% INFO    : Bus 94337	: V=0.9986237, theta=-58.700287 -> V=1.0, theta=0.0
% INFO    : Bus 94338	: V=1.0073073, theta=-58.542409 -> V=1.0, theta=0.0
% INFO    : Bus 94339	: V=1.0008241, theta=-59.363776 -> V=1.0, theta=0.0
% INFO    : Bus 94340	: V=0.9971811, theta=-59.744597 -> V=1.0, theta=0.0
% INFO    : Bus 94341	: V=0.9957535, theta=-71.985526 -> V=1.0, theta=0.0
% INFO    : Bus 94342	: V=0.9902447, theta=-73.725019 -> V=1.0, theta=0.0
% INFO    : Bus 94343	: V=0.9896669, theta=-70.303398 -> V=1.0, theta=0.0
% INFO    : Bus 94344	: V=0.9952919, theta=-69.958658 -> V=1.0, theta=0.0
% INFO    : Bus 94345	: V=0.9751788, theta=-72.024043 -> V=1.0, theta=0.0
% INFO    : Bus 94346	: V=0.994581, theta=-69.652047 -> V=1.0, theta=0.0
% INFO    : Bus 94347	: V=0.987554, theta=-70.06619 -> V=1.0, theta=0.0
% INFO    : Bus 94348	: V=0.9807663, theta=-71.0704 -> V=1.0, theta=0.0
% INFO    : Bus 94349	: V=0.9754516, theta=-72.016494 -> V=1.0, theta=0.0
% INFO    : Bus 94350	: V=0.9824631, theta=-70.993543 -> V=1.0, theta=0.0
% INFO    : Bus 94351	: V=0.9822566, theta=-70.994438 -> V=1.0, theta=0.0
% INFO    : Bus 94352	: V=0.9926809, theta=-69.557648 -> V=1.0, theta=0.0
% INFO    : Bus 94353	: V=1.0032864, theta=-58.643824 -> V=1.0, theta=0.0
% INFO    : Bus 94354	: V=1.0028994, theta=-58.665344 -> V=1.0, theta=0.0
% INFO    : Bus 94355	: V=0.9984063, theta=-58.992973 -> V=1.0, theta=0.0
% INFO    : Bus 94356	: V=1.0096438, theta=-57.775914 -> V=1.0, theta=0.0
% INFO    : Bus 94357	: V=0.9912088, theta=-59.302375 -> V=1.0, theta=0.0
% INFO    : Bus 94358	: V=0.9921634, theta=-60.501729 -> V=1.0, theta=0.0
% INFO    : Bus 94359	: V=1.011312, theta=-56.259462 -> V=1.0, theta=0.0
% INFO    : Bus 94360	: V=0.9774966, theta=-61.574542 -> V=1.0, theta=0.0
% INFO    : Bus 94361	: V=0.9842935, theta=-73.601833 -> V=1.0, theta=0.0
% INFO    : Bus 94362	: V=0.99126, theta=-72.26635 -> V=1.0, theta=0.0
% INFO    : Bus 94363	: V=0.9999377, theta=-70.40675 -> V=1.0, theta=0.0
% INFO    : Bus 94364	: V=0.9631436, theta=-78.395214 -> V=1.0, theta=0.0
% INFO    : Bus 94365	: V=0.9630773, theta=-78.430746 -> V=1.0, theta=0.0
% INFO    : Bus 94366	: V=0.957868, theta=-79.038961 -> V=1.0, theta=0.0
% INFO    : Bus 94367	: V=0.9598531, theta=-78.92858 -> V=1.0, theta=0.0
% INFO    : Bus 94368	: V=0.9617329, theta=-78.89687 -> V=1.0, theta=0.0
% INFO    : Bus 94369	: V=0.9594311, theta=-78.954363 -> V=1.0, theta=0.0
% INFO    : Bus 94370	: V=0.9538917, theta=-79.761493 -> V=1.0, theta=0.0
% INFO    : Bus 94371	: V=0.9567129, theta=-79.730672 -> V=1.0, theta=0.0
% INFO    : Bus 94372	: V=0.9586845, theta=-79.639189 -> V=1.0, theta=0.0
% INFO    : Bus 94373	: V=0.9841825, theta=-76.10406 -> V=1.0, theta=0.0
% INFO    : Bus 94374	: V=0.9656652, theta=-78.805928 -> V=1.0, theta=0.0
% INFO    : Bus 94375	: V=0.95673, theta=-79.655663 -> V=1.0, theta=0.0
% INFO    : Bus 94376	: V=0.9606824, theta=-78.821566 -> V=1.0, theta=0.0
% INFO    : Bus 94377	: V=0.9616117, theta=-78.682799 -> V=1.0, theta=0.0
% INFO    : Bus 94378	: V=0.9632076, theta=-78.49188 -> V=1.0, theta=0.0
% INFO    : Bus 94379	: V=0.9629813, theta=-78.321441 -> V=1.0, theta=0.0
% INFO    : Bus 94380	: V=0.9614187, theta=-78.552425 -> V=1.0, theta=0.0
% INFO    : Bus 94381	: V=0.9612716, theta=-78.406977 -> V=1.0, theta=0.0
% INFO    : Bus 94382	: V=0.9668183, theta=-77.833945 -> V=1.0, theta=0.0
% INFO    : Bus 94383	: V=0.9677873, theta=-77.698163 -> V=1.0, theta=0.0
% INFO    : Bus 94384	: V=0.9864244, theta=-75.834675 -> V=1.0, theta=0.0
% INFO    : Bus 94385	: V=0.9770635, theta=-76.846626 -> V=1.0, theta=0.0
% INFO    : Bus 94386	: V=0.9708228, theta=-77.6394 -> V=1.0, theta=0.0
% INFO    : Bus 94387	: V=0.9685546, theta=-78.073684 -> V=1.0, theta=0.0
% INFO    : Bus 94388	: V=0.9727452, theta=-78.242587 -> V=1.0, theta=0.0
% INFO    : Bus 94389	: V=0.9760719, theta=-77.807371 -> V=1.0, theta=0.0
% INFO    : Bus 94390	: V=0.9738385, theta=-78.052266 -> V=1.0, theta=0.0
% INFO    : Bus 94391	: V=0.9741256, theta=-77.981421 -> V=1.0, theta=0.0
% INFO    : Bus 94392	: V=0.977675, theta=-77.980338 -> V=1.0, theta=0.0
% INFO    : Bus 94393	: V=0.9724047, theta=-78.463865 -> V=1.0, theta=0.0
% INFO    : Bus 94394	: V=0.9723826, theta=-78.127601 -> V=1.0, theta=0.0
% INFO    : Bus 94395	: V=0.972537, theta=-78.023782 -> V=1.0, theta=0.0
% INFO    : Bus 94396	: V=0.994563, theta=-76.999879 -> V=1.0, theta=0.0
% INFO    : Bus 94397	: V=0.9924434, theta=-77.153629 -> V=1.0, theta=0.0
% INFO    : Bus 94398	: V=0.9819748, theta=-77.768248 -> V=1.0, theta=0.0
% INFO    : Bus 94399	: V=0.9748344, theta=-78.634 -> V=1.0, theta=0.0
% INFO    : Bus 94400	: V=0.9726552, theta=-78.767857 -> V=1.0, theta=0.0
% INFO    : Bus 94401	: V=0.9734807, theta=-78.771019 -> V=1.0, theta=0.0
% INFO    : Bus 94402	: V=0.9880715, theta=-77.435872 -> V=1.0, theta=0.0
% INFO    : Bus 94403	: V=0.9803789, theta=-78.021897 -> V=1.0, theta=0.0
% INFO    : Bus 94404	: V=0.9646292, theta=-79.11695 -> V=1.0, theta=0.0
% INFO    : Bus 94405	: V=0.9736791, theta=-78.37282 -> V=1.0, theta=0.0
% INFO    : Bus 94406	: V=0.9747184, theta=-78.435099 -> V=1.0, theta=0.0
% INFO    : Bus 94407	: V=0.9681408, theta=-77.605549 -> V=1.0, theta=0.0
% INFO    : Bus 94408	: V=0.987311, theta=-75.380227 -> V=1.0, theta=0.0
% INFO    : Bus 94409	: V=0.9789602, theta=-76.441359 -> V=1.0, theta=0.0
% INFO    : Bus 94410	: V=0.9773984, theta=-76.687788 -> V=1.0, theta=0.0
% INFO    : Bus 94411	: V=0.9681595, theta=-77.617308 -> V=1.0, theta=0.0
% INFO    : Bus 94412	: V=0.9697668, theta=-77.269102 -> V=1.0, theta=0.0
% INFO    : Bus 94413	: V=0.9686012, theta=-77.358915 -> V=1.0, theta=0.0
% INFO    : Bus 94414	: V=0.9640263, theta=-77.543031 -> V=1.0, theta=0.0
% INFO    : Bus 94415	: V=0.9591103, theta=-79.236234 -> V=1.0, theta=0.0
% INFO    : Bus 94416	: V=0.9604853, theta=-79.36295 -> V=1.0, theta=0.0
% INFO    : Bus 94417	: V=0.9643417, theta=-78.747576 -> V=1.0, theta=0.0
% INFO    : Bus 94418	: V=0.9611999, theta=-79.276065 -> V=1.0, theta=0.0
% INFO    : Bus 94419	: V=0.9659629, theta=-78.375626 -> V=1.0, theta=0.0
% INFO    : Bus 94420	: V=0.9653939, theta=-78.270822 -> V=1.0, theta=0.0
% INFO    : Bus 94421	: V=0.9670369, theta=-78.000563 -> V=1.0, theta=0.0
% INFO    : Bus 94422	: V=0.9760497, theta=-76.873637 -> V=1.0, theta=0.0
% INFO    : Bus 94423	: V=0.9880728, theta=-76.41161 -> V=1.0, theta=0.0
% INFO    : Bus 94424	: V=0.9912423, theta=-76.101505 -> V=1.0, theta=0.0
% INFO    : Bus 94425	: V=0.9976184, theta=-76.791876 -> V=1.0, theta=0.0
% INFO    : Bus 94426	: V=1.0105739, theta=-75.624076 -> V=1.0, theta=0.0
% INFO    : Bus 94427	: V=1.0022604, theta=-76.58232 -> V=1.0, theta=0.0
% INFO    : Bus 94428	: V=0.9887084, theta=-78.04428 -> V=1.0, theta=0.0
% INFO    : Bus 94429	: V=1.0026026, theta=-76.475514 -> V=1.0, theta=0.0
% INFO    : Bus 94430	: V=0.9956673, theta=-76.505515 -> V=1.0, theta=0.0
% INFO    : Bus 94431	: V=1.0113383, theta=-75.572924 -> V=1.0, theta=0.0
% INFO    : Bus 94432	: V=1.0108774, theta=-75.964341 -> V=1.0, theta=0.0
% INFO    : Bus 94433	: V=1.0154603, theta=-74.891372 -> V=1.0, theta=0.0
% INFO    : Bus 94434	: V=1.0105478, theta=-75.393709 -> V=1.0, theta=0.0
% INFO    : Bus 94435	: V=1.016636, theta=-74.594306 -> V=1.0, theta=0.0
% INFO    : Bus 94436	: V=1.0159559, theta=-74.82096 -> V=1.0, theta=0.0
% INFO    : Bus 94437	: V=1.0152921, theta=-74.964324 -> V=1.0, theta=0.0
% INFO    : Bus 94438	: V=1.0157943, theta=-74.927121 -> V=1.0, theta=0.0
% INFO    : Bus 94439	: V=1.0138172, theta=-75.125797 -> V=1.0, theta=0.0
% INFO    : Bus 94440	: V=1.015617, theta=-75.202603 -> V=1.0, theta=0.0
% INFO    : Bus 94441	: V=1.0132406, theta=-75.364628 -> V=1.0, theta=0.0
% INFO    : Bus 94442	: V=0.9531588, theta=-79.695945 -> V=1.0, theta=0.0
% INFO    : Bus 94443	: V=0.9553928, theta=-79.630937 -> V=1.0, theta=0.0
% INFO    : Bus 94444	: V=0.9525767, theta=-79.590914 -> V=1.0, theta=0.0
% INFO    : Bus 94445	: V=0.9550494, theta=-79.252564 -> V=1.0, theta=0.0
% INFO    : Bus 94446	: V=0.9570333, theta=-78.072549 -> V=1.0, theta=0.0
% INFO    : Bus 94447	: V=0.978266, theta=-74.745705 -> V=1.0, theta=0.0
% INFO    : Bus 94448	: V=0.961567, theta=-77.15453 -> V=1.0, theta=0.0
% INFO    : Bus 94449	: V=0.9600043, theta=-78.037232 -> V=1.0, theta=0.0
% INFO    : Bus 94450	: V=0.9515247, theta=-79.398794 -> V=1.0, theta=0.0
% INFO    : Bus 94451	: V=0.9571218, theta=-78.65268 -> V=1.0, theta=0.0
% INFO    : Bus 94452	: V=0.9550239, theta=-79.662491 -> V=1.0, theta=0.0
% INFO    : Bus 94453	: V=0.9683569, theta=-79.245379 -> V=1.0, theta=0.0
% INFO    : Bus 94454	: V=0.9545759, theta=-79.498375 -> V=1.0, theta=0.0
% INFO    : Bus 94455	: V=0.9608422, theta=-79.151856 -> V=1.0, theta=0.0
% INFO    : Bus 94456	: V=0.9708813, theta=-79.014471 -> V=1.0, theta=0.0
% INFO    : Bus 94457	: V=0.9588243, theta=-79.480119 -> V=1.0, theta=0.0
% INFO    : Bus 94458	: V=0.9782144, theta=-78.13587 -> V=1.0, theta=0.0
% INFO    : Bus 94459	: V=0.9792062, theta=-78.099171 -> V=1.0, theta=0.0
% INFO    : Bus 94460	: V=0.9885341, theta=-77.229877 -> V=1.0, theta=0.0
% INFO    : Bus 94461	: V=0.9777423, theta=-78.173331 -> V=1.0, theta=0.0
% INFO    : Bus 94462	: V=0.9785396, theta=-78.103583 -> V=1.0, theta=0.0
% INFO    : Bus 94463	: V=0.9778527, theta=-78.15725 -> V=1.0, theta=0.0
% INFO    : Bus 94464	: V=0.9646635, theta=-79.482729 -> V=1.0, theta=0.0
% INFO    : Bus 94465	: V=0.9656612, theta=-79.457833 -> V=1.0, theta=0.0
% INFO    : Bus 94466	: V=0.962994, theta=-79.46794 -> V=1.0, theta=0.0
% INFO    : Bus 94467	: V=0.9621796, theta=-79.5407 -> V=1.0, theta=0.0
% INFO    : Bus 94468	: V=0.9765118, theta=-78.132012 -> V=1.0, theta=0.0
% INFO    : Bus 94469	: V=0.9694954, theta=-78.784032 -> V=1.0, theta=0.0
% INFO    : Bus 94470	: V=0.9799806, theta=-73.635527 -> V=1.0, theta=0.0
% INFO    : Bus 94471	: V=0.9845492, theta=-72.291755 -> V=1.0, theta=0.0
% INFO    : Bus 94472	: V=0.9587267, theta=-76.37134 -> V=1.0, theta=0.0
% INFO    : Bus 94473	: V=0.9588002, theta=-78.314965 -> V=1.0, theta=0.0
% INFO    : Bus 94474	: V=0.9855499, theta=-76.229069 -> V=1.0, theta=0.0
% INFO    : Bus 94475	: V=0.9663397, theta=-77.702107 -> V=1.0, theta=0.0
% INFO    : Bus 94476	: V=0.9635981, theta=-78.695788 -> V=1.0, theta=0.0
% INFO    : Bus 94477	: V=0.9682614, theta=-76.896291 -> V=1.0, theta=0.0
% INFO    : Bus 94478	: V=0.9613056, theta=-78.293132 -> V=1.0, theta=0.0
% INFO    : Bus 94479	: V=0.9473783, theta=-79.222464 -> V=1.0, theta=0.0
% INFO    : Bus 94480	: V=0.948144, theta=-79.315269 -> V=1.0, theta=0.0
% INFO    : Bus 94481	: V=0.9521431, theta=-79.658318 -> V=1.0, theta=0.0
% INFO    : Bus 94482	: V=0.9724437, theta=-75.262849 -> V=1.0, theta=0.0
% INFO    : Bus 94483	: V=0.9692004, theta=-76.26605 -> V=1.0, theta=0.0
% INFO    : Bus 94484	: V=0.9757005, theta=-78.570972 -> V=1.0, theta=0.0
% INFO    : Bus 94485	: V=0.9689574, theta=-79.034989 -> V=1.0, theta=0.0
% INFO    : Bus 94486	: V=0.9636753, theta=-79.584625 -> V=1.0, theta=0.0
% INFO    : Bus 94487	: V=0.9615322, theta=-79.528154 -> V=1.0, theta=0.0
% INFO    : Bus 94488	: V=0.9588328, theta=-79.746846 -> V=1.0, theta=0.0
% INFO    : Bus 94489	: V=0.9580378, theta=-80.0367 -> V=1.0, theta=0.0
% INFO    : Bus 94490	: V=0.9727027, theta=-78.862774 -> V=1.0, theta=0.0
% INFO    : Bus 94491	: V=0.9607435, theta=-79.794047 -> V=1.0, theta=0.0
% INFO    : Bus 94492	: V=0.9722415, theta=-79.097105 -> V=1.0, theta=0.0
% INFO    : Bus 94493	: V=0.977032, theta=-78.597437 -> V=1.0, theta=0.0
% INFO    : Bus 94494	: V=0.9703452, theta=-79.57905 -> V=1.0, theta=0.0
% INFO    : Bus 94495	: V=0.9957501, theta=-76.84349 -> V=1.0, theta=0.0
% INFO    : Bus 94496	: V=0.9916372, theta=-77.343397 -> V=1.0, theta=0.0
% INFO    : Bus 94497	: V=0.9969573, theta=-76.79934 -> V=1.0, theta=0.0
% INFO    : Bus 94498	: V=0.9870678, theta=-79.552842 -> V=1.0, theta=0.0
% INFO    : Bus 94499	: V=0.9839752, theta=-77.792248 -> V=1.0, theta=0.0
% INFO    : Bus 94500	: V=1.0056383, theta=-75.952075 -> V=1.0, theta=0.0
% INFO    : Bus 94501	: V=1.013412, theta=-75.414928 -> V=1.0, theta=0.0
% INFO    : Bus 94502	: V=0.9955407, theta=-76.557065 -> V=1.0, theta=0.0
% INFO    : Bus 94503	: V=0.9764331, theta=-80.643597 -> V=1.0, theta=0.0
% INFO    : Bus 94504	: V=0.9739626, theta=-80.459143 -> V=1.0, theta=0.0
% INFO    : Bus 94505	: V=0.9523259, theta=-79.765575 -> V=1.0, theta=0.0
% INFO    : Bus 94506	: V=0.9485476, theta=-79.348546 -> V=1.0, theta=0.0
% INFO    : Bus 94507	: V=0.9560473, theta=-79.051286 -> V=1.0, theta=0.0
% INFO    : Bus 94508	: V=0.9560807, theta=-78.706044 -> V=1.0, theta=0.0
% INFO    : Bus 94509	: V=0.9559493, theta=-78.724102 -> V=1.0, theta=0.0
% INFO    : Bus 94510	: V=0.9583179, theta=-78.567851 -> V=1.0, theta=0.0
% INFO    : Bus 94511	: V=0.959816, theta=-77.563692 -> V=1.0, theta=0.0
% INFO    : Bus 94512	: V=0.9607018, theta=-77.15292 -> V=1.0, theta=0.0
% INFO    : Bus 94513	: V=0.9610656, theta=-77.52487 -> V=1.0, theta=0.0
% INFO    : Bus 94514	: V=0.9571461, theta=-77.880667 -> V=1.0, theta=0.0
% INFO    : Bus 94515	: V=0.9626205, theta=-76.556076 -> V=1.0, theta=0.0
% INFO    : Bus 94516	: V=0.9622439, theta=-77.010014 -> V=1.0, theta=0.0
% INFO    : Bus 94517	: V=0.9678893, theta=-74.564941 -> V=1.0, theta=0.0
% INFO    : Bus 94518	: V=0.9642706, theta=-76.506847 -> V=1.0, theta=0.0
% INFO    : Bus 94519	: V=0.9594912, theta=-77.290296 -> V=1.0, theta=0.0
% INFO    : Bus 94520	: V=0.956723, theta=-77.952626 -> V=1.0, theta=0.0
% INFO    : Bus 94521	: V=0.9575202, theta=-77.925584 -> V=1.0, theta=0.0
% INFO    : Bus 94522	: V=0.9562132, theta=-78.097216 -> V=1.0, theta=0.0
% INFO    : Bus 94523	: V=0.9563659, theta=-78.08656 -> V=1.0, theta=0.0
% INFO    : Bus 94524	: V=0.9626231, theta=-76.596524 -> V=1.0, theta=0.0
% INFO    : Bus 94525	: V=0.9632662, theta=-76.811489 -> V=1.0, theta=0.0
% INFO    : Bus 94526	: V=0.9595287, theta=-77.482637 -> V=1.0, theta=0.0
% INFO    : Bus 94527	: V=0.9624414, theta=-76.795643 -> V=1.0, theta=0.0
% INFO    : Bus 94528	: V=0.9616555, theta=-76.767495 -> V=1.0, theta=0.0
% INFO    : Bus 94529	: V=0.9827663, theta=-73.177663 -> V=1.0, theta=0.0
% INFO    : Bus 94530	: V=0.9673687, theta=-75.69401 -> V=1.0, theta=0.0
% INFO    : Bus 94531	: V=0.9663474, theta=-76.023556 -> V=1.0, theta=0.0
% INFO    : Bus 94532	: V=0.9700394, theta=-75.516399 -> V=1.0, theta=0.0
% INFO    : Bus 94533	: V=0.9627696, theta=-76.567334 -> V=1.0, theta=0.0
% INFO    : Bus 94534	: V=0.9569122, theta=-78.060813 -> V=1.0, theta=0.0
% INFO    : Bus 94535	: V=0.960212, theta=-77.213068 -> V=1.0, theta=0.0
% INFO    : Bus 94536	: V=0.9604918, theta=-77.22184 -> V=1.0, theta=0.0
% INFO    : Bus 94537	: V=0.9592809, theta=-77.719739 -> V=1.0, theta=0.0
% INFO    : Bus 94538	: V=0.9592235, theta=-77.715703 -> V=1.0, theta=0.0
% INFO    : Bus 94539	: V=0.9559789, theta=-78.120032 -> V=1.0, theta=0.0
% INFO    : Bus 94540	: V=0.9571809, theta=-78.064126 -> V=1.0, theta=0.0
% INFO    : Bus 94541	: V=0.9553118, theta=-78.269401 -> V=1.0, theta=0.0
% INFO    : Bus 94542	: V=0.9577156, theta=-77.88159 -> V=1.0, theta=0.0
% INFO    : Bus 94543	: V=0.9576467, theta=-77.632188 -> V=1.0, theta=0.0
% INFO    : Bus 94544	: V=0.9620323, theta=-76.862007 -> V=1.0, theta=0.0
% INFO    : Bus 94545	: V=0.9621726, theta=-76.824818 -> V=1.0, theta=0.0
% INFO    : Bus 94546	: V=0.9631341, theta=-76.747526 -> V=1.0, theta=0.0
% INFO    : Bus 94547	: V=0.9664606, theta=-76.335489 -> V=1.0, theta=0.0
% INFO    : Bus 94548	: V=0.9643266, theta=-76.914503 -> V=1.0, theta=0.0
% INFO    : Bus 94549	: V=0.9582316, theta=-77.242002 -> V=1.0, theta=0.0
% INFO    : Bus 94550	: V=0.9634364, theta=-76.770823 -> V=1.0, theta=0.0
% INFO    : Bus 94551	: V=0.9612259, theta=-76.930124 -> V=1.0, theta=0.0
% INFO    : Bus 94552	: V=0.9589318, theta=-77.003283 -> V=1.0, theta=0.0
% INFO    : Bus 94553	: V=0.9647427, theta=-76.109756 -> V=1.0, theta=0.0
% INFO    : Bus 94554	: V=0.9625377, theta=-76.778508 -> V=1.0, theta=0.0
% INFO    : Bus 94555	: V=0.9559605, theta=-77.378615 -> V=1.0, theta=0.0
% INFO    : Bus 94556	: V=0.9569269, theta=-77.115419 -> V=1.0, theta=0.0
% INFO    : Bus 94557	: V=0.9717456, theta=-74.754594 -> V=1.0, theta=0.0
% INFO    : Bus 94558	: V=0.9681035, theta=-75.742301 -> V=1.0, theta=0.0
% INFO    : Bus 94559	: V=0.9606082, theta=-76.80798 -> V=1.0, theta=0.0
% INFO    : Bus 94560	: V=0.9628024, theta=-76.639136 -> V=1.0, theta=0.0
% INFO    : Bus 94561	: V=0.9645637, theta=-76.480901 -> V=1.0, theta=0.0
% INFO    : Bus 94562	: V=0.9559393, theta=-79.075728 -> V=1.0, theta=0.0
% INFO    : Bus 94563	: V=0.9559729, theta=-79.047721 -> V=1.0, theta=0.0
% INFO    : Bus 94564	: V=0.9577906, theta=-78.885138 -> V=1.0, theta=0.0
% INFO    : Bus 94565	: V=0.9575268, theta=-78.875843 -> V=1.0, theta=0.0
% INFO    : Bus 94566	: V=0.9581283, theta=-78.846836 -> V=1.0, theta=0.0
% INFO    : Bus 94567	: V=0.9578339, theta=-78.948976 -> V=1.0, theta=0.0
% INFO    : Bus 94568	: V=0.9560781, theta=-78.511702 -> V=1.0, theta=0.0
% INFO    : Bus 94569	: V=0.9608468, theta=-78.332301 -> V=1.0, theta=0.0
% INFO    : Bus 94570	: V=0.9560343, theta=-78.31415 -> V=1.0, theta=0.0
% INFO    : Bus 94571	: V=0.9614676, theta=-77.692187 -> V=1.0, theta=0.0
% INFO    : Bus 94572	: V=0.9623401, theta=-77.669093 -> V=1.0, theta=0.0
% INFO    : Bus 94573	: V=0.9683814, theta=-76.785271 -> V=1.0, theta=0.0
% INFO    : Bus 94574	: V=0.968046, theta=-77.108021 -> V=1.0, theta=0.0
% INFO    : Bus 94575	: V=0.9620122, theta=-77.655613 -> V=1.0, theta=0.0
% INFO    : Bus 94576	: V=0.9603548, theta=-77.748684 -> V=1.0, theta=0.0
% INFO    : Bus 94577	: V=0.9561135, theta=-78.330304 -> V=1.0, theta=0.0
% INFO    : Bus 94578	: V=0.9575785, theta=-78.658567 -> V=1.0, theta=0.0
% INFO    : Bus 94579	: V=0.9582874, theta=-78.568086 -> V=1.0, theta=0.0
% INFO    : Bus 94580	: V=0.9590893, theta=-78.848997 -> V=1.0, theta=0.0
% INFO    : Bus 94581	: V=0.961659, theta=-78.374307 -> V=1.0, theta=0.0
% INFO    : Bus 94582	: V=0.9609028, theta=-78.415397 -> V=1.0, theta=0.0
% INFO    : Bus 94583	: V=0.9621131, theta=-78.257396 -> V=1.0, theta=0.0
% INFO    : Bus 94584	: V=0.9616614, theta=-78.240654 -> V=1.0, theta=0.0
% INFO    : Bus 94585	: V=0.9641609, theta=-77.961798 -> V=1.0, theta=0.0
% INFO    : Bus 94586	: V=0.9658298, theta=-77.878642 -> V=1.0, theta=0.0
% INFO    : Bus 94587	: V=0.9648312, theta=-78.018123 -> V=1.0, theta=0.0
% INFO    : Bus 94588	: V=0.9642481, theta=-78.03605 -> V=1.0, theta=0.0
% INFO    : Bus 94589	: V=0.9680364, theta=-77.599543 -> V=1.0, theta=0.0
% INFO    : Bus 94590	: V=0.9674396, theta=-77.583035 -> V=1.0, theta=0.0
% INFO    : Bus 94591	: V=0.9686871, theta=-77.56259 -> V=1.0, theta=0.0
% INFO    : Bus 94592	: V=0.9743578, theta=-76.760756 -> V=1.0, theta=0.0
% INFO    : Bus 94593	: V=0.974952, theta=-76.72516 -> V=1.0, theta=0.0
% INFO    : Bus 94594	: V=0.9785785, theta=-76.368604 -> V=1.0, theta=0.0
% INFO    : Bus 94595	: V=0.9678337, theta=-77.719983 -> V=1.0, theta=0.0
% INFO    : Bus 94596	: V=0.9672681, theta=-76.717231 -> V=1.0, theta=0.0
% INFO    : Bus 94597	: V=0.9661837, theta=-77.013866 -> V=1.0, theta=0.0
% INFO    : Bus 94598	: V=0.9561787, theta=-78.839397 -> V=1.0, theta=0.0
% INFO    : Bus 94599	: V=0.9530917, theta=-78.980294 -> V=1.0, theta=0.0
% INFO    : Bus 94600	: V=0.9607317, theta=-78.275641 -> V=1.0, theta=0.0
% INFO    : Bus 94601	: V=0.9572745, theta=-78.437717 -> V=1.0, theta=0.0
% INFO    : Bus 94602	: V=0.9582107, theta=-78.299024 -> V=1.0, theta=0.0
% INFO    : Bus 94603	: V=0.9603601, theta=-77.897062 -> V=1.0, theta=0.0
% INFO    : Bus 94604	: V=0.9555459, theta=-78.511796 -> V=1.0, theta=0.0
% INFO    : Bus 94605	: V=0.9562765, theta=-78.504548 -> V=1.0, theta=0.0
% INFO    : Bus 94606	: V=0.95936, theta=-77.74541 -> V=1.0, theta=0.0
% INFO    : Bus 94607	: V=0.9606915, theta=-77.679671 -> V=1.0, theta=0.0
% INFO    : Bus 94608	: V=0.9562732, theta=-77.112904 -> V=1.0, theta=0.0
% INFO    : Bus 94609	: V=0.9924833, theta=-72.845179 -> V=1.0, theta=0.0
% INFO    : Bus 94610	: V=0.9773165, theta=-75.00694 -> V=1.0, theta=0.0
% INFO    : Bus 94611	: V=0.975316, theta=-75.349588 -> V=1.0, theta=0.0
% INFO    : Bus 94612	: V=0.9784177, theta=-75.023125 -> V=1.0, theta=0.0
% INFO    : Bus 94613	: V=0.9691688, theta=-76.141408 -> V=1.0, theta=0.0
% INFO    : Bus 94614	: V=0.9638847, theta=-77.087927 -> V=1.0, theta=0.0
% INFO    : Bus 94615	: V=0.968929, theta=-77.325247 -> V=1.0, theta=0.0
% INFO    : Bus 94616	: V=0.9698934, theta=-77.268584 -> V=1.0, theta=0.0
% INFO    : Bus 94617	: V=0.9663405, theta=-77.591487 -> V=1.0, theta=0.0
% INFO    : Bus 94618	: V=0.9658057, theta=-78.389986 -> V=1.0, theta=0.0
% INFO    : Bus 94619	: V=0.9652939, theta=-77.731921 -> V=1.0, theta=0.0
% INFO    : Bus 94620	: V=0.9682164, theta=-77.370526 -> V=1.0, theta=0.0
% INFO    : Bus 94621	: V=0.9677931, theta=-77.414271 -> V=1.0, theta=0.0
% INFO    : Bus 94622	: V=0.9746233, theta=-76.745418 -> V=1.0, theta=0.0
% INFO    : Bus 94623	: V=0.9781785, theta=-76.344406 -> V=1.0, theta=0.0
% INFO    : Bus 94624	: V=0.9789018, theta=-76.202078 -> V=1.0, theta=0.0
% INFO    : Bus 94625	: V=0.9659902, theta=-78.399627 -> V=1.0, theta=0.0
% INFO    : Bus 94626	: V=0.9668951, theta=-77.885224 -> V=1.0, theta=0.0
% INFO    : Bus 94627	: V=0.9675544, theta=-77.794695 -> V=1.0, theta=0.0
% INFO    : Bus 94628	: V=0.9644479, theta=-77.85691 -> V=1.0, theta=0.0
% INFO    : Bus 94629	: V=0.9643698, theta=-77.868004 -> V=1.0, theta=0.0
% INFO    : Bus 94630	: V=0.9657491, theta=-77.8191 -> V=1.0, theta=0.0
% INFO    : Bus 94631	: V=0.9673626, theta=-77.258967 -> V=1.0, theta=0.0
% INFO    : Bus 94632	: V=0.9672107, theta=-77.703506 -> V=1.0, theta=0.0
% INFO    : Bus 94633	: V=0.9675858, theta=-77.651579 -> V=1.0, theta=0.0
% INFO    : Bus 94634	: V=0.9654792, theta=-77.652046 -> V=1.0, theta=0.0
% INFO    : Bus 94635	: V=0.9650105, theta=-77.731192 -> V=1.0, theta=0.0
% INFO    : Bus 94636	: V=0.9638691, theta=-76.951401 -> V=1.0, theta=0.0
% INFO    : Bus 94637	: V=0.9645239, theta=-77.000378 -> V=1.0, theta=0.0
% INFO    : Bus 94638	: V=0.964811, theta=-76.982185 -> V=1.0, theta=0.0
% INFO    : Bus 94639	: V=0.962963, theta=-77.917967 -> V=1.0, theta=0.0
% INFO    : Bus 94640	: V=0.9642949, theta=-77.983711 -> V=1.0, theta=0.0
% INFO    : Bus 94641	: V=0.9727503, theta=-76.670562 -> V=1.0, theta=0.0
% INFO    : Bus 94642	: V=0.9788946, theta=-75.795392 -> V=1.0, theta=0.0
% INFO    : Bus 94643	: V=0.9632425, theta=-77.722451 -> V=1.0, theta=0.0
% INFO    : Bus 94644	: V=0.96507, theta=-76.143462 -> V=1.0, theta=0.0
% INFO    : Bus 94645	: V=0.965859, theta=-75.562367 -> V=1.0, theta=0.0
% INFO    : Bus 94646	: V=0.9537544, theta=-79.228725 -> V=1.0, theta=0.0
% INFO    : Bus 94647	: V=0.9709997, theta=-77.701933 -> V=1.0, theta=0.0
% INFO    : Bus 94648	: V=0.9664374, theta=-78.594191 -> V=1.0, theta=0.0
% INFO    : Bus 94649	: V=0.9678226, theta=-62.312149 -> V=1.0, theta=0.0
% INFO    : Bus 94650	: V=0.9960973, theta=-57.595334 -> V=1.0, theta=0.0
% INFO    : Bus 94651	: V=0.9919542, theta=-57.850327 -> V=1.0, theta=0.0
% INFO    : Bus 94652	: V=1.0064677, theta=-57.173003 -> V=1.0, theta=0.0
% INFO    : Bus 94653	: V=1.0185464, theta=-55.312217 -> V=1.0, theta=0.0
% INFO    : Bus 94654	: V=1.0144845, theta=-57.59126 -> V=1.0, theta=0.0
% INFO    : Bus 94655	: V=1.0091641, theta=-58.142109 -> V=1.0, theta=0.0
% INFO    : Bus 94656	: V=1.0092735, theta=-54.155813 -> V=1.0, theta=0.0
% INFO    : Bus 94657	: V=0.965603, theta=-72.526285 -> V=1.0, theta=0.0
% INFO    : Bus 94658	: V=0.9685157, theta=-72.489585 -> V=1.0, theta=0.0
% INFO    : Bus 94659	: V=0.977903, theta=-71.714173 -> V=1.0, theta=0.0
% INFO    : Bus 94660	: V=0.9736766, theta=-72.323613 -> V=1.0, theta=0.0
% INFO    : Bus 94661	: V=0.9652153, theta=-73.120509 -> V=1.0, theta=0.0
% INFO    : Bus 94662	: V=0.9838548, theta=-71.229985 -> V=1.0, theta=0.0
% INFO    : Bus 94663	: V=0.9868069, theta=-70.920571 -> V=1.0, theta=0.0
% INFO    : Bus 94664	: V=0.9661883, theta=-72.321781 -> V=1.0, theta=0.0
% INFO    : Bus 94665	: V=0.9682488, theta=-71.493777 -> V=1.0, theta=0.0
% INFO    : Bus 94666	: V=0.9751514, theta=-59.171705 -> V=1.0, theta=0.0
% INFO    : Bus 94667	: V=0.9762351, theta=-66.107364 -> V=1.0, theta=0.0
% INFO    : Bus 94668	: V=0.9813436, theta=-67.808364 -> V=1.0, theta=0.0
% INFO    : Bus 94669	: V=0.9879527, theta=-69.096326 -> V=1.0, theta=0.0
% INFO    : Bus 94670	: V=0.9999717, theta=-69.382564 -> V=1.0, theta=0.0
% INFO    : Bus 94671	: V=0.9951224, theta=-69.424837 -> V=1.0, theta=0.0
% INFO    : Bus 94672	: V=0.9891986, theta=-68.401343 -> V=1.0, theta=0.0
% INFO    : Bus 94673	: V=1.0024832, theta=-63.122332 -> V=1.0, theta=0.0
% INFO    : Bus 94674	: V=0.9979376, theta=-63.375396 -> V=1.0, theta=0.0
% INFO    : Bus 94675	: V=1.0004575, theta=-63.217821 -> V=1.0, theta=0.0
% INFO    : Bus 94676	: V=0.9985101, theta=-63.422908 -> V=1.0, theta=0.0
% INFO    : Bus 94677	: V=0.9801278, theta=-64.992678 -> V=1.0, theta=0.0
% INFO    : Bus 94678	: V=0.9876475, theta=-64.443136 -> V=1.0, theta=0.0
% INFO    : Bus 94679	: V=0.997631, theta=-63.427386 -> V=1.0, theta=0.0
% INFO    : Bus 94680	: V=0.9914076, theta=-64.070038 -> V=1.0, theta=0.0
% INFO    : Bus 94681	: V=0.9848529, theta=-64.70921 -> V=1.0, theta=0.0
% INFO    : Bus 94682	: V=0.9951579, theta=-63.510058 -> V=1.0, theta=0.0
% INFO    : Bus 94683	: V=0.9812404, theta=-64.8698 -> V=1.0, theta=0.0
% INFO    : Bus 94684	: V=0.9808206, theta=-64.969801 -> V=1.0, theta=0.0
% INFO    : Bus 94685	: V=0.9667309, theta=-68.379515 -> V=1.0, theta=0.0
% INFO    : Bus 94686	: V=0.9656294, theta=-68.537314 -> V=1.0, theta=0.0
% INFO    : Bus 94687	: V=0.9653504, theta=-68.434636 -> V=1.0, theta=0.0
% INFO    : Bus 94688	: V=0.9891856, theta=-64.165692 -> V=1.0, theta=0.0
% INFO    : Bus 94689	: V=0.9823002, theta=-64.762936 -> V=1.0, theta=0.0
% INFO    : Bus 94690	: V=0.9836373, theta=-64.924444 -> V=1.0, theta=0.0
% INFO    : Bus 94691	: V=0.9767621, theta=-65.339414 -> V=1.0, theta=0.0
% INFO    : Bus 94692	: V=0.9732917, theta=-65.526915 -> V=1.0, theta=0.0
% INFO    : Bus 94693	: V=0.9838435, theta=-64.76749 -> V=1.0, theta=0.0
% INFO    : Bus 94694	: V=0.9888135, theta=-64.446004 -> V=1.0, theta=0.0
% INFO    : Bus 94695	: V=0.9924677, theta=-64.231536 -> V=1.0, theta=0.0
% INFO    : Bus 94696	: V=1.0183517, theta=-61.838139 -> V=1.0, theta=0.0
% INFO    : Bus 94697	: V=1.0060421, theta=-62.931017 -> V=1.0, theta=0.0
% INFO    : Bus 94698	: V=0.9936637, theta=-63.820228 -> V=1.0, theta=0.0
% INFO    : Bus 94699	: V=0.9973421, theta=-64.287549 -> V=1.0, theta=0.0
% INFO    : Bus 94700	: V=1.0058541, theta=-63.351175 -> V=1.0, theta=0.0
% INFO    : Bus 94701	: V=0.9772678, theta=-65.589981 -> V=1.0, theta=0.0
% INFO    : Bus 94702	: V=1.0010626, theta=-67.288812 -> V=1.0, theta=0.0
% INFO    : Bus 94703	: V=1.0019412, theta=-67.376952 -> V=1.0, theta=0.0
% INFO    : Bus 94704	: V=0.98105, theta=-71.366609 -> V=1.0, theta=0.0
% INFO    : Bus 94705	: V=0.9666949, theta=-59.901244 -> V=1.0, theta=0.0
% INFO    : Bus 94706	: V=1.0025748, theta=-64.37388 -> V=1.0, theta=0.0
% INFO    : Bus 94707	: V=1.0159317, theta=-63.363414 -> V=1.0, theta=0.0
% INFO    : Bus 94708	: V=1.0024218, theta=-65.071128 -> V=1.0, theta=0.0
% INFO    : Bus 94709	: V=1.0014127, theta=-65.376778 -> V=1.0, theta=0.0
% INFO    : Bus 94710	: V=1.0037842, theta=-63.024328 -> V=1.0, theta=0.0
% INFO    : Bus 94711	: V=0.9999543, theta=-61.452065 -> V=1.0, theta=0.0
% INFO    : Bus 94712	: V=1.0008206, theta=-59.842973 -> V=1.0, theta=0.0
% INFO    : Bus 94713	: V=1.0021163, theta=-60.80941 -> V=1.0, theta=0.0
% INFO    : Bus 94714	: V=0.996828, theta=-68.777398 -> V=1.0, theta=0.0
% INFO    : Bus 94715	: V=0.9736076, theta=-70.358622 -> V=1.0, theta=0.0
% INFO    : Bus 94716	: V=0.9824488, theta=-70.829417 -> V=1.0, theta=0.0
% INFO    : Bus 94717	: V=1.0128861, theta=-51.715484 -> V=1.0, theta=0.0
% INFO    : Bus 94718	: V=1.0163125, theta=-51.425986 -> V=1.0, theta=0.0
% INFO    : Bus 94719	: V=1.0118336, theta=-51.790484 -> V=1.0, theta=0.0
% INFO    : Bus 94720	: V=0.9872008, theta=-61.876226 -> V=1.0, theta=0.0
% INFO    : Bus 94721	: V=0.9968114, theta=-65.679112 -> V=1.0, theta=0.0
% INFO    : Bus 94722	: V=0.9960539, theta=-65.888822 -> V=1.0, theta=0.0
% INFO    : Bus 94723	: V=0.9938725, theta=-69.106666 -> V=1.0, theta=0.0
% INFO    : Bus 94724	: V=0.9913896, theta=-66.870884 -> V=1.0, theta=0.0
% INFO    : Bus 94725	: V=1.0063978, theta=-57.649706 -> V=1.0, theta=0.0
% INFO    : Bus 94726	: V=1.0171608, theta=-56.958138 -> V=1.0, theta=0.0
% INFO    : Bus 94727	: V=1.014359, theta=-57.057065 -> V=1.0, theta=0.0
% INFO    : Bus 94728	: V=1.0160704, theta=-56.988241 -> V=1.0, theta=0.0
% INFO    : Bus 94729	: V=1.0194244, theta=-56.221571 -> V=1.0, theta=0.0
% INFO    : Bus 94730	: V=1.0144809, theta=-56.900507 -> V=1.0, theta=0.0
% INFO    : Bus 94731	: V=1.0169185, theta=-56.891318 -> V=1.0, theta=0.0
% INFO    : Bus 94732	: V=0.9849635, theta=-57.411446 -> V=1.0, theta=0.0
% INFO    : Bus 94733	: V=1.0068388, theta=-62.652682 -> V=1.0, theta=0.0
% INFO    : Bus 94734	: V=0.9921389, theta=-64.414292 -> V=1.0, theta=0.0
% INFO    : Bus 94735	: V=0.9918828, theta=-64.551956 -> V=1.0, theta=0.0
% INFO    : Bus 94736	: V=0.979142, theta=-69.243081 -> V=1.0, theta=0.0
% INFO    : Bus 94737	: V=1.0062092, theta=-69.007096 -> V=1.0, theta=0.0
% INFO    : Bus 94738	: V=1.0072683, theta=-68.551625 -> V=1.0, theta=0.0
% INFO    : Bus 94739	: V=1.006929, theta=-68.340894 -> V=1.0, theta=0.0
% INFO    : Bus 94740	: V=0.9948827, theta=-71.178864 -> V=1.0, theta=0.0
% INFO    : Bus 94741	: V=0.9965932, theta=-71.078631 -> V=1.0, theta=0.0
% INFO    : Bus 94742	: V=0.9898254, theta=-71.582324 -> V=1.0, theta=0.0
% INFO    : Bus 94743	: V=1.0017597, theta=-70.605496 -> V=1.0, theta=0.0
% INFO    : Bus 94744	: V=0.9967886, theta=-71.073845 -> V=1.0, theta=0.0
% INFO    : Bus 94745	: V=0.9935116, theta=-71.303686 -> V=1.0, theta=0.0
% INFO    : Bus 94746	: V=0.9918935, theta=-71.649654 -> V=1.0, theta=0.0
% INFO    : Bus 94747	: V=0.999892, theta=-70.635981 -> V=1.0, theta=0.0
% INFO    : Bus 94748	: V=0.9993283, theta=-70.871577 -> V=1.0, theta=0.0
% INFO    : Bus 94749	: V=1.0065017, theta=-69.532021 -> V=1.0, theta=0.0
% INFO    : Bus 94750	: V=0.9958419, theta=-70.86929 -> V=1.0, theta=0.0
% INFO    : Bus 94751	: V=0.9927653, theta=-70.578778 -> V=1.0, theta=0.0
% INFO    : Bus 94752	: V=1.005388, theta=-69.30308 -> V=1.0, theta=0.0
% INFO    : Bus 94753	: V=1.0090588, theta=-68.976113 -> V=1.0, theta=0.0
% INFO    : Bus 94754	: V=1.000868, theta=-70.065119 -> V=1.0, theta=0.0
% INFO    : Bus 94755	: V=1.0118851, theta=-69.281653 -> V=1.0, theta=0.0
% INFO    : Bus 94756	: V=1.0047986, theta=-70.167366 -> V=1.0, theta=0.0
% INFO    : Bus 94757	: V=0.9983557, theta=-70.567188 -> V=1.0, theta=0.0
% INFO    : Bus 94758	: V=1.0016871, theta=-70.005054 -> V=1.0, theta=0.0
% INFO    : Bus 94759	: V=1.0066069, theta=-69.215039 -> V=1.0, theta=0.0
% INFO    : Bus 94760	: V=1.0079934, theta=-69.39537 -> V=1.0, theta=0.0
% INFO    : Bus 94761	: V=0.9954944, theta=-70.733185 -> V=1.0, theta=0.0
% INFO    : Bus 94762	: V=1.0106708, theta=-69.100615 -> V=1.0, theta=0.0
% INFO    : Bus 94763	: V=1.0043445, theta=-70.179529 -> V=1.0, theta=0.0
% INFO    : Bus 94764	: V=1.006032, theta=-69.712289 -> V=1.0, theta=0.0
% INFO    : Bus 94765	: V=0.9926502, theta=-71.446841 -> V=1.0, theta=0.0
% INFO    : Bus 94766	: V=0.9920842, theta=-71.539131 -> V=1.0, theta=0.0
% INFO    : Bus 94767	: V=0.9874379, theta=-71.931699 -> V=1.0, theta=0.0
% INFO    : Bus 94768	: V=0.981465, theta=-72.75165 -> V=1.0, theta=0.0
% INFO    : Bus 94769	: V=1.0046526, theta=-71.044766 -> V=1.0, theta=0.0
% INFO    : Bus 94770	: V=1.0008057, theta=-71.478067 -> V=1.0, theta=0.0
% INFO    : Bus 94771	: V=0.9987174, theta=-71.448287 -> V=1.0, theta=0.0
% INFO    : Bus 94772	: V=1.0027388, theta=-70.31885 -> V=1.0, theta=0.0
% INFO    : Bus 94773	: V=0.9993256, theta=-70.81219 -> V=1.0, theta=0.0
% INFO    : Bus 94774	: V=0.9995906, theta=-65.606271 -> V=1.0, theta=0.0
% INFO    : Bus 94775	: V=0.9607671, theta=-66.716734 -> V=1.0, theta=0.0
% INFO    : Bus 94776	: V=0.9771019, theta=-71.155817 -> V=1.0, theta=0.0
% INFO    : Bus 94777	: V=0.9801467, theta=-70.85544 -> V=1.0, theta=0.0
% INFO    : Bus 94778	: V=0.988445, theta=-69.066722 -> V=1.0, theta=0.0
% INFO    : Bus 94779	: V=1.0009678, theta=-67.293439 -> V=1.0, theta=0.0
% INFO    : Bus 94780	: V=0.9965584, theta=-67.89911 -> V=1.0, theta=0.0
% INFO    : Bus 94781	: V=0.9975447, theta=-67.747255 -> V=1.0, theta=0.0
% INFO    : Bus 94782	: V=0.9827057, theta=-70.383613 -> V=1.0, theta=0.0
% INFO    : Bus 94783	: V=0.9789525, theta=-70.356272 -> V=1.0, theta=0.0
% INFO    : Bus 94784	: V=0.98491, theta=-68.774011 -> V=1.0, theta=0.0
% INFO    : Bus 94785	: V=1.0142946, theta=-49.724116 -> V=1.0, theta=0.0
% INFO    : Bus 94786	: V=0.9843024, theta=-68.547663 -> V=1.0, theta=0.0
% INFO    : Bus 94787	: V=0.988619, theta=-74.568323 -> V=1.0, theta=0.0
% INFO    : Bus 94788	: V=0.998766, theta=-71.485346 -> V=1.0, theta=0.0
% INFO    : Bus 94789	: V=0.9956532, theta=-71.645377 -> V=1.0, theta=0.0
% INFO    : Bus 94790	: V=0.9915038, theta=-71.622933 -> V=1.0, theta=0.0
% INFO    : Bus 94791	: V=0.9434905, theta=-76.435127 -> V=1.0, theta=0.0
% INFO    : Bus 94792	: V=0.9465163, theta=-74.172723 -> V=1.0, theta=0.0
% INFO    : Bus 94793	: V=1.0107665, theta=-58.9725 -> V=1.0, theta=0.0
% INFO    : Bus 94794	: V=1.0066631, theta=-59.578299 -> V=1.0, theta=0.0
% INFO    : Bus 94795	: V=0.9995657, theta=-56.421445 -> V=1.0, theta=0.0
% INFO    : Bus 94796	: V=1.0005902, theta=-56.608015 -> V=1.0, theta=0.0
% INFO    : Bus 94797	: V=1.0006768, theta=-58.435621 -> V=1.0, theta=0.0
% INFO    : Bus 94798	: V=1.0056519, theta=-56.970289 -> V=1.0, theta=0.0
% INFO    : Bus 94799	: V=1.0061405, theta=-56.594916 -> V=1.0, theta=0.0
% INFO    : Bus 94800	: V=0.9910537, theta=-58.199773 -> V=1.0, theta=0.0
% INFO    : Bus 94801	: V=0.9670901, theta=-69.766661 -> V=1.0, theta=0.0
% INFO    : Bus 94802	: V=0.9957028, theta=-69.11068 -> V=1.0, theta=0.0
% INFO    : Bus 94803	: V=1.0120659, theta=-68.582097 -> V=1.0, theta=0.0
% INFO    : Bus 94804	: V=0.9992142, theta=-69.93343 -> V=1.0, theta=0.0
% INFO    : Bus 94805	: V=1.0143571, theta=-67.408654 -> V=1.0, theta=0.0
% INFO    : Bus 94806	: V=1.0153036, theta=-66.834267 -> V=1.0, theta=0.0
% INFO    : Bus 94807	: V=0.9934016, theta=-73.358279 -> V=1.0, theta=0.0
% INFO    : Bus 94808	: V=0.987414, theta=-74.462393 -> V=1.0, theta=0.0
% INFO    : Bus 94809	: V=0.9792947, theta=-76.008504 -> V=1.0, theta=0.0
% INFO    : Bus 94810	: V=0.9928012, theta=-75.415526 -> V=1.0, theta=0.0
% INFO    : Bus 94811	: V=1.0068139, theta=-74.160279 -> V=1.0, theta=0.0
% INFO    : Bus 94812	: V=1.006422, theta=-74.497625 -> V=1.0, theta=0.0
% INFO    : Bus 94813	: V=1.0039956, theta=-74.705203 -> V=1.0, theta=0.0
% INFO    : Bus 94814	: V=0.9858507, theta=-74.430007 -> V=1.0, theta=0.0
% INFO    : Bus 94815	: V=0.9970471, theta=-73.776594 -> V=1.0, theta=0.0
% INFO    : Bus 94816	: V=0.9894167, theta=-69.644566 -> V=1.0, theta=0.0
% INFO    : Bus 94817	: V=0.9935812, theta=-69.280215 -> V=1.0, theta=0.0
% INFO    : Bus 94818	: V=0.9928154, theta=-69.94505 -> V=1.0, theta=0.0
% INFO    : Bus 94819	: V=1.0039979, theta=-68.338426 -> V=1.0, theta=0.0
% INFO    : Bus 94820	: V=1.0074008, theta=-68.599461 -> V=1.0, theta=0.0
% INFO    : Bus 94821	: V=0.9764058, theta=-68.460713 -> V=1.0, theta=0.0
% INFO    : Bus 94822	: V=0.9718026, theta=-67.541902 -> V=1.0, theta=0.0
% INFO    : Bus 94823	: V=0.977489, theta=-61.158413 -> V=1.0, theta=0.0
% INFO    : Bus 94824	: V=0.9728619, theta=-61.452103 -> V=1.0, theta=0.0
% INFO    : Bus 94825	: V=0.9719533, theta=-61.461335 -> V=1.0, theta=0.0
% INFO    : Bus 94826	: V=0.9749308, theta=-61.305166 -> V=1.0, theta=0.0
% INFO    : Bus 94827	: V=0.9707491, theta=-61.507099 -> V=1.0, theta=0.0
% INFO    : Bus 94828	: V=0.9685994, theta=-61.576962 -> V=1.0, theta=0.0
% INFO    : Bus 94829	: V=0.965329, theta=-61.726237 -> V=1.0, theta=0.0
% INFO    : Bus 94830	: V=0.9744445, theta=-61.303296 -> V=1.0, theta=0.0
% INFO    : Bus 94831	: V=0.9744153, theta=-61.343034 -> V=1.0, theta=0.0
% INFO    : Bus 94832	: V=0.9916433, theta=-59.718266 -> V=1.0, theta=0.0
% INFO    : Bus 94833	: V=0.9920535, theta=-59.776205 -> V=1.0, theta=0.0
% INFO    : Bus 94834	: V=0.9639348, theta=-61.672078 -> V=1.0, theta=0.0
% INFO    : Bus 94835	: V=0.9886142, theta=-59.991007 -> V=1.0, theta=0.0
% INFO    : Bus 94836	: V=0.9679805, theta=-61.677112 -> V=1.0, theta=0.0
% INFO    : Bus 94837	: V=1.005423, theta=-58.348415 -> V=1.0, theta=0.0
% INFO    : Bus 94838	: V=1.0044579, theta=-58.487067 -> V=1.0, theta=0.0
% INFO    : Bus 94839	: V=0.9925512, theta=-58.940008 -> V=1.0, theta=0.0
% INFO    : Bus 94840	: V=0.9666309, theta=-72.234161 -> V=1.0, theta=0.0
% INFO    : Bus 94841	: V=0.958084, theta=-73.516855 -> V=1.0, theta=0.0
% INFO    : Bus 94842	: V=0.9625654, theta=-72.946807 -> V=1.0, theta=0.0
% INFO    : Bus 94843	: V=0.9627033, theta=-73.055645 -> V=1.0, theta=0.0
% INFO    : Bus 94844	: V=0.9873166, theta=-70.714699 -> V=1.0, theta=0.0
% INFO    : Bus 94845	: V=0.9915729, theta=-70.323903 -> V=1.0, theta=0.0
% INFO    : Bus 94846	: V=0.967382, theta=-71.944908 -> V=1.0, theta=0.0
% INFO    : Bus 94847	: V=0.965668, theta=-73.061754 -> V=1.0, theta=0.0
% INFO    : Bus 94848	: V=0.9648848, theta=-72.489169 -> V=1.0, theta=0.0
% INFO    : Bus 94849	: V=0.9667443, theta=-72.217438 -> V=1.0, theta=0.0
% INFO    : Bus 94850	: V=0.9768881, theta=-71.274736 -> V=1.0, theta=0.0
% INFO    : Bus 94851	: V=0.9772123, theta=-71.26442 -> V=1.0, theta=0.0
% INFO    : Bus 94852	: V=0.9697808, theta=-71.783 -> V=1.0, theta=0.0
% INFO    : Bus 94853	: V=0.9638404, theta=-73.248914 -> V=1.0, theta=0.0
% INFO    : Bus 94854	: V=1.0138439, theta=-68.928308 -> V=1.0, theta=0.0
% INFO    : Bus 94855	: V=1.0121306, theta=-69.095124 -> V=1.0, theta=0.0
% INFO    : Bus 94856	: V=0.9987743, theta=-56.311399 -> V=1.0, theta=0.0
% INFO    : Bus 94857	: V=0.9527218, theta=-68.061577 -> V=1.0, theta=0.0
% INFO    : Bus 94858	: V=1.0131011, theta=-63.108821 -> V=1.0, theta=0.0
% INFO    : Bus 94859	: V=1.0114221, theta=-63.283069 -> V=1.0, theta=0.0
% INFO    : Bus 94860	: V=0.981509, theta=-71.645763 -> V=1.0, theta=0.0
% INFO    : Bus 94861	: V=0.9623162, theta=-75.447362 -> V=1.0, theta=0.0
% INFO    : Bus 94862	: V=0.9795076, theta=-71.399296 -> V=1.0, theta=0.0
% INFO    : Bus 94863	: V=0.969219, theta=-58.163322 -> V=1.0, theta=0.0
% INFO    : Bus 94864	: V=0.9689241, theta=-58.148676 -> V=1.0, theta=0.0
% INFO    : Bus 94865	: V=0.9680898, theta=-58.223647 -> V=1.0, theta=0.0
% INFO    : Bus 94866	: V=0.9667305, theta=-58.369106 -> V=1.0, theta=0.0
% INFO    : Bus 94867	: V=0.9732059, theta=-58.00854 -> V=1.0, theta=0.0
% INFO    : Bus 94868	: V=0.9729548, theta=-57.887135 -> V=1.0, theta=0.0
% INFO    : Bus 94869	: V=0.9774518, theta=-58.607516 -> V=1.0, theta=0.0
% INFO    : Bus 94870	: V=0.9864657, theta=-56.694306 -> V=1.0, theta=0.0
% INFO    : Bus 94871	: V=0.982645, theta=-57.175658 -> V=1.0, theta=0.0
% INFO    : Bus 94872	: V=0.969957, theta=-58.261854 -> V=1.0, theta=0.0
% INFO    : Bus 94873	: V=0.9774754, theta=-63.061791 -> V=1.0, theta=0.0
% INFO    : Bus 94874	: V=0.9680163, theta=-68.340725 -> V=1.0, theta=0.0
% INFO    : Bus 94875	: V=0.9658916, theta=-76.506513 -> V=1.0, theta=0.0
% INFO    : Bus 94876	: V=0.9732914, theta=-76.374527 -> V=1.0, theta=0.0
% INFO    : Bus 94877	: V=0.9898155, theta=-74.331323 -> V=1.0, theta=0.0
% INFO    : Bus 94878	: V=0.9832479, theta=-75.189532 -> V=1.0, theta=0.0
% INFO    : Bus 94879	: V=0.9800256, theta=-75.545471 -> V=1.0, theta=0.0
% INFO    : Bus 94880	: V=0.9702134, theta=-76.76659 -> V=1.0, theta=0.0
% INFO    : Bus 94881	: V=0.9757197, theta=-75.868636 -> V=1.0, theta=0.0
% INFO    : Bus 94882	: V=0.9792816, theta=-75.616927 -> V=1.0, theta=0.0
% INFO    : Bus 94883	: V=0.9777331, theta=-75.821749 -> V=1.0, theta=0.0
% INFO    : Bus 94884	: V=0.9790347, theta=-75.635344 -> V=1.0, theta=0.0
% INFO    : Bus 94885	: V=0.9777686, theta=-75.812539 -> V=1.0, theta=0.0
% INFO    : Bus 94886	: V=0.9739346, theta=-76.34245 -> V=1.0, theta=0.0
% INFO    : Bus 94887	: V=0.9731447, theta=-76.356919 -> V=1.0, theta=0.0
% INFO    : Bus 94888	: V=0.9799281, theta=-75.645663 -> V=1.0, theta=0.0
% INFO    : Bus 94889	: V=0.9798227, theta=-75.670955 -> V=1.0, theta=0.0
% INFO    : Bus 94890	: V=0.9722232, theta=-76.139671 -> V=1.0, theta=0.0
% INFO    : Bus 94891	: V=0.9637452, theta=-77.813963 -> V=1.0, theta=0.0
% INFO    : Bus 94892	: V=0.9637959, theta=-78.329853 -> V=1.0, theta=0.0
% INFO    : Bus 94893	: V=0.9660654, theta=-77.192545 -> V=1.0, theta=0.0
% INFO    : Bus 94894	: V=0.9712381, theta=-75.590975 -> V=1.0, theta=0.0
% INFO    : Bus 94895	: V=0.9835261, theta=-74.106493 -> V=1.0, theta=0.0
% INFO    : Bus 94896	: V=0.9813896, theta=-74.636433 -> V=1.0, theta=0.0
% INFO    : Bus 94897	: V=0.9677915, theta=-76.593277 -> V=1.0, theta=0.0
% INFO    : Bus 94898	: V=0.9724401, theta=-76.43388 -> V=1.0, theta=0.0
% INFO    : Bus 94899	: V=0.9872088, theta=-75.349715 -> V=1.0, theta=0.0
% INFO    : Bus 94900	: V=0.9878762, theta=-74.55658 -> V=1.0, theta=0.0
% INFO    : Bus 94901	: V=1.0131039, theta=-58.233646 -> V=1.0, theta=0.0
% INFO    : Bus 94902	: V=1.0150808, theta=-58.013474 -> V=1.0, theta=0.0
% INFO    : Bus 94903	: V=1.0102387, theta=-58.055499 -> V=1.0, theta=0.0
% INFO    : Bus 94904	: V=0.9936803, theta=-54.916283 -> V=1.0, theta=0.0
% INFO    : Bus 94905	: V=1.0169359, theta=-55.190008 -> V=1.0, theta=0.0
% INFO    : Bus 94906	: V=1.0050233, theta=-56.434928 -> V=1.0, theta=0.0
% INFO    : Bus 94907	: V=1.0135462, theta=-58.260458 -> V=1.0, theta=0.0
% INFO    : Bus 94908	: V=0.958391, theta=-69.646945 -> V=1.0, theta=0.0
% INFO    : Bus 94909	: V=0.9686245, theta=-67.000192 -> V=1.0, theta=0.0
% INFO    : Bus 94910	: V=0.9595919, theta=-68.89847 -> V=1.0, theta=0.0
% INFO    : Bus 94911	: V=0.9580682, theta=-68.462441 -> V=1.0, theta=0.0
% INFO    : Bus 94912	: V=0.9828999, theta=-72.11156 -> V=1.0, theta=0.0
% INFO    : Bus 94913	: V=0.9837614, theta=-72.230551 -> V=1.0, theta=0.0
% INFO    : Bus 94914	: V=0.998653, theta=-69.968768 -> V=1.0, theta=0.0
% INFO    : Bus 94915	: V=0.9801031, theta=-71.989614 -> V=1.0, theta=0.0
% INFO    : Bus 94916	: V=0.9805141, theta=-65.890944 -> V=1.0, theta=0.0
% INFO    : Bus 94917	: V=1.0167149, theta=-66.854066 -> V=1.0, theta=0.0
% INFO    : Bus 94918	: V=1.0163187, theta=-66.929816 -> V=1.0, theta=0.0
% INFO    : Bus 94919	: V=1.020064, theta=-44.614836 -> V=1.0, theta=0.0
% INFO    : Bus 94920	: V=1.018807, theta=-44.425104 -> V=1.0, theta=0.0
% INFO    : Bus 94921	: V=1.0149557, theta=-58.305081 -> V=1.0, theta=0.0
% INFO    : Bus 94922	: V=1.0072444, theta=-59.153163 -> V=1.0, theta=0.0
% INFO    : Bus 94923	: V=0.9880688, theta=-60.704255 -> V=1.0, theta=0.0
% INFO    : Bus 94924	: V=0.994032, theta=-60.23184 -> V=1.0, theta=0.0
% INFO    : Bus 94925	: V=1.0030756, theta=-58.959508 -> V=1.0, theta=0.0
% INFO    : Bus 94926	: V=1.0071298, theta=-58.79281 -> V=1.0, theta=0.0
% INFO    : Bus 94927	: V=1.0041321, theta=-58.915843 -> V=1.0, theta=0.0
% INFO    : Bus 94928	: V=1.0045475, theta=-59.08918 -> V=1.0, theta=0.0
% INFO    : Bus 94929	: V=0.9906039, theta=-60.4277 -> V=1.0, theta=0.0
% INFO    : Bus 94930	: V=0.9942274, theta=-59.977868 -> V=1.0, theta=0.0
% INFO    : Bus 94931	: V=0.9882813, theta=-60.591733 -> V=1.0, theta=0.0
% INFO    : Bus 94932	: V=0.984501, theta=-60.738586 -> V=1.0, theta=0.0
% INFO    : Bus 94933	: V=0.9843939, theta=-60.732823 -> V=1.0, theta=0.0
% INFO    : Bus 94934	: V=0.9894198, theta=-60.266047 -> V=1.0, theta=0.0
% INFO    : Bus 94935	: V=0.990041, theta=-60.182589 -> V=1.0, theta=0.0
% INFO    : Bus 94936	: V=0.9836132, theta=-60.597441 -> V=1.0, theta=0.0
% INFO    : Bus 94937	: V=1.0070073, theta=-61.449979 -> V=1.0, theta=0.0
% INFO    : Bus 94938	: V=1.0050942, theta=-61.168535 -> V=1.0, theta=0.0
% INFO    : Bus 94939	: V=1.0023618, theta=-63.424229 -> V=1.0, theta=0.0
% INFO    : Bus 94940	: V=0.982614, theta=-60.837074 -> V=1.0, theta=0.0
% INFO    : Bus 94941	: V=0.9958445, theta=-62.818422 -> V=1.0, theta=0.0
% INFO    : Bus 94942	: V=0.9906109, theta=-63.955572 -> V=1.0, theta=0.0
% INFO    : Bus 94943	: V=0.9966667, theta=-61.14816 -> V=1.0, theta=0.0
% INFO    : Bus 94944	: V=0.9877121, theta=-62.256271 -> V=1.0, theta=0.0
% INFO    : Bus 94945	: V=0.9921998, theta=-61.657148 -> V=1.0, theta=0.0
% INFO    : Bus 94946	: V=0.9705832, theta=-60.561205 -> V=1.0, theta=0.0
% INFO    : Bus 94947	: V=1.013157, theta=-67.878446 -> V=1.0, theta=0.0
% INFO    : Bus 94948	: V=0.9958208, theta=-70.025797 -> V=1.0, theta=0.0
% INFO    : Bus 94949	: V=0.9861725, theta=-70.224249 -> V=1.0, theta=0.0
% INFO    : Bus 94950	: V=0.9945069, theta=-70.137955 -> V=1.0, theta=0.0
% INFO    : Bus 94951	: V=1.0142526, theta=-67.95491 -> V=1.0, theta=0.0
% INFO    : Bus 94952	: V=1.0184649, theta=-59.383871 -> V=1.0, theta=0.0
% INFO    : Bus 94953	: V=1.0138085, theta=-61.517813 -> V=1.0, theta=0.0
% INFO    : Bus 94954	: V=1.0134312, theta=-61.857703 -> V=1.0, theta=0.0
% INFO    : Bus 94955	: V=1.013078, theta=-61.887522 -> V=1.0, theta=0.0
% INFO    : Bus 94956	: V=1.0078818, theta=-62.241489 -> V=1.0, theta=0.0
% INFO    : Bus 94957	: V=0.9611535, theta=-63.940743 -> V=1.0, theta=0.0
% INFO    : Bus 94958	: V=0.9838487, theta=-61.125473 -> V=1.0, theta=0.0
% INFO    : Bus 94959	: V=0.989407, theta=-60.353343 -> V=1.0, theta=0.0
% INFO    : Bus 94960	: V=0.9947739, theta=-66.519094 -> V=1.0, theta=0.0
% INFO    : Bus 94961	: V=0.9951455, theta=-66.403032 -> V=1.0, theta=0.0
% INFO    : Bus 94962	: V=0.9827002, theta=-69.089648 -> V=1.0, theta=0.0
% INFO    : Bus 94963	: V=0.9892057, theta=-69.203773 -> V=1.0, theta=0.0
% INFO    : Bus 94964	: V=0.9950973, theta=-69.391585 -> V=1.0, theta=0.0
% INFO    : Bus 94965	: V=0.9911408, theta=-69.12737 -> V=1.0, theta=0.0
% INFO    : Bus 94966	: V=1.0065415, theta=-66.062625 -> V=1.0, theta=0.0
% INFO    : Bus 94967	: V=1.0057566, theta=-64.205605 -> V=1.0, theta=0.0
% INFO    : Bus 94968	: V=1.0080175, theta=-63.100138 -> V=1.0, theta=0.0
% INFO    : Bus 94969	: V=0.9970937, theta=-67.954323 -> V=1.0, theta=0.0
% INFO    : Bus 94970	: V=0.9926602, theta=-69.832999 -> V=1.0, theta=0.0
% INFO    : Bus 94971	: V=1.0028392, theta=-56.93494 -> V=1.0, theta=0.0
% INFO    : Bus 94972	: V=1.0009469, theta=-57.171972 -> V=1.0, theta=0.0
% INFO    : Bus 94973	: V=1.0184007, theta=-58.059138 -> V=1.0, theta=0.0
% INFO    : Bus 94974	: V=0.9733848, theta=-63.544519 -> V=1.0, theta=0.0
% INFO    : Bus 94975	: V=0.9737421, theta=-74.116075 -> V=1.0, theta=0.0
% INFO    : Bus 94976	: V=0.9775175, theta=-72.661695 -> V=1.0, theta=0.0
% INFO    : Bus 94977	: V=0.9869545, theta=-68.304374 -> V=1.0, theta=0.0
% INFO    : Bus 94978	: V=0.9756494, theta=-59.76451 -> V=1.0, theta=0.0
% INFO    : Bus 94979	: V=0.9843172, theta=-59.318234 -> V=1.0, theta=0.0
% INFO    : Bus 94980	: V=0.9845142, theta=-59.206524 -> V=1.0, theta=0.0
% INFO    : Bus 94981	: V=0.9842885, theta=-59.326256 -> V=1.0, theta=0.0
% INFO    : Bus 94982	: V=0.9957942, theta=-58.156187 -> V=1.0, theta=0.0
% INFO    : Bus 94983	: V=0.9824036, theta=-59.41077 -> V=1.0, theta=0.0
% INFO    : Bus 94984	: V=0.9820237, theta=-59.395147 -> V=1.0, theta=0.0
% INFO    : Bus 94985	: V=0.977694, theta=-59.70137 -> V=1.0, theta=0.0
% INFO    : Bus 94986	: V=0.9795022, theta=-59.578171 -> V=1.0, theta=0.0
% INFO    : Bus 94987	: V=0.9798998, theta=-59.549262 -> V=1.0, theta=0.0
% INFO    : Bus 94988	: V=0.977558, theta=-59.685272 -> V=1.0, theta=0.0
% INFO    : Bus 94989	: V=0.9774364, theta=-59.700274 -> V=1.0, theta=0.0
% INFO    : Bus 94990	: V=0.9777887, theta=-59.686293 -> V=1.0, theta=0.0
% INFO    : Bus 94991	: V=0.9773195, theta=-59.712968 -> V=1.0, theta=0.0
% INFO    : Bus 94992	: V=0.9792136, theta=-59.604002 -> V=1.0, theta=0.0
% INFO    : Bus 94993	: V=0.9798164, theta=-59.762154 -> V=1.0, theta=0.0
% INFO    : Bus 94994	: V=0.9778991, theta=-59.869469 -> V=1.0, theta=0.0
% INFO    : Bus 94995	: V=0.980138, theta=-59.735386 -> V=1.0, theta=0.0
% INFO    : Bus 94996	: V=0.9939505, theta=-58.259374 -> V=1.0, theta=0.0
% INFO    : Bus 94997	: V=0.9895674, theta=-58.848069 -> V=1.0, theta=0.0
% INFO    : Bus 94998	: V=0.9959351, theta=-52.314358 -> V=1.0, theta=0.0
% INFO    : Bus 94999	: V=0.9893384, theta=-62.464602 -> V=1.0, theta=0.0
% INFO    : Bus 95000	: V=0.9973036, theta=-70.14022 -> V=1.0, theta=0.0
% INFO    : Bus 95001	: V=0.9951103, theta=-70.916572 -> V=1.0, theta=0.0
% INFO    : Bus 95002	: V=0.9959035, theta=-69.473668 -> V=1.0, theta=0.0
% INFO    : Bus 95003	: V=0.9924354, theta=-71.002327 -> V=1.0, theta=0.0
% INFO    : Bus 95004	: V=0.9945249, theta=-72.272413 -> V=1.0, theta=0.0
% INFO    : Bus 95005	: V=0.9746072, theta=-52.009677 -> V=1.0, theta=0.0
% INFO    : Bus 95006	: V=1.0111309, theta=-59.140861 -> V=1.0, theta=0.0
% INFO    : Bus 95007	: V=1.0045745, theta=-59.809855 -> V=1.0, theta=0.0
% INFO    : Bus 95008	: V=1.0026624, theta=-59.921511 -> V=1.0, theta=0.0
% INFO    : Bus 95009	: V=0.9984644, theta=-61.15668 -> V=1.0, theta=0.0
% INFO    : Bus 95010	: V=0.9698098, theta=-65.70169 -> V=1.0, theta=0.0
% INFO    : Bus 95011	: V=0.9714842, theta=-67.123194 -> V=1.0, theta=0.0
% INFO    : Bus 95012	: V=0.9975903, theta=-59.60053 -> V=1.0, theta=0.0
% INFO    : Bus 95013	: V=1.014252, theta=-58.203393 -> V=1.0, theta=0.0
% INFO    : Bus 95014	: V=1.0142661, theta=-58.158504 -> V=1.0, theta=0.0
% INFO    : Bus 95015	: V=0.9922225, theta=-63.032016 -> V=1.0, theta=0.0
% INFO    : Bus 95016	: V=0.9655406, theta=-64.885761 -> V=1.0, theta=0.0
% INFO    : Bus 95017	: V=0.985768, theta=-63.05819 -> V=1.0, theta=0.0
% INFO    : Bus 95018	: V=0.9703749, theta=-64.549399 -> V=1.0, theta=0.0
% INFO    : Bus 95019	: V=0.9810864, theta=-64.418416 -> V=1.0, theta=0.0
% INFO    : Bus 95020	: V=0.9787269, theta=-65.121368 -> V=1.0, theta=0.0
% INFO    : Bus 95021	: V=0.9761461, theta=-65.146182 -> V=1.0, theta=0.0
% INFO    : Bus 95022	: V=0.9738916, theta=-64.901116 -> V=1.0, theta=0.0
% INFO    : Bus 95023	: V=0.971398, theta=-66.385491 -> V=1.0, theta=0.0
% INFO    : Bus 95024	: V=1.0058613, theta=-64.41789 -> V=1.0, theta=0.0
% INFO    : Bus 95025	: V=1.0069135, theta=-56.793435 -> V=1.0, theta=0.0
% INFO    : Bus 95026	: V=1.0104865, theta=-52.440851 -> V=1.0, theta=0.0
% INFO    : Bus 95027	: V=0.9994339, theta=-61.39153 -> V=1.0, theta=0.0
% INFO    : Bus 95028	: V=0.9945086, theta=-62.350455 -> V=1.0, theta=0.0
% INFO    : Bus 95029	: V=0.9835703, theta=-71.96559 -> V=1.0, theta=0.0
% INFO    : Bus 95030	: V=0.9827632, theta=-72.039652 -> V=1.0, theta=0.0
% INFO    : Bus 95031	: V=0.984726, theta=-71.40547 -> V=1.0, theta=0.0
% INFO    : Bus 95032	: V=0.9834776, theta=-71.573571 -> V=1.0, theta=0.0
% INFO    : Bus 95033	: V=0.9850829, theta=-71.53293 -> V=1.0, theta=0.0
% INFO    : Bus 95034	: V=0.9818889, theta=-71.873124 -> V=1.0, theta=0.0
% INFO    : Bus 95035	: V=0.9845944, theta=-71.752278 -> V=1.0, theta=0.0
% INFO    : Bus 95036	: V=0.9816728, theta=-74.797557 -> V=1.0, theta=0.0
% INFO    : Bus 95037	: V=0.9812373, theta=-74.584774 -> V=1.0, theta=0.0
% INFO    : Bus 95038	: V=0.977673, theta=-72.465584 -> V=1.0, theta=0.0
% INFO    : Bus 95039	: V=0.9783027, theta=-72.392416 -> V=1.0, theta=0.0
% INFO    : Bus 95040	: V=0.9778644, theta=-72.807563 -> V=1.0, theta=0.0
% INFO    : Bus 95041	: V=0.9777881, theta=-72.439688 -> V=1.0, theta=0.0
% INFO    : Bus 95042	: V=0.9778607, theta=-74.930299 -> V=1.0, theta=0.0
% INFO    : Bus 95043	: V=0.9707362, theta=-73.88451 -> V=1.0, theta=0.0
% INFO    : Bus 95044	: V=0.9697411, theta=-74.559271 -> V=1.0, theta=0.0
% INFO    : Bus 95045	: V=0.9722622, theta=-73.868314 -> V=1.0, theta=0.0
% INFO    : Bus 95046	: V=0.9809675, theta=-73.725802 -> V=1.0, theta=0.0
% INFO    : Bus 95047	: V=0.9814516, theta=-73.684337 -> V=1.0, theta=0.0
% INFO    : Bus 95048	: V=0.9730363, theta=-74.5905 -> V=1.0, theta=0.0
% INFO    : Bus 95049	: V=0.9793176, theta=-73.16848 -> V=1.0, theta=0.0
% INFO    : Bus 95050	: V=0.9780487, theta=-73.491743 -> V=1.0, theta=0.0
% INFO    : Bus 95051	: V=0.9716792, theta=-74.747239 -> V=1.0, theta=0.0
% INFO    : Bus 95052	: V=0.9755148, theta=-72.249094 -> V=1.0, theta=0.0
% INFO    : Bus 95053	: V=0.9761894, theta=-73.474003 -> V=1.0, theta=0.0
% INFO    : Bus 95054	: V=0.9766962, theta=-73.237765 -> V=1.0, theta=0.0
% INFO    : Bus 95055	: V=0.9796627, theta=-71.502026 -> V=1.0, theta=0.0
% INFO    : Bus 95056	: V=0.973893, theta=-73.377472 -> V=1.0, theta=0.0
% INFO    : Bus 95057	: V=0.9814519, theta=-72.577298 -> V=1.0, theta=0.0
% INFO    : Bus 95058	: V=0.9776626, theta=-73.310388 -> V=1.0, theta=0.0
% INFO    : Bus 95059	: V=0.9799065, theta=-73.7643 -> V=1.0, theta=0.0
% INFO    : Bus 95060	: V=0.9801004, theta=-73.85854 -> V=1.0, theta=0.0
% INFO    : Bus 95061	: V=0.9847166, theta=-74.292305 -> V=1.0, theta=0.0
% INFO    : Bus 95062	: V=0.9884851, theta=-73.105855 -> V=1.0, theta=0.0
% INFO    : Bus 95063	: V=0.976349, theta=-74.802024 -> V=1.0, theta=0.0
% INFO    : Bus 95064	: V=0.9756305, theta=-75.097635 -> V=1.0, theta=0.0
% INFO    : Bus 95065	: V=0.9621835, theta=-77.468622 -> V=1.0, theta=0.0
% INFO    : Bus 95066	: V=0.9815635, theta=-73.515815 -> V=1.0, theta=0.0
% INFO    : Bus 95067	: V=0.9803691, theta=-73.7975 -> V=1.0, theta=0.0
% INFO    : Bus 95068	: V=0.9796801, theta=-73.527279 -> V=1.0, theta=0.0
% INFO    : Bus 95069	: V=0.98037, theta=-73.459324 -> V=1.0, theta=0.0
% INFO    : Bus 95070	: V=0.9775928, theta=-72.97528 -> V=1.0, theta=0.0
% INFO    : Bus 95071	: V=0.9780788, theta=-72.437563 -> V=1.0, theta=0.0
% INFO    : Bus 95072	: V=0.9800285, theta=-71.698048 -> V=1.0, theta=0.0
% INFO    : Bus 95073	: V=0.9850928, theta=-71.890617 -> V=1.0, theta=0.0
% INFO    : Bus 95074	: V=0.9901941, theta=-70.69656 -> V=1.0, theta=0.0
% INFO    : Bus 95075	: V=0.9754087, theta=-71.711152 -> V=1.0, theta=0.0
% INFO    : Bus 95076	: V=0.975237, theta=-72.784438 -> V=1.0, theta=0.0
% INFO    : Bus 95077	: V=0.9738412, theta=-73.1656 -> V=1.0, theta=0.0
% INFO    : Bus 95078	: V=0.975762, theta=-71.642295 -> V=1.0, theta=0.0
% INFO    : Bus 95079	: V=0.9821298, theta=-70.913609 -> V=1.0, theta=0.0
% INFO    : Bus 95080	: V=0.9766162, theta=-74.107166 -> V=1.0, theta=0.0
% INFO    : Bus 95081	: V=0.9710465, theta=-73.466564 -> V=1.0, theta=0.0
% INFO    : Bus 95082	: V=0.9714025, theta=-73.512377 -> V=1.0, theta=0.0
% INFO    : Bus 95083	: V=0.9674116, theta=-75.474233 -> V=1.0, theta=0.0
% INFO    : Bus 95084	: V=0.9607651, theta=-75.548532 -> V=1.0, theta=0.0
% INFO    : Bus 95085	: V=0.9677809, theta=-75.171964 -> V=1.0, theta=0.0
% INFO    : Bus 95086	: V=0.9611118, theta=-76.607648 -> V=1.0, theta=0.0
% INFO    : Bus 95087	: V=0.9730854, theta=-74.699233 -> V=1.0, theta=0.0
% INFO    : Bus 95088	: V=0.9725046, theta=-74.884904 -> V=1.0, theta=0.0
% INFO    : Bus 95089	: V=0.9759443, theta=-75.693264 -> V=1.0, theta=0.0
% INFO    : Bus 95090	: V=0.9682536, theta=-75.838627 -> V=1.0, theta=0.0
% INFO    : Bus 95091	: V=0.9667783, theta=-76.732701 -> V=1.0, theta=0.0
% INFO    : Bus 95092	: V=0.9660345, theta=-76.246272 -> V=1.0, theta=0.0
% INFO    : Bus 95093	: V=0.9761032, theta=-75.173812 -> V=1.0, theta=0.0
% INFO    : Bus 95094	: V=0.9689595, theta=-75.89368 -> V=1.0, theta=0.0
% INFO    : Bus 95095	: V=0.9638011, theta=-76.196534 -> V=1.0, theta=0.0
% INFO    : Bus 95096	: V=0.9733074, theta=-75.654098 -> V=1.0, theta=0.0
% INFO    : Bus 95097	: V=0.9857465, theta=-73.006718 -> V=1.0, theta=0.0
% INFO    : Bus 95098	: V=0.9749037, theta=-75.290825 -> V=1.0, theta=0.0
% INFO    : Bus 95099	: V=0.9732451, theta=-76.005854 -> V=1.0, theta=0.0
% INFO    : Bus 95100	: V=0.9884137, theta=-73.181542 -> V=1.0, theta=0.0
% INFO    : Bus 95101	: V=0.9783731, theta=-74.911849 -> V=1.0, theta=0.0
% INFO    : Bus 95102	: V=0.974999, theta=-75.994656 -> V=1.0, theta=0.0
% INFO    : Bus 95103	: V=0.9739157, theta=-75.963847 -> V=1.0, theta=0.0
% INFO    : Bus 95104	: V=0.9748913, theta=-75.536374 -> V=1.0, theta=0.0
% INFO    : Bus 95105	: V=0.9758294, theta=-74.813571 -> V=1.0, theta=0.0
% INFO    : Bus 95106	: V=0.9703677, theta=-75.19752 -> V=1.0, theta=0.0
% INFO    : Bus 95107	: V=0.9758264, theta=-74.80561 -> V=1.0, theta=0.0
% INFO    : Bus 95108	: V=0.9728585, theta=-75.211312 -> V=1.0, theta=0.0
% INFO    : Bus 95109	: V=0.9725482, theta=-75.228395 -> V=1.0, theta=0.0
% INFO    : Bus 95110	: V=0.9769142, theta=-75.169834 -> V=1.0, theta=0.0
% INFO    : Bus 95111	: V=0.9714176, theta=-75.777528 -> V=1.0, theta=0.0
% INFO    : Bus 95112	: V=0.9702669, theta=-75.932437 -> V=1.0, theta=0.0
% INFO    : Bus 95113	: V=0.9722992, theta=-75.403035 -> V=1.0, theta=0.0
% INFO    : Bus 95114	: V=0.9649812, theta=-77.119276 -> V=1.0, theta=0.0
% INFO    : Bus 95115	: V=0.9709461, theta=-75.932601 -> V=1.0, theta=0.0
% INFO    : Bus 95116	: V=0.9715251, theta=-75.457101 -> V=1.0, theta=0.0
% INFO    : Bus 95117	: V=0.9682712, theta=-76.303517 -> V=1.0, theta=0.0
% INFO    : Bus 95118	: V=0.9731081, theta=-75.022623 -> V=1.0, theta=0.0
% INFO    : Bus 95119	: V=0.9696991, theta=-75.663151 -> V=1.0, theta=0.0
% INFO    : Bus 95120	: V=0.9764315, theta=-74.289667 -> V=1.0, theta=0.0
% INFO    : Bus 95121	: V=0.9694472, theta=-75.414302 -> V=1.0, theta=0.0
% INFO    : Bus 95122	: V=0.968544, theta=-75.049256 -> V=1.0, theta=0.0
% INFO    : Bus 95123	: V=0.9693109, theta=-75.346336 -> V=1.0, theta=0.0
% INFO    : Bus 95124	: V=0.9771894, theta=-73.901629 -> V=1.0, theta=0.0
% INFO    : Bus 95125	: V=0.9739092, theta=-74.648181 -> V=1.0, theta=0.0
% INFO    : Bus 95126	: V=0.9707982, theta=-74.855465 -> V=1.0, theta=0.0
% INFO    : Bus 95127	: V=0.9683352, theta=-74.812244 -> V=1.0, theta=0.0
% INFO    : Bus 95128	: V=0.964675, theta=-74.525724 -> V=1.0, theta=0.0
% INFO    : Bus 95129	: V=0.9687723, theta=-74.921488 -> V=1.0, theta=0.0
% INFO    : Bus 95130	: V=0.9780788, theta=-73.878589 -> V=1.0, theta=0.0
% INFO    : Bus 95131	: V=0.9760337, theta=-73.250244 -> V=1.0, theta=0.0
% INFO    : Bus 95132	: V=0.9774446, theta=-72.730911 -> V=1.0, theta=0.0
% INFO    : Bus 95133	: V=0.9901919, theta=-70.392898 -> V=1.0, theta=0.0
% INFO    : Bus 95134	: V=0.9834316, theta=-71.195271 -> V=1.0, theta=0.0
% INFO    : Bus 95135	: V=0.9883802, theta=-70.43587 -> V=1.0, theta=0.0
% INFO    : Bus 95136	: V=0.9769282, theta=-74.670335 -> V=1.0, theta=0.0
% INFO    : Bus 95137	: V=0.970822, theta=-76.080729 -> V=1.0, theta=0.0
% INFO    : Bus 95138	: V=0.9751383, theta=-75.634163 -> V=1.0, theta=0.0
% INFO    : Bus 95139	: V=0.977425, theta=-74.709118 -> V=1.0, theta=0.0
% INFO    : Bus 95140	: V=0.9752767, theta=-75.702149 -> V=1.0, theta=0.0
% INFO    : Bus 95141	: V=0.9732557, theta=-75.786352 -> V=1.0, theta=0.0
% INFO    : Bus 95142	: V=0.9761788, theta=-75.348023 -> V=1.0, theta=0.0
% INFO    : Bus 95143	: V=0.976067, theta=-75.174269 -> V=1.0, theta=0.0
% INFO    : Bus 95144	: V=0.9756603, theta=-75.569004 -> V=1.0, theta=0.0
% INFO    : Bus 95145	: V=0.9704451, theta=-74.348149 -> V=1.0, theta=0.0
% INFO    : Bus 95146	: V=0.9722057, theta=-73.863332 -> V=1.0, theta=0.0
% INFO    : Bus 95147	: V=0.9715953, theta=-74.453496 -> V=1.0, theta=0.0
% INFO    : Bus 95148	: V=1.0119287, theta=-48.206827 -> V=1.0, theta=0.0
% INFO    : Bus 95149	: V=1.0060194, theta=-48.481849 -> V=1.0, theta=0.0
% INFO    : Bus 95150	: V=1.013006, theta=-48.219597 -> V=1.0, theta=0.0
% INFO    : Bus 95151	: V=1.0130546, theta=-48.025556 -> V=1.0, theta=0.0
% INFO    : Bus 95152	: V=1.0106486, theta=-48.258907 -> V=1.0, theta=0.0
% INFO    : Bus 95153	: V=1.0137838, theta=-47.42053 -> V=1.0, theta=0.0
% INFO    : Bus 95154	: V=1.0122248, theta=-47.558146 -> V=1.0, theta=0.0
% INFO    : Bus 95155	: V=1.0111554, theta=-47.511175 -> V=1.0, theta=0.0
% INFO    : Bus 95156	: V=1.0129981, theta=-46.996084 -> V=1.0, theta=0.0
% INFO    : Bus 95157	: V=1.0123408, theta=-47.071545 -> V=1.0, theta=0.0
% INFO    : Bus 95158	: V=1.0001422, theta=-48.729719 -> V=1.0, theta=0.0
% INFO    : Bus 95159	: V=1.0118054, theta=-47.468497 -> V=1.0, theta=0.0
% INFO    : Bus 95160	: V=0.9960464, theta=-49.850042 -> V=1.0, theta=0.0
% INFO    : Bus 95161	: V=0.9923659, theta=-56.08922 -> V=1.0, theta=0.0
% INFO    : Bus 95162	: V=0.9956356, theta=-56.682219 -> V=1.0, theta=0.0
% INFO    : Bus 95163	: V=0.9677866, theta=-57.912543 -> V=1.0, theta=0.0
% INFO    : Bus 95164	: V=0.9702351, theta=-58.219883 -> V=1.0, theta=0.0
% INFO    : Bus 95165	: V=0.9608395, theta=-59.418778 -> V=1.0, theta=0.0
% INFO    : Bus 95166	: V=0.9627253, theta=-58.795248 -> V=1.0, theta=0.0
% INFO    : Bus 95167	: V=0.9714321, theta=-58.324574 -> V=1.0, theta=0.0
% INFO    : Bus 95168	: V=0.9612152, theta=-58.835156 -> V=1.0, theta=0.0
% INFO    : Bus 95169	: V=0.9652964, theta=-58.462774 -> V=1.0, theta=0.0
% INFO    : Bus 95170	: V=0.9827393, theta=-71.822639 -> V=1.0, theta=0.0
% INFO    : Bus 95171	: V=0.9837133, theta=-71.753776 -> V=1.0, theta=0.0
% INFO    : Bus 95172	: V=0.9911406, theta=-70.861811 -> V=1.0, theta=0.0
% INFO    : Bus 95173	: V=0.9882881, theta=-71.308001 -> V=1.0, theta=0.0
% INFO    : Bus 95174	: V=0.9880272, theta=-71.626219 -> V=1.0, theta=0.0
% INFO    : Bus 95175	: V=0.9765208, theta=-72.67395 -> V=1.0, theta=0.0
% INFO    : Bus 95176	: V=0.9775232, theta=-72.673552 -> V=1.0, theta=0.0
% INFO    : Bus 95177	: V=0.9898391, theta=-71.095857 -> V=1.0, theta=0.0
% INFO    : Bus 95178	: V=0.9883585, theta=-71.620604 -> V=1.0, theta=0.0
% INFO    : Bus 95179	: V=0.9842009, theta=-72.036511 -> V=1.0, theta=0.0
% INFO    : Bus 95180	: V=0.9833567, theta=-72.07238 -> V=1.0, theta=0.0
% INFO    : Bus 95181	: V=0.9769067, theta=-72.61408 -> V=1.0, theta=0.0
% INFO    : Bus 95182	: V=0.9747014, theta=-72.498781 -> V=1.0, theta=0.0
% INFO    : Bus 95183	: V=0.9662116, theta=-73.057699 -> V=1.0, theta=0.0
% INFO    : Bus 95184	: V=0.9584898, theta=-74.030581 -> V=1.0, theta=0.0
% INFO    : Bus 95185	: V=0.960905, theta=-73.224377 -> V=1.0, theta=0.0
% INFO    : Bus 95186	: V=0.9758838, theta=-71.637719 -> V=1.0, theta=0.0
% INFO    : Bus 95187	: V=0.9629911, theta=-73.203405 -> V=1.0, theta=0.0
% INFO    : Bus 95188	: V=0.9572812, theta=-74.330371 -> V=1.0, theta=0.0
% INFO    : Bus 95189	: V=0.9644804, theta=-73.468193 -> V=1.0, theta=0.0
% INFO    : Bus 95190	: V=0.9638757, theta=-73.023505 -> V=1.0, theta=0.0
% INFO    : Bus 95191	: V=0.973924, theta=-71.816758 -> V=1.0, theta=0.0
% INFO    : Bus 95192	: V=0.9690842, theta=-72.825188 -> V=1.0, theta=0.0
% INFO    : Bus 95193	: V=0.9678665, theta=-72.854739 -> V=1.0, theta=0.0
% INFO    : Bus 95194	: V=0.9675233, theta=-72.592577 -> V=1.0, theta=0.0
% INFO    : Bus 95195	: V=0.9699726, theta=-72.468839 -> V=1.0, theta=0.0
% INFO    : Bus 95196	: V=0.9693953, theta=-72.362677 -> V=1.0, theta=0.0
% INFO    : Bus 95197	: V=0.9645274, theta=-72.474032 -> V=1.0, theta=0.0
% INFO    : Bus 95198	: V=0.9635705, theta=-72.557813 -> V=1.0, theta=0.0
% INFO    : Bus 95199	: V=0.9686877, theta=-72.501073 -> V=1.0, theta=0.0
% INFO    : Bus 95200	: V=0.9813314, theta=-71.276757 -> V=1.0, theta=0.0
% INFO    : Bus 95201	: V=0.9681331, theta=-72.521736 -> V=1.0, theta=0.0
% INFO    : Bus 95202	: V=0.9638848, theta=-72.488869 -> V=1.0, theta=0.0
% INFO    : Bus 95203	: V=0.9742801, theta=-71.141659 -> V=1.0, theta=0.0
% INFO    : Bus 95204	: V=0.9589617, theta=-73.124687 -> V=1.0, theta=0.0
% INFO    : Bus 95205	: V=0.9682416, theta=-71.969957 -> V=1.0, theta=0.0
% INFO    : Bus 95206	: V=0.9681305, theta=-72.235787 -> V=1.0, theta=0.0
% INFO    : Bus 95207	: V=0.9652508, theta=-72.32409 -> V=1.0, theta=0.0
% INFO    : Bus 95208	: V=0.9667754, theta=-72.470816 -> V=1.0, theta=0.0
% INFO    : Bus 95209	: V=0.9639914, theta=-73.179959 -> V=1.0, theta=0.0
% INFO    : Bus 95210	: V=0.9604647, theta=-74.182376 -> V=1.0, theta=0.0
% INFO    : Bus 95211	: V=0.9937642, theta=-70.660639 -> V=1.0, theta=0.0
% INFO    : Bus 95212	: V=1.0076169, theta=-68.953048 -> V=1.0, theta=0.0
% INFO    : Bus 95213	: V=0.9978133, theta=-70.292339 -> V=1.0, theta=0.0
% INFO    : Bus 95214	: V=1.0096858, theta=-68.857678 -> V=1.0, theta=0.0
% INFO    : Bus 95215	: V=0.9916009, theta=-71.00125 -> V=1.0, theta=0.0
% INFO    : Bus 95216	: V=0.9828602, theta=-71.869295 -> V=1.0, theta=0.0
% INFO    : Bus 95217	: V=0.9950673, theta=-70.383161 -> V=1.0, theta=0.0
% INFO    : Bus 95218	: V=0.9962452, theta=-70.175009 -> V=1.0, theta=0.0
% INFO    : Bus 95219	: V=0.9872416, theta=-71.359536 -> V=1.0, theta=0.0
% INFO    : Bus 95220	: V=1.0101966, theta=-68.841234 -> V=1.0, theta=0.0
% INFO    : Bus 95221	: V=1.0004482, theta=-70.023861 -> V=1.0, theta=0.0
% INFO    : Bus 95222	: V=0.9859654, theta=-71.599104 -> V=1.0, theta=0.0
% INFO    : Bus 95223	: V=0.9780665, theta=-72.190015 -> V=1.0, theta=0.0
% INFO    : Bus 95224	: V=0.969487, theta=-72.767929 -> V=1.0, theta=0.0
% INFO    : Bus 95225	: V=0.9673253, theta=-72.513449 -> V=1.0, theta=0.0
% INFO    : Bus 95226	: V=0.9912943, theta=-70.822287 -> V=1.0, theta=0.0
% INFO    : Bus 95227	: V=0.9856877, theta=-71.535147 -> V=1.0, theta=0.0
% INFO    : Bus 95228	: V=0.9737811, theta=-71.381139 -> V=1.0, theta=0.0
% INFO    : Bus 95229	: V=0.9732327, theta=-71.377323 -> V=1.0, theta=0.0
% INFO    : Bus 95230	: V=0.9773781, theta=-71.123664 -> V=1.0, theta=0.0
% INFO    : Bus 95231	: V=0.9887703, theta=-69.90528 -> V=1.0, theta=0.0
% INFO    : Bus 95232	: V=0.9840914, theta=-70.918665 -> V=1.0, theta=0.0
% INFO    : Bus 95233	: V=1.0165498, theta=-55.925812 -> V=1.0, theta=0.0
% INFO    : Bus 95234	: V=1.0144394, theta=-56.342839 -> V=1.0, theta=0.0
% INFO    : Bus 95235	: V=0.9644884, theta=-72.891465 -> V=1.0, theta=0.0
% INFO    : Bus 95236	: V=1.0063577, theta=-66.919161 -> V=1.0, theta=0.0
% INFO    : Bus 95237	: V=0.9966239, theta=-67.846536 -> V=1.0, theta=0.0
% INFO    : Bus 95238	: V=1.0077146, theta=-66.902702 -> V=1.0, theta=0.0
% INFO    : Bus 95239	: V=1.0066986, theta=-67.008221 -> V=1.0, theta=0.0
% INFO    : Bus 95240	: V=0.9994311, theta=-67.783775 -> V=1.0, theta=0.0
% INFO    : Bus 95241	: V=0.9798155, theta=-65.437244 -> V=1.0, theta=0.0
% INFO    : Bus 95242	: V=0.974686, theta=-66.661151 -> V=1.0, theta=0.0
% INFO    : Bus 95243	: V=1.0137568, theta=-61.069402 -> V=1.0, theta=0.0
% INFO    : Bus 95244	: V=1.0109472, theta=-61.267445 -> V=1.0, theta=0.0
% INFO    : Bus 95245	: V=1.0050621, theta=-62.427293 -> V=1.0, theta=0.0
% INFO    : Bus 95246	: V=1.00977, theta=-61.407039 -> V=1.0, theta=0.0
% INFO    : Bus 95247	: V=1.0081475, theta=-61.976524 -> V=1.0, theta=0.0
% INFO    : Bus 95248	: V=0.9773593, theta=-72.509927 -> V=1.0, theta=0.0
% INFO    : Bus 95249	: V=0.9779878, theta=-73.228044 -> V=1.0, theta=0.0
% INFO    : Bus 95250	: V=0.9770725, theta=-74.83962 -> V=1.0, theta=0.0
% INFO    : Bus 95251	: V=0.9951288, theta=-71.834868 -> V=1.0, theta=0.0
% INFO    : Bus 95252	: V=0.9786795, theta=-73.429059 -> V=1.0, theta=0.0
% INFO    : Bus 95253	: V=0.972809, theta=-75.31515 -> V=1.0, theta=0.0
% INFO    : Bus 95254	: V=0.9747851, theta=-75.01007 -> V=1.0, theta=0.0
% INFO    : Bus 95255	: V=0.9888276, theta=-72.754964 -> V=1.0, theta=0.0
% INFO    : Bus 95256	: V=0.9862024, theta=-73.100374 -> V=1.0, theta=0.0
% INFO    : Bus 95257	: V=0.9781974, theta=-73.55736 -> V=1.0, theta=0.0
% INFO    : Bus 95258	: V=1.0113323, theta=-56.56931 -> V=1.0, theta=0.0
% INFO    : Bus 95259	: V=1.0154285, theta=-56.366256 -> V=1.0, theta=0.0
% INFO    : Bus 95260	: V=1.0159098, theta=-56.47996 -> V=1.0, theta=0.0
% INFO    : Bus 95261	: V=0.9872739, theta=-71.304511 -> V=1.0, theta=0.0
% INFO    : Bus 95262	: V=0.9996283, theta=-69.999132 -> V=1.0, theta=0.0
% INFO    : Bus 95263	: V=1.0000544, theta=-69.900322 -> V=1.0, theta=0.0
% INFO    : Bus 95264	: V=1.0069158, theta=-68.922915 -> V=1.0, theta=0.0
% INFO    : Bus 95265	: V=0.9874818, theta=-69.55924 -> V=1.0, theta=0.0
% INFO    : Bus 95266	: V=1.0050436, theta=-68.635159 -> V=1.0, theta=0.0
% INFO    : Bus 95267	: V=0.9975854, theta=-69.70029 -> V=1.0, theta=0.0
% INFO    : Bus 95268	: V=1.0032394, theta=-69.197797 -> V=1.0, theta=0.0
% INFO    : Bus 95269	: V=1.0042609, theta=-69.300695 -> V=1.0, theta=0.0
% INFO    : Bus 95270	: V=1.0047687, theta=-69.215032 -> V=1.0, theta=0.0
% INFO    : Bus 95271	: V=0.9949181, theta=-70.379117 -> V=1.0, theta=0.0
% INFO    : Bus 95272	: V=0.9924411, theta=-69.895834 -> V=1.0, theta=0.0
% INFO    : Bus 95273	: V=0.984547, theta=-68.548537 -> V=1.0, theta=0.0
% INFO    : Bus 95274	: V=0.9843546, theta=-67.675586 -> V=1.0, theta=0.0
% INFO    : Bus 95275	: V=0.9886563, theta=-65.782949 -> V=1.0, theta=0.0
% INFO    : Bus 95276	: V=0.9915054, theta=-56.48238 -> V=1.0, theta=0.0
% INFO    : Bus 95277	: V=0.9703961, theta=-65.713601 -> V=1.0, theta=0.0
% INFO    : Bus 95278	: V=0.9677683, theta=-66.158264 -> V=1.0, theta=0.0
% INFO    : Bus 95279	: V=0.9733885, theta=-65.80963 -> V=1.0, theta=0.0
% INFO    : Bus 95280	: V=0.9875925, theta=-63.957164 -> V=1.0, theta=0.0
% INFO    : Bus 95281	: V=0.9875005, theta=-62.99948 -> V=1.0, theta=0.0
% INFO    : Bus 95282	: V=0.9853214, theta=-63.23128 -> V=1.0, theta=0.0
% INFO    : Bus 95283	: V=0.9933554, theta=-63.249691 -> V=1.0, theta=0.0
% INFO    : Bus 95284	: V=0.9930616, theta=-63.245763 -> V=1.0, theta=0.0
% INFO    : Bus 95285	: V=1.0003735, theta=-61.362187 -> V=1.0, theta=0.0
% INFO    : Bus 95286	: V=0.9921691, theta=-60.739236 -> V=1.0, theta=0.0
% INFO    : Bus 95287	: V=0.9829986, theta=-63.543605 -> V=1.0, theta=0.0
% INFO    : Bus 95288	: V=0.9809114, theta=-69.21871 -> V=1.0, theta=0.0
% INFO    : Bus 95289	: V=0.9904436, theta=-68.360257 -> V=1.0, theta=0.0
% INFO    : Bus 95290	: V=0.9783334, theta=-69.782021 -> V=1.0, theta=0.0
% INFO    : Bus 95291	: V=0.9673904, theta=-70.920826 -> V=1.0, theta=0.0
% INFO    : Bus 95292	: V=0.9629757, theta=-72.511581 -> V=1.0, theta=0.0
% INFO    : Bus 95293	: V=0.9604844, theta=-73.072094 -> V=1.0, theta=0.0
% INFO    : Bus 95294	: V=0.9802416, theta=-71.146355 -> V=1.0, theta=0.0
% INFO    : Bus 95295	: V=0.9952552, theta=-68.984513 -> V=1.0, theta=0.0
% INFO    : Bus 95296	: V=0.9758834, theta=-71.458817 -> V=1.0, theta=0.0
% INFO    : Bus 95297	: V=0.9640857, theta=-72.480233 -> V=1.0, theta=0.0
% INFO    : Bus 95298	: V=0.9642762, theta=-72.070171 -> V=1.0, theta=0.0
% INFO    : Bus 95299	: V=0.9697112, theta=-71.685762 -> V=1.0, theta=0.0
% INFO    : Bus 95300	: V=0.9738897, theta=-71.071654 -> V=1.0, theta=0.0
% INFO    : Bus 95301	: V=0.9665126, theta=-71.79885 -> V=1.0, theta=0.0
% INFO    : Bus 95302	: V=0.9654124, theta=-71.850203 -> V=1.0, theta=0.0
% INFO    : Bus 95303	: V=0.9906105, theta=-68.306474 -> V=1.0, theta=0.0
% INFO    : Bus 95304	: V=0.984318, theta=-68.98651 -> V=1.0, theta=0.0
% INFO    : Bus 95305	: V=0.990573, theta=-68.34328 -> V=1.0, theta=0.0
% INFO    : Bus 95306	: V=0.9826556, theta=-69.303257 -> V=1.0, theta=0.0
% INFO    : Bus 95307	: V=0.9687169, theta=-71.7365 -> V=1.0, theta=0.0
% INFO    : Bus 95308	: V=0.9664503, theta=-71.917472 -> V=1.0, theta=0.0
% INFO    : Bus 95309	: V=0.9916563, theta=-68.807969 -> V=1.0, theta=0.0
% INFO    : Bus 95310	: V=0.9799323, theta=-70.402991 -> V=1.0, theta=0.0
% INFO    : Bus 95311	: V=0.9765395, theta=-70.87101 -> V=1.0, theta=0.0
% INFO    : Bus 95312	: V=0.9720676, theta=-70.483801 -> V=1.0, theta=0.0
% INFO    : Bus 95313	: V=0.9816842, theta=-69.828288 -> V=1.0, theta=0.0
% INFO    : Bus 95314	: V=0.9871793, theta=-69.188631 -> V=1.0, theta=0.0
% INFO    : Bus 95315	: V=0.9954851, theta=-69.233702 -> V=1.0, theta=0.0
% INFO    : Bus 95316	: V=0.9793707, theta=-69.498147 -> V=1.0, theta=0.0
% INFO    : Bus 95317	: V=0.9532952, theta=-61.535363 -> V=1.0, theta=0.0
% INFO    : Bus 95318	: V=0.9784762, theta=-69.730206 -> V=1.0, theta=0.0
% INFO    : Bus 95319	: V=0.977784, theta=-68.887892 -> V=1.0, theta=0.0
% INFO    : Bus 95320	: V=0.9746095, theta=-71.820825 -> V=1.0, theta=0.0
% INFO    : Bus 95321	: V=1.0095153, theta=-57.884094 -> V=1.0, theta=0.0
% INFO    : Bus 95322	: V=1.0058061, theta=-58.730383 -> V=1.0, theta=0.0
% INFO    : Bus 95323	: V=1.0037774, theta=-59.122776 -> V=1.0, theta=0.0
% INFO    : Bus 95324	: V=0.9888316, theta=-61.629715 -> V=1.0, theta=0.0
% INFO    : Bus 95325	: V=1.0017753, theta=-60.508446 -> V=1.0, theta=0.0
% INFO    : Bus 95326	: V=0.9995902, theta=-60.909041 -> V=1.0, theta=0.0
% INFO    : Bus 95327	: V=0.9853392, theta=-62.19069 -> V=1.0, theta=0.0
% INFO    : Bus 95328	: V=0.9823237, theta=-63.631442 -> V=1.0, theta=0.0
% INFO    : Bus 95329	: V=1.0154104, theta=-55.620052 -> V=1.0, theta=0.0
% INFO    : Bus 95330	: V=0.9989994, theta=-59.219435 -> V=1.0, theta=0.0
% INFO    : Bus 95331	: V=0.9834064, theta=-71.07284 -> V=1.0, theta=0.0
% INFO    : Bus 95332	: V=1.02, theta=-63.412168 -> V=1.0, theta=0.0
% INFO    : Bus 95333	: V=0.0, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 95334	: V=0.0, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 95335	: V=1.0185589, theta=-40.952302 -> V=1.0, theta=0.0
% INFO    : Bus 95336	: V=1.0283135, theta=-58.131453 -> V=1.0, theta=0.0
% INFO    : Bus 95337	: V=0.9793545, theta=-40.568549 -> V=1.0, theta=0.0
% INFO    : Bus 95338	: V=1.006087, theta=-23.461305 -> V=1.0, theta=0.0
% INFO    : Bus 95339	: V=1.006215, theta=-60.359641 -> V=1.0, theta=0.0
% INFO    : Bus 95340	: V=1.0237513, theta=-29.274893 -> V=1.0, theta=0.0
% INFO    : Bus 95342	: V=0.0, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 95343	: V=0.9988576, theta=-37.111875 -> V=1.0, theta=0.0
% INFO    : Bus 95344	: V=0.0, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 95345	: V=1.0203341, theta=-39.060838 -> V=1.0, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 1	: Pg=1253.0, Qg=90.63 -> Pg=659.0, Qg=0.0
% INFO    : Gen at bus 1	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 1	: Pg=909.9, Qg=90.63 -> Pg=479.95, Qg=68.7
% INFO    : Gen at bus 1	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 2	: Pg=312.82, Qg=222.8 -> Pg=280.0, Qg=34.75
% INFO    : Gen at bus 2	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3	: Pg=399.99, Qg=85.72 -> Pg=265.0, Qg=57.3
% INFO    : Gen at bus 3	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3	: Pg=79.55, Qg=85.72 -> Pg=110.84, Qg=23.35
% INFO    : Gen at bus 3	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4	: Pg=196.53, Qg=127.27 -> Pg=224.5, Qg=41.4
% INFO    : Gen at bus 4	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4	: Pg=196.53, Qg=127.27 -> Pg=224.5, Qg=41.4
% INFO    : Gen at bus 4	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 5	: Pg=190.41, Qg=102.18 -> Pg=212.5, Qg=40.1
% INFO    : Gen at bus 5	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 5	: Pg=190.41, Qg=102.18 -> Pg=212.5, Qg=40.1
% INFO    : Gen at bus 5	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 5	: Pg=190.41, Qg=102.18 -> Pg=212.5, Qg=40.1
% INFO    : Gen at bus 5	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 6	: Pg=179.99, Qg=57.14 -> Pg=137.7, Qg=25.8
% INFO    : Gen at bus 6	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 6	: Pg=170.0, Qg=57.14 -> Pg=130.05, Qg=24.35
% INFO    : Gen at bus 6	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 6	: Pg=170.0, Qg=57.14 -> Pg=130.05, Qg=24.35
% INFO    : Gen at bus 6	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 7	: Pg=162.8, Qg=148.4 -> Pg=169.7, Qg=34.3
% INFO    : Gen at bus 7	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 7	: Pg=77.25, Qg=70.4 -> Pg=79.3, Qg=16.25
% INFO    : Gen at bus 7	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 7	: Pg=282.15, Qg=200.9 -> Pg=269.95, Qg=31.3
% INFO    : Gen at bus 7	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8	: Pg=65.28, Qg=72.0 -> Pg=73.0, Qg=20.0
% INFO    : Gen at bus 8	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 9	: Pg=57.12, Qg=27.6 -> Pg=62.0, Qg=0.0
% INFO    : Gen at bus 9	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 10	: Pg=195.63, Qg=164.8 -> Pg=269.95, Qg=31.3
% INFO    : Gen at bus 10	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 10	: Pg=40.0, Qg=56.3 -> Pg=57.5, Qg=15.65
% INFO    : Gen at bus 10	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 11	: Pg=67.0, Qg=41.5 -> Pg=38.5, Qg=9.6
% INFO    : Gen at bus 11	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13	: Pg=40.0, Qg=24.8 -> Pg=27.5, Qg=5.75
% INFO    : Gen at bus 13	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13	: Pg=56.0, Qg=34.7 -> Pg=36.0, Qg=8.0
% INFO    : Gen at bus 13	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14	: Pg=34.68, Qg=31.6 -> Pg=33.5, Qg=7.3
% INFO    : Gen at bus 14	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14	: Pg=34.68, Qg=31.6 -> Pg=33.5, Qg=7.3
% INFO    : Gen at bus 14	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14	: Pg=34.68, Qg=31.6 -> Pg=33.5, Qg=7.3
% INFO    : Gen at bus 14	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14	: Pg=34.68, Qg=31.6 -> Pg=33.5, Qg=7.3
% INFO    : Gen at bus 14	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 15	: Pg=34.0, Qg=31.0 -> Pg=26.0, Qg=7.15
% INFO    : Gen at bus 15	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 15	: Pg=34.0, Qg=31.0 -> Pg=26.0, Qg=7.15
% INFO    : Gen at bus 15	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 15	: Pg=34.0, Qg=31.0 -> Pg=26.0, Qg=7.15
% INFO    : Gen at bus 15	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 15	: Pg=34.0, Qg=31.0 -> Pg=26.0, Qg=7.15
% INFO    : Gen at bus 15	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 15	: Pg=34.0, Qg=31.0 -> Pg=26.0, Qg=7.15
% INFO    : Gen at bus 15	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 16	: Pg=30.6, Qg=21.8 -> Pg=33.5, Qg=3.4
% INFO    : Gen at bus 16	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 16	: Pg=30.6, Qg=33.8 -> Pg=33.5, Qg=9.4
% INFO    : Gen at bus 16	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 17	: Pg=29.99, Qg=21.4 -> Pg=34.55, Qg=3.35
% INFO    : Gen at bus 17	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 17	: Pg=23.19, Qg=16.5 -> Pg=19.55, Qg=2.55
% INFO    : Gen at bus 17	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 18	: Pg=28.43, Qg=20.2 -> Pg=25.9, Qg=3.15
% INFO    : Gen at bus 18	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 18	: Pg=28.43, Qg=20.2 -> Pg=25.9, Qg=3.15
% INFO    : Gen at bus 18	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 18	: Pg=28.43, Qg=20.2 -> Pg=25.9, Qg=3.15
% INFO    : Gen at bus 18	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 18	: Pg=28.43, Qg=31.4 -> Pg=25.9, Qg=8.75
% INFO    : Gen at bus 18	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 19	: Pg=35.88, Qg=23.1 -> Pg=36.1, Qg=5.35
% INFO    : Gen at bus 19	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20	: Pg=21.3, Qg=0.0 -> Pg=18.65, Qg=0.0
% INFO    : Gen at bus 20	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 21	: Pg=5.19, Qg=4.25 -> Pg=4.215, Qg=0.85
% INFO    : Gen at bus 21	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 21	: Pg=5.19, Qg=4.25 -> Pg=4.215, Qg=0.85
% INFO    : Gen at bus 21	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 21	: Pg=5.19, Qg=4.25 -> Pg=4.215, Qg=0.85
% INFO    : Gen at bus 21	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 21	: Pg=5.19, Qg=4.25 -> Pg=4.215, Qg=0.85
% INFO    : Gen at bus 21	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 23	: Pg=17.52, Qg=16.0 -> Pg=18.9, Qg=3.7
% INFO    : Gen at bus 23	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 25	: Pg=23.6, Qg=18.0 -> Pg=23.5, Qg=5.0
% INFO    : Gen at bus 25	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 26	: Pg=23.2, Qg=14.4 -> Pg=19.1, Qg=3.35
% INFO    : Gen at bus 26	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 26	: Pg=23.2, Qg=14.4 -> Pg=19.1, Qg=3.35
% INFO    : Gen at bus 26	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 26	: Pg=23.2, Qg=14.4 -> Pg=19.1, Qg=3.35
% INFO    : Gen at bus 26	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27	: Pg=17.92, Qg=13.5 -> Pg=19.6, Qg=3.1
% INFO    : Gen at bus 27	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28	: Pg=16.67, Qg=13.5 -> Pg=18.95, Qg=3.1
% INFO    : Gen at bus 28	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 29	: Pg=21.8, Qg=13.5 -> Pg=19.6, Qg=3.1
% INFO    : Gen at bus 29	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 30	: Pg=13.74, Qg=14.6 -> Pg=13.8, Qg=3.95
% INFO    : Gen at bus 30	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 31	: Pg=20.0, Qg=12.4 -> Pg=19.8, Qg=2.85
% INFO    : Gen at bus 31	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 31	: Pg=20.0, Qg=12.4 -> Pg=19.55, Qg=2.85
% INFO    : Gen at bus 31	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 31	: Pg=25.0, Qg=15.5 -> Pg=22.05, Qg=3.6
% INFO    : Gen at bus 31	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 31	: Pg=25.0, Qg=15.5 -> Pg=22.05, Qg=3.6
% INFO    : Gen at bus 31	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 31	: Pg=25.0, Qg=15.5 -> Pg=21.85, Qg=3.6
% INFO    : Gen at bus 31	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 32	: Pg=579.98, Qg=126.31 -> Pg=375.0, Qg=0.0
% INFO    : Gen at bus 32	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 32	: Pg=275.84, Qg=126.31 -> Pg=392.5, Qg=0.0
% INFO    : Gen at bus 32	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 33	: Pg=57.8, Qg=21.08 -> Pg=70.0, Qg=6.45
% INFO    : Gen at bus 33	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 33	: Pg=60.59, Qg=21.08 -> Pg=64.185, Qg=6.725
% INFO    : Gen at bus 33	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 33	: Pg=60.59, Qg=21.08 -> Pg=64.185, Qg=6.725
% INFO    : Gen at bus 33	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 33	: Pg=60.59, Qg=21.08 -> Pg=64.185, Qg=6.725
% INFO    : Gen at bus 33	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 33	: Pg=57.8, Qg=21.08 -> Pg=62.5, Qg=6.45
% INFO    : Gen at bus 33	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 33	: Pg=57.8, Qg=21.08 -> Pg=62.5, Qg=6.45
% INFO    : Gen at bus 33	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 33	: Pg=57.8, Qg=21.08 -> Pg=62.5, Qg=6.45
% INFO    : Gen at bus 33	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 33	: Pg=57.8, Qg=21.08 -> Pg=62.5, Qg=6.45
% INFO    : Gen at bus 33	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 33	: Pg=71.4, Qg=21.08 -> Pg=62.5, Qg=7.95
% INFO    : Gen at bus 33	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 33	: Pg=60.59, Qg=21.08 -> Pg=64.185, Qg=6.725
% INFO    : Gen at bus 33	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 33	: Pg=60.59, Qg=21.08 -> Pg=64.185, Qg=6.725
% INFO    : Gen at bus 33	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 33	: Pg=60.59, Qg=21.08 -> Pg=64.185, Qg=6.725
% INFO    : Gen at bus 33	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 34	: Pg=227.51, Qg=31.44 -> Pg=260.0, Qg=22.65
% INFO    : Gen at bus 34	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 34	: Pg=227.51, Qg=31.44 -> Pg=260.0, Qg=22.65
% INFO    : Gen at bus 34	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35	: Pg=196.53, Qg=171.05 -> Pg=222.0, Qg=60.25
% INFO    : Gen at bus 35	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 36	: Pg=196.53, Qg=145.68 -> Pg=219.5, Qg=41.4
% INFO    : Gen at bus 36	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 36	: Pg=196.53, Qg=145.68 -> Pg=219.5, Qg=41.4
% INFO    : Gen at bus 36	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 37	: Pg=196.53, Qg=58.22 -> Pg=219.5, Qg=41.4
% INFO    : Gen at bus 37	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 37	: Pg=196.53, Qg=58.22 -> Pg=219.5, Qg=41.4
% INFO    : Gen at bus 37	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 38	: Pg=419.58, Qg=149.76 -> Pg=353.5, Qg=46.55
% INFO    : Gen at bus 38	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 38	: Pg=189.46, Qg=149.76 -> Pg=209.3, Qg=39.9
% INFO    : Gen at bus 38	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 38	: Pg=189.46, Qg=149.76 -> Pg=209.3, Qg=39.9
% INFO    : Gen at bus 38	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 38	: Pg=189.46, Qg=149.76 -> Pg=209.3, Qg=39.9
% INFO    : Gen at bus 38	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 38	: Pg=189.46, Qg=149.76 -> Pg=209.3, Qg=39.9
% INFO    : Gen at bus 38	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 38	: Pg=214.21, Qg=149.76 -> Pg=195.0, Qg=45.1
% INFO    : Gen at bus 38	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 38	: Pg=214.21, Qg=149.76 -> Pg=195.0, Qg=45.1
% INFO    : Gen at bus 38	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39	: Pg=146.98, Qg=156.77 -> Pg=209.3, Qg=39.9
% INFO    : Gen at bus 39	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39	: Pg=146.98, Qg=156.77 -> Pg=209.3, Qg=39.9
% INFO    : Gen at bus 39	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39	: Pg=148.53, Qg=156.77 -> Pg=195.0, Qg=45.1
% INFO    : Gen at bus 39	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40	: Pg=14.5, Qg=12.4 -> Pg=17.0, Qg=2.85
% INFO    : Gen at bus 40	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40	: Pg=18.5, Qg=16.9 -> Pg=20.6, Qg=3.9
% INFO    : Gen at bus 40	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40	: Pg=15.64, Qg=17.3 -> Pg=14.0, Qg=4.8
% INFO    : Gen at bus 40	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40	: Pg=57.49, Qg=54.13 -> Pg=61.265, Qg=12.98
% INFO    : Gen at bus 40	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40	: Pg=57.49, Qg=54.13 -> Pg=61.265, Qg=12.98
% INFO    : Gen at bus 40	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40	: Pg=57.49, Qg=54.13 -> Pg=61.265, Qg=12.98
% INFO    : Gen at bus 40	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40	: Pg=126.62, Qg=92.37 -> Pg=138.1, Qg=26.65
% INFO    : Gen at bus 40	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 41	: Pg=323.36, Qg=70.59 -> Pg=262.75, Qg=35.9
% INFO    : Gen at bus 41	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 41	: Pg=163.89, Qg=70.59 -> Pg=170.5, Qg=18.2
% INFO    : Gen at bus 41	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 41	: Pg=163.89, Qg=70.59 -> Pg=170.5, Qg=18.2
% INFO    : Gen at bus 41	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 41	: Pg=436.99, Qg=70.59 -> Pg=496.3, Qg=0.0
% INFO    : Gen at bus 41	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 42	: Pg=130.89, Qg=20.26 -> Pg=180.0, Qg=0.0
% INFO    : Gen at bus 42	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 42	: Pg=130.89, Qg=20.26 -> Pg=180.0, Qg=0.0
% INFO    : Gen at bus 42	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 42	: Pg=130.89, Qg=20.26 -> Pg=180.0, Qg=0.0
% INFO    : Gen at bus 42	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 42	: Pg=130.89, Qg=20.26 -> Pg=180.0, Qg=0.0
% INFO    : Gen at bus 42	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 43	: Pg=156.41, Qg=75.6 -> Pg=172.5, Qg=0.0
% INFO    : Gen at bus 43	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 43	: Pg=88.4, Qg=42.7 -> Pg=97.5, Qg=0.0
% INFO    : Gen at bus 43	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 44	: Pg=136.01, Qg=123.9 -> Pg=154.0, Qg=28.6
% INFO    : Gen at bus 44	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 45	: Pg=63.41, Qg=84.3 -> Pg=98.0, Qg=19.5
% INFO    : Gen at bus 45	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47	: Pg=88.22, Qg=32.3 -> Pg=106.85, Qg=0.0
% INFO    : Gen at bus 47	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47	: Pg=88.22, Qg=32.3 -> Pg=106.85, Qg=0.0
% INFO    : Gen at bus 47	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47	: Pg=87.52, Qg=32.3 -> Pg=79.35, Qg=0.0
% INFO    : Gen at bus 47	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50	: Pg=69.0, Qg=33.4 -> Pg=37.0, Qg=5.2
% INFO    : Gen at bus 50	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 51	: Pg=8.23, Qg=6.82 -> Pg=9.15, Qg=2.15
% INFO    : Gen at bus 51	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 51	: Pg=8.23, Qg=6.82 -> Pg=9.15, Qg=2.15
% INFO    : Gen at bus 51	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 51	: Pg=8.23, Qg=6.82 -> Pg=9.15, Qg=2.15
% INFO    : Gen at bus 51	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 51	: Pg=8.23, Qg=6.82 -> Pg=9.15, Qg=2.15
% INFO    : Gen at bus 51	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 51	: Pg=8.23, Qg=6.82 -> Pg=9.15, Qg=2.15
% INFO    : Gen at bus 51	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 51	: Pg=8.23, Qg=6.82 -> Pg=9.15, Qg=2.15
% INFO    : Gen at bus 51	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 52	: Pg=66.63, Qg=70.4 -> Pg=71.8, Qg=16.25
% INFO    : Gen at bus 52	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 52	: Pg=40.8, Qg=37.2 -> Pg=42.5, Qg=8.6
% INFO    : Gen at bus 52	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 52	: Pg=40.8, Qg=37.2 -> Pg=42.5, Qg=8.6
% INFO    : Gen at bus 52	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 53	: Pg=57.9, Qg=35.9 -> Pg=51.45, Qg=8.3
% INFO    : Gen at bus 53	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 53	: Pg=27.1, Qg=16.8 -> Pg=18.55, Qg=3.9
% INFO    : Gen at bus 53	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 54	: Pg=53.7, Qg=40.3 -> Pg=30.35, Qg=11.2
% INFO    : Gen at bus 54	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 56	: Pg=30.6, Qg=27.9 -> Pg=32.5, Qg=6.45
% INFO    : Gen at bus 56	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 56	: Pg=30.6, Qg=27.9 -> Pg=32.5, Qg=6.45
% INFO    : Gen at bus 56	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 56	: Pg=30.6, Qg=27.9 -> Pg=32.5, Qg=6.45
% INFO    : Gen at bus 56	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 57	: Pg=14.2, Qg=8.8 -> Pg=9.6, Qg=2.035
% INFO    : Gen at bus 57	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 57	: Pg=14.2, Qg=8.8 -> Pg=9.6, Qg=2.035
% INFO    : Gen at bus 57	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 57	: Pg=14.2, Qg=8.8 -> Pg=9.6, Qg=2.035
% INFO    : Gen at bus 57	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58	: Pg=27.68, Qg=13.4 -> Pg=32.85, Qg=0.0
% INFO    : Gen at bus 58	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58	: Pg=27.68, Qg=13.4 -> Pg=32.85, Qg=0.0
% INFO    : Gen at bus 58	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58	: Pg=27.68, Qg=13.4 -> Pg=32.85, Qg=0.0
% INFO    : Gen at bus 58	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58	: Pg=36.31, Qg=17.6 -> Pg=29.7, Qg=0.0
% INFO    : Gen at bus 58	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 59	: Pg=27.38, Qg=25.0 -> Pg=24.15, Qg=5.8
% INFO    : Gen at bus 59	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 60	: Pg=34.0, Qg=16.5 -> Pg=21.5, Qg=2.6
% INFO    : Gen at bus 60	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 60	: Pg=64.5, Qg=31.2 -> Pg=35.25, Qg=4.85
% INFO    : Gen at bus 60	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61	: Pg=7.92, Qg=10.45 -> Pg=12.1, Qg=2.45
% INFO    : Gen at bus 61	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61	: Pg=7.92, Qg=10.45 -> Pg=12.1, Qg=2.45
% INFO    : Gen at bus 61	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 62	: Pg=11.0, Qg=8.27 -> Pg=6.665, Qg=2.3
% INFO    : Gen at bus 62	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 62	: Pg=11.0, Qg=8.27 -> Pg=6.665, Qg=2.3
% INFO    : Gen at bus 62	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 62	: Pg=11.0, Qg=8.27 -> Pg=6.665, Qg=2.3
% INFO    : Gen at bus 62	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 63	: Pg=10.83, Qg=8.13 -> Pg=5.915, Qg=2.265
% INFO    : Gen at bus 63	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 63	: Pg=10.83, Qg=8.13 -> Pg=5.915, Qg=2.265
% INFO    : Gen at bus 63	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 63	: Pg=10.83, Qg=8.13 -> Pg=5.915, Qg=2.265
% INFO    : Gen at bus 63	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 64	: Pg=17.68, Qg=12.6 -> Pg=17.0, Qg=1.95
% INFO    : Gen at bus 64	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 64	: Pg=17.68, Qg=12.6 -> Pg=17.0, Qg=1.95
% INFO    : Gen at bus 64	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 65	: Pg=6.8, Qg=4.22 -> Pg=4.4, Qg=0.975
% INFO    : Gen at bus 65	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 65	: Pg=11.0, Qg=6.8 -> Pg=6.0, Qg=1.575
% INFO    : Gen at bus 65	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 65	: Pg=6.8, Qg=4.22 -> Pg=4.4, Qg=0.975
% INFO    : Gen at bus 65	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 65	: Pg=6.8, Qg=4.22 -> Pg=4.4, Qg=0.975
% INFO    : Gen at bus 65	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 65	: Pg=6.8, Qg=4.22 -> Pg=4.4, Qg=0.975
% INFO    : Gen at bus 65	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 65	: Pg=6.8, Qg=4.22 -> Pg=4.4, Qg=0.975
% INFO    : Gen at bus 65	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 65	: Pg=6.8, Qg=4.22 -> Pg=4.4, Qg=0.975
% INFO    : Gen at bus 65	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 65	: Pg=12.5, Qg=7.75 -> Pg=9.25, Qg=1.8
% INFO    : Gen at bus 65	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 65	: Pg=12.5, Qg=7.75 -> Pg=9.25, Qg=1.8
% INFO    : Gen at bus 65	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 65	: Pg=11.0, Qg=6.8 -> Pg=6.0, Qg=1.575
% INFO    : Gen at bus 65	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66	: Pg=24.7, Qg=18.5 -> Pg=21.85, Qg=5.15
% INFO    : Gen at bus 66	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 67	: Pg=72.38, Qg=46.0 -> Pg=82.5, Qg=7.15
% INFO    : Gen at bus 67	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 67	: Pg=15.64, Qg=11.1 -> Pg=13.0, Qg=1.7
% INFO    : Gen at bus 67	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 67	: Pg=23.0, Qg=17.5 -> Pg=25.65, Qg=4.05
% INFO    : Gen at bus 67	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 68	: Pg=7.63, Qg=0.0 -> Pg=3.865, Qg=0.0
% INFO    : Gen at bus 68	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 68	: Pg=7.63, Qg=0.0 -> Pg=3.865, Qg=0.0
% INFO    : Gen at bus 68	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 68	: Pg=7.63, Qg=0.0 -> Pg=3.865, Qg=0.0
% INFO    : Gen at bus 68	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 69	: Pg=43.6, Qg=14.3 -> Pg=35.8, Qg=0.0
% INFO    : Gen at bus 69	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 69	: Pg=21.3, Qg=13.2 -> Pg=18.65, Qg=3.05
% INFO    : Gen at bus 69	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 71	: Pg=15.53, Qg=13.1 -> Pg=18.05, Qg=3.05
% INFO    : Gen at bus 71	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75	: Pg=125.26, Qg=67.56 -> Pg=144.6, Qg=26.4
% INFO    : Gen at bus 75	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75	: Pg=125.26, Qg=67.56 -> Pg=144.6, Qg=26.4
% INFO    : Gen at bus 75	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75	: Pg=132.95, Qg=67.56 -> Pg=135.25, Qg=28.0
% INFO    : Gen at bus 75	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77	: Pg=120.91, Qg=42.12 -> Pg=121.4, Qg=25.45
% INFO    : Gen at bus 77	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77	: Pg=120.91, Qg=42.12 -> Pg=121.4, Qg=25.45
% INFO    : Gen at bus 77	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77	: Pg=132.33, Qg=42.12 -> Pg=117.3, Qg=27.85
% INFO    : Gen at bus 77	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=3.03, Qg=0.5 -> Pg=2.805, Qg=0.335
% INFO    : Gen at bus 78	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79	: Pg=69.77, Qg=6.99 -> Pg=53.8, Qg=9.2
% INFO    : Gen at bus 79	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82	: Pg=57.0, Qg=-2.54 -> Pg=28.5, Qg=0.0
% INFO    : Gen at bus 82	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 83	: Pg=39.36, Qg=32.99 -> Pg=46.25, Qg=7.8
% INFO    : Gen at bus 83	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 83	: Pg=39.36, Qg=32.99 -> Pg=46.25, Qg=7.8
% INFO    : Gen at bus 83	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 83	: Pg=39.36, Qg=32.99 -> Pg=46.25, Qg=7.8
% INFO    : Gen at bus 83	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84	: Pg=430.05, Qg=62.2 -> Pg=346.2, Qg=0.0
% INFO    : Gen at bus 84	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84	: Pg=30.0, Qg=62.2 -> Pg=71.8, Qg=16.25
% INFO    : Gen at bus 84	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84	: Pg=10.0, Qg=31.0 -> Pg=30.0, Qg=7.15
% INFO    : Gen at bus 84	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84	: Pg=10.0, Qg=31.0 -> Pg=30.0, Qg=7.15
% INFO    : Gen at bus 84	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 85	: Pg=48.5, Qg=23.5 -> Pg=26.75, Qg=3.65
% INFO    : Gen at bus 85	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 85	: Pg=68.4, Qg=42.4 -> Pg=36.7, Qg=9.8
% INFO    : Gen at bus 85	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 86	: Pg=45.7, Qg=14.0 -> Pg=31.85, Qg=6.55
% INFO    : Gen at bus 86	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87	: Pg=5.04, Qg=1.58 -> Pg=5.795, Qg=0.565
% INFO    : Gen at bus 87	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87	: Pg=5.04, Qg=1.58 -> Pg=5.795, Qg=0.565
% INFO    : Gen at bus 87	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87	: Pg=5.04, Qg=1.58 -> Pg=5.795, Qg=0.565
% INFO    : Gen at bus 87	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87	: Pg=5.04, Qg=1.58 -> Pg=5.795, Qg=0.565
% INFO    : Gen at bus 87	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87	: Pg=5.04, Qg=1.58 -> Pg=5.795, Qg=0.565
% INFO    : Gen at bus 87	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87	: Pg=5.04, Qg=1.58 -> Pg=5.795, Qg=0.565
% INFO    : Gen at bus 87	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88	: Pg=42.0, Qg=3.81 -> Pg=21.0, Qg=0.0
% INFO    : Gen at bus 88	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89	: Pg=39.6, Qg=19.2 -> Pg=29.8, Qg=3.0
% INFO    : Gen at bus 89	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 90	: Pg=26.93, Qg=4.01 -> Pg=28.8, Qg=3.0
% INFO    : Gen at bus 90	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91	: Pg=25.5, Qg=28.1 -> Pg=26.25, Qg=7.8
% INFO    : Gen at bus 91	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 93	: Pg=20.4, Qg=7.7 -> Pg=22.5, Qg=2.25
% INFO    : Gen at bus 93	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 93	: Pg=20.4, Qg=7.7 -> Pg=22.5, Qg=2.25
% INFO    : Gen at bus 93	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 94	: Pg=2.23, Qg=0.6 -> Pg=1.55, Qg=0.0
% INFO    : Gen at bus 94	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 94	: Pg=2.23, Qg=0.6 -> Pg=1.55, Qg=0.0
% INFO    : Gen at bus 94	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 94	: Pg=2.23, Qg=0.6 -> Pg=1.55, Qg=0.0
% INFO    : Gen at bus 94	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 94	: Pg=2.23, Qg=0.6 -> Pg=1.55, Qg=0.0
% INFO    : Gen at bus 94	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 94	: Pg=2.23, Qg=0.6 -> Pg=1.55, Qg=0.0
% INFO    : Gen at bus 94	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 94	: Pg=2.23, Qg=0.6 -> Pg=1.55, Qg=0.0
% INFO    : Gen at bus 94	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 94	: Pg=2.23, Qg=0.6 -> Pg=1.55, Qg=0.0
% INFO    : Gen at bus 94	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 94	: Pg=2.23, Qg=0.6 -> Pg=1.55, Qg=0.0
% INFO    : Gen at bus 94	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 94	: Pg=2.23, Qg=0.6 -> Pg=1.55, Qg=0.0
% INFO    : Gen at bus 94	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 94	: Pg=2.23, Qg=0.6 -> Pg=1.55, Qg=0.0
% INFO    : Gen at bus 94	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 94	: Pg=2.23, Qg=0.6 -> Pg=1.55, Qg=0.0
% INFO    : Gen at bus 94	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 94	: Pg=2.23, Qg=0.6 -> Pg=1.55, Qg=0.0
% INFO    : Gen at bus 94	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 94	: Pg=2.23, Qg=0.6 -> Pg=1.55, Qg=0.0
% INFO    : Gen at bus 94	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 95	: Pg=9.69, Qg=8.85 -> Pg=8.125, Qg=2.05
% INFO    : Gen at bus 95	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 95	: Pg=9.69, Qg=8.85 -> Pg=8.125, Qg=2.05
% INFO    : Gen at bus 95	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 96	: Pg=9.66, Qg=6.9 -> Pg=7.2, Qg=1.075
% INFO    : Gen at bus 96	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 96	: Pg=9.66, Qg=6.9 -> Pg=7.2, Qg=1.075
% INFO    : Gen at bus 96	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 98	: Pg=18.7, Qg=17.0 -> Pg=16.75, Qg=3.9
% INFO    : Gen at bus 98	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 99	: Pg=1.5, Qg=2.97 -> Pg=2.965, Qg=0.745
% INFO    : Gen at bus 99	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 99	: Pg=1.5, Qg=2.97 -> Pg=2.965, Qg=0.745
% INFO    : Gen at bus 99	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 99	: Pg=1.5, Qg=2.97 -> Pg=2.965, Qg=0.745
% INFO    : Gen at bus 99	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 99	: Pg=1.5, Qg=2.97 -> Pg=2.965, Qg=0.745
% INFO    : Gen at bus 99	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 99	: Pg=1.5, Qg=2.97 -> Pg=2.965, Qg=0.745
% INFO    : Gen at bus 99	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 99	: Pg=1.5, Qg=2.97 -> Pg=2.965, Qg=0.745
% INFO    : Gen at bus 99	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 100	: Pg=25.5, Qg=4.61 -> Pg=12.75, Qg=0.0
% INFO    : Gen at bus 100	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 101	: Pg=17.18, Qg=15.7 -> Pg=15.15, Qg=3.65
% INFO    : Gen at bus 101	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 102	: Pg=17.0, Qg=1.67 -> Pg=17.0, Qg=1.9
% INFO    : Gen at bus 102	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 102	: Pg=17.0, Qg=1.67 -> Pg=17.0, Qg=1.9
% INFO    : Gen at bus 102	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 102	: Pg=20.4, Qg=1.67 -> Pg=19.0, Qg=2.25
% INFO    : Gen at bus 102	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 104	: Pg=14.96, Qg=10.18 -> Pg=14.0, Qg=3.15
% INFO    : Gen at bus 104	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 105	: Pg=1242.0, Qg=408.2 -> Pg=801.0, Qg=0.0
% INFO    : Gen at bus 105	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 106	: Pg=281.53, Qg=0.37 -> Pg=237.0, Qg=31.25
% INFO    : Gen at bus 106	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 107	: Pg=176.81, Qg=131.88 -> Pg=207.5, Qg=37.2
% INFO    : Gen at bus 107	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 107	: Pg=176.81, Qg=131.88 -> Pg=207.5, Qg=37.2
% INFO    : Gen at bus 107	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 107	: Pg=183.61, Qg=131.88 -> Pg=177.5, Qg=38.65
% INFO    : Gen at bus 107	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 108	: Pg=159.33, Qg=78.56 -> Pg=152.15, Qg=17.7
% INFO    : Gen at bus 108	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 108	: Pg=126.21, Qg=78.56 -> Pg=145.3, Qg=26.55
% INFO    : Gen at bus 108	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 108	: Pg=126.21, Qg=78.56 -> Pg=145.3, Qg=26.55
% INFO    : Gen at bus 108	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 109	: Pg=36.25, Qg=31.0 -> Pg=42.5, Qg=7.15
% INFO    : Gen at bus 109	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 109	: Pg=34.0, Qg=31.0 -> Pg=31.5, Qg=7.15
% INFO    : Gen at bus 109	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 109	: Pg=34.0, Qg=31.0 -> Pg=31.5, Qg=7.15
% INFO    : Gen at bus 109	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 109	: Pg=14.42, Qg=13.1 -> Pg=13.1, Qg=3.0
% INFO    : Gen at bus 109	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 110	: Pg=12.65, Qg=11.55 -> Pg=11.3, Qg=2.675
% INFO    : Gen at bus 110	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 110	: Pg=12.65, Qg=11.55 -> Pg=11.3, Qg=2.675
% INFO    : Gen at bus 110	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 110	: Pg=82.85, Qg=70.4 -> Pg=96.8, Qg=16.25
% INFO    : Gen at bus 110	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 110	: Pg=235.02, Qg=97.54 -> Pg=282.8, Qg=26.1
% INFO    : Gen at bus 110	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 112	: Pg=25.0, Qg=18.8 -> Pg=20.0, Qg=5.25
% INFO    : Gen at bus 112	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 113	: Pg=24.0, Qg=9.5 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 113	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 114	: Pg=20.0, Qg=9.7 -> Pg=11.0, Qg=1.5
% INFO    : Gen at bus 114	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 115	: Pg=20.0, Qg=15.0 -> Pg=17.0, Qg=4.15
% INFO    : Gen at bus 115	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 116	: Pg=134.91, Qg=70.85 -> Pg=163.0, Qg=40.85
% INFO    : Gen at bus 116	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 116	: Pg=134.91, Qg=70.85 -> Pg=163.0, Qg=40.85
% INFO    : Gen at bus 116	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 116	: Pg=138.73, Qg=70.85 -> Pg=102.0, Qg=42.5
% INFO    : Gen at bus 116	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 117	: Pg=121.93, Qg=111.1 -> Pg=127.15, Qg=25.65
% INFO    : Gen at bus 117	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 117	: Pg=63.38, Qg=57.8 -> Pg=74.1, Qg=13.35
% INFO    : Gen at bus 117	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 118	: Pg=41.2, Qg=34.5 -> Pg=43.0, Qg=9.6
% INFO    : Gen at bus 118	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 118	: Pg=41.2, Qg=34.5 -> Pg=43.0, Qg=9.6
% INFO    : Gen at bus 118	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 118	: Pg=41.2, Qg=36.0 -> Pg=44.0, Qg=10.0
% INFO    : Gen at bus 118	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 118	: Pg=85.0, Qg=71.36 -> Pg=97.5, Qg=17.9
% INFO    : Gen at bus 118	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 118	: Pg=85.0, Qg=71.36 -> Pg=97.5, Qg=17.9
% INFO    : Gen at bus 118	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 118	: Pg=85.0, Qg=71.36 -> Pg=97.5, Qg=17.9
% INFO    : Gen at bus 118	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 119	: Pg=56.31, Qg=9.53 -> Pg=60.4, Qg=11.85
% INFO    : Gen at bus 119	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 119	: Pg=56.31, Qg=9.53 -> Pg=60.4, Qg=11.85
% INFO    : Gen at bus 119	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 119	: Pg=60.25, Qg=9.53 -> Pg=59.3, Qg=12.7
% INFO    : Gen at bus 119	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 120	: Pg=56.31, Qg=44.24 -> Pg=66.4, Qg=11.85
% INFO    : Gen at bus 120	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 120	: Pg=56.31, Qg=44.24 -> Pg=66.4, Qg=11.85
% INFO    : Gen at bus 120	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 120	: Pg=60.25, Qg=44.24 -> Pg=64.3, Qg=12.7
% INFO    : Gen at bus 120	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 124	: Pg=41.8, Qg=31.4 -> Pg=32.9, Qg=8.75
% INFO    : Gen at bus 124	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 125	: Pg=13.6, Qg=10.2 -> Pg=8.8, Qg=2.835
% INFO    : Gen at bus 125	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 125	: Pg=13.6, Qg=10.2 -> Pg=8.8, Qg=2.835
% INFO    : Gen at bus 125	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 125	: Pg=13.6, Qg=10.2 -> Pg=8.8, Qg=2.835
% INFO    : Gen at bus 125	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 126	: Pg=8.07, Qg=5.6 -> Pg=7.4, Qg=0.0
% INFO    : Gen at bus 126	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 126	: Pg=8.07, Qg=5.6 -> Pg=7.4, Qg=0.0
% INFO    : Gen at bus 126	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 126	: Pg=8.07, Qg=5.6 -> Pg=7.4, Qg=0.0
% INFO    : Gen at bus 126	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 128	: Pg=8.32, Qg=7.64 -> Pg=9.6, Qg=2.335
% INFO    : Gen at bus 128	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 128	: Pg=8.32, Qg=7.64 -> Pg=9.6, Qg=2.335
% INFO    : Gen at bus 128	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 128	: Pg=8.32, Qg=7.64 -> Pg=9.6, Qg=2.335
% INFO    : Gen at bus 128	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 129	: Pg=12.02, Qg=15.8 -> Pg=15.25, Qg=3.65
% INFO    : Gen at bus 129	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 130	: Pg=4.2, Qg=0.0 -> Pg=2.3, Qg=0.0
% INFO    : Gen at bus 130	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 130	: Pg=4.2, Qg=0.0 -> Pg=2.3, Qg=0.0
% INFO    : Gen at bus 130	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 130	: Pg=4.2, Qg=0.0 -> Pg=2.3, Qg=0.0
% INFO    : Gen at bus 130	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 130	: Pg=4.2, Qg=0.0 -> Pg=2.3, Qg=0.0
% INFO    : Gen at bus 130	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 130	: Pg=4.2, Qg=0.0 -> Pg=2.3, Qg=0.0
% INFO    : Gen at bus 130	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 130	: Pg=4.2, Qg=0.0 -> Pg=2.3, Qg=0.0
% INFO    : Gen at bus 130	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 131	: Pg=21.5, Qg=0.0 -> Pg=17.35, Qg=0.0
% INFO    : Gen at bus 131	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3502	: Pg=1299.0, Qg=266.49 -> Pg=649.5, Qg=270.65
% INFO    : Gen at bus 3502	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3503	: Pg=1012.0, Qg=266.49 -> Pg=506.0, Qg=210.85
% INFO    : Gen at bus 3503	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3504	: Pg=115.98, Qg=133.65 -> Pg=473.4, Qg=0.0
% INFO    : Gen at bus 3504	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3504	: Pg=425.21, Qg=133.65 -> Pg=473.4, Qg=0.0
% INFO    : Gen at bus 3504	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3505	: Pg=623.43, Qg=0.0 -> Pg=442.0, Qg=0.0
% INFO    : Gen at bus 3505	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3506	: Pg=882.0, Qg=123.01 -> Pg=441.0, Qg=183.75
% INFO    : Gen at bus 3506	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3507	: Pg=172.84, Qg=111.51 -> Pg=402.55, Qg=49.45
% INFO    : Gen at bus 3507	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3508	: Pg=1259.3, Qg=61.5 -> Pg=667.15, Qg=95.05
% INFO    : Gen at bus 3508	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3508	: Pg=641.8, Qg=61.5 -> Pg=373.4, Qg=91.95
% INFO    : Gen at bus 3508	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3509	: Pg=614.66, Qg=300.8 -> Pg=360.5, Qg=46.9
% INFO    : Gen at bus 3509	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3509	: Pg=422.3, Qg=300.8 -> Pg=350.5, Qg=46.9
% INFO    : Gen at bus 3509	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3510	: Pg=330.36, Qg=50.79 -> Pg=380.5, Qg=46.9
% INFO    : Gen at bus 3510	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3510	: Pg=318.84, Qg=50.79 -> Pg=380.5, Qg=46.9
% INFO    : Gen at bus 3510	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3511	: Pg=614.0, Qg=186.78 -> Pg=452.5, Qg=0.0
% INFO    : Gen at bus 3511	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3512	: Pg=69.97, Qg=29.53 -> Pg=79.7, Qg=0.0
% INFO    : Gen at bus 3512	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3512	: Pg=105.15, Qg=29.53 -> Pg=150.75, Qg=0.0
% INFO    : Gen at bus 3512	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3512	: Pg=105.15, Qg=29.53 -> Pg=150.75, Qg=0.0
% INFO    : Gen at bus 3512	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3512	: Pg=47.38, Qg=29.53 -> Pg=70.1, Qg=7.2
% INFO    : Gen at bus 3512	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3512	: Pg=47.38, Qg=29.53 -> Pg=70.1, Qg=7.2
% INFO    : Gen at bus 3512	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3512	: Pg=47.38, Qg=29.53 -> Pg=70.1, Qg=7.2
% INFO    : Gen at bus 3512	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3513	: Pg=386.99, Qg=70.9 -> Pg=213.5, Qg=29.2
% INFO    : Gen at bus 3513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3513	: Pg=386.99, Qg=70.9 -> Pg=213.5, Qg=29.2
% INFO    : Gen at bus 3513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3513	: Pg=386.99, Qg=70.9 -> Pg=213.5, Qg=29.2
% INFO    : Gen at bus 3513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3513	: Pg=386.99, Qg=70.9 -> Pg=208.5, Qg=29.2
% INFO    : Gen at bus 3513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3514	: Pg=535.48, Qg=259.4 -> Pg=342.75, Qg=40.45
% INFO    : Gen at bus 3514	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3514	: Pg=341.99, Qg=256.5 -> Pg=216.0, Qg=71.25
% INFO    : Gen at bus 3514	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3515	: Pg=187.99, Qg=102.19 -> Pg=101.5, Qg=26.9
% INFO    : Gen at bus 3515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3515	: Pg=25.93, Qg=15.32 -> Pg=22.21, Qg=3.34
% INFO    : Gen at bus 3515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3515	: Pg=25.93, Qg=15.32 -> Pg=22.21, Qg=3.34
% INFO    : Gen at bus 3515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3515	: Pg=25.93, Qg=15.32 -> Pg=22.21, Qg=3.34
% INFO    : Gen at bus 3515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3515	: Pg=25.93, Qg=15.32 -> Pg=22.21, Qg=3.34
% INFO    : Gen at bus 3515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3515	: Pg=25.93, Qg=15.32 -> Pg=22.21, Qg=3.34
% INFO    : Gen at bus 3515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3515	: Pg=187.99, Qg=102.19 -> Pg=101.5, Qg=26.9
% INFO    : Gen at bus 3515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3515	: Pg=25.93, Qg=15.32 -> Pg=22.21, Qg=3.34
% INFO    : Gen at bus 3515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3515	: Pg=25.93, Qg=15.32 -> Pg=22.21, Qg=3.34
% INFO    : Gen at bus 3515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3515	: Pg=25.93, Qg=15.32 -> Pg=22.21, Qg=3.34
% INFO    : Gen at bus 3515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3515	: Pg=25.93, Qg=15.32 -> Pg=22.21, Qg=3.34
% INFO    : Gen at bus 3515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3515	: Pg=25.93, Qg=15.32 -> Pg=22.21, Qg=3.34
% INFO    : Gen at bus 3515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3515	: Pg=25.93, Qg=15.32 -> Pg=22.21, Qg=3.34
% INFO    : Gen at bus 3515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3515	: Pg=25.93, Qg=15.32 -> Pg=22.21, Qg=3.34
% INFO    : Gen at bus 3515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3516	: Pg=93.53, Qg=11.01 -> Pg=115.5, Qg=20.2
% INFO    : Gen at bus 3516	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3516	: Pg=93.53, Qg=11.01 -> Pg=115.5, Qg=20.2
% INFO    : Gen at bus 3516	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3516	: Pg=93.53, Qg=11.01 -> Pg=115.5, Qg=20.2
% INFO    : Gen at bus 3516	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3516	: Pg=201.51, Qg=11.01 -> Pg=247.0, Qg=42.95
% INFO    : Gen at bus 3516	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3516	: Pg=201.51, Qg=11.01 -> Pg=247.0, Qg=42.95
% INFO    : Gen at bus 3516	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3516	: Pg=201.51, Qg=11.01 -> Pg=247.0, Qg=42.95
% INFO    : Gen at bus 3516	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3517	: Pg=170.01, Qg=0.0 -> Pg=125.5, Qg=0.0
% INFO    : Gen at bus 3517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3517	: Pg=170.01, Qg=0.0 -> Pg=125.5, Qg=0.0
% INFO    : Gen at bus 3517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3517	: Pg=170.01, Qg=0.0 -> Pg=125.5, Qg=0.0
% INFO    : Gen at bus 3517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3517	: Pg=170.01, Qg=0.0 -> Pg=125.5, Qg=0.0
% INFO    : Gen at bus 3517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3518	: Pg=152.7, Qg=50.2 -> Pg=116.35, Qg=0.0
% INFO    : Gen at bus 3518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3518	: Pg=196.19, Qg=64.5 -> Pg=160.6, Qg=0.0
% INFO    : Gen at bus 3518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3519	: Pg=199.99, Qg=150.0 -> Pg=132.5, Qg=41.65
% INFO    : Gen at bus 3519	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3519	: Pg=156.2, Qg=117.2 -> Pg=100.6, Qg=32.55
% INFO    : Gen at bus 3519	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3519	: Pg=179.99, Qg=111.6 -> Pg=145.0, Qg=25.8
% INFO    : Gen at bus 3519	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3519	: Pg=179.99, Qg=111.6 -> Pg=145.0, Qg=25.8
% INFO    : Gen at bus 3519	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3520	: Pg=84.87, Qg=0.0 -> Pg=120.0, Qg=0.0
% INFO    : Gen at bus 3520	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3520	: Pg=177.29, Qg=0.0 -> Pg=225.5, Qg=0.0
% INFO    : Gen at bus 3520	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3520	: Pg=84.69, Qg=0.0 -> Pg=231.0, Qg=0.0
% INFO    : Gen at bus 3520	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3520	: Pg=84.69, Qg=0.0 -> Pg=231.0, Qg=0.0
% INFO    : Gen at bus 3520	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3521	: Pg=89.8, Qg=56.7 -> Pg=63.65, Qg=13.375
% INFO    : Gen at bus 3521	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3521	: Pg=89.8, Qg=56.7 -> Pg=63.65, Qg=13.375
% INFO    : Gen at bus 3521	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3521	: Pg=60.0, Qg=37.2 -> Pg=47.5, Qg=8.6
% INFO    : Gen at bus 3521	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3521	: Pg=60.0, Qg=37.2 -> Pg=47.5, Qg=8.6
% INFO    : Gen at bus 3521	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3521	: Pg=33.7, Qg=20.9 -> Pg=24.35, Qg=4.85
% INFO    : Gen at bus 3521	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3521	: Pg=33.7, Qg=20.9 -> Pg=24.35, Qg=4.85
% INFO    : Gen at bus 3521	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3521	: Pg=36.0, Qg=22.3 -> Pg=20.5, Qg=5.15
% INFO    : Gen at bus 3521	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3522	: Pg=121.73, Qg=110.9 -> Pg=134.5, Qg=25.6
% INFO    : Gen at bus 3522	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3522	: Pg=121.73, Qg=110.9 -> Pg=134.5, Qg=25.6
% INFO    : Gen at bus 3522	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3522	: Pg=201.09, Qg=126.78 -> Pg=215.35, Qg=42.35
% INFO    : Gen at bus 3522	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=25.0, Qg=15.5 -> Pg=17.5, Qg=3.6
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=42.9, Qg=26.6 -> Pg=26.45, Qg=6.15
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=42.9, Qg=26.6 -> Pg=26.45, Qg=6.15
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=42.9, Qg=26.6 -> Pg=26.45, Qg=6.15
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=42.9, Qg=26.6 -> Pg=26.45, Qg=6.15
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=42.9, Qg=26.6 -> Pg=26.45, Qg=6.15
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=42.9, Qg=26.6 -> Pg=26.45, Qg=6.15
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=170.0, Qg=105.4 -> Pg=130.0, Qg=24.35
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=80.0, Qg=49.6 -> Pg=72.5, Qg=11.45
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=25.0, Qg=15.5 -> Pg=17.5, Qg=3.6
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=25.0, Qg=15.5 -> Pg=17.5, Qg=3.6
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=21.1, Qg=13.1 -> Pg=14.05, Qg=3.05
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=21.1, Qg=13.1 -> Pg=14.05, Qg=3.05
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=22.0, Qg=13.6 -> Pg=14.5, Qg=3.15
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=22.0, Qg=13.6 -> Pg=14.5, Qg=3.15
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=42.9, Qg=26.6 -> Pg=26.45, Qg=6.15
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=42.9, Qg=26.6 -> Pg=26.45, Qg=6.15
% INFO    : Gen at bus 3523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3524	: Pg=104.26, Qg=105.4 -> Pg=135.0, Qg=24.35
% INFO    : Gen at bus 3524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3524	: Pg=104.26, Qg=105.4 -> Pg=135.0, Qg=24.35
% INFO    : Gen at bus 3524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3524	: Pg=150.31, Qg=158.0 -> Pg=187.5, Qg=36.5
% INFO    : Gen at bus 3524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3525	: Pg=170.0, Qg=0.0 -> Pg=85.5, Qg=0.0
% INFO    : Gen at bus 3525	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3525	: Pg=170.0, Qg=0.0 -> Pg=85.5, Qg=0.0
% INFO    : Gen at bus 3525	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3525	: Pg=187.99, Qg=0.0 -> Pg=94.5, Qg=0.0
% INFO    : Gen at bus 3525	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3526	: Pg=94.24, Qg=6.2 -> Pg=129.6, Qg=35.25
% INFO    : Gen at bus 3526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3526	: Pg=94.24, Qg=6.2 -> Pg=129.6, Qg=35.25
% INFO    : Gen at bus 3526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3526	: Pg=94.24, Qg=6.2 -> Pg=129.6, Qg=35.25
% INFO    : Gen at bus 3526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3526	: Pg=94.25, Qg=6.2 -> Pg=129.75, Qg=35.3
% INFO    : Gen at bus 3526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3526	: Pg=50.12, Qg=6.2 -> Pg=124.75, Qg=18.3
% INFO    : Gen at bus 3526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3526	: Pg=50.12, Qg=6.2 -> Pg=124.75, Qg=18.3
% INFO    : Gen at bus 3526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3527	: Pg=113.7, Qg=93.94 -> Pg=108.6, Qg=19.3
% INFO    : Gen at bus 3527	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3527	: Pg=105.61, Qg=93.94 -> Pg=102.65, Qg=22.2
% INFO    : Gen at bus 3527	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=20.59, Qg=12.76 -> Pg=17.845, Qg=2.95
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=41.9, Qg=20.3 -> Pg=30.25, Qg=3.15
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=41.9, Qg=20.3 -> Pg=30.25, Qg=3.15
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=41.9, Qg=20.3 -> Pg=30.25, Qg=3.15
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=41.9, Qg=20.3 -> Pg=30.25, Qg=3.15
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=41.9, Qg=20.3 -> Pg=30.25, Qg=3.15
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=41.9, Qg=20.3 -> Pg=30.25, Qg=3.15
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=41.9, Qg=20.3 -> Pg=30.25, Qg=3.15
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=41.9, Qg=20.3 -> Pg=30.25, Qg=3.15
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=41.9, Qg=20.3 -> Pg=30.25, Qg=3.15
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=41.9, Qg=20.3 -> Pg=30.25, Qg=3.15
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=20.59, Qg=12.76 -> Pg=17.845, Qg=2.95
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=23.8, Qg=14.7 -> Pg=20.7, Qg=3.4
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=23.8, Qg=14.7 -> Pg=20.55, Qg=3.4
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=23.8, Qg=14.7 -> Pg=20.4, Qg=3.4
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=23.8, Qg=14.7 -> Pg=20.35, Qg=3.4
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=20.59, Qg=12.76 -> Pg=17.845, Qg=2.95
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=20.59, Qg=12.76 -> Pg=17.845, Qg=2.95
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=20.59, Qg=12.76 -> Pg=17.845, Qg=2.95
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=20.59, Qg=12.76 -> Pg=17.845, Qg=2.95
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=20.59, Qg=12.76 -> Pg=17.845, Qg=2.95
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=41.9, Qg=20.3 -> Pg=30.25, Qg=3.15
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=41.9, Qg=20.3 -> Pg=30.25, Qg=3.15
% INFO    : Gen at bus 3528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3529	: Pg=14.72, Qg=16.23 -> Pg=13.16, Qg=4.505
% INFO    : Gen at bus 3529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3529	: Pg=17.46, Qg=19.2 -> Pg=15.3, Qg=5.35
% INFO    : Gen at bus 3529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3529	: Pg=14.72, Qg=16.23 -> Pg=13.16, Qg=4.505
% INFO    : Gen at bus 3529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3529	: Pg=14.72, Qg=16.23 -> Pg=13.16, Qg=4.505
% INFO    : Gen at bus 3529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3529	: Pg=14.72, Qg=16.23 -> Pg=13.16, Qg=4.505
% INFO    : Gen at bus 3529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3529	: Pg=14.72, Qg=16.23 -> Pg=13.16, Qg=4.505
% INFO    : Gen at bus 3529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3529	: Pg=14.72, Qg=16.23 -> Pg=13.16, Qg=4.505
% INFO    : Gen at bus 3529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3529	: Pg=17.46, Qg=19.2 -> Pg=15.3, Qg=5.35
% INFO    : Gen at bus 3529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3529	: Pg=17.46, Qg=19.2 -> Pg=15.3, Qg=5.35
% INFO    : Gen at bus 3529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3529	: Pg=17.46, Qg=19.2 -> Pg=15.3, Qg=5.35
% INFO    : Gen at bus 3529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3530	: Pg=126.0, Qg=18.82 -> Pg=66.15, Qg=0.0
% INFO    : Gen at bus 3530	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3531	: Pg=40.0, Qg=0.0 -> Pg=37.5, Qg=0.0
% INFO    : Gen at bus 3531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3531	: Pg=40.0, Qg=0.0 -> Pg=37.5, Qg=0.0
% INFO    : Gen at bus 3531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3531	: Pg=121.0, Qg=0.0 -> Pg=105.5, Qg=0.0
% INFO    : Gen at bus 3531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3531	: Pg=121.0, Qg=0.0 -> Pg=105.5, Qg=0.0
% INFO    : Gen at bus 3531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3532	: Pg=114.0, Qg=64.6 -> Pg=71.25, Qg=13.3
% INFO    : Gen at bus 3532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3532	: Pg=114.0, Qg=64.6 -> Pg=71.25, Qg=13.3
% INFO    : Gen at bus 3532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3532	: Pg=55.0, Qg=26.6 -> Pg=49.55, Qg=4.15
% INFO    : Gen at bus 3532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3532	: Pg=55.0, Qg=26.6 -> Pg=47.5, Qg=4.15
% INFO    : Gen at bus 3532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3533	: Pg=112.0, Qg=69.4 -> Pg=76.0, Qg=16.05
% INFO    : Gen at bus 3533	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3534	: Pg=112.0, Qg=49.4 -> Pg=56.0, Qg=0.0
% INFO    : Gen at bus 3534	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3535	: Pg=56.0, Qg=0.0 -> Pg=28.5, Qg=0.0
% INFO    : Gen at bus 3535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3535	: Pg=108.0, Qg=0.0 -> Pg=54.5, Qg=0.0
% INFO    : Gen at bus 3535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3536	: Pg=106.5, Qg=6.34 -> Pg=55.91, Qg=0.0
% INFO    : Gen at bus 3536	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3537	: Pg=81.0, Qg=2.87 -> Pg=42.525, Qg=0.0
% INFO    : Gen at bus 3537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3537	: Pg=100.5, Qg=2.87 -> Pg=50.25, Qg=0.0
% INFO    : Gen at bus 3537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3538	: Pg=100.5, Qg=38.66 -> Pg=50.25, Qg=0.0
% INFO    : Gen at bus 3538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3540	: Pg=97.5, Qg=42.01 -> Pg=48.75, Qg=0.0
% INFO    : Gen at bus 3540	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3541	: Pg=217.59, Qg=45.08 -> Pg=151.3, Qg=31.2
% INFO    : Gen at bus 3541	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3541	: Pg=217.59, Qg=45.08 -> Pg=151.3, Qg=31.2
% INFO    : Gen at bus 3541	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3541	: Pg=96.0, Qg=45.08 -> Pg=65.5, Qg=20.0
% INFO    : Gen at bus 3541	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3541	: Pg=96.0, Qg=45.08 -> Pg=65.5, Qg=20.0
% INFO    : Gen at bus 3541	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3542	: Pg=44.89, Qg=-0.6 -> Pg=67.6, Qg=7.2
% INFO    : Gen at bus 3542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3542	: Pg=44.89, Qg=-0.6 -> Pg=67.6, Qg=7.2
% INFO    : Gen at bus 3542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3542	: Pg=44.89, Qg=-0.6 -> Pg=52.6, Qg=7.2
% INFO    : Gen at bus 3542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3543	: Pg=39.38, Qg=33.04 -> Pg=46.5, Qg=7.9
% INFO    : Gen at bus 3543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3543	: Pg=71.3, Qg=33.04 -> Pg=80.5, Qg=13.15
% INFO    : Gen at bus 3543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3544	: Pg=87.5, Qg=38.6 -> Pg=43.75, Qg=0.0
% INFO    : Gen at bus 3544	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3545	: Pg=79.5, Qg=34.96 -> Pg=73.8, Qg=16.55
% INFO    : Gen at bus 3545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3545	: Pg=79.5, Qg=34.96 -> Pg=72.95, Qg=16.55
% INFO    : Gen at bus 3545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3545	: Pg=79.5, Qg=34.96 -> Pg=72.7, Qg=16.55
% INFO    : Gen at bus 3545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3547	: Pg=100.03, Qg=32.86 -> Pg=93.55, Qg=21.1
% INFO    : Gen at bus 3547	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3547	: Pg=162.8, Qg=32.86 -> Pg=149.7, Qg=34.3
% INFO    : Gen at bus 3547	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3547	: Pg=48.96, Qg=32.86 -> Pg=46.0, Qg=10.3
% INFO    : Gen at bus 3547	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3547	: Pg=49.98, Qg=32.86 -> Pg=46.75, Qg=10.55
% INFO    : Gen at bus 3547	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3548	: Pg=30.89, Qg=3.01 -> Pg=32.8, Qg=2.65
% INFO    : Gen at bus 3548	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3548	: Pg=47.67, Qg=3.01 -> Pg=56.25, Qg=5.0
% INFO    : Gen at bus 3548	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3549	: Pg=50.46, Qg=32.1 -> Pg=57.5, Qg=5.0
% INFO    : Gen at bus 3549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3549	: Pg=35.49, Qg=23.1 -> Pg=41.0, Qg=3.6
% INFO    : Gen at bus 3549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3550	: Pg=46.64, Qg=31.7 -> Pg=55.25, Qg=4.95
% INFO    : Gen at bus 3550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3550	: Pg=25.93, Qg=18.0 -> Pg=31.1, Qg=2.8
% INFO    : Gen at bus 3550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3551	: Pg=48.61, Qg=31.1 -> Pg=55.6, Qg=4.85
% INFO    : Gen at bus 3551	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3551	: Pg=36.19, Qg=23.1 -> Pg=41.35, Qg=3.6
% INFO    : Gen at bus 3551	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3553	: Pg=60.5, Qg=0.0 -> Pg=43.25, Qg=0.0
% INFO    : Gen at bus 3553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3554	: Pg=40.6, Qg=19.7 -> Pg=40.3, Qg=3.1
% INFO    : Gen at bus 3554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3554	: Pg=59.9, Qg=29.0 -> Pg=44.205, Qg=4.5
% INFO    : Gen at bus 3554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3555	: Pg=8.5, Qg=44.8 -> Pg=33.35, Qg=12.45
% INFO    : Gen at bus 3555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3556	: Pg=35.53, Qg=20.0 -> Pg=37.85, Qg=3.15
% INFO    : Gen at bus 3556	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3556	: Pg=45.94, Qg=27.8 -> Pg=50.95, Qg=4.35
% INFO    : Gen at bus 3556	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=26.88, Qg=0.0 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 3557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=26.88, Qg=0.0 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 3557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=26.88, Qg=0.0 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 3557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=26.88, Qg=0.0 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 3557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=26.88, Qg=0.0 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 3557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=26.88, Qg=0.0 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 3557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=26.88, Qg=0.0 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 3557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=26.88, Qg=0.0 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 3557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=26.88, Qg=0.0 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 3557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=26.88, Qg=0.0 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 3557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=26.88, Qg=0.0 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 3557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=26.88, Qg=0.0 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 3557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=26.88, Qg=0.0 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 3557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=26.88, Qg=0.0 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 3557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=26.88, Qg=0.0 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 3557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=26.88, Qg=0.0 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 3557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3558	: Pg=56.7, Qg=27.5 -> Pg=49.25, Qg=4.3
% INFO    : Gen at bus 3558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3558	: Pg=56.7, Qg=27.5 -> Pg=45.9, Qg=4.3
% INFO    : Gen at bus 3558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3558	: Pg=56.7, Qg=27.5 -> Pg=48.55, Qg=4.3
% INFO    : Gen at bus 3558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3558	: Pg=56.7, Qg=27.5 -> Pg=48.5, Qg=4.3
% INFO    : Gen at bus 3558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3558	: Pg=56.7, Qg=27.5 -> Pg=48.4, Qg=4.3
% INFO    : Gen at bus 3558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3558	: Pg=56.7, Qg=27.5 -> Pg=47.6, Qg=4.3
% INFO    : Gen at bus 3558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3558	: Pg=56.7, Qg=27.5 -> Pg=47.15, Qg=4.3
% INFO    : Gen at bus 3558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3558	: Pg=56.7, Qg=27.5 -> Pg=46.75, Qg=4.3
% INFO    : Gen at bus 3558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3558	: Pg=56.7, Qg=27.5 -> Pg=46.3, Qg=4.3
% INFO    : Gen at bus 3558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3558	: Pg=56.7, Qg=27.5 -> Pg=46.25, Qg=4.3
% INFO    : Gen at bus 3558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3559	: Pg=34.99, Qg=16.19 -> Pg=36.7, Qg=3.0
% INFO    : Gen at bus 3559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3559	: Pg=45.42, Qg=16.19 -> Pg=50.3, Qg=4.25
% INFO    : Gen at bus 3559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3560	: Pg=56.0, Qg=22.71 -> Pg=38.0, Qg=4.2
% INFO    : Gen at bus 3560	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3563	: Pg=54.0, Qg=26.2 -> Pg=37.0, Qg=4.1
% INFO    : Gen at bus 3563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3564	: Pg=187.99, Qg=28.63 -> Pg=101.5, Qg=14.2
% INFO    : Gen at bus 3564	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3564	: Pg=187.99, Qg=28.63 -> Pg=101.5, Qg=14.2
% INFO    : Gen at bus 3564	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3564	: Pg=53.0, Qg=25.7 -> Pg=45.0, Qg=4.0
% INFO    : Gen at bus 3564	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3564	: Pg=53.0, Qg=25.7 -> Pg=45.0, Qg=4.0
% INFO    : Gen at bus 3564	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3566	: Pg=52.9, Qg=25.6 -> Pg=46.15, Qg=4.0
% INFO    : Gen at bus 3566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3567	: Pg=52.4, Qg=25.4 -> Pg=46.95, Qg=3.95
% INFO    : Gen at bus 3567	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3572	: Pg=16.3, Qg=10.1 -> Pg=13.65, Qg=2.335
% INFO    : Gen at bus 3572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3572	: Pg=16.3, Qg=10.1 -> Pg=13.65, Qg=2.335
% INFO    : Gen at bus 3572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3572	: Pg=16.3, Qg=10.1 -> Pg=13.65, Qg=2.335
% INFO    : Gen at bus 3572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3573	: Pg=17.0, Qg=12.1 -> Pg=17.5, Qg=1.9
% INFO    : Gen at bus 3573	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3573	: Pg=33.19, Qg=30.2 -> Pg=32.4, Qg=6.95
% INFO    : Gen at bus 3573	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3573	: Pg=33.19, Qg=30.2 -> Pg=32.4, Qg=6.95
% INFO    : Gen at bus 3573	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3575	: Pg=47.7, Qg=23.1 -> Pg=44.85, Qg=3.6
% INFO    : Gen at bus 3575	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3577	: Pg=22.16, Qg=35.3 -> Pg=27.5, Qg=9.8
% INFO    : Gen at bus 3577	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3578	: Pg=47.0, Qg=0.0 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 3578	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3578	: Pg=47.0, Qg=0.0 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 3578	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3579	: Pg=47.0, Qg=0.0 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 3579	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3579	: Pg=47.0, Qg=0.0 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 3579	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3580	: Pg=47.0, Qg=0.0 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 3580	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3581	: Pg=47.0, Qg=0.0 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 3581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3581	: Pg=47.0, Qg=0.0 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 3581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3582	: Pg=47.0, Qg=0.0 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 3582	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3582	: Pg=47.0, Qg=0.0 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 3582	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3583	: Pg=47.0, Qg=0.0 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 3583	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3584	: Pg=47.0, Qg=0.0 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 3584	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3585	: Pg=41.18, Qg=22.8 -> Pg=43.5, Qg=3.55
% INFO    : Gen at bus 3585	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3585	: Pg=11.79, Qg=12.1 -> Pg=17.5, Qg=1.9
% INFO    : Gen at bus 3585	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3586	: Pg=47.0, Qg=29.1 -> Pg=35.0, Qg=6.7
% INFO    : Gen at bus 3586	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3588	: Pg=44.6, Qg=21.6 -> Pg=39.3, Qg=3.35
% INFO    : Gen at bus 3588	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3588	: Pg=46.0, Qg=22.3 -> Pg=37.5, Qg=3.5
% INFO    : Gen at bus 3588	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3589	: Pg=9.88, Qg=8.67 -> Pg=7.265, Qg=1.92
% INFO    : Gen at bus 3589	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3589	: Pg=9.88, Qg=8.67 -> Pg=7.265, Qg=1.92
% INFO    : Gen at bus 3589	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3589	: Pg=9.88, Qg=8.67 -> Pg=7.265, Qg=1.92
% INFO    : Gen at bus 3589	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3590	: Pg=42.1, Qg=20.4 -> Pg=22.05, Qg=3.2
% INFO    : Gen at bus 3590	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3591	: Pg=3.96, Qg=6.3 -> Pg=4.7, Qg=1.75
% INFO    : Gen at bus 3591	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3591	: Pg=3.96, Qg=6.3 -> Pg=4.7, Qg=1.75
% INFO    : Gen at bus 3591	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3591	: Pg=3.96, Qg=6.3 -> Pg=4.7, Qg=1.75
% INFO    : Gen at bus 3591	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3591	: Pg=3.96, Qg=6.3 -> Pg=4.7, Qg=1.75
% INFO    : Gen at bus 3591	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3591	: Pg=3.96, Qg=6.3 -> Pg=4.7, Qg=1.75
% INFO    : Gen at bus 3591	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3592	: Pg=28.5, Qg=11.4 -> Pg=34.5, Qg=3.15
% INFO    : Gen at bus 3592	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3592	: Pg=17.0, Qg=11.4 -> Pg=17.5, Qg=1.9
% INFO    : Gen at bus 3592	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3594	: Pg=26.02, Qg=13.4 -> Pg=32.95, Qg=0.0
% INFO    : Gen at bus 3594	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3594	: Pg=10.55, Qg=7.2 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 3594	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3595	: Pg=26.86, Qg=19.1 -> Pg=21.5, Qg=2.95
% INFO    : Gen at bus 3595	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3596	: Pg=18.75, Qg=14.05 -> Pg=13.525, Qg=3.9
% INFO    : Gen at bus 3596	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3596	: Pg=18.75, Qg=14.05 -> Pg=13.525, Qg=3.9
% INFO    : Gen at bus 3596	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3597	: Pg=37.5, Qg=14.8 -> Pg=18.75, Qg=0.0
% INFO    : Gen at bus 3597	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3598	: Pg=18.5, Qg=11.45 -> Pg=13.25, Qg=2.65
% INFO    : Gen at bus 3598	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3598	: Pg=18.5, Qg=11.45 -> Pg=13.25, Qg=2.65
% INFO    : Gen at bus 3598	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3599	: Pg=2.85, Qg=4.53 -> Pg=3.46, Qg=1.255
% INFO    : Gen at bus 3599	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3599	: Pg=2.85, Qg=4.53 -> Pg=3.46, Qg=1.255
% INFO    : Gen at bus 3599	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3599	: Pg=2.85, Qg=4.53 -> Pg=3.46, Qg=1.255
% INFO    : Gen at bus 3599	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3599	: Pg=2.85, Qg=4.53 -> Pg=3.46, Qg=1.255
% INFO    : Gen at bus 3599	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3599	: Pg=2.85, Qg=4.53 -> Pg=3.46, Qg=1.255
% INFO    : Gen at bus 3599	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3599	: Pg=2.85, Qg=4.53 -> Pg=3.46, Qg=1.255
% INFO    : Gen at bus 3599	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3600	: Pg=4.2, Qg=6.75 -> Pg=6.0, Qg=1.875
% INFO    : Gen at bus 3600	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3600	: Pg=4.2, Qg=6.75 -> Pg=6.0, Qg=1.875
% INFO    : Gen at bus 3600	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3600	: Pg=4.2, Qg=6.75 -> Pg=6.0, Qg=1.875
% INFO    : Gen at bus 3600	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3600	: Pg=4.2, Qg=6.75 -> Pg=6.0, Qg=1.875
% INFO    : Gen at bus 3600	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3601	: Pg=5.66, Qg=7.44 -> Pg=6.1, Qg=2.5
% INFO    : Gen at bus 3601	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3601	: Pg=5.66, Qg=7.44 -> Pg=6.1, Qg=2.5
% INFO    : Gen at bus 3601	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3601	: Pg=5.66, Qg=7.44 -> Pg=6.1, Qg=2.5
% INFO    : Gen at bus 3601	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3602	: Pg=16.97, Qg=27.0 -> Pg=25.5, Qg=7.5
% INFO    : Gen at bus 3602	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3603	: Pg=34.5, Qg=13.6 -> Pg=17.25, Qg=0.0
% INFO    : Gen at bus 3603	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3604	: Pg=33.0, Qg=13.0 -> Pg=16.65, Qg=0.0
% INFO    : Gen at bus 3604	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3604	: Pg=61.0, Qg=14.42 -> Pg=30.75, Qg=0.0
% INFO    : Gen at bus 3604	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3604	: Pg=137.0, Qg=14.42 -> Pg=69.05, Qg=0.0
% INFO    : Gen at bus 3604	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3604	: Pg=91.0, Qg=14.42 -> Pg=45.85, Qg=0.0
% INFO    : Gen at bus 3604	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3605	: Pg=5.12, Qg=5.27 -> Pg=6.25, Qg=0.82
% INFO    : Gen at bus 3605	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3605	: Pg=5.12, Qg=5.27 -> Pg=6.25, Qg=0.82
% INFO    : Gen at bus 3605	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3605	: Pg=5.12, Qg=5.27 -> Pg=6.25, Qg=0.82
% INFO    : Gen at bus 3605	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3607	: Pg=28.0, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3607	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3608	: Pg=6.82, Qg=4.02 -> Pg=6.075, Qg=0.875
% INFO    : Gen at bus 3608	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3608	: Pg=6.82, Qg=4.02 -> Pg=6.075, Qg=0.875
% INFO    : Gen at bus 3608	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3608	: Pg=6.82, Qg=4.02 -> Pg=6.075, Qg=0.875
% INFO    : Gen at bus 3608	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3608	: Pg=6.82, Qg=4.02 -> Pg=6.075, Qg=0.875
% INFO    : Gen at bus 3608	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3608	: Pg=21.3, Qg=13.2 -> Pg=18.35, Qg=3.05
% INFO    : Gen at bus 3608	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3609	: Pg=26.9, Qg=13.0 -> Pg=15.95, Qg=2.0
% INFO    : Gen at bus 3609	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3610	: Pg=12.26, Qg=18.18 -> Pg=13.5, Qg=5.4
% INFO    : Gen at bus 3610	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3611	: Pg=8.64, Qg=4.15 -> Pg=7.1, Qg=0.0
% INFO    : Gen at bus 3611	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3611	: Pg=8.64, Qg=4.15 -> Pg=7.1, Qg=0.0
% INFO    : Gen at bus 3611	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3613	: Pg=11.79, Qg=3.56 -> Pg=13.0, Qg=5.25
% INFO    : Gen at bus 3613	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3614	: Pg=25.0, Qg=4.41 -> Pg=14.0, Qg=1.9
% INFO    : Gen at bus 3614	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3614	: Pg=25.0, Qg=4.41 -> Pg=14.0, Qg=1.9
% INFO    : Gen at bus 3614	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3615	: Pg=11.58, Qg=11.9 -> Pg=15.3, Qg=1.85
% INFO    : Gen at bus 3615	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3615	: Pg=11.58, Qg=11.9 -> Pg=15.3, Qg=1.85
% INFO    : Gen at bus 3615	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3616	: Pg=11.32, Qg=18.0 -> Pg=12.5, Qg=5.0
% INFO    : Gen at bus 3616	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3617	: Pg=7.8, Qg=0.0 -> Pg=5.45, Qg=0.0
% INFO    : Gen at bus 3617	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3617	: Pg=7.8, Qg=0.0 -> Pg=5.45, Qg=0.0
% INFO    : Gen at bus 3617	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3617	: Pg=7.8, Qg=0.0 -> Pg=5.45, Qg=0.0
% INFO    : Gen at bus 3617	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3618	: Pg=5.19, Qg=8.25 -> Pg=6.0, Qg=2.3
% INFO    : Gen at bus 3618	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3618	: Pg=5.19, Qg=8.25 -> Pg=6.0, Qg=2.3
% INFO    : Gen at bus 3618	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=22.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=22.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=22.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=22.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=22.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=22.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=22.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=22.0, Qg=0.0 -> Pg=18.9, Qg=0.0
% INFO    : Gen at bus 3619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=22.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=22.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=22.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=22.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=22.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=22.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=22.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=22.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3620	: Pg=10.37, Qg=7.2 -> Pg=11.05, Qg=0.0
% INFO    : Gen at bus 3620	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3620	: Pg=10.37, Qg=7.2 -> Pg=11.05, Qg=0.0
% INFO    : Gen at bus 3620	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3621	: Pg=4.96, Qg=5.47 -> Pg=4.65, Qg=1.52
% INFO    : Gen at bus 3621	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3621	: Pg=4.96, Qg=5.47 -> Pg=4.65, Qg=1.52
% INFO    : Gen at bus 3621	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3621	: Pg=4.96, Qg=5.47 -> Pg=4.65, Qg=1.52
% INFO    : Gen at bus 3621	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3623	: Pg=10.18, Qg=12.8 -> Pg=11.8, Qg=2.8
% INFO    : Gen at bus 3623	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3624	: Pg=13.03, Qg=10.2 -> Pg=16.8, Qg=1.6
% INFO    : Gen at bus 3624	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3625	: Pg=9.9, Qg=3.83 -> Pg=11.0, Qg=4.4
% INFO    : Gen at bus 3625	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3626	: Pg=6.8, Qg=7.5 -> Pg=7.0, Qg=2.075
% INFO    : Gen at bus 3626	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3626	: Pg=6.8, Qg=7.5 -> Pg=7.0, Qg=2.075
% INFO    : Gen at bus 3626	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3627	: Pg=20.0, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3627	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3627	: Pg=20.0, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3627	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3627	: Pg=20.0, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3627	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3627	: Pg=20.0, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3627	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3627	: Pg=20.0, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3627	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3627	: Pg=20.0, Qg=0.0 -> Pg=17.8, Qg=0.0
% INFO    : Gen at bus 3627	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3627	: Pg=20.0, Qg=0.0 -> Pg=17.8, Qg=0.0
% INFO    : Gen at bus 3627	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3627	: Pg=20.0, Qg=0.0 -> Pg=17.3, Qg=0.0
% INFO    : Gen at bus 3627	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3627	: Pg=20.0, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3627	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3627	: Pg=20.0, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3627	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3627	: Pg=20.0, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3627	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3627	: Pg=20.0, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3627	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3627	: Pg=20.0, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3627	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3627	: Pg=20.0, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3627	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3627	: Pg=20.0, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3627	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3627	: Pg=20.0, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3627	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3628	: Pg=20.0, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 3628	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3628	: Pg=20.0, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 3628	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3628	: Pg=20.0, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 3628	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3628	: Pg=13.6, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 3628	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3628	: Pg=13.6, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 3628	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3628	: Pg=13.6, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 3628	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3628	: Pg=13.6, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 3628	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3628	: Pg=13.6, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 3628	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3628	: Pg=13.6, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 3628	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3628	: Pg=13.6, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 3628	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3628	: Pg=13.6, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 3628	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3628	: Pg=13.6, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 3628	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3629	: Pg=20.0, Qg=7.9 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 3629	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8510	: Pg=1290.7, Qg=-12.44 -> Pg=778.85, Qg=0.0
% INFO    : Gen at bus 8510	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8511	: Pg=41.8, Qg=19.9 -> Pg=40.1, Qg=3.15
% INFO    : Gen at bus 8511	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8511	: Pg=1170.0, Qg=19.9 -> Pg=681.5, Qg=88.35
% INFO    : Gen at bus 8511	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8511	: Pg=1170.0, Qg=19.9 -> Pg=674.0, Qg=88.35
% INFO    : Gen at bus 8511	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8512	: Pg=550.0, Qg=136.97 -> Pg=314.5, Qg=114.6
% INFO    : Gen at bus 8512	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8513	: Pg=454.69, Qg=220.2 -> Pg=281.915, Qg=34.3
% INFO    : Gen at bus 8513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8513	: Pg=659.68, Qg=319.5 -> Pg=439.85, Qg=49.8
% INFO    : Gen at bus 8513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8514	: Pg=115.2, Qg=71.4 -> Pg=115.1, Qg=16.5
% INFO    : Gen at bus 8514	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8514	: Pg=221.96, Qg=202.3 -> Pg=198.2, Qg=46.75
% INFO    : Gen at bus 8514	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8514	: Pg=221.96, Qg=202.3 -> Pg=198.2, Qg=46.75
% INFO    : Gen at bus 8514	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8515	: Pg=193.81, Qg=33.43 -> Pg=165.5, Qg=40.8
% INFO    : Gen at bus 8515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8516	: Pg=164.77, Qg=150.2 -> Pg=146.15, Qg=34.7
% INFO    : Gen at bus 8516	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8517	: Pg=191.49, Qg=118.7 -> Pg=155.75, Qg=27.45
% INFO    : Gen at bus 8517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8517	: Pg=191.49, Qg=118.7 -> Pg=155.75, Qg=27.45
% INFO    : Gen at bus 8517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8518	: Pg=181.39, Qg=50.98 -> Pg=160.7, Qg=25.95
% INFO    : Gen at bus 8518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8518	: Pg=314.99, Qg=50.98 -> Pg=227.5, Qg=45.1
% INFO    : Gen at bus 8518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8518	: Pg=181.39, Qg=50.98 -> Pg=160.7, Qg=25.95
% INFO    : Gen at bus 8518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8518	: Pg=181.39, Qg=50.98 -> Pg=160.7, Qg=25.95
% INFO    : Gen at bus 8518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8518	: Pg=181.39, Qg=50.98 -> Pg=160.7, Qg=25.95
% INFO    : Gen at bus 8518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8518	: Pg=96.1, Qg=50.98 -> Pg=90.55, Qg=13.8
% INFO    : Gen at bus 8518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8518	: Pg=96.1, Qg=50.98 -> Pg=90.55, Qg=13.8
% INFO    : Gen at bus 8518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8518	: Pg=96.1, Qg=50.98 -> Pg=89.55, Qg=13.8
% INFO    : Gen at bus 8518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8518	: Pg=96.1, Qg=50.98 -> Pg=88.05, Qg=13.8
% INFO    : Gen at bus 8518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8518	: Pg=314.99, Qg=50.98 -> Pg=227.5, Qg=45.1
% INFO    : Gen at bus 8518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8519	: Pg=180.19, Qg=55.13 -> Pg=150.1, Qg=25.8
% INFO    : Gen at bus 8519	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8519	: Pg=180.19, Qg=55.13 -> Pg=150.1, Qg=25.8
% INFO    : Gen at bus 8519	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8519	: Pg=180.19, Qg=55.13 -> Pg=150.1, Qg=25.8
% INFO    : Gen at bus 8519	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8519	: Pg=280.49, Qg=55.13 -> Pg=170.25, Qg=40.15
% INFO    : Gen at bus 8519	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8521	: Pg=136.0, Qg=49.41 -> Pg=103.0, Qg=19.5
% INFO    : Gen at bus 8521	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8521	: Pg=163.2, Qg=49.41 -> Pg=121.6, Qg=23.35
% INFO    : Gen at bus 8521	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8521	: Pg=94.57, Qg=49.41 -> Pg=108.2, Qg=13.3
% INFO    : Gen at bus 8521	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8522	: Pg=76.71, Qg=54.6 -> Pg=77.4, Qg=8.5
% INFO    : Gen at bus 8522	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8523	: Pg=183.59, Qg=113.8 -> Pg=154.3, Qg=26.3
% INFO    : Gen at bus 8523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8523	: Pg=183.59, Qg=113.8 -> Pg=154.3, Qg=26.3
% INFO    : Gen at bus 8523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8523	: Pg=258.39, Qg=160.1 -> Pg=191.7, Qg=37.0
% INFO    : Gen at bus 8523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8523	: Pg=325.19, Qg=201.5 -> Pg=217.6, Qg=46.55
% INFO    : Gen at bus 8523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8523	: Pg=112.5, Qg=54.5 -> Pg=111.25, Qg=8.5
% INFO    : Gen at bus 8523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8523	: Pg=112.5, Qg=54.5 -> Pg=111.25, Qg=8.5
% INFO    : Gen at bus 8523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8523	: Pg=112.5, Qg=54.5 -> Pg=111.25, Qg=8.5
% INFO    : Gen at bus 8523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8523	: Pg=112.5, Qg=54.5 -> Pg=111.25, Qg=8.5
% INFO    : Gen at bus 8523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8524	: Pg=107.5, Qg=66.6 -> Pg=63.75, Qg=15.4
% INFO    : Gen at bus 8524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8524	: Pg=107.5, Qg=66.6 -> Pg=63.75, Qg=15.4
% INFO    : Gen at bus 8524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8524	: Pg=110.7, Qg=68.6 -> Pg=65.35, Qg=15.85
% INFO    : Gen at bus 8524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8524	: Pg=126.5, Qg=78.4 -> Pg=73.25, Qg=18.1
% INFO    : Gen at bus 8524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8524	: Pg=115.2, Qg=55.8 -> Pg=110.1, Qg=8.7
% INFO    : Gen at bus 8524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8525	: Pg=114.63, Qg=63.8 -> Pg=110.9, Qg=9.95
% INFO    : Gen at bus 8525	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8525	: Pg=99.4, Qg=48.1 -> Pg=70.7, Qg=7.5
% INFO    : Gen at bus 8525	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8526	: Pg=212.49, Qg=131.7 -> Pg=151.25, Qg=30.45
% INFO    : Gen at bus 8526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8526	: Pg=95.2, Qg=46.1 -> Pg=71.4, Qg=7.2
% INFO    : Gen at bus 8526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8526	: Pg=95.2, Qg=46.1 -> Pg=71.4, Qg=7.2
% INFO    : Gen at bus 8526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8526	: Pg=95.2, Qg=46.1 -> Pg=71.4, Qg=7.2
% INFO    : Gen at bus 8526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8526	: Pg=95.2, Qg=46.1 -> Pg=71.4, Qg=7.2
% INFO    : Gen at bus 8526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8526	: Pg=95.2, Qg=46.1 -> Pg=71.4, Qg=7.2
% INFO    : Gen at bus 8526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8526	: Pg=95.2, Qg=46.1 -> Pg=60.1, Qg=7.2
% INFO    : Gen at bus 8526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8526	: Pg=95.2, Qg=46.1 -> Pg=60.1, Qg=7.2
% INFO    : Gen at bus 8526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8526	: Pg=95.2, Qg=46.1 -> Pg=60.1, Qg=7.2
% INFO    : Gen at bus 8526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8528	: Pg=45.0, Qg=27.9 -> Pg=25.0, Qg=6.45
% INFO    : Gen at bus 8528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8528	: Pg=90.0, Qg=55.8 -> Pg=76.0, Qg=12.9
% INFO    : Gen at bus 8528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8528	: Pg=90.0, Qg=55.8 -> Pg=76.0, Qg=12.9
% INFO    : Gen at bus 8528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8529	: Pg=81.0, Qg=60.8 -> Pg=80.35, Qg=16.9
% INFO    : Gen at bus 8529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8529	: Pg=77.9, Qg=58.4 -> Pg=70.0, Qg=16.2
% INFO    : Gen at bus 8529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8529	: Pg=77.9, Qg=58.4 -> Pg=70.0, Qg=16.2
% INFO    : Gen at bus 8529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8530	: Pg=55.49, Qg=50.6 -> Pg=55.8, Qg=11.7
% INFO    : Gen at bus 8530	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8530	: Pg=49.98, Qg=55.1 -> Pg=51.75, Qg=15.3
% INFO    : Gen at bus 8530	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8531	: Pg=43.52, Qg=37.5 -> Pg=51.25, Qg=8.65
% INFO    : Gen at bus 8531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8531	: Pg=32.16, Qg=20.2 -> Pg=36.63, Qg=3.15
% INFO    : Gen at bus 8531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8531	: Pg=30.91, Qg=20.2 -> Pg=36.355, Qg=3.15
% INFO    : Gen at bus 8531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8531	: Pg=30.53, Qg=20.2 -> Pg=36.165, Qg=3.15
% INFO    : Gen at bus 8531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8531	: Pg=42.0, Qg=37.5 -> Pg=51.25, Qg=8.65
% INFO    : Gen at bus 8531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8531	: Pg=42.0, Qg=37.5 -> Pg=51.25, Qg=8.65
% INFO    : Gen at bus 8531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8531	: Pg=50.7, Qg=37.5 -> Pg=51.25, Qg=8.65
% INFO    : Gen at bus 8531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8531	: Pg=41.8, Qg=20.2 -> Pg=40.4, Qg=3.15
% INFO    : Gen at bus 8531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8531	: Pg=41.8, Qg=20.2 -> Pg=40.4, Qg=3.15
% INFO    : Gen at bus 8531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8531	: Pg=41.8, Qg=20.2 -> Pg=40.4, Qg=3.15
% INFO    : Gen at bus 8531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8531	: Pg=41.8, Qg=20.2 -> Pg=40.4, Qg=3.15
% INFO    : Gen at bus 8531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8531	: Pg=41.8, Qg=20.2 -> Pg=36.63, Qg=3.15
% INFO    : Gen at bus 8531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8532	: Pg=60.5, Qg=37.5 -> Pg=45.25, Qg=8.65
% INFO    : Gen at bus 8532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8532	: Pg=60.5, Qg=37.5 -> Pg=45.25, Qg=8.65
% INFO    : Gen at bus 8532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8532	: Pg=60.5, Qg=37.5 -> Pg=45.25, Qg=8.65
% INFO    : Gen at bus 8532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8532	: Pg=60.5, Qg=37.5 -> Pg=45.25, Qg=8.65
% INFO    : Gen at bus 8532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8532	: Pg=146.2, Qg=86.4 -> Pg=111.845, Qg=18.85
% INFO    : Gen at bus 8532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8532	: Pg=146.2, Qg=86.4 -> Pg=111.845, Qg=18.85
% INFO    : Gen at bus 8532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8533	: Pg=59.0, Qg=36.6 -> Pg=50.5, Qg=8.45
% INFO    : Gen at bus 8533	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8533	: Pg=24.0, Qg=14.9 -> Pg=17.71, Qg=3.45
% INFO    : Gen at bus 8533	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8535	: Pg=24.0, Qg=11.6 -> Pg=23.0, Qg=1.8
% INFO    : Gen at bus 8535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8535	: Pg=135.0, Qg=20.63 -> Pg=86.0, Qg=10.2
% INFO    : Gen at bus 8535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8535	: Pg=24.0, Qg=11.6 -> Pg=23.0, Qg=1.8
% INFO    : Gen at bus 8535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8535	: Pg=24.0, Qg=11.6 -> Pg=23.0, Qg=1.8
% INFO    : Gen at bus 8535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8535	: Pg=24.0, Qg=11.6 -> Pg=22.0, Qg=1.8
% INFO    : Gen at bus 8535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8535	: Pg=54.0, Qg=20.63 -> Pg=48.0, Qg=4.1
% INFO    : Gen at bus 8535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8535	: Pg=54.0, Qg=20.63 -> Pg=48.0, Qg=4.1
% INFO    : Gen at bus 8535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8535	: Pg=54.0, Qg=20.63 -> Pg=48.0, Qg=4.1
% INFO    : Gen at bus 8535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8535	: Pg=54.0, Qg=20.63 -> Pg=48.0, Qg=4.1
% INFO    : Gen at bus 8535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8535	: Pg=161.0, Qg=20.63 -> Pg=155.5, Qg=12.15
% INFO    : Gen at bus 8535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8536	: Pg=53.0, Qg=32.8 -> Pg=49.5, Qg=7.55
% INFO    : Gen at bus 8536	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8536	: Pg=53.0, Qg=32.8 -> Pg=49.5, Qg=7.55
% INFO    : Gen at bus 8536	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8536	: Pg=53.0, Qg=32.8 -> Pg=49.5, Qg=7.55
% INFO    : Gen at bus 8536	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8536	: Pg=53.0, Qg=32.8 -> Pg=49.5, Qg=7.55
% INFO    : Gen at bus 8536	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8537	: Pg=53.0, Qg=32.8 -> Pg=51.5, Qg=7.55
% INFO    : Gen at bus 8537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8537	: Pg=53.0, Qg=32.8 -> Pg=51.5, Qg=7.55
% INFO    : Gen at bus 8537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8537	: Pg=53.0, Qg=32.8 -> Pg=51.5, Qg=7.55
% INFO    : Gen at bus 8537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8537	: Pg=53.0, Qg=32.8 -> Pg=51.5, Qg=7.55
% INFO    : Gen at bus 8537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8538	: Pg=21.6, Qg=10.5 -> Pg=13.3, Qg=1.65
% INFO    : Gen at bus 8538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8538	: Pg=21.6, Qg=10.5 -> Pg=13.3, Qg=1.65
% INFO    : Gen at bus 8538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8538	: Pg=45.9, Qg=28.4 -> Pg=37.95, Qg=6.55
% INFO    : Gen at bus 8538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8538	: Pg=45.9, Qg=28.4 -> Pg=37.95, Qg=6.55
% INFO    : Gen at bus 8538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8540	: Pg=55.0, Qg=34.1 -> Pg=40.59, Qg=7.9
% INFO    : Gen at bus 8540	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8540	: Pg=42.0, Qg=26.0 -> Pg=30.995, Qg=6.0
% INFO    : Gen at bus 8540	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8540	: Pg=42.0, Qg=26.0 -> Pg=30.87, Qg=6.0
% INFO    : Gen at bus 8540	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8542	: Pg=41.8, Qg=20.2 -> Pg=41.4, Qg=3.15
% INFO    : Gen at bus 8542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8542	: Pg=41.8, Qg=20.2 -> Pg=41.4, Qg=3.15
% INFO    : Gen at bus 8542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8542	: Pg=41.8, Qg=20.2 -> Pg=41.4, Qg=3.15
% INFO    : Gen at bus 8542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8542	: Pg=41.8, Qg=20.2 -> Pg=30.9, Qg=3.15
% INFO    : Gen at bus 8542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8542	: Pg=41.8, Qg=20.2 -> Pg=41.4, Qg=3.15
% INFO    : Gen at bus 8542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8542	: Pg=41.8, Qg=20.2 -> Pg=41.4, Qg=3.15
% INFO    : Gen at bus 8542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8542	: Pg=41.8, Qg=20.2 -> Pg=41.4, Qg=3.15
% INFO    : Gen at bus 8542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8542	: Pg=41.8, Qg=20.2 -> Pg=41.4, Qg=3.15
% INFO    : Gen at bus 8542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8542	: Pg=41.8, Qg=20.2 -> Pg=41.4, Qg=3.15
% INFO    : Gen at bus 8542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8542	: Pg=41.8, Qg=20.2 -> Pg=41.4, Qg=3.15
% INFO    : Gen at bus 8542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8542	: Pg=41.8, Qg=20.2 -> Pg=41.4, Qg=3.15
% INFO    : Gen at bus 8542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8542	: Pg=41.8, Qg=20.2 -> Pg=41.4, Qg=3.15
% INFO    : Gen at bus 8542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8543	: Pg=41.8, Qg=20.2 -> Pg=39.9, Qg=3.15
% INFO    : Gen at bus 8543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8543	: Pg=41.8, Qg=20.2 -> Pg=39.9, Qg=3.15
% INFO    : Gen at bus 8543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8543	: Pg=41.8, Qg=20.2 -> Pg=39.9, Qg=3.15
% INFO    : Gen at bus 8543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8543	: Pg=41.8, Qg=20.2 -> Pg=39.9, Qg=3.15
% INFO    : Gen at bus 8543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8543	: Pg=93.6, Qg=45.3 -> Pg=86.8, Qg=7.05
% INFO    : Gen at bus 8543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8543	: Pg=41.8, Qg=20.2 -> Pg=39.9, Qg=3.15
% INFO    : Gen at bus 8543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8543	: Pg=41.8, Qg=20.2 -> Pg=39.9, Qg=3.15
% INFO    : Gen at bus 8543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8543	: Pg=41.8, Qg=20.2 -> Pg=39.9, Qg=3.15
% INFO    : Gen at bus 8543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8543	: Pg=41.8, Qg=20.2 -> Pg=39.9, Qg=3.15
% INFO    : Gen at bus 8543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8543	: Pg=41.8, Qg=20.2 -> Pg=39.9, Qg=3.15
% INFO    : Gen at bus 8543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8543	: Pg=41.8, Qg=20.2 -> Pg=39.9, Qg=3.15
% INFO    : Gen at bus 8543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8543	: Pg=41.8, Qg=20.2 -> Pg=39.9, Qg=3.15
% INFO    : Gen at bus 8543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8543	: Pg=41.8, Qg=20.2 -> Pg=39.9, Qg=3.15
% INFO    : Gen at bus 8543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8544	: Pg=38.4, Qg=23.8 -> Pg=34.7, Qg=5.5
% INFO    : Gen at bus 8544	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8544	: Pg=38.4, Qg=23.8 -> Pg=31.7, Qg=5.5
% INFO    : Gen at bus 8544	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8545	: Pg=17.5, Qg=8.5 -> Pg=10.75, Qg=1.325
% INFO    : Gen at bus 8545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8545	: Pg=17.5, Qg=8.5 -> Pg=10.75, Qg=1.325
% INFO    : Gen at bus 8545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8546	: Pg=34.9, Qg=16.9 -> Pg=19.95, Qg=2.65
% INFO    : Gen at bus 8546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8546	: Pg=34.9, Qg=16.9 -> Pg=19.95, Qg=2.65
% INFO    : Gen at bus 8546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8549	: Pg=9.0, Qg=15.5 -> Pg=17.0, Qg=3.6
% INFO    : Gen at bus 8549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8552	: Pg=20.0, Qg=9.7 -> Pg=19.0, Qg=1.5
% INFO    : Gen at bus 8552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8552	: Pg=20.0, Qg=9.7 -> Pg=19.0, Qg=1.5
% INFO    : Gen at bus 8552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8552	: Pg=20.0, Qg=9.7 -> Pg=19.0, Qg=1.5
% INFO    : Gen at bus 8552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8552	: Pg=20.0, Qg=9.7 -> Pg=19.0, Qg=1.5
% INFO    : Gen at bus 8552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8552	: Pg=20.0, Qg=9.7 -> Pg=19.0, Qg=1.5
% INFO    : Gen at bus 8552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8552	: Pg=20.0, Qg=9.7 -> Pg=19.0, Qg=1.5
% INFO    : Gen at bus 8552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8552	: Pg=20.0, Qg=9.7 -> Pg=19.0, Qg=1.5
% INFO    : Gen at bus 8552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8553	: Pg=1298.0, Qg=62.64 -> Pg=734.0, Qg=0.0
% INFO    : Gen at bus 8553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8553	: Pg=1298.0, Qg=62.64 -> Pg=734.0, Qg=0.0
% INFO    : Gen at bus 8553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8554	: Pg=1138.5, Qg=423.95 -> Pg=599.25, Qg=85.95
% INFO    : Gen at bus 8554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8554	: Pg=1138.5, Qg=423.95 -> Pg=599.25, Qg=85.95
% INFO    : Gen at bus 8554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8555	: Pg=980.8, Qg=339.5 -> Pg=552.9, Qg=0.0
% INFO    : Gen at bus 8555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8556	: Pg=636.51, Qg=-90.22 -> Pg=630.5, Qg=70.65
% INFO    : Gen at bus 8556	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8556	: Pg=636.51, Qg=-90.22 -> Pg=630.5, Qg=70.65
% INFO    : Gen at bus 8556	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8557	: Pg=373.44, Qg=60.66 -> Pg=643.0, Qg=70.65
% INFO    : Gen at bus 8557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8558	: Pg=900.0, Qg=132.08 -> Pg=508.7, Qg=0.0
% INFO    : Gen at bus 8558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8559	: Pg=913.67, Qg=566.3 -> Pg=731.85, Qg=130.85
% INFO    : Gen at bus 8559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8560	: Pg=317.33, Qg=-16.31 -> Pg=496.0, Qg=0.0
% INFO    : Gen at bus 8560	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8560	: Pg=326.53, Qg=-16.31 -> Pg=485.0, Qg=49.85
% INFO    : Gen at bus 8560	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8560	: Pg=326.53, Qg=-16.31 -> Pg=485.0, Qg=49.85
% INFO    : Gen at bus 8560	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8561	: Pg=239.64, Qg=290.2 -> Pg=431.0, Qg=0.0
% INFO    : Gen at bus 8561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8562	: Pg=214.65, Qg=215.48 -> Pg=392.5, Qg=44.15
% INFO    : Gen at bus 8562	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8563	: Pg=250.59, Qg=2.97 -> Pg=406.08, Qg=46.75
% INFO    : Gen at bus 8563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8563	: Pg=250.59, Qg=2.97 -> Pg=406.08, Qg=46.75
% INFO    : Gen at bus 8563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8563	: Pg=250.59, Qg=2.97 -> Pg=406.08, Qg=46.75
% INFO    : Gen at bus 8563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8564	: Pg=299.19, Qg=172.8 -> Pg=207.945, Qg=36.55
% INFO    : Gen at bus 8564	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8564	: Pg=26.89, Qg=46.3 -> Pg=50.795, Qg=10.7
% INFO    : Gen at bus 8564	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8565	: Pg=181.78, Qg=109.02 -> Pg=217.1, Qg=19.55
% INFO    : Gen at bus 8565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8565	: Pg=175.19, Qg=109.02 -> Pg=217.1, Qg=19.55
% INFO    : Gen at bus 8565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8565	: Pg=181.49, Qg=109.02 -> Pg=217.1, Qg=19.55
% INFO    : Gen at bus 8565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8566	: Pg=20.0, Qg=12.4 -> Pg=18.5, Qg=2.85
% INFO    : Gen at bus 8566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8566	: Pg=156.0, Qg=61.65 -> Pg=123.0, Qg=22.35
% INFO    : Gen at bus 8566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8566	: Pg=245.92, Qg=61.65 -> Pg=158.5, Qg=36.5
% INFO    : Gen at bus 8566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8566	: Pg=85.61, Qg=61.65 -> Pg=118.0, Qg=24.65
% INFO    : Gen at bus 8566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8567	: Pg=249.99, Qg=134.1 -> Pg=172.5, Qg=35.8
% INFO    : Gen at bus 8567	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8567	: Pg=249.99, Qg=134.1 -> Pg=172.5, Qg=35.8
% INFO    : Gen at bus 8567	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8567	: Pg=227.99, Qg=134.1 -> Pg=161.5, Qg=32.65
% INFO    : Gen at bus 8567	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8568	: Pg=21.2, Qg=13.1 -> Pg=13.1, Qg=3.0
% INFO    : Gen at bus 8568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8568	: Pg=58.22, Qg=37.45 -> Pg=37.845, Qg=9.025
% INFO    : Gen at bus 8568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8568	: Pg=58.22, Qg=37.45 -> Pg=37.845, Qg=9.025
% INFO    : Gen at bus 8568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8568	: Pg=58.22, Qg=37.45 -> Pg=37.845, Qg=9.025
% INFO    : Gen at bus 8568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8568	: Pg=58.22, Qg=37.45 -> Pg=37.845, Qg=9.025
% INFO    : Gen at bus 8568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8568	: Pg=190.39, Qg=118.0 -> Pg=129.47, Qg=27.25
% INFO    : Gen at bus 8568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8569	: Pg=204.52, Qg=142.5 -> Pg=156.4, Qg=32.9
% INFO    : Gen at bus 8569	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8570	: Pg=228.59, Qg=89.8 -> Pg=191.8, Qg=17.25
% INFO    : Gen at bus 8570	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8570	: Pg=211.49, Qg=89.8 -> Pg=173.25, Qg=15.95
% INFO    : Gen at bus 8570	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8570	: Pg=211.49, Qg=89.8 -> Pg=173.25, Qg=15.95
% INFO    : Gen at bus 8570	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8571	: Pg=271.19, Qg=80.06 -> Pg=163.1, Qg=38.85
% INFO    : Gen at bus 8571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8571	: Pg=184.43, Qg=80.06 -> Pg=163.1, Qg=38.85
% INFO    : Gen at bus 8571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8571	: Pg=135.26, Qg=80.06 -> Pg=151.95, Qg=28.5
% INFO    : Gen at bus 8571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8571	: Pg=135.26, Qg=80.06 -> Pg=151.95, Qg=28.5
% INFO    : Gen at bus 8571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8571	: Pg=198.89, Qg=80.06 -> Pg=151.95, Qg=28.5
% INFO    : Gen at bus 8571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8571	: Pg=198.89, Qg=80.06 -> Pg=151.95, Qg=28.5
% INFO    : Gen at bus 8571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8572	: Pg=190.8, Qg=89.58 -> Pg=227.75, Qg=38.9
% INFO    : Gen at bus 8572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8572	: Pg=127.98, Qg=89.58 -> Pg=144.1, Qg=26.95
% INFO    : Gen at bus 8572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8572	: Pg=127.98, Qg=89.58 -> Pg=144.1, Qg=26.95
% INFO    : Gen at bus 8572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8572	: Pg=127.98, Qg=89.58 -> Pg=144.1, Qg=26.95
% INFO    : Gen at bus 8572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8574	: Pg=132.23, Qg=89.1 -> Pg=156.0, Qg=13.9
% INFO    : Gen at bus 8574	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8574	: Pg=132.23, Qg=89.1 -> Pg=156.0, Qg=13.9
% INFO    : Gen at bus 8574	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8574	: Pg=131.32, Qg=91.1 -> Pg=157.5, Qg=14.2
% INFO    : Gen at bus 8574	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8575	: Pg=178.99, Qg=110.9 -> Pg=144.5, Qg=25.6
% INFO    : Gen at bus 8575	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8575	: Pg=178.99, Qg=110.9 -> Pg=144.5, Qg=25.6
% INFO    : Gen at bus 8575	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8575	: Pg=178.99, Qg=110.9 -> Pg=144.5, Qg=25.6
% INFO    : Gen at bus 8575	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8575	: Pg=360.99, Qg=155.88 -> Pg=250.5, Qg=51.7
% INFO    : Gen at bus 8575	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8576	: Pg=104.31, Qg=45.61 -> Pg=136.0, Qg=24.65
% INFO    : Gen at bus 8576	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8576	: Pg=104.31, Qg=45.61 -> Pg=136.0, Qg=24.65
% INFO    : Gen at bus 8576	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8576	: Pg=104.31, Qg=45.61 -> Pg=136.0, Qg=24.65
% INFO    : Gen at bus 8576	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8576	: Pg=104.31, Qg=45.61 -> Pg=136.0, Qg=24.65
% INFO    : Gen at bus 8576	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8577	: Pg=69.09, Qg=101.3 -> Pg=114.25, Qg=23.4
% INFO    : Gen at bus 8577	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8577	: Pg=69.09, Qg=101.3 -> Pg=114.25, Qg=23.4
% INFO    : Gen at bus 8577	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8577	: Pg=117.94, Qg=107.09 -> Pg=213.55, Qg=45.4
% INFO    : Gen at bus 8577	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8578	: Pg=162.42, Qg=99.79 -> Pg=113.425, Qg=30.6
% INFO    : Gen at bus 8578	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8578	: Pg=162.42, Qg=99.79 -> Pg=113.425, Qg=30.6
% INFO    : Gen at bus 8578	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8579	: Pg=57.6, Qg=35.7 -> Pg=36.3, Qg=8.25
% INFO    : Gen at bus 8579	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8579	: Pg=135.0, Qg=83.7 -> Pg=97.5, Qg=19.35
% INFO    : Gen at bus 8579	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8580	: Pg=134.1, Qg=83.1 -> Pg=99.55, Qg=19.2
% INFO    : Gen at bus 8580	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8581	: Pg=134.0, Qg=37.56 -> Pg=92.0, Qg=10.1
% INFO    : Gen at bus 8581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8581	: Pg=134.0, Qg=37.56 -> Pg=92.0, Qg=10.1
% INFO    : Gen at bus 8581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8581	: Pg=134.0, Qg=37.56 -> Pg=92.0, Qg=10.1
% INFO    : Gen at bus 8581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8581	: Pg=134.0, Qg=37.56 -> Pg=92.0, Qg=10.1
% INFO    : Gen at bus 8581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8581	: Pg=134.0, Qg=37.56 -> Pg=92.0, Qg=10.1
% INFO    : Gen at bus 8581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8581	: Pg=134.0, Qg=37.56 -> Pg=92.0, Qg=10.1
% INFO    : Gen at bus 8581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8581	: Pg=134.0, Qg=37.56 -> Pg=92.0, Qg=10.1
% INFO    : Gen at bus 8581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8581	: Pg=134.0, Qg=37.56 -> Pg=92.0, Qg=10.1
% INFO    : Gen at bus 8581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8582	: Pg=195.49, Qg=52.74 -> Pg=117.75, Qg=28.0
% INFO    : Gen at bus 8582	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8582	: Pg=195.49, Qg=52.74 -> Pg=117.75, Qg=28.0
% INFO    : Gen at bus 8582	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8582	: Pg=127.0, Qg=52.74 -> Pg=101.0, Qg=18.2
% INFO    : Gen at bus 8582	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8582	: Pg=127.0, Qg=52.74 -> Pg=101.0, Qg=18.2
% INFO    : Gen at bus 8582	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8582	: Pg=127.0, Qg=52.74 -> Pg=101.0, Qg=18.2
% INFO    : Gen at bus 8582	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8582	: Pg=127.0, Qg=52.74 -> Pg=101.0, Qg=18.2
% INFO    : Gen at bus 8582	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8582	: Pg=127.0, Qg=52.74 -> Pg=101.0, Qg=18.2
% INFO    : Gen at bus 8582	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8582	: Pg=127.0, Qg=52.74 -> Pg=101.0, Qg=18.2
% INFO    : Gen at bus 8582	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8583	: Pg=106.71, Qg=21.07 -> Pg=145.0, Qg=26.9
% INFO    : Gen at bus 8583	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8583	: Pg=106.71, Qg=21.07 -> Pg=145.0, Qg=26.9
% INFO    : Gen at bus 8583	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8583	: Pg=53.13, Qg=21.07 -> Pg=87.5, Qg=26.05
% INFO    : Gen at bus 8583	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8583	: Pg=53.13, Qg=21.07 -> Pg=87.5, Qg=26.05
% INFO    : Gen at bus 8583	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8584	: Pg=79.96, Qg=16.8 -> Pg=97.5, Qg=0.0
% INFO    : Gen at bus 8584	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8586	: Pg=102.0, Qg=29.69 -> Pg=51.0, Qg=0.0
% INFO    : Gen at bus 8586	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8587	: Pg=100.5, Qg=44.3 -> Pg=50.25, Qg=0.0
% INFO    : Gen at bus 8587	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8588	: Pg=125.0, Qg=77.5 -> Pg=86.875, Qg=17.9
% INFO    : Gen at bus 8588	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8588	: Pg=137.42, Qg=114.7 -> Pg=128.575, Qg=26.5
% INFO    : Gen at bus 8588	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8588	: Pg=37.5, Qg=62.0 -> Pg=67.5, Qg=14.35
% INFO    : Gen at bus 8588	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8588	: Pg=37.5, Qg=75.0 -> Pg=67.5, Qg=20.85
% INFO    : Gen at bus 8588	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8589	: Pg=66.64, Qg=73.5 -> Pg=59.0, Qg=20.4
% INFO    : Gen at bus 8589	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8590	: Pg=94.7, Qg=58.7 -> Pg=72.35, Qg=13.55
% INFO    : Gen at bus 8590	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8592	: Pg=22.25, Qg=0.0 -> Pg=55.0, Qg=0.0
% INFO    : Gen at bus 8592	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8594	: Pg=80.0, Qg=31.6 -> Pg=40.0, Qg=0.0
% INFO    : Gen at bus 8594	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8595	: Pg=5.0, Qg=12.33 -> Pg=12.45, Qg=2.855
% INFO    : Gen at bus 8595	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8595	: Pg=5.0, Qg=12.33 -> Pg=12.45, Qg=2.855
% INFO    : Gen at bus 8595	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8595	: Pg=5.0, Qg=12.33 -> Pg=12.45, Qg=2.855
% INFO    : Gen at bus 8595	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8595	: Pg=5.0, Qg=12.33 -> Pg=12.45, Qg=2.855
% INFO    : Gen at bus 8595	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8595	: Pg=5.0, Qg=13.1 -> Pg=13.1, Qg=3.0
% INFO    : Gen at bus 8595	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8595	: Pg=5.0, Qg=13.1 -> Pg=13.1, Qg=3.0
% INFO    : Gen at bus 8595	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8595	: Pg=50.01, Qg=242.3 -> Pg=220.5, Qg=56.0
% INFO    : Gen at bus 8595	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8595	: Pg=287.72, Qg=242.3 -> Pg=220.5, Qg=56.0
% INFO    : Gen at bus 8595	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8596	: Pg=19.25, Qg=11.92 -> Pg=12.125, Qg=2.75
% INFO    : Gen at bus 8596	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8596	: Pg=19.25, Qg=11.92 -> Pg=12.125, Qg=2.75
% INFO    : Gen at bus 8596	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8596	: Pg=19.25, Qg=11.92 -> Pg=12.125, Qg=2.75
% INFO    : Gen at bus 8596	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8596	: Pg=19.25, Qg=11.92 -> Pg=12.125, Qg=2.75
% INFO    : Gen at bus 8596	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8596	: Pg=21.2, Qg=13.1 -> Pg=13.1, Qg=3.0
% INFO    : Gen at bus 8596	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8597	: Pg=18.6, Qg=11.52 -> Pg=11.8, Qg=2.66
% INFO    : Gen at bus 8597	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8597	: Pg=18.6, Qg=11.52 -> Pg=11.8, Qg=2.66
% INFO    : Gen at bus 8597	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8597	: Pg=18.6, Qg=11.52 -> Pg=11.8, Qg=2.66
% INFO    : Gen at bus 8597	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8597	: Pg=18.6, Qg=11.52 -> Pg=11.8, Qg=2.66
% INFO    : Gen at bus 8597	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8598	: Pg=45.9, Qg=34.4 -> Pg=34.05, Qg=9.55
% INFO    : Gen at bus 8598	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8598	: Pg=14.08, Qg=10.56 -> Pg=10.13, Qg=2.93
% INFO    : Gen at bus 8598	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8598	: Pg=14.08, Qg=10.56 -> Pg=10.13, Qg=2.93
% INFO    : Gen at bus 8598	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8598	: Pg=14.08, Qg=10.56 -> Pg=10.13, Qg=2.93
% INFO    : Gen at bus 8598	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8598	: Pg=14.08, Qg=10.56 -> Pg=10.13, Qg=2.93
% INFO    : Gen at bus 8598	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8598	: Pg=14.08, Qg=10.56 -> Pg=10.13, Qg=2.93
% INFO    : Gen at bus 8598	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8598	: Pg=39.1, Qg=29.3 -> Pg=23.65, Qg=8.15
% INFO    : Gen at bus 8598	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8599	: Pg=70.0, Qg=27.7 -> Pg=35.05, Qg=0.0
% INFO    : Gen at bus 8599	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8600	: Pg=68.3, Qg=33.1 -> Pg=39.15, Qg=5.15
% INFO    : Gen at bus 8600	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8600	: Pg=68.3, Qg=33.1 -> Pg=39.15, Qg=5.15
% INFO    : Gen at bus 8600	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8600	: Pg=68.3, Qg=33.1 -> Pg=39.15, Qg=5.15
% INFO    : Gen at bus 8600	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8600	: Pg=68.3, Qg=33.1 -> Pg=39.15, Qg=5.15
% INFO    : Gen at bus 8600	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8600	: Pg=68.3, Qg=33.1 -> Pg=39.15, Qg=5.15
% INFO    : Gen at bus 8600	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8600	: Pg=68.3, Qg=33.1 -> Pg=39.15, Qg=5.15
% INFO    : Gen at bus 8600	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8600	: Pg=68.3, Qg=33.1 -> Pg=39.15, Qg=5.15
% INFO    : Gen at bus 8600	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8600	: Pg=68.3, Qg=33.1 -> Pg=39.15, Qg=5.15
% INFO    : Gen at bus 8600	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8601	: Pg=67.0, Qg=41.5 -> Pg=35.0, Qg=9.6
% INFO    : Gen at bus 8601	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8602	: Pg=35.61, Qg=69.7 -> Pg=88.0, Qg=10.85
% INFO    : Gen at bus 8602	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8602	: Pg=15.64, Qg=15.8 -> Pg=20.25, Qg=3.65
% INFO    : Gen at bus 8602	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8602	: Pg=15.64, Qg=15.8 -> Pg=20.25, Qg=3.65
% INFO    : Gen at bus 8602	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8602	: Pg=15.64, Qg=15.8 -> Pg=20.25, Qg=3.65
% INFO    : Gen at bus 8602	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8602	: Pg=31.64, Qg=31.6 -> Pg=47.65, Qg=4.9
% INFO    : Gen at bus 8602	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8602	: Pg=31.64, Qg=31.6 -> Pg=47.65, Qg=4.9
% INFO    : Gen at bus 8602	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8602	: Pg=31.64, Qg=31.6 -> Pg=47.65, Qg=4.9
% INFO    : Gen at bus 8602	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8603	: Pg=16.0, Qg=9.93 -> Pg=15.0, Qg=2.305
% INFO    : Gen at bus 8603	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8603	: Pg=16.0, Qg=9.93 -> Pg=15.0, Qg=2.305
% INFO    : Gen at bus 8603	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8603	: Pg=16.0, Qg=9.93 -> Pg=15.0, Qg=2.305
% INFO    : Gen at bus 8603	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8603	: Pg=16.0, Qg=9.93 -> Pg=15.0, Qg=2.305
% INFO    : Gen at bus 8603	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8605	: Pg=62.5, Qg=24.7 -> Pg=31.25, Qg=0.0
% INFO    : Gen at bus 8605	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8607	: Pg=58.9, Qg=31.34 -> Pg=40.45, Qg=8.45
% INFO    : Gen at bus 8607	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8607	: Pg=58.9, Qg=31.34 -> Pg=40.45, Qg=8.45
% INFO    : Gen at bus 8607	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8607	: Pg=58.9, Qg=31.34 -> Pg=40.45, Qg=8.45
% INFO    : Gen at bus 8607	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8607	: Pg=58.9, Qg=31.34 -> Pg=39.45, Qg=8.45
% INFO    : Gen at bus 8607	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8607	: Pg=58.9, Qg=31.34 -> Pg=37.95, Qg=8.45
% INFO    : Gen at bus 8607	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8608	: Pg=39.17, Qg=27.9 -> Pg=42.3, Qg=4.35
% INFO    : Gen at bus 8608	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8609	: Pg=5.47, Qg=11.53 -> Pg=11.8, Qg=2.665
% INFO    : Gen at bus 8609	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8609	: Pg=5.47, Qg=11.53 -> Pg=11.8, Qg=2.665
% INFO    : Gen at bus 8609	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8609	: Pg=5.47, Qg=11.53 -> Pg=11.8, Qg=2.665
% INFO    : Gen at bus 8609	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8610	: Pg=54.0, Qg=26.2 -> Pg=33.0, Qg=4.1
% INFO    : Gen at bus 8610	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8611	: Pg=36.45, Qg=40.2 -> Pg=41.8, Qg=11.15
% INFO    : Gen at bus 8611	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8612	: Pg=36.25, Qg=33.0 -> Pg=26.65, Qg=7.6
% INFO    : Gen at bus 8612	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8613	: Pg=53.1, Qg=32.9 -> Pg=29.05, Qg=7.6
% INFO    : Gen at bus 8613	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8614	: Pg=17.57, Qg=11.13 -> Pg=9.535, Qg=2.63
% INFO    : Gen at bus 8614	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8614	: Pg=17.57, Qg=11.13 -> Pg=9.535, Qg=2.63
% INFO    : Gen at bus 8614	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8614	: Pg=17.57, Qg=11.13 -> Pg=9.535, Qg=2.63
% INFO    : Gen at bus 8614	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8614	: Pg=156.2, Qg=96.8 -> Pg=105.6, Qg=22.35
% INFO    : Gen at bus 8614	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8614	: Pg=89.1, Qg=43.2 -> Pg=62.05, Qg=6.75
% INFO    : Gen at bus 8614	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8614	: Pg=89.1, Qg=43.2 -> Pg=62.05, Qg=6.75
% INFO    : Gen at bus 8614	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8614	: Pg=103.5, Qg=64.1 -> Pg=74.25, Qg=14.8
% INFO    : Gen at bus 8614	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8615	: Pg=52.5, Qg=20.7 -> Pg=26.25, Qg=0.0
% INFO    : Gen at bus 8615	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8616	: Pg=26.1, Qg=18.35 -> Pg=17.65, Qg=4.825
% INFO    : Gen at bus 8616	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8616	: Pg=26.1, Qg=18.35 -> Pg=17.65, Qg=4.825
% INFO    : Gen at bus 8616	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8617	: Pg=3.32, Qg=3.83 -> Pg=7.9, Qg=0.96
% INFO    : Gen at bus 8617	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8617	: Pg=3.32, Qg=3.83 -> Pg=7.9, Qg=0.96
% INFO    : Gen at bus 8617	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8617	: Pg=3.32, Qg=3.83 -> Pg=7.9, Qg=0.96
% INFO    : Gen at bus 8617	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8617	: Pg=3.32, Qg=3.83 -> Pg=7.9, Qg=0.96
% INFO    : Gen at bus 8617	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8618	: Pg=50.5, Qg=37.9 -> Pg=42.75, Qg=10.55
% INFO    : Gen at bus 8618	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8619	: Pg=49.9, Qg=30.9 -> Pg=26.95, Qg=7.15
% INFO    : Gen at bus 8619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8623	: Pg=5.1, Qg=21.2 -> Pg=23.9, Qg=3.3
% INFO    : Gen at bus 8623	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8623	: Pg=5.1, Qg=21.2 -> Pg=23.9, Qg=3.3
% INFO    : Gen at bus 8623	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8624	: Pg=5.1, Qg=21.2 -> Pg=23.9, Qg=3.3
% INFO    : Gen at bus 8624	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8624	: Pg=5.1, Qg=21.2 -> Pg=23.9, Qg=3.3
% INFO    : Gen at bus 8624	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8625	: Pg=43.8, Qg=21.2 -> Pg=23.9, Qg=3.3
% INFO    : Gen at bus 8625	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8625	: Pg=43.8, Qg=21.2 -> Pg=23.9, Qg=3.3
% INFO    : Gen at bus 8625	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8629	: Pg=36.5, Qg=22.6 -> Pg=24.1, Qg=5.2
% INFO    : Gen at bus 8629	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8630	: Pg=18.0, Qg=11.15 -> Pg=15.5, Qg=2.575
% INFO    : Gen at bus 8630	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8630	: Pg=18.0, Qg=11.15 -> Pg=15.5, Qg=2.575
% INFO    : Gen at bus 8630	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8630	: Pg=75.0, Qg=45.5 -> Pg=49.5, Qg=10.25
% INFO    : Gen at bus 8630	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8630	: Pg=75.0, Qg=45.5 -> Pg=49.5, Qg=10.25
% INFO    : Gen at bus 8630	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8630	: Pg=75.0, Qg=45.5 -> Pg=49.5, Qg=10.25
% INFO    : Gen at bus 8630	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8632	: Pg=10.88, Qg=26.3 -> Pg=22.5, Qg=7.3
% INFO    : Gen at bus 8632	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8632	: Pg=32.86, Qg=85.5 -> Pg=72.0, Qg=23.75
% INFO    : Gen at bus 8632	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8633	: Pg=34.5, Qg=13.6 -> Pg=17.25, Qg=0.0
% INFO    : Gen at bus 8633	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8635	: Pg=33.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 8635	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8636	: Pg=32.3, Qg=15.6 -> Pg=23.65, Qg=2.4
% INFO    : Gen at bus 8636	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8636	: Pg=38.4, Qg=23.8 -> Pg=29.2, Qg=5.5
% INFO    : Gen at bus 8636	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8637	: Pg=32.1, Qg=15.5 -> Pg=23.05, Qg=2.4
% INFO    : Gen at bus 8637	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8640	: Pg=16.0, Qg=9.9 -> Pg=14.7, Qg=2.275
% INFO    : Gen at bus 8640	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8640	: Pg=16.0, Qg=9.9 -> Pg=14.7, Qg=2.275
% INFO    : Gen at bus 8640	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8641	: Pg=32.0, Qg=0.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 8641	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8641	: Pg=37.5, Qg=0.0 -> Pg=18.75, Qg=0.0
% INFO    : Gen at bus 8641	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8641	: Pg=37.5, Qg=0.0 -> Pg=18.75, Qg=0.0
% INFO    : Gen at bus 8641	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8641	: Pg=37.5, Qg=0.0 -> Pg=18.75, Qg=0.0
% INFO    : Gen at bus 8641	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8641	: Pg=32.0, Qg=0.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 8641	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8641	: Pg=32.0, Qg=0.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 8641	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8641	: Pg=32.0, Qg=0.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 8641	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8641	: Pg=32.0, Qg=0.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 8641	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8641	: Pg=33.0, Qg=0.0 -> Pg=16.5, Qg=0.0
% INFO    : Gen at bus 8641	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8641	: Pg=33.0, Qg=0.0 -> Pg=16.5, Qg=0.0
% INFO    : Gen at bus 8641	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8641	: Pg=37.5, Qg=0.0 -> Pg=18.75, Qg=0.0
% INFO    : Gen at bus 8641	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8641	: Pg=37.5, Qg=0.0 -> Pg=18.75, Qg=0.0
% INFO    : Gen at bus 8641	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8642	: Pg=10.0, Qg=7.5 -> Pg=6.835, Qg=2.085
% INFO    : Gen at bus 8642	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8642	: Pg=10.0, Qg=7.5 -> Pg=6.835, Qg=2.085
% INFO    : Gen at bus 8642	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8642	: Pg=4.72, Qg=7.5 -> Pg=6.835, Qg=2.085
% INFO    : Gen at bus 8642	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8643	: Pg=10.0, Qg=7.5 -> Pg=6.5, Qg=2.085
% INFO    : Gen at bus 8643	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8643	: Pg=10.0, Qg=7.5 -> Pg=6.5, Qg=2.085
% INFO    : Gen at bus 8643	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8643	: Pg=10.0, Qg=7.5 -> Pg=6.5, Qg=2.085
% INFO    : Gen at bus 8643	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8644	: Pg=30.0, Qg=11.9 -> Pg=15.75, Qg=0.0
% INFO    : Gen at bus 8644	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8646	: Pg=28.07, Qg=18.0 -> Pg=28.53, Qg=4.15
% INFO    : Gen at bus 8646	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8646	: Pg=134.81, Qg=94.07 -> Pg=149.0, Qg=31.5
% INFO    : Gen at bus 8646	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8646	: Pg=205.97, Qg=94.07 -> Pg=149.0, Qg=31.5
% INFO    : Gen at bus 8646	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8647	: Pg=27.0, Qg=16.7 -> Pg=22.5, Qg=3.85
% INFO    : Gen at bus 8647	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8647	: Pg=27.0, Qg=16.7 -> Pg=22.5, Qg=3.85
% INFO    : Gen at bus 8647	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8648	: Pg=27.0, Qg=16.7 -> Pg=22.5, Qg=3.85
% INFO    : Gen at bus 8648	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8649	: Pg=27.0, Qg=16.7 -> Pg=22.5, Qg=3.85
% INFO    : Gen at bus 8649	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8649	: Pg=27.0, Qg=16.7 -> Pg=22.5, Qg=3.85
% INFO    : Gen at bus 8649	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8650	: Pg=26.0, Qg=10.3 -> Pg=13.0, Qg=0.0
% INFO    : Gen at bus 8650	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8651	: Pg=25.0, Qg=18.8 -> Pg=13.75, Qg=5.25
% INFO    : Gen at bus 8651	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8651	: Pg=25.0, Qg=18.8 -> Pg=13.75, Qg=5.25
% INFO    : Gen at bus 8651	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8652	: Pg=0.65, Qg=2.95 -> Pg=3.3, Qg=0.46
% INFO    : Gen at bus 8652	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8652	: Pg=0.65, Qg=2.95 -> Pg=3.3, Qg=0.46
% INFO    : Gen at bus 8652	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8652	: Pg=0.65, Qg=2.95 -> Pg=3.3, Qg=0.46
% INFO    : Gen at bus 8652	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8652	: Pg=0.65, Qg=2.95 -> Pg=3.3, Qg=0.46
% INFO    : Gen at bus 8652	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8653	: Pg=24.1, Qg=0.0 -> Pg=15.55, Qg=0.0
% INFO    : Gen at bus 8653	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8654	: Pg=6.0, Qg=4.5 -> Pg=3.5, Qg=1.25
% INFO    : Gen at bus 8654	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8654	: Pg=6.0, Qg=4.5 -> Pg=3.5, Qg=1.25
% INFO    : Gen at bus 8654	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8654	: Pg=6.0, Qg=4.5 -> Pg=3.5, Qg=1.25
% INFO    : Gen at bus 8654	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8654	: Pg=6.0, Qg=4.5 -> Pg=3.5, Qg=1.25
% INFO    : Gen at bus 8654	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8657	: Pg=22.3, Qg=13.8 -> Pg=20.15, Qg=3.2
% INFO    : Gen at bus 8657	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8657	: Pg=22.3, Qg=13.8 -> Pg=20.15, Qg=3.2
% INFO    : Gen at bus 8657	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8657	: Pg=22.3, Qg=13.8 -> Pg=20.15, Qg=3.2
% INFO    : Gen at bus 8657	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8657	: Pg=22.3, Qg=13.8 -> Pg=20.15, Qg=3.2
% INFO    : Gen at bus 8657	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8657	: Pg=850.48, Qg=97.35 -> Pg=550.25, Qg=64.2
% INFO    : Gen at bus 8657	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8657	: Pg=850.48, Qg=97.35 -> Pg=550.25, Qg=64.2
% INFO    : Gen at bus 8657	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8661	: Pg=21.0, Qg=13.0 -> Pg=11.5, Qg=3.0
% INFO    : Gen at bus 8661	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8662	: Pg=20.0, Qg=12.4 -> Pg=19.0, Qg=2.85
% INFO    : Gen at bus 8662	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8662	: Pg=20.0, Qg=12.4 -> Pg=19.0, Qg=2.85
% INFO    : Gen at bus 8662	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 8662	: Pg=20.0, Qg=12.4 -> Pg=18.5, Qg=2.85
% INFO    : Gen at bus 8662	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13881	: Pg=50.4, Qg=31.23 -> Pg=33.035, Qg=7.215
% INFO    : Gen at bus 13881	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13881	: Pg=50.4, Qg=31.23 -> Pg=33.035, Qg=7.215
% INFO    : Gen at bus 13881	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13881	: Pg=50.4, Qg=31.23 -> Pg=33.035, Qg=7.215
% INFO    : Gen at bus 13881	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13882	: Pg=97.93, Qg=44.4 -> Pg=112.0, Qg=20.6
% INFO    : Gen at bus 13882	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13882	: Pg=97.93, Qg=44.4 -> Pg=112.0, Qg=20.6
% INFO    : Gen at bus 13882	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13882	: Pg=97.93, Qg=44.4 -> Pg=112.0, Qg=20.6
% INFO    : Gen at bus 13882	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13882	: Pg=136.01, Qg=44.4 -> Pg=140.0, Qg=15.1
% INFO    : Gen at bus 13882	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13882	: Pg=132.61, Qg=44.4 -> Pg=120.0, Qg=27.95
% INFO    : Gen at bus 13882	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13882	: Pg=83.06, Qg=44.4 -> Pg=101.0, Qg=9.2
% INFO    : Gen at bus 13882	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13882	: Pg=83.06, Qg=44.4 -> Pg=101.0, Qg=9.2
% INFO    : Gen at bus 13882	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13882	: Pg=83.06, Qg=44.4 -> Pg=101.0, Qg=9.2
% INFO    : Gen at bus 13882	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13883	: Pg=27.5, Qg=0.0 -> Pg=21.25, Qg=0.0
% INFO    : Gen at bus 13883	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13883	: Pg=27.5, Qg=0.0 -> Pg=21.25, Qg=0.0
% INFO    : Gen at bus 13883	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13883	: Pg=75.0, Qg=0.0 -> Pg=46.0, Qg=0.0
% INFO    : Gen at bus 13883	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13883	: Pg=92.0, Qg=0.0 -> Pg=68.5, Qg=0.0
% INFO    : Gen at bus 13883	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13883	: Pg=92.0, Qg=0.0 -> Pg=68.5, Qg=0.0
% INFO    : Gen at bus 13883	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13884	: Pg=176.79, Qg=38.03 -> Pg=113.4, Qg=25.35
% INFO    : Gen at bus 13884	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13884	: Pg=81.6, Qg=38.03 -> Pg=55.08, Qg=11.15
% INFO    : Gen at bus 13884	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13884	: Pg=81.6, Qg=38.03 -> Pg=55.08, Qg=11.15
% INFO    : Gen at bus 13884	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13884	: Pg=445.49, Qg=38.03 -> Pg=317.75, Qg=33.65
% INFO    : Gen at bus 13884	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13885	: Pg=160.7, Qg=109.6 -> Pg=113.4, Qg=25.35
% INFO    : Gen at bus 13885	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13885	: Pg=445.99, Qg=215.56 -> Pg=255.5, Qg=33.65
% INFO    : Gen at bus 13885	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13885	: Pg=75.0, Qg=46.5 -> Pg=50.0, Qg=10.75
% INFO    : Gen at bus 13885	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13886	: Pg=68.0, Qg=29.25 -> Pg=51.5, Qg=8.55
% INFO    : Gen at bus 13886	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13886	: Pg=50.0, Qg=29.25 -> Pg=40.0, Qg=7.15
% INFO    : Gen at bus 13886	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13886	: Pg=50.0, Qg=29.25 -> Pg=40.0, Qg=7.15
% INFO    : Gen at bus 13886	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13888	: Pg=45.0, Qg=27.9 -> Pg=23.5, Qg=6.45
% INFO    : Gen at bus 13888	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13889	: Pg=20.7, Qg=19.5 -> Pg=23.0, Qg=5.4
% INFO    : Gen at bus 13889	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13889	: Pg=20.7, Qg=19.5 -> Pg=23.0, Qg=5.4
% INFO    : Gen at bus 13889	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13890	: Pg=10.0, Qg=6.2 -> Pg=6.425, Qg=1.425
% INFO    : Gen at bus 13890	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13890	: Pg=10.0, Qg=6.2 -> Pg=6.425, Qg=1.425
% INFO    : Gen at bus 13890	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13891	: Pg=20.0, Qg=12.4 -> Pg=17.5, Qg=2.85
% INFO    : Gen at bus 13891	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13892	: Pg=918.0, Qg=147.86 -> Pg=484.0, Qg=69.3
% INFO    : Gen at bus 13892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13892	: Pg=910.7, Qg=147.86 -> Pg=475.35, Qg=68.75
% INFO    : Gen at bus 13892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13893	: Pg=684.98, Qg=331.8 -> Pg=452.5, Qg=51.75
% INFO    : Gen at bus 13893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13893	: Pg=684.98, Qg=331.8 -> Pg=452.5, Qg=51.75
% INFO    : Gen at bus 13893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13894	: Pg=125.0, Qg=60.5 -> Pg=95.0, Qg=9.4
% INFO    : Gen at bus 13894	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13894	: Pg=363.99, Qg=156.45 -> Pg=267.0, Qg=52.15
% INFO    : Gen at bus 13894	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13894	: Pg=125.0, Qg=60.5 -> Pg=95.0, Qg=9.4
% INFO    : Gen at bus 13894	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13894	: Pg=94.0, Qg=45.5 -> Pg=62.0, Qg=7.1
% INFO    : Gen at bus 13894	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13894	: Pg=35.0, Qg=17.0 -> Pg=20.0, Qg=2.65
% INFO    : Gen at bus 13894	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13894	: Pg=103.0, Qg=63.8 -> Pg=68.0, Qg=14.75
% INFO    : Gen at bus 13894	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13894	: Pg=103.0, Qg=63.8 -> Pg=68.0, Qg=14.75
% INFO    : Gen at bus 13894	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13894	: Pg=658.98, Qg=156.45 -> Pg=620.5, Qg=49.75
% INFO    : Gen at bus 13894	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13894	: Pg=658.98, Qg=156.45 -> Pg=620.5, Qg=49.75
% INFO    : Gen at bus 13894	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13894	: Pg=363.99, Qg=156.45 -> Pg=272.0, Qg=52.15
% INFO    : Gen at bus 13894	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13895	: Pg=49.33, Qg=25.57 -> Pg=32.5, Qg=4.56
% INFO    : Gen at bus 13895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13895	: Pg=49.33, Qg=25.57 -> Pg=32.5, Qg=4.56
% INFO    : Gen at bus 13895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13895	: Pg=49.33, Qg=25.57 -> Pg=32.5, Qg=4.56
% INFO    : Gen at bus 13895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13895	: Pg=49.33, Qg=25.57 -> Pg=32.5, Qg=4.56
% INFO    : Gen at bus 13895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13895	: Pg=49.33, Qg=25.57 -> Pg=32.5, Qg=4.56
% INFO    : Gen at bus 13895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13895	: Pg=49.33, Qg=25.57 -> Pg=32.5, Qg=4.56
% INFO    : Gen at bus 13895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13895	: Pg=625.98, Qg=114.39 -> Pg=414.5, Qg=47.25
% INFO    : Gen at bus 13895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13895	: Pg=625.98, Qg=114.39 -> Pg=411.5, Qg=47.25
% INFO    : Gen at bus 13895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13897	: Pg=195.99, Qg=121.5 -> Pg=128.0, Qg=28.1
% INFO    : Gen at bus 13897	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13897	: Pg=195.99, Qg=121.5 -> Pg=128.0, Qg=28.1
% INFO    : Gen at bus 13897	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13897	: Pg=195.99, Qg=121.5 -> Pg=128.0, Qg=28.1
% INFO    : Gen at bus 13897	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13897	: Pg=163.0, Qg=78.9 -> Pg=101.5, Qg=12.3
% INFO    : Gen at bus 13897	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13897	: Pg=163.0, Qg=78.9 -> Pg=101.5, Qg=12.3
% INFO    : Gen at bus 13897	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13898	: Pg=36.11, Qg=32.9 -> Pg=29.05, Qg=7.6
% INFO    : Gen at bus 13898	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13898	: Pg=36.11, Qg=32.9 -> Pg=29.05, Qg=7.6
% INFO    : Gen at bus 13898	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13898	: Pg=36.11, Qg=32.9 -> Pg=29.05, Qg=7.6
% INFO    : Gen at bus 13898	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13898	: Pg=36.11, Qg=32.9 -> Pg=29.05, Qg=7.6
% INFO    : Gen at bus 13898	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13898	: Pg=130.57, Qg=93.0 -> Pg=101.0, Qg=14.5
% INFO    : Gen at bus 13898	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13899	: Pg=129.48, Qg=118.0 -> Pg=140.2, Qg=27.25
% INFO    : Gen at bus 13899	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13899	: Pg=142.4, Qg=129.8 -> Pg=134.7, Qg=30.0
% INFO    : Gen at bus 13899	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13900	: Pg=175.89, Qg=83.05 -> Pg=137.95, Qg=25.2
% INFO    : Gen at bus 13900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13900	: Pg=198.89, Qg=83.05 -> Pg=149.45, Qg=28.5
% INFO    : Gen at bus 13900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13900	: Pg=198.89, Qg=83.05 -> Pg=149.45, Qg=28.5
% INFO    : Gen at bus 13900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13900	: Pg=198.89, Qg=83.05 -> Pg=149.45, Qg=28.5
% INFO    : Gen at bus 13900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13901	: Pg=76.41, Qg=60.8 -> Pg=108.5, Qg=12.25
% INFO    : Gen at bus 13901	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13902	: Pg=12.24, Qg=11.15 -> Pg=10.5, Qg=2.575
% INFO    : Gen at bus 13902	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13902	: Pg=12.24, Qg=11.15 -> Pg=10.5, Qg=2.575
% INFO    : Gen at bus 13902	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13902	: Pg=12.24, Qg=11.15 -> Pg=10.5, Qg=2.575
% INFO    : Gen at bus 13902	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13902	: Pg=12.24, Qg=11.15 -> Pg=10.5, Qg=2.575
% INFO    : Gen at bus 13902	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13902	: Pg=12.24, Qg=11.15 -> Pg=10.5, Qg=2.575
% INFO    : Gen at bus 13902	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13902	: Pg=12.24, Qg=11.15 -> Pg=10.5, Qg=2.575
% INFO    : Gen at bus 13902	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13902	: Pg=12.24, Qg=11.15 -> Pg=10.5, Qg=2.575
% INFO    : Gen at bus 13902	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13902	: Pg=12.24, Qg=11.15 -> Pg=10.5, Qg=2.575
% INFO    : Gen at bus 13902	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13903	: Pg=33.41, Qg=84.3 -> Pg=83.0, Qg=19.5
% INFO    : Gen at bus 13903	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13903	: Pg=70.39, Qg=200.8 -> Pg=237.35, Qg=31.3
% INFO    : Gen at bus 13903	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13903	: Pg=138.99, Qg=173.9 -> Pg=244.5, Qg=27.1
% INFO    : Gen at bus 13903	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13904	: Pg=5.63, Qg=15.5 -> Pg=15.0, Qg=3.6
% INFO    : Gen at bus 13904	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13904	: Pg=5.63, Qg=15.5 -> Pg=15.0, Qg=3.6
% INFO    : Gen at bus 13904	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13904	: Pg=21.81, Qg=44.7 -> Pg=46.1, Qg=10.3
% INFO    : Gen at bus 13904	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13904	: Pg=23.38, Qg=65.4 -> Pg=77.5, Qg=10.2
% INFO    : Gen at bus 13904	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13905	: Pg=121.5, Qg=58.8 -> Pg=70.75, Qg=9.15
% INFO    : Gen at bus 13905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13908	: Pg=23.9, Qg=10.03 -> Pg=12.45, Qg=3.4
% INFO    : Gen at bus 13908	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13908	: Pg=23.9, Qg=10.03 -> Pg=12.45, Qg=3.4
% INFO    : Gen at bus 13908	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13908	: Pg=15.27, Qg=10.03 -> Pg=8.135, Qg=2.5
% INFO    : Gen at bus 13908	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13908	: Pg=15.27, Qg=10.03 -> Pg=8.135, Qg=2.5
% INFO    : Gen at bus 13908	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13908	: Pg=15.27, Qg=10.03 -> Pg=8.135, Qg=2.5
% INFO    : Gen at bus 13908	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13908	: Pg=15.27, Qg=10.03 -> Pg=8.135, Qg=2.5
% INFO    : Gen at bus 13908	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13908	: Pg=15.27, Qg=10.03 -> Pg=8.135, Qg=2.5
% INFO    : Gen at bus 13908	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13908	: Pg=15.27, Qg=10.03 -> Pg=8.135, Qg=2.5
% INFO    : Gen at bus 13908	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13912	: Pg=4.85, Qg=3.64 -> Pg=2.425, Qg=1.015
% INFO    : Gen at bus 13912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13912	: Pg=4.85, Qg=3.64 -> Pg=2.425, Qg=1.015
% INFO    : Gen at bus 13912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13912	: Pg=4.85, Qg=3.64 -> Pg=2.425, Qg=1.015
% INFO    : Gen at bus 13912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13912	: Pg=4.85, Qg=3.64 -> Pg=2.425, Qg=1.015
% INFO    : Gen at bus 13912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13912	: Pg=4.85, Qg=3.64 -> Pg=2.425, Qg=1.015
% INFO    : Gen at bus 13912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13912	: Pg=4.85, Qg=3.64 -> Pg=2.425, Qg=1.015
% INFO    : Gen at bus 13912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13912	: Pg=4.85, Qg=3.64 -> Pg=2.425, Qg=1.015
% INFO    : Gen at bus 13912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13912	: Pg=4.85, Qg=3.64 -> Pg=2.425, Qg=1.015
% INFO    : Gen at bus 13912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13917	: Pg=22.0, Qg=0.0 -> Pg=20.5, Qg=0.0
% INFO    : Gen at bus 13917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13920	: Pg=847.05, Qg=603.3 -> Pg=945.8, Qg=94.05
% INFO    : Gen at bus 13920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13921	: Pg=1157.6, Qg=260.21 -> Pg=1188.95, Qg=142.4
% INFO    : Gen at bus 13921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13921	: Pg=1138.5, Qg=260.21 -> Pg=1179.4, Qg=206.6
% INFO    : Gen at bus 13921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13922	: Pg=1001.6, Qg=-10.69 -> Pg=969.8, Qg=0.0
% INFO    : Gen at bus 13922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13922	: Pg=1001.6, Qg=-10.69 -> Pg=966.8, Qg=0.0
% INFO    : Gen at bus 13922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13923	: Pg=950.9, Qg=312.5 -> Pg=939.45, Qg=0.0
% INFO    : Gen at bus 13923	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13924	: Pg=763.18, Qg=332.87 -> Pg=456.6, Qg=57.6
% INFO    : Gen at bus 13924	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13925	: Pg=745.18, Qg=59.89 -> Pg=497.6, Qg=56.25
% INFO    : Gen at bus 13925	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13925	: Pg=656.98, Qg=59.89 -> Pg=403.5, Qg=49.6
% INFO    : Gen at bus 13925	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13925	: Pg=745.18, Qg=59.89 -> Pg=422.6, Qg=56.25
% INFO    : Gen at bus 13925	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13925	: Pg=371.52, Qg=59.89 -> Pg=255.4, Qg=31.05
% INFO    : Gen at bus 13925	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13926	: Pg=199.39, Qg=-1.03 -> Pg=149.7, Qg=28.55
% INFO    : Gen at bus 13926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13926	: Pg=199.39, Qg=-1.03 -> Pg=149.7, Qg=28.55
% INFO    : Gen at bus 13926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13926	: Pg=199.39, Qg=-1.03 -> Pg=149.7, Qg=28.55
% INFO    : Gen at bus 13926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13926	: Pg=199.39, Qg=-1.03 -> Pg=149.7, Qg=28.55
% INFO    : Gen at bus 13926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13926	: Pg=199.39, Qg=-1.03 -> Pg=149.7, Qg=28.55
% INFO    : Gen at bus 13926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13926	: Pg=195.49, Qg=-1.03 -> Pg=141.74, Qg=28.0
% INFO    : Gen at bus 13926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13926	: Pg=199.39, Qg=-1.03 -> Pg=144.565, Qg=28.55
% INFO    : Gen at bus 13926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13926	: Pg=199.39, Qg=-1.03 -> Pg=144.565, Qg=28.55
% INFO    : Gen at bus 13926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13927	: Pg=199.39, Qg=85.4 -> Pg=187.2, Qg=28.55
% INFO    : Gen at bus 13927	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13927	: Pg=138.75, Qg=85.4 -> Pg=147.2, Qg=28.55
% INFO    : Gen at bus 13927	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13927	: Pg=135.6, Qg=85.4 -> Pg=147.2, Qg=28.55
% INFO    : Gen at bus 13927	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13927	: Pg=135.6, Qg=85.4 -> Pg=147.2, Qg=28.55
% INFO    : Gen at bus 13927	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13927	: Pg=132.61, Qg=85.4 -> Pg=141.375, Qg=27.95
% INFO    : Gen at bus 13927	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13927	: Pg=135.6, Qg=85.4 -> Pg=144.565, Qg=28.55
% INFO    : Gen at bus 13927	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13928	: Pg=195.49, Qg=100.51 -> Pg=180.25, Qg=28.0
% INFO    : Gen at bus 13928	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13928	: Pg=195.49, Qg=100.51 -> Pg=180.25, Qg=28.0
% INFO    : Gen at bus 13928	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13928	: Pg=195.49, Qg=100.51 -> Pg=180.25, Qg=28.0
% INFO    : Gen at bus 13928	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13928	: Pg=195.49, Qg=100.51 -> Pg=180.25, Qg=28.0
% INFO    : Gen at bus 13928	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13928	: Pg=195.49, Qg=100.51 -> Pg=180.25, Qg=28.0
% INFO    : Gen at bus 13928	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13929	: Pg=195.19, Qg=73.73 -> Pg=147.6, Qg=27.95
% INFO    : Gen at bus 13929	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13929	: Pg=195.19, Qg=73.73 -> Pg=147.6, Qg=27.95
% INFO    : Gen at bus 13929	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13929	: Pg=198.89, Qg=73.73 -> Pg=149.45, Qg=28.5
% INFO    : Gen at bus 13929	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13929	: Pg=195.19, Qg=73.73 -> Pg=132.6, Qg=27.95
% INFO    : Gen at bus 13929	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13929	: Pg=195.19, Qg=73.73 -> Pg=132.6, Qg=27.95
% INFO    : Gen at bus 13929	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13930	: Pg=65.09, Qg=101.1 -> Pg=112.1, Qg=23.35
% INFO    : Gen at bus 13930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13930	: Pg=65.09, Qg=101.1 -> Pg=112.1, Qg=23.35
% INFO    : Gen at bus 13930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13930	: Pg=132.81, Qg=106.39 -> Pg=199.0, Qg=38.95
% INFO    : Gen at bus 13930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13930	: Pg=122.81, Qg=106.39 -> Pg=194.0, Qg=38.95
% INFO    : Gen at bus 13930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13930	: Pg=121.96, Qg=106.39 -> Pg=196.5, Qg=39.8
% INFO    : Gen at bus 13930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13931	: Pg=112.5, Qg=69.7 -> Pg=75.94, Qg=16.1
% INFO    : Gen at bus 13931	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13931	: Pg=112.5, Qg=69.7 -> Pg=75.94, Qg=16.1
% INFO    : Gen at bus 13931	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13931	: Pg=37.5, Qg=23.2 -> Pg=21.75, Qg=5.35
% INFO    : Gen at bus 13931	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13931	: Pg=37.5, Qg=23.2 -> Pg=21.75, Qg=5.35
% INFO    : Gen at bus 13931	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13931	: Pg=446.59, Qg=216.3 -> Pg=312.62, Qg=33.7
% INFO    : Gen at bus 13931	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13932	: Pg=51.0, Qg=31.6 -> Pg=36.72, Qg=7.3
% INFO    : Gen at bus 13932	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13932	: Pg=51.0, Qg=31.6 -> Pg=36.72, Qg=7.3
% INFO    : Gen at bus 13932	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13932	: Pg=187.89, Qg=116.4 -> Pg=130.59, Qg=26.9
% INFO    : Gen at bus 13932	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13932	: Pg=140.6, Qg=105.5 -> Pg=97.715, Qg=29.3
% INFO    : Gen at bus 13932	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13933	: Pg=55.2, Qg=43.07 -> Pg=92.435, Qg=27.75
% INFO    : Gen at bus 13933	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13933	: Pg=55.2, Qg=43.07 -> Pg=92.435, Qg=27.75
% INFO    : Gen at bus 13933	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13933	: Pg=15.38, Qg=18.9 -> Pg=24.165, Qg=3.8
% INFO    : Gen at bus 13933	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13933	: Pg=15.38, Qg=18.9 -> Pg=24.165, Qg=3.8
% INFO    : Gen at bus 13933	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13933	: Pg=15.38, Qg=18.9 -> Pg=24.165, Qg=3.8
% INFO    : Gen at bus 13933	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13933	: Pg=15.38, Qg=18.9 -> Pg=24.165, Qg=3.8
% INFO    : Gen at bus 13933	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13933	: Pg=37.5, Qg=43.07 -> Pg=67.5, Qg=20.85
% INFO    : Gen at bus 13933	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13933	: Pg=37.5, Qg=43.07 -> Pg=67.5, Qg=20.85
% INFO    : Gen at bus 13933	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13934	: Pg=83.5, Qg=28.8 -> Pg=84.4, Qg=0.0
% INFO    : Gen at bus 13934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13934	: Pg=83.5, Qg=28.8 -> Pg=84.4, Qg=0.0
% INFO    : Gen at bus 13934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13934	: Pg=83.5, Qg=28.8 -> Pg=84.4, Qg=0.0
% INFO    : Gen at bus 13934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13934	: Pg=83.5, Qg=28.8 -> Pg=84.4, Qg=0.0
% INFO    : Gen at bus 13934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13936	: Pg=75.0, Qg=46.5 -> Pg=50.625, Qg=10.75
% INFO    : Gen at bus 13936	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13936	: Pg=75.0, Qg=46.5 -> Pg=50.625, Qg=10.75
% INFO    : Gen at bus 13936	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13936	: Pg=29.9, Qg=18.5 -> Pg=21.155, Qg=4.25
% INFO    : Gen at bus 13936	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13936	: Pg=29.9, Qg=18.5 -> Pg=21.155, Qg=4.25
% INFO    : Gen at bus 13936	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13936	: Pg=29.9, Qg=18.5 -> Pg=21.155, Qg=4.25
% INFO    : Gen at bus 13936	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13936	: Pg=252.39, Qg=122.2 -> Pg=175.42, Qg=19.05
% INFO    : Gen at bus 13936	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13937	: Pg=35.07, Qg=17.37 -> Pg=51.95, Qg=5.35
% INFO    : Gen at bus 13937	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13937	: Pg=59.08, Qg=17.37 -> Pg=75.85, Qg=0.0
% INFO    : Gen at bus 13937	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13938	: Pg=67.5, Qg=15.12 -> Pg=60.5, Qg=5.1
% INFO    : Gen at bus 13938	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13938	: Pg=67.5, Qg=15.12 -> Pg=60.5, Qg=5.1
% INFO    : Gen at bus 13938	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13940	: Pg=14.85, Qg=11.25 -> Pg=14.75, Qg=3.125
% INFO    : Gen at bus 13940	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13940	: Pg=14.85, Qg=11.25 -> Pg=14.75, Qg=3.125
% INFO    : Gen at bus 13940	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13940	: Pg=14.85, Qg=11.25 -> Pg=14.75, Qg=3.125
% INFO    : Gen at bus 13940	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13940	: Pg=14.85, Qg=11.25 -> Pg=14.75, Qg=3.125
% INFO    : Gen at bus 13940	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13941	: Pg=57.8, Qg=28.0 -> Pg=34.9, Qg=4.35
% INFO    : Gen at bus 13941	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13942	: Pg=57.4, Qg=35.6 -> Pg=28.7, Qg=8.25
% INFO    : Gen at bus 13942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13942	: Pg=57.4, Qg=35.6 -> Pg=28.7, Qg=8.25
% INFO    : Gen at bus 13942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13943	: Pg=38.97, Qg=18.46 -> Pg=42.65, Qg=8.2
% INFO    : Gen at bus 13943	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13943	: Pg=38.97, Qg=18.46 -> Pg=42.65, Qg=8.2
% INFO    : Gen at bus 13943	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13943	: Pg=38.97, Qg=18.46 -> Pg=42.65, Qg=8.2
% INFO    : Gen at bus 13943	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13943	: Pg=38.97, Qg=18.46 -> Pg=42.65, Qg=8.2
% INFO    : Gen at bus 13943	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13943	: Pg=38.97, Qg=18.46 -> Pg=42.65, Qg=8.2
% INFO    : Gen at bus 13943	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13943	: Pg=38.97, Qg=18.46 -> Pg=42.65, Qg=8.2
% INFO    : Gen at bus 13943	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13945	: Pg=54.0, Qg=13.5 -> Pg=29.5, Qg=0.0
% INFO    : Gen at bus 13945	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13946	: Pg=3.02, Qg=6.57 -> Pg=5.775, Qg=1.825
% INFO    : Gen at bus 13946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13946	: Pg=3.02, Qg=6.57 -> Pg=5.775, Qg=1.825
% INFO    : Gen at bus 13946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13946	: Pg=3.02, Qg=6.57 -> Pg=5.775, Qg=1.825
% INFO    : Gen at bus 13946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13946	: Pg=3.02, Qg=6.57 -> Pg=5.775, Qg=1.825
% INFO    : Gen at bus 13946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13946	: Pg=3.02, Qg=6.57 -> Pg=5.775, Qg=1.825
% INFO    : Gen at bus 13946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13946	: Pg=3.02, Qg=6.57 -> Pg=5.775, Qg=1.825
% INFO    : Gen at bus 13946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13948	: Pg=50.0, Qg=31.0 -> Pg=37.5, Qg=7.15
% INFO    : Gen at bus 13948	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13949	: Pg=46.0, Qg=28.5 -> Pg=31.05, Qg=6.6
% INFO    : Gen at bus 13949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13949	: Pg=46.0, Qg=28.5 -> Pg=31.05, Qg=6.6
% INFO    : Gen at bus 13949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13949	: Pg=73.5, Qg=37.86 -> Pg=49.615, Qg=15.3
% INFO    : Gen at bus 13949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13950	: Pg=44.4, Qg=16.1 -> Pg=22.2, Qg=9.25
% INFO    : Gen at bus 13950	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13950	: Pg=44.4, Qg=16.1 -> Pg=22.2, Qg=9.25
% INFO    : Gen at bus 13950	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13950	: Pg=44.4, Qg=16.1 -> Pg=22.2, Qg=9.25
% INFO    : Gen at bus 13950	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13950	: Pg=44.4, Qg=16.1 -> Pg=22.2, Qg=9.25
% INFO    : Gen at bus 13950	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13951	: Pg=44.1, Qg=27.3 -> Pg=23.55, Qg=6.3
% INFO    : Gen at bus 13951	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13953	: Pg=43.2, Qg=32.4 -> Pg=43.2, Qg=9.0
% INFO    : Gen at bus 13953	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13954	: Pg=9.5, Qg=6.77 -> Pg=9.5, Qg=1.05
% INFO    : Gen at bus 13954	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13954	: Pg=9.5, Qg=6.77 -> Pg=9.5, Qg=1.05
% INFO    : Gen at bus 13954	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13954	: Pg=9.5, Qg=6.77 -> Pg=9.5, Qg=1.05
% INFO    : Gen at bus 13954	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13955	: Pg=85.0, Qg=93.8 -> Pg=86.875, Qg=26.05
% INFO    : Gen at bus 13955	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13955	: Pg=85.0, Qg=93.8 -> Pg=86.875, Qg=26.05
% INFO    : Gen at bus 13955	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13955	: Pg=23.67, Qg=19.4 -> Pg=24.88, Qg=3.9
% INFO    : Gen at bus 13955	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13955	: Pg=23.67, Qg=19.4 -> Pg=24.88, Qg=3.9
% INFO    : Gen at bus 13955	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13955	: Pg=23.67, Qg=19.4 -> Pg=24.88, Qg=3.9
% INFO    : Gen at bus 13955	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13955	: Pg=27.15, Qg=24.3 -> Pg=27.0, Qg=5.5
% INFO    : Gen at bus 13955	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13955	: Pg=54.4, Qg=48.5 -> Pg=54.0, Qg=10.9
% INFO    : Gen at bus 13955	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13956	: Pg=15.0, Qg=24.3 -> Pg=27.0, Qg=5.5
% INFO    : Gen at bus 13956	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13956	: Pg=15.0, Qg=24.3 -> Pg=27.0, Qg=5.5
% INFO    : Gen at bus 13956	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13956	: Pg=24.38, Qg=39.4 -> Pg=43.875, Qg=8.85
% INFO    : Gen at bus 13956	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13956	: Pg=24.38, Qg=39.4 -> Pg=43.875, Qg=8.85
% INFO    : Gen at bus 13956	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13956	: Pg=140.55, Qg=236.84 -> Pg=373.0, Qg=46.9
% INFO    : Gen at bus 13956	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13957	: Pg=54.0, Qg=6.61 -> Pg=49.0, Qg=7.75
% INFO    : Gen at bus 13957	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13957	: Pg=40.0, Qg=6.61 -> Pg=32.0, Qg=5.75
% INFO    : Gen at bus 13957	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13957	: Pg=86.0, Qg=6.61 -> Pg=69.0, Qg=12.3
% INFO    : Gen at bus 13957	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13958	: Pg=18.0, Qg=13.5 -> Pg=18.0, Qg=3.75
% INFO    : Gen at bus 13958	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13958	: Pg=18.0, Qg=13.5 -> Pg=18.0, Qg=3.75
% INFO    : Gen at bus 13958	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13959	: Pg=36.0, Qg=27.0 -> Pg=36.0, Qg=7.5
% INFO    : Gen at bus 13959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13959	: Pg=36.0, Qg=27.0 -> Pg=36.0, Qg=7.5
% INFO    : Gen at bus 13959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13959	: Pg=36.0, Qg=27.0 -> Pg=36.0, Qg=7.5
% INFO    : Gen at bus 13959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13960	: Pg=34.7, Qg=21.5 -> Pg=18.85, Qg=4.95
% INFO    : Gen at bus 13960	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13961	: Pg=34.7, Qg=21.5 -> Pg=19.85, Qg=4.95
% INFO    : Gen at bus 13961	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13962	: Pg=7.4, Qg=4.23 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 13962	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13962	: Pg=7.4, Qg=4.23 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 13962	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13962	: Pg=7.4, Qg=4.23 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 13962	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13963	: Pg=7.12, Qg=5.9 -> Pg=7.735, Qg=1.2
% INFO    : Gen at bus 13963	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13963	: Pg=7.12, Qg=5.9 -> Pg=7.735, Qg=1.2
% INFO    : Gen at bus 13963	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13963	: Pg=7.12, Qg=5.9 -> Pg=7.735, Qg=1.2
% INFO    : Gen at bus 13963	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13964	: Pg=7.07, Qg=4.95 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 13964	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13964	: Pg=7.07, Qg=4.95 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 13964	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13965	: Pg=29.7, Qg=18.4 -> Pg=24.85, Qg=4.25
% INFO    : Gen at bus 13965	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13966	: Pg=28.8, Qg=13.9 -> Pg=14.9, Qg=2.15
% INFO    : Gen at bus 13966	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13966	: Pg=28.8, Qg=13.9 -> Pg=14.9, Qg=2.15
% INFO    : Gen at bus 13966	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13966	: Pg=28.8, Qg=13.9 -> Pg=14.9, Qg=2.15
% INFO    : Gen at bus 13966	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13966	: Pg=28.8, Qg=13.9 -> Pg=14.9, Qg=2.15
% INFO    : Gen at bus 13966	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13966	: Pg=28.8, Qg=13.9 -> Pg=14.9, Qg=2.15
% INFO    : Gen at bus 13966	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13966	: Pg=28.8, Qg=13.9 -> Pg=14.9, Qg=2.15
% INFO    : Gen at bus 13966	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13966	: Pg=28.8, Qg=13.9 -> Pg=14.9, Qg=2.15
% INFO    : Gen at bus 13966	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13966	: Pg=28.8, Qg=13.9 -> Pg=14.9, Qg=2.15
% INFO    : Gen at bus 13966	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13966	: Pg=73.0, Qg=35.4 -> Pg=44.0, Qg=5.55
% INFO    : Gen at bus 13966	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13968	: Pg=28.3, Qg=13.7 -> Pg=15.15, Qg=2.15
% INFO    : Gen at bus 13968	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13969	: Pg=28.0, Qg=17.4 -> Pg=17.5, Qg=4.05
% INFO    : Gen at bus 13969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13970	: Pg=27.4, Qg=15.3 -> Pg=19.59, Qg=3.1
% INFO    : Gen at bus 13970	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13970	: Pg=35.2, Qg=19.7 -> Pg=25.17, Qg=4.0
% INFO    : Gen at bus 13970	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13970	: Pg=35.2, Qg=19.7 -> Pg=25.17, Qg=4.0
% INFO    : Gen at bus 13970	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13971	: Pg=13.0, Qg=6.3 -> Pg=13.0, Qg=0.975
% INFO    : Gen at bus 13971	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13971	: Pg=13.0, Qg=6.3 -> Pg=13.0, Qg=0.975
% INFO    : Gen at bus 13971	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13972	: Pg=8.6, Qg=0.0 -> Pg=8.6, Qg=0.0
% INFO    : Gen at bus 13972	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13972	: Pg=8.6, Qg=0.0 -> Pg=8.6, Qg=0.0
% INFO    : Gen at bus 13972	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13972	: Pg=8.6, Qg=0.0 -> Pg=8.6, Qg=0.0
% INFO    : Gen at bus 13972	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13973	: Pg=8.5, Qg=2.8 -> Pg=8.5, Qg=0.0
% INFO    : Gen at bus 13973	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13973	: Pg=8.5, Qg=2.8 -> Pg=8.5, Qg=0.0
% INFO    : Gen at bus 13973	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13973	: Pg=8.5, Qg=2.8 -> Pg=8.5, Qg=0.0
% INFO    : Gen at bus 13973	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13974	: Pg=25.0, Qg=12.1 -> Pg=17.5, Qg=1.9
% INFO    : Gen at bus 13974	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13974	: Pg=25.0, Qg=12.1 -> Pg=17.5, Qg=1.9
% INFO    : Gen at bus 13974	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13974	: Pg=25.0, Qg=12.1 -> Pg=17.5, Qg=1.9
% INFO    : Gen at bus 13974	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13974	: Pg=25.0, Qg=12.1 -> Pg=17.5, Qg=1.9
% INFO    : Gen at bus 13974	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13975	: Pg=4.1, Qg=3.08 -> Pg=3.8, Qg=0.855
% INFO    : Gen at bus 13975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13975	: Pg=17.5, Qg=10.85 -> Pg=14.75, Qg=2.515
% INFO    : Gen at bus 13975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13975	: Pg=4.1, Qg=3.08 -> Pg=3.8, Qg=0.855
% INFO    : Gen at bus 13975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13975	: Pg=4.1, Qg=3.08 -> Pg=3.8, Qg=0.855
% INFO    : Gen at bus 13975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13975	: Pg=4.1, Qg=3.08 -> Pg=3.8, Qg=0.855
% INFO    : Gen at bus 13975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13975	: Pg=4.1, Qg=3.08 -> Pg=3.8, Qg=0.855
% INFO    : Gen at bus 13975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13975	: Pg=4.1, Qg=3.08 -> Pg=3.8, Qg=0.855
% INFO    : Gen at bus 13975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13975	: Pg=17.5, Qg=10.85 -> Pg=14.75, Qg=2.515
% INFO    : Gen at bus 13975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13975	: Pg=17.5, Qg=10.85 -> Pg=14.75, Qg=2.515
% INFO    : Gen at bus 13975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13975	: Pg=17.5, Qg=10.85 -> Pg=14.75, Qg=2.515
% INFO    : Gen at bus 13975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13976	: Pg=23.8, Qg=12.8 -> Pg=16.84, Qg=2.45
% INFO    : Gen at bus 13976	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13976	: Pg=23.8, Qg=12.8 -> Pg=16.84, Qg=2.45
% INFO    : Gen at bus 13976	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13977	: Pg=22.0, Qg=16.5 -> Pg=22.0, Qg=4.6
% INFO    : Gen at bus 13977	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13977	: Pg=21.55, Qg=16.5 -> Pg=21.5, Qg=4.6
% INFO    : Gen at bus 13977	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13977	: Pg=18.55, Qg=16.5 -> Pg=20.0, Qg=4.6
% INFO    : Gen at bus 13977	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13978	: Pg=20.27, Qg=16.2 -> Pg=20.65, Qg=4.5
% INFO    : Gen at bus 13978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13979	: Pg=7.7, Qg=-0.24 -> Pg=13.6, Qg=0.0
% INFO    : Gen at bus 13979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13979	: Pg=7.7, Qg=-0.24 -> Pg=13.6, Qg=0.0
% INFO    : Gen at bus 13979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13979	: Pg=7.7, Qg=-0.24 -> Pg=13.6, Qg=0.0
% INFO    : Gen at bus 13979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13979	: Pg=7.7, Qg=-0.24 -> Pg=13.6, Qg=0.0
% INFO    : Gen at bus 13979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13979	: Pg=15.75, Qg=-0.24 -> Pg=22.5, Qg=6.25
% INFO    : Gen at bus 13979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13980	: Pg=979.7, Qg=114.39 -> Pg=582.35, Qg=73.95
% INFO    : Gen at bus 13980	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13980	: Pg=979.7, Qg=114.39 -> Pg=582.35, Qg=73.95
% INFO    : Gen at bus 13980	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13981	: Pg=113.6, Qg=70.4 -> Pg=76.8, Qg=16.25
% INFO    : Gen at bus 13981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13981	: Pg=881.97, Qg=427.2 -> Pg=503.5, Qg=66.6
% INFO    : Gen at bus 13981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13981	: Pg=239.29, Qg=148.3 -> Pg=149.65, Qg=34.25
% INFO    : Gen at bus 13981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13981	: Pg=139.71, Qg=69.6 -> Pg=80.07, Qg=11.515
% INFO    : Gen at bus 13981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13981	: Pg=139.71, Qg=69.6 -> Pg=80.07, Qg=11.515
% INFO    : Gen at bus 13981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13981	: Pg=139.71, Qg=69.6 -> Pg=80.07, Qg=11.515
% INFO    : Gen at bus 13981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13981	: Pg=139.71, Qg=69.6 -> Pg=80.07, Qg=11.515
% INFO    : Gen at bus 13981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13981	: Pg=139.71, Qg=69.6 -> Pg=80.07, Qg=11.515
% INFO    : Gen at bus 13981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13981	: Pg=139.71, Qg=69.6 -> Pg=80.07, Qg=11.515
% INFO    : Gen at bus 13981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13981	: Pg=139.71, Qg=69.6 -> Pg=80.07, Qg=11.515
% INFO    : Gen at bus 13981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13982	: Pg=847.5, Qg=75.71 -> Pg=518.25, Qg=64.0
% INFO    : Gen at bus 13982	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13982	: Pg=847.5, Qg=75.71 -> Pg=518.25, Qg=64.0
% INFO    : Gen at bus 13982	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13983	: Pg=476.99, Qg=19.18 -> Pg=342.0, Qg=36.0
% INFO    : Gen at bus 13983	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13983	: Pg=476.99, Qg=19.18 -> Pg=342.0, Qg=36.0
% INFO    : Gen at bus 13983	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13983	: Pg=476.99, Qg=19.18 -> Pg=342.0, Qg=36.0
% INFO    : Gen at bus 13983	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13983	: Pg=476.99, Qg=19.18 -> Pg=342.0, Qg=36.0
% INFO    : Gen at bus 13983	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13983	: Pg=476.99, Qg=19.18 -> Pg=342.0, Qg=36.0
% INFO    : Gen at bus 13983	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13983	: Pg=476.99, Qg=19.18 -> Pg=342.0, Qg=36.0
% INFO    : Gen at bus 13983	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13984	: Pg=199.92, Qg=36.71 -> Pg=277.0, Qg=32.05
% INFO    : Gen at bus 13984	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13984	: Pg=302.49, Qg=36.71 -> Pg=277.0, Qg=32.05
% INFO    : Gen at bus 13984	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13985	: Pg=258.29, Qg=76.26 -> Pg=164.15, Qg=19.5
% INFO    : Gen at bus 13985	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13986	: Pg=65.95, Qg=98.96 -> Pg=148.75, Qg=49.45
% INFO    : Gen at bus 13986	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13986	: Pg=65.95, Qg=98.96 -> Pg=148.75, Qg=49.45
% INFO    : Gen at bus 13986	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13986	: Pg=65.95, Qg=98.96 -> Pg=148.75, Qg=49.45
% INFO    : Gen at bus 13986	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13987	: Pg=89.7, Qg=90.8 -> Pg=136.25, Qg=14.15
% INFO    : Gen at bus 13987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13987	: Pg=89.7, Qg=116.2 -> Pg=136.25, Qg=26.85
% INFO    : Gen at bus 13987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13987	: Pg=212.09, Qg=131.37 -> Pg=536.0, Qg=66.6
% INFO    : Gen at bus 13987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13988	: Pg=183.29, Qg=20.61 -> Pg=141.65, Qg=26.25
% INFO    : Gen at bus 13988	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13988	: Pg=183.29, Qg=20.61 -> Pg=141.65, Qg=26.25
% INFO    : Gen at bus 13988	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13988	: Pg=183.29, Qg=20.61 -> Pg=141.65, Qg=26.25
% INFO    : Gen at bus 13988	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13988	: Pg=396.19, Qg=20.61 -> Pg=223.1, Qg=29.9
% INFO    : Gen at bus 13988	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13989	: Pg=178.49, Qg=25.14 -> Pg=134.25, Qg=25.55
% INFO    : Gen at bus 13989	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13989	: Pg=178.49, Qg=25.14 -> Pg=134.25, Qg=25.55
% INFO    : Gen at bus 13989	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13989	: Pg=178.49, Qg=25.14 -> Pg=134.25, Qg=25.55
% INFO    : Gen at bus 13989	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13989	: Pg=178.49, Qg=25.14 -> Pg=134.25, Qg=25.55
% INFO    : Gen at bus 13989	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13989	: Pg=178.49, Qg=25.14 -> Pg=134.25, Qg=25.55
% INFO    : Gen at bus 13989	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13990	: Pg=171.1, Qg=106.0 -> Pg=134.05, Qg=24.5
% INFO    : Gen at bus 13990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13990	: Pg=171.1, Qg=106.0 -> Pg=133.55, Qg=24.5
% INFO    : Gen at bus 13990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13990	: Pg=171.1, Qg=106.0 -> Pg=133.55, Qg=24.5
% INFO    : Gen at bus 13990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13991	: Pg=170.0, Qg=105.4 -> Pg=130.0, Qg=24.35
% INFO    : Gen at bus 13991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13991	: Pg=178.49, Qg=110.6 -> Pg=134.25, Qg=25.55
% INFO    : Gen at bus 13991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13991	: Pg=178.49, Qg=110.6 -> Pg=134.25, Qg=25.55
% INFO    : Gen at bus 13991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13991	: Pg=178.49, Qg=110.6 -> Pg=134.25, Qg=25.55
% INFO    : Gen at bus 13991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13992	: Pg=20.32, Qg=12.6 -> Pg=14.635, Qg=2.915
% INFO    : Gen at bus 13992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13992	: Pg=112.5, Qg=54.5 -> Pg=86.75, Qg=8.5
% INFO    : Gen at bus 13992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13992	: Pg=112.5, Qg=54.5 -> Pg=86.75, Qg=8.5
% INFO    : Gen at bus 13992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13992	: Pg=23.8, Qg=14.7 -> Pg=16.84, Qg=3.4
% INFO    : Gen at bus 13992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13992	: Pg=23.8, Qg=14.7 -> Pg=16.84, Qg=3.4
% INFO    : Gen at bus 13992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13992	: Pg=23.8, Qg=14.7 -> Pg=16.84, Qg=3.4
% INFO    : Gen at bus 13992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13992	: Pg=23.8, Qg=14.7 -> Pg=16.84, Qg=3.4
% INFO    : Gen at bus 13992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13992	: Pg=239.29, Qg=148.3 -> Pg=202.15, Qg=34.25
% INFO    : Gen at bus 13992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13992	: Pg=20.32, Qg=12.6 -> Pg=14.635, Qg=2.915
% INFO    : Gen at bus 13992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13992	: Pg=20.32, Qg=12.6 -> Pg=14.635, Qg=2.915
% INFO    : Gen at bus 13992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13992	: Pg=20.32, Qg=12.6 -> Pg=14.635, Qg=2.915
% INFO    : Gen at bus 13992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13992	: Pg=20.32, Qg=12.6 -> Pg=14.635, Qg=2.915
% INFO    : Gen at bus 13992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13992	: Pg=20.32, Qg=12.6 -> Pg=14.635, Qg=2.915
% INFO    : Gen at bus 13992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13992	: Pg=20.32, Qg=12.6 -> Pg=14.635, Qg=2.915
% INFO    : Gen at bus 13992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13992	: Pg=20.32, Qg=12.6 -> Pg=14.635, Qg=2.915
% INFO    : Gen at bus 13992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13992	: Pg=185.19, Qg=114.8 -> Pg=139.6, Qg=26.55
% INFO    : Gen at bus 13992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13993	: Pg=66.0, Qg=21.7 -> Pg=65.5, Qg=0.0
% INFO    : Gen at bus 13993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13993	: Pg=66.0, Qg=21.7 -> Pg=65.5, Qg=0.0
% INFO    : Gen at bus 13993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13993	: Pg=150.1, Qg=38.74 -> Pg=144.06, Qg=0.0
% INFO    : Gen at bus 13993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13993	: Pg=150.1, Qg=38.74 -> Pg=144.06, Qg=0.0
% INFO    : Gen at bus 13993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13993	: Pg=115.3, Qg=37.9 -> Pg=110.15, Qg=0.0
% INFO    : Gen at bus 13993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13994	: Pg=129.6, Qg=62.8 -> Pg=103.8, Qg=9.8
% INFO    : Gen at bus 13994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13994	: Pg=129.6, Qg=62.8 -> Pg=103.8, Qg=9.8
% INFO    : Gen at bus 13994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13994	: Pg=129.6, Qg=62.8 -> Pg=103.8, Qg=9.8
% INFO    : Gen at bus 13994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13995	: Pg=186.99, Qg=32.12 -> Pg=130.75, Qg=14.15
% INFO    : Gen at bus 13995	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13995	: Pg=132.0, Qg=32.12 -> Pg=80.35, Qg=9.95
% INFO    : Gen at bus 13995	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13995	: Pg=132.0, Qg=32.12 -> Pg=80.35, Qg=9.95
% INFO    : Gen at bus 13995	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13995	: Pg=122.0, Qg=32.12 -> Pg=97.65, Qg=17.45
% INFO    : Gen at bus 13995	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13995	: Pg=122.0, Qg=32.12 -> Pg=97.65, Qg=17.45
% INFO    : Gen at bus 13995	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13995	: Pg=122.0, Qg=32.12 -> Pg=97.65, Qg=17.45
% INFO    : Gen at bus 13995	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13995	: Pg=122.0, Qg=32.12 -> Pg=97.65, Qg=17.45
% INFO    : Gen at bus 13995	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13996	: Pg=187.49, Qg=23.71 -> Pg=138.75, Qg=26.85
% INFO    : Gen at bus 13996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13996	: Pg=145.0, Qg=23.71 -> Pg=106.5, Qg=10.95
% INFO    : Gen at bus 13996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13996	: Pg=148.0, Qg=23.71 -> Pg=105.5, Qg=11.2
% INFO    : Gen at bus 13996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13996	: Pg=112.5, Qg=23.71 -> Pg=73.75, Qg=16.1
% INFO    : Gen at bus 13996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13996	: Pg=693.88, Qg=23.71 -> Pg=546.95, Qg=52.4
% INFO    : Gen at bus 13996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13996	: Pg=358.99, Qg=23.71 -> Pg=272.5, Qg=51.4
% INFO    : Gen at bus 13996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13996	: Pg=79.2, Qg=23.71 -> Pg=58.1, Qg=6.0
% INFO    : Gen at bus 13996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13996	: Pg=74.4, Qg=23.71 -> Pg=53.2, Qg=5.6
% INFO    : Gen at bus 13996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13998	: Pg=25.0, Qg=12.22 -> Pg=16.0, Qg=3.6
% INFO    : Gen at bus 13998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13998	: Pg=46.0, Qg=12.22 -> Pg=28.0, Qg=6.6
% INFO    : Gen at bus 13998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13998	: Pg=20.2, Qg=12.22 -> Pg=13.08, Qg=3.09
% INFO    : Gen at bus 13998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13998	: Pg=20.2, Qg=12.22 -> Pg=13.08, Qg=3.09
% INFO    : Gen at bus 13998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13998	: Pg=20.2, Qg=12.22 -> Pg=13.08, Qg=3.09
% INFO    : Gen at bus 13998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13998	: Pg=20.2, Qg=12.22 -> Pg=13.08, Qg=3.09
% INFO    : Gen at bus 13998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13998	: Pg=20.2, Qg=12.22 -> Pg=13.08, Qg=3.09
% INFO    : Gen at bus 13998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13999	: Pg=96.0, Qg=0.0 -> Pg=75.5, Qg=0.0
% INFO    : Gen at bus 13999	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13999	: Pg=101.0, Qg=0.0 -> Pg=78.0, Qg=0.0
% INFO    : Gen at bus 13999	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13999	: Pg=101.0, Qg=0.0 -> Pg=78.0, Qg=0.0
% INFO    : Gen at bus 13999	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 13999	: Pg=101.0, Qg=0.0 -> Pg=78.0, Qg=0.0
% INFO    : Gen at bus 13999	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14000	: Pg=27.5, Qg=48.4 -> Pg=62.5, Qg=7.55
% INFO    : Gen at bus 14000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14000	: Pg=80.95, Qg=178.1 -> Pg=156.25, Qg=49.45
% INFO    : Gen at bus 14000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14001	: Pg=27.5, Qg=15.4 -> Pg=17.325, Qg=3.1
% INFO    : Gen at bus 14001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14001	: Pg=36.1, Qg=22.4 -> Pg=20.55, Qg=5.2
% INFO    : Gen at bus 14001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14001	: Pg=14.24, Qg=8.0 -> Pg=8.105, Qg=1.63
% INFO    : Gen at bus 14001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14001	: Pg=14.24, Qg=8.0 -> Pg=8.105, Qg=1.63
% INFO    : Gen at bus 14001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14001	: Pg=14.24, Qg=8.0 -> Pg=8.105, Qg=1.63
% INFO    : Gen at bus 14001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14001	: Pg=14.24, Qg=8.0 -> Pg=8.105, Qg=1.63
% INFO    : Gen at bus 14001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14001	: Pg=14.24, Qg=8.0 -> Pg=8.105, Qg=1.63
% INFO    : Gen at bus 14001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14001	: Pg=14.24, Qg=8.0 -> Pg=8.105, Qg=1.63
% INFO    : Gen at bus 14001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14001	: Pg=14.24, Qg=8.0 -> Pg=8.105, Qg=1.63
% INFO    : Gen at bus 14001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14003	: Pg=62.63, Qg=44.6 -> Pg=66.05, Qg=6.95
% INFO    : Gen at bus 14003	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14003	: Pg=62.63, Qg=44.6 -> Pg=66.05, Qg=6.95
% INFO    : Gen at bus 14003	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14003	: Pg=62.63, Qg=44.6 -> Pg=66.05, Qg=6.95
% INFO    : Gen at bus 14003	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14003	: Pg=62.63, Qg=44.6 -> Pg=66.05, Qg=6.95
% INFO    : Gen at bus 14003	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14005	: Pg=84.5, Qg=16.25 -> Pg=65.25, Qg=12.1
% INFO    : Gen at bus 14005	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14005	: Pg=84.5, Qg=16.25 -> Pg=65.25, Qg=12.1
% INFO    : Gen at bus 14005	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14005	: Pg=84.5, Qg=16.25 -> Pg=65.25, Qg=12.1
% INFO    : Gen at bus 14005	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14005	: Pg=84.5, Qg=16.25 -> Pg=65.25, Qg=12.1
% INFO    : Gen at bus 14005	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14005	: Pg=171.1, Qg=16.25 -> Pg=133.05, Qg=24.5
% INFO    : Gen at bus 14005	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14006	: Pg=14.47, Qg=9.05 -> Pg=16.35, Qg=1.415
% INFO    : Gen at bus 14006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14006	: Pg=14.47, Qg=9.05 -> Pg=16.35, Qg=1.415
% INFO    : Gen at bus 14006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14006	: Pg=14.47, Qg=9.05 -> Pg=16.35, Qg=1.415
% INFO    : Gen at bus 14006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14006	: Pg=14.47, Qg=9.05 -> Pg=16.35, Qg=1.415
% INFO    : Gen at bus 14006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14007	: Pg=71.1, Qg=44.1 -> Pg=45.55, Qg=10.2
% INFO    : Gen at bus 14007	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14008	: Pg=71.1, Qg=44.1 -> Pg=45.55, Qg=10.2
% INFO    : Gen at bus 14008	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14009	: Pg=71.1, Qg=44.1 -> Pg=45.55, Qg=10.2
% INFO    : Gen at bus 14009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14010	: Pg=69.9, Qg=31.98 -> Pg=42.95, Qg=5.3
% INFO    : Gen at bus 14010	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14010	: Pg=69.9, Qg=31.98 -> Pg=42.95, Qg=5.3
% INFO    : Gen at bus 14010	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14011	: Pg=185.19, Qg=22.43 -> Pg=125.1, Qg=16.6
% INFO    : Gen at bus 14011	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14011	: Pg=69.0, Qg=22.43 -> Pg=52.0, Qg=6.15
% INFO    : Gen at bus 14011	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14012	: Pg=16.37, Qg=9.93 -> Pg=8.905, Qg=2.24
% INFO    : Gen at bus 14012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14012	: Pg=16.37, Qg=9.93 -> Pg=8.905, Qg=2.24
% INFO    : Gen at bus 14012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14012	: Pg=16.37, Qg=9.93 -> Pg=8.905, Qg=2.24
% INFO    : Gen at bus 14012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14012	: Pg=16.37, Qg=9.93 -> Pg=8.905, Qg=2.24
% INFO    : Gen at bus 14012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14012	: Pg=34.0, Qg=21.1 -> Pg=18.5, Qg=4.9
% INFO    : Gen at bus 14012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14012	: Pg=34.0, Qg=21.1 -> Pg=18.5, Qg=4.9
% INFO    : Gen at bus 14012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14013	: Pg=62.0, Qg=30.0 -> Pg=36.0, Qg=4.65
% INFO    : Gen at bus 14013	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14013	: Pg=62.0, Qg=30.0 -> Pg=36.0, Qg=4.65
% INFO    : Gen at bus 14013	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14014	: Pg=39.1, Qg=14.17 -> Pg=46.25, Qg=8.2
% INFO    : Gen at bus 14014	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14014	: Pg=39.1, Qg=14.17 -> Pg=46.25, Qg=8.2
% INFO    : Gen at bus 14014	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14014	: Pg=39.1, Qg=14.17 -> Pg=46.25, Qg=8.2
% INFO    : Gen at bus 14014	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14014	: Pg=39.1, Qg=14.17 -> Pg=46.25, Qg=8.2
% INFO    : Gen at bus 14014	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14014	: Pg=39.1, Qg=14.17 -> Pg=46.25, Qg=8.2
% INFO    : Gen at bus 14014	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14014	: Pg=39.1, Qg=14.17 -> Pg=46.25, Qg=8.2
% INFO    : Gen at bus 14014	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14014	: Pg=39.1, Qg=14.17 -> Pg=46.25, Qg=8.2
% INFO    : Gen at bus 14014	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14015	: Pg=57.4, Qg=35.6 -> Pg=41.2, Qg=8.25
% INFO    : Gen at bus 14015	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14015	: Pg=57.4, Qg=35.6 -> Pg=41.2, Qg=8.25
% INFO    : Gen at bus 14015	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14016	: Pg=57.4, Qg=35.6 -> Pg=28.7, Qg=8.25
% INFO    : Gen at bus 14016	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14016	: Pg=57.4, Qg=35.6 -> Pg=28.7, Qg=8.25
% INFO    : Gen at bus 14016	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14017	: Pg=57.4, Qg=35.6 -> Pg=31.2, Qg=8.25
% INFO    : Gen at bus 14017	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14017	: Pg=57.4, Qg=35.6 -> Pg=31.2, Qg=8.25
% INFO    : Gen at bus 14017	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14017	: Pg=57.4, Qg=35.6 -> Pg=31.2, Qg=8.25
% INFO    : Gen at bus 14017	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14017	: Pg=57.4, Qg=35.6 -> Pg=31.2, Qg=8.25
% INFO    : Gen at bus 14017	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14018	: Pg=26.43, Qg=35.3 -> Pg=41.0, Qg=8.15
% INFO    : Gen at bus 14018	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14018	: Pg=26.43, Qg=35.3 -> Pg=41.0, Qg=8.15
% INFO    : Gen at bus 14018	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14018	: Pg=26.43, Qg=35.3 -> Pg=41.0, Qg=8.15
% INFO    : Gen at bus 14018	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14018	: Pg=26.43, Qg=35.3 -> Pg=41.0, Qg=8.15
% INFO    : Gen at bus 14018	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14018	: Pg=26.43, Qg=35.3 -> Pg=41.0, Qg=8.15
% INFO    : Gen at bus 14018	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14020	: Pg=46.8, Qg=16.01 -> Pg=39.4, Qg=3.55
% INFO    : Gen at bus 14020	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14020	: Pg=46.8, Qg=16.01 -> Pg=39.4, Qg=3.55
% INFO    : Gen at bus 14020	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14020	: Pg=46.8, Qg=16.01 -> Pg=39.4, Qg=3.55
% INFO    : Gen at bus 14020	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14020	: Pg=46.8, Qg=16.01 -> Pg=39.4, Qg=3.55
% INFO    : Gen at bus 14020	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14020	: Pg=46.8, Qg=16.01 -> Pg=39.4, Qg=3.55
% INFO    : Gen at bus 14020	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14020	: Pg=46.8, Qg=16.01 -> Pg=39.4, Qg=3.55
% INFO    : Gen at bus 14020	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14021	: Pg=45.0, Qg=27.9 -> Pg=37.5, Qg=6.45
% INFO    : Gen at bus 14021	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14021	: Pg=45.0, Qg=27.9 -> Pg=37.5, Qg=6.45
% INFO    : Gen at bus 14021	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14022	: Pg=5.1, Qg=21.3 -> Pg=24.0, Qg=3.3
% INFO    : Gen at bus 14022	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14022	: Pg=5.1, Qg=21.3 -> Pg=24.0, Qg=3.3
% INFO    : Gen at bus 14022	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14023	: Pg=14.5, Qg=7.0 -> Pg=8.0, Qg=1.075
% INFO    : Gen at bus 14023	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14023	: Pg=14.5, Qg=7.0 -> Pg=8.0, Qg=1.075
% INFO    : Gen at bus 14023	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14024	: Pg=3.21, Qg=5.67 -> Pg=4.4, Qg=1.7
% INFO    : Gen at bus 14024	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14024	: Pg=2.56, Qg=5.67 -> Pg=4.4, Qg=1.7
% INFO    : Gen at bus 14024	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14024	: Pg=2.17, Qg=5.67 -> Pg=4.4, Qg=1.7
% INFO    : Gen at bus 14024	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14024	: Pg=2.17, Qg=5.67 -> Pg=4.4, Qg=1.7
% INFO    : Gen at bus 14024	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14025	: Pg=18.36, Qg=20.3 -> Pg=16.0, Qg=5.65
% INFO    : Gen at bus 14025	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14027	: Pg=4.0, Qg=3.0 -> Pg=2.25, Qg=0.835
% INFO    : Gen at bus 14027	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14027	: Pg=4.0, Qg=3.0 -> Pg=2.25, Qg=0.835
% INFO    : Gen at bus 14027	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14027	: Pg=4.0, Qg=3.0 -> Pg=2.25, Qg=0.835
% INFO    : Gen at bus 14027	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14027	: Pg=4.0, Qg=3.0 -> Pg=2.25, Qg=0.835
% INFO    : Gen at bus 14027	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14027	: Pg=4.0, Qg=3.0 -> Pg=2.25, Qg=0.835
% INFO    : Gen at bus 14027	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14027	: Pg=4.0, Qg=3.0 -> Pg=2.25, Qg=0.835
% INFO    : Gen at bus 14027	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14028	: Pg=1.14, Qg=2.62 -> Pg=3.2, Qg=0.41
% INFO    : Gen at bus 14028	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14028	: Pg=1.14, Qg=2.62 -> Pg=3.2, Qg=0.41
% INFO    : Gen at bus 14028	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14028	: Pg=1.14, Qg=2.62 -> Pg=3.2, Qg=0.41
% INFO    : Gen at bus 14028	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14028	: Pg=1.14, Qg=2.62 -> Pg=3.2, Qg=0.41
% INFO    : Gen at bus 14028	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14030	: Pg=6.83, Qg=5.13 -> Pg=3.665, Qg=1.43
% INFO    : Gen at bus 14030	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14030	: Pg=6.83, Qg=5.13 -> Pg=3.665, Qg=1.43
% INFO    : Gen at bus 14030	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14030	: Pg=6.83, Qg=5.13 -> Pg=3.665, Qg=1.43
% INFO    : Gen at bus 14030	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14031	: Pg=20.0, Qg=15.0 -> Pg=19.2, Qg=4.15
% INFO    : Gen at bus 14031	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14031	: Pg=20.0, Qg=15.0 -> Pg=19.2, Qg=4.15
% INFO    : Gen at bus 14031	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14032	: Pg=20.0, Qg=15.0 -> Pg=11.0, Qg=4.15
% INFO    : Gen at bus 14032	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14032	: Pg=20.0, Qg=15.0 -> Pg=11.0, Qg=4.15
% INFO    : Gen at bus 14032	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14032	: Pg=20.0, Qg=15.0 -> Pg=11.0, Qg=4.15
% INFO    : Gen at bus 14032	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14033	: Pg=532.56, Qg=20.09 -> Pg=900.0, Qg=98.15
% INFO    : Gen at bus 14033	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14034	: Pg=632.56, Qg=124.89 -> Pg=950.0, Qg=98.15
% INFO    : Gen at bus 14034	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14034	: Pg=320.44, Qg=124.89 -> Pg=558.15, Qg=61.65
% INFO    : Gen at bus 14034	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14034	: Pg=320.44, Qg=124.89 -> Pg=558.15, Qg=61.65
% INFO    : Gen at bus 14034	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14035	: Pg=430.44, Qg=-31.36 -> Pg=613.15, Qg=61.65
% INFO    : Gen at bus 14035	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14035	: Pg=390.44, Qg=-31.36 -> Pg=593.15, Qg=61.65
% INFO    : Gen at bus 14035	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14036	: Pg=392.13, Qg=5.68 -> Pg=529.5, Qg=0.0
% INFO    : Gen at bus 14036	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14036	: Pg=392.13, Qg=5.68 -> Pg=529.5, Qg=0.0
% INFO    : Gen at bus 14036	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14036	: Pg=392.13, Qg=5.68 -> Pg=529.5, Qg=0.0
% INFO    : Gen at bus 14036	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14037	: Pg=392.13, Qg=-35.72 -> Pg=529.5, Qg=51.65
% INFO    : Gen at bus 14037	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14037	: Pg=392.13, Qg=-35.72 -> Pg=529.5, Qg=51.65
% INFO    : Gen at bus 14037	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14038	: Pg=234.43, Qg=-75.86 -> Pg=398.0, Qg=43.5
% INFO    : Gen at bus 14038	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14038	: Pg=234.43, Qg=-75.86 -> Pg=398.0, Qg=43.5
% INFO    : Gen at bus 14038	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14039	: Pg=379.32, Qg=32.91 -> Pg=411.0, Qg=39.4
% INFO    : Gen at bus 14039	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14039	: Pg=387.76, Qg=32.91 -> Pg=417.6, Qg=43.05
% INFO    : Gen at bus 14039	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14039	: Pg=387.76, Qg=32.91 -> Pg=417.6, Qg=43.05
% INFO    : Gen at bus 14039	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14040	: Pg=105.95, Qg=38.67 -> Pg=168.75, Qg=49.45
% INFO    : Gen at bus 14040	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14040	: Pg=105.95, Qg=38.67 -> Pg=168.75, Qg=49.45
% INFO    : Gen at bus 14040	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14040	: Pg=105.95, Qg=38.67 -> Pg=168.75, Qg=49.45
% INFO    : Gen at bus 14040	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14042	: Pg=134.34, Qg=59.09 -> Pg=151.0, Qg=24.65
% INFO    : Gen at bus 14042	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14042	: Pg=134.34, Qg=59.09 -> Pg=151.0, Qg=24.65
% INFO    : Gen at bus 14042	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14043	: Pg=53.82, Qg=43.92 -> Pg=101.25, Qg=31.8
% INFO    : Gen at bus 14043	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14043	: Pg=53.82, Qg=43.92 -> Pg=101.25, Qg=31.8
% INFO    : Gen at bus 14043	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14043	: Pg=53.82, Qg=43.92 -> Pg=101.25, Qg=31.8
% INFO    : Gen at bus 14043	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14043	: Pg=53.82, Qg=43.92 -> Pg=101.25, Qg=31.8
% INFO    : Gen at bus 14043	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14043	: Pg=282.41, Qg=43.92 -> Pg=382.75, Qg=70.95
% INFO    : Gen at bus 14043	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14044	: Pg=100.5, Qg=44.3 -> Pg=50.25, Qg=0.0
% INFO    : Gen at bus 14044	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14045	: Pg=100.0, Qg=0.5 -> Pg=54.3, Qg=0.0
% INFO    : Gen at bus 14045	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14045	: Pg=164.0, Qg=0.5 -> Pg=86.3, Qg=0.0
% INFO    : Gen at bus 14045	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14047	: Pg=66.17, Qg=48.51 -> Pg=75.25, Qg=12.4
% INFO    : Gen at bus 14047	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14047	: Pg=66.17, Qg=48.51 -> Pg=75.25, Qg=12.4
% INFO    : Gen at bus 14047	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14047	: Pg=66.17, Qg=48.51 -> Pg=75.25, Qg=12.4
% INFO    : Gen at bus 14047	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14047	: Pg=66.17, Qg=48.51 -> Pg=75.25, Qg=12.4
% INFO    : Gen at bus 14047	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14047	: Pg=66.17, Qg=48.51 -> Pg=75.25, Qg=12.4
% INFO    : Gen at bus 14047	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14047	: Pg=66.17, Qg=48.51 -> Pg=75.25, Qg=12.4
% INFO    : Gen at bus 14047	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14049	: Pg=58.19, Qg=-21.32 -> Pg=97.44, Qg=26.3
% INFO    : Gen at bus 14049	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14049	: Pg=25.88, Qg=-21.32 -> Pg=46.575, Qg=9.45
% INFO    : Gen at bus 14049	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14049	: Pg=25.88, Qg=-21.32 -> Pg=46.575, Qg=9.45
% INFO    : Gen at bus 14049	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14050	: Pg=21.73, Qg=42.7 -> Pg=44.45, Qg=9.85
% INFO    : Gen at bus 14050	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14051	: Pg=3.3, Qg=26.1 -> Pg=34.65, Qg=0.0
% INFO    : Gen at bus 14051	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14052	: Pg=26.48, Qg=26.89 -> Pg=41.95, Qg=8.45
% INFO    : Gen at bus 14052	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14052	: Pg=26.48, Qg=26.89 -> Pg=41.95, Qg=8.45
% INFO    : Gen at bus 14052	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14052	: Pg=26.48, Qg=26.89 -> Pg=41.95, Qg=8.45
% INFO    : Gen at bus 14052	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14052	: Pg=26.48, Qg=26.89 -> Pg=41.95, Qg=8.45
% INFO    : Gen at bus 14052	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14052	: Pg=26.48, Qg=26.89 -> Pg=41.95, Qg=8.45
% INFO    : Gen at bus 14052	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14052	: Pg=26.48, Qg=26.89 -> Pg=41.95, Qg=8.45
% INFO    : Gen at bus 14052	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14053	: Pg=67.74, Qg=74.77 -> Pg=113.425, Qg=30.6
% INFO    : Gen at bus 14053	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14053	: Pg=18.75, Qg=30.3 -> Pg=33.75, Qg=6.8
% INFO    : Gen at bus 14053	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14058	: Pg=2.64, Qg=12.4 -> Pg=13.75, Qg=1.95
% INFO    : Gen at bus 14058	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14058	: Pg=2.64, Qg=12.4 -> Pg=13.75, Qg=1.95
% INFO    : Gen at bus 14058	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14058	: Pg=2.64, Qg=12.4 -> Pg=13.75, Qg=1.95
% INFO    : Gen at bus 14058	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14058	: Pg=2.64, Qg=12.4 -> Pg=13.75, Qg=1.95
% INFO    : Gen at bus 14058	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14060	: Pg=3.53, Qg=10.2 -> Pg=12.0, Qg=1.6
% INFO    : Gen at bus 14060	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 14060	: Pg=3.53, Qg=10.2 -> Pg=12.0, Qg=1.6
% INFO    : Gen at bus 14060	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20401	: Pg=532.56, Qg=101.34 -> Pg=900.0, Qg=98.15
% INFO    : Gen at bus 20401	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20401	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20402	: Pg=292.32, Qg=-67.77 -> Pg=458.95, Qg=50.45
% INFO    : Gen at bus 20402	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20402	: Pg=266.73, Qg=-67.77 -> Pg=458.95, Qg=50.45
% INFO    : Gen at bus 20402	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20402	: Pg=291.32, Qg=-67.77 -> Pg=458.95, Qg=50.45
% INFO    : Gen at bus 20402	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20402	: Pg=314.92, Qg=-67.77 -> Pg=448.95, Qg=50.45
% INFO    : Gen at bus 20402	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20402	: Pg=314.92, Qg=-67.77 -> Pg=448.95, Qg=50.45
% INFO    : Gen at bus 20402	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20403	: Pg=20.13, Qg=40.2 -> Pg=44.975, Qg=8.45
% INFO    : Gen at bus 20403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20403	: Pg=20.13, Qg=40.2 -> Pg=44.975, Qg=8.45
% INFO    : Gen at bus 20403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20403	: Pg=311.42, Qg=261.5 -> Pg=425.0, Qg=40.75
% INFO    : Gen at bus 20403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20404	: Pg=539.98, Qg=-20.04 -> Pg=400.0, Qg=40.75
% INFO    : Gen at bus 20404	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20404	: Pg=539.98, Qg=-20.04 -> Pg=400.0, Qg=40.75
% INFO    : Gen at bus 20404	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20405	: Pg=112.5, Qg=54.5 -> Pg=83.75, Qg=8.5
% INFO    : Gen at bus 20405	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20405	: Pg=530.98, Qg=79.37 -> Pg=415.5, Qg=40.1
% INFO    : Gen at bus 20405	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20405	: Pg=530.98, Qg=79.37 -> Pg=380.5, Qg=40.1
% INFO    : Gen at bus 20405	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20406	: Pg=670.88, Qg=-36.3 -> Pg=447.95, Qg=96.1
% INFO    : Gen at bus 20406	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20406	: Pg=670.88, Qg=-36.3 -> Pg=445.45, Qg=96.1
% INFO    : Gen at bus 20406	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20406	: Pg=281.59, Qg=-36.3 -> Pg=205.8, Qg=40.3
% INFO    : Gen at bus 20406	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20406	: Pg=523.29, Qg=-36.3 -> Pg=374.15, Qg=74.95
% INFO    : Gen at bus 20406	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20407	: Pg=12.21, Qg=39.34 -> Pg=49.1, Qg=12.65
% INFO    : Gen at bus 20407	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20407	: Pg=12.21, Qg=39.34 -> Pg=49.1, Qg=12.65
% INFO    : Gen at bus 20407	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20407	: Pg=126.64, Qg=39.34 -> Pg=192.6, Qg=20.0
% INFO    : Gen at bus 20407	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20407	: Pg=126.64, Qg=39.34 -> Pg=192.6, Qg=20.0
% INFO    : Gen at bus 20407	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20408	: Pg=217.29, Qg=40.91 -> Pg=190.15, Qg=36.8
% INFO    : Gen at bus 20408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20408	: Pg=217.29, Qg=40.91 -> Pg=190.15, Qg=36.8
% INFO    : Gen at bus 20408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20408	: Pg=217.29, Qg=40.91 -> Pg=190.15, Qg=36.8
% INFO    : Gen at bus 20408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20408	: Pg=217.29, Qg=40.91 -> Pg=190.15, Qg=36.8
% INFO    : Gen at bus 20408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20408	: Pg=217.29, Qg=40.91 -> Pg=190.15, Qg=36.8
% INFO    : Gen at bus 20408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20408	: Pg=217.29, Qg=40.91 -> Pg=190.15, Qg=36.8
% INFO    : Gen at bus 20408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20409	: Pg=115.09, Qg=92.41 -> Pg=156.6, Qg=29.1
% INFO    : Gen at bus 20409	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20409	: Pg=115.09, Qg=92.41 -> Pg=156.6, Qg=29.1
% INFO    : Gen at bus 20409	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20409	: Pg=115.33, Qg=92.41 -> Pg=161.5, Qg=30.5
% INFO    : Gen at bus 20409	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20410	: Pg=140.27, Qg=96.7 -> Pg=100.65, Qg=15.05
% INFO    : Gen at bus 20410	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20411	: Pg=126.89, Qg=118.0 -> Pg=145.2, Qg=27.25
% INFO    : Gen at bus 20411	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20411	: Pg=20.1, Qg=23.2 -> Pg=28.75, Qg=5.35
% INFO    : Gen at bus 20411	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20411	: Pg=151.09, Qg=256.0 -> Pg=281.55, Qg=59.15
% INFO    : Gen at bus 20411	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20412	: Pg=92.65, Qg=112.7 -> Pg=136.95, Qg=26.05
% INFO    : Gen at bus 20412	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20412	: Pg=92.65, Qg=112.7 -> Pg=136.95, Qg=26.05
% INFO    : Gen at bus 20412	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20412	: Pg=212.99, Qg=103.2 -> Pg=119.0, Qg=16.1
% INFO    : Gen at bus 20412	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20413	: Pg=174.0, Qg=-15.92 -> Pg=122.0, Qg=24.9
% INFO    : Gen at bus 20413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20413	: Pg=174.0, Qg=-15.92 -> Pg=122.0, Qg=24.9
% INFO    : Gen at bus 20413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20413	: Pg=174.0, Qg=-15.92 -> Pg=122.0, Qg=24.9
% INFO    : Gen at bus 20413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20413	: Pg=174.0, Qg=-15.92 -> Pg=122.0, Qg=24.9
% INFO    : Gen at bus 20413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20413	: Pg=267.99, Qg=-15.92 -> Pg=169.0, Qg=38.4
% INFO    : Gen at bus 20413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20413	: Pg=267.99, Qg=-15.92 -> Pg=169.0, Qg=38.4
% INFO    : Gen at bus 20413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=100.0, Qg=62.0 -> Pg=77.0, Qg=14.35
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=28.05, Qg=17.65 -> Pg=16.95, Qg=4.15
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=28.05, Qg=17.65 -> Pg=16.95, Qg=4.15
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=462.99, Qg=286.9 -> Pg=341.5, Qg=66.3
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=100.0, Qg=62.0 -> Pg=77.0, Qg=14.35
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=83.0, Qg=62.3 -> Pg=64.0, Qg=17.3
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=83.0, Qg=62.3 -> Pg=64.0, Qg=17.3
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=161.0, Qg=99.8 -> Pg=125.5, Qg=23.05
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=28.05, Qg=17.65 -> Pg=16.95, Qg=4.15
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=28.05, Qg=17.65 -> Pg=16.95, Qg=4.15
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=28.05, Qg=17.65 -> Pg=16.95, Qg=4.15
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=28.05, Qg=17.65 -> Pg=16.95, Qg=4.15
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20415	: Pg=44.17, Qg=34.55 -> Pg=103.3, Qg=23.85
% INFO    : Gen at bus 20415	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20415	: Pg=44.17, Qg=34.55 -> Pg=103.3, Qg=23.85
% INFO    : Gen at bus 20415	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20415	: Pg=44.17, Qg=34.55 -> Pg=103.3, Qg=23.85
% INFO    : Gen at bus 20415	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20415	: Pg=88.09, Qg=34.55 -> Pg=201.5, Qg=46.25
% INFO    : Gen at bus 20415	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20416	: Pg=161.0, Qg=78.0 -> Pg=105.5, Qg=12.15
% INFO    : Gen at bus 20416	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20417	: Pg=152.5, Qg=-23.87 -> Pg=101.25, Qg=31.8
% INFO    : Gen at bus 20417	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20417	: Pg=152.5, Qg=-23.87 -> Pg=101.25, Qg=31.8
% INFO    : Gen at bus 20417	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20417	: Pg=215.39, Qg=-23.87 -> Pg=140.2, Qg=44.9
% INFO    : Gen at bus 20417	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20417	: Pg=579.68, Qg=-23.87 -> Pg=439.85, Qg=83.05
% INFO    : Gen at bus 20417	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=31.16, Qg=18.1 -> Pg=28.5, Qg=0.0
% INFO    : Gen at bus 20418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=2.4, Qg=16.58 -> Pg=16.4, Qg=3.22
% INFO    : Gen at bus 20418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=30.4, Qg=16.58 -> Pg=16.4, Qg=3.22
% INFO    : Gen at bus 20418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=30.4, Qg=16.58 -> Pg=16.4, Qg=3.22
% INFO    : Gen at bus 20418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=30.4, Qg=16.58 -> Pg=16.4, Qg=3.22
% INFO    : Gen at bus 20418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=30.4, Qg=16.58 -> Pg=16.4, Qg=3.22
% INFO    : Gen at bus 20418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=36.4, Qg=24.8 -> Pg=22.0, Qg=5.75
% INFO    : Gen at bus 20418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=32.0, Qg=19.8 -> Pg=17.0, Qg=4.55
% INFO    : Gen at bus 20418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20419	: Pg=150.0, Qg=74.99 -> Pg=107.5, Qg=21.5
% INFO    : Gen at bus 20419	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20419	: Pg=150.0, Qg=74.99 -> Pg=107.5, Qg=21.5
% INFO    : Gen at bus 20419	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20419	: Pg=150.0, Qg=74.99 -> Pg=104.25, Qg=21.5
% INFO    : Gen at bus 20419	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20419	: Pg=150.0, Qg=74.99 -> Pg=104.25, Qg=21.5
% INFO    : Gen at bus 20419	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20421	: Pg=129.0, Qg=62.5 -> Pg=99.5, Qg=9.75
% INFO    : Gen at bus 20421	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20421	: Pg=129.0, Qg=62.5 -> Pg=99.5, Qg=9.75
% INFO    : Gen at bus 20421	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20422	: Pg=88.54, Qg=78.3 -> Pg=86.315, Qg=16.15
% INFO    : Gen at bus 20422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20422	: Pg=112.21, Qg=90.3 -> Pg=88.61, Qg=23.9
% INFO    : Gen at bus 20422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20422	: Pg=128.0, Qg=90.7 -> Pg=88.96, Qg=24.0
% INFO    : Gen at bus 20422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20422	: Pg=128.0, Qg=90.7 -> Pg=88.96, Qg=24.0
% INFO    : Gen at bus 20422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20423	: Pg=48.13, Qg=13.59 -> Pg=85.05, Qg=9.45
% INFO    : Gen at bus 20423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20423	: Pg=48.13, Qg=13.59 -> Pg=85.05, Qg=9.45
% INFO    : Gen at bus 20423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20423	: Pg=48.13, Qg=13.59 -> Pg=85.05, Qg=9.45
% INFO    : Gen at bus 20423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20423	: Pg=48.13, Qg=13.59 -> Pg=85.05, Qg=9.45
% INFO    : Gen at bus 20423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20425	: Pg=125.0, Qg=11.85 -> Pg=91.0, Qg=17.9
% INFO    : Gen at bus 20425	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20425	: Pg=123.2, Qg=11.85 -> Pg=86.6, Qg=17.65
% INFO    : Gen at bus 20425	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20425	: Pg=112.5, Qg=11.85 -> Pg=81.25, Qg=16.1
% INFO    : Gen at bus 20425	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20425	: Pg=112.5, Qg=11.85 -> Pg=81.25, Qg=16.1
% INFO    : Gen at bus 20425	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20425	: Pg=112.5, Qg=11.85 -> Pg=83.75, Qg=23.45
% INFO    : Gen at bus 20425	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20425	: Pg=191.99, Qg=11.85 -> Pg=146.0, Qg=40.0
% INFO    : Gen at bus 20425	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20425	: Pg=386.99, Qg=11.85 -> Pg=258.5, Qg=55.4
% INFO    : Gen at bus 20425	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20428	: Pg=47.6, Qg=3.73 -> Pg=74.35, Qg=14.85
% INFO    : Gen at bus 20428	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20428	: Pg=141.64, Qg=3.73 -> Pg=200.1, Qg=0.0
% INFO    : Gen at bus 20428	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20429	: Pg=103.5, Qg=45.6 -> Pg=52.45, Qg=0.0
% INFO    : Gen at bus 20429	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20430	: Pg=37.36, Qg=96.9 -> Pg=101.8, Qg=15.1
% INFO    : Gen at bus 20430	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20430	: Pg=0.6, Qg=97.5 -> Pg=100.95, Qg=15.2
% INFO    : Gen at bus 20430	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20430	: Pg=20.0, Qg=44.1 -> Pg=60.0, Qg=0.0
% INFO    : Gen at bus 20430	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20430	: Pg=0.3, Qg=43.7 -> Pg=49.65, Qg=0.0
% INFO    : Gen at bus 20430	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20431	: Pg=99.0, Qg=43.7 -> Pg=50.25, Qg=0.0
% INFO    : Gen at bus 20431	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20432	: Pg=98.7, Qg=43.5 -> Pg=49.7, Qg=0.0
% INFO    : Gen at bus 20432	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20433	: Pg=10.34, Qg=0.0 -> Pg=52.3, Qg=0.0
% INFO    : Gen at bus 20433	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20434	: Pg=90.0, Qg=0.0 -> Pg=49.5, Qg=0.0
% INFO    : Gen at bus 20434	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20435	: Pg=30.0, Qg=9.9 -> Pg=17.5, Qg=0.0
% INFO    : Gen at bus 20435	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20435	: Pg=14.8, Qg=7.53 -> Pg=8.635, Qg=1.3
% INFO    : Gen at bus 20435	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20435	: Pg=14.8, Qg=7.53 -> Pg=8.635, Qg=1.3
% INFO    : Gen at bus 20435	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20435	: Pg=14.8, Qg=7.53 -> Pg=8.635, Qg=1.3
% INFO    : Gen at bus 20435	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20435	: Pg=14.8, Qg=7.53 -> Pg=8.635, Qg=1.3
% INFO    : Gen at bus 20435	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20435	: Pg=14.8, Qg=7.53 -> Pg=8.635, Qg=1.3
% INFO    : Gen at bus 20435	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20435	: Pg=14.8, Qg=7.53 -> Pg=8.635, Qg=1.3
% INFO    : Gen at bus 20435	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20436	: Pg=86.5, Qg=23.88 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20436	: Pg=86.5, Qg=23.88 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20436	: Pg=86.5, Qg=23.88 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20436	: Pg=86.5, Qg=23.88 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20436	: Pg=86.5, Qg=23.88 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20436	: Pg=86.5, Qg=23.88 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20436	: Pg=86.5, Qg=23.88 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20436	: Pg=86.5, Qg=23.88 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20437	: Pg=85.0, Qg=52.7 -> Pg=65.0, Qg=12.2
% INFO    : Gen at bus 20437	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20437	: Pg=85.0, Qg=52.7 -> Pg=65.0, Qg=12.2
% INFO    : Gen at bus 20437	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20437	: Pg=85.0, Qg=52.7 -> Pg=65.0, Qg=12.2
% INFO    : Gen at bus 20437	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20437	: Pg=85.0, Qg=52.7 -> Pg=65.0, Qg=12.2
% INFO    : Gen at bus 20437	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20438	: Pg=67.0, Qg=41.5 -> Pg=43.5, Qg=9.6
% INFO    : Gen at bus 20438	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20438	: Pg=67.0, Qg=41.5 -> Pg=43.5, Qg=9.6
% INFO    : Gen at bus 20438	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20438	: Pg=67.0, Qg=41.5 -> Pg=43.5, Qg=9.6
% INFO    : Gen at bus 20438	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20438	: Pg=67.0, Qg=41.5 -> Pg=43.5, Qg=9.6
% INFO    : Gen at bus 20438	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20438	: Pg=67.0, Qg=41.5 -> Pg=43.5, Qg=9.6
% INFO    : Gen at bus 20438	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20438	: Pg=67.0, Qg=41.5 -> Pg=43.5, Qg=9.6
% INFO    : Gen at bus 20438	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20439	: Pg=61.0, Qg=40.3 -> Pg=44.0, Qg=10.0
% INFO    : Gen at bus 20439	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20440	: Pg=50.0, Qg=37.5 -> Pg=36.9, Qg=10.4
% INFO    : Gen at bus 20440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20440	: Pg=50.0, Qg=37.5 -> Pg=36.9, Qg=10.4
% INFO    : Gen at bus 20440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20440	: Pg=61.0, Qg=45.8 -> Pg=45.02, Qg=12.75
% INFO    : Gen at bus 20440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20440	: Pg=61.0, Qg=45.8 -> Pg=45.02, Qg=12.75
% INFO    : Gen at bus 20440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20440	: Pg=61.0, Qg=45.8 -> Pg=45.02, Qg=12.75
% INFO    : Gen at bus 20440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20442	: Pg=59.0, Qg=36.6 -> Pg=34.5, Qg=8.45
% INFO    : Gen at bus 20442	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20442	: Pg=59.0, Qg=36.6 -> Pg=34.5, Qg=8.45
% INFO    : Gen at bus 20442	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20442	: Pg=59.0, Qg=36.6 -> Pg=34.5, Qg=8.45
% INFO    : Gen at bus 20442	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20442	: Pg=59.0, Qg=36.6 -> Pg=34.5, Qg=8.45
% INFO    : Gen at bus 20442	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20444	: Pg=10.13, Qg=16.8 -> Pg=30.5, Qg=0.0
% INFO    : Gen at bus 20444	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20444	: Pg=63.2, Qg=20.8 -> Pg=36.6, Qg=0.0
% INFO    : Gen at bus 20444	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20444	: Pg=2.22, Qg=20.4 -> Pg=32.0, Qg=0.0
% INFO    : Gen at bus 20444	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20445	: Pg=50.0, Qg=31.0 -> Pg=42.0, Qg=7.15
% INFO    : Gen at bus 20445	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20445	: Pg=113.6, Qg=70.4 -> Pg=83.8, Qg=16.25
% INFO    : Gen at bus 20445	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20445	: Pg=69.0, Qg=42.8 -> Pg=50.5, Qg=9.9
% INFO    : Gen at bus 20445	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20445	: Pg=69.0, Qg=42.8 -> Pg=50.5, Qg=9.9
% INFO    : Gen at bus 20445	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20445	: Pg=16.56, Qg=28.5 -> Pg=31.28, Qg=6.6
% INFO    : Gen at bus 20445	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20445	: Pg=16.56, Qg=28.5 -> Pg=31.28, Qg=6.6
% INFO    : Gen at bus 20445	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20446	: Pg=41.8, Qg=20.2 -> Pg=21.9, Qg=3.15
% INFO    : Gen at bus 20446	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20446	: Pg=41.8, Qg=20.2 -> Pg=21.9, Qg=3.15
% INFO    : Gen at bus 20446	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20448	: Pg=41.4, Qg=25.7 -> Pg=29.2, Qg=5.95
% INFO    : Gen at bus 20448	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20448	: Pg=41.4, Qg=25.7 -> Pg=29.2, Qg=5.95
% INFO    : Gen at bus 20448	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20448	: Pg=85.9, Qg=53.2 -> Pg=60.95, Qg=12.3
% INFO    : Gen at bus 20448	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20449	: Pg=15.08, Qg=19.82 -> Pg=27.135, Qg=8.4
% INFO    : Gen at bus 20449	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20449	: Pg=25.88, Qg=19.82 -> Pg=46.575, Qg=14.4
% INFO    : Gen at bus 20449	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20449	: Pg=12.6, Qg=19.82 -> Pg=23.8, Qg=7.3
% INFO    : Gen at bus 20449	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20450	: Pg=60.9, Qg=37.7 -> Pg=44.45, Qg=8.7
% INFO    : Gen at bus 20450	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20450	: Pg=33.0, Qg=20.5 -> Pg=23.0, Qg=4.75
% INFO    : Gen at bus 20450	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20451	: Pg=30.8, Qg=23.1 -> Pg=17.9, Qg=6.4
% INFO    : Gen at bus 20451	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20452	: Pg=25.0, Qg=15.5 -> Pg=17.25, Qg=3.6
% INFO    : Gen at bus 20452	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20453	: Pg=12.05, Qg=7.45 -> Pg=6.775, Qg=1.725
% INFO    : Gen at bus 20453	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20453	: Pg=12.05, Qg=7.45 -> Pg=6.775, Qg=1.725
% INFO    : Gen at bus 20453	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20454	: Pg=5.85, Qg=0.0 -> Pg=3.3, Qg=0.0
% INFO    : Gen at bus 20454	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20454	: Pg=5.85, Qg=0.0 -> Pg=3.3, Qg=0.0
% INFO    : Gen at bus 20454	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20454	: Pg=5.85, Qg=0.0 -> Pg=3.3, Qg=0.0
% INFO    : Gen at bus 20454	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20454	: Pg=5.85, Qg=0.0 -> Pg=3.3, Qg=0.0
% INFO    : Gen at bus 20454	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20455	: Pg=2.28, Qg=6.9 -> Pg=6.55, Qg=1.6
% INFO    : Gen at bus 20455	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20455	: Pg=2.28, Qg=6.9 -> Pg=6.55, Qg=1.6
% INFO    : Gen at bus 20455	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20457	: Pg=21.6, Qg=5.35 -> Pg=11.3, Qg=4.5
% INFO    : Gen at bus 20457	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20457	: Pg=21.6, Qg=5.35 -> Pg=11.3, Qg=4.5
% INFO    : Gen at bus 20457	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20457	: Pg=21.6, Qg=5.35 -> Pg=11.3, Qg=4.5
% INFO    : Gen at bus 20457	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=616.18, Qg=1.71 -> Pg=459.1, Qg=79.515
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=87.1, Qg=1.71 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=87.1, Qg=1.71 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=87.1, Qg=1.71 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=87.1, Qg=1.71 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=87.1, Qg=1.71 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=87.1, Qg=1.71 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=87.1, Qg=1.71 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=87.1, Qg=1.71 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=616.18, Qg=1.71 -> Pg=459.1, Qg=79.515
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=616.18, Qg=1.71 -> Pg=459.1, Qg=79.515
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=409.99, Qg=1.71 -> Pg=217.5, Qg=30.95
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=379.99, Qg=1.71 -> Pg=210.0, Qg=54.4
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=87.1, Qg=1.71 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=87.1, Qg=1.71 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=87.1, Qg=1.71 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=87.1, Qg=1.71 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20459	: Pg=1133.3, Qg=263.31 -> Pg=1093.15, Qg=85.55
% INFO    : Gen at bus 20459	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20459	: Pg=1152.0, Qg=263.31 -> Pg=1079.0, Qg=86.95
% INFO    : Gen at bus 20459	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20460	: Pg=655.27, Qg=363.93 -> Pg=405.9, Qg=169.15
% INFO    : Gen at bus 20460	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20461	: Pg=697.48, Qg=193.34 -> Pg=426.25, Qg=52.65
% INFO    : Gen at bus 20461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20461	: Pg=697.48, Qg=193.34 -> Pg=426.25, Qg=52.65
% INFO    : Gen at bus 20461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20461	: Pg=85.3, Qg=52.9 -> Pg=48.65, Qg=12.25
% INFO    : Gen at bus 20461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20461	: Pg=85.3, Qg=52.9 -> Pg=48.65, Qg=12.25
% INFO    : Gen at bus 20461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20461	: Pg=85.3, Qg=52.9 -> Pg=48.65, Qg=12.25
% INFO    : Gen at bus 20461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20462	: Pg=248.26, Qg=27.16 -> Pg=284.9, Qg=47.25
% INFO    : Gen at bus 20462	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20462	: Pg=248.26, Qg=27.16 -> Pg=284.9, Qg=47.25
% INFO    : Gen at bus 20462	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20462	: Pg=248.26, Qg=27.16 -> Pg=284.9, Qg=47.25
% INFO    : Gen at bus 20462	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20462	: Pg=248.26, Qg=27.16 -> Pg=284.9, Qg=47.25
% INFO    : Gen at bus 20462	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20462	: Pg=248.26, Qg=27.16 -> Pg=284.9, Qg=47.25
% INFO    : Gen at bus 20462	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20462	: Pg=248.26, Qg=27.16 -> Pg=284.9, Qg=47.25
% INFO    : Gen at bus 20462	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20463	: Pg=67.33, Qg=219.4 -> Pg=176.25, Qg=60.95
% INFO    : Gen at bus 20463	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20463	: Pg=275.03, Qg=212.0 -> Pg=141.3, Qg=58.9
% INFO    : Gen at bus 20463	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20463	: Pg=358.09, Qg=268.6 -> Pg=246.55, Qg=74.6
% INFO    : Gen at bus 20463	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20464	: Pg=712.54, Qg=141.71 -> Pg=633.4, Qg=119.2
% INFO    : Gen at bus 20464	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20464	: Pg=265.19, Qg=141.71 -> Pg=182.6, Qg=38.0
% INFO    : Gen at bus 20464	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20464	: Pg=378.79, Qg=141.71 -> Pg=239.4, Qg=93.8
% INFO    : Gen at bus 20464	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20465	: Pg=147.0, Qg=73.13 -> Pg=118.5, Qg=21.05
% INFO    : Gen at bus 20465	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20465	: Pg=147.0, Qg=73.13 -> Pg=118.5, Qg=21.05
% INFO    : Gen at bus 20465	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20465	: Pg=147.0, Qg=73.13 -> Pg=118.5, Qg=21.05
% INFO    : Gen at bus 20465	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20465	: Pg=244.99, Qg=73.13 -> Pg=207.5, Qg=35.05
% INFO    : Gen at bus 20465	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20465	: Pg=244.99, Qg=73.13 -> Pg=207.5, Qg=35.05
% INFO    : Gen at bus 20465	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20465	: Pg=244.99, Qg=73.13 -> Pg=207.5, Qg=35.05
% INFO    : Gen at bus 20465	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=33.6, Qg=19.14 -> Pg=19.3, Qg=4.8
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.71, Qg=14.6 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.71, Qg=14.6 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.71, Qg=14.6 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.71, Qg=14.6 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=33.6, Qg=19.14 -> Pg=19.3, Qg=4.8
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=33.6, Qg=19.14 -> Pg=19.3, Qg=4.8
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=33.6, Qg=19.14 -> Pg=19.3, Qg=4.8
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.71, Qg=14.6 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.71, Qg=14.6 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.71, Qg=14.6 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.71, Qg=14.6 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.71, Qg=14.6 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20467	: Pg=188.69, Qg=74.84 -> Pg=151.85, Qg=27.0
% INFO    : Gen at bus 20467	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20467	: Pg=188.69, Qg=74.84 -> Pg=151.85, Qg=27.0
% INFO    : Gen at bus 20467	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20467	: Pg=213.39, Qg=74.84 -> Pg=166.7, Qg=30.6
% INFO    : Gen at bus 20467	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20467	: Pg=188.69, Qg=74.84 -> Pg=139.35, Qg=27.0
% INFO    : Gen at bus 20467	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20467	: Pg=188.69, Qg=74.84 -> Pg=139.35, Qg=27.0
% INFO    : Gen at bus 20467	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20468	: Pg=117.88, Qg=154.9 -> Pg=131.5, Qg=35.8
% INFO    : Gen at bus 20468	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20468	: Pg=99.26, Qg=105.4 -> Pg=132.5, Qg=24.35
% INFO    : Gen at bus 20468	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20468	: Pg=99.26, Qg=105.4 -> Pg=132.5, Qg=24.35
% INFO    : Gen at bus 20468	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20468	: Pg=99.26, Qg=105.4 -> Pg=132.5, Qg=24.35
% INFO    : Gen at bus 20468	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20469	: Pg=170.0, Qg=39.45 -> Pg=143.0, Qg=24.35
% INFO    : Gen at bus 20469	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20469	: Pg=170.0, Qg=39.45 -> Pg=143.0, Qg=24.35
% INFO    : Gen at bus 20469	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20469	: Pg=170.0, Qg=39.45 -> Pg=143.0, Qg=24.35
% INFO    : Gen at bus 20469	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20469	: Pg=170.0, Qg=39.45 -> Pg=143.0, Qg=24.35
% INFO    : Gen at bus 20469	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=41.8, Qg=20.2 -> Pg=22.9, Qg=3.15
% INFO    : Gen at bus 20470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=41.8, Qg=20.2 -> Pg=22.9, Qg=3.15
% INFO    : Gen at bus 20470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=26.7, Qg=14.7 -> Pg=15.015, Qg=2.9
% INFO    : Gen at bus 20470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=26.7, Qg=14.7 -> Pg=15.015, Qg=2.9
% INFO    : Gen at bus 20470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=26.7, Qg=14.7 -> Pg=15.015, Qg=2.9
% INFO    : Gen at bus 20470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=26.7, Qg=14.7 -> Pg=15.015, Qg=2.9
% INFO    : Gen at bus 20470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=21.59, Qg=14.7 -> Pg=15.015, Qg=2.9
% INFO    : Gen at bus 20470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=18.16, Qg=14.7 -> Pg=15.015, Qg=2.9
% INFO    : Gen at bus 20470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20471	: Pg=156.3, Qg=91.76 -> Pg=113.15, Qg=22.4
% INFO    : Gen at bus 20471	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20471	: Pg=156.3, Qg=91.76 -> Pg=113.15, Qg=22.4
% INFO    : Gen at bus 20471	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20472	: Pg=154.7, Qg=95.9 -> Pg=127.35, Qg=22.15
% INFO    : Gen at bus 20472	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20473	: Pg=73.41, Qg=43.03 -> Pg=103.0, Qg=19.5
% INFO    : Gen at bus 20473	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20473	: Pg=73.41, Qg=43.03 -> Pg=103.0, Qg=19.5
% INFO    : Gen at bus 20473	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20473	: Pg=68.41, Qg=43.03 -> Pg=100.5, Qg=19.5
% INFO    : Gen at bus 20473	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20473	: Pg=68.41, Qg=43.03 -> Pg=100.5, Qg=19.5
% INFO    : Gen at bus 20473	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20473	: Pg=326.52, Qg=43.03 -> Pg=376.25, Qg=99.2
% INFO    : Gen at bus 20473	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20473	: Pg=581.84, Qg=43.03 -> Pg=384.9, Qg=101.65
% INFO    : Gen at bus 20473	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20475	: Pg=57.05, Qg=25.9 -> Pg=84.095, Qg=22.7
% INFO    : Gen at bus 20475	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20476	: Pg=120.0, Qg=58.1 -> Pg=73.0, Qg=9.05
% INFO    : Gen at bus 20476	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20476	: Pg=120.0, Qg=90.0 -> Pg=68.5, Qg=25.0
% INFO    : Gen at bus 20476	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20476	: Pg=283.47, Qg=259.4 -> Pg=346.75, Qg=40.45
% INFO    : Gen at bus 20476	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20477	: Pg=86.56, Qg=82.3 -> Pg=103.9, Qg=19.0
% INFO    : Gen at bus 20477	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20477	: Pg=106.3, Qg=65.9 -> Pg=83.15, Qg=15.25
% INFO    : Gen at bus 20477	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20477	: Pg=106.3, Qg=65.9 -> Pg=83.15, Qg=15.25
% INFO    : Gen at bus 20477	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20479	: Pg=89.4, Qg=55.4 -> Pg=69.7, Qg=12.8
% INFO    : Gen at bus 20479	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20479	: Pg=89.4, Qg=55.4 -> Pg=69.7, Qg=12.8
% INFO    : Gen at bus 20479	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20479	: Pg=89.4, Qg=55.4 -> Pg=69.7, Qg=12.8
% INFO    : Gen at bus 20479	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20479	: Pg=89.4, Qg=55.4 -> Pg=69.7, Qg=12.8
% INFO    : Gen at bus 20479	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20480	: Pg=815.38, Qg=112.44 -> Pg=485.2, Qg=61.55
% INFO    : Gen at bus 20480	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20480	: Pg=85.3, Qg=52.9 -> Pg=48.65, Qg=12.25
% INFO    : Gen at bus 20480	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20480	: Pg=85.3, Qg=52.9 -> Pg=48.65, Qg=12.25
% INFO    : Gen at bus 20480	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20480	: Pg=85.3, Qg=52.9 -> Pg=48.65, Qg=12.25
% INFO    : Gen at bus 20480	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20481	: Pg=47.13, Qg=57.1 -> Pg=65.0, Qg=14.4
% INFO    : Gen at bus 20481	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20481	: Pg=47.13, Qg=57.1 -> Pg=65.0, Qg=14.4
% INFO    : Gen at bus 20481	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20481	: Pg=47.13, Qg=57.1 -> Pg=65.0, Qg=14.4
% INFO    : Gen at bus 20481	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20481	: Pg=47.13, Qg=57.1 -> Pg=65.0, Qg=14.4
% INFO    : Gen at bus 20481	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20483	: Pg=8.4, Qg=3.49 -> Pg=12.0, Qg=1.86
% INFO    : Gen at bus 20483	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20483	: Pg=8.4, Qg=3.49 -> Pg=12.0, Qg=1.86
% INFO    : Gen at bus 20483	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20483	: Pg=8.4, Qg=3.49 -> Pg=12.0, Qg=1.86
% INFO    : Gen at bus 20483	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20483	: Pg=8.4, Qg=3.49 -> Pg=12.0, Qg=1.86
% INFO    : Gen at bus 20483	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20483	: Pg=8.4, Qg=3.49 -> Pg=12.0, Qg=1.86
% INFO    : Gen at bus 20483	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20485	: Pg=75.0, Qg=45.5 -> Pg=50.625, Qg=10.25
% INFO    : Gen at bus 20485	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20485	: Pg=75.0, Qg=45.5 -> Pg=50.625, Qg=10.25
% INFO    : Gen at bus 20485	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20487	: Pg=69.0, Qg=27.3 -> Pg=34.95, Qg=0.0
% INFO    : Gen at bus 20487	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20489	: Pg=4.4, Qg=9.93 -> Pg=10.0, Qg=2.305
% INFO    : Gen at bus 20489	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20489	: Pg=4.4, Qg=9.93 -> Pg=10.0, Qg=2.305
% INFO    : Gen at bus 20489	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20489	: Pg=4.4, Qg=9.93 -> Pg=10.0, Qg=2.305
% INFO    : Gen at bus 20489	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20489	: Pg=4.4, Qg=9.93 -> Pg=10.0, Qg=2.305
% INFO    : Gen at bus 20489	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20490	: Pg=16.0, Qg=9.93 -> Pg=11.31, Qg=2.305
% INFO    : Gen at bus 20490	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20490	: Pg=16.0, Qg=9.93 -> Pg=11.31, Qg=2.305
% INFO    : Gen at bus 20490	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20490	: Pg=16.0, Qg=9.93 -> Pg=11.31, Qg=2.305
% INFO    : Gen at bus 20490	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20490	: Pg=16.0, Qg=9.93 -> Pg=11.31, Qg=2.305
% INFO    : Gen at bus 20490	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20490	: Pg=21.2, Qg=13.1 -> Pg=14.6, Qg=3.0
% INFO    : Gen at bus 20490	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20490	: Pg=21.2, Qg=13.1 -> Pg=14.6, Qg=3.0
% INFO    : Gen at bus 20490	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20490	: Pg=23.4, Qg=14.5 -> Pg=15.7, Qg=3.35
% INFO    : Gen at bus 20490	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20493	: Pg=21.52, Qg=37.5 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 20493	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=60.0, Qg=37.2 -> Pg=36.0, Qg=8.6
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=60.0, Qg=37.2 -> Pg=36.0, Qg=8.6
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=29.49, Qg=37.2 -> Pg=36.0, Qg=8.6
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=28.29, Qg=37.2 -> Pg=36.0, Qg=8.6
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=28.29, Qg=37.2 -> Pg=36.0, Qg=8.6
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=28.29, Qg=37.2 -> Pg=36.0, Qg=8.6
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=46.98, Qg=38.3 -> Pg=62.0, Qg=6.0
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=105.0, Qg=45.72 -> Pg=58.5, Qg=15.05
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=105.0, Qg=45.72 -> Pg=58.5, Qg=15.05
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20496	: Pg=55.0, Qg=26.6 -> Pg=40.0, Qg=4.15
% INFO    : Gen at bus 20496	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20497	: Pg=0.9, Qg=20.9 -> Pg=26.85, Qg=0.0
% INFO    : Gen at bus 20497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20498	: Pg=9.44, Qg=6.5 -> Pg=6.07, Qg=1.68
% INFO    : Gen at bus 20498	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20498	: Pg=9.44, Qg=6.5 -> Pg=6.07, Qg=1.68
% INFO    : Gen at bus 20498	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20498	: Pg=9.44, Qg=6.5 -> Pg=6.07, Qg=1.68
% INFO    : Gen at bus 20498	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20498	: Pg=9.44, Qg=6.5 -> Pg=6.07, Qg=1.68
% INFO    : Gen at bus 20498	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20498	: Pg=9.44, Qg=6.5 -> Pg=6.07, Qg=1.68
% INFO    : Gen at bus 20498	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20500	: Pg=80.0, Qg=45.68 -> Pg=60.0, Qg=11.45
% INFO    : Gen at bus 20500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20500	: Pg=80.0, Qg=45.68 -> Pg=60.0, Qg=11.45
% INFO    : Gen at bus 20500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20500	: Pg=80.0, Qg=45.68 -> Pg=60.0, Qg=11.45
% INFO    : Gen at bus 20500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20500	: Pg=44.0, Qg=27.3 -> Pg=32.0, Qg=6.3
% INFO    : Gen at bus 20500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20500	: Pg=44.0, Qg=27.3 -> Pg=32.0, Qg=6.3
% INFO    : Gen at bus 20500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20500	: Pg=47.0, Qg=29.1 -> Pg=33.5, Qg=6.7
% INFO    : Gen at bus 20500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20502	: Pg=29.46, Qg=13.64 -> Pg=35.4, Qg=6.1
% INFO    : Gen at bus 20502	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20502	: Pg=27.86, Qg=13.64 -> Pg=34.6, Qg=6.1
% INFO    : Gen at bus 20502	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20502	: Pg=26.27, Qg=13.64 -> Pg=34.05, Qg=6.15
% INFO    : Gen at bus 20502	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20502	: Pg=25.46, Qg=13.64 -> Pg=33.4, Qg=6.1
% INFO    : Gen at bus 20502	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20504	: Pg=39.5, Qg=24.5 -> Pg=24.75, Qg=5.65
% INFO    : Gen at bus 20504	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20505	: Pg=39.1, Qg=24.2 -> Pg=27.05, Qg=5.6
% INFO    : Gen at bus 20505	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20505	: Pg=39.1, Qg=24.2 -> Pg=27.05, Qg=5.6
% INFO    : Gen at bus 20505	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20505	: Pg=83.5, Qg=51.7 -> Pg=66.75, Qg=11.95
% INFO    : Gen at bus 20505	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20506	: Pg=10.95, Qg=23.6 -> Pg=24.0, Qg=5.45
% INFO    : Gen at bus 20506	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20507	: Pg=18.0, Qg=11.15 -> Pg=12.87, Qg=2.575
% INFO    : Gen at bus 20507	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20507	: Pg=18.0, Qg=11.15 -> Pg=12.87, Qg=2.575
% INFO    : Gen at bus 20507	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20509	: Pg=7.14, Qg=7.87 -> Pg=5.25, Qg=2.185
% INFO    : Gen at bus 20509	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20509	: Pg=7.14, Qg=7.87 -> Pg=5.25, Qg=2.185
% INFO    : Gen at bus 20509	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20509	: Pg=7.14, Qg=7.87 -> Pg=5.25, Qg=2.185
% INFO    : Gen at bus 20509	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20510	: Pg=20.64, Qg=6.2 -> Pg=22.25, Qg=0.0
% INFO    : Gen at bus 20510	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20512	: Pg=5.7, Qg=21.0 -> Pg=16.5, Qg=5.85
% INFO    : Gen at bus 20512	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20513	: Pg=6.3, Qg=2.84 -> Pg=4.255, Qg=0.915
% INFO    : Gen at bus 20513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20513	: Pg=6.3, Qg=2.84 -> Pg=4.255, Qg=0.915
% INFO    : Gen at bus 20513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20513	: Pg=6.3, Qg=2.84 -> Pg=4.255, Qg=0.915
% INFO    : Gen at bus 20513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20513	: Pg=6.3, Qg=2.84 -> Pg=4.255, Qg=0.915
% INFO    : Gen at bus 20513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20513	: Pg=21.3, Qg=2.84 -> Pg=13.15, Qg=3.05
% INFO    : Gen at bus 20513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20514	: Pg=19.6, Qg=15.5 -> Pg=22.0, Qg=3.6
% INFO    : Gen at bus 20514	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20514	: Pg=19.6, Qg=15.5 -> Pg=22.0, Qg=3.6
% INFO    : Gen at bus 20514	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20515	: Pg=5.6, Qg=7.9 -> Pg=14.5, Qg=0.0
% INFO    : Gen at bus 20515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20516	: Pg=10.0, Qg=11.6 -> Pg=17.0, Qg=1.8
% INFO    : Gen at bus 20516	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20517	: Pg=7.97, Qg=5.17 -> Pg=4.685, Qg=1.25
% INFO    : Gen at bus 20517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20517	: Pg=7.97, Qg=5.17 -> Pg=4.685, Qg=1.25
% INFO    : Gen at bus 20517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20517	: Pg=7.97, Qg=5.17 -> Pg=4.685, Qg=1.25
% INFO    : Gen at bus 20517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20518	: Pg=4.02, Qg=0.61 -> Pg=4.34, Qg=0.42
% INFO    : Gen at bus 20518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20518	: Pg=4.02, Qg=0.61 -> Pg=4.34, Qg=0.42
% INFO    : Gen at bus 20518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20518	: Pg=4.02, Qg=0.61 -> Pg=4.34, Qg=0.42
% INFO    : Gen at bus 20518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20518	: Pg=4.02, Qg=0.61 -> Pg=4.34, Qg=0.42
% INFO    : Gen at bus 20518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20518	: Pg=4.02, Qg=0.61 -> Pg=4.34, Qg=0.42
% INFO    : Gen at bus 20518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20520	: Pg=4.29, Qg=7.15 -> Pg=7.75, Qg=1.65
% INFO    : Gen at bus 20520	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20520	: Pg=4.29, Qg=7.15 -> Pg=7.75, Qg=1.65
% INFO    : Gen at bus 20520	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20522	: Pg=5.57, Qg=10.9 -> Pg=13.8, Qg=1.7
% INFO    : Gen at bus 20522	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20523	: Pg=3.19, Qg=2.39 -> Pg=2.4, Qg=0.665
% INFO    : Gen at bus 20523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20523	: Pg=3.19, Qg=2.39 -> Pg=2.4, Qg=0.665
% INFO    : Gen at bus 20523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20523	: Pg=3.19, Qg=2.39 -> Pg=2.4, Qg=0.665
% INFO    : Gen at bus 20523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20523	: Pg=3.19, Qg=2.39 -> Pg=2.4, Qg=0.665
% INFO    : Gen at bus 20523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20523	: Pg=3.19, Qg=2.39 -> Pg=2.4, Qg=0.665
% INFO    : Gen at bus 20523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20523	: Pg=3.19, Qg=2.39 -> Pg=2.4, Qg=0.665
% INFO    : Gen at bus 20523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20523	: Pg=3.19, Qg=2.39 -> Pg=2.4, Qg=0.665
% INFO    : Gen at bus 20523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20524	: Pg=22.0, Qg=13.6 -> Pg=18.5, Qg=3.15
% INFO    : Gen at bus 20524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20524	: Pg=29.3, Qg=18.2 -> Pg=23.65, Qg=4.2
% INFO    : Gen at bus 20524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20527	: Pg=0.17, Qg=2.2 -> Pg=3.35, Qg=0.0
% INFO    : Gen at bus 20527	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20527	: Pg=0.17, Qg=2.2 -> Pg=3.35, Qg=0.0
% INFO    : Gen at bus 20527	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20527	: Pg=0.17, Qg=2.2 -> Pg=3.35, Qg=0.0
% INFO    : Gen at bus 20527	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20528	: Pg=5.5, Qg=15.0 -> Pg=12.5, Qg=4.15
% INFO    : Gen at bus 20528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20529	: Pg=6.5, Qg=4.39 -> Pg=13.0, Qg=1.5
% INFO    : Gen at bus 20529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20529	: Pg=6.5, Qg=4.39 -> Pg=13.0, Qg=1.5
% INFO    : Gen at bus 20529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20529	: Pg=6.5, Qg=4.39 -> Pg=13.0, Qg=1.5
% INFO    : Gen at bus 20529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20530	: Pg=8.5, Qg=12.4 -> Pg=14.0, Qg=2.85
% INFO    : Gen at bus 20530	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20532	: Pg=1311.6, Qg=416.46 -> Pg=722.3, Qg=0.0
% INFO    : Gen at bus 20532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20533	: Pg=911.34, Qg=-37.13 -> Pg=1000.0, Qg=98.15
% INFO    : Gen at bus 20533	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20533	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20534	: Pg=925.2, Qg=448.1 -> Pg=517.6, Qg=69.85
% INFO    : Gen at bus 20534	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20535	: Pg=28.7, Qg=21.5 -> Pg=23.35, Qg=5.95
% INFO    : Gen at bus 20535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20535	: Pg=660.58, Qg=210.47 -> Pg=395.3, Qg=49.85
% INFO    : Gen at bus 20535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20536	: Pg=441.28, Qg=167.79 -> Pg=537.5, Qg=49.05
% INFO    : Gen at bus 20536	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20536	: Pg=440.41, Qg=167.79 -> Pg=520.1, Qg=88.1
% INFO    : Gen at bus 20536	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20536	: Pg=440.41, Qg=167.79 -> Pg=520.1, Qg=88.1
% INFO    : Gen at bus 20536	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20537	: Pg=610.18, Qg=-39.21 -> Pg=455.1, Qg=46.05
% INFO    : Gen at bus 20537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20537	: Pg=610.18, Qg=-39.21 -> Pg=455.1, Qg=46.05
% INFO    : Gen at bus 20537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20537	: Pg=610.18, Qg=-39.21 -> Pg=455.1, Qg=46.05
% INFO    : Gen at bus 20537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20537	: Pg=610.18, Qg=-39.21 -> Pg=455.1, Qg=46.05
% INFO    : Gen at bus 20537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=135.0, Qg=83.7 -> Pg=87.5, Qg=19.35
% INFO    : Gen at bus 20538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=135.0, Qg=83.7 -> Pg=87.5, Qg=19.35
% INFO    : Gen at bus 20538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=135.0, Qg=83.7 -> Pg=87.5, Qg=19.35
% INFO    : Gen at bus 20538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=87.0, Qg=53.92 -> Pg=56.1, Qg=12.46
% INFO    : Gen at bus 20538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=87.0, Qg=53.92 -> Pg=56.1, Qg=12.46
% INFO    : Gen at bus 20538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=87.0, Qg=53.92 -> Pg=56.1, Qg=12.46
% INFO    : Gen at bus 20538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=87.0, Qg=53.92 -> Pg=56.1, Qg=12.46
% INFO    : Gen at bus 20538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=87.0, Qg=53.92 -> Pg=56.1, Qg=12.46
% INFO    : Gen at bus 20538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20540	: Pg=255.99, Qg=192.0 -> Pg=163.0, Qg=53.35
% INFO    : Gen at bus 20540	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20541	: Pg=219.59, Qg=60.05 -> Pg=139.8, Qg=45.75
% INFO    : Gen at bus 20541	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20541	: Pg=219.59, Qg=60.05 -> Pg=139.8, Qg=45.75
% INFO    : Gen at bus 20541	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20541	: Pg=237.49, Qg=60.05 -> Pg=148.75, Qg=49.45
% INFO    : Gen at bus 20541	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20541	: Pg=237.49, Qg=60.05 -> Pg=148.75, Qg=49.45
% INFO    : Gen at bus 20541	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20541	: Pg=615.18, Qg=60.05 -> Pg=482.6, Qg=88.1
% INFO    : Gen at bus 20541	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20542	: Pg=217.29, Qg=4.14 -> Pg=198.65, Qg=36.8
% INFO    : Gen at bus 20542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20542	: Pg=217.29, Qg=4.14 -> Pg=198.65, Qg=36.8
% INFO    : Gen at bus 20542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20542	: Pg=217.29, Qg=4.14 -> Pg=198.65, Qg=36.8
% INFO    : Gen at bus 20542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20542	: Pg=217.29, Qg=4.14 -> Pg=198.65, Qg=36.8
% INFO    : Gen at bus 20542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20542	: Pg=217.29, Qg=4.14 -> Pg=198.65, Qg=36.8
% INFO    : Gen at bus 20542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20543	: Pg=127.94, Qg=47.58 -> Pg=218.55, Qg=45.4
% INFO    : Gen at bus 20543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20543	: Pg=94.98, Qg=47.58 -> Pg=144.45, Qg=28.5
% INFO    : Gen at bus 20543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20543	: Pg=94.98, Qg=47.58 -> Pg=144.45, Qg=28.5
% INFO    : Gen at bus 20543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20544	: Pg=197.99, Qg=122.7 -> Pg=149.0, Qg=28.35
% INFO    : Gen at bus 20544	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20544	: Pg=197.99, Qg=122.7 -> Pg=149.0, Qg=28.35
% INFO    : Gen at bus 20544	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20544	: Pg=197.99, Qg=122.7 -> Pg=149.0, Qg=28.35
% INFO    : Gen at bus 20544	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20545	: Pg=195.49, Qg=66.58 -> Pg=155.5, Qg=28.0
% INFO    : Gen at bus 20545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20545	: Pg=195.49, Qg=66.58 -> Pg=155.5, Qg=28.0
% INFO    : Gen at bus 20545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20545	: Pg=195.49, Qg=66.58 -> Pg=155.5, Qg=28.0
% INFO    : Gen at bus 20545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20545	: Pg=195.49, Qg=66.58 -> Pg=155.5, Qg=28.0
% INFO    : Gen at bus 20545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20545	: Pg=195.49, Qg=66.58 -> Pg=155.5, Qg=28.0
% INFO    : Gen at bus 20545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20546	: Pg=59.77, Qg=118.0 -> Pg=122.7, Qg=27.25
% INFO    : Gen at bus 20546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20546	: Pg=59.77, Qg=118.0 -> Pg=122.7, Qg=27.25
% INFO    : Gen at bus 20546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20546	: Pg=59.77, Qg=118.0 -> Pg=122.7, Qg=27.25
% INFO    : Gen at bus 20546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20546	: Pg=59.77, Qg=118.0 -> Pg=122.7, Qg=27.25
% INFO    : Gen at bus 20546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20546	: Pg=427.03, Qg=137.06 -> Pg=545.0, Qg=97.35
% INFO    : Gen at bus 20546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20546	: Pg=427.03, Qg=137.06 -> Pg=545.0, Qg=97.35
% INFO    : Gen at bus 20546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20546	: Pg=143.36, Qg=137.06 -> Pg=234.5, Qg=47.85
% INFO    : Gen at bus 20546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20547	: Pg=98.36, Qg=14.95 -> Pg=134.1, Qg=24.95
% INFO    : Gen at bus 20547	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20547	: Pg=98.36, Qg=14.95 -> Pg=134.1, Qg=24.95
% INFO    : Gen at bus 20547	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20547	: Pg=98.36, Qg=14.95 -> Pg=134.1, Qg=24.95
% INFO    : Gen at bus 20547	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20547	: Pg=103.99, Qg=14.95 -> Pg=246.5, Qg=57.15
% INFO    : Gen at bus 20547	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20548	: Pg=172.0, Qg=106.6 -> Pg=159.0, Qg=24.65
% INFO    : Gen at bus 20548	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20548	: Pg=172.0, Qg=106.6 -> Pg=159.0, Qg=24.65
% INFO    : Gen at bus 20548	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20548	: Pg=172.0, Qg=106.6 -> Pg=159.0, Qg=24.65
% INFO    : Gen at bus 20548	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20548	: Pg=172.0, Qg=106.6 -> Pg=159.0, Qg=24.65
% INFO    : Gen at bus 20548	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20549	: Pg=163.5, Qg=-14.99 -> Pg=131.75, Qg=23.4
% INFO    : Gen at bus 20549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20549	: Pg=163.5, Qg=-14.99 -> Pg=131.75, Qg=23.4
% INFO    : Gen at bus 20549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20549	: Pg=163.5, Qg=-14.99 -> Pg=131.75, Qg=23.4
% INFO    : Gen at bus 20549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20549	: Pg=163.5, Qg=-14.99 -> Pg=131.75, Qg=23.4
% INFO    : Gen at bus 20549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20549	: Pg=317.09, Qg=-14.99 -> Pg=298.55, Qg=45.4
% INFO    : Gen at bus 20549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20549	: Pg=317.09, Qg=-14.99 -> Pg=298.55, Qg=45.4
% INFO    : Gen at bus 20549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20550	: Pg=161.5, Qg=114.4 -> Pg=80.75, Qg=30.3
% INFO    : Gen at bus 20550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20550	: Pg=841.48, Qg=407.6 -> Pg=578.25, Qg=63.55
% INFO    : Gen at bus 20550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20550	: Pg=443.89, Qg=215.0 -> Pg=286.95, Qg=33.5
% INFO    : Gen at bus 20550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20550	: Pg=443.89, Qg=215.0 -> Pg=286.95, Qg=33.5
% INFO    : Gen at bus 20550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20551	: Pg=140.6, Qg=75.9 -> Pg=97.715, Qg=14.5
% INFO    : Gen at bus 20551	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20551	: Pg=140.6, Qg=75.9 -> Pg=97.715, Qg=14.5
% INFO    : Gen at bus 20551	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20551	: Pg=217.59, Qg=117.4 -> Pg=151.23, Qg=22.45
% INFO    : Gen at bus 20551	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20552	: Pg=132.8, Qg=82.3 -> Pg=92.295, Qg=19.0
% INFO    : Gen at bus 20552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20552	: Pg=132.8, Qg=82.3 -> Pg=92.295, Qg=19.0
% INFO    : Gen at bus 20552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20552	: Pg=27.0, Qg=16.7 -> Pg=16.0, Qg=3.85
% INFO    : Gen at bus 20552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20553	: Pg=17.93, Qg=11.11 -> Pg=16.0, Qg=2.57
% INFO    : Gen at bus 20553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20553	: Pg=17.93, Qg=11.11 -> Pg=16.0, Qg=2.57
% INFO    : Gen at bus 20553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20553	: Pg=17.93, Qg=11.11 -> Pg=16.0, Qg=2.57
% INFO    : Gen at bus 20553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20553	: Pg=17.93, Qg=11.11 -> Pg=16.0, Qg=2.57
% INFO    : Gen at bus 20553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20553	: Pg=17.93, Qg=11.11 -> Pg=16.0, Qg=2.57
% INFO    : Gen at bus 20553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20553	: Pg=17.93, Qg=11.11 -> Pg=16.0, Qg=2.57
% INFO    : Gen at bus 20553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20553	: Pg=17.93, Qg=11.11 -> Pg=16.0, Qg=2.57
% INFO    : Gen at bus 20553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20554	: Pg=123.0, Qg=76.2 -> Pg=86.5, Qg=17.6
% INFO    : Gen at bus 20554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20554	: Pg=123.0, Qg=76.2 -> Pg=86.5, Qg=17.6
% INFO    : Gen at bus 20554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20554	: Pg=207.99, Qg=147.3 -> Pg=144.56, Qg=39.0
% INFO    : Gen at bus 20554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20554	: Pg=123.0, Qg=92.3 -> Pg=86.5, Qg=25.65
% INFO    : Gen at bus 20554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20554	: Pg=32.0, Qg=19.8 -> Pg=20.0, Qg=4.55
% INFO    : Gen at bus 20554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20554	: Pg=679.98, Qg=337.0 -> Pg=483.82, Qg=55.15
% INFO    : Gen at bus 20554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=163.2, Qg=79.0 -> Pg=112.1, Qg=12.3
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=460.79, Qg=223.2 -> Pg=260.9, Qg=34.8
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=125.0, Qg=60.5 -> Pg=86.875, Qg=9.4
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=112.5, Qg=54.5 -> Pg=75.94, Qg=8.5
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=115.0, Qg=55.7 -> Pg=77.625, Qg=8.7
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=52.9, Qg=25.6 -> Pg=31.45, Qg=4.0
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=52.9, Qg=25.6 -> Pg=31.45, Qg=4.0
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=52.9, Qg=25.6 -> Pg=31.45, Qg=4.0
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=52.9, Qg=25.6 -> Pg=31.45, Qg=4.0
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=244.79, Qg=151.7 -> Pg=160.9, Qg=35.05
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20556	: Pg=106.2, Qg=65.8 -> Pg=59.6, Qg=15.2
% INFO    : Gen at bus 20556	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20557	: Pg=64.83, Qg=54.43 -> Pg=108.56, Qg=29.3
% INFO    : Gen at bus 20557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20557	: Pg=64.83, Qg=54.43 -> Pg=108.56, Qg=29.3
% INFO    : Gen at bus 20557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20557	: Pg=38.78, Qg=54.43 -> Pg=69.795, Qg=14.1
% INFO    : Gen at bus 20557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20559	: Pg=94.0, Qg=58.3 -> Pg=67.0, Qg=13.5
% INFO    : Gen at bus 20559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20559	: Pg=94.0, Qg=58.3 -> Pg=67.0, Qg=13.5
% INFO    : Gen at bus 20559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20559	: Pg=94.0, Qg=58.3 -> Pg=67.0, Qg=13.5
% INFO    : Gen at bus 20559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20559	: Pg=94.0, Qg=58.3 -> Pg=67.0, Qg=13.5
% INFO    : Gen at bus 20559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20559	: Pg=94.0, Qg=58.3 -> Pg=67.0, Qg=13.5
% INFO    : Gen at bus 20559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20559	: Pg=94.0, Qg=58.3 -> Pg=67.0, Qg=13.5
% INFO    : Gen at bus 20559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20560	: Pg=94.0, Qg=58.3 -> Pg=83.0, Qg=13.5
% INFO    : Gen at bus 20560	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20560	: Pg=94.0, Qg=58.3 -> Pg=83.0, Qg=13.5
% INFO    : Gen at bus 20560	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20560	: Pg=94.0, Qg=58.3 -> Pg=83.0, Qg=13.5
% INFO    : Gen at bus 20560	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20560	: Pg=94.0, Qg=58.3 -> Pg=83.0, Qg=13.5
% INFO    : Gen at bus 20560	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20561	: Pg=86.5, Qg=53.6 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20561	: Pg=86.5, Qg=53.6 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20561	: Pg=86.5, Qg=53.6 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20561	: Pg=86.5, Qg=53.6 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20561	: Pg=86.5, Qg=53.6 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20561	: Pg=86.5, Qg=53.6 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20561	: Pg=86.5, Qg=53.6 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20561	: Pg=86.5, Qg=53.6 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20562	: Pg=86.0, Qg=53.3 -> Pg=57.0, Qg=12.3
% INFO    : Gen at bus 20562	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20562	: Pg=29.0, Qg=18.0 -> Pg=28.5, Qg=4.15
% INFO    : Gen at bus 20562	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20562	: Pg=679.98, Qg=421.4 -> Pg=505.0, Qg=97.35
% INFO    : Gen at bus 20562	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20563	: Pg=65.3, Qg=40.5 -> Pg=42.65, Qg=9.35
% INFO    : Gen at bus 20563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20563	: Pg=65.3, Qg=40.5 -> Pg=42.65, Qg=9.35
% INFO    : Gen at bus 20563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20563	: Pg=85.0, Qg=52.7 -> Pg=57.5, Qg=12.2
% INFO    : Gen at bus 20563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20563	: Pg=85.0, Qg=52.7 -> Pg=57.5, Qg=12.2
% INFO    : Gen at bus 20563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20563	: Pg=85.0, Qg=52.7 -> Pg=57.5, Qg=12.2
% INFO    : Gen at bus 20563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20563	: Pg=85.0, Qg=52.7 -> Pg=57.5, Qg=12.2
% INFO    : Gen at bus 20563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20563	: Pg=85.0, Qg=52.7 -> Pg=57.5, Qg=12.2
% INFO    : Gen at bus 20563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20564	: Pg=84.2, Qg=52.2 -> Pg=62.6, Qg=12.05
% INFO    : Gen at bus 20564	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20564	: Pg=103.5, Qg=64.1 -> Pg=72.25, Qg=14.8
% INFO    : Gen at bus 20564	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20564	: Pg=106.1, Qg=65.8 -> Pg=73.55, Qg=15.2
% INFO    : Gen at bus 20564	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20565	: Pg=32.6, Qg=20.2 -> Pg=28.8, Qg=4.65
% INFO    : Gen at bus 20565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20565	: Pg=69.0, Qg=42.8 -> Pg=49.5, Qg=9.9
% INFO    : Gen at bus 20565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20565	: Pg=69.0, Qg=42.8 -> Pg=49.5, Qg=9.9
% INFO    : Gen at bus 20565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20565	: Pg=69.0, Qg=42.8 -> Pg=49.5, Qg=9.9
% INFO    : Gen at bus 20565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20565	: Pg=69.0, Qg=42.8 -> Pg=49.5, Qg=9.9
% INFO    : Gen at bus 20565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20565	: Pg=69.0, Qg=42.8 -> Pg=47.0, Qg=9.9
% INFO    : Gen at bus 20565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20565	: Pg=69.0, Qg=42.8 -> Pg=47.0, Qg=9.9
% INFO    : Gen at bus 20565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20566	: Pg=13.6, Qg=6.58 -> Pg=8.3, Qg=1.02
% INFO    : Gen at bus 20566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20566	: Pg=13.6, Qg=6.58 -> Pg=8.3, Qg=1.02
% INFO    : Gen at bus 20566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20566	: Pg=13.6, Qg=6.58 -> Pg=8.3, Qg=1.02
% INFO    : Gen at bus 20566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20566	: Pg=13.6, Qg=6.58 -> Pg=8.3, Qg=1.02
% INFO    : Gen at bus 20566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20566	: Pg=13.6, Qg=6.58 -> Pg=8.3, Qg=1.02
% INFO    : Gen at bus 20566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20566	: Pg=23.0, Qg=11.1 -> Pg=13.0, Qg=1.7
% INFO    : Gen at bus 20566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20567	: Pg=67.0, Qg=22.0 -> Pg=38.5, Qg=0.0
% INFO    : Gen at bus 20567	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20568	: Pg=16.5, Qg=10.23 -> Pg=9.75, Qg=2.365
% INFO    : Gen at bus 20568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20568	: Pg=16.5, Qg=10.23 -> Pg=9.75, Qg=2.365
% INFO    : Gen at bus 20568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20568	: Pg=16.5, Qg=10.23 -> Pg=9.75, Qg=2.365
% INFO    : Gen at bus 20568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20568	: Pg=16.5, Qg=10.23 -> Pg=9.75, Qg=2.365
% INFO    : Gen at bus 20568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20568	: Pg=163.2, Qg=101.1 -> Pg=120.6, Qg=23.35
% INFO    : Gen at bus 20568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20568	: Pg=557.08, Qg=345.3 -> Pg=355.55, Qg=79.8
% INFO    : Gen at bus 20568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20568	: Pg=557.68, Qg=345.6 -> Pg=355.85, Qg=79.85
% INFO    : Gen at bus 20568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20569	: Pg=59.0, Qg=36.6 -> Pg=44.5, Qg=8.45
% INFO    : Gen at bus 20569	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20569	: Pg=59.0, Qg=36.6 -> Pg=44.5, Qg=8.45
% INFO    : Gen at bus 20569	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20569	: Pg=59.0, Qg=36.6 -> Pg=44.5, Qg=8.45
% INFO    : Gen at bus 20569	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20569	: Pg=59.0, Qg=36.6 -> Pg=44.5, Qg=8.45
% INFO    : Gen at bus 20569	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20570	: Pg=22.0, Qg=0.0 -> Pg=14.0, Qg=0.0
% INFO    : Gen at bus 20570	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20570	: Pg=13.37, Qg=6.58 -> Pg=8.755, Qg=1.065
% INFO    : Gen at bus 20570	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20570	: Pg=13.37, Qg=6.58 -> Pg=8.755, Qg=1.065
% INFO    : Gen at bus 20570	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20570	: Pg=13.37, Qg=6.58 -> Pg=8.755, Qg=1.065
% INFO    : Gen at bus 20570	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20570	: Pg=13.37, Qg=6.58 -> Pg=8.755, Qg=1.065
% INFO    : Gen at bus 20570	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20571	: Pg=45.3, Qg=31.2 -> Pg=32.15, Qg=8.05
% INFO    : Gen at bus 20571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20572	: Pg=9.25, Qg=5.95 -> Pg=7.585, Qg=1.435
% INFO    : Gen at bus 20572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20572	: Pg=9.25, Qg=5.95 -> Pg=7.585, Qg=1.435
% INFO    : Gen at bus 20572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20572	: Pg=9.25, Qg=5.95 -> Pg=7.585, Qg=1.435
% INFO    : Gen at bus 20572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20572	: Pg=9.25, Qg=5.95 -> Pg=7.585, Qg=1.435
% INFO    : Gen at bus 20572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20573	: Pg=12.27, Qg=7.83 -> Pg=7.3, Qg=1.865
% INFO    : Gen at bus 20573	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20573	: Pg=12.27, Qg=7.83 -> Pg=7.3, Qg=1.865
% INFO    : Gen at bus 20573	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20573	: Pg=12.27, Qg=7.83 -> Pg=7.3, Qg=1.865
% INFO    : Gen at bus 20573	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20575	: Pg=33.0, Qg=20.5 -> Pg=29.5, Qg=4.75
% INFO    : Gen at bus 20575	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20577	: Pg=16.0, Qg=9.9 -> Pg=10.5, Qg=2.275
% INFO    : Gen at bus 20577	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20577	: Pg=16.0, Qg=9.9 -> Pg=10.5, Qg=2.275
% INFO    : Gen at bus 20577	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20578	: Pg=32.0, Qg=19.8 -> Pg=30.5, Qg=4.55
% INFO    : Gen at bus 20578	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20579	: Pg=32.0, Qg=19.8 -> Pg=30.5, Qg=4.55
% INFO    : Gen at bus 20579	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20580	: Pg=8.8, Qg=19.8 -> Pg=20.0, Qg=4.55
% INFO    : Gen at bus 20580	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20581	: Pg=5.22, Qg=3.27 -> Pg=3.075, Qg=0.77
% INFO    : Gen at bus 20581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20581	: Pg=5.22, Qg=3.27 -> Pg=3.075, Qg=0.77
% INFO    : Gen at bus 20581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20581	: Pg=5.22, Qg=3.27 -> Pg=3.075, Qg=0.77
% INFO    : Gen at bus 20581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20581	: Pg=5.22, Qg=3.27 -> Pg=3.075, Qg=0.77
% INFO    : Gen at bus 20581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20581	: Pg=5.22, Qg=3.27 -> Pg=3.075, Qg=0.77
% INFO    : Gen at bus 20581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20581	: Pg=5.22, Qg=3.27 -> Pg=3.075, Qg=0.77
% INFO    : Gen at bus 20581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20584	: Pg=0.0, Qg=18.15 -> Pg=500.0, Qg=0.0
% INFO    : Gen at bus 20584	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 20584	: Pg=50.6, Qg=18.15 -> Pg=37.3, Qg=7.25
% INFO    : Gen at bus 20584	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 20584	: Pg=25.0, Qg=15.5 -> Pg=16.5, Qg=3.6
% INFO    : Gen at bus 20584	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 20585	: Pg=27.2, Qg=16.9 -> Pg=18.6, Qg=3.9
% INFO    : Gen at bus 20585	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20585	: Pg=24.0, Qg=14.9 -> Pg=16.0, Qg=3.45
% INFO    : Gen at bus 20585	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20585	: Pg=31.0, Qg=19.2 -> Pg=20.5, Qg=4.45
% INFO    : Gen at bus 20585	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20587	: Pg=13.05, Qg=9.8 -> Pg=8.775, Qg=2.725
% INFO    : Gen at bus 20587	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20587	: Pg=13.05, Qg=9.8 -> Pg=8.775, Qg=2.725
% INFO    : Gen at bus 20587	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20588	: Pg=1.59, Qg=4.21 -> Pg=12.35, Qg=0.0
% INFO    : Gen at bus 20588	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20588	: Pg=1.59, Qg=4.21 -> Pg=12.35, Qg=0.0
% INFO    : Gen at bus 20588	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20589	: Pg=23.4, Qg=4.8 -> Pg=12.2, Qg=0.0
% INFO    : Gen at bus 20589	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20589	: Pg=23.4, Qg=4.8 -> Pg=12.2, Qg=0.0
% INFO    : Gen at bus 20589	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20589	: Pg=23.4, Qg=4.8 -> Pg=12.2, Qg=0.0
% INFO    : Gen at bus 20589	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20590	: Pg=22.0, Qg=13.6 -> Pg=14.5, Qg=3.15
% INFO    : Gen at bus 20590	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20590	: Pg=25.0, Qg=18.8 -> Pg=16.0, Qg=5.25
% INFO    : Gen at bus 20590	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20590	: Pg=25.0, Qg=18.8 -> Pg=16.0, Qg=5.25
% INFO    : Gen at bus 20590	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20591	: Pg=6.83, Qg=5.13 -> Pg=3.915, Qg=1.43
% INFO    : Gen at bus 20591	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20591	: Pg=6.83, Qg=5.13 -> Pg=3.915, Qg=1.43
% INFO    : Gen at bus 20591	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20591	: Pg=6.83, Qg=5.13 -> Pg=3.915, Qg=1.43
% INFO    : Gen at bus 20591	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20592	: Pg=20.0, Qg=12.4 -> Pg=17.0, Qg=2.85
% INFO    : Gen at bus 20592	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27810	: Pg=1080.0, Qg=190.62 -> Pg=1033.5, Qg=81.55
% INFO    : Gen at bus 27810	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27810	: Pg=1080.0, Qg=190.62 -> Pg=1030.5, Qg=81.55
% INFO    : Gen at bus 27810	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27811	: Pg=368.43, Qg=219.36 -> Pg=542.95, Qg=55.55
% INFO    : Gen at bus 27811	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27811	: Pg=368.43, Qg=219.36 -> Pg=542.95, Qg=55.55
% INFO    : Gen at bus 27811	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27812	: Pg=678.98, Qg=165.69 -> Pg=439.5, Qg=51.3
% INFO    : Gen at bus 27812	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27812	: Pg=418.56, Qg=165.69 -> Pg=439.5, Qg=51.3
% INFO    : Gen at bus 27812	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27813	: Pg=262.26, Qg=225.83 -> Pg=323.1, Qg=42.0
% INFO    : Gen at bus 27813	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27813	: Pg=262.26, Qg=225.83 -> Pg=318.1, Qg=42.0
% INFO    : Gen at bus 27813	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27814	: Pg=160.09, Qg=125.9 -> Pg=179.1, Qg=29.1
% INFO    : Gen at bus 27814	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27814	: Pg=219.02, Qg=225.0 -> Pg=279.75, Qg=35.1
% INFO    : Gen at bus 27814	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27814	: Pg=219.02, Qg=225.0 -> Pg=277.25, Qg=35.1
% INFO    : Gen at bus 27814	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27814	: Pg=72.04, Qg=80.4 -> Pg=99.295, Qg=18.55
% INFO    : Gen at bus 27814	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27815	: Pg=29.23, Qg=38.4 -> Pg=38.0, Qg=8.85
% INFO    : Gen at bus 27815	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27815	: Pg=210.06, Qg=89.5 -> Pg=317.75, Qg=33.65
% INFO    : Gen at bus 27815	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27815	: Pg=210.06, Qg=89.5 -> Pg=315.25, Qg=33.65
% INFO    : Gen at bus 27815	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27815	: Pg=210.06, Qg=89.5 -> Pg=315.25, Qg=33.65
% INFO    : Gen at bus 27815	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27815	: Pg=229.16, Qg=89.5 -> Pg=321.5, Qg=36.7
% INFO    : Gen at bus 27815	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27816	: Pg=348.54, Qg=40.32 -> Pg=482.1, Qg=55.8
% INFO    : Gen at bus 27816	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27816	: Pg=348.54, Qg=40.32 -> Pg=482.1, Qg=55.8
% INFO    : Gen at bus 27816	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27816	: Pg=890.4, Qg=40.32 -> Pg=601.02, Qg=67.2
% INFO    : Gen at bus 27816	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27816	: Pg=207.7, Qg=40.32 -> Pg=270.25, Qg=33.25
% INFO    : Gen at bus 27816	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27816	: Pg=246.98, Qg=40.32 -> Pg=321.9, Qg=39.55
% INFO    : Gen at bus 27816	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27817	: Pg=189.55, Qg=69.08 -> Pg=241.2, Qg=0.0
% INFO    : Gen at bus 27817	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27817	: Pg=189.55, Qg=69.08 -> Pg=241.2, Qg=0.0
% INFO    : Gen at bus 27817	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27819	: Pg=59.41, Qg=61.0 -> Pg=78.0, Qg=9.5
% INFO    : Gen at bus 27819	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27819	: Pg=12.54, Qg=12.9 -> Pg=14.8, Qg=2.0
% INFO    : Gen at bus 27819	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27819	: Pg=48.8, Qg=50.1 -> Pg=64.25, Qg=7.8
% INFO    : Gen at bus 27819	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27819	: Pg=146.24, Qg=120.6 -> Pg=194.5, Qg=18.8
% INFO    : Gen at bus 27819	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27819	: Pg=189.11, Qg=148.6 -> Pg=271.9, Qg=27.45
% INFO    : Gen at bus 27819	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27819	: Pg=120.0, Qg=58.1 -> Pg=120.0, Qg=9.05
% INFO    : Gen at bus 27819	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27820	: Pg=146.36, Qg=140.5 -> Pg=186.24, Qg=0.0
% INFO    : Gen at bus 27820	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27820	: Pg=146.36, Qg=140.5 -> Pg=186.24, Qg=0.0
% INFO    : Gen at bus 27820	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27821	: Pg=363.2, Qg=106.52 -> Pg=438.5, Qg=75.45
% INFO    : Gen at bus 27821	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27821	: Pg=363.2, Qg=106.52 -> Pg=438.5, Qg=75.45
% INFO    : Gen at bus 27821	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27821	: Pg=239.46, Qg=106.52 -> Pg=265.0, Qg=42.7
% INFO    : Gen at bus 27821	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27821	: Pg=239.46, Qg=106.52 -> Pg=265.0, Qg=42.7
% INFO    : Gen at bus 27821	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27821	: Pg=239.46, Qg=106.52 -> Pg=265.0, Qg=42.7
% INFO    : Gen at bus 27821	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27821	: Pg=239.46, Qg=106.52 -> Pg=265.0, Qg=42.7
% INFO    : Gen at bus 27821	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27821	: Pg=239.46, Qg=106.52 -> Pg=265.0, Qg=42.7
% INFO    : Gen at bus 27821	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27821	: Pg=239.46, Qg=106.52 -> Pg=265.0, Qg=42.7
% INFO    : Gen at bus 27821	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27822	: Pg=29.28, Qg=30.1 -> Pg=38.55, Qg=4.7
% INFO    : Gen at bus 27822	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27822	: Pg=29.28, Qg=30.1 -> Pg=38.55, Qg=4.7
% INFO    : Gen at bus 27822	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27822	: Pg=29.28, Qg=30.1 -> Pg=38.55, Qg=4.7
% INFO    : Gen at bus 27822	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27822	: Pg=29.28, Qg=30.1 -> Pg=38.55, Qg=4.7
% INFO    : Gen at bus 27822	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27822	: Pg=265.79, Qg=145.62 -> Pg=306.85, Qg=42.55
% INFO    : Gen at bus 27822	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27822	: Pg=187.45, Qg=145.62 -> Pg=238.75, Qg=42.6
% INFO    : Gen at bus 27822	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27822	: Pg=187.45, Qg=145.62 -> Pg=238.75, Qg=42.6
% INFO    : Gen at bus 27822	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27823	: Pg=291.59, Qg=180.7 -> Pg=190.8, Qg=41.75
% INFO    : Gen at bus 27823	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27824	: Pg=11.64, Qg=15.2 -> Pg=13.8, Qg=3.5
% INFO    : Gen at bus 27824	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27824	: Pg=11.64, Qg=15.2 -> Pg=13.8, Qg=3.5
% INFO    : Gen at bus 27824	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27824	: Pg=35.36, Qg=46.5 -> Pg=48.0, Qg=10.75
% INFO    : Gen at bus 27824	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27824	: Pg=52.41, Qg=59.6 -> Pg=73.05, Qg=13.8
% INFO    : Gen at bus 27824	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27824	: Pg=118.21, Qg=151.62 -> Pg=157.85, Qg=35.9
% INFO    : Gen at bus 27824	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27825	: Pg=103.54, Qg=107.02 -> Pg=149.8, Qg=31.45
% INFO    : Gen at bus 27825	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27825	: Pg=90.44, Qg=107.02 -> Pg=128.4, Qg=27.5
% INFO    : Gen at bus 27825	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27826	: Pg=26.12, Qg=26.8 -> Pg=37.7, Qg=4.15
% INFO    : Gen at bus 27826	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27826	: Pg=26.12, Qg=26.8 -> Pg=37.7, Qg=4.15
% INFO    : Gen at bus 27826	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27826	: Pg=26.12, Qg=26.8 -> Pg=37.7, Qg=4.15
% INFO    : Gen at bus 27826	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27826	: Pg=26.12, Qg=26.8 -> Pg=37.7, Qg=4.15
% INFO    : Gen at bus 27826	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27826	: Pg=198.6, Qg=133.52 -> Pg=286.415, Qg=31.8
% INFO    : Gen at bus 27826	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27826	: Pg=98.9, Qg=129.0 -> Pg=150.945, Qg=29.8
% INFO    : Gen at bus 27826	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27826	: Pg=98.9, Qg=129.0 -> Pg=150.945, Qg=29.8
% INFO    : Gen at bus 27826	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27826	: Pg=98.9, Qg=129.0 -> Pg=150.945, Qg=29.8
% INFO    : Gen at bus 27826	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27826	: Pg=98.9, Qg=129.0 -> Pg=150.945, Qg=29.8
% INFO    : Gen at bus 27826	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27827	: Pg=105.01, Qg=54.4 -> Pg=150.0, Qg=28.6
% INFO    : Gen at bus 27827	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27827	: Pg=105.01, Qg=54.4 -> Pg=150.0, Qg=28.6
% INFO    : Gen at bus 27827	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27827	: Pg=105.01, Qg=54.4 -> Pg=150.0, Qg=28.6
% INFO    : Gen at bus 27827	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27828	: Pg=100.01, Qg=115.97 -> Pg=147.5, Qg=28.6
% INFO    : Gen at bus 27828	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27828	: Pg=51.87, Qg=46.2 -> Pg=62.25, Qg=10.7
% INFO    : Gen at bus 27828	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27829	: Pg=135.6, Qg=58.0 -> Pg=149.7, Qg=28.55
% INFO    : Gen at bus 27829	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27829	: Pg=135.6, Qg=58.0 -> Pg=149.7, Qg=28.55
% INFO    : Gen at bus 27829	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27830	: Pg=93.83, Qg=14.9 -> Pg=139.5, Qg=28.5
% INFO    : Gen at bus 27830	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27830	: Pg=93.83, Qg=14.9 -> Pg=139.5, Qg=28.5
% INFO    : Gen at bus 27830	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27830	: Pg=89.12, Qg=14.9 -> Pg=117.0, Qg=27.05
% INFO    : Gen at bus 27830	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27831	: Pg=28.29, Qg=14.23 -> Pg=36.0, Qg=8.6
% INFO    : Gen at bus 27831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27831	: Pg=28.29, Qg=14.23 -> Pg=36.0, Qg=8.6
% INFO    : Gen at bus 27831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27831	: Pg=12.7, Qg=14.23 -> Pg=15.0, Qg=3.85
% INFO    : Gen at bus 27831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27831	: Pg=35.36, Qg=14.23 -> Pg=52.5, Qg=10.75
% INFO    : Gen at bus 27831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27831	: Pg=126.49, Qg=14.23 -> Pg=189.6, Qg=37.1
% INFO    : Gen at bus 27831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27831	: Pg=93.78, Qg=14.23 -> Pg=134.45, Qg=28.5
% INFO    : Gen at bus 27831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27832	: Pg=106.98, Qg=52.56 -> Pg=150.4, Qg=28.45
% INFO    : Gen at bus 27832	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27832	: Pg=106.98, Qg=52.56 -> Pg=150.45, Qg=28.5
% INFO    : Gen at bus 27832	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27832	: Pg=106.98, Qg=52.56 -> Pg=150.45, Qg=28.5
% INFO    : Gen at bus 27832	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27832	: Pg=106.98, Qg=52.56 -> Pg=150.45, Qg=28.5
% INFO    : Gen at bus 27832	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27832	: Pg=106.98, Qg=52.56 -> Pg=150.45, Qg=28.5
% INFO    : Gen at bus 27832	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27833	: Pg=135.89, Qg=31.4 -> Pg=163.1, Qg=27.95
% INFO    : Gen at bus 27833	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27833	: Pg=73.08, Qg=31.4 -> Pg=76.95, Qg=11.9
% INFO    : Gen at bus 27833	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27834	: Pg=93.4, Qg=-10.5 -> Pg=132.4, Qg=13.25
% INFO    : Gen at bus 27834	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27834	: Pg=93.4, Qg=-10.5 -> Pg=132.4, Qg=13.25
% INFO    : Gen at bus 27834	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27834	: Pg=93.83, Qg=-10.5 -> Pg=140.95, Qg=25.1
% INFO    : Gen at bus 27834	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27834	: Pg=93.4, Qg=-10.5 -> Pg=132.4, Qg=25.2
% INFO    : Gen at bus 27834	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27834	: Pg=93.4, Qg=-10.5 -> Pg=132.4, Qg=25.2
% INFO    : Gen at bus 27834	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27834	: Pg=62.9, Qg=-10.5 -> Pg=83.2, Qg=19.1
% INFO    : Gen at bus 27834	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27835	: Pg=122.59, Qg=55.74 -> Pg=160.0, Qg=37.2
% INFO    : Gen at bus 27835	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27835	: Pg=104.81, Qg=55.74 -> Pg=146.05, Qg=27.55
% INFO    : Gen at bus 27835	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27835	: Pg=104.81, Qg=55.74 -> Pg=146.05, Qg=27.55
% INFO    : Gen at bus 27835	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27836	: Pg=32.96, Qg=43.3 -> Pg=41.95, Qg=10.0
% INFO    : Gen at bus 27836	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27836	: Pg=89.54, Qg=92.0 -> Pg=133.95, Qg=14.35
% INFO    : Gen at bus 27836	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27836	: Pg=89.54, Qg=92.0 -> Pg=133.95, Qg=14.35
% INFO    : Gen at bus 27836	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27836	: Pg=89.54, Qg=92.0 -> Pg=133.95, Qg=14.35
% INFO    : Gen at bus 27836	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27836	: Pg=112.88, Qg=146.99 -> Pg=143.2, Qg=34.3
% INFO    : Gen at bus 27836	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27836	: Pg=32.96, Qg=43.3 -> Pg=41.95, Qg=10.0
% INFO    : Gen at bus 27836	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27836	: Pg=32.96, Qg=43.3 -> Pg=41.95, Qg=10.0
% INFO    : Gen at bus 27836	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27836	: Pg=32.96, Qg=43.3 -> Pg=41.95, Qg=10.0
% INFO    : Gen at bus 27836	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27836	: Pg=210.15, Qg=146.99 -> Pg=248.85, Qg=33.65
% INFO    : Gen at bus 27836	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27836	: Pg=89.54, Qg=92.0 -> Pg=133.95, Qg=14.35
% INFO    : Gen at bus 27836	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27836	: Pg=89.54, Qg=92.0 -> Pg=133.95, Qg=14.35
% INFO    : Gen at bus 27836	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27836	: Pg=89.54, Qg=92.0 -> Pg=133.95, Qg=14.35
% INFO    : Gen at bus 27836	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27836	: Pg=89.54, Qg=92.0 -> Pg=133.95, Qg=14.35
% INFO    : Gen at bus 27836	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=73.65, Qg=59.09 -> Pg=104.83, Qg=22.35
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=29.23, Qg=30.0 -> Pg=33.5, Qg=4.65
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=29.23, Qg=30.0 -> Pg=33.5, Qg=4.65
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=29.23, Qg=30.0 -> Pg=33.5, Qg=4.65
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=6.55, Qg=30.0 -> Pg=33.5, Qg=4.65
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=163.54, Qg=59.09 -> Pg=170.0, Qg=25.95
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=23.53, Qg=59.09 -> Pg=100.0, Qg=25.95
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=205.63, Qg=59.09 -> Pg=296.55, Qg=62.45
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=94.71, Qg=59.09 -> Pg=139.1, Qg=26.95
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=94.71, Qg=59.09 -> Pg=139.1, Qg=26.95
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=94.71, Qg=59.09 -> Pg=139.1, Qg=26.95
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=29.23, Qg=30.0 -> Pg=33.5, Qg=4.65
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=94.71, Qg=59.09 -> Pg=139.1, Qg=26.95
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=94.71, Qg=59.09 -> Pg=139.1, Qg=26.95
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=94.71, Qg=59.09 -> Pg=139.1, Qg=26.95
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=29.23, Qg=30.0 -> Pg=33.5, Qg=4.65
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=29.23, Qg=30.0 -> Pg=33.5, Qg=4.65
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=29.23, Qg=30.0 -> Pg=33.5, Qg=4.65
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=29.23, Qg=30.0 -> Pg=33.5, Qg=4.65
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=29.23, Qg=30.0 -> Pg=33.5, Qg=4.65
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=29.23, Qg=30.0 -> Pg=33.5, Qg=4.65
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27837	: Pg=29.23, Qg=30.0 -> Pg=33.5, Qg=4.65
% INFO    : Gen at bus 27837	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27838	: Pg=305.92, Qg=48.12 -> Pg=365.55, Qg=39.0
% INFO    : Gen at bus 27838	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27838	: Pg=89.4, Qg=48.12 -> Pg=136.445, Qg=26.95
% INFO    : Gen at bus 27838	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27838	: Pg=73.65, Qg=48.12 -> Pg=106.215, Qg=22.35
% INFO    : Gen at bus 27838	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27838	: Pg=305.92, Qg=48.12 -> Pg=365.55, Qg=39.0
% INFO    : Gen at bus 27838	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27838	: Pg=89.4, Qg=48.12 -> Pg=136.445, Qg=26.95
% INFO    : Gen at bus 27838	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27838	: Pg=89.4, Qg=48.12 -> Pg=136.445, Qg=26.95
% INFO    : Gen at bus 27838	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27838	: Pg=89.4, Qg=48.12 -> Pg=136.445, Qg=26.95
% INFO    : Gen at bus 27838	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27838	: Pg=89.4, Qg=48.12 -> Pg=136.445, Qg=26.95
% INFO    : Gen at bus 27838	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27838	: Pg=89.4, Qg=48.12 -> Pg=136.445, Qg=26.95
% INFO    : Gen at bus 27838	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27838	: Pg=89.4, Qg=48.12 -> Pg=136.445, Qg=26.95
% INFO    : Gen at bus 27838	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27838	: Pg=89.4, Qg=48.12 -> Pg=136.445, Qg=26.95
% INFO    : Gen at bus 27838	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27839	: Pg=407.06, Qg=55.85 -> Pg=526.65, Qg=77.25
% INFO    : Gen at bus 27839	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27839	: Pg=407.06, Qg=55.85 -> Pg=526.65, Qg=77.25
% INFO    : Gen at bus 27839	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27839	: Pg=321.82, Qg=55.85 -> Pg=390.9, Qg=67.55
% INFO    : Gen at bus 27839	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27839	: Pg=89.4, Qg=55.85 -> Pg=136.445, Qg=26.95
% INFO    : Gen at bus 27839	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27839	: Pg=89.4, Qg=55.85 -> Pg=136.445, Qg=26.95
% INFO    : Gen at bus 27839	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27839	: Pg=89.4, Qg=55.85 -> Pg=136.445, Qg=26.95
% INFO    : Gen at bus 27839	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27839	: Pg=89.4, Qg=55.85 -> Pg=136.445, Qg=26.95
% INFO    : Gen at bus 27839	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27840	: Pg=934.47, Qg=-32.56 -> Pg=562.25, Qg=83.65
% INFO    : Gen at bus 27840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 27840	: Pg=203.99, Qg=-32.56 -> Pg=173.5, Qg=42.5
% INFO    : Gen at bus 27840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 27840	: Pg=203.99, Qg=-32.56 -> Pg=173.5, Qg=42.5
% INFO    : Gen at bus 27840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 27840	: Pg=203.99, Qg=-32.56 -> Pg=173.5, Qg=42.5
% INFO    : Gen at bus 27840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 27840	: Pg=203.99, Qg=-32.56 -> Pg=173.5, Qg=42.5
% INFO    : Gen at bus 27840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 27840	: Pg=934.47, Qg=-32.56 -> Pg=562.25, Qg=83.65
% INFO    : Gen at bus 27840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 27840	: Pg=471.69, Qg=-32.56 -> Pg=395.85, Qg=67.55
% INFO    : Gen at bus 27840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 27840	: Pg=188.19, Qg=-32.56 -> Pg=136.445, Qg=26.95
% INFO    : Gen at bus 27840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 27840	: Pg=188.19, Qg=-32.56 -> Pg=136.445, Qg=26.95
% INFO    : Gen at bus 27840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 27840	: Pg=188.19, Qg=-32.56 -> Pg=136.445, Qg=26.95
% INFO    : Gen at bus 27840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 27840	: Pg=188.19, Qg=-32.56 -> Pg=136.445, Qg=26.95
% INFO    : Gen at bus 27840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 27840	: Pg=203.99, Qg=-32.56 -> Pg=173.5, Qg=42.5
% INFO    : Gen at bus 27840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 27840	: Pg=203.99, Qg=-32.56 -> Pg=173.5, Qg=42.5
% INFO    : Gen at bus 27840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 27841	: Pg=760.0, Qg=72.63 -> Pg=592.0, Qg=57.4
% INFO    : Gen at bus 27841	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27841	: Pg=877.2, Qg=72.63 -> Pg=648.6, Qg=66.2
% INFO    : Gen at bus 27841	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27841	: Pg=321.82, Qg=72.63 -> Pg=391.0, Qg=67.6
% INFO    : Gen at bus 27841	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27841	: Pg=189.55, Qg=72.63 -> Pg=246.0, Qg=57.55
% INFO    : Gen at bus 27841	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27841	: Pg=189.55, Qg=72.63 -> Pg=246.0, Qg=57.55
% INFO    : Gen at bus 27841	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27841	: Pg=89.31, Qg=72.63 -> Pg=136.3, Qg=26.9
% INFO    : Gen at bus 27841	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27841	: Pg=89.31, Qg=72.63 -> Pg=136.3, Qg=26.9
% INFO    : Gen at bus 27841	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27841	: Pg=89.31, Qg=72.63 -> Pg=136.3, Qg=26.9
% INFO    : Gen at bus 27841	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27841	: Pg=89.31, Qg=72.63 -> Pg=136.3, Qg=26.9
% INFO    : Gen at bus 27841	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=25.7 -> Pg=19.6, Qg=7.15
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=71.29, Qg=93.7 -> Pg=99.76, Qg=21.65
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=71.29, Qg=93.7 -> Pg=99.76, Qg=21.65
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=159.63, Qg=115.07 -> Pg=170.0, Qg=38.55
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=159.63, Qg=115.07 -> Pg=170.0, Qg=38.55
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=159.63, Qg=115.07 -> Pg=170.0, Qg=38.55
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=159.63, Qg=115.07 -> Pg=170.0, Qg=38.55
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27842	: Pg=16.13, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27843	: Pg=184.99, Qg=89.6 -> Pg=125.0, Qg=13.95
% INFO    : Gen at bus 27843	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27843	: Pg=184.99, Qg=114.7 -> Pg=125.0, Qg=26.5
% INFO    : Gen at bus 27843	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27844	: Pg=152.66, Qg=89.6 -> Pg=135.0, Qg=13.95
% INFO    : Gen at bus 27844	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27844	: Pg=184.99, Qg=89.6 -> Pg=135.0, Qg=13.95
% INFO    : Gen at bus 27844	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27844	: Pg=184.99, Qg=89.6 -> Pg=135.0, Qg=13.95
% INFO    : Gen at bus 27844	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27844	: Pg=70.71, Qg=116.8 -> Pg=146.55, Qg=32.7
% INFO    : Gen at bus 27844	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27845	: Pg=114.56, Qg=-14.44 -> Pg=146.0, Qg=26.05
% INFO    : Gen at bus 27845	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27845	: Pg=114.56, Qg=-14.44 -> Pg=146.0, Qg=26.05
% INFO    : Gen at bus 27845	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27845	: Pg=114.56, Qg=-14.44 -> Pg=146.0, Qg=26.05
% INFO    : Gen at bus 27845	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27845	: Pg=114.56, Qg=-14.44 -> Pg=146.0, Qg=26.05
% INFO    : Gen at bus 27845	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27846	: Pg=23.63, Qg=23.23 -> Pg=33.85, Qg=4.08
% INFO    : Gen at bus 27846	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27846	: Pg=23.63, Qg=23.23 -> Pg=33.85, Qg=4.08
% INFO    : Gen at bus 27846	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27846	: Pg=23.63, Qg=23.23 -> Pg=33.85, Qg=4.08
% INFO    : Gen at bus 27846	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27846	: Pg=23.63, Qg=23.23 -> Pg=33.85, Qg=4.08
% INFO    : Gen at bus 27846	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27847	: Pg=114.52, Qg=111.8 -> Pg=145.2, Qg=25.85
% INFO    : Gen at bus 27847	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27847	: Pg=114.52, Qg=111.8 -> Pg=145.2, Qg=25.85
% INFO    : Gen at bus 27847	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27847	: Pg=114.52, Qg=111.8 -> Pg=145.2, Qg=25.85
% INFO    : Gen at bus 27847	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27848	: Pg=100.24, Qg=-4.03 -> Pg=138.16, Qg=25.85
% INFO    : Gen at bus 27848	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27848	: Pg=91.68, Qg=-4.03 -> Pg=139.925, Qg=27.65
% INFO    : Gen at bus 27848	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27848	: Pg=94.53, Qg=-4.03 -> Pg=144.275, Qg=28.5
% INFO    : Gen at bus 27848	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27848	: Pg=94.53, Qg=-4.03 -> Pg=144.275, Qg=28.5
% INFO    : Gen at bus 27848	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27848	: Pg=93.08, Qg=-4.03 -> Pg=128.29, Qg=24.0
% INFO    : Gen at bus 27848	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27848	: Pg=93.08, Qg=-4.03 -> Pg=128.29, Qg=24.0
% INFO    : Gen at bus 27848	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27848	: Pg=96.24, Qg=-4.03 -> Pg=132.65, Qg=24.85
% INFO    : Gen at bus 27848	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27848	: Pg=96.24, Qg=-4.03 -> Pg=132.65, Qg=24.85
% INFO    : Gen at bus 27848	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27848	: Pg=94.87, Qg=-4.03 -> Pg=144.78, Qg=28.6
% INFO    : Gen at bus 27848	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27848	: Pg=96.91, Qg=-4.03 -> Pg=147.9, Qg=29.2
% INFO    : Gen at bus 27848	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27848	: Pg=100.95, Qg=-4.03 -> Pg=154.065, Qg=30.45
% INFO    : Gen at bus 27848	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27848	: Pg=91.68, Qg=-4.03 -> Pg=139.925, Qg=27.65
% INFO    : Gen at bus 27848	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27849	: Pg=78.75, Qg=65.78 -> Pg=112.3, Qg=21.4
% INFO    : Gen at bus 27849	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27849	: Pg=190.39, Qg=65.78 -> Pg=132.7, Qg=27.25
% INFO    : Gen at bus 27849	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27849	: Pg=41.8, Qg=20.2 -> Pg=36.9, Qg=3.15
% INFO    : Gen at bus 27849	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27849	: Pg=213.29, Qg=65.78 -> Pg=178.955, Qg=30.55
% INFO    : Gen at bus 27849	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27849	: Pg=96.53, Qg=65.78 -> Pg=147.32, Qg=29.1
% INFO    : Gen at bus 27849	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27849	: Pg=96.53, Qg=65.78 -> Pg=147.32, Qg=29.1
% INFO    : Gen at bus 27849	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27850	: Pg=93.26, Qg=80.6 -> Pg=110.05, Qg=18.6
% INFO    : Gen at bus 27850	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27851	: Pg=58.94, Qg=93.8 -> Pg=75.0, Qg=26.05
% INFO    : Gen at bus 27851	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27852	: Pg=20.67, Qg=10.57 -> Pg=13.085, Qg=2.7
% INFO    : Gen at bus 27852	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27852	: Pg=20.67, Qg=10.57 -> Pg=13.085, Qg=2.7
% INFO    : Gen at bus 27852	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27852	: Pg=20.67, Qg=10.57 -> Pg=13.085, Qg=2.7
% INFO    : Gen at bus 27852	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27852	: Pg=20.67, Qg=10.57 -> Pg=13.085, Qg=2.7
% INFO    : Gen at bus 27852	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27852	: Pg=20.67, Qg=10.57 -> Pg=13.085, Qg=2.7
% INFO    : Gen at bus 27852	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27852	: Pg=6.02, Qg=10.57 -> Pg=13.085, Qg=2.7
% INFO    : Gen at bus 27852	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27852	: Pg=5.59, Qg=10.57 -> Pg=14.2, Qg=1.75
% INFO    : Gen at bus 27852	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27852	: Pg=11.05, Qg=10.57 -> Pg=26.0, Qg=6.0
% INFO    : Gen at bus 27852	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27853	: Pg=98.07, Qg=75.9 -> Pg=108.7, Qg=17.55
% INFO    : Gen at bus 27853	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27854	: Pg=24.52, Qg=25.2 -> Pg=33.5, Qg=3.95
% INFO    : Gen at bus 27854	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27854	: Pg=73.04, Qg=58.8 -> Pg=95.75, Qg=9.15
% INFO    : Gen at bus 27854	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27855	: Pg=31.5, Qg=26.86 -> Pg=43.4, Qg=5.05
% INFO    : Gen at bus 27855	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27855	: Pg=49.65, Qg=26.86 -> Pg=72.65, Qg=16.45
% INFO    : Gen at bus 27855	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27855	: Pg=31.5, Qg=26.86 -> Pg=43.4, Qg=5.05
% INFO    : Gen at bus 27855	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27855	: Pg=31.5, Qg=26.86 -> Pg=43.4, Qg=5.05
% INFO    : Gen at bus 27855	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27855	: Pg=31.5, Qg=26.86 -> Pg=43.4, Qg=5.05
% INFO    : Gen at bus 27855	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27855	: Pg=31.5, Qg=26.86 -> Pg=43.4, Qg=5.05
% INFO    : Gen at bus 27855	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27855	: Pg=31.5, Qg=26.86 -> Pg=43.4, Qg=5.05
% INFO    : Gen at bus 27855	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27855	: Pg=49.65, Qg=26.86 -> Pg=72.65, Qg=15.1
% INFO    : Gen at bus 27855	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27855	: Pg=49.65, Qg=26.86 -> Pg=72.65, Qg=15.1
% INFO    : Gen at bus 27855	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27855	: Pg=49.65, Qg=26.86 -> Pg=72.65, Qg=15.1
% INFO    : Gen at bus 27855	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27856	: Pg=31.42, Qg=26.07 -> Pg=43.35, Qg=4.3
% INFO    : Gen at bus 27856	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27856	: Pg=52.59, Qg=26.07 -> Pg=76.75, Qg=14.8
% INFO    : Gen at bus 27856	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27856	: Pg=48.8, Qg=26.07 -> Pg=71.75, Qg=14.8
% INFO    : Gen at bus 27856	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27856	: Pg=48.8, Qg=26.07 -> Pg=71.75, Qg=14.8
% INFO    : Gen at bus 27856	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27856	: Pg=48.8, Qg=26.07 -> Pg=71.75, Qg=14.8
% INFO    : Gen at bus 27856	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27856	: Pg=48.8, Qg=26.07 -> Pg=71.75, Qg=14.8
% INFO    : Gen at bus 27856	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27856	: Pg=31.42, Qg=26.07 -> Pg=43.35, Qg=4.3
% INFO    : Gen at bus 27856	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27856	: Pg=31.42, Qg=26.07 -> Pg=43.35, Qg=4.3
% INFO    : Gen at bus 27856	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27856	: Pg=31.42, Qg=26.07 -> Pg=43.35, Qg=4.3
% INFO    : Gen at bus 27856	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27856	: Pg=31.42, Qg=26.07 -> Pg=43.35, Qg=4.3
% INFO    : Gen at bus 27856	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27856	: Pg=31.42, Qg=26.07 -> Pg=43.35, Qg=4.3
% INFO    : Gen at bus 27856	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27856	: Pg=62.59, Qg=26.07 -> Pg=81.75, Qg=7.8
% INFO    : Gen at bus 27856	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27856	: Pg=52.59, Qg=26.07 -> Pg=76.75, Qg=14.8
% INFO    : Gen at bus 27856	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27856	: Pg=52.59, Qg=26.07 -> Pg=76.75, Qg=14.8
% INFO    : Gen at bus 27856	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27857	: Pg=47.35, Qg=58.1 -> Pg=69.35, Qg=13.45
% INFO    : Gen at bus 27857	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27857	: Pg=47.35, Qg=58.1 -> Pg=69.35, Qg=13.45
% INFO    : Gen at bus 27857	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27857	: Pg=229.26, Qg=202.86 -> Pg=294.85, Qg=52.95
% INFO    : Gen at bus 27857	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27857	: Pg=294.48, Qg=202.86 -> Pg=429.0, Qg=82.75
% INFO    : Gen at bus 27857	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27860	: Pg=52.13, Qg=41.2 -> Pg=67.5, Qg=6.45
% INFO    : Gen at bus 27860	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27860	: Pg=52.13, Qg=41.2 -> Pg=67.5, Qg=6.45
% INFO    : Gen at bus 27860	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27860	: Pg=52.13, Qg=41.2 -> Pg=67.5, Qg=6.45
% INFO    : Gen at bus 27860	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27860	: Pg=52.13, Qg=41.2 -> Pg=67.5, Qg=6.45
% INFO    : Gen at bus 27860	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27860	: Pg=56.58, Qg=58.1 -> Pg=85.0, Qg=9.05
% INFO    : Gen at bus 27860	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27860	: Pg=56.58, Qg=58.1 -> Pg=85.0, Qg=9.05
% INFO    : Gen at bus 27860	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27861	: Pg=21.08, Qg=21.0 -> Pg=31.65, Qg=3.3
% INFO    : Gen at bus 27861	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27861	: Pg=42.05, Qg=39.7 -> Pg=61.0, Qg=6.2
% INFO    : Gen at bus 27861	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27863	: Pg=100.43, Qg=99.35 -> Pg=133.125, Qg=30.5
% INFO    : Gen at bus 27863	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27863	: Pg=37.25, Qg=49.0 -> Pg=50.76, Qg=11.35
% INFO    : Gen at bus 27863	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27863	: Pg=149.47, Qg=99.35 -> Pg=185.445, Qg=23.9
% INFO    : Gen at bus 27863	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27864	: Pg=126.3, Qg=91.8 -> Pg=101.25, Qg=18.9
% INFO    : Gen at bus 27864	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27864	: Pg=35.13, Qg=42.8 -> Pg=47.865, Qg=9.0
% INFO    : Gen at bus 27864	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27866	: Pg=47.6, Qg=52.5 -> Pg=36.5, Qg=14.6
% INFO    : Gen at bus 27866	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27866	: Pg=41.82, Qg=46.1 -> Pg=31.75, Qg=12.8
% INFO    : Gen at bus 27866	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27868	: Pg=66.0, Qg=40.9 -> Pg=38.0, Qg=9.45
% INFO    : Gen at bus 27868	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27869	: Pg=29.38, Qg=38.6 -> Pg=31.15, Qg=8.9
% INFO    : Gen at bus 27869	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27870	: Pg=31.53, Qg=25.0 -> Pg=45.6, Qg=4.6
% INFO    : Gen at bus 27870	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27870	: Pg=31.53, Qg=25.0 -> Pg=45.6, Qg=4.6
% INFO    : Gen at bus 27870	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27870	: Pg=31.53, Qg=25.0 -> Pg=45.6, Qg=4.6
% INFO    : Gen at bus 27870	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27870	: Pg=20.86, Qg=21.4 -> Pg=27.25, Qg=4.95
% INFO    : Gen at bus 27870	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27870	: Pg=20.94, Qg=23.2 -> Pg=28.75, Qg=5.35
% INFO    : Gen at bus 27870	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27870	: Pg=41.88, Qg=25.0 -> Pg=57.5, Qg=14.05
% INFO    : Gen at bus 27870	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27871	: Pg=2.02, Qg=2.59 -> Pg=2.785, Qg=0.69
% INFO    : Gen at bus 27871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27871	: Pg=2.02, Qg=2.59 -> Pg=2.785, Qg=0.69
% INFO    : Gen at bus 27871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27871	: Pg=2.02, Qg=2.59 -> Pg=2.785, Qg=0.69
% INFO    : Gen at bus 27871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27871	: Pg=2.02, Qg=2.59 -> Pg=2.785, Qg=0.69
% INFO    : Gen at bus 27871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27871	: Pg=2.02, Qg=2.59 -> Pg=2.785, Qg=0.69
% INFO    : Gen at bus 27871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27871	: Pg=2.02, Qg=2.59 -> Pg=2.785, Qg=0.69
% INFO    : Gen at bus 27871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27871	: Pg=2.02, Qg=2.59 -> Pg=2.785, Qg=0.69
% INFO    : Gen at bus 27871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27871	: Pg=2.02, Qg=2.59 -> Pg=2.785, Qg=0.69
% INFO    : Gen at bus 27871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27871	: Pg=2.02, Qg=2.59 -> Pg=2.785, Qg=0.69
% INFO    : Gen at bus 27871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27871	: Pg=2.02, Qg=2.59 -> Pg=2.785, Qg=0.69
% INFO    : Gen at bus 27871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27871	: Pg=2.02, Qg=2.59 -> Pg=2.785, Qg=0.69
% INFO    : Gen at bus 27871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27871	: Pg=2.02, Qg=2.59 -> Pg=2.785, Qg=0.69
% INFO    : Gen at bus 27871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27871	: Pg=2.02, Qg=2.59 -> Pg=2.785, Qg=0.69
% INFO    : Gen at bus 27871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27871	: Pg=2.02, Qg=2.59 -> Pg=2.785, Qg=0.69
% INFO    : Gen at bus 27871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27871	: Pg=2.02, Qg=2.59 -> Pg=2.785, Qg=0.69
% INFO    : Gen at bus 27871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27871	: Pg=2.02, Qg=2.59 -> Pg=2.785, Qg=0.69
% INFO    : Gen at bus 27871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27872	: Pg=15.56, Qg=6.7 -> Pg=21.5, Qg=0.0
% INFO    : Gen at bus 27872	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27872	: Pg=25.93, Qg=11.2 -> Pg=35.5, Qg=0.0
% INFO    : Gen at bus 27872	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27872	: Pg=33.45, Qg=11.8 -> Pg=44.95, Qg=0.0
% INFO    : Gen at bus 27872	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27873	: Pg=12.5, Qg=19.9 -> Pg=15.75, Qg=5.55
% INFO    : Gen at bus 27873	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27873	: Pg=27.06, Qg=43.1 -> Pg=33.7, Qg=12.0
% INFO    : Gen at bus 27873	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27873	: Pg=27.06, Qg=43.1 -> Pg=33.7, Qg=12.0
% INFO    : Gen at bus 27873	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27874	: Pg=31.42, Qg=27.5 -> Pg=43.35, Qg=4.3
% INFO    : Gen at bus 27874	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27874	: Pg=31.42, Qg=27.5 -> Pg=43.35, Qg=4.3
% INFO    : Gen at bus 27874	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27874	: Pg=31.42, Qg=27.5 -> Pg=43.35, Qg=4.3
% INFO    : Gen at bus 27874	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27874	: Pg=31.42, Qg=27.5 -> Pg=43.35, Qg=4.3
% INFO    : Gen at bus 27874	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27877	: Pg=25.46, Qg=29.13 -> Pg=29.5, Qg=7.75
% INFO    : Gen at bus 27877	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27877	: Pg=35.32, Qg=29.13 -> Pg=39.95, Qg=10.7
% INFO    : Gen at bus 27877	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27879	: Pg=23.09, Qg=30.4 -> Pg=34.5, Qg=7.05
% INFO    : Gen at bus 27879	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27879	: Pg=23.09, Qg=30.4 -> Pg=34.5, Qg=7.05
% INFO    : Gen at bus 27879	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27882	: Pg=31.83, Qg=29.0 -> Pg=28.4, Qg=6.7
% INFO    : Gen at bus 27882	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27883	: Pg=21.45, Qg=28.2 -> Pg=25.25, Qg=6.5
% INFO    : Gen at bus 27883	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27884	: Pg=5.23, Qg=5.67 -> Pg=7.05, Qg=0.985
% INFO    : Gen at bus 27884	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27884	: Pg=5.23, Qg=5.67 -> Pg=7.05, Qg=0.985
% INFO    : Gen at bus 27884	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27884	: Pg=5.23, Qg=5.67 -> Pg=7.05, Qg=0.985
% INFO    : Gen at bus 27884	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27884	: Pg=5.23, Qg=5.67 -> Pg=7.05, Qg=0.985
% INFO    : Gen at bus 27884	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27885	: Pg=44.0, Qg=27.3 -> Pg=23.25, Qg=6.3
% INFO    : Gen at bus 27885	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27885	: Pg=74.4, Qg=46.1 -> Pg=38.45, Qg=10.65
% INFO    : Gen at bus 27885	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27886	: Pg=6.84, Qg=4.77 -> Pg=9.75, Qg=0.0
% INFO    : Gen at bus 27886	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27886	: Pg=6.84, Qg=4.77 -> Pg=9.75, Qg=0.0
% INFO    : Gen at bus 27886	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27886	: Pg=6.84, Qg=4.77 -> Pg=9.75, Qg=0.0
% INFO    : Gen at bus 27886	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27887	: Pg=43.0, Qg=20.8 -> Pg=42.545, Qg=3.25
% INFO    : Gen at bus 27887	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27888	: Pg=23.04, Qg=25.7 -> Pg=31.7, Qg=5.95
% INFO    : Gen at bus 27888	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27888	: Pg=23.04, Qg=25.7 -> Pg=31.7, Qg=5.95
% INFO    : Gen at bus 27888	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27888	: Pg=61.3, Qg=55.38 -> Pg=85.0, Qg=18.65
% INFO    : Gen at bus 27888	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27888	: Pg=61.3, Qg=55.38 -> Pg=85.0, Qg=18.65
% INFO    : Gen at bus 27888	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27890	: Pg=31.08, Qg=20.9 -> Pg=36.6, Qg=3.25
% INFO    : Gen at bus 27890	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27890	: Pg=22.99, Qg=19.2 -> Pg=30.8, Qg=3.0
% INFO    : Gen at bus 27890	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27891	: Pg=38.5, Qg=23.9 -> Pg=21.75, Qg=5.55
% INFO    : Gen at bus 27891	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27891	: Pg=38.5, Qg=23.9 -> Pg=21.75, Qg=5.55
% INFO    : Gen at bus 27891	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27892	: Pg=9.05, Qg=11.9 -> Pg=12.6, Qg=2.75
% INFO    : Gen at bus 27892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27892	: Pg=9.05, Qg=11.9 -> Pg=12.6, Qg=2.75
% INFO    : Gen at bus 27892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27893	: Pg=17.92, Qg=23.6 -> Pg=20.0, Qg=5.45
% INFO    : Gen at bus 27893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27895	: Pg=5.0, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27895	: Pg=5.0, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27895	: Pg=5.0, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27895	: Pg=5.0, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27895	: Pg=80.41, Qg=143.98 -> Pg=241.2, Qg=0.0
% INFO    : Gen at bus 27895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27895	: Pg=80.41, Qg=143.98 -> Pg=241.2, Qg=0.0
% INFO    : Gen at bus 27895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27895	: Pg=89.29, Qg=143.98 -> Pg=168.64, Qg=35.5
% INFO    : Gen at bus 27895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27895	: Pg=89.29, Qg=143.98 -> Pg=168.64, Qg=35.5
% INFO    : Gen at bus 27895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27895	: Pg=5.86, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27895	: Pg=5.0, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27895	: Pg=5.0, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27895	: Pg=5.0, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27895	: Pg=5.0, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27895	: Pg=5.0, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27895	: Pg=5.0, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27895	: Pg=5.0, Qg=21.2 -> Pg=19.6, Qg=4.9
% INFO    : Gen at bus 27895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27897	: Pg=15.89, Qg=20.9 -> Pg=22.85, Qg=4.85
% INFO    : Gen at bus 27897	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27897	: Pg=15.89, Qg=20.9 -> Pg=22.85, Qg=4.85
% INFO    : Gen at bus 27897	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27897	: Pg=20.23, Qg=26.6 -> Pg=27.45, Qg=6.15
% INFO    : Gen at bus 27897	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27897	: Pg=20.23, Qg=26.6 -> Pg=27.45, Qg=6.15
% INFO    : Gen at bus 27897	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27899	: Pg=22.54, Qg=6.8 -> Pg=26.4, Qg=0.0
% INFO    : Gen at bus 27899	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27899	: Pg=15.09, Qg=19.8 -> Pg=17.5, Qg=4.55
% INFO    : Gen at bus 27899	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27900	: Pg=3.21, Qg=4.22 -> Pg=4.75, Qg=0.975
% INFO    : Gen at bus 27900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27900	: Pg=3.21, Qg=4.22 -> Pg=4.75, Qg=0.975
% INFO    : Gen at bus 27900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27900	: Pg=3.21, Qg=4.22 -> Pg=4.75, Qg=0.975
% INFO    : Gen at bus 27900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27900	: Pg=3.21, Qg=4.22 -> Pg=4.75, Qg=0.975
% INFO    : Gen at bus 27900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27900	: Pg=3.21, Qg=4.22 -> Pg=4.75, Qg=0.975
% INFO    : Gen at bus 27900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27900	: Pg=3.21, Qg=4.22 -> Pg=4.75, Qg=0.975
% INFO    : Gen at bus 27900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27900	: Pg=12.5, Qg=16.4 -> Pg=17.25, Qg=3.8
% INFO    : Gen at bus 27900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27900	: Pg=21.79, Qg=16.6 -> Pg=26.2, Qg=3.05
% INFO    : Gen at bus 27900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27901	: Pg=14.71, Qg=10.3 -> Pg=18.1, Qg=0.0
% INFO    : Gen at bus 27901	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27902	: Pg=7.07, Qg=9.3 -> Pg=9.0, Qg=2.15
% INFO    : Gen at bus 27902	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27902	: Pg=7.07, Qg=9.3 -> Pg=9.0, Qg=2.15
% INFO    : Gen at bus 27902	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27902	: Pg=124.01, Qg=34.51 -> Pg=140.0, Qg=22.95
% INFO    : Gen at bus 27902	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27902	: Pg=23.58, Qg=31.0 -> Pg=35.0, Qg=7.15
% INFO    : Gen at bus 27902	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27902	: Pg=52.18, Qg=34.51 -> Pg=68.5, Qg=12.45
% INFO    : Gen at bus 27902	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27903	: Pg=30.0, Qg=18.6 -> Pg=17.0, Qg=4.3
% INFO    : Gen at bus 27903	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27904	: Pg=13.67, Qg=0.0 -> Pg=17.0, Qg=0.0
% INFO    : Gen at bus 27904	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27905	: Pg=12.87, Qg=16.9 -> Pg=15.65, Qg=3.9
% INFO    : Gen at bus 27905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27906	: Pg=12.26, Qg=16.1 -> Pg=15.0, Qg=3.7
% INFO    : Gen at bus 27906	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27906	: Pg=23.81, Qg=31.3 -> Pg=28.75, Qg=7.25
% INFO    : Gen at bus 27906	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27907	: Pg=25.0, Qg=12.1 -> Pg=12.5, Qg=1.9
% INFO    : Gen at bus 27907	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27908	: Pg=12.6, Qg=11.6 -> Pg=18.0, Qg=1.8
% INFO    : Gen at bus 27908	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27908	: Pg=12.6, Qg=11.6 -> Pg=18.0, Qg=1.8
% INFO    : Gen at bus 27908	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27910	: Pg=10.39, Qg=10.7 -> Pg=15.55, Qg=1.65
% INFO    : Gen at bus 27910	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27911	: Pg=2.75, Qg=0.0 -> Pg=2.75, Qg=0.0
% INFO    : Gen at bus 27911	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27911	: Pg=2.75, Qg=0.0 -> Pg=2.75, Qg=0.0
% INFO    : Gen at bus 27911	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27911	: Pg=2.75, Qg=0.0 -> Pg=2.75, Qg=0.0
% INFO    : Gen at bus 27911	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27911	: Pg=2.75, Qg=0.0 -> Pg=2.75, Qg=0.0
% INFO    : Gen at bus 27911	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27911	: Pg=2.75, Qg=0.0 -> Pg=2.75, Qg=0.0
% INFO    : Gen at bus 27911	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27911	: Pg=2.75, Qg=0.0 -> Pg=2.75, Qg=0.0
% INFO    : Gen at bus 27911	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27911	: Pg=2.75, Qg=0.0 -> Pg=2.75, Qg=0.0
% INFO    : Gen at bus 27911	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27911	: Pg=2.75, Qg=0.0 -> Pg=2.75, Qg=0.0
% INFO    : Gen at bus 27911	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27912	: Pg=9.9, Qg=13.0 -> Pg=12.5, Qg=3.0
% INFO    : Gen at bus 27912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27913	: Pg=9.43, Qg=12.4 -> Pg=11.5, Qg=2.85
% INFO    : Gen at bus 27913	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27914	: Pg=10.5, Qg=12.4 -> Pg=15.0, Qg=2.85
% INFO    : Gen at bus 27914	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27914	: Pg=19.98, Qg=24.2 -> Pg=29.0, Qg=5.6
% INFO    : Gen at bus 27914	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27915	: Pg=1050.0, Qg=-171.26 -> Pg=705.0, Qg=87.55
% INFO    : Gen at bus 27915	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27915	: Pg=1050.0, Qg=-171.26 -> Pg=705.0, Qg=87.55
% INFO    : Gen at bus 27915	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27916	: Pg=453.84, Qg=45.0 -> Pg=691.0, Qg=136.35
% INFO    : Gen at bus 27916	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27916	: Pg=453.84, Qg=45.0 -> Pg=691.0, Qg=136.35
% INFO    : Gen at bus 27916	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27916	: Pg=6.32, Qg=25.6 -> Pg=28.9, Qg=4.0
% INFO    : Gen at bus 27916	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27917	: Pg=372.31, Qg=53.43 -> Pg=620.5, Qg=67.25
% INFO    : Gen at bus 27917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27917	: Pg=372.31, Qg=53.43 -> Pg=620.5, Qg=67.25
% INFO    : Gen at bus 27917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27918	: Pg=857.1, Qg=-20.94 -> Pg=553.55, Qg=88.45
% INFO    : Gen at bus 27918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27918	: Pg=864.7, Qg=-20.94 -> Pg=557.35, Qg=89.25
% INFO    : Gen at bus 27918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27919	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27919	: Pg=951.97, Qg=590.0 -> Pg=751.0, Qg=136.35
% INFO    : Gen at bus 27919	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27919	: Pg=41.8, Qg=22.4 -> Pg=29.575, Qg=4.25
% INFO    : Gen at bus 27919	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27919	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27919	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27920	: Pg=5.18, Qg=17.3 -> Pg=28.76, Qg=4.91
% INFO    : Gen at bus 27920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27920	: Pg=5.18, Qg=17.3 -> Pg=28.76, Qg=4.91
% INFO    : Gen at bus 27920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27920	: Pg=5.18, Qg=17.3 -> Pg=28.76, Qg=4.91
% INFO    : Gen at bus 27920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27920	: Pg=5.18, Qg=17.3 -> Pg=28.76, Qg=4.91
% INFO    : Gen at bus 27920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27920	: Pg=5.18, Qg=17.3 -> Pg=28.76, Qg=4.91
% INFO    : Gen at bus 27920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27920	: Pg=5.18, Qg=17.3 -> Pg=28.76, Qg=4.91
% INFO    : Gen at bus 27920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27920	: Pg=5.18, Qg=17.3 -> Pg=28.76, Qg=4.91
% INFO    : Gen at bus 27920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27920	: Pg=5.18, Qg=17.3 -> Pg=28.76, Qg=4.91
% INFO    : Gen at bus 27920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27920	: Pg=5.18, Qg=17.3 -> Pg=28.76, Qg=4.91
% INFO    : Gen at bus 27920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27920	: Pg=5.18, Qg=17.3 -> Pg=28.76, Qg=4.91
% INFO    : Gen at bus 27920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27920	: Pg=5.18, Qg=17.3 -> Pg=28.76, Qg=4.91
% INFO    : Gen at bus 27920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27920	: Pg=5.18, Qg=17.3 -> Pg=28.76, Qg=4.91
% INFO    : Gen at bus 27920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27921	: Pg=5.33, Qg=12.09 -> Pg=28.55, Qg=7.6
% INFO    : Gen at bus 27921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27921	: Pg=4.93, Qg=12.09 -> Pg=24.84, Qg=6.595
% INFO    : Gen at bus 27921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27921	: Pg=4.93, Qg=12.09 -> Pg=24.84, Qg=6.595
% INFO    : Gen at bus 27921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27921	: Pg=4.93, Qg=12.09 -> Pg=24.84, Qg=6.595
% INFO    : Gen at bus 27921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27921	: Pg=4.93, Qg=12.09 -> Pg=24.84, Qg=6.595
% INFO    : Gen at bus 27921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27921	: Pg=19.51, Qg=12.09 -> Pg=28.55, Qg=7.6
% INFO    : Gen at bus 27921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27921	: Pg=25.04, Qg=12.09 -> Pg=28.55, Qg=7.6
% INFO    : Gen at bus 27921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27921	: Pg=25.04, Qg=12.09 -> Pg=28.55, Qg=7.6
% INFO    : Gen at bus 27921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27921	: Pg=25.04, Qg=12.09 -> Pg=28.55, Qg=7.6
% INFO    : Gen at bus 27921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27921	: Pg=25.04, Qg=12.09 -> Pg=28.55, Qg=7.6
% INFO    : Gen at bus 27921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27921	: Pg=21.64, Qg=12.09 -> Pg=24.84, Qg=6.595
% INFO    : Gen at bus 27921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27921	: Pg=21.64, Qg=12.09 -> Pg=24.84, Qg=6.595
% INFO    : Gen at bus 27921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27921	: Pg=21.64, Qg=12.09 -> Pg=24.84, Qg=6.595
% INFO    : Gen at bus 27921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27922	: Pg=107.49, Qg=-7.61 -> Pg=199.6, Qg=42.85
% INFO    : Gen at bus 27922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27922	: Pg=152.59, Qg=-7.61 -> Pg=251.3, Qg=49.05
% INFO    : Gen at bus 27922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27922	: Pg=263.62, Qg=-7.61 -> Pg=397.0, Qg=77.9
% INFO    : Gen at bus 27922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27922	: Pg=263.62, Qg=-7.61 -> Pg=397.0, Qg=77.9
% INFO    : Gen at bus 27922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27923	: Pg=32.98, Qg=20.2 -> Pg=36.9, Qg=3.15
% INFO    : Gen at bus 27923	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27923	: Pg=32.98, Qg=20.2 -> Pg=36.9, Qg=3.15
% INFO    : Gen at bus 27923	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27923	: Pg=141.08, Qg=172.8 -> Pg=207.945, Qg=36.55
% INFO    : Gen at bus 27923	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27923	: Pg=141.08, Qg=172.8 -> Pg=207.945, Qg=36.55
% INFO    : Gen at bus 27923	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27924	: Pg=282.59, Qg=48.35 -> Pg=191.3, Qg=21.35
% INFO    : Gen at bus 27924	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27924	: Pg=282.59, Qg=48.35 -> Pg=191.3, Qg=21.35
% INFO    : Gen at bus 27924	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27924	: Pg=282.59, Qg=48.35 -> Pg=191.3, Qg=21.35
% INFO    : Gen at bus 27924	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27925	: Pg=171.64, Qg=-16.14 -> Pg=223.24, Qg=21.25
% INFO    : Gen at bus 27925	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27925	: Pg=171.58, Qg=-16.14 -> Pg=223.21, Qg=21.25
% INFO    : Gen at bus 27925	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27925	: Pg=96.53, Qg=-16.14 -> Pg=147.32, Qg=29.1
% INFO    : Gen at bus 27925	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27925	: Pg=96.53, Qg=-16.14 -> Pg=147.32, Qg=29.1
% INFO    : Gen at bus 27925	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27925	: Pg=96.53, Qg=-16.14 -> Pg=147.32, Qg=29.1
% INFO    : Gen at bus 27925	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27925	: Pg=96.53, Qg=-16.14 -> Pg=147.32, Qg=29.1
% INFO    : Gen at bus 27925	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27926	: Pg=126.04, Qg=19.27 -> Pg=162.025, Qg=29.1
% INFO    : Gen at bus 27926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27926	: Pg=125.49, Qg=19.27 -> Pg=161.75, Qg=29.1
% INFO    : Gen at bus 27926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27926	: Pg=101.33, Qg=19.27 -> Pg=154.645, Qg=30.55
% INFO    : Gen at bus 27926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27926	: Pg=101.33, Qg=19.27 -> Pg=154.645, Qg=30.55
% INFO    : Gen at bus 27926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27926	: Pg=96.48, Qg=19.27 -> Pg=147.25, Qg=29.1
% INFO    : Gen at bus 27926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27926	: Pg=96.48, Qg=19.27 -> Pg=147.25, Qg=29.1
% INFO    : Gen at bus 27926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27927	: Pg=93.27, Qg=42.93 -> Pg=131.9, Qg=25.75
% INFO    : Gen at bus 27927	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27927	: Pg=104.99, Qg=42.93 -> Pg=149.7, Qg=28.55
% INFO    : Gen at bus 27927	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27927	: Pg=104.99, Qg=42.93 -> Pg=149.7, Qg=28.55
% INFO    : Gen at bus 27927	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27928	: Pg=104.98, Qg=0.19 -> Pg=149.45, Qg=28.5
% INFO    : Gen at bus 27928	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27928	: Pg=104.98, Qg=0.19 -> Pg=149.45, Qg=28.5
% INFO    : Gen at bus 27928	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27928	: Pg=104.98, Qg=0.19 -> Pg=149.45, Qg=28.5
% INFO    : Gen at bus 27928	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27928	: Pg=104.98, Qg=0.19 -> Pg=149.45, Qg=28.5
% INFO    : Gen at bus 27928	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27929	: Pg=114.64, Qg=32.33 -> Pg=147.7, Qg=14.0
% INFO    : Gen at bus 27929	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27929	: Pg=115.03, Qg=32.33 -> Pg=155.35, Qg=15.15
% INFO    : Gen at bus 27929	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27930	: Pg=94.59, Qg=-10.09 -> Pg=136.6, Qg=13.8
% INFO    : Gen at bus 27930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27930	: Pg=94.59, Qg=-10.09 -> Pg=136.6, Qg=13.8
% INFO    : Gen at bus 27930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27930	: Pg=94.59, Qg=-10.09 -> Pg=136.6, Qg=13.8
% INFO    : Gen at bus 27930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27930	: Pg=94.59, Qg=-10.09 -> Pg=136.6, Qg=13.8
% INFO    : Gen at bus 27930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27930	: Pg=94.59, Qg=-10.09 -> Pg=136.6, Qg=13.8
% INFO    : Gen at bus 27930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27930	: Pg=94.59, Qg=-10.09 -> Pg=136.6, Qg=13.8
% INFO    : Gen at bus 27930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27931	: Pg=79.51, Qg=16.1 -> Pg=127.5, Qg=25.8
% INFO    : Gen at bus 27931	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27931	: Pg=79.51, Qg=16.1 -> Pg=127.5, Qg=25.8
% INFO    : Gen at bus 27931	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27932	: Pg=83.74, Qg=13.86 -> Pg=121.3, Qg=13.4
% INFO    : Gen at bus 27932	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27932	: Pg=59.54, Qg=13.86 -> Pg=79.15, Qg=14.5
% INFO    : Gen at bus 27932	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27932	: Pg=59.54, Qg=13.86 -> Pg=79.15, Qg=14.5
% INFO    : Gen at bus 27932	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27932	: Pg=59.54, Qg=13.86 -> Pg=79.15, Qg=14.5
% INFO    : Gen at bus 27932	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27932	: Pg=59.54, Qg=13.86 -> Pg=79.15, Qg=14.5
% INFO    : Gen at bus 27932	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27932	: Pg=59.54, Qg=13.86 -> Pg=79.15, Qg=14.5
% INFO    : Gen at bus 27932	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27932	: Pg=59.54, Qg=13.86 -> Pg=79.15, Qg=14.5
% INFO    : Gen at bus 27932	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27932	: Pg=59.54, Qg=13.86 -> Pg=79.15, Qg=14.5
% INFO    : Gen at bus 27932	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27932	: Pg=59.54, Qg=13.86 -> Pg=79.15, Qg=14.5
% INFO    : Gen at bus 27932	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27933	: Pg=134.41, Qg=38.53 -> Pg=153.0, Qg=25.2
% INFO    : Gen at bus 27933	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27933	: Pg=69.41, Qg=38.53 -> Pg=120.5, Qg=25.2
% INFO    : Gen at bus 27933	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27933	: Pg=134.7, Qg=38.53 -> Pg=158.85, Qg=26.85
% INFO    : Gen at bus 27933	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27934	: Pg=104.39, Qg=56.43 -> Pg=137.65, Qg=25.1
% INFO    : Gen at bus 27934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27934	: Pg=104.39, Qg=56.43 -> Pg=137.65, Qg=25.1
% INFO    : Gen at bus 27934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27934	: Pg=104.39, Qg=56.43 -> Pg=137.65, Qg=25.1
% INFO    : Gen at bus 27934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27934	: Pg=104.39, Qg=56.43 -> Pg=137.65, Qg=25.1
% INFO    : Gen at bus 27934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27935	: Pg=114.28, Qg=60.8 -> Pg=140.5, Qg=24.5
% INFO    : Gen at bus 27935	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27935	: Pg=114.28, Qg=60.8 -> Pg=140.5, Qg=24.5
% INFO    : Gen at bus 27935	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27935	: Pg=70.66, Qg=60.8 -> Pg=145.5, Qg=32.4
% INFO    : Gen at bus 27935	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27936	: Pg=111.13, Qg=80.7 -> Pg=136.0, Qg=23.65
% INFO    : Gen at bus 27936	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27936	: Pg=111.13, Qg=80.7 -> Pg=136.0, Qg=23.65
% INFO    : Gen at bus 27936	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27936	: Pg=110.13, Qg=80.7 -> Pg=135.5, Qg=23.65
% INFO    : Gen at bus 27936	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27937	: Pg=104.12, Qg=79.75 -> Pg=132.35, Qg=12.45
% INFO    : Gen at bus 27937	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27937	: Pg=104.12, Qg=79.75 -> Pg=132.35, Qg=12.45
% INFO    : Gen at bus 27937	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27937	: Pg=104.12, Qg=79.75 -> Pg=132.35, Qg=12.45
% INFO    : Gen at bus 27937	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27938	: Pg=163.2, Qg=19.96 -> Pg=114.1, Qg=23.35
% INFO    : Gen at bus 27938	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27938	: Pg=41.8, Qg=19.96 -> Pg=36.4, Qg=3.15
% INFO    : Gen at bus 27938	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27938	: Pg=41.8, Qg=19.96 -> Pg=36.4, Qg=3.15
% INFO    : Gen at bus 27938	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27938	: Pg=41.8, Qg=19.96 -> Pg=29.575, Qg=4.25
% INFO    : Gen at bus 27938	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27939	: Pg=147.0, Qg=50.15 -> Pg=118.5, Qg=21.05
% INFO    : Gen at bus 27939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27939	: Pg=147.0, Qg=50.15 -> Pg=118.5, Qg=21.05
% INFO    : Gen at bus 27939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27939	: Pg=147.0, Qg=50.15 -> Pg=118.5, Qg=21.05
% INFO    : Gen at bus 27939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27939	: Pg=147.0, Qg=50.15 -> Pg=118.5, Qg=21.05
% INFO    : Gen at bus 27939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27939	: Pg=301.99, Qg=50.15 -> Pg=196.0, Qg=43.25
% INFO    : Gen at bus 27939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27939	: Pg=301.99, Qg=50.15 -> Pg=196.0, Qg=43.25
% INFO    : Gen at bus 27939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27940	: Pg=125.0, Qg=16.2 -> Pg=87.5, Qg=9.4
% INFO    : Gen at bus 27940	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27940	: Pg=125.0, Qg=16.2 -> Pg=87.5, Qg=9.4
% INFO    : Gen at bus 27940	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27940	: Pg=125.0, Qg=16.2 -> Pg=87.5, Qg=9.4
% INFO    : Gen at bus 27940	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27940	: Pg=577.98, Qg=16.2 -> Pg=401.5, Qg=82.75
% INFO    : Gen at bus 27940	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27941	: Pg=125.0, Qg=41.1 -> Pg=122.5, Qg=0.0
% INFO    : Gen at bus 27941	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27941	: Pg=125.0, Qg=41.1 -> Pg=122.5, Qg=0.0
% INFO    : Gen at bus 27941	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27941	: Pg=125.0, Qg=41.1 -> Pg=122.5, Qg=0.0
% INFO    : Gen at bus 27941	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27941	: Pg=125.0, Qg=41.1 -> Pg=122.5, Qg=0.0
% INFO    : Gen at bus 27941	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27942	: Pg=57.76, Qg=59.3 -> Pg=83.75, Qg=9.25
% INFO    : Gen at bus 27942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27942	: Pg=57.76, Qg=59.3 -> Pg=83.75, Qg=9.25
% INFO    : Gen at bus 27942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27942	: Pg=57.76, Qg=59.3 -> Pg=83.75, Qg=9.25
% INFO    : Gen at bus 27942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27942	: Pg=73.65, Qg=71.55 -> Pg=105.6, Qg=22.35
% INFO    : Gen at bus 27942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27942	: Pg=73.65, Qg=71.55 -> Pg=105.6, Qg=22.35
% INFO    : Gen at bus 27942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27942	: Pg=190.35, Qg=71.55 -> Pg=251.85, Qg=57.8
% INFO    : Gen at bus 27942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27942	: Pg=190.35, Qg=71.55 -> Pg=251.85, Qg=57.8
% INFO    : Gen at bus 27942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27943	: Pg=121.0, Qg=39.99 -> Pg=93.0, Qg=17.35
% INFO    : Gen at bus 27943	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27943	: Pg=121.0, Qg=39.99 -> Pg=93.0, Qg=17.35
% INFO    : Gen at bus 27943	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27943	: Pg=164.0, Qg=39.99 -> Pg=116.5, Qg=23.45
% INFO    : Gen at bus 27943	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27943	: Pg=164.0, Qg=39.99 -> Pg=116.5, Qg=23.45
% INFO    : Gen at bus 27943	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27944	: Pg=68.03, Qg=40.89 -> Pg=93.0, Qg=17.35
% INFO    : Gen at bus 27944	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27944	: Pg=68.03, Qg=40.89 -> Pg=93.0, Qg=17.35
% INFO    : Gen at bus 27944	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27945	: Pg=73.03, Qg=25.75 -> Pg=95.5, Qg=17.35
% INFO    : Gen at bus 27945	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27945	: Pg=73.03, Qg=25.75 -> Pg=95.5, Qg=17.35
% INFO    : Gen at bus 27945	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27945	: Pg=73.03, Qg=25.75 -> Pg=95.5, Qg=17.35
% INFO    : Gen at bus 27945	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27945	: Pg=73.03, Qg=25.75 -> Pg=95.5, Qg=17.35
% INFO    : Gen at bus 27945	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27945	: Pg=73.03, Qg=25.75 -> Pg=95.5, Qg=17.35
% INFO    : Gen at bus 27945	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27945	: Pg=73.03, Qg=25.75 -> Pg=95.5, Qg=17.35
% INFO    : Gen at bus 27945	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27946	: Pg=82.65, Qg=37.25 -> Pg=93.25, Qg=8.05
% INFO    : Gen at bus 27946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27946	: Pg=82.65, Qg=37.25 -> Pg=93.25, Qg=8.05
% INFO    : Gen at bus 27946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27946	: Pg=82.75, Qg=37.25 -> Pg=95.0, Qg=8.3
% INFO    : Gen at bus 27946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27947	: Pg=57.3, Qg=57.0 -> Pg=73.45, Qg=13.2
% INFO    : Gen at bus 27947	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27947	: Pg=57.3, Qg=57.0 -> Pg=73.45, Qg=13.2
% INFO    : Gen at bus 27947	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27948	: Pg=72.26, Qg=21.58 -> Pg=80.95, Qg=13.2
% INFO    : Gen at bus 27948	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27948	: Pg=72.26, Qg=21.58 -> Pg=80.95, Qg=13.2
% INFO    : Gen at bus 27948	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27948	: Pg=72.26, Qg=21.58 -> Pg=80.95, Qg=13.2
% INFO    : Gen at bus 27948	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27948	: Pg=72.26, Qg=21.58 -> Pg=80.95, Qg=13.2
% INFO    : Gen at bus 27948	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27948	: Pg=72.26, Qg=21.58 -> Pg=80.95, Qg=13.2
% INFO    : Gen at bus 27948	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27948	: Pg=72.26, Qg=21.58 -> Pg=80.95, Qg=13.2
% INFO    : Gen at bus 27948	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27948	: Pg=72.26, Qg=21.58 -> Pg=80.95, Qg=13.2
% INFO    : Gen at bus 27948	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27948	: Pg=72.26, Qg=21.58 -> Pg=80.95, Qg=13.2
% INFO    : Gen at bus 27948	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27948	: Pg=72.26, Qg=21.58 -> Pg=80.95, Qg=13.2
% INFO    : Gen at bus 27948	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27948	: Pg=72.26, Qg=21.58 -> Pg=80.95, Qg=13.2
% INFO    : Gen at bus 27948	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27949	: Pg=62.17, Qg=1.81 -> Pg=73.25, Qg=12.4
% INFO    : Gen at bus 27949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27949	: Pg=62.17, Qg=1.81 -> Pg=73.25, Qg=12.4
% INFO    : Gen at bus 27949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27949	: Pg=62.17, Qg=1.81 -> Pg=73.25, Qg=12.4
% INFO    : Gen at bus 27949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27949	: Pg=62.17, Qg=1.81 -> Pg=73.25, Qg=12.4
% INFO    : Gen at bus 27949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27949	: Pg=62.17, Qg=1.81 -> Pg=73.25, Qg=12.4
% INFO    : Gen at bus 27949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27949	: Pg=62.17, Qg=1.81 -> Pg=73.25, Qg=12.4
% INFO    : Gen at bus 27949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27949	: Pg=62.17, Qg=1.81 -> Pg=73.25, Qg=12.4
% INFO    : Gen at bus 27949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27949	: Pg=62.17, Qg=1.81 -> Pg=73.25, Qg=12.4
% INFO    : Gen at bus 27949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27950	: Pg=80.0, Qg=21.87 -> Pg=80.0, Qg=0.0
% INFO    : Gen at bus 27950	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27950	: Pg=85.0, Qg=21.87 -> Pg=85.0, Qg=6.45
% INFO    : Gen at bus 27950	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27950	: Pg=85.0, Qg=21.87 -> Pg=85.0, Qg=6.45
% INFO    : Gen at bus 27950	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27950	: Pg=85.0, Qg=21.87 -> Pg=85.0, Qg=6.45
% INFO    : Gen at bus 27950	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27950	: Pg=85.0, Qg=21.87 -> Pg=85.0, Qg=6.45
% INFO    : Gen at bus 27950	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27951	: Pg=12.73, Qg=8.88 -> Pg=17.5, Qg=3.85
% INFO    : Gen at bus 27951	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27951	: Pg=14.15, Qg=8.88 -> Pg=19.0, Qg=4.3
% INFO    : Gen at bus 27951	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27951	: Pg=7.26, Qg=8.88 -> Pg=10.15, Qg=2.46
% INFO    : Gen at bus 27951	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27951	: Pg=7.26, Qg=8.88 -> Pg=10.15, Qg=2.46
% INFO    : Gen at bus 27951	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27951	: Pg=7.26, Qg=8.88 -> Pg=10.15, Qg=2.46
% INFO    : Gen at bus 27951	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27951	: Pg=7.26, Qg=8.88 -> Pg=10.15, Qg=2.46
% INFO    : Gen at bus 27951	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27951	: Pg=7.26, Qg=8.88 -> Pg=10.15, Qg=2.46
% INFO    : Gen at bus 27951	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27952	: Pg=75.0, Qg=14.37 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 27952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27952	: Pg=75.0, Qg=14.37 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 27952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27952	: Pg=75.0, Qg=14.37 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 27952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27952	: Pg=75.0, Qg=14.37 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 27952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27952	: Pg=82.0, Qg=14.37 -> Pg=82.0, Qg=0.0
% INFO    : Gen at bus 27952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27952	: Pg=82.0, Qg=14.37 -> Pg=82.0, Qg=0.0
% INFO    : Gen at bus 27952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27952	: Pg=82.0, Qg=14.37 -> Pg=82.0, Qg=0.0
% INFO    : Gen at bus 27952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27952	: Pg=82.0, Qg=14.37 -> Pg=82.0, Qg=0.0
% INFO    : Gen at bus 27952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27953	: Pg=23.58, Qg=10.2 -> Pg=25.05, Qg=0.0
% INFO    : Gen at bus 27953	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27953	: Pg=11.35, Qg=7.1 -> Pg=12.085, Qg=0.0
% INFO    : Gen at bus 27953	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27953	: Pg=11.35, Qg=7.1 -> Pg=12.085, Qg=0.0
% INFO    : Gen at bus 27953	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27953	: Pg=11.35, Qg=7.1 -> Pg=12.085, Qg=0.0
% INFO    : Gen at bus 27953	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27954	: Pg=12.0, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 27954	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27954	: Pg=12.0, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 27954	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27954	: Pg=12.0, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 27954	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27954	: Pg=12.0, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 27954	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27954	: Pg=12.0, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 27954	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27954	: Pg=12.0, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 27954	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27955	: Pg=39.04, Qg=51.3 -> Pg=46.4, Qg=11.85
% INFO    : Gen at bus 27955	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27955	: Pg=33.57, Qg=44.1 -> Pg=45.6, Qg=10.2
% INFO    : Gen at bus 27955	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27956	: Pg=51.4, Qg=39.7 -> Pg=57.0, Qg=9.2
% INFO    : Gen at bus 27956	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27956	: Pg=51.65, Qg=34.8 -> Pg=60.9, Qg=5.45
% INFO    : Gen at bus 27956	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27956	: Pg=51.65, Qg=34.8 -> Pg=60.9, Qg=5.45
% INFO    : Gen at bus 27956	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27956	: Pg=52.31, Qg=60.64 -> Pg=75.35, Qg=14.4
% INFO    : Gen at bus 27956	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27956	: Pg=52.31, Qg=60.64 -> Pg=75.35, Qg=14.4
% INFO    : Gen at bus 27956	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27957	: Pg=36.55, Qg=20.4 -> Pg=48.5, Qg=0.0
% INFO    : Gen at bus 27957	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27957	: Pg=36.55, Qg=20.4 -> Pg=48.5, Qg=0.0
% INFO    : Gen at bus 27957	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27958	: Pg=14.91, Qg=11.25 -> Pg=14.775, Qg=3.125
% INFO    : Gen at bus 27958	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27958	: Pg=14.91, Qg=11.25 -> Pg=14.775, Qg=3.125
% INFO    : Gen at bus 27958	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27958	: Pg=14.91, Qg=11.25 -> Pg=14.775, Qg=3.125
% INFO    : Gen at bus 27958	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27958	: Pg=14.91, Qg=11.25 -> Pg=14.775, Qg=3.125
% INFO    : Gen at bus 27958	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27959	: Pg=56.04, Qg=4.3 -> Pg=55.4, Qg=4.25
% INFO    : Gen at bus 27959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27959	: Pg=56.04, Qg=4.3 -> Pg=55.4, Qg=4.25
% INFO    : Gen at bus 27959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27959	: Pg=52.05, Qg=4.3 -> Pg=51.45, Qg=3.95
% INFO    : Gen at bus 27959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27959	: Pg=52.05, Qg=4.3 -> Pg=51.45, Qg=3.95
% INFO    : Gen at bus 27959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27959	: Pg=52.05, Qg=4.3 -> Pg=51.45, Qg=3.95
% INFO    : Gen at bus 27959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27959	: Pg=52.05, Qg=4.3 -> Pg=51.45, Qg=3.95
% INFO    : Gen at bus 27959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27960	: Pg=59.41, Qg=40.69 -> Pg=78.0, Qg=9.5
% INFO    : Gen at bus 27960	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27960	: Pg=52.59, Qg=40.69 -> Pg=76.75, Qg=7.8
% INFO    : Gen at bus 27960	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27960	: Pg=33.25, Qg=31.0 -> Pg=41.0, Qg=7.15
% INFO    : Gen at bus 27960	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27960	: Pg=33.36, Qg=33.7 -> Pg=43.2, Qg=7.8
% INFO    : Gen at bus 27960	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27961	: Pg=23.58, Qg=31.0 -> Pg=27.5, Qg=7.15
% INFO    : Gen at bus 27961	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27961	: Pg=24.14, Qg=31.7 -> Pg=28.1, Qg=7.3
% INFO    : Gen at bus 27961	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27962	: Pg=38.28, Qg=28.08 -> Pg=43.4, Qg=7.15
% INFO    : Gen at bus 27962	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27962	: Pg=38.28, Qg=28.08 -> Pg=43.4, Qg=7.15
% INFO    : Gen at bus 27962	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27963	: Pg=7.36, Qg=8.7 -> Pg=11.155, Qg=1.75
% INFO    : Gen at bus 27963	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27963	: Pg=7.36, Qg=8.7 -> Pg=11.155, Qg=1.75
% INFO    : Gen at bus 27963	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27963	: Pg=7.36, Qg=8.7 -> Pg=11.155, Qg=1.75
% INFO    : Gen at bus 27963	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27964	: Pg=46.6, Qg=22.6 -> Pg=25.8, Qg=3.55
% INFO    : Gen at bus 27964	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27965	: Pg=11.2, Qg=5.42 -> Pg=11.2, Qg=0.845
% INFO    : Gen at bus 27965	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27965	: Pg=11.2, Qg=5.42 -> Pg=11.2, Qg=0.845
% INFO    : Gen at bus 27965	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27965	: Pg=11.2, Qg=5.42 -> Pg=11.2, Qg=0.845
% INFO    : Gen at bus 27965	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27965	: Pg=11.2, Qg=5.42 -> Pg=11.2, Qg=0.845
% INFO    : Gen at bus 27965	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27966	: Pg=42.3, Qg=13.9 -> Pg=31.15, Qg=0.0
% INFO    : Gen at bus 27966	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27966	: Pg=42.3, Qg=13.9 -> Pg=31.15, Qg=0.0
% INFO    : Gen at bus 27966	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27967	: Pg=42.0, Qg=13.8 -> Pg=41.0, Qg=0.0
% INFO    : Gen at bus 27967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27967	: Pg=42.0, Qg=13.8 -> Pg=41.0, Qg=0.0
% INFO    : Gen at bus 27967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27967	: Pg=42.0, Qg=13.8 -> Pg=41.0, Qg=0.0
% INFO    : Gen at bus 27967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27967	: Pg=42.0, Qg=13.8 -> Pg=41.0, Qg=0.0
% INFO    : Gen at bus 27967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27968	: Pg=3.93, Qg=13.5 -> Pg=20.05, Qg=0.0
% INFO    : Gen at bus 27968	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27968	: Pg=4.13, Qg=16.3 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 27968	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27969	: Pg=35.0, Qg=17.0 -> Pg=35.0, Qg=2.65
% INFO    : Gen at bus 27969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27969	: Pg=35.0, Qg=17.0 -> Pg=35.0, Qg=2.65
% INFO    : Gen at bus 27969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27970	: Pg=4.58, Qg=2.75 -> Pg=6.36, Qg=0.0
% INFO    : Gen at bus 27970	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27970	: Pg=4.58, Qg=2.75 -> Pg=6.36, Qg=0.0
% INFO    : Gen at bus 27970	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27970	: Pg=4.58, Qg=2.75 -> Pg=6.36, Qg=0.0
% INFO    : Gen at bus 27970	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27970	: Pg=4.58, Qg=2.75 -> Pg=6.36, Qg=0.0
% INFO    : Gen at bus 27970	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27971	: Pg=2.5, Qg=1.88 -> Pg=2.5, Qg=0.525
% INFO    : Gen at bus 27971	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27971	: Pg=2.5, Qg=1.88 -> Pg=2.5, Qg=0.525
% INFO    : Gen at bus 27971	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27971	: Pg=2.5, Qg=1.88 -> Pg=2.5, Qg=0.525
% INFO    : Gen at bus 27971	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27971	: Pg=2.5, Qg=1.88 -> Pg=2.5, Qg=0.525
% INFO    : Gen at bus 27971	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27971	: Pg=2.5, Qg=1.88 -> Pg=2.5, Qg=0.525
% INFO    : Gen at bus 27971	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27971	: Pg=2.5, Qg=1.88 -> Pg=2.5, Qg=0.525
% INFO    : Gen at bus 27971	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27971	: Pg=2.5, Qg=1.88 -> Pg=2.5, Qg=0.525
% INFO    : Gen at bus 27971	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27971	: Pg=2.5, Qg=1.88 -> Pg=2.5, Qg=0.525
% INFO    : Gen at bus 27971	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27971	: Pg=2.5, Qg=1.88 -> Pg=2.5, Qg=0.525
% INFO    : Gen at bus 27971	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27971	: Pg=2.5, Qg=1.88 -> Pg=2.5, Qg=0.525
% INFO    : Gen at bus 27971	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27971	: Pg=2.5, Qg=1.88 -> Pg=2.5, Qg=0.525
% INFO    : Gen at bus 27971	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27971	: Pg=2.5, Qg=1.88 -> Pg=2.5, Qg=0.525
% INFO    : Gen at bus 27971	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27974	: Pg=11.88, Qg=6.68 -> Pg=13.6, Qg=5.25
% INFO    : Gen at bus 27974	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27974	: Pg=11.88, Qg=6.68 -> Pg=13.6, Qg=5.25
% INFO    : Gen at bus 27974	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27974	: Pg=21.22, Qg=6.68 -> Pg=23.5, Qg=9.4
% INFO    : Gen at bus 27974	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27974	: Pg=21.22, Qg=6.68 -> Pg=23.5, Qg=9.4
% INFO    : Gen at bus 27974	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27975	: Pg=7.5, Qg=3.63 -> Pg=7.5, Qg=0.565
% INFO    : Gen at bus 27975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27975	: Pg=7.5, Qg=3.63 -> Pg=7.5, Qg=0.565
% INFO    : Gen at bus 27975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27975	: Pg=7.5, Qg=3.63 -> Pg=7.5, Qg=0.565
% INFO    : Gen at bus 27975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27976	: Pg=22.44, Qg=10.06 -> Pg=22.2, Qg=4.7
% INFO    : Gen at bus 27976	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27976	: Pg=22.44, Qg=10.06 -> Pg=22.2, Qg=4.7
% INFO    : Gen at bus 27976	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27977	: Pg=10.37, Qg=16.5 -> Pg=14.6, Qg=4.6
% INFO    : Gen at bus 27977	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27978	: Pg=22.0, Qg=13.6 -> Pg=21.0, Qg=3.15
% INFO    : Gen at bus 27978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27978	: Pg=38.4, Qg=23.8 -> Pg=34.2, Qg=5.5
% INFO    : Gen at bus 27978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27979	: Pg=2.0, Qg=15.0 -> Pg=10.75, Qg=4.15
% INFO    : Gen at bus 27979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27980	: Pg=1150.1, Qg=208.83 -> Pg=1177.6, Qg=91.0
% INFO    : Gen at bus 27980	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27980	: Pg=1140.1, Qg=208.83 -> Pg=1172.6, Qg=91.0
% INFO    : Gen at bus 27980	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27981	: Pg=1029.6, Qg=254.61 -> Pg=589.8, Qg=0.0
% INFO    : Gen at bus 27981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27982	: Pg=859.0, Qg=209.43 -> Pg=876.15, Qg=67.4
% INFO    : Gen at bus 27982	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27982	: Pg=848.0, Qg=209.43 -> Pg=867.35, Qg=66.9
% INFO    : Gen at bus 27982	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27982	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27983	: Pg=18.24, Qg=16.7 -> Pg=15.95, Qg=3.85
% INFO    : Gen at bus 27983	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27983	: Pg=18.24, Qg=16.7 -> Pg=15.95, Qg=3.85
% INFO    : Gen at bus 27983	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27983	: Pg=515.85, Qg=306.4 -> Pg=566.35, Qg=47.75
% INFO    : Gen at bus 27983	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27984	: Pg=378.24, Qg=40.37 -> Pg=403.1, Qg=42.0
% INFO    : Gen at bus 27984	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27984	: Pg=401.83, Qg=40.37 -> Pg=425.45, Qg=44.6
% INFO    : Gen at bus 27984	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27984	: Pg=401.9, Qg=40.37 -> Pg=420.5, Qg=44.6
% INFO    : Gen at bus 27984	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27984	: Pg=443.38, Qg=40.37 -> Pg=451.0, Qg=49.25
% INFO    : Gen at bus 27984	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27985	: Pg=320.45, Qg=79.92 -> Pg=363.65, Qg=59.75
% INFO    : Gen at bus 27985	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27986	: Pg=229.66, Qg=136.23 -> Pg=302.95, Qg=55.3
% INFO    : Gen at bus 27986	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27986	: Pg=229.66, Qg=136.23 -> Pg=302.95, Qg=55.3
% INFO    : Gen at bus 27986	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27987	: Pg=214.21, Qg=7.84 -> Pg=212.5, Qg=23.8
% INFO    : Gen at bus 27987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27987	: Pg=214.21, Qg=7.84 -> Pg=207.5, Qg=23.8
% INFO    : Gen at bus 27987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27987	: Pg=214.21, Qg=7.84 -> Pg=207.5, Qg=23.8
% INFO    : Gen at bus 27987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27987	: Pg=214.21, Qg=7.84 -> Pg=207.5, Qg=23.8
% INFO    : Gen at bus 27987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27988	: Pg=140.5, Qg=100.73 -> Pg=143.585, Qg=29.55
% INFO    : Gen at bus 27988	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27988	: Pg=768.6, Qg=100.73 -> Pg=754.8, Qg=0.0
% INFO    : Gen at bus 27988	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27989	: Pg=190.96, Qg=29.63 -> Pg=230.0, Qg=30.6
% INFO    : Gen at bus 27989	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27989	: Pg=93.78, Qg=29.63 -> Pg=141.95, Qg=28.5
% INFO    : Gen at bus 27989	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27989	: Pg=93.78, Qg=29.63 -> Pg=141.95, Qg=28.5
% INFO    : Gen at bus 27989	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27989	: Pg=93.78, Qg=29.63 -> Pg=141.95, Qg=28.5
% INFO    : Gen at bus 27989	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27990	: Pg=10.33, Qg=9.85 -> Pg=16.23, Qg=2.55
% INFO    : Gen at bus 27990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27990	: Pg=10.97, Qg=9.85 -> Pg=15.115, Qg=2.54
% INFO    : Gen at bus 27990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27990	: Pg=10.97, Qg=9.85 -> Pg=15.115, Qg=2.54
% INFO    : Gen at bus 27990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27990	: Pg=10.97, Qg=9.85 -> Pg=15.115, Qg=2.54
% INFO    : Gen at bus 27990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27990	: Pg=10.97, Qg=9.85 -> Pg=15.115, Qg=2.54
% INFO    : Gen at bus 27990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27990	: Pg=10.97, Qg=9.85 -> Pg=15.115, Qg=2.54
% INFO    : Gen at bus 27990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27990	: Pg=10.33, Qg=9.85 -> Pg=16.23, Qg=2.55
% INFO    : Gen at bus 27990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27990	: Pg=10.33, Qg=9.85 -> Pg=16.23, Qg=2.55
% INFO    : Gen at bus 27990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27990	: Pg=10.33, Qg=9.85 -> Pg=16.23, Qg=2.55
% INFO    : Gen at bus 27990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27990	: Pg=10.97, Qg=9.85 -> Pg=15.115, Qg=2.54
% INFO    : Gen at bus 27990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27990	: Pg=10.97, Qg=9.85 -> Pg=15.115, Qg=2.54
% INFO    : Gen at bus 27990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27990	: Pg=10.97, Qg=9.85 -> Pg=15.115, Qg=2.54
% INFO    : Gen at bus 27990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27990	: Pg=10.97, Qg=9.85 -> Pg=15.115, Qg=2.54
% INFO    : Gen at bus 27990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27990	: Pg=10.97, Qg=9.85 -> Pg=15.115, Qg=2.54
% INFO    : Gen at bus 27990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27991	: Pg=104.93, Qg=61.32 -> Pg=148.5, Qg=28.2
% INFO    : Gen at bus 27991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27991	: Pg=104.93, Qg=61.32 -> Pg=148.5, Qg=28.2
% INFO    : Gen at bus 27991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27991	: Pg=104.93, Qg=61.32 -> Pg=148.5, Qg=28.2
% INFO    : Gen at bus 27991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27991	: Pg=104.93, Qg=61.32 -> Pg=148.5, Qg=28.2
% INFO    : Gen at bus 27991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27991	: Pg=104.93, Qg=61.32 -> Pg=148.5, Qg=28.2
% INFO    : Gen at bus 27991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27992	: Pg=129.43, Qg=132.9 -> Pg=147.25, Qg=20.7
% INFO    : Gen at bus 27992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27992	: Pg=104.93, Qg=122.1 -> Pg=148.5, Qg=28.2
% INFO    : Gen at bus 27992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27992	: Pg=104.93, Qg=122.1 -> Pg=148.5, Qg=28.2
% INFO    : Gen at bus 27992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27993	: Pg=159.85, Qg=77.6 -> Pg=174.25, Qg=14.6
% INFO    : Gen at bus 27993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27993	: Pg=159.85, Qg=77.6 -> Pg=174.25, Qg=14.6
% INFO    : Gen at bus 27993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27993	: Pg=159.85, Qg=77.6 -> Pg=174.25, Qg=14.6
% INFO    : Gen at bus 27993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27993	: Pg=159.85, Qg=77.6 -> Pg=174.25, Qg=14.6
% INFO    : Gen at bus 27993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27994	: Pg=124.13, Qg=39.89 -> Pg=142.5, Qg=23.65
% INFO    : Gen at bus 27994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27994	: Pg=124.13, Qg=39.89 -> Pg=142.5, Qg=23.65
% INFO    : Gen at bus 27994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27994	: Pg=24.13, Qg=39.89 -> Pg=92.5, Qg=23.65
% INFO    : Gen at bus 27994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27994	: Pg=24.13, Qg=39.89 -> Pg=92.5, Qg=23.65
% INFO    : Gen at bus 27994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27994	: Pg=12.1, Qg=39.89 -> Pg=47.0, Qg=12.05
% INFO    : Gen at bus 27994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27994	: Pg=12.1, Qg=39.89 -> Pg=47.0, Qg=12.05
% INFO    : Gen at bus 27994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27994	: Pg=12.1, Qg=39.89 -> Pg=47.0, Qg=12.05
% INFO    : Gen at bus 27994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27994	: Pg=124.76, Qg=39.89 -> Pg=155.0, Qg=27.25
% INFO    : Gen at bus 27994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27995	: Pg=69.22, Qg=91.0 -> Pg=100.9, Qg=21.05
% INFO    : Gen at bus 27995	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27995	: Pg=69.22, Qg=91.0 -> Pg=100.9, Qg=21.05
% INFO    : Gen at bus 27995	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27996	: Pg=64.13, Qg=54.05 -> Pg=90.5, Qg=25.5
% INFO    : Gen at bus 27996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27996	: Pg=102.6, Qg=54.05 -> Pg=131.3, Qg=40.8
% INFO    : Gen at bus 27996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27996	: Pg=64.13, Qg=54.05 -> Pg=94.52, Qg=25.5
% INFO    : Gen at bus 27996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27997	: Pg=15.16, Qg=11.44 -> Pg=13.55, Qg=2.0
% INFO    : Gen at bus 27997	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27997	: Pg=15.16, Qg=11.44 -> Pg=13.55, Qg=2.0
% INFO    : Gen at bus 27997	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27997	: Pg=15.16, Qg=11.44 -> Pg=13.55, Qg=2.0
% INFO    : Gen at bus 27997	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27997	: Pg=15.16, Qg=11.44 -> Pg=13.55, Qg=2.0
% INFO    : Gen at bus 27997	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27997	: Pg=15.16, Qg=11.44 -> Pg=13.55, Qg=2.0
% INFO    : Gen at bus 27997	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27997	: Pg=24.01, Qg=17.1 -> Pg=22.65, Qg=2.65
% INFO    : Gen at bus 27997	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27997	: Pg=18.09, Qg=12.9 -> Pg=15.3, Qg=2.0
% INFO    : Gen at bus 27997	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27997	: Pg=18.09, Qg=12.9 -> Pg=15.3, Qg=2.0
% INFO    : Gen at bus 27997	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27998	: Pg=16.48, Qg=36.5 -> Pg=36.95, Qg=8.45
% INFO    : Gen at bus 27998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27998	: Pg=51.88, Qg=40.3 -> Pg=62.5, Qg=15.65
% INFO    : Gen at bus 27998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27998	: Pg=62.5, Qg=40.3 -> Pg=80.0, Qg=20.85
% INFO    : Gen at bus 27998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27998	: Pg=8.2, Qg=17.23 -> Pg=17.635, Qg=3.99
% INFO    : Gen at bus 27998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27998	: Pg=8.2, Qg=17.23 -> Pg=17.635, Qg=3.99
% INFO    : Gen at bus 27998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27998	: Pg=8.2, Qg=17.23 -> Pg=17.635, Qg=3.99
% INFO    : Gen at bus 27998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27998	: Pg=8.2, Qg=17.23 -> Pg=17.635, Qg=3.99
% INFO    : Gen at bus 27998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27998	: Pg=79.98, Qg=40.3 -> Pg=136.95, Qg=28.5
% INFO    : Gen at bus 27998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27998	: Pg=79.98, Qg=40.3 -> Pg=136.95, Qg=41.45
% INFO    : Gen at bus 27998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27998	: Pg=51.88, Qg=40.3 -> Pg=62.5, Qg=15.65
% INFO    : Gen at bus 27998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27999	: Pg=53.79, Qg=44.8 -> Pg=42.05, Qg=9.2
% INFO    : Gen at bus 27999	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27999	: Pg=24.39, Qg=20.83 -> Pg=20.6, Qg=4.43
% INFO    : Gen at bus 27999	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27999	: Pg=24.39, Qg=20.83 -> Pg=20.6, Qg=4.43
% INFO    : Gen at bus 27999	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 27999	: Pg=24.39, Qg=20.83 -> Pg=20.6, Qg=4.43
% INFO    : Gen at bus 27999	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28000	: Pg=76.9, Qg=21.58 -> Pg=87.15, Qg=14.3
% INFO    : Gen at bus 28000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28000	: Pg=76.9, Qg=21.58 -> Pg=87.15, Qg=14.3
% INFO    : Gen at bus 28000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28000	: Pg=76.9, Qg=21.58 -> Pg=87.15, Qg=14.3
% INFO    : Gen at bus 28000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28000	: Pg=76.9, Qg=21.58 -> Pg=87.15, Qg=14.3
% INFO    : Gen at bus 28000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28000	: Pg=76.9, Qg=21.58 -> Pg=87.15, Qg=14.3
% INFO    : Gen at bus 28000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28000	: Pg=76.9, Qg=21.58 -> Pg=87.15, Qg=14.3
% INFO    : Gen at bus 28000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28000	: Pg=76.9, Qg=21.58 -> Pg=87.15, Qg=14.3
% INFO    : Gen at bus 28000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28000	: Pg=76.9, Qg=21.58 -> Pg=87.15, Qg=14.3
% INFO    : Gen at bus 28000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28001	: Pg=67.46, Qg=61.5 -> Pg=62.1, Qg=14.2
% INFO    : Gen at bus 28001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28002	: Pg=42.3, Qg=26.2 -> Pg=47.5, Qg=4.1
% INFO    : Gen at bus 28002	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28002	: Pg=42.3, Qg=26.2 -> Pg=47.5, Qg=4.1
% INFO    : Gen at bus 28002	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28002	: Pg=52.25, Qg=55.8 -> Pg=70.0, Qg=12.9
% INFO    : Gen at bus 28002	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28002	: Pg=51.25, Qg=55.8 -> Pg=69.5, Qg=12.9
% INFO    : Gen at bus 28002	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28003	: Pg=55.49, Qg=49.5 -> Pg=55.08, Qg=11.15
% INFO    : Gen at bus 28003	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28003	: Pg=55.49, Qg=49.5 -> Pg=55.08, Qg=11.15
% INFO    : Gen at bus 28003	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28004	: Pg=78.02, Qg=38.2 -> Pg=77.4, Qg=5.95
% INFO    : Gen at bus 28004	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28004	: Pg=78.02, Qg=38.2 -> Pg=77.4, Qg=5.95
% INFO    : Gen at bus 28004	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28005	: Pg=8.72, Qg=11.47 -> Pg=9.75, Qg=2.65
% INFO    : Gen at bus 28005	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28005	: Pg=8.72, Qg=11.47 -> Pg=9.75, Qg=2.65
% INFO    : Gen at bus 28005	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28005	: Pg=8.72, Qg=11.47 -> Pg=9.75, Qg=2.65
% INFO    : Gen at bus 28005	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28005	: Pg=8.72, Qg=11.47 -> Pg=9.75, Qg=2.65
% INFO    : Gen at bus 28005	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28006	: Pg=45.43, Qg=15.25 -> Pg=38.4, Qg=5.05
% INFO    : Gen at bus 28006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28006	: Pg=44.75, Qg=15.25 -> Pg=37.9, Qg=5.0
% INFO    : Gen at bus 28006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28006	: Pg=44.75, Qg=15.25 -> Pg=37.9, Qg=5.0
% INFO    : Gen at bus 28006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28006	: Pg=107.45, Qg=15.25 -> Pg=99.0, Qg=11.9
% INFO    : Gen at bus 28006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28006	: Pg=107.45, Qg=15.25 -> Pg=99.0, Qg=11.9
% INFO    : Gen at bus 28006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28006	: Pg=45.43, Qg=15.25 -> Pg=38.4, Qg=5.05
% INFO    : Gen at bus 28006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28006	: Pg=45.43, Qg=15.25 -> Pg=38.4, Qg=5.05
% INFO    : Gen at bus 28006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28006	: Pg=45.43, Qg=15.25 -> Pg=38.4, Qg=5.05
% INFO    : Gen at bus 28006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28006	: Pg=45.43, Qg=15.25 -> Pg=38.4, Qg=5.05
% INFO    : Gen at bus 28006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28006	: Pg=45.43, Qg=15.25 -> Pg=38.4, Qg=5.05
% INFO    : Gen at bus 28006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28006	: Pg=44.75, Qg=15.25 -> Pg=37.9, Qg=5.0
% INFO    : Gen at bus 28006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28006	: Pg=44.75, Qg=15.25 -> Pg=37.9, Qg=5.0
% INFO    : Gen at bus 28006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28006	: Pg=44.75, Qg=15.25 -> Pg=37.9, Qg=5.0
% INFO    : Gen at bus 28006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28007	: Pg=51.64, Qg=11.86 -> Pg=56.95, Qg=4.8
% INFO    : Gen at bus 28007	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28007	: Pg=51.64, Qg=11.86 -> Pg=56.95, Qg=4.8
% INFO    : Gen at bus 28007	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28007	: Pg=51.64, Qg=11.86 -> Pg=56.95, Qg=4.8
% INFO    : Gen at bus 28007	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28007	: Pg=51.64, Qg=11.86 -> Pg=56.95, Qg=4.8
% INFO    : Gen at bus 28007	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28007	: Pg=51.64, Qg=11.86 -> Pg=56.95, Qg=4.8
% INFO    : Gen at bus 28007	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28007	: Pg=51.64, Qg=11.86 -> Pg=56.95, Qg=4.8
% INFO    : Gen at bus 28007	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28007	: Pg=51.64, Qg=11.86 -> Pg=56.95, Qg=4.8
% INFO    : Gen at bus 28007	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28007	: Pg=51.64, Qg=11.86 -> Pg=56.95, Qg=4.8
% INFO    : Gen at bus 28007	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28008	: Pg=15.0, Qg=7.28 -> Pg=15.0, Qg=1.14
% INFO    : Gen at bus 28008	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28008	: Pg=15.0, Qg=7.28 -> Pg=15.0, Qg=1.14
% INFO    : Gen at bus 28008	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28008	: Pg=15.0, Qg=7.28 -> Pg=15.0, Qg=1.14
% INFO    : Gen at bus 28008	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28008	: Pg=15.0, Qg=7.28 -> Pg=15.0, Qg=1.14
% INFO    : Gen at bus 28008	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28009	: Pg=51.5, Qg=37.2 -> Pg=55.0, Qg=8.6
% INFO    : Gen at bus 28009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28009	: Pg=18.03, Qg=25.5 -> Pg=29.1, Qg=5.9
% INFO    : Gen at bus 28009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28010	: Pg=11.2, Qg=3.68 -> Pg=11.2, Qg=0.0
% INFO    : Gen at bus 28010	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28010	: Pg=11.2, Qg=3.68 -> Pg=11.2, Qg=0.0
% INFO    : Gen at bus 28010	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28010	: Pg=11.2, Qg=3.68 -> Pg=11.2, Qg=0.0
% INFO    : Gen at bus 28010	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28010	: Pg=11.2, Qg=3.68 -> Pg=11.2, Qg=0.0
% INFO    : Gen at bus 28010	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28010	: Pg=11.2, Qg=3.68 -> Pg=11.2, Qg=0.0
% INFO    : Gen at bus 28010	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28011	: Pg=49.31, Qg=25.0 -> Pg=49.85, Qg=3.9
% INFO    : Gen at bus 28011	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28011	: Pg=49.31, Qg=25.0 -> Pg=49.85, Qg=3.9
% INFO    : Gen at bus 28011	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28011	: Pg=49.31, Qg=25.0 -> Pg=49.85, Qg=3.9
% INFO    : Gen at bus 28011	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28011	: Pg=49.31, Qg=25.0 -> Pg=49.85, Qg=3.9
% INFO    : Gen at bus 28011	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28011	: Pg=49.31, Qg=25.0 -> Pg=49.85, Qg=3.9
% INFO    : Gen at bus 28011	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28011	: Pg=49.31, Qg=25.0 -> Pg=49.85, Qg=3.9
% INFO    : Gen at bus 28011	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28011	: Pg=49.31, Qg=25.0 -> Pg=49.85, Qg=3.9
% INFO    : Gen at bus 28011	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28012	: Pg=34.95, Qg=31.9 -> Pg=33.2, Qg=7.4
% INFO    : Gen at bus 28012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28013	: Pg=31.21, Qg=30.0 -> Pg=39.2, Qg=6.95
% INFO    : Gen at bus 28013	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28013	: Pg=31.53, Qg=37.9 -> Pg=45.6, Qg=8.75
% INFO    : Gen at bus 28013	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28014	: Pg=15.0, Qg=8.63 -> Pg=15.0, Qg=1.815
% INFO    : Gen at bus 28014	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28014	: Pg=15.0, Qg=8.63 -> Pg=15.0, Qg=1.815
% INFO    : Gen at bus 28014	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28014	: Pg=15.0, Qg=8.63 -> Pg=15.0, Qg=1.815
% INFO    : Gen at bus 28014	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28015	: Pg=14.36, Qg=11.27 -> Pg=14.5, Qg=3.135
% INFO    : Gen at bus 28015	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28015	: Pg=14.36, Qg=11.27 -> Pg=14.5, Qg=3.135
% INFO    : Gen at bus 28015	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28015	: Pg=14.36, Qg=11.27 -> Pg=14.5, Qg=3.135
% INFO    : Gen at bus 28015	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28016	: Pg=8.46, Qg=4.1 -> Pg=8.46, Qg=0.64
% INFO    : Gen at bus 28016	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28016	: Pg=8.46, Qg=4.1 -> Pg=8.46, Qg=0.64
% INFO    : Gen at bus 28016	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28016	: Pg=8.46, Qg=4.1 -> Pg=8.46, Qg=0.64
% INFO    : Gen at bus 28016	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28016	: Pg=8.46, Qg=4.1 -> Pg=8.46, Qg=0.64
% INFO    : Gen at bus 28016	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28016	: Pg=8.46, Qg=4.1 -> Pg=8.46, Qg=0.64
% INFO    : Gen at bus 28016	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28018	: Pg=21.76, Qg=19.8 -> Pg=17.25, Qg=4.55
% INFO    : Gen at bus 28018	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28018	: Pg=21.76, Qg=19.8 -> Pg=17.25, Qg=4.55
% INFO    : Gen at bus 28018	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28018	: Pg=82.96, Qg=75.6 -> Pg=66.0, Qg=17.45
% INFO    : Gen at bus 28018	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28019	: Pg=20.81, Qg=14.8 -> Pg=24.3, Qg=2.3
% INFO    : Gen at bus 28019	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28019	: Pg=20.81, Qg=14.8 -> Pg=24.3, Qg=2.3
% INFO    : Gen at bus 28019	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28019	: Pg=20.81, Qg=14.8 -> Pg=21.8, Qg=2.3
% INFO    : Gen at bus 28019	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28019	: Pg=20.81, Qg=14.8 -> Pg=21.8, Qg=2.3
% INFO    : Gen at bus 28019	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28019	: Pg=15.0, Qg=21.84 -> Pg=32.5, Qg=7.15
% INFO    : Gen at bus 28019	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28019	: Pg=15.0, Qg=21.84 -> Pg=32.5, Qg=7.15
% INFO    : Gen at bus 28019	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28020	: Pg=4.7, Qg=7.5 -> Pg=5.585, Qg=2.085
% INFO    : Gen at bus 28020	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28020	: Pg=4.7, Qg=7.5 -> Pg=5.585, Qg=2.085
% INFO    : Gen at bus 28020	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28020	: Pg=4.7, Qg=7.5 -> Pg=5.585, Qg=2.085
% INFO    : Gen at bus 28020	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28021	: Pg=3.46, Qg=2.62 -> Pg=3.44, Qg=0.73
% INFO    : Gen at bus 28021	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28021	: Pg=3.46, Qg=2.62 -> Pg=3.44, Qg=0.73
% INFO    : Gen at bus 28021	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28021	: Pg=3.46, Qg=2.62 -> Pg=3.44, Qg=0.73
% INFO    : Gen at bus 28021	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28021	: Pg=3.46, Qg=2.62 -> Pg=3.44, Qg=0.73
% INFO    : Gen at bus 28021	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28021	: Pg=3.46, Qg=2.62 -> Pg=3.44, Qg=0.73
% INFO    : Gen at bus 28021	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28021	: Pg=3.46, Qg=2.62 -> Pg=3.44, Qg=0.73
% INFO    : Gen at bus 28021	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28021	: Pg=3.46, Qg=2.62 -> Pg=3.44, Qg=0.73
% INFO    : Gen at bus 28021	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28021	: Pg=3.46, Qg=2.62 -> Pg=3.44, Qg=0.73
% INFO    : Gen at bus 28021	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28023	: Pg=19.04, Qg=17.4 -> Pg=15.0, Qg=4.05
% INFO    : Gen at bus 28023	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28024	: Pg=30.51, Qg=31.3 -> Pg=35.85, Qg=4.85
% INFO    : Gen at bus 28024	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28024	: Pg=12.54, Qg=12.9 -> Pg=14.3, Qg=2.0
% INFO    : Gen at bus 28024	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28024	: Pg=12.54, Qg=12.9 -> Pg=14.3, Qg=2.0
% INFO    : Gen at bus 28024	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28025	: Pg=3.0, Qg=2.25 -> Pg=3.0, Qg=0.625
% INFO    : Gen at bus 28025	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28025	: Pg=3.0, Qg=2.25 -> Pg=3.0, Qg=0.625
% INFO    : Gen at bus 28025	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28025	: Pg=3.0, Qg=2.25 -> Pg=3.0, Qg=0.625
% INFO    : Gen at bus 28025	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28025	: Pg=3.0, Qg=2.25 -> Pg=3.0, Qg=0.625
% INFO    : Gen at bus 28025	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28025	: Pg=3.0, Qg=2.25 -> Pg=3.0, Qg=0.625
% INFO    : Gen at bus 28025	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28025	: Pg=3.0, Qg=2.25 -> Pg=3.0, Qg=0.625
% INFO    : Gen at bus 28025	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28025	: Pg=3.0, Qg=2.25 -> Pg=3.0, Qg=0.625
% INFO    : Gen at bus 28025	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 28025	: Pg=3.0, Qg=2.25 -> Pg=3.0, Qg=0.625
% INFO    : Gen at bus 28025	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35250	: Pg=1100.8, Qg=72.84 -> Pg=1126.4, Qg=0.0
% INFO    : Gen at bus 35250	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35250	: Pg=1103.0, Qg=72.84 -> Pg=1127.5, Qg=0.0
% INFO    : Gen at bus 35250	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35250	: Pg=1104.9, Qg=72.84 -> Pg=1147.45, Qg=0.0
% INFO    : Gen at bus 35250	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35251	: Pg=840.3, Qg=176.08 -> Pg=569.1, Qg=127.2
% INFO    : Gen at bus 35251	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35251	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35252	: Pg=317.67, Qg=53.7 -> Pg=502.75, Qg=101.0
% INFO    : Gen at bus 35252	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35252	: Pg=317.67, Qg=53.7 -> Pg=502.75, Qg=101.0
% INFO    : Gen at bus 35252	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35252	: Pg=317.67, Qg=53.7 -> Pg=502.75, Qg=101.0
% INFO    : Gen at bus 35252	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35252	: Pg=317.67, Qg=53.7 -> Pg=502.75, Qg=101.0
% INFO    : Gen at bus 35252	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35253	: Pg=77.09, Qg=33.32 -> Pg=113.75, Qg=20.735
% INFO    : Gen at bus 35253	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35253	: Pg=77.09, Qg=33.32 -> Pg=113.75, Qg=20.735
% INFO    : Gen at bus 35253	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35253	: Pg=77.09, Qg=33.32 -> Pg=113.75, Qg=20.735
% INFO    : Gen at bus 35253	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35253	: Pg=77.09, Qg=33.32 -> Pg=113.75, Qg=20.735
% INFO    : Gen at bus 35253	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35254	: Pg=58.83, Qg=30.85 -> Pg=104.05, Qg=21.95
% INFO    : Gen at bus 35254	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35254	: Pg=135.89, Qg=30.85 -> Pg=163.1, Qg=27.95
% INFO    : Gen at bus 35254	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35254	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35254	: Pg=58.83, Qg=30.85 -> Pg=104.05, Qg=21.95
% INFO    : Gen at bus 35254	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35254	: Pg=108.26, Qg=30.85 -> Pg=137.05, Qg=24.35
% INFO    : Gen at bus 35254	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35254	: Pg=108.26, Qg=30.85 -> Pg=137.05, Qg=24.35
% INFO    : Gen at bus 35254	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35254	: Pg=91.26, Qg=30.85 -> Pg=128.55, Qg=24.35
% INFO    : Gen at bus 35254	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35254	: Pg=83.26, Qg=30.85 -> Pg=124.55, Qg=24.35
% INFO    : Gen at bus 35254	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35254	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35254	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35254	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35255	: Pg=76.13, Qg=48.65 -> Pg=157.4, Qg=35.05
% INFO    : Gen at bus 35255	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35255	: Pg=723.84, Qg=48.65 -> Pg=826.0, Qg=136.35
% INFO    : Gen at bus 35255	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35255	: Pg=16.52, Qg=13.1 -> Pg=18.6, Qg=3.0
% INFO    : Gen at bus 35255	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35255	: Pg=76.81, Qg=48.65 -> Pg=171.0, Qg=38.95
% INFO    : Gen at bus 35255	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35255	: Pg=76.81, Qg=48.65 -> Pg=171.0, Qg=38.95
% INFO    : Gen at bus 35255	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35255	: Pg=76.81, Qg=48.65 -> Pg=171.0, Qg=38.95
% INFO    : Gen at bus 35255	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35256	: Pg=68.0, Qg=6.55 -> Pg=73.0, Qg=11.45
% INFO    : Gen at bus 35256	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35256	: Pg=116.74, Qg=6.55 -> Pg=189.6, Qg=38.55
% INFO    : Gen at bus 35256	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35256	: Pg=117.49, Qg=6.55 -> Pg=204.6, Qg=42.85
% INFO    : Gen at bus 35256	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35256	: Pg=68.0, Qg=6.55 -> Pg=73.0, Qg=11.45
% INFO    : Gen at bus 35256	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35256	: Pg=68.0, Qg=6.55 -> Pg=73.0, Qg=11.45
% INFO    : Gen at bus 35256	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35256	: Pg=68.0, Qg=6.55 -> Pg=73.0, Qg=11.45
% INFO    : Gen at bus 35256	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35256	: Pg=68.0, Qg=6.55 -> Pg=73.0, Qg=11.45
% INFO    : Gen at bus 35256	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35256	: Pg=68.0, Qg=6.55 -> Pg=73.0, Qg=11.45
% INFO    : Gen at bus 35256	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35256	: Pg=68.0, Qg=6.55 -> Pg=73.0, Qg=11.45
% INFO    : Gen at bus 35256	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35256	: Pg=68.0, Qg=6.55 -> Pg=73.0, Qg=11.45
% INFO    : Gen at bus 35256	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35256	: Pg=68.0, Qg=6.55 -> Pg=73.0, Qg=11.45
% INFO    : Gen at bus 35256	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35257	: Pg=181.47, Qg=-24.4 -> Pg=216.7, Qg=37.0
% INFO    : Gen at bus 35257	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35257	: Pg=181.47, Qg=-24.4 -> Pg=216.7, Qg=37.0
% INFO    : Gen at bus 35257	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35257	: Pg=102.66, Qg=-24.4 -> Pg=200.5, Qg=43.8
% INFO    : Gen at bus 35257	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35258	: Pg=222.36, Qg=141.9 -> Pg=194.5, Qg=32.8
% INFO    : Gen at bus 35258	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35258	: Pg=88.4, Qg=54.8 -> Pg=76.55, Qg=12.65
% INFO    : Gen at bus 35258	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35259	: Pg=36.76, Qg=68.92 -> Pg=150.0, Qg=20.4
% INFO    : Gen at bus 35259	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35259	: Pg=71.28, Qg=68.92 -> Pg=138.4, Qg=30.15
% INFO    : Gen at bus 35259	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35259	: Pg=71.28, Qg=68.92 -> Pg=138.4, Qg=30.15
% INFO    : Gen at bus 35259	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35259	: Pg=71.28, Qg=68.92 -> Pg=138.4, Qg=30.15
% INFO    : Gen at bus 35259	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35260	: Pg=36.76, Qg=31.04 -> Pg=150.0, Qg=56.25
% INFO    : Gen at bus 35260	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35260	: Pg=69.26, Qg=31.04 -> Pg=137.0, Qg=43.75
% INFO    : Gen at bus 35260	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35260	: Pg=69.26, Qg=31.04 -> Pg=137.0, Qg=43.75
% INFO    : Gen at bus 35260	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35260	: Pg=69.26, Qg=31.04 -> Pg=137.0, Qg=43.75
% INFO    : Gen at bus 35260	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35261	: Pg=119.82, Qg=-15.99 -> Pg=197.33, Qg=40.35
% INFO    : Gen at bus 35261	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35261	: Pg=119.82, Qg=-15.99 -> Pg=197.33, Qg=40.35
% INFO    : Gen at bus 35261	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35261	: Pg=127.67, Qg=-15.99 -> Pg=162.84, Qg=29.1
% INFO    : Gen at bus 35261	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35261	: Pg=125.13, Qg=-15.99 -> Pg=161.575, Qg=29.1
% INFO    : Gen at bus 35261	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35261	: Pg=108.06, Qg=-15.99 -> Pg=153.035, Qg=29.1
% INFO    : Gen at bus 35261	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35261	: Pg=101.33, Qg=-15.99 -> Pg=154.645, Qg=30.55
% INFO    : Gen at bus 35261	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35261	: Pg=96.48, Qg=-15.99 -> Pg=147.25, Qg=29.1
% INFO    : Gen at bus 35261	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35261	: Pg=96.48, Qg=-15.99 -> Pg=147.25, Qg=29.1
% INFO    : Gen at bus 35261	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35261	: Pg=96.48, Qg=-15.99 -> Pg=147.25, Qg=29.1
% INFO    : Gen at bus 35261	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35262	: Pg=61.01, Qg=0.93 -> Pg=128.0, Qg=15.1
% INFO    : Gen at bus 35262	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35262	: Pg=11.49, Qg=0.93 -> Pg=34.75, Qg=4.5
% INFO    : Gen at bus 35262	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35262	: Pg=11.49, Qg=0.93 -> Pg=34.75, Qg=4.5
% INFO    : Gen at bus 35262	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35262	: Pg=11.49, Qg=0.93 -> Pg=34.75, Qg=4.5
% INFO    : Gen at bus 35262	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35262	: Pg=340.77, Qg=0.93 -> Pg=438.5, Qg=41.55
% INFO    : Gen at bus 35262	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35262	: Pg=61.01, Qg=0.93 -> Pg=128.0, Qg=15.1
% INFO    : Gen at bus 35262	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35262	: Pg=61.01, Qg=0.93 -> Pg=128.0, Qg=15.1
% INFO    : Gen at bus 35262	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35262	: Pg=61.01, Qg=0.93 -> Pg=128.0, Qg=15.1
% INFO    : Gen at bus 35262	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35262	: Pg=11.49, Qg=0.93 -> Pg=34.75, Qg=4.5
% INFO    : Gen at bus 35262	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35262	: Pg=11.49, Qg=0.93 -> Pg=34.75, Qg=4.5
% INFO    : Gen at bus 35262	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35262	: Pg=11.49, Qg=0.93 -> Pg=34.75, Qg=4.5
% INFO    : Gen at bus 35262	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35262	: Pg=11.49, Qg=0.93 -> Pg=34.75, Qg=4.5
% INFO    : Gen at bus 35262	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35262	: Pg=11.49, Qg=0.93 -> Pg=34.75, Qg=4.5
% INFO    : Gen at bus 35262	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35263	: Pg=89.68, Qg=70.0 -> Pg=136.0, Qg=26.8
% INFO    : Gen at bus 35263	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35263	: Pg=89.68, Qg=70.0 -> Pg=136.0, Qg=26.8
% INFO    : Gen at bus 35263	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35263	: Pg=89.68, Qg=70.0 -> Pg=136.0, Qg=26.8
% INFO    : Gen at bus 35263	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35263	: Pg=89.68, Qg=70.0 -> Pg=136.0, Qg=26.8
% INFO    : Gen at bus 35263	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35264	: Pg=113.36, Qg=29.27 -> Pg=146.86, Qg=26.5
% INFO    : Gen at bus 35264	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35264	: Pg=113.2, Qg=29.27 -> Pg=146.785, Qg=26.5
% INFO    : Gen at bus 35264	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35264	: Pg=102.68, Qg=29.27 -> Pg=141.525, Qg=26.5
% INFO    : Gen at bus 35264	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35264	: Pg=102.68, Qg=29.27 -> Pg=141.525, Qg=26.5
% INFO    : Gen at bus 35264	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35264	: Pg=119.86, Qg=29.27 -> Pg=197.4, Qg=21.3
% INFO    : Gen at bus 35264	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35264	: Pg=119.86, Qg=29.27 -> Pg=197.4, Qg=21.3
% INFO    : Gen at bus 35264	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35265	: Pg=94.59, Qg=-3.61 -> Pg=136.55, Qg=13.85
% INFO    : Gen at bus 35265	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35265	: Pg=94.59, Qg=-3.61 -> Pg=136.55, Qg=13.85
% INFO    : Gen at bus 35265	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35265	: Pg=94.59, Qg=-3.61 -> Pg=136.55, Qg=13.85
% INFO    : Gen at bus 35265	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35265	: Pg=44.77, Qg=-3.61 -> Pg=212.55, Qg=29.45
% INFO    : Gen at bus 35265	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35266	: Pg=94.48, Qg=-3.61 -> Pg=134.5, Qg=13.5
% INFO    : Gen at bus 35266	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35266	: Pg=94.48, Qg=-3.61 -> Pg=134.5, Qg=13.5
% INFO    : Gen at bus 35266	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35266	: Pg=94.48, Qg=-3.61 -> Pg=134.5, Qg=13.5
% INFO    : Gen at bus 35266	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35266	: Pg=69.77, Qg=-3.61 -> Pg=225.05, Qg=29.45
% INFO    : Gen at bus 35266	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35268	: Pg=140.6, Qg=20.6 -> Pg=97.715, Qg=10.6
% INFO    : Gen at bus 35268	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35268	: Pg=140.6, Qg=20.6 -> Pg=97.715, Qg=10.6
% INFO    : Gen at bus 35268	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35268	: Pg=140.6, Qg=20.6 -> Pg=97.715, Qg=10.6
% INFO    : Gen at bus 35268	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35268	: Pg=140.6, Qg=20.6 -> Pg=97.715, Qg=10.6
% INFO    : Gen at bus 35268	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35268	: Pg=140.6, Qg=20.6 -> Pg=97.715, Qg=29.3
% INFO    : Gen at bus 35268	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35268	: Pg=140.6, Qg=20.6 -> Pg=97.715, Qg=29.3
% INFO    : Gen at bus 35268	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35268	: Pg=549.98, Qg=20.6 -> Pg=401.0, Qg=41.55
% INFO    : Gen at bus 35268	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35268	: Pg=574.98, Qg=20.6 -> Pg=413.5, Qg=43.4
% INFO    : Gen at bus 35268	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35269	: Pg=94.7, Qg=27.72 -> Pg=138.75, Qg=26.85
% INFO    : Gen at bus 35269	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35269	: Pg=94.77, Qg=27.72 -> Pg=140.2, Qg=27.25
% INFO    : Gen at bus 35269	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35269	: Pg=53.13, Qg=27.72 -> Pg=87.5, Qg=17.9
% INFO    : Gen at bus 35269	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35269	: Pg=53.13, Qg=27.72 -> Pg=87.5, Qg=17.9
% INFO    : Gen at bus 35269	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35269	: Pg=619.75, Qg=27.72 -> Pg=694.4, Qg=113.0
% INFO    : Gen at bus 35269	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35270	: Pg=67.83, Qg=12.05 -> Pg=89.0, Qg=16.15
% INFO    : Gen at bus 35270	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35270	: Pg=67.83, Qg=12.05 -> Pg=89.0, Qg=16.15
% INFO    : Gen at bus 35270	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35270	: Pg=115.26, Qg=12.05 -> Pg=140.5, Qg=24.35
% INFO    : Gen at bus 35270	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35270	: Pg=115.26, Qg=12.05 -> Pg=140.5, Qg=24.35
% INFO    : Gen at bus 35270	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35271	: Pg=82.04, Qg=28.5 -> Pg=81.1, Qg=11.75
% INFO    : Gen at bus 35271	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35271	: Pg=94.43, Qg=28.5 -> Pg=94.5, Qg=13.9
% INFO    : Gen at bus 35271	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35272	: Pg=85.25, Qg=43.8 -> Pg=86.75, Qg=6.8
% INFO    : Gen at bus 35272	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35272	: Pg=85.25, Qg=43.8 -> Pg=86.75, Qg=6.8
% INFO    : Gen at bus 35272	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35274	: Pg=3.65, Qg=13.03 -> Pg=14.565, Qg=3.75
% INFO    : Gen at bus 35274	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35274	: Pg=3.65, Qg=13.03 -> Pg=14.565, Qg=3.75
% INFO    : Gen at bus 35274	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35274	: Pg=3.65, Qg=13.03 -> Pg=14.565, Qg=3.75
% INFO    : Gen at bus 35274	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35276	: Pg=29.73, Qg=42.8 -> Pg=48.5, Qg=9.9
% INFO    : Gen at bus 35276	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35276	: Pg=29.73, Qg=42.8 -> Pg=48.5, Qg=9.9
% INFO    : Gen at bus 35276	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35277	: Pg=63.19, Qg=15.3 -> Pg=64.5, Qg=5.1
% INFO    : Gen at bus 35277	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35277	: Pg=63.19, Qg=15.3 -> Pg=64.5, Qg=5.1
% INFO    : Gen at bus 35277	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35278	: Pg=41.65, Qg=7.65 -> Pg=53.0, Qg=5.0
% INFO    : Gen at bus 35278	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35278	: Pg=145.91, Qg=7.65 -> Pg=188.0, Qg=17.8
% INFO    : Gen at bus 35278	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35278	: Pg=145.91, Qg=7.65 -> Pg=188.0, Qg=17.8
% INFO    : Gen at bus 35278	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35279	: Pg=20.38, Qg=27.3 -> Pg=37.1, Qg=4.45
% INFO    : Gen at bus 35279	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35279	: Pg=17.96, Qg=23.7 -> Pg=27.6, Qg=5.5
% INFO    : Gen at bus 35279	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35280	: Pg=53.33, Qg=23.0 -> Pg=52.95, Qg=0.0
% INFO    : Gen at bus 35280	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35281	: Pg=51.2, Qg=0.02 -> Pg=50.75, Qg=3.85
% INFO    : Gen at bus 35281	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35281	: Pg=51.2, Qg=0.02 -> Pg=50.75, Qg=3.85
% INFO    : Gen at bus 35281	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35282	: Pg=42.06, Qg=11.92 -> Pg=45.5, Qg=0.0
% INFO    : Gen at bus 35282	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35282	: Pg=42.06, Qg=11.92 -> Pg=45.5, Qg=0.0
% INFO    : Gen at bus 35282	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35282	: Pg=42.06, Qg=11.92 -> Pg=45.5, Qg=0.0
% INFO    : Gen at bus 35282	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35282	: Pg=42.3, Qg=11.92 -> Pg=50.4, Qg=0.0
% INFO    : Gen at bus 35282	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35283	: Pg=11.23, Qg=37.0 -> Pg=29.65, Qg=10.3
% INFO    : Gen at bus 35283	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35283	: Pg=11.23, Qg=37.0 -> Pg=29.65, Qg=10.3
% INFO    : Gen at bus 35283	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35284	: Pg=6.2, Qg=23.2 -> Pg=26.5, Qg=3.6
% INFO    : Gen at bus 35284	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35284	: Pg=6.73, Qg=33.4 -> Pg=37.0, Qg=5.2
% INFO    : Gen at bus 35284	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35286	: Pg=42.7, Qg=20.7 -> Pg=42.25, Qg=3.25
% INFO    : Gen at bus 35286	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35286	: Pg=42.59, Qg=20.7 -> Pg=42.15, Qg=3.25
% INFO    : Gen at bus 35286	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35286	: Pg=42.59, Qg=20.7 -> Pg=42.15, Qg=3.25
% INFO    : Gen at bus 35286	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35287	: Pg=5.01, Qg=9.53 -> Pg=9.15, Qg=2.5
% INFO    : Gen at bus 35287	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35287	: Pg=5.01, Qg=9.53 -> Pg=9.15, Qg=2.5
% INFO    : Gen at bus 35287	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35287	: Pg=5.01, Qg=9.53 -> Pg=9.15, Qg=2.5
% INFO    : Gen at bus 35287	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35288	: Pg=35.01, Qg=13.3 -> Pg=37.25, Qg=0.0
% INFO    : Gen at bus 35288	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35288	: Pg=35.01, Qg=13.3 -> Pg=37.25, Qg=0.0
% INFO    : Gen at bus 35288	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35289	: Pg=9.01, Qg=19.6 -> Pg=24.25, Qg=3.05
% INFO    : Gen at bus 35289	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35289	: Pg=11.23, Qg=26.11 -> Pg=29.65, Qg=7.1
% INFO    : Gen at bus 35289	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35290	: Pg=6.32, Qg=-0.87 -> Pg=6.29, Qg=0.985
% INFO    : Gen at bus 35290	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35290	: Pg=6.32, Qg=-0.87 -> Pg=6.29, Qg=0.985
% INFO    : Gen at bus 35290	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35290	: Pg=6.32, Qg=-0.87 -> Pg=6.29, Qg=0.985
% INFO    : Gen at bus 35290	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35290	: Pg=6.32, Qg=-0.87 -> Pg=6.29, Qg=0.985
% INFO    : Gen at bus 35290	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35290	: Pg=6.32, Qg=-0.87 -> Pg=6.29, Qg=0.985
% INFO    : Gen at bus 35290	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35290	: Pg=6.32, Qg=-0.87 -> Pg=6.29, Qg=0.985
% INFO    : Gen at bus 35290	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35291	: Pg=10.94, Qg=14.52 -> Pg=23.7, Qg=5.35
% INFO    : Gen at bus 35291	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35291	: Pg=11.0, Qg=14.52 -> Pg=25.0, Qg=5.75
% INFO    : Gen at bus 35291	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35292	: Pg=18.89, Qg=22.1 -> Pg=26.85, Qg=5.1
% INFO    : Gen at bus 35292	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35292	: Pg=28.76, Qg=37.8 -> Pg=40.5, Qg=8.75
% INFO    : Gen at bus 35292	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35293	: Pg=35.1, Qg=5.54 -> Pg=31.35, Qg=2.65
% INFO    : Gen at bus 35293	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35293	: Pg=43.6, Qg=5.54 -> Pg=35.8, Qg=3.3
% INFO    : Gen at bus 35293	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35293	: Pg=43.6, Qg=5.54 -> Pg=35.75, Qg=3.3
% INFO    : Gen at bus 35293	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35293	: Pg=36.0, Qg=5.54 -> Pg=31.6, Qg=2.7
% INFO    : Gen at bus 35293	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35293	: Pg=35.1, Qg=5.54 -> Pg=30.25, Qg=2.65
% INFO    : Gen at bus 35293	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35293	: Pg=35.1, Qg=5.54 -> Pg=30.05, Qg=2.65
% INFO    : Gen at bus 35293	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35293	: Pg=35.1, Qg=5.54 -> Pg=29.3, Qg=2.65
% INFO    : Gen at bus 35293	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35293	: Pg=35.1, Qg=5.54 -> Pg=29.25, Qg=2.65
% INFO    : Gen at bus 35293	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35293	: Pg=35.1, Qg=5.54 -> Pg=29.25, Qg=2.65
% INFO    : Gen at bus 35293	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35293	: Pg=35.1, Qg=5.54 -> Pg=29.2, Qg=2.65
% INFO    : Gen at bus 35293	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35293	: Pg=35.1, Qg=5.54 -> Pg=29.05, Qg=2.65
% INFO    : Gen at bus 35293	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35294	: Pg=24.84, Qg=9.47 -> Pg=28.85, Qg=0.0
% INFO    : Gen at bus 35294	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35294	: Pg=24.84, Qg=9.47 -> Pg=28.85, Qg=0.0
% INFO    : Gen at bus 35294	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35294	: Pg=24.84, Qg=9.47 -> Pg=28.85, Qg=0.0
% INFO    : Gen at bus 35294	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35295	: Pg=4.49, Qg=8.85 -> Pg=9.925, Qg=1.8
% INFO    : Gen at bus 35295	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35295	: Pg=4.49, Qg=8.85 -> Pg=9.925, Qg=1.8
% INFO    : Gen at bus 35295	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35296	: Pg=29.5, Qg=6.62 -> Pg=29.25, Qg=2.25
% INFO    : Gen at bus 35296	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35296	: Pg=29.5, Qg=6.62 -> Pg=29.25, Qg=2.25
% INFO    : Gen at bus 35296	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35296	: Pg=29.5, Qg=6.62 -> Pg=29.25, Qg=2.25
% INFO    : Gen at bus 35296	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35296	: Pg=29.5, Qg=6.62 -> Pg=29.25, Qg=2.25
% INFO    : Gen at bus 35296	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35296	: Pg=29.5, Qg=6.62 -> Pg=29.25, Qg=2.25
% INFO    : Gen at bus 35296	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35296	: Pg=29.5, Qg=6.62 -> Pg=29.25, Qg=2.25
% INFO    : Gen at bus 35296	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35297	: Pg=22.99, Qg=14.1 -> Pg=25.75, Qg=2.2
% INFO    : Gen at bus 35297	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35297	: Pg=22.99, Qg=14.1 -> Pg=25.75, Qg=2.2
% INFO    : Gen at bus 35297	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35297	: Pg=22.99, Qg=14.1 -> Pg=25.75, Qg=2.2
% INFO    : Gen at bus 35297	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35298	: Pg=28.8, Qg=13.9 -> Pg=21.7, Qg=2.15
% INFO    : Gen at bus 35298	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35298	: Pg=28.8, Qg=13.9 -> Pg=20.85, Qg=2.15
% INFO    : Gen at bus 35298	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35298	: Pg=28.8, Qg=13.9 -> Pg=19.25, Qg=2.15
% INFO    : Gen at bus 35298	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35298	: Pg=28.8, Qg=13.9 -> Pg=19.25, Qg=2.15
% INFO    : Gen at bus 35298	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35299	: Pg=3.31, Qg=9.4 -> Pg=7.75, Qg=2.625
% INFO    : Gen at bus 35299	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35299	: Pg=3.31, Qg=9.4 -> Pg=7.75, Qg=2.625
% INFO    : Gen at bus 35299	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35300	: Pg=25.0, Qg=11.02 -> Pg=25.0, Qg=3.2
% INFO    : Gen at bus 35300	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35300	: Pg=25.0, Qg=11.02 -> Pg=25.0, Qg=3.2
% INFO    : Gen at bus 35300	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35300	: Pg=25.0, Qg=11.02 -> Pg=25.0, Qg=3.2
% INFO    : Gen at bus 35300	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35300	: Pg=25.0, Qg=11.02 -> Pg=25.0, Qg=3.2
% INFO    : Gen at bus 35300	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35301	: Pg=24.1, Qg=12.0 -> Pg=24.25, Qg=0.0
% INFO    : Gen at bus 35301	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35301	: Pg=24.1, Qg=12.3 -> Pg=24.5, Qg=0.0
% INFO    : Gen at bus 35301	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35302	: Pg=13.63, Qg=15.5 -> Pg=19.0, Qg=3.6
% INFO    : Gen at bus 35302	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35302	: Pg=20.8, Qg=19.8 -> Pg=26.0, Qg=4.55
% INFO    : Gen at bus 35302	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35302	: Pg=21.39, Qg=34.4 -> Pg=37.75, Qg=7.95
% INFO    : Gen at bus 35302	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35303	: Pg=22.97, Qg=11.8 -> Pg=23.35, Qg=1.85
% INFO    : Gen at bus 35303	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35303	: Pg=22.9, Qg=11.8 -> Pg=23.3, Qg=1.85
% INFO    : Gen at bus 35303	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35303	: Pg=22.9, Qg=11.8 -> Pg=23.3, Qg=1.85
% INFO    : Gen at bus 35303	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=52.53, Qg=9.36 -> Pg=52.6, Qg=4.1
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=18.73, Qg=9.36 -> Pg=23.6, Qg=2.2
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=18.73, Qg=9.36 -> Pg=23.6, Qg=2.2
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=18.73, Qg=9.36 -> Pg=23.6, Qg=2.2
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=18.73, Qg=9.36 -> Pg=23.6, Qg=2.2
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=18.73, Qg=9.36 -> Pg=23.6, Qg=2.2
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=18.73, Qg=9.36 -> Pg=23.6, Qg=2.2
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=18.73, Qg=9.36 -> Pg=23.6, Qg=2.2
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=20.9, Qg=9.36 -> Pg=28.0, Qg=2.7
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=21.6, Qg=9.36 -> Pg=22.0, Qg=4.8
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=21.6, Qg=9.36 -> Pg=22.0, Qg=4.8
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=51.35, Qg=9.36 -> Pg=52.0, Qg=4.1
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=21.6, Qg=9.36 -> Pg=22.0, Qg=4.8
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=21.6, Qg=9.36 -> Pg=22.0, Qg=4.8
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=51.35, Qg=9.36 -> Pg=52.0, Qg=4.1
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=22.64, Qg=9.36 -> Pg=23.6, Qg=1.9
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=22.72, Qg=9.36 -> Pg=25.6, Qg=2.2
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=18.63, Qg=9.36 -> Pg=21.6, Qg=1.9
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=20.77, Qg=9.36 -> Pg=25.45, Qg=2.35
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=20.77, Qg=9.36 -> Pg=25.45, Qg=2.35
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35304	: Pg=20.77, Qg=9.36 -> Pg=25.45, Qg=2.35
% INFO    : Gen at bus 35304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35305	: Pg=15.55, Qg=6.7 -> Pg=17.75, Qg=0.0
% INFO    : Gen at bus 35305	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35305	: Pg=15.55, Qg=6.7 -> Pg=17.75, Qg=0.0
% INFO    : Gen at bus 35305	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35305	: Pg=15.55, Qg=6.7 -> Pg=17.75, Qg=0.0
% INFO    : Gen at bus 35305	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35305	: Pg=15.55, Qg=6.7 -> Pg=17.75, Qg=0.0
% INFO    : Gen at bus 35305	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35306	: Pg=50.0, Qg=-3.42 -> Pg=49.4, Qg=10.4
% INFO    : Gen at bus 35306	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35306	: Pg=50.0, Qg=-3.42 -> Pg=49.4, Qg=10.4
% INFO    : Gen at bus 35306	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35306	: Pg=50.0, Qg=-3.42 -> Pg=49.4, Qg=10.4
% INFO    : Gen at bus 35306	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35306	: Pg=20.0, Qg=-3.42 -> Pg=19.75, Qg=4.15
% INFO    : Gen at bus 35306	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35307	: Pg=5.5, Qg=8.5 -> Pg=12.5, Qg=0.0
% INFO    : Gen at bus 35307	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35307	: Pg=5.5, Qg=8.5 -> Pg=12.5, Qg=0.0
% INFO    : Gen at bus 35307	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35307	: Pg=5.5, Qg=8.5 -> Pg=12.5, Qg=0.0
% INFO    : Gen at bus 35307	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35307	: Pg=5.55, Qg=9.4 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 35307	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35308	: Pg=459.33, Qg=373.9 -> Pg=606.0, Qg=58.3
% INFO    : Gen at bus 35308	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35309	: Pg=764.81, Qg=81.47 -> Pg=943.1, Qg=86.85
% INFO    : Gen at bus 35309	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35309	: Pg=421.63, Qg=81.47 -> Pg=554.0, Qg=53.15
% INFO    : Gen at bus 35309	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35309	: Pg=418.63, Qg=81.47 -> Pg=552.5, Qg=53.15
% INFO    : Gen at bus 35309	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35310	: Pg=84.98, Qg=15.78 -> Pg=139.5, Qg=28.5
% INFO    : Gen at bus 35310	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35310	: Pg=84.98, Qg=15.78 -> Pg=139.5, Qg=28.5
% INFO    : Gen at bus 35310	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35310	: Pg=84.98, Qg=15.78 -> Pg=139.5, Qg=28.5
% INFO    : Gen at bus 35310	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35310	: Pg=84.98, Qg=15.78 -> Pg=139.5, Qg=28.5
% INFO    : Gen at bus 35310	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35310	: Pg=84.98, Qg=15.78 -> Pg=139.5, Qg=28.5
% INFO    : Gen at bus 35310	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35310	: Pg=84.98, Qg=15.78 -> Pg=139.5, Qg=28.5
% INFO    : Gen at bus 35310	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35310	: Pg=155.18, Qg=15.78 -> Pg=353.55, Qg=42.75
% INFO    : Gen at bus 35310	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35311	: Pg=170.95, Qg=96.14 -> Pg=356.95, Qg=42.05
% INFO    : Gen at bus 35311	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35311	: Pg=168.93, Qg=96.14 -> Pg=355.65, Qg=42.0
% INFO    : Gen at bus 35311	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35311	: Pg=166.93, Qg=96.14 -> Pg=354.6, Qg=42.0
% INFO    : Gen at bus 35311	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35311	: Pg=163.94, Qg=96.14 -> Pg=353.25, Qg=42.0
% INFO    : Gen at bus 35311	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35312	: Pg=312.76, Qg=-31.39 -> Pg=404.7, Qg=38.45
% INFO    : Gen at bus 35312	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35313	: Pg=181.59, Qg=158.46 -> Pg=316.3, Qg=34.9
% INFO    : Gen at bus 35313	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35313	: Pg=123.9, Qg=158.46 -> Pg=235.25, Qg=26.85
% INFO    : Gen at bus 35313	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35313	: Pg=123.9, Qg=158.46 -> Pg=235.25, Qg=26.85
% INFO    : Gen at bus 35313	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35313	: Pg=188.61, Qg=158.46 -> Pg=359.3, Qg=41.05
% INFO    : Gen at bus 35313	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35314	: Pg=188.25, Qg=45.26 -> Pg=254.7, Qg=47.15
% INFO    : Gen at bus 35314	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35314	: Pg=188.25, Qg=45.26 -> Pg=254.7, Qg=47.15
% INFO    : Gen at bus 35314	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35314	: Pg=153.96, Qg=45.26 -> Pg=251.3, Qg=0.0
% INFO    : Gen at bus 35314	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35314	: Pg=294.83, Qg=45.26 -> Pg=436.05, Qg=0.0
% INFO    : Gen at bus 35314	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35315	: Pg=168.34, Qg=21.98 -> Pg=227.0, Qg=22.1
% INFO    : Gen at bus 35315	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35315	: Pg=112.34, Qg=21.98 -> Pg=199.0, Qg=22.1
% INFO    : Gen at bus 35315	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35316	: Pg=320.44, Qg=51.61 -> Pg=558.15, Qg=61.65
% INFO    : Gen at bus 35316	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35316	: Pg=107.03, Qg=51.61 -> Pg=190.25, Qg=40.15
% INFO    : Gen at bus 35316	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35317	: Pg=125.76, Qg=-7.93 -> Pg=175.0, Qg=32.9
% INFO    : Gen at bus 35317	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35317	: Pg=125.76, Qg=-7.93 -> Pg=175.0, Qg=32.9
% INFO    : Gen at bus 35317	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35317	: Pg=125.76, Qg=-7.93 -> Pg=175.0, Qg=32.9
% INFO    : Gen at bus 35317	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35317	: Pg=125.76, Qg=-7.93 -> Pg=175.0, Qg=32.9
% INFO    : Gen at bus 35317	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35317	: Pg=125.76, Qg=-7.93 -> Pg=175.0, Qg=32.9
% INFO    : Gen at bus 35317	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35318	: Pg=122.21, Qg=105.25 -> Pg=162.5, Qg=29.8
% INFO    : Gen at bus 35318	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35318	: Pg=122.21, Qg=105.25 -> Pg=162.5, Qg=29.8
% INFO    : Gen at bus 35318	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35318	: Pg=122.21, Qg=105.25 -> Pg=162.5, Qg=29.8
% INFO    : Gen at bus 35318	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35319	: Pg=125.13, Qg=19.6 -> Pg=162.5, Qg=15.5
% INFO    : Gen at bus 35319	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35319	: Pg=100.01, Qg=19.6 -> Pg=147.5, Qg=15.1
% INFO    : Gen at bus 35319	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35320	: Pg=72.81, Qg=2.39 -> Pg=130.0, Qg=14.5
% INFO    : Gen at bus 35320	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35320	: Pg=70.13, Qg=2.39 -> Pg=135.0, Qg=29.35
% INFO    : Gen at bus 35320	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35320	: Pg=55.13, Qg=2.39 -> Pg=127.5, Qg=29.35
% INFO    : Gen at bus 35320	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35321	: Pg=55.38, Qg=-20.88 -> Pg=113.0, Qg=13.25
% INFO    : Gen at bus 35321	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35321	: Pg=72.63, Qg=-20.88 -> Pg=121.625, Qg=13.25
% INFO    : Gen at bus 35321	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35321	: Pg=55.38, Qg=-20.88 -> Pg=113.0, Qg=13.25
% INFO    : Gen at bus 35321	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35321	: Pg=55.38, Qg=-20.88 -> Pg=113.0, Qg=13.25
% INFO    : Gen at bus 35321	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35321	: Pg=55.38, Qg=-20.88 -> Pg=113.0, Qg=13.25
% INFO    : Gen at bus 35321	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35321	: Pg=55.38, Qg=-20.88 -> Pg=113.0, Qg=13.25
% INFO    : Gen at bus 35321	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35321	: Pg=55.38, Qg=-20.88 -> Pg=113.0, Qg=13.25
% INFO    : Gen at bus 35321	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35321	: Pg=55.38, Qg=-20.88 -> Pg=113.0, Qg=13.25
% INFO    : Gen at bus 35321	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35321	: Pg=55.38, Qg=-20.88 -> Pg=113.0, Qg=13.25
% INFO    : Gen at bus 35321	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35321	: Pg=55.38, Qg=-20.88 -> Pg=113.0, Qg=13.25
% INFO    : Gen at bus 35321	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35322	: Pg=69.09, Qg=101.1 -> Pg=114.1, Qg=23.35
% INFO    : Gen at bus 35322	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35322	: Pg=70.24, Qg=129.8 -> Pg=137.2, Qg=30.0
% INFO    : Gen at bus 35322	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35322	: Pg=86.81, Qg=168.6 -> Pg=176.0, Qg=38.95
% INFO    : Gen at bus 35322	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35323	: Pg=94.09, Qg=90.81 -> Pg=126.6, Qg=23.35
% INFO    : Gen at bus 35323	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35323	: Pg=157.07, Qg=90.81 -> Pg=216.05, Qg=21.3
% INFO    : Gen at bus 35323	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35324	: Pg=64.13, Qg=49.62 -> Pg=121.75, Qg=25.7
% INFO    : Gen at bus 35324	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35324	: Pg=155.34, Qg=49.62 -> Pg=309.5, Qg=35.0
% INFO    : Gen at bus 35324	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35324	: Pg=36.08, Qg=49.62 -> Pg=74.8, Qg=16.25
% INFO    : Gen at bus 35324	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35324	: Pg=50.09, Qg=49.62 -> Pg=86.5, Qg=17.6
% INFO    : Gen at bus 35324	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35324	: Pg=50.09, Qg=49.62 -> Pg=88.0, Qg=18.05
% INFO    : Gen at bus 35324	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35324	: Pg=50.0, Qg=49.62 -> Pg=88.0, Qg=18.05
% INFO    : Gen at bus 35324	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35324	: Pg=53.16, Qg=49.62 -> Pg=88.0, Qg=18.05
% INFO    : Gen at bus 35324	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35324	: Pg=53.16, Qg=49.62 -> Pg=88.0, Qg=18.05
% INFO    : Gen at bus 35324	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35324	: Pg=109.43, Qg=49.62 -> Pg=140.9, Qg=25.35
% INFO    : Gen at bus 35324	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35324	: Pg=94.43, Qg=49.62 -> Pg=133.4, Qg=25.35
% INFO    : Gen at bus 35324	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35325	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35325	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35327	: Pg=57.45, Qg=41.88 -> Pg=76.5, Qg=7.4
% INFO    : Gen at bus 35327	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35327	: Pg=57.45, Qg=41.88 -> Pg=76.5, Qg=7.4
% INFO    : Gen at bus 35327	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35327	: Pg=57.7, Qg=41.88 -> Pg=81.5, Qg=8.15
% INFO    : Gen at bus 35327	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35327	: Pg=57.7, Qg=41.88 -> Pg=81.5, Qg=8.15
% INFO    : Gen at bus 35327	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35327	: Pg=32.45, Qg=41.88 -> Pg=64.0, Qg=14.0
% INFO    : Gen at bus 35327	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35327	: Pg=2.45, Qg=41.88 -> Pg=49.0, Qg=14.0
% INFO    : Gen at bus 35327	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35327	: Pg=6.73, Qg=41.88 -> Pg=76.0, Qg=11.25
% INFO    : Gen at bus 35327	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35327	: Pg=6.73, Qg=41.88 -> Pg=76.0, Qg=11.25
% INFO    : Gen at bus 35327	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35327	: Pg=6.73, Qg=41.88 -> Pg=76.0, Qg=11.25
% INFO    : Gen at bus 35327	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35328	: Pg=17.2, Qg=40.61 -> Pg=51.5, Qg=6.65
% INFO    : Gen at bus 35328	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35329	: Pg=47.15, Qg=6.14 -> Pg=65.5, Qg=6.5
% INFO    : Gen at bus 35329	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35329	: Pg=47.15, Qg=6.14 -> Pg=65.5, Qg=6.5
% INFO    : Gen at bus 35329	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35329	: Pg=47.15, Qg=6.14 -> Pg=65.5, Qg=6.5
% INFO    : Gen at bus 35329	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35329	: Pg=47.15, Qg=6.14 -> Pg=65.5, Qg=6.5
% INFO    : Gen at bus 35329	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35329	: Pg=47.15, Qg=6.14 -> Pg=65.5, Qg=6.5
% INFO    : Gen at bus 35329	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35329	: Pg=47.15, Qg=6.14 -> Pg=65.5, Qg=6.5
% INFO    : Gen at bus 35329	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35329	: Pg=47.15, Qg=6.14 -> Pg=65.5, Qg=6.5
% INFO    : Gen at bus 35329	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35329	: Pg=47.15, Qg=6.14 -> Pg=65.5, Qg=6.5
% INFO    : Gen at bus 35329	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35330	: Pg=2.27, Qg=5.18 -> Pg=6.325, Qg=0.815
% INFO    : Gen at bus 35330	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35330	: Pg=2.27, Qg=5.18 -> Pg=6.325, Qg=0.815
% INFO    : Gen at bus 35330	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35330	: Pg=2.27, Qg=5.18 -> Pg=6.325, Qg=0.815
% INFO    : Gen at bus 35330	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35330	: Pg=2.27, Qg=5.18 -> Pg=6.325, Qg=0.815
% INFO    : Gen at bus 35330	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35330	: Pg=2.27, Qg=5.18 -> Pg=6.325, Qg=0.815
% INFO    : Gen at bus 35330	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35330	: Pg=2.27, Qg=5.18 -> Pg=6.325, Qg=0.815
% INFO    : Gen at bus 35330	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35330	: Pg=2.27, Qg=5.18 -> Pg=6.325, Qg=0.815
% INFO    : Gen at bus 35330	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35330	: Pg=2.27, Qg=5.18 -> Pg=6.325, Qg=0.815
% INFO    : Gen at bus 35330	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35332	: Pg=26.31, Qg=45.5 -> Pg=50.625, Qg=10.25
% INFO    : Gen at bus 35332	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35333	: Pg=61.0, Qg=33.9 -> Pg=65.5, Qg=5.3
% INFO    : Gen at bus 35333	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35334	: Pg=16.5, Qg=29.37 -> Pg=37.5, Qg=8.6
% INFO    : Gen at bus 35334	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35334	: Pg=16.5, Qg=29.37 -> Pg=37.5, Qg=8.6
% INFO    : Gen at bus 35334	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35335	: Pg=45.0, Qg=21.8 -> Pg=45.0, Qg=3.4
% INFO    : Gen at bus 35335	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35335	: Pg=45.0, Qg=21.8 -> Pg=45.0, Qg=3.4
% INFO    : Gen at bus 35335	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35335	: Pg=45.0, Qg=21.8 -> Pg=45.0, Qg=3.4
% INFO    : Gen at bus 35335	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35335	: Pg=45.0, Qg=21.8 -> Pg=45.0, Qg=3.4
% INFO    : Gen at bus 35335	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35335	: Pg=45.0, Qg=21.8 -> Pg=45.0, Qg=3.4
% INFO    : Gen at bus 35335	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35335	: Pg=45.0, Qg=21.8 -> Pg=45.0, Qg=3.4
% INFO    : Gen at bus 35335	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35337	: Pg=23.82, Qg=20.2 -> Pg=27.8, Qg=4.65
% INFO    : Gen at bus 35337	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35337	: Pg=85.46, Qg=110.3 -> Pg=129.5, Qg=25.5
% INFO    : Gen at bus 35337	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35339	: Pg=2.0, Qg=7.07 -> Pg=5.7, Qg=1.97
% INFO    : Gen at bus 35339	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35339	: Pg=2.0, Qg=7.07 -> Pg=5.7, Qg=1.97
% INFO    : Gen at bus 35339	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35339	: Pg=2.0, Qg=7.07 -> Pg=5.7, Qg=1.97
% INFO    : Gen at bus 35339	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35340	: Pg=24.06, Qg=50.2 -> Pg=52.5, Qg=11.6
% INFO    : Gen at bus 35340	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35340	: Pg=24.06, Qg=50.2 -> Pg=52.5, Qg=11.6
% INFO    : Gen at bus 35340	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35340	: Pg=7.0, Qg=16.7 -> Pg=17.0, Qg=3.85
% INFO    : Gen at bus 35340	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35340	: Pg=7.0, Qg=16.7 -> Pg=17.0, Qg=3.85
% INFO    : Gen at bus 35340	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35341	: Pg=3.67, Qg=12.9 -> Pg=14.85, Qg=2.0
% INFO    : Gen at bus 35341	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35342	: Pg=2.52, Qg=12.8 -> Pg=11.35, Qg=2.95
% INFO    : Gen at bus 35342	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35342	: Pg=2.52, Qg=12.8 -> Pg=11.35, Qg=2.95
% INFO    : Gen at bus 35342	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35342	: Pg=2.52, Qg=12.8 -> Pg=11.35, Qg=2.95
% INFO    : Gen at bus 35342	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35343	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35344	: Pg=224.57, Qg=41.11 -> Pg=493.2, Qg=58.95
% INFO    : Gen at bus 35344	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35345	: Pg=114.65, Qg=18.75 -> Pg=147.75, Qg=26.6
% INFO    : Gen at bus 35345	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35345	: Pg=114.65, Qg=18.75 -> Pg=147.75, Qg=26.6
% INFO    : Gen at bus 35345	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35345	: Pg=114.65, Qg=18.75 -> Pg=147.75, Qg=26.6
% INFO    : Gen at bus 35345	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35345	: Pg=114.65, Qg=18.75 -> Pg=147.75, Qg=26.6
% INFO    : Gen at bus 35345	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35345	: Pg=149.89, Qg=18.75 -> Pg=170.1, Qg=27.95
% INFO    : Gen at bus 35345	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35345	: Pg=149.89, Qg=18.75 -> Pg=170.1, Qg=27.95
% INFO    : Gen at bus 35345	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35345	: Pg=258.53, Qg=18.75 -> Pg=356.65, Qg=78.5
% INFO    : Gen at bus 35345	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35345	: Pg=258.53, Qg=18.75 -> Pg=356.65, Qg=78.5
% INFO    : Gen at bus 35345	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35346	: Pg=203.64, Qg=44.84 -> Pg=367.3, Qg=78.0
% INFO    : Gen at bus 35346	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35346	: Pg=209.61, Qg=44.84 -> Pg=486.5, Qg=59.1
% INFO    : Gen at bus 35346	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35347	: Pg=362.87, Qg=13.89 -> Pg=431.85, Qg=38.8
% INFO    : Gen at bus 35347	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35348	: Pg=7.66, Qg=0.0 -> Pg=135.45, Qg=0.0
% INFO    : Gen at bus 35348	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35348	: Pg=7.66, Qg=0.0 -> Pg=135.45, Qg=0.0
% INFO    : Gen at bus 35348	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35348	: Pg=8.68, Qg=0.0 -> Pg=155.7, Qg=0.0
% INFO    : Gen at bus 35348	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35349	: Pg=60.01, Qg=53.46 -> Pg=127.5, Qg=28.6
% INFO    : Gen at bus 35349	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35349	: Pg=60.01, Qg=53.46 -> Pg=127.5, Qg=28.6
% INFO    : Gen at bus 35349	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35350	: Pg=119.62, Qg=-4.44 -> Pg=149.75, Qg=13.95
% INFO    : Gen at bus 35350	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35350	: Pg=119.62, Qg=-4.44 -> Pg=149.75, Qg=13.95
% INFO    : Gen at bus 35350	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35350	: Pg=119.62, Qg=-4.44 -> Pg=149.75, Qg=13.95
% INFO    : Gen at bus 35350	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35350	: Pg=42.82, Qg=-4.44 -> Pg=76.25, Qg=8.5
% INFO    : Gen at bus 35350	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35350	: Pg=42.82, Qg=-4.44 -> Pg=76.25, Qg=8.5
% INFO    : Gen at bus 35350	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35350	: Pg=42.82, Qg=-4.44 -> Pg=76.25, Qg=8.5
% INFO    : Gen at bus 35350	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35351	: Pg=133.59, Qg=86.8 -> Pg=154.2, Qg=13.5
% INFO    : Gen at bus 35351	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35351	: Pg=133.59, Qg=86.8 -> Pg=154.2, Qg=13.5
% INFO    : Gen at bus 35351	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35351	: Pg=133.59, Qg=86.8 -> Pg=154.2, Qg=13.5
% INFO    : Gen at bus 35351	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35351	: Pg=78.96, Qg=59.1 -> Pg=98.95, Qg=9.2
% INFO    : Gen at bus 35351	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35351	: Pg=78.96, Qg=59.1 -> Pg=98.95, Qg=9.2
% INFO    : Gen at bus 35351	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35351	: Pg=78.96, Qg=59.1 -> Pg=98.95, Qg=9.2
% INFO    : Gen at bus 35351	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35352	: Pg=114.48, Qg=-49.15 -> Pg=144.5, Qg=25.6
% INFO    : Gen at bus 35352	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35352	: Pg=114.48, Qg=-49.15 -> Pg=144.5, Qg=25.6
% INFO    : Gen at bus 35352	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35352	: Pg=114.48, Qg=-49.15 -> Pg=144.5, Qg=25.6
% INFO    : Gen at bus 35352	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35352	: Pg=149.07, Qg=-49.15 -> Pg=251.0, Qg=51.8
% INFO    : Gen at bus 35352	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35353	: Pg=86.87, Qg=39.19 -> Pg=130.45, Qg=13.5
% INFO    : Gen at bus 35353	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35353	: Pg=86.87, Qg=39.19 -> Pg=130.45, Qg=13.5
% INFO    : Gen at bus 35353	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35353	: Pg=86.87, Qg=39.19 -> Pg=130.45, Qg=13.5
% INFO    : Gen at bus 35353	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35353	: Pg=71.51, Qg=39.19 -> Pg=111.8, Qg=11.8
% INFO    : Gen at bus 35353	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35353	: Pg=71.51, Qg=39.19 -> Pg=111.8, Qg=11.8
% INFO    : Gen at bus 35353	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35353	: Pg=71.51, Qg=39.19 -> Pg=111.8, Qg=11.8
% INFO    : Gen at bus 35353	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35354	: Pg=94.42, Qg=109.4 -> Pg=133.3, Qg=25.25
% INFO    : Gen at bus 35354	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35354	: Pg=94.42, Qg=109.4 -> Pg=133.3, Qg=25.25
% INFO    : Gen at bus 35354	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35354	: Pg=124.96, Qg=120.4 -> Pg=159.05, Qg=28.4
% INFO    : Gen at bus 35354	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35355	: Pg=99.42, Qg=23.5 -> Pg=135.8, Qg=25.25
% INFO    : Gen at bus 35355	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35355	: Pg=99.42, Qg=23.5 -> Pg=135.8, Qg=25.25
% INFO    : Gen at bus 35355	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35355	: Pg=64.96, Qg=23.5 -> Pg=129.05, Qg=28.4
% INFO    : Gen at bus 35355	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35356	: Pg=72.54, Qg=14.37 -> Pg=85.65, Qg=14.5
% INFO    : Gen at bus 35356	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35356	: Pg=21.25, Qg=14.37 -> Pg=27.25, Qg=4.89
% INFO    : Gen at bus 35356	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35356	: Pg=21.25, Qg=14.37 -> Pg=27.25, Qg=4.89
% INFO    : Gen at bus 35356	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35356	: Pg=21.25, Qg=14.37 -> Pg=27.25, Qg=4.89
% INFO    : Gen at bus 35356	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35356	: Pg=21.25, Qg=14.37 -> Pg=27.25, Qg=4.89
% INFO    : Gen at bus 35356	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35356	: Pg=21.25, Qg=14.37 -> Pg=27.25, Qg=4.89
% INFO    : Gen at bus 35356	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35357	: Pg=135.33, Qg=-7.73 -> Pg=146.15, Qg=12.15
% INFO    : Gen at bus 35357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35357	: Pg=135.33, Qg=-7.73 -> Pg=146.15, Qg=12.15
% INFO    : Gen at bus 35357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35357	: Pg=135.33, Qg=-7.73 -> Pg=146.15, Qg=12.15
% INFO    : Gen at bus 35357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35357	: Pg=76.35, Qg=-7.73 -> Pg=89.85, Qg=8.0
% INFO    : Gen at bus 35357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35357	: Pg=76.35, Qg=-7.73 -> Pg=89.85, Qg=8.0
% INFO    : Gen at bus 35357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35357	: Pg=76.35, Qg=-7.73 -> Pg=89.85, Qg=8.0
% INFO    : Gen at bus 35357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35359	: Pg=62.33, Qg=21.39 -> Pg=76.5, Qg=7.0
% INFO    : Gen at bus 35359	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35359	: Pg=62.33, Qg=21.39 -> Pg=76.5, Qg=7.0
% INFO    : Gen at bus 35359	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35359	: Pg=62.33, Qg=21.39 -> Pg=76.5, Qg=7.0
% INFO    : Gen at bus 35359	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35359	: Pg=62.33, Qg=21.39 -> Pg=76.5, Qg=7.0
% INFO    : Gen at bus 35359	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35360	: Pg=55.09, Qg=22.07 -> Pg=68.25, Qg=11.95
% INFO    : Gen at bus 35360	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35360	: Pg=55.09, Qg=22.07 -> Pg=68.25, Qg=11.95
% INFO    : Gen at bus 35360	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35360	: Pg=55.09, Qg=22.07 -> Pg=68.25, Qg=11.95
% INFO    : Gen at bus 35360	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35361	: Pg=51.92, Qg=0.0 -> Pg=63.3, Qg=0.0
% INFO    : Gen at bus 35361	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35361	: Pg=51.92, Qg=0.0 -> Pg=63.3, Qg=0.0
% INFO    : Gen at bus 35361	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35361	: Pg=51.92, Qg=0.0 -> Pg=63.3, Qg=0.0
% INFO    : Gen at bus 35361	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35361	: Pg=51.92, Qg=0.0 -> Pg=63.3, Qg=0.0
% INFO    : Gen at bus 35361	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35362	: Pg=31.78, Qg=16.65 -> Pg=50.6, Qg=5.4
% INFO    : Gen at bus 35362	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35362	: Pg=31.78, Qg=16.65 -> Pg=50.6, Qg=5.4
% INFO    : Gen at bus 35362	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35362	: Pg=31.78, Qg=16.65 -> Pg=50.6, Qg=5.4
% INFO    : Gen at bus 35362	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35362	: Pg=31.78, Qg=16.65 -> Pg=50.6, Qg=5.4
% INFO    : Gen at bus 35362	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35362	: Pg=31.78, Qg=16.65 -> Pg=50.6, Qg=5.4
% INFO    : Gen at bus 35362	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35362	: Pg=31.78, Qg=16.65 -> Pg=50.6, Qg=5.4
% INFO    : Gen at bus 35362	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35363	: Pg=20.46, Qg=37.9 -> Pg=42.405, Qg=7.95
% INFO    : Gen at bus 35363	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35364	: Pg=37.48, Qg=20.9 -> Pg=47.5, Qg=8.45
% INFO    : Gen at bus 35364	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35364	: Pg=37.48, Qg=20.9 -> Pg=47.5, Qg=8.45
% INFO    : Gen at bus 35364	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35364	: Pg=37.48, Qg=20.9 -> Pg=47.5, Qg=8.45
% INFO    : Gen at bus 35364	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35364	: Pg=55.08, Qg=20.9 -> Pg=68.0, Qg=11.85
% INFO    : Gen at bus 35364	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35364	: Pg=55.09, Qg=20.9 -> Pg=68.25, Qg=11.95
% INFO    : Gen at bus 35364	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35365	: Pg=7.2, Qg=15.8 -> Pg=27.0, Qg=0.0
% INFO    : Gen at bus 35365	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35366	: Pg=25.18, Qg=29.1 -> Pg=35.5, Qg=6.7
% INFO    : Gen at bus 35366	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35366	: Pg=25.18, Qg=29.1 -> Pg=35.5, Qg=6.7
% INFO    : Gen at bus 35366	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35366	: Pg=25.18, Qg=29.1 -> Pg=35.5, Qg=6.7
% INFO    : Gen at bus 35366	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35367	: Pg=3.6, Qg=27.8 -> Pg=33.0, Qg=4.85
% INFO    : Gen at bus 35367	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35367	: Pg=6.15, Qg=27.8 -> Pg=25.5, Qg=9.6
% INFO    : Gen at bus 35367	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35368	: Pg=22.05, Qg=20.3 -> Pg=31.45, Qg=3.15
% INFO    : Gen at bus 35368	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35368	: Pg=18.15, Qg=28.5 -> Pg=31.5, Qg=6.6
% INFO    : Gen at bus 35368	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35368	: Pg=18.23, Qg=30.4 -> Pg=33.0, Qg=7.05
% INFO    : Gen at bus 35368	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35369	: Pg=51.3, Qg=63.85 -> Pg=69.4, Qg=15.55
% INFO    : Gen at bus 35369	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35369	: Pg=22.05, Qg=20.3 -> Pg=31.45, Qg=3.15
% INFO    : Gen at bus 35369	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35369	: Pg=272.54, Qg=63.85 -> Pg=367.15, Qg=82.75
% INFO    : Gen at bus 35369	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35369	: Pg=44.23, Qg=58.1 -> Pg=56.9, Qg=13.4
% INFO    : Gen at bus 35369	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35369	: Pg=44.23, Qg=58.1 -> Pg=56.9, Qg=13.4
% INFO    : Gen at bus 35369	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35369	: Pg=141.08, Qg=63.85 -> Pg=183.35, Qg=42.85
% INFO    : Gen at bus 35369	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35370	: Pg=4.93, Qg=10.9 -> Pg=10.775, Qg=2.6
% INFO    : Gen at bus 35370	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35370	: Pg=4.93, Qg=10.9 -> Pg=10.775, Qg=2.6
% INFO    : Gen at bus 35370	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35371	: Pg=5.81, Qg=16.5 -> Pg=18.6, Qg=2.9
% INFO    : Gen at bus 35371	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35371	: Pg=5.82, Qg=20.2 -> Pg=18.8, Qg=4.65
% INFO    : Gen at bus 35371	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35372	: Pg=8.03, Qg=14.9 -> Pg=16.64, Qg=3.15
% INFO    : Gen at bus 35372	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35372	: Pg=8.03, Qg=14.9 -> Pg=16.64, Qg=3.15
% INFO    : Gen at bus 35372	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35372	: Pg=8.03, Qg=14.9 -> Pg=16.64, Qg=3.15
% INFO    : Gen at bus 35372	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35373	: Pg=4.63, Qg=18.9 -> Pg=14.6, Qg=5.25
% INFO    : Gen at bus 35373	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35373	: Pg=4.63, Qg=18.9 -> Pg=14.6, Qg=5.25
% INFO    : Gen at bus 35373	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35374	: Pg=10.56, Qg=0.0 -> Pg=16.1, Qg=0.0
% INFO    : Gen at bus 35374	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35374	: Pg=11.64, Qg=0.0 -> Pg=18.25, Qg=0.0
% INFO    : Gen at bus 35374	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35375	: Pg=6.5, Qg=6.6 -> Pg=13.0, Qg=0.0
% INFO    : Gen at bus 35375	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35376	: Pg=16.48, Qg=12.4 -> Pg=18.0, Qg=2.85
% INFO    : Gen at bus 35376	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35377	: Pg=682.56, Qg=320.96 -> Pg=975.0, Qg=98.15
% INFO    : Gen at bus 35377	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35377	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35378	: Pg=1123.0, Qg=470.52 -> Pg=1196.45, Qg=95.85
% INFO    : Gen at bus 35378	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35379	: Pg=1152.0, Qg=135.29 -> Pg=1186.25, Qg=92.15
% INFO    : Gen at bus 35379	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35379	: Pg=1125.7, Qg=135.29 -> Pg=1173.1, Qg=92.15
% INFO    : Gen at bus 35379	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35380	: Pg=595.79, Qg=344.8 -> Pg=761.0, Qg=0.0
% INFO    : Gen at bus 35380	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35381	: Pg=428.39, Qg=106.46 -> Pg=364.2, Qg=32.35
% INFO    : Gen at bus 35381	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35381	: Pg=428.39, Qg=106.46 -> Pg=364.2, Qg=32.35
% INFO    : Gen at bus 35381	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35381	: Pg=428.39, Qg=106.46 -> Pg=364.2, Qg=32.35
% INFO    : Gen at bus 35381	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35381	: Pg=428.39, Qg=106.46 -> Pg=234.2, Qg=32.35
% INFO    : Gen at bus 35381	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=5.6, Qg=11.6 -> Pg=14.45, Qg=1.8
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=5.6, Qg=11.6 -> Pg=14.45, Qg=1.8
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=5.6, Qg=11.6 -> Pg=14.45, Qg=1.8
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=5.6, Qg=11.6 -> Pg=14.45, Qg=1.8
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=5.6, Qg=11.6 -> Pg=14.45, Qg=1.8
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=5.6, Qg=11.6 -> Pg=14.45, Qg=1.8
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=5.6, Qg=11.6 -> Pg=14.45, Qg=1.8
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=5.6, Qg=11.6 -> Pg=14.45, Qg=1.8
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=11.49, Qg=28.9 -> Pg=34.8, Qg=4.5
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=11.49, Qg=28.9 -> Pg=34.8, Qg=4.5
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=11.49, Qg=28.9 -> Pg=34.8, Qg=4.5
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=5.6, Qg=11.6 -> Pg=14.45, Qg=1.8
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=11.49, Qg=28.9 -> Pg=34.8, Qg=4.5
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=176.26, Qg=117.44 -> Pg=249.0, Qg=24.9
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=176.26, Qg=117.44 -> Pg=249.0, Qg=42.9
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=176.26, Qg=117.44 -> Pg=249.0, Qg=42.9
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=5.6, Qg=11.6 -> Pg=14.45, Qg=1.8
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=5.6, Qg=11.6 -> Pg=14.45, Qg=1.8
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=5.6, Qg=11.6 -> Pg=14.45, Qg=1.8
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=5.6, Qg=11.6 -> Pg=14.45, Qg=1.8
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=5.6, Qg=11.6 -> Pg=14.45, Qg=1.8
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=5.6, Qg=11.6 -> Pg=14.45, Qg=1.8
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35382	: Pg=5.6, Qg=11.6 -> Pg=14.45, Qg=1.8
% INFO    : Gen at bus 35382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35383	: Pg=83.01, Qg=96.9 -> Pg=139.0, Qg=15.1
% INFO    : Gen at bus 35383	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35383	: Pg=83.01, Qg=96.9 -> Pg=139.0, Qg=15.1
% INFO    : Gen at bus 35383	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35383	: Pg=83.01, Qg=141.7 -> Pg=139.0, Qg=37.5
% INFO    : Gen at bus 35383	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35383	: Pg=83.01, Qg=141.7 -> Pg=139.0, Qg=37.5
% INFO    : Gen at bus 35383	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35385	: Pg=74.64, Qg=39.84 -> Pg=127.7, Qg=14.0
% INFO    : Gen at bus 35385	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35385	: Pg=74.79, Qg=39.84 -> Pg=130.6, Qg=14.45
% INFO    : Gen at bus 35385	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35385	: Pg=74.79, Qg=39.84 -> Pg=130.6, Qg=14.45
% INFO    : Gen at bus 35385	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35386	: Pg=78.01, Qg=72.01 -> Pg=136.5, Qg=15.1
% INFO    : Gen at bus 35386	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35386	: Pg=78.01, Qg=72.01 -> Pg=136.5, Qg=15.1
% INFO    : Gen at bus 35386	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35386	: Pg=78.01, Qg=72.01 -> Pg=136.5, Qg=15.1
% INFO    : Gen at bus 35386	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35386	: Pg=78.01, Qg=72.01 -> Pg=136.5, Qg=15.1
% INFO    : Gen at bus 35386	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35386	: Pg=78.01, Qg=72.01 -> Pg=136.5, Qg=15.1
% INFO    : Gen at bus 35386	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35386	: Pg=59.38, Qg=72.01 -> Pg=115.0, Qg=13.25
% INFO    : Gen at bus 35386	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35386	: Pg=59.38, Qg=72.01 -> Pg=115.0, Qg=13.25
% INFO    : Gen at bus 35386	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35386	: Pg=59.38, Qg=72.01 -> Pg=115.0, Qg=13.25
% INFO    : Gen at bus 35386	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35386	: Pg=59.38, Qg=72.01 -> Pg=115.0, Qg=13.25
% INFO    : Gen at bus 35386	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35387	: Pg=82.54, Qg=12.72 -> Pg=125.8, Qg=13.1
% INFO    : Gen at bus 35387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35387	: Pg=62.12, Qg=12.72 -> Pg=72.25, Qg=6.35
% INFO    : Gen at bus 35387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35387	: Pg=62.16, Qg=12.72 -> Pg=73.1, Qg=6.5
% INFO    : Gen at bus 35387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35387	: Pg=62.16, Qg=12.72 -> Pg=73.1, Qg=6.5
% INFO    : Gen at bus 35387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35387	: Pg=62.16, Qg=12.72 -> Pg=73.1, Qg=6.5
% INFO    : Gen at bus 35387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35387	: Pg=62.16, Qg=12.72 -> Pg=73.1, Qg=6.5
% INFO    : Gen at bus 35387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35387	: Pg=103.25, Qg=12.72 -> Pg=177.2, Qg=19.45
% INFO    : Gen at bus 35387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35387	: Pg=82.54, Qg=12.72 -> Pg=125.8, Qg=13.1
% INFO    : Gen at bus 35387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35387	: Pg=62.12, Qg=12.72 -> Pg=72.25, Qg=6.35
% INFO    : Gen at bus 35387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35387	: Pg=62.12, Qg=12.72 -> Pg=72.25, Qg=6.35
% INFO    : Gen at bus 35387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35387	: Pg=62.12, Qg=12.72 -> Pg=72.25, Qg=6.35
% INFO    : Gen at bus 35387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35387	: Pg=62.12, Qg=12.72 -> Pg=72.25, Qg=6.35
% INFO    : Gen at bus 35387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35387	: Pg=62.12, Qg=12.72 -> Pg=72.25, Qg=6.35
% INFO    : Gen at bus 35387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35387	: Pg=62.12, Qg=12.72 -> Pg=72.25, Qg=6.35
% INFO    : Gen at bus 35387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35387	: Pg=62.12, Qg=12.72 -> Pg=72.25, Qg=6.35
% INFO    : Gen at bus 35387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=63.13, Qg=2.41 -> Pg=92.5, Qg=9.4
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=71.72, Qg=2.41 -> Pg=120.095, Qg=13.05
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=58.12, Qg=2.41 -> Pg=70.25, Qg=6.35
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=58.12, Qg=2.41 -> Pg=70.25, Qg=6.35
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=58.12, Qg=2.41 -> Pg=70.25, Qg=6.35
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=58.12, Qg=2.41 -> Pg=70.25, Qg=6.35
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=26.7, Qg=2.41 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=26.7, Qg=2.41 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=26.7, Qg=2.41 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=26.7, Qg=2.41 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=26.7, Qg=2.41 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=63.13, Qg=2.41 -> Pg=92.5, Qg=9.4
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=26.7, Qg=2.41 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=26.7, Qg=2.41 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=26.7, Qg=2.41 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=26.7, Qg=2.41 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=26.7, Qg=2.41 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=26.7, Qg=2.41 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=26.7, Qg=2.41 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=26.7, Qg=2.41 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=26.7, Qg=2.41 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=26.7, Qg=2.41 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=63.13, Qg=2.41 -> Pg=92.5, Qg=9.4
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=26.7, Qg=2.41 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=63.13, Qg=2.41 -> Pg=92.5, Qg=9.4
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=61.68, Qg=2.41 -> Pg=102.5, Qg=11.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=61.68, Qg=2.41 -> Pg=102.5, Qg=11.1
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=64.33, Qg=2.41 -> Pg=116.4, Qg=13.05
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=64.33, Qg=2.41 -> Pg=116.4, Qg=13.05
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35388	: Pg=71.72, Qg=2.41 -> Pg=120.095, Qg=13.05
% INFO    : Gen at bus 35388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35389	: Pg=86.96, Qg=50.88 -> Pg=101.0, Qg=8.95
% INFO    : Gen at bus 35389	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35389	: Pg=86.96, Qg=50.88 -> Pg=101.0, Qg=8.95
% INFO    : Gen at bus 35389	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35389	: Pg=77.81, Qg=50.88 -> Pg=93.5, Qg=8.45
% INFO    : Gen at bus 35389	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35389	: Pg=77.81, Qg=50.88 -> Pg=93.5, Qg=8.45
% INFO    : Gen at bus 35389	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35390	: Pg=59.12, Qg=40.9 -> Pg=70.75, Qg=6.35
% INFO    : Gen at bus 35390	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35390	: Pg=59.12, Qg=40.9 -> Pg=70.75, Qg=6.35
% INFO    : Gen at bus 35390	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35390	: Pg=59.12, Qg=40.9 -> Pg=70.75, Qg=6.35
% INFO    : Gen at bus 35390	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35390	: Pg=59.12, Qg=40.9 -> Pg=70.75, Qg=6.35
% INFO    : Gen at bus 35390	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35390	: Pg=12.04, Qg=39.4 -> Pg=45.65, Qg=6.15
% INFO    : Gen at bus 35390	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35390	: Pg=12.04, Qg=39.4 -> Pg=45.65, Qg=6.15
% INFO    : Gen at bus 35390	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35390	: Pg=12.04, Qg=39.4 -> Pg=45.65, Qg=6.15
% INFO    : Gen at bus 35390	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35390	: Pg=12.04, Qg=39.4 -> Pg=45.65, Qg=6.15
% INFO    : Gen at bus 35390	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35391	: Pg=21.07, Qg=6.93 -> Pg=11.535, Qg=0.0
% INFO    : Gen at bus 35391	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35391	: Pg=21.07, Qg=6.93 -> Pg=11.535, Qg=0.0
% INFO    : Gen at bus 35391	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35391	: Pg=21.07, Qg=6.93 -> Pg=11.535, Qg=0.0
% INFO    : Gen at bus 35391	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35391	: Pg=25.0, Qg=8.2 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 35391	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35393	: Pg=18.0, Qg=8.73 -> Pg=18.0, Qg=1.365
% INFO    : Gen at bus 35393	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35393	: Pg=18.0, Qg=8.73 -> Pg=18.0, Qg=1.365
% INFO    : Gen at bus 35393	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35393	: Pg=18.0, Qg=8.73 -> Pg=18.0, Qg=1.365
% INFO    : Gen at bus 35393	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35395	: Pg=19.25, Qg=31.0 -> Pg=34.0, Qg=7.15
% INFO    : Gen at bus 35395	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35396	: Pg=8.42, Qg=12.47 -> Pg=12.3, Qg=3.47
% INFO    : Gen at bus 35396	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35396	: Pg=8.42, Qg=12.47 -> Pg=12.3, Qg=3.47
% INFO    : Gen at bus 35396	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35396	: Pg=8.42, Qg=12.47 -> Pg=12.3, Qg=3.47
% INFO    : Gen at bus 35396	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35398	: Pg=45.0, Qg=21.8 -> Pg=45.0, Qg=3.4
% INFO    : Gen at bus 35398	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35398	: Pg=45.0, Qg=21.8 -> Pg=45.0, Qg=3.4
% INFO    : Gen at bus 35398	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35398	: Pg=45.0, Qg=21.8 -> Pg=45.0, Qg=3.4
% INFO    : Gen at bus 35398	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35399	: Pg=14.14, Qg=20.1 -> Pg=27.25, Qg=3.15
% INFO    : Gen at bus 35399	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35399	: Pg=14.41, Qg=25.3 -> Pg=32.65, Qg=3.95
% INFO    : Gen at bus 35399	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35400	: Pg=33.7, Qg=16.96 -> Pg=36.35, Qg=0.0
% INFO    : Gen at bus 35400	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35400	: Pg=33.7, Qg=16.96 -> Pg=36.35, Qg=0.0
% INFO    : Gen at bus 35400	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35400	: Pg=33.7, Qg=16.96 -> Pg=36.35, Qg=0.0
% INFO    : Gen at bus 35400	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35400	: Pg=33.7, Qg=16.96 -> Pg=36.35, Qg=0.0
% INFO    : Gen at bus 35400	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35400	: Pg=31.8, Qg=16.96 -> Pg=35.4, Qg=0.0
% INFO    : Gen at bus 35400	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35400	: Pg=31.8, Qg=16.96 -> Pg=35.4, Qg=0.0
% INFO    : Gen at bus 35400	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35401	: Pg=12.3, Qg=13.1 -> Pg=25.6, Qg=0.0
% INFO    : Gen at bus 35401	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35401	: Pg=35.11, Qg=13.1 -> Pg=25.6, Qg=0.0
% INFO    : Gen at bus 35401	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35401	: Pg=39.9, Qg=13.1 -> Pg=25.6, Qg=0.0
% INFO    : Gen at bus 35401	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35401	: Pg=39.9, Qg=13.1 -> Pg=25.6, Qg=0.0
% INFO    : Gen at bus 35401	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35402	: Pg=15.56, Qg=18.6 -> Pg=26.55, Qg=2.9
% INFO    : Gen at bus 35402	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35403	: Pg=12.0, Qg=5.8 -> Pg=12.0, Qg=0.9
% INFO    : Gen at bus 35403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35403	: Pg=12.0, Qg=5.8 -> Pg=12.0, Qg=0.9
% INFO    : Gen at bus 35403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35403	: Pg=12.0, Qg=5.8 -> Pg=12.0, Qg=0.9
% INFO    : Gen at bus 35403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35404	: Pg=10.2, Qg=17.4 -> Pg=22.65, Qg=2.7
% INFO    : Gen at bus 35404	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35404	: Pg=10.2, Qg=17.4 -> Pg=22.65, Qg=2.7
% INFO    : Gen at bus 35404	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35405	: Pg=25.12, Qg=13.3 -> Pg=32.35, Qg=0.0
% INFO    : Gen at bus 35405	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35405	: Pg=25.18, Qg=14.1 -> Pg=33.55, Qg=0.0
% INFO    : Gen at bus 35405	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35405	: Pg=11.46, Qg=16.6 -> Pg=22.4, Qg=2.6
% INFO    : Gen at bus 35405	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35405	: Pg=11.49, Qg=17.2 -> Pg=23.05, Qg=2.7
% INFO    : Gen at bus 35405	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35406	: Pg=16.85, Qg=9.45 -> Pg=12.925, Qg=1.925
% INFO    : Gen at bus 35406	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35406	: Pg=16.85, Qg=9.45 -> Pg=12.925, Qg=1.925
% INFO    : Gen at bus 35406	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35408	: Pg=33.3, Qg=16.1 -> Pg=33.3, Qg=2.5
% INFO    : Gen at bus 35408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35408	: Pg=33.3, Qg=16.1 -> Pg=33.3, Qg=2.5
% INFO    : Gen at bus 35408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35408	: Pg=33.3, Qg=16.1 -> Pg=33.3, Qg=2.5
% INFO    : Gen at bus 35408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35409	: Pg=15.31, Qg=15.7 -> Pg=23.45, Qg=2.45
% INFO    : Gen at bus 35409	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35409	: Pg=15.34, Qg=16.2 -> Pg=23.95, Qg=2.55
% INFO    : Gen at bus 35409	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35409	: Pg=15.37, Qg=16.8 -> Pg=24.55, Qg=2.65
% INFO    : Gen at bus 35409	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35409	: Pg=15.37, Qg=16.8 -> Pg=24.55, Qg=2.65
% INFO    : Gen at bus 35409	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35410	: Pg=14.99, Qg=15.3 -> Pg=22.85, Qg=2.4
% INFO    : Gen at bus 35410	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35410	: Pg=15.11, Qg=17.7 -> Pg=25.35, Qg=2.75
% INFO    : Gen at bus 35410	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35410	: Pg=14.04, Qg=20.1 -> Pg=27.2, Qg=3.15
% INFO    : Gen at bus 35410	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35410	: Pg=14.04, Qg=20.1 -> Pg=27.2, Qg=3.15
% INFO    : Gen at bus 35410	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35412	: Pg=20.44, Qg=9.7 -> Pg=24.65, Qg=0.0
% INFO    : Gen at bus 35412	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35412	: Pg=20.65, Qg=12.5 -> Pg=28.85, Qg=0.0
% INFO    : Gen at bus 35412	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35412	: Pg=20.66, Qg=12.6 -> Pg=29.0, Qg=0.0
% INFO    : Gen at bus 35412	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35413	: Pg=11.52, Qg=13.9 -> Pg=19.8, Qg=2.15
% INFO    : Gen at bus 35413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35414	: Pg=28.8, Qg=13.9 -> Pg=24.7, Qg=2.15
% INFO    : Gen at bus 35414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35414	: Pg=28.8, Qg=13.9 -> Pg=22.25, Qg=2.15
% INFO    : Gen at bus 35414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35415	: Pg=28.0, Qg=13.6 -> Pg=28.0, Qg=2.15
% INFO    : Gen at bus 35415	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35416	: Pg=0.0, Qg=10.7 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 35416	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35417	: Pg=25.0, Qg=15.5 -> Pg=25.0, Qg=3.6
% INFO    : Gen at bus 35417	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35417	: Pg=25.0, Qg=15.5 -> Pg=25.0, Qg=3.6
% INFO    : Gen at bus 35417	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35417	: Pg=25.0, Qg=15.5 -> Pg=25.0, Qg=3.6
% INFO    : Gen at bus 35417	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35417	: Pg=25.74, Qg=17.8 -> Pg=26.85, Qg=4.1
% INFO    : Gen at bus 35417	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35418	: Pg=1.63, Qg=8.2 -> Pg=13.0, Qg=0.0
% INFO    : Gen at bus 35418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35421	: Pg=3.25, Qg=14.97 -> Pg=26.0, Qg=0.0
% INFO    : Gen at bus 35421	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35421	: Pg=2.56, Qg=10.9 -> Pg=12.25, Qg=1.7
% INFO    : Gen at bus 35421	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35422	: Pg=0.4, Qg=0.97 -> Pg=1.2, Qg=0.155
% INFO    : Gen at bus 35422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35422	: Pg=0.4, Qg=0.97 -> Pg=1.2, Qg=0.155
% INFO    : Gen at bus 35422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35422	: Pg=0.4, Qg=0.97 -> Pg=1.2, Qg=0.155
% INFO    : Gen at bus 35422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35422	: Pg=0.4, Qg=0.97 -> Pg=1.2, Qg=0.155
% INFO    : Gen at bus 35422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35422	: Pg=0.4, Qg=0.97 -> Pg=1.2, Qg=0.155
% INFO    : Gen at bus 35422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35422	: Pg=0.4, Qg=0.97 -> Pg=1.2, Qg=0.155
% INFO    : Gen at bus 35422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35422	: Pg=0.4, Qg=0.97 -> Pg=1.2, Qg=0.155
% INFO    : Gen at bus 35422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35422	: Pg=0.4, Qg=0.97 -> Pg=1.2, Qg=0.155
% INFO    : Gen at bus 35422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35422	: Pg=0.4, Qg=0.97 -> Pg=1.2, Qg=0.155
% INFO    : Gen at bus 35422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35422	: Pg=0.4, Qg=0.97 -> Pg=1.2, Qg=0.155
% INFO    : Gen at bus 35422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35422	: Pg=0.4, Qg=0.97 -> Pg=1.2, Qg=0.155
% INFO    : Gen at bus 35422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35423	: Pg=2.0, Qg=0.65 -> Pg=1.25, Qg=0.0
% INFO    : Gen at bus 35423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35423	: Pg=2.0, Qg=0.65 -> Pg=1.25, Qg=0.0
% INFO    : Gen at bus 35423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35423	: Pg=2.0, Qg=0.65 -> Pg=1.25, Qg=0.0
% INFO    : Gen at bus 35423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35423	: Pg=2.0, Qg=0.65 -> Pg=1.25, Qg=0.0
% INFO    : Gen at bus 35423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35423	: Pg=2.0, Qg=0.65 -> Pg=1.25, Qg=0.0
% INFO    : Gen at bus 35423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35423	: Pg=2.0, Qg=0.65 -> Pg=1.25, Qg=0.0
% INFO    : Gen at bus 35423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35423	: Pg=2.0, Qg=0.65 -> Pg=1.25, Qg=0.0
% INFO    : Gen at bus 35423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35423	: Pg=2.0, Qg=0.65 -> Pg=1.25, Qg=0.0
% INFO    : Gen at bus 35423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35423	: Pg=2.0, Qg=0.65 -> Pg=1.25, Qg=0.0
% INFO    : Gen at bus 35423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35423	: Pg=2.0, Qg=0.65 -> Pg=1.25, Qg=0.0
% INFO    : Gen at bus 35423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 35423	: Pg=2.0, Qg=0.65 -> Pg=1.25, Qg=0.0
% INFO    : Gen at bus 35423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39875	: Pg=295.33, Qg=49.84 -> Pg=543.45, Qg=61.3
% INFO    : Gen at bus 39875	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39876	: Pg=267.43, Qg=141.6 -> Pg=472.95, Qg=52.5
% INFO    : Gen at bus 39876	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39877	: Pg=60.0, Qg=90.45 -> Pg=369.75, Qg=0.0
% INFO    : Gen at bus 39877	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39878	: Pg=2.4, Qg=-30.8 -> Pg=151.2, Qg=22.65
% INFO    : Gen at bus 39878	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39880	: Pg=10.0, Qg=-1.95 -> Pg=105.0, Qg=15.1
% INFO    : Gen at bus 39880	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39882	: Pg=124.77, Qg=36.63 -> Pg=155.2, Qg=27.25
% INFO    : Gen at bus 39882	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39882	: Pg=124.77, Qg=36.63 -> Pg=155.2, Qg=27.25
% INFO    : Gen at bus 39882	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39882	: Pg=59.9, Qg=36.63 -> Pg=125.25, Qg=28.0
% INFO    : Gen at bus 39882	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39883	: Pg=0.1, Qg=55.02 -> Pg=87.45, Qg=13.2
% INFO    : Gen at bus 39883	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39884	: Pg=99.34, Qg=-5.41 -> Pg=134.2, Qg=24.85
% INFO    : Gen at bus 39884	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39884	: Pg=99.34, Qg=-5.41 -> Pg=134.2, Qg=24.85
% INFO    : Gen at bus 39884	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39884	: Pg=69.41, Qg=-5.41 -> Pg=159.5, Qg=36.7
% INFO    : Gen at bus 39884	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39885	: Pg=0.1, Qg=44.98 -> Pg=76.55, Qg=0.0
% INFO    : Gen at bus 39885	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39886	: Pg=0.1, Qg=66.1 -> Pg=75.05, Qg=0.0
% INFO    : Gen at bus 39886	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39888	: Pg=7.5, Qg=26.31 -> Pg=78.75, Qg=0.0
% INFO    : Gen at bus 39888	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39889	: Pg=7.5, Qg=54.74 -> Pg=78.75, Qg=0.0
% INFO    : Gen at bus 39889	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39890	: Pg=68.68, Qg=70.8 -> Pg=106.0, Qg=21.05
% INFO    : Gen at bus 39890	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39890	: Pg=98.75, Qg=70.8 -> Pg=219.6, Qg=26.35
% INFO    : Gen at bus 39890	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39890	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39891	: Pg=33.41, Qg=84.3 -> Pg=83.0, Qg=19.5
% INFO    : Gen at bus 39891	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39892	: Pg=7.78, Qg=9.91 -> Pg=9.25, Qg=2.285
% INFO    : Gen at bus 39892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39892	: Pg=7.54, Qg=9.91 -> Pg=9.25, Qg=2.285
% INFO    : Gen at bus 39892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39892	: Pg=7.54, Qg=9.91 -> Pg=9.25, Qg=2.285
% INFO    : Gen at bus 39892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39892	: Pg=7.54, Qg=9.91 -> Pg=9.25, Qg=2.285
% INFO    : Gen at bus 39892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39892	: Pg=16.0, Qg=9.91 -> Pg=9.25, Qg=2.285
% INFO    : Gen at bus 39892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39892	: Pg=16.0, Qg=9.91 -> Pg=9.25, Qg=2.285
% INFO    : Gen at bus 39892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39892	: Pg=16.0, Qg=9.91 -> Pg=9.25, Qg=2.285
% INFO    : Gen at bus 39892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39892	: Pg=16.0, Qg=9.91 -> Pg=9.25, Qg=2.285
% INFO    : Gen at bus 39892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39894	: Pg=1.0, Qg=20.9 -> Pg=56.75, Qg=0.0
% INFO    : Gen at bus 39894	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39895	: Pg=2.5, Qg=19.8 -> Pg=26.25, Qg=0.0
% INFO    : Gen at bus 39895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39895	: Pg=5.0, Qg=44.1 -> Pg=52.5, Qg=0.0
% INFO    : Gen at bus 39895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39896	: Pg=1.0, Qg=14.61 -> Pg=50.5, Qg=0.0
% INFO    : Gen at bus 39896	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39897	: Pg=0.1, Qg=43.7 -> Pg=49.55, Qg=0.0
% INFO    : Gen at bus 39897	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39898	: Pg=0.0, Qg=32.03 -> Pg=49.5, Qg=7.45
% INFO    : Gen at bus 39898	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39899	: Pg=4.9, Qg=28.2 -> Pg=51.45, Qg=0.0
% INFO    : Gen at bus 39899	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39900	: Pg=9.87, Qg=16.48 -> Pg=18.72, Qg=3.77
% INFO    : Gen at bus 39900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39900	: Pg=9.87, Qg=16.48 -> Pg=18.72, Qg=3.77
% INFO    : Gen at bus 39900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39900	: Pg=9.87, Qg=16.48 -> Pg=18.72, Qg=3.77
% INFO    : Gen at bus 39900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39902	: Pg=12.94, Qg=-3.94 -> Pg=24.75, Qg=5.35
% INFO    : Gen at bus 39902	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39902	: Pg=47.04, Qg=-3.94 -> Pg=63.3, Qg=11.7
% INFO    : Gen at bus 39902	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39903	: Pg=1.0, Qg=10.73 -> Pg=40.6, Qg=0.0
% INFO    : Gen at bus 39903	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39904	: Pg=1.0, Qg=3.67 -> Pg=40.5, Qg=0.0
% INFO    : Gen at bus 39904	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39905	: Pg=0.0, Qg=6.16 -> Pg=40.0, Qg=0.0
% INFO    : Gen at bus 39905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39906	: Pg=85.31, Qg=48.32 -> Pg=146.0, Qg=16.0
% INFO    : Gen at bus 39906	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39906	: Pg=5.49, Qg=9.55 -> Pg=12.35, Qg=1.485
% INFO    : Gen at bus 39906	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39906	: Pg=5.49, Qg=9.55 -> Pg=12.35, Qg=1.485
% INFO    : Gen at bus 39906	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39906	: Pg=5.49, Qg=9.55 -> Pg=12.35, Qg=1.485
% INFO    : Gen at bus 39906	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39906	: Pg=5.49, Qg=9.55 -> Pg=12.35, Qg=1.485
% INFO    : Gen at bus 39906	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39908	: Pg=7.97, Qg=38.2 -> Pg=42.4, Qg=5.95
% INFO    : Gen at bus 39908	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39908	: Pg=7.97, Qg=38.2 -> Pg=42.4, Qg=5.95
% INFO    : Gen at bus 39908	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39909	: Pg=20.08, Qg=34.83 -> Pg=62.5, Qg=15.05
% INFO    : Gen at bus 39909	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39909	: Pg=0.06, Qg=34.83 -> Pg=37.5, Qg=10.75
% INFO    : Gen at bus 39909	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39910	: Pg=0.1, Qg=29.6 -> Pg=37.55, Qg=0.0
% INFO    : Gen at bus 39910	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39911	: Pg=2.95, Qg=11.15 -> Pg=10.25, Qg=2.575
% INFO    : Gen at bus 39911	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39911	: Pg=2.95, Qg=11.15 -> Pg=10.25, Qg=2.575
% INFO    : Gen at bus 39911	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39911	: Pg=2.95, Qg=11.15 -> Pg=10.25, Qg=2.575
% INFO    : Gen at bus 39911	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39911	: Pg=2.95, Qg=11.15 -> Pg=10.25, Qg=2.575
% INFO    : Gen at bus 39911	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39912	: Pg=7.78, Qg=34.5 -> Pg=38.6, Qg=5.4
% INFO    : Gen at bus 39912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39912	: Pg=8.23, Qg=40.31 -> Pg=47.5, Qg=6.7
% INFO    : Gen at bus 39912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39912	: Pg=8.6, Qg=40.31 -> Pg=54.95, Qg=7.85
% INFO    : Gen at bus 39912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39913	: Pg=3.3, Qg=16.21 -> Pg=34.65, Qg=0.0
% INFO    : Gen at bus 39913	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39914	: Pg=31.58, Qg=5.01 -> Pg=46.5, Qg=4.75
% INFO    : Gen at bus 39914	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39914	: Pg=31.58, Qg=5.01 -> Pg=46.5, Qg=4.75
% INFO    : Gen at bus 39914	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39914	: Pg=31.58, Qg=5.01 -> Pg=46.5, Qg=4.75
% INFO    : Gen at bus 39914	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39915	: Pg=31.52, Qg=0.46 -> Pg=45.25, Qg=8.65
% INFO    : Gen at bus 39915	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39915	: Pg=31.52, Qg=0.46 -> Pg=45.25, Qg=8.65
% INFO    : Gen at bus 39915	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39915	: Pg=31.52, Qg=0.46 -> Pg=45.25, Qg=8.65
% INFO    : Gen at bus 39915	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39917	: Pg=0.1, Qg=15.2 -> Pg=29.3, Qg=0.0
% INFO    : Gen at bus 39917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39917	: Pg=0.1, Qg=15.2 -> Pg=37.55, Qg=0.0
% INFO    : Gen at bus 39917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39917	: Pg=0.1, Qg=15.2 -> Pg=61.55, Qg=0.0
% INFO    : Gen at bus 39917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39919	: Pg=5.86, Qg=19.14 -> Pg=19.7, Qg=4.9
% INFO    : Gen at bus 39919	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39919	: Pg=16.0, Qg=19.14 -> Pg=27.5, Qg=5.75
% INFO    : Gen at bus 39919	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39919	: Pg=19.25, Qg=19.14 -> Pg=34.0, Qg=7.15
% INFO    : Gen at bus 39919	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39920	: Pg=26.23, Qg=30.4 -> Pg=37.0, Qg=7.05
% INFO    : Gen at bus 39920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39920	: Pg=42.04, Qg=46.99 -> Pg=60.8, Qg=11.7
% INFO    : Gen at bus 39920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39920	: Pg=388.1, Qg=46.99 -> Pg=643.75, Qg=69.65
% INFO    : Gen at bus 39920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39920	: Pg=368.18, Qg=46.99 -> Pg=537.9, Qg=54.8
% INFO    : Gen at bus 39920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39923	: Pg=0.0, Qg=5.76 -> Pg=21.75, Qg=0.0
% INFO    : Gen at bus 39923	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39924	: Pg=2.1, Qg=2.6 -> Pg=22.05, Qg=0.0
% INFO    : Gen at bus 39924	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39926	: Pg=14.06, Qg=3.34 -> Pg=25.31, Qg=5.35
% INFO    : Gen at bus 39926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39926	: Pg=103.77, Qg=3.34 -> Pg=185.7, Qg=20.7
% INFO    : Gen at bus 39926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39927	: Pg=14.06, Qg=5.01 -> Pg=25.31, Qg=5.1
% INFO    : Gen at bus 39927	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39927	: Pg=12.94, Qg=5.01 -> Pg=24.75, Qg=5.35
% INFO    : Gen at bus 39927	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39927	: Pg=26.04, Qg=5.01 -> Pg=52.8, Qg=11.7
% INFO    : Gen at bus 39927	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39930	: Pg=6.88, Qg=17.0 -> Pg=20.5, Qg=2.65
% INFO    : Gen at bus 39930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39931	: Pg=0.1, Qg=13.8 -> Pg=17.55, Qg=0.0
% INFO    : Gen at bus 39931	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39931	: Pg=0.1, Qg=44.84 -> Pg=92.55, Qg=13.95
% INFO    : Gen at bus 39931	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39932	: Pg=0.0, Qg=3.16 -> Pg=14.85, Qg=0.0
% INFO    : Gen at bus 39932	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39933	: Pg=8.0, Qg=23.2 -> Pg=22.75, Qg=5.35
% INFO    : Gen at bus 39933	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39933	: Pg=8.0, Qg=21.5 -> Pg=18.35, Qg=5.95
% INFO    : Gen at bus 39933	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39934	: Pg=1.05, Qg=0.41 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 39934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39934	: Pg=1.05, Qg=0.41 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 39934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39934	: Pg=1.05, Qg=0.41 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 39934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39934	: Pg=1.05, Qg=0.41 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 39934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39934	: Pg=1.05, Qg=0.41 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 39934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39934	: Pg=1.05, Qg=0.41 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 39934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39934	: Pg=1.05, Qg=0.41 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 39934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39934	: Pg=1.05, Qg=0.41 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 39934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39934	: Pg=1.05, Qg=0.41 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 39934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39934	: Pg=1.05, Qg=0.41 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 39934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39934	: Pg=1.05, Qg=0.41 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 39934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39934	: Pg=1.05, Qg=0.41 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 39934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39934	: Pg=1.05, Qg=0.41 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 39934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39934	: Pg=1.05, Qg=0.41 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 39934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39935	: Pg=0.0, Qg=8.14 -> Pg=14.0, Qg=0.0
% INFO    : Gen at bus 39935	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39935	: Pg=0.0, Qg=8.14 -> Pg=66.0, Qg=0.0
% INFO    : Gen at bus 39935	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39938	: Pg=11.63, Qg=15.5 -> Pg=18.0, Qg=3.6
% INFO    : Gen at bus 39938	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39938	: Pg=14.94, Qg=23.2 -> Pg=25.75, Qg=5.35
% INFO    : Gen at bus 39938	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39939	: Pg=0.1, Qg=1.5 -> Pg=1.05, Qg=0.415
% INFO    : Gen at bus 39939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39939	: Pg=0.1, Qg=1.5 -> Pg=1.05, Qg=0.415
% INFO    : Gen at bus 39939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39939	: Pg=0.1, Qg=1.5 -> Pg=1.05, Qg=0.415
% INFO    : Gen at bus 39939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39939	: Pg=0.1, Qg=1.5 -> Pg=1.05, Qg=0.415
% INFO    : Gen at bus 39939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39939	: Pg=0.1, Qg=1.5 -> Pg=1.05, Qg=0.415
% INFO    : Gen at bus 39939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39939	: Pg=0.1, Qg=1.5 -> Pg=1.05, Qg=0.415
% INFO    : Gen at bus 39939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39939	: Pg=0.1, Qg=1.5 -> Pg=1.05, Qg=0.415
% INFO    : Gen at bus 39939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39939	: Pg=0.1, Qg=1.5 -> Pg=1.05, Qg=0.415
% INFO    : Gen at bus 39939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39939	: Pg=0.1, Qg=1.5 -> Pg=1.05, Qg=0.415
% INFO    : Gen at bus 39939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39939	: Pg=0.1, Qg=1.5 -> Pg=1.05, Qg=0.415
% INFO    : Gen at bus 39939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39939	: Pg=0.1, Qg=1.5 -> Pg=1.05, Qg=0.415
% INFO    : Gen at bus 39939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39939	: Pg=0.1, Qg=1.5 -> Pg=1.05, Qg=0.415
% INFO    : Gen at bus 39939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39940	: Pg=10.6, Qg=14.7 -> Pg=16.9, Qg=3.4
% INFO    : Gen at bus 39940	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39941	: Pg=10.6, Qg=17.9 -> Pg=16.9, Qg=5.0
% INFO    : Gen at bus 39941	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39942	: Pg=10.6, Qg=10.7 -> Pg=16.9, Qg=3.4
% INFO    : Gen at bus 39942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39942	: Pg=10.6, Qg=10.7 -> Pg=16.9, Qg=3.4
% INFO    : Gen at bus 39942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39943	: Pg=48.73, Qg=61.54 -> Pg=96.9, Qg=21.3
% INFO    : Gen at bus 39943	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39943	: Pg=8.63, Qg=14.0 -> Pg=15.525, Qg=3.15
% INFO    : Gen at bus 39943	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39943	: Pg=10.45, Qg=31.0 -> Pg=29.6, Qg=7.15
% INFO    : Gen at bus 39943	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39944	: Pg=14.46, Qg=13.9 -> Pg=18.2, Qg=3.2
% INFO    : Gen at bus 39944	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39945	: Pg=0.1, Qg=8.9 -> Pg=11.3, Qg=0.0
% INFO    : Gen at bus 39945	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39945	: Pg=0.1, Qg=50.82 -> Pg=80.3, Qg=0.0
% INFO    : Gen at bus 39945	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39946	: Pg=1.93, Qg=0.75 -> Pg=2.75, Qg=0.0
% INFO    : Gen at bus 39946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39946	: Pg=1.93, Qg=0.75 -> Pg=2.75, Qg=0.0
% INFO    : Gen at bus 39946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39946	: Pg=1.93, Qg=0.75 -> Pg=2.75, Qg=0.0
% INFO    : Gen at bus 39946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39946	: Pg=1.93, Qg=0.75 -> Pg=2.75, Qg=0.0
% INFO    : Gen at bus 39946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39946	: Pg=1.93, Qg=0.75 -> Pg=2.75, Qg=0.0
% INFO    : Gen at bus 39946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39946	: Pg=1.93, Qg=0.75 -> Pg=2.75, Qg=0.0
% INFO    : Gen at bus 39946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39947	: Pg=5.53, Qg=13.2 -> Pg=13.15, Qg=3.05
% INFO    : Gen at bus 39947	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39948	: Pg=1.34, Qg=5.27 -> Pg=4.085, Qg=1.47
% INFO    : Gen at bus 39948	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39948	: Pg=1.34, Qg=5.27 -> Pg=4.085, Qg=1.47
% INFO    : Gen at bus 39948	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39948	: Pg=1.34, Qg=5.27 -> Pg=4.085, Qg=1.47
% INFO    : Gen at bus 39948	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39949	: Pg=1.0, Qg=5.21 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 39949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39951	: Pg=5.5, Qg=12.36 -> Pg=12.5, Qg=2.85
% INFO    : Gen at bus 39951	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39951	: Pg=5.5, Qg=12.36 -> Pg=12.5, Qg=2.85
% INFO    : Gen at bus 39951	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39952	: Pg=0.0, Qg=6.59 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 39952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39953	: Pg=658.1, Qg=593.2 -> Pg=941.5, Qg=92.45
% INFO    : Gen at bus 39953	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39953	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39954	: Pg=658.5, Qg=234.71 -> Pg=941.7, Qg=92.45
% INFO    : Gen at bus 39954	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39954	: Pg=648.1, Qg=234.71 -> Pg=936.5, Qg=92.45
% INFO    : Gen at bus 39954	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39955	: Pg=135.0, Qg=57.9 -> Pg=652.5, Qg=88.35
% INFO    : Gen at bus 39955	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39955	: Pg=1100.0, Qg=57.9 -> Pg=652.0, Qg=88.35
% INFO    : Gen at bus 39955	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39956	: Pg=1100.0, Qg=-26.25 -> Pg=718.2, Qg=85.95
% INFO    : Gen at bus 39956	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39957	: Pg=854.47, Qg=349.3 -> Pg=579.65, Qg=0.0
% INFO    : Gen at bus 39957	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39957	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39958	: Pg=132.0, Qg=2.77 -> Pg=570.65, Qg=0.0
% INFO    : Gen at bus 39958	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39958	: Pg=132.0, Qg=2.77 -> Pg=570.65, Qg=0.0
% INFO    : Gen at bus 39958	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39959	: Pg=347.36, Qg=106.83 -> Pg=608.9, Qg=67.4
% INFO    : Gen at bus 39959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39960	: Pg=136.53, Qg=319.7 -> Pg=390.0, Qg=49.85
% INFO    : Gen at bus 39960	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39960	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39961	: Pg=256.52, Qg=24.5 -> Pg=449.75, Qg=49.8
% INFO    : Gen at bus 39961	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39961	: Pg=256.52, Qg=24.5 -> Pg=449.75, Qg=49.8
% INFO    : Gen at bus 39961	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39962	: Pg=265.89, Qg=61.53 -> Pg=442.25, Qg=47.9
% INFO    : Gen at bus 39962	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39962	: Pg=265.89, Qg=61.53 -> Pg=442.25, Qg=47.9
% INFO    : Gen at bus 39962	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39962	: Pg=265.66, Qg=61.53 -> Pg=437.55, Qg=89.5
% INFO    : Gen at bus 39962	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39963	: Pg=315.46, Qg=55.74 -> Pg=458.7, Qg=46.6
% INFO    : Gen at bus 39963	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39963	: Pg=215.46, Qg=55.74 -> Pg=408.7, Qg=46.6
% INFO    : Gen at bus 39963	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39964	: Pg=107.22, Qg=20.64 -> Pg=291.5, Qg=36.8
% INFO    : Gen at bus 39964	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39964	: Pg=16.56, Qg=20.64 -> Pg=31.28, Qg=6.6
% INFO    : Gen at bus 39964	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39964	: Pg=16.56, Qg=20.64 -> Pg=31.28, Qg=6.6
% INFO    : Gen at bus 39964	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39964	: Pg=16.56, Qg=20.64 -> Pg=31.28, Qg=6.6
% INFO    : Gen at bus 39964	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39964	: Pg=16.56, Qg=20.64 -> Pg=31.28, Qg=6.6
% INFO    : Gen at bus 39964	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39964	: Pg=16.56, Qg=20.64 -> Pg=31.28, Qg=6.6
% INFO    : Gen at bus 39964	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39965	: Pg=256.04, Qg=46.75 -> Pg=343.0, Qg=63.15
% INFO    : Gen at bus 39965	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39966	: Pg=209.74, Qg=16.81 -> Pg=294.45, Qg=55.7
% INFO    : Gen at bus 39966	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39966	: Pg=325.44, Qg=16.81 -> Pg=463.25, Qg=46.55
% INFO    : Gen at bus 39966	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39967	: Pg=10.09, Qg=14.1 -> Pg=16.4, Qg=3.25
% INFO    : Gen at bus 39967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39967	: Pg=10.15, Qg=23.6 -> Pg=24.0, Qg=5.45
% INFO    : Gen at bus 39967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39967	: Pg=10.15, Qg=23.6 -> Pg=24.0, Qg=5.45
% INFO    : Gen at bus 39967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39967	: Pg=10.15, Qg=23.6 -> Pg=24.0, Qg=5.45
% INFO    : Gen at bus 39967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39967	: Pg=10.15, Qg=23.6 -> Pg=24.0, Qg=5.45
% INFO    : Gen at bus 39967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39967	: Pg=10.15, Qg=23.6 -> Pg=24.0, Qg=5.45
% INFO    : Gen at bus 39967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39967	: Pg=10.15, Qg=23.6 -> Pg=24.0, Qg=5.45
% INFO    : Gen at bus 39967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39967	: Pg=10.15, Qg=23.6 -> Pg=24.0, Qg=5.45
% INFO    : Gen at bus 39967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39967	: Pg=151.04, Qg=226.9 -> Pg=261.8, Qg=51.1
% INFO    : Gen at bus 39967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39970	: Pg=0.0, Qg=96.51 -> Pg=150.0, Qg=22.65
% INFO    : Gen at bus 39970	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39971	: Pg=94.25, Qg=138.2 -> Pg=166.315, Qg=29.2
% INFO    : Gen at bus 39971	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39971	: Pg=144.62, Qg=217.2 -> Pg=250.67, Qg=48.9
% INFO    : Gen at bus 39971	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39972	: Pg=123.59, Qg=2.18 -> Pg=170.6, Qg=16.85
% INFO    : Gen at bus 39972	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39972	: Pg=115.59, Qg=2.18 -> Pg=166.6, Qg=16.85
% INFO    : Gen at bus 39972	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39972	: Pg=44.03, Qg=2.18 -> Pg=61.45, Qg=9.4
% INFO    : Gen at bus 39972	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39972	: Pg=60.85, Qg=2.18 -> Pg=85.8, Qg=16.25
% INFO    : Gen at bus 39972	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39974	: Pg=134.5, Qg=12.99 -> Pg=162.6, Qg=27.4
% INFO    : Gen at bus 39974	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39974	: Pg=147.55, Qg=12.99 -> Pg=178.5, Qg=30.05
% INFO    : Gen at bus 39974	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39974	: Pg=147.55, Qg=12.99 -> Pg=178.5, Qg=30.05
% INFO    : Gen at bus 39974	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39975	: Pg=198.0, Qg=68.62 -> Pg=199.0, Qg=15.1
% INFO    : Gen at bus 39975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39976	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39976	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39976	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39977	: Pg=1.5, Qg=82.39 -> Pg=99.75, Qg=14.95
% INFO    : Gen at bus 39977	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39977	: Pg=1.5, Qg=82.39 -> Pg=99.75, Qg=14.95
% INFO    : Gen at bus 39977	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39978	: Pg=104.81, Qg=119.0 -> Pg=146.0, Qg=27.5
% INFO    : Gen at bus 39978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39978	: Pg=104.81, Qg=119.0 -> Pg=146.0, Qg=27.5
% INFO    : Gen at bus 39978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39978	: Pg=104.81, Qg=119.0 -> Pg=146.0, Qg=27.5
% INFO    : Gen at bus 39978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39979	: Pg=183.69, Qg=130.1 -> Pg=127.67, Qg=34.45
% INFO    : Gen at bus 39979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39979	: Pg=187.49, Qg=132.8 -> Pg=130.31, Qg=35.15
% INFO    : Gen at bus 39979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39979	: Pg=299.19, Qg=185.4 -> Pg=197.1, Qg=42.85
% INFO    : Gen at bus 39979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39979	: Pg=510.96, Qg=370.9 -> Pg=389.2, Qg=85.7
% INFO    : Gen at bus 39979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39980	: Pg=51.59, Qg=2.06 -> Pg=115.15, Qg=26.25
% INFO    : Gen at bus 39980	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39980	: Pg=51.59, Qg=2.06 -> Pg=115.15, Qg=26.25
% INFO    : Gen at bus 39980	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39980	: Pg=51.59, Qg=2.06 -> Pg=115.15, Qg=26.25
% INFO    : Gen at bus 39980	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39980	: Pg=51.59, Qg=2.06 -> Pg=115.15, Qg=26.25
% INFO    : Gen at bus 39980	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39980	: Pg=51.59, Qg=2.06 -> Pg=115.15, Qg=26.25
% INFO    : Gen at bus 39980	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39980	: Pg=51.59, Qg=2.06 -> Pg=115.15, Qg=26.25
% INFO    : Gen at bus 39980	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39981	: Pg=90.66, Qg=103.63 -> Pg=135.0, Qg=25.8
% INFO    : Gen at bus 39981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39981	: Pg=90.66, Qg=103.63 -> Pg=135.0, Qg=25.8
% INFO    : Gen at bus 39981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39981	: Pg=90.66, Qg=103.63 -> Pg=135.0, Qg=25.8
% INFO    : Gen at bus 39981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39981	: Pg=90.66, Qg=103.63 -> Pg=135.0, Qg=25.8
% INFO    : Gen at bus 39981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39981	: Pg=65.49, Qg=83.0 -> Pg=99.5, Qg=19.15
% INFO    : Gen at bus 39981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39981	: Pg=65.49, Qg=83.0 -> Pg=99.5, Qg=19.15
% INFO    : Gen at bus 39981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39981	: Pg=65.49, Qg=83.0 -> Pg=99.5, Qg=19.15
% INFO    : Gen at bus 39981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39981	: Pg=65.49, Qg=83.0 -> Pg=99.5, Qg=19.15
% INFO    : Gen at bus 39981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39982	: Pg=104.47, Qg=35.81 -> Pg=139.25, Qg=25.55
% INFO    : Gen at bus 39982	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39982	: Pg=104.47, Qg=35.81 -> Pg=139.25, Qg=25.55
% INFO    : Gen at bus 39982	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39982	: Pg=58.64, Qg=35.81 -> Pg=197.55, Qg=49.45
% INFO    : Gen at bus 39982	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39983	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39984	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39984	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39985	: Pg=125.6, Qg=0.0 -> Pg=140.7, Qg=0.0
% INFO    : Gen at bus 39985	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39985	: Pg=125.6, Qg=0.0 -> Pg=140.7, Qg=0.0
% INFO    : Gen at bus 39985	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39986	: Pg=150.0, Qg=19.56 -> Pg=150.0, Qg=0.0
% INFO    : Gen at bus 39986	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39987	: Pg=78.47, Qg=67.1 -> Pg=106.8, Qg=10.45
% INFO    : Gen at bus 39987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39988	: Pg=73.41, Qg=55.63 -> Pg=103.0, Qg=19.5
% INFO    : Gen at bus 39988	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39988	: Pg=147.03, Qg=55.63 -> Pg=210.25, Qg=40.15
% INFO    : Gen at bus 39988	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39988	: Pg=184.11, Qg=55.63 -> Pg=269.4, Qg=52.1
% INFO    : Gen at bus 39988	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39989	: Pg=92.38, Qg=43.51 -> Pg=112.0, Qg=10.2
% INFO    : Gen at bus 39989	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39989	: Pg=92.38, Qg=43.51 -> Pg=112.0, Qg=10.2
% INFO    : Gen at bus 39989	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39990	: Pg=69.38, Qg=48.13 -> Pg=100.5, Qg=10.2
% INFO    : Gen at bus 39990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39990	: Pg=69.38, Qg=48.13 -> Pg=100.5, Qg=10.2
% INFO    : Gen at bus 39990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39992	: Pg=52.86, Qg=11.94 -> Pg=82.0, Qg=16.35
% INFO    : Gen at bus 39992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39992	: Pg=41.86, Qg=11.94 -> Pg=76.5, Qg=16.35
% INFO    : Gen at bus 39992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39992	: Pg=41.86, Qg=11.94 -> Pg=76.5, Qg=16.35
% INFO    : Gen at bus 39992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39992	: Pg=41.86, Qg=11.94 -> Pg=76.5, Qg=16.35
% INFO    : Gen at bus 39992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39993	: Pg=49.86, Qg=20.9 -> Pg=80.5, Qg=16.35
% INFO    : Gen at bus 39993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39993	: Pg=49.86, Qg=20.9 -> Pg=80.5, Qg=16.35
% INFO    : Gen at bus 39993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39993	: Pg=49.86, Qg=20.9 -> Pg=80.5, Qg=16.35
% INFO    : Gen at bus 39993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39993	: Pg=49.86, Qg=20.9 -> Pg=80.5, Qg=16.35
% INFO    : Gen at bus 39993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39993	: Pg=49.86, Qg=20.9 -> Pg=80.5, Qg=16.35
% INFO    : Gen at bus 39993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39993	: Pg=49.86, Qg=20.9 -> Pg=80.5, Qg=16.35
% INFO    : Gen at bus 39993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39994	: Pg=37.82, Qg=40.64 -> Pg=73.75, Qg=16.1
% INFO    : Gen at bus 39994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39994	: Pg=15.5, Qg=28.7 -> Pg=32.125, Qg=6.0
% INFO    : Gen at bus 39994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39994	: Pg=15.5, Qg=28.7 -> Pg=32.125, Qg=6.0
% INFO    : Gen at bus 39994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39994	: Pg=15.5, Qg=28.7 -> Pg=32.125, Qg=6.0
% INFO    : Gen at bus 39994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39994	: Pg=124.71, Qg=40.64 -> Pg=251.3, Qg=55.5
% INFO    : Gen at bus 39994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39995	: Pg=102.0, Qg=28.73 -> Pg=102.0, Qg=0.0
% INFO    : Gen at bus 39995	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39996	: Pg=45.08, Qg=25.03 -> Pg=73.4, Qg=14.6
% INFO    : Gen at bus 39996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39996	: Pg=45.08, Qg=25.03 -> Pg=73.4, Qg=14.6
% INFO    : Gen at bus 39996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39996	: Pg=45.08, Qg=25.03 -> Pg=73.4, Qg=14.6
% INFO    : Gen at bus 39996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39996	: Pg=45.08, Qg=25.03 -> Pg=73.4, Qg=14.6
% INFO    : Gen at bus 39996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39996	: Pg=45.08, Qg=25.03 -> Pg=73.4, Qg=14.6
% INFO    : Gen at bus 39996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39996	: Pg=45.08, Qg=25.03 -> Pg=73.4, Qg=14.6
% INFO    : Gen at bus 39996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39996	: Pg=45.08, Qg=25.03 -> Pg=73.4, Qg=14.6
% INFO    : Gen at bus 39996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39996	: Pg=45.08, Qg=25.03 -> Pg=73.4, Qg=14.6
% INFO    : Gen at bus 39996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39997	: Pg=0.0, Qg=44.3 -> Pg=50.25, Qg=0.0
% INFO    : Gen at bus 39997	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39998	: Pg=1.5, Qg=44.3 -> Pg=51.0, Qg=0.0
% INFO    : Gen at bus 39998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39999	: Pg=95.19, Qg=21.55 -> Pg=148.65, Qg=15.65
% INFO    : Gen at bus 39999	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39999	: Pg=50.26, Qg=21.55 -> Pg=69.1, Qg=0.0
% INFO    : Gen at bus 39999	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39999	: Pg=50.26, Qg=21.55 -> Pg=69.1, Qg=6.8
% INFO    : Gen at bus 39999	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 39999	: Pg=80.76, Qg=21.55 -> Pg=152.55, Qg=32.95
% INFO    : Gen at bus 39999	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40000	: Pg=47.23, Qg=55.2 -> Pg=67.0, Qg=12.75
% INFO    : Gen at bus 40000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40000	: Pg=47.23, Qg=55.2 -> Pg=67.0, Qg=12.75
% INFO    : Gen at bus 40000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40000	: Pg=47.23, Qg=55.2 -> Pg=67.0, Qg=12.75
% INFO    : Gen at bus 40000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40000	: Pg=47.23, Qg=55.2 -> Pg=67.0, Qg=12.75
% INFO    : Gen at bus 40000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40001	: Pg=47.17, Qg=53.6 -> Pg=65.75, Qg=12.4
% INFO    : Gen at bus 40001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40001	: Pg=47.17, Qg=53.6 -> Pg=65.75, Qg=12.4
% INFO    : Gen at bus 40001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40001	: Pg=47.17, Qg=53.6 -> Pg=65.75, Qg=12.4
% INFO    : Gen at bus 40001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40001	: Pg=47.17, Qg=53.6 -> Pg=65.75, Qg=12.4
% INFO    : Gen at bus 40001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40001	: Pg=47.17, Qg=53.6 -> Pg=65.75, Qg=12.4
% INFO    : Gen at bus 40001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40001	: Pg=47.17, Qg=53.6 -> Pg=65.75, Qg=12.4
% INFO    : Gen at bus 40001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40001	: Pg=47.17, Qg=53.6 -> Pg=65.75, Qg=12.4
% INFO    : Gen at bus 40001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40001	: Pg=47.17, Qg=53.6 -> Pg=65.75, Qg=12.4
% INFO    : Gen at bus 40001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40002	: Pg=0.0, Qg=31.6 -> Pg=40.0, Qg=0.0
% INFO    : Gen at bus 40002	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40003	: Pg=3.95, Qg=25.6 -> Pg=40.0, Qg=0.0
% INFO    : Gen at bus 40003	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40004	: Pg=26.88, Qg=17.25 -> Pg=50.0, Qg=15.65
% INFO    : Gen at bus 40004	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40004	: Pg=85.79, Qg=17.25 -> Pg=155.65, Qg=33.1
% INFO    : Gen at bus 40004	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40005	: Pg=27.57, Qg=37.52 -> Pg=49.615, Qg=10.05
% INFO    : Gen at bus 40005	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40005	: Pg=40.8, Qg=37.52 -> Pg=73.44, Qg=14.85
% INFO    : Gen at bus 40005	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40006	: Pg=2.95, Qg=11.15 -> Pg=10.25, Qg=2.575
% INFO    : Gen at bus 40006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40006	: Pg=2.95, Qg=11.15 -> Pg=10.25, Qg=2.575
% INFO    : Gen at bus 40006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40006	: Pg=2.95, Qg=11.15 -> Pg=10.25, Qg=2.575
% INFO    : Gen at bus 40006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40006	: Pg=2.95, Qg=11.15 -> Pg=10.25, Qg=2.575
% INFO    : Gen at bus 40006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40007	: Pg=0.0, Qg=16.3 -> Pg=36.0, Qg=0.0
% INFO    : Gen at bus 40007	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40008	: Pg=21.78, Qg=34.4 -> Pg=45.5, Qg=5.35
% INFO    : Gen at bus 40008	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40010	: Pg=9.19, Qg=9.93 -> Pg=13.125, Qg=2.055
% INFO    : Gen at bus 40010	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40010	: Pg=9.19, Qg=9.93 -> Pg=13.125, Qg=2.055
% INFO    : Gen at bus 40010	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40010	: Pg=9.19, Qg=9.93 -> Pg=13.125, Qg=2.055
% INFO    : Gen at bus 40010	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40010	: Pg=9.19, Qg=9.93 -> Pg=13.125, Qg=2.055
% INFO    : Gen at bus 40010	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40012	: Pg=6.53, Qg=37.8 -> Pg=33.0, Qg=8.75
% INFO    : Gen at bus 40012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40012	: Pg=16.5, Qg=20.1 -> Pg=26.53, Qg=3.8
% INFO    : Gen at bus 40012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40012	: Pg=70.13, Qg=60.5 -> Pg=96.0, Qg=9.4
% INFO    : Gen at bus 40012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40012	: Pg=124.01, Qg=123.9 -> Pg=159.5, Qg=28.6
% INFO    : Gen at bus 40012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40012	: Pg=124.01, Qg=123.9 -> Pg=159.5, Qg=28.6
% INFO    : Gen at bus 40012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40013	: Pg=33.5, Qg=21.37 -> Pg=46.0, Qg=8.6
% INFO    : Gen at bus 40013	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40013	: Pg=33.5, Qg=21.37 -> Pg=46.0, Qg=8.6
% INFO    : Gen at bus 40013	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40013	: Pg=33.52, Qg=21.37 -> Pg=46.25, Qg=8.65
% INFO    : Gen at bus 40013	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40013	: Pg=33.52, Qg=21.37 -> Pg=46.25, Qg=8.65
% INFO    : Gen at bus 40013	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40013	: Pg=33.52, Qg=21.37 -> Pg=46.25, Qg=8.65
% INFO    : Gen at bus 40013	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40013	: Pg=33.52, Qg=21.37 -> Pg=46.25, Qg=8.65
% INFO    : Gen at bus 40013	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40013	: Pg=33.52, Qg=21.37 -> Pg=46.25, Qg=8.65
% INFO    : Gen at bus 40013	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40013	: Pg=33.52, Qg=21.37 -> Pg=46.25, Qg=8.65
% INFO    : Gen at bus 40013	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40014	: Pg=13.98, Qg=36.5 -> Pg=35.7, Qg=8.45
% INFO    : Gen at bus 40014	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40014	: Pg=13.98, Qg=36.5 -> Pg=35.7, Qg=8.45
% INFO    : Gen at bus 40014	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40014	: Pg=13.98, Qg=36.5 -> Pg=35.7, Qg=8.45
% INFO    : Gen at bus 40014	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40014	: Pg=13.98, Qg=36.5 -> Pg=35.7, Qg=8.45
% INFO    : Gen at bus 40014	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40014	: Pg=13.98, Qg=36.5 -> Pg=35.7, Qg=8.45
% INFO    : Gen at bus 40014	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40014	: Pg=13.98, Qg=36.5 -> Pg=35.7, Qg=8.45
% INFO    : Gen at bus 40014	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40016	: Pg=0.0, Qg=20.9 -> Pg=26.5, Qg=0.0
% INFO    : Gen at bus 40016	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40017	: Pg=21.27, Qg=31.5 -> Pg=35.45, Qg=7.25
% INFO    : Gen at bus 40017	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40017	: Pg=21.27, Qg=31.5 -> Pg=35.45, Qg=7.25
% INFO    : Gen at bus 40017	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40017	: Pg=21.27, Qg=31.5 -> Pg=35.45, Qg=7.25
% INFO    : Gen at bus 40017	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40017	: Pg=21.27, Qg=31.5 -> Pg=35.45, Qg=7.25
% INFO    : Gen at bus 40017	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40017	: Pg=21.27, Qg=31.5 -> Pg=35.45, Qg=7.25
% INFO    : Gen at bus 40017	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40017	: Pg=21.27, Qg=31.5 -> Pg=35.45, Qg=7.25
% INFO    : Gen at bus 40017	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40017	: Pg=21.27, Qg=31.5 -> Pg=35.45, Qg=7.25
% INFO    : Gen at bus 40017	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40017	: Pg=21.27, Qg=31.5 -> Pg=35.45, Qg=7.25
% INFO    : Gen at bus 40017	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40018	: Pg=0.0, Qg=19.9 -> Pg=25.2, Qg=0.0
% INFO    : Gen at bus 40018	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40021	: Pg=19.18, Qg=29.1 -> Pg=32.5, Qg=6.7
% INFO    : Gen at bus 40021	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40021	: Pg=19.18, Qg=29.1 -> Pg=32.5, Qg=6.7
% INFO    : Gen at bus 40021	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40021	: Pg=19.18, Qg=29.1 -> Pg=32.5, Qg=6.7
% INFO    : Gen at bus 40021	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40021	: Pg=19.18, Qg=29.1 -> Pg=32.5, Qg=6.7
% INFO    : Gen at bus 40021	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40022	: Pg=30.13, Qg=9.36 -> Pg=37.0, Qg=6.45
% INFO    : Gen at bus 40022	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40022	: Pg=30.13, Qg=9.36 -> Pg=37.0, Qg=6.45
% INFO    : Gen at bus 40022	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40022	: Pg=30.13, Qg=9.36 -> Pg=37.0, Qg=6.45
% INFO    : Gen at bus 40022	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40022	: Pg=30.13, Qg=9.36 -> Pg=37.0, Qg=6.45
% INFO    : Gen at bus 40022	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40022	: Pg=31.25, Qg=9.36 -> Pg=40.0, Qg=10.4
% INFO    : Gen at bus 40022	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40022	: Pg=31.25, Qg=9.36 -> Pg=40.0, Qg=10.4
% INFO    : Gen at bus 40022	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40022	: Pg=31.25, Qg=9.36 -> Pg=40.0, Qg=10.4
% INFO    : Gen at bus 40022	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40022	: Pg=31.25, Qg=9.36 -> Pg=40.0, Qg=10.4
% INFO    : Gen at bus 40022	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40023	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40023	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40023	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40023	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40026	: Pg=1.06, Qg=3.55 -> Pg=2.84, Qg=0.985
% INFO    : Gen at bus 40026	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40026	: Pg=1.06, Qg=3.55 -> Pg=2.84, Qg=0.985
% INFO    : Gen at bus 40026	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40026	: Pg=1.06, Qg=3.55 -> Pg=2.84, Qg=0.985
% INFO    : Gen at bus 40026	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40026	: Pg=1.06, Qg=3.55 -> Pg=2.84, Qg=0.985
% INFO    : Gen at bus 40026	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40026	: Pg=1.06, Qg=3.55 -> Pg=2.84, Qg=0.985
% INFO    : Gen at bus 40026	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40026	: Pg=1.06, Qg=3.55 -> Pg=2.84, Qg=0.985
% INFO    : Gen at bus 40026	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40026	: Pg=1.06, Qg=3.55 -> Pg=2.84, Qg=0.985
% INFO    : Gen at bus 40026	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40026	: Pg=1.06, Qg=3.55 -> Pg=2.84, Qg=0.985
% INFO    : Gen at bus 40026	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40028	: Pg=34.63, Qg=12.89 -> Pg=68.5, Qg=15.05
% INFO    : Gen at bus 40028	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40028	: Pg=1.88, Qg=12.89 -> Pg=37.5, Qg=10.75
% INFO    : Gen at bus 40028	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40028	: Pg=0.78, Qg=12.89 -> Pg=15.5, Qg=6.5
% INFO    : Gen at bus 40028	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40028	: Pg=0.78, Qg=12.89 -> Pg=15.5, Qg=6.5
% INFO    : Gen at bus 40028	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40028	: Pg=0.78, Qg=12.89 -> Pg=15.5, Qg=6.5
% INFO    : Gen at bus 40028	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40028	: Pg=0.78, Qg=12.89 -> Pg=15.5, Qg=6.5
% INFO    : Gen at bus 40028	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40028	: Pg=0.78, Qg=12.89 -> Pg=15.5, Qg=6.5
% INFO    : Gen at bus 40028	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40029	: Pg=0.23, Qg=1.25 -> Pg=1.11, Qg=0.29
% INFO    : Gen at bus 40029	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40029	: Pg=0.23, Qg=1.25 -> Pg=1.11, Qg=0.29
% INFO    : Gen at bus 40029	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40029	: Pg=0.23, Qg=1.25 -> Pg=1.11, Qg=0.29
% INFO    : Gen at bus 40029	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40029	: Pg=0.23, Qg=1.25 -> Pg=1.11, Qg=0.29
% INFO    : Gen at bus 40029	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40029	: Pg=0.23, Qg=1.25 -> Pg=1.11, Qg=0.29
% INFO    : Gen at bus 40029	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40029	: Pg=0.23, Qg=1.25 -> Pg=1.11, Qg=0.29
% INFO    : Gen at bus 40029	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40029	: Pg=0.23, Qg=1.25 -> Pg=1.11, Qg=0.29
% INFO    : Gen at bus 40029	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40029	: Pg=0.23, Qg=1.25 -> Pg=1.11, Qg=0.29
% INFO    : Gen at bus 40029	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40029	: Pg=0.23, Qg=1.25 -> Pg=1.11, Qg=0.29
% INFO    : Gen at bus 40029	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40029	: Pg=0.23, Qg=1.25 -> Pg=1.11, Qg=0.29
% INFO    : Gen at bus 40029	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40029	: Pg=0.23, Qg=1.25 -> Pg=1.11, Qg=0.29
% INFO    : Gen at bus 40029	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40029	: Pg=0.23, Qg=1.25 -> Pg=1.11, Qg=0.29
% INFO    : Gen at bus 40029	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40029	: Pg=0.23, Qg=1.25 -> Pg=1.11, Qg=0.29
% INFO    : Gen at bus 40029	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40029	: Pg=0.23, Qg=1.25 -> Pg=1.11, Qg=0.29
% INFO    : Gen at bus 40029	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40029	: Pg=0.23, Qg=1.25 -> Pg=1.11, Qg=0.29
% INFO    : Gen at bus 40029	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40030	: Pg=1.23, Qg=2.04 -> Pg=2.215, Qg=0.475
% INFO    : Gen at bus 40030	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40030	: Pg=1.23, Qg=2.04 -> Pg=2.215, Qg=0.475
% INFO    : Gen at bus 40030	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40030	: Pg=1.23, Qg=2.04 -> Pg=2.215, Qg=0.475
% INFO    : Gen at bus 40030	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40030	: Pg=1.23, Qg=2.04 -> Pg=2.215, Qg=0.475
% INFO    : Gen at bus 40030	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40030	: Pg=1.23, Qg=2.04 -> Pg=2.215, Qg=0.475
% INFO    : Gen at bus 40030	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40030	: Pg=1.23, Qg=2.04 -> Pg=2.215, Qg=0.475
% INFO    : Gen at bus 40030	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40030	: Pg=1.23, Qg=2.04 -> Pg=2.215, Qg=0.475
% INFO    : Gen at bus 40030	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40030	: Pg=1.23, Qg=2.04 -> Pg=2.215, Qg=0.475
% INFO    : Gen at bus 40030	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40030	: Pg=1.23, Qg=2.04 -> Pg=2.215, Qg=0.475
% INFO    : Gen at bus 40030	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40031	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40031	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40031	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40031	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40031	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40032	: Pg=2.5, Qg=7.07 -> Pg=5.95, Qg=1.97
% INFO    : Gen at bus 40032	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40032	: Pg=2.5, Qg=7.07 -> Pg=5.95, Qg=1.97
% INFO    : Gen at bus 40032	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40032	: Pg=2.5, Qg=7.07 -> Pg=5.95, Qg=1.97
% INFO    : Gen at bus 40032	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40034	: Pg=7.33, Qg=8.05 -> Pg=10.0, Qg=1.85
% INFO    : Gen at bus 40034	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40034	: Pg=1.78, Qg=4.46 -> Pg=4.085, Qg=1.135
% INFO    : Gen at bus 40034	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40034	: Pg=1.78, Qg=4.46 -> Pg=4.085, Qg=1.135
% INFO    : Gen at bus 40034	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40034	: Pg=7.33, Qg=8.05 -> Pg=10.0, Qg=1.85
% INFO    : Gen at bus 40034	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40034	: Pg=1.78, Qg=4.46 -> Pg=4.085, Qg=1.135
% INFO    : Gen at bus 40034	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40034	: Pg=1.78, Qg=4.46 -> Pg=4.085, Qg=1.135
% INFO    : Gen at bus 40034	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40034	: Pg=1.78, Qg=4.46 -> Pg=4.085, Qg=1.135
% INFO    : Gen at bus 40034	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40034	: Pg=1.78, Qg=4.46 -> Pg=4.085, Qg=1.135
% INFO    : Gen at bus 40034	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40034	: Pg=1.78, Qg=4.46 -> Pg=4.085, Qg=1.135
% INFO    : Gen at bus 40034	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40034	: Pg=1.78, Qg=4.46 -> Pg=4.085, Qg=1.135
% INFO    : Gen at bus 40034	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40034	: Pg=1.78, Qg=4.46 -> Pg=4.085, Qg=1.135
% INFO    : Gen at bus 40034	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40035	: Pg=1.49, Qg=2.64 -> Pg=2.455, Qg=0.735
% INFO    : Gen at bus 40035	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40035	: Pg=1.49, Qg=2.64 -> Pg=2.455, Qg=0.735
% INFO    : Gen at bus 40035	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40035	: Pg=1.49, Qg=2.64 -> Pg=2.455, Qg=0.735
% INFO    : Gen at bus 40035	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40035	: Pg=1.49, Qg=2.64 -> Pg=2.455, Qg=0.735
% INFO    : Gen at bus 40035	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40035	: Pg=1.49, Qg=2.64 -> Pg=2.455, Qg=0.735
% INFO    : Gen at bus 40035	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40035	: Pg=1.49, Qg=2.64 -> Pg=2.455, Qg=0.735
% INFO    : Gen at bus 40035	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40035	: Pg=1.49, Qg=2.64 -> Pg=2.455, Qg=0.735
% INFO    : Gen at bus 40035	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40036	: Pg=10.83, Qg=13.3 -> Pg=17.015, Qg=2.7
% INFO    : Gen at bus 40036	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40036	: Pg=10.83, Qg=13.3 -> Pg=17.015, Qg=2.7
% INFO    : Gen at bus 40036	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40036	: Pg=10.83, Qg=13.3 -> Pg=17.015, Qg=2.7
% INFO    : Gen at bus 40036	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40036	: Pg=10.83, Qg=13.3 -> Pg=17.015, Qg=2.7
% INFO    : Gen at bus 40036	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40038	: Pg=8.25, Qg=13.3 -> Pg=14.85, Qg=3.0
% INFO    : Gen at bus 40038	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40038	: Pg=2.6, Qg=11.6 -> Pg=13.0, Qg=1.8
% INFO    : Gen at bus 40038	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40040	: Pg=12.5, Qg=9.7 -> Pg=16.0, Qg=1.5
% INFO    : Gen at bus 40040	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40040	: Pg=12.5, Qg=9.7 -> Pg=16.0, Qg=1.5
% INFO    : Gen at bus 40040	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40040	: Pg=12.63, Qg=12.1 -> Pg=18.5, Qg=1.9
% INFO    : Gen at bus 40040	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40040	: Pg=6.75, Qg=14.5 -> Pg=18.0, Qg=2.25
% INFO    : Gen at bus 40040	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40040	: Pg=6.75, Qg=14.5 -> Pg=18.0, Qg=2.25
% INFO    : Gen at bus 40040	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40041	: Pg=423.51, Qg=106.83 -> Pg=669.35, Qg=70.85
% INFO    : Gen at bus 40041	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40041	: Pg=279.17, Qg=106.83 -> Pg=512.65, Qg=0.0
% INFO    : Gen at bus 40041	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40041	: Pg=279.17, Qg=106.83 -> Pg=512.65, Qg=0.0
% INFO    : Gen at bus 40041	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40042	: Pg=364.99, Qg=225.14 -> Pg=474.2, Qg=85.7
% INFO    : Gen at bus 40042	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40043	: Pg=590.0, Qg=142.26 -> Pg=546.55, Qg=44.8
% INFO    : Gen at bus 40043	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40043	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40044	: Pg=115.32, Qg=52.72 -> Pg=161.25, Qg=30.45
% INFO    : Gen at bus 40044	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40044	: Pg=73.06, Qg=52.72 -> Pg=96.0, Qg=17.45
% INFO    : Gen at bus 40044	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40045	: Pg=104.01, Qg=50.67 -> Pg=208.0, Qg=24.15
% INFO    : Gen at bus 40045	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40045	: Pg=125.26, Qg=50.67 -> Pg=165.0, Qg=30.05
% INFO    : Gen at bus 40045	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40046	: Pg=200.0, Qg=-32.34 -> Pg=102.75, Qg=15.5
% INFO    : Gen at bus 40046	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40047	: Pg=90.16, Qg=53.52 -> Pg=147.0, Qg=29.2
% INFO    : Gen at bus 40047	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40047	: Pg=90.16, Qg=53.52 -> Pg=147.0, Qg=29.2
% INFO    : Gen at bus 40047	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40048	: Pg=1.0, Qg=38.31 -> Pg=101.0, Qg=15.15
% INFO    : Gen at bus 40048	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40049	: Pg=168.26, Qg=154.9 -> Pg=206.0, Qg=35.8
% INFO    : Gen at bus 40049	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40049	: Pg=92.93, Qg=122.1 -> Pg=142.5, Qg=28.2
% INFO    : Gen at bus 40049	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40049	: Pg=92.93, Qg=122.1 -> Pg=142.5, Qg=28.2
% INFO    : Gen at bus 40049	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40050	: Pg=62.43, Qg=73.9 -> Pg=97.95, Qg=14.15
% INFO    : Gen at bus 40050	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40050	: Pg=105.71, Qg=116.4 -> Pg=144.45, Qg=26.9
% INFO    : Gen at bus 40050	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40052	: Pg=0.0, Qg=20.17 -> Pg=74.4, Qg=0.0
% INFO    : Gen at bus 40052	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40053	: Pg=68.33, Qg=-10.7 -> Pg=98.9, Qg=10.0
% INFO    : Gen at bus 40053	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40053	: Pg=40.13, Qg=-10.7 -> Pg=103.75, Qg=24.0
% INFO    : Gen at bus 40053	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40053	: Pg=40.13, Qg=-10.7 -> Pg=103.75, Qg=24.0
% INFO    : Gen at bus 40053	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40055	: Pg=12.67, Qg=2.55 -> Pg=20.375, Qg=2.95
% INFO    : Gen at bus 40055	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40055	: Pg=11.13, Qg=2.55 -> Pg=22.56, Qg=4.2
% INFO    : Gen at bus 40055	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40055	: Pg=11.13, Qg=2.55 -> Pg=22.56, Qg=4.2
% INFO    : Gen at bus 40055	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40055	: Pg=11.13, Qg=2.55 -> Pg=22.56, Qg=4.2
% INFO    : Gen at bus 40055	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40055	: Pg=26.04, Qg=2.55 -> Pg=52.8, Qg=11.7
% INFO    : Gen at bus 40055	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40056	: Pg=5.2, Qg=30.09 -> Pg=54.35, Qg=0.0
% INFO    : Gen at bus 40056	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40057	: Pg=0.0, Qg=10.48 -> Pg=50.25, Qg=0.0
% INFO    : Gen at bus 40057	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40059	: Pg=1.0, Qg=9.7 -> Pg=50.75, Qg=13.05
% INFO    : Gen at bus 40059	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40060	: Pg=8.12, Qg=8.12 -> Pg=16.125, Qg=0.0
% INFO    : Gen at bus 40060	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40060	: Pg=8.12, Qg=8.12 -> Pg=16.125, Qg=0.0
% INFO    : Gen at bus 40060	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40060	: Pg=8.12, Qg=8.12 -> Pg=16.125, Qg=0.0
% INFO    : Gen at bus 40060	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40060	: Pg=8.12, Qg=8.12 -> Pg=16.125, Qg=0.0
% INFO    : Gen at bus 40060	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40060	: Pg=16.35, Qg=17.7 -> Pg=34.5, Qg=0.0
% INFO    : Gen at bus 40060	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40060	: Pg=5.63, Qg=8.2 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 40060	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40061	: Pg=0.0, Qg=11.0 -> Pg=49.5, Qg=0.0
% INFO    : Gen at bus 40061	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40062	: Pg=4.9, Qg=6.47 -> Pg=51.9, Qg=0.0
% INFO    : Gen at bus 40062	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40063	: Pg=47.24, Qg=-3.11 -> Pg=67.15, Qg=12.75
% INFO    : Gen at bus 40063	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40063	: Pg=47.24, Qg=-3.11 -> Pg=67.15, Qg=12.75
% INFO    : Gen at bus 40063	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40063	: Pg=47.24, Qg=-3.11 -> Pg=67.15, Qg=12.75
% INFO    : Gen at bus 40063	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40063	: Pg=47.24, Qg=-3.11 -> Pg=67.15, Qg=12.75
% INFO    : Gen at bus 40063	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40063	: Pg=47.24, Qg=-3.11 -> Pg=67.15, Qg=12.75
% INFO    : Gen at bus 40063	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40063	: Pg=47.24, Qg=-3.11 -> Pg=67.15, Qg=12.75
% INFO    : Gen at bus 40063	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40065	: Pg=37.1, Qg=-8.4 -> Pg=59.5, Qg=6.35
% INFO    : Gen at bus 40065	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40065	: Pg=34.1, Qg=-8.4 -> Pg=58.0, Qg=6.35
% INFO    : Gen at bus 40065	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40065	: Pg=34.1, Qg=-8.4 -> Pg=58.0, Qg=6.35
% INFO    : Gen at bus 40065	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40066	: Pg=31.88, Qg=3.18 -> Pg=52.5, Qg=10.75
% INFO    : Gen at bus 40066	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40066	: Pg=31.88, Qg=3.18 -> Pg=52.5, Qg=10.75
% INFO    : Gen at bus 40066	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40066	: Pg=209.13, Qg=3.18 -> Pg=282.25, Qg=27.5
% INFO    : Gen at bus 40066	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40066	: Pg=303.97, Qg=3.18 -> Pg=424.0, Qg=42.15
% INFO    : Gen at bus 40066	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40067	: Pg=0.8, Qg=9.08 -> Pg=6.3, Qg=2.525
% INFO    : Gen at bus 40067	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40067	: Pg=0.8, Qg=9.08 -> Pg=6.3, Qg=2.525
% INFO    : Gen at bus 40067	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40067	: Pg=0.8, Qg=9.08 -> Pg=6.3, Qg=2.525
% INFO    : Gen at bus 40067	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40067	: Pg=0.8, Qg=9.08 -> Pg=6.3, Qg=2.525
% INFO    : Gen at bus 40067	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40067	: Pg=0.8, Qg=9.08 -> Pg=6.3, Qg=2.525
% INFO    : Gen at bus 40067	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40067	: Pg=0.8, Qg=9.08 -> Pg=6.3, Qg=2.525
% INFO    : Gen at bus 40067	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40068	: Pg=3.45, Qg=11.15 -> Pg=10.5, Qg=2.575
% INFO    : Gen at bus 40068	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40068	: Pg=3.45, Qg=11.15 -> Pg=10.5, Qg=2.575
% INFO    : Gen at bus 40068	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40068	: Pg=3.45, Qg=11.15 -> Pg=10.5, Qg=2.575
% INFO    : Gen at bus 40068	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40068	: Pg=3.45, Qg=11.15 -> Pg=10.5, Qg=2.575
% INFO    : Gen at bus 40068	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40070	: Pg=5.63, Qg=18.8 -> Pg=15.0, Qg=5.25
% INFO    : Gen at bus 40070	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40070	: Pg=14.14, Qg=39.61 -> Pg=39.0, Qg=13.65
% INFO    : Gen at bus 40070	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40070	: Pg=11.35, Qg=39.61 -> Pg=32.0, Qg=11.25
% INFO    : Gen at bus 40070	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40071	: Pg=6.57, Qg=38.7 -> Pg=33.75, Qg=8.95
% INFO    : Gen at bus 40071	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40072	: Pg=11.53, Qg=29.6 -> Pg=35.6, Qg=4.6
% INFO    : Gen at bus 40072	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40074	: Pg=33.42, Qg=27.5 -> Pg=44.35, Qg=4.3
% INFO    : Gen at bus 40074	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40074	: Pg=20.42, Qg=27.5 -> Pg=37.85, Qg=4.3
% INFO    : Gen at bus 40074	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40074	: Pg=20.42, Qg=27.5 -> Pg=37.85, Qg=4.3
% INFO    : Gen at bus 40074	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40074	: Pg=20.42, Qg=27.5 -> Pg=37.85, Qg=4.3
% INFO    : Gen at bus 40074	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40075	: Pg=33.36, Qg=29.31 -> Pg=43.2, Qg=7.8
% INFO    : Gen at bus 40075	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40075	: Pg=44.88, Qg=29.31 -> Pg=59.0, Qg=10.75
% INFO    : Gen at bus 40075	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40076	: Pg=6.0, Qg=11.91 -> Pg=25.5, Qg=0.0
% INFO    : Gen at bus 40076	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40077	: Pg=16.25, Qg=31.0 -> Pg=32.5, Qg=7.15
% INFO    : Gen at bus 40077	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40079	: Pg=1.0, Qg=19.8 -> Pg=25.5, Qg=0.0
% INFO    : Gen at bus 40079	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40080	: Pg=0.0, Qg=-0.1 -> Pg=24.75, Qg=0.0
% INFO    : Gen at bus 40080	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40081	: Pg=2.23, Qg=36.8 -> Pg=25.0, Qg=10.25
% INFO    : Gen at bus 40081	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40082	: Pg=7.07, Qg=9.9 -> Pg=11.335, Qg=2.285
% INFO    : Gen at bus 40082	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40082	: Pg=7.07, Qg=9.9 -> Pg=11.335, Qg=2.285
% INFO    : Gen at bus 40082	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40082	: Pg=7.07, Qg=9.9 -> Pg=11.335, Qg=2.285
% INFO    : Gen at bus 40082	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40082	: Pg=10.63, Qg=15.5 -> Pg=17.5, Qg=3.6
% INFO    : Gen at bus 40082	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40082	: Pg=110.15, Qg=118.6 -> Pg=150.65, Qg=27.4
% INFO    : Gen at bus 40082	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40083	: Pg=2.03, Qg=2.96 -> Pg=3.225, Qg=0.945
% INFO    : Gen at bus 40083	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40083	: Pg=2.03, Qg=2.96 -> Pg=3.225, Qg=0.945
% INFO    : Gen at bus 40083	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40083	: Pg=2.03, Qg=2.96 -> Pg=3.225, Qg=0.945
% INFO    : Gen at bus 40083	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40083	: Pg=2.03, Qg=2.96 -> Pg=3.225, Qg=0.945
% INFO    : Gen at bus 40083	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40083	: Pg=2.03, Qg=2.96 -> Pg=3.225, Qg=0.945
% INFO    : Gen at bus 40083	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40083	: Pg=2.03, Qg=2.96 -> Pg=3.225, Qg=0.945
% INFO    : Gen at bus 40083	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40083	: Pg=2.03, Qg=2.96 -> Pg=3.225, Qg=0.945
% INFO    : Gen at bus 40083	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40083	: Pg=2.03, Qg=2.96 -> Pg=3.225, Qg=0.945
% INFO    : Gen at bus 40083	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40083	: Pg=2.03, Qg=2.96 -> Pg=3.225, Qg=0.945
% INFO    : Gen at bus 40083	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40084	: Pg=12.93, Qg=17.9 -> Pg=24.5, Qg=2.8
% INFO    : Gen at bus 40084	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40086	: Pg=3.88, Qg=21.9 -> Pg=19.15, Qg=5.05
% INFO    : Gen at bus 40086	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40086	: Pg=1.94, Qg=23.2 -> Pg=19.25, Qg=5.35
% INFO    : Gen at bus 40086	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40089	: Pg=7.8, Qg=2.9 -> Pg=19.45, Qg=2.4
% INFO    : Gen at bus 40089	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40090	: Pg=1.15, Qg=2.11 -> Pg=3.42, Qg=1.22
% INFO    : Gen at bus 40090	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40090	: Pg=1.15, Qg=2.11 -> Pg=3.42, Qg=1.22
% INFO    : Gen at bus 40090	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40090	: Pg=1.15, Qg=2.11 -> Pg=3.42, Qg=1.22
% INFO    : Gen at bus 40090	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40090	: Pg=1.15, Qg=2.11 -> Pg=3.42, Qg=1.22
% INFO    : Gen at bus 40090	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40090	: Pg=1.15, Qg=2.11 -> Pg=3.42, Qg=1.22
% INFO    : Gen at bus 40090	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40091	: Pg=12.67, Qg=15.5 -> Pg=20.375, Qg=2.95
% INFO    : Gen at bus 40091	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40092	: Pg=4.69, Qg=17.1 -> Pg=15.8, Qg=3.95
% INFO    : Gen at bus 40092	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40092	: Pg=7.04, Qg=20.4 -> Pg=23.75, Qg=5.95
% INFO    : Gen at bus 40092	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40093	: Pg=2.13, Qg=3.95 -> Pg=4.42, Qg=0.825
% INFO    : Gen at bus 40093	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40093	: Pg=2.13, Qg=3.95 -> Pg=4.42, Qg=0.825
% INFO    : Gen at bus 40093	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40093	: Pg=2.13, Qg=3.95 -> Pg=4.42, Qg=0.825
% INFO    : Gen at bus 40093	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40093	: Pg=2.13, Qg=3.95 -> Pg=4.42, Qg=0.825
% INFO    : Gen at bus 40093	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40095	: Pg=5.33, Qg=3.01 -> Pg=9.125, Qg=2.325
% INFO    : Gen at bus 40095	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40095	: Pg=5.33, Qg=3.01 -> Pg=9.125, Qg=2.325
% INFO    : Gen at bus 40095	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40097	: Pg=1.31, Qg=9.4 -> Pg=6.75, Qg=2.625
% INFO    : Gen at bus 40097	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40097	: Pg=1.31, Qg=9.4 -> Pg=6.75, Qg=2.625
% INFO    : Gen at bus 40097	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40098	: Pg=15.63, Qg=15.5 -> Pg=20.0, Qg=3.6
% INFO    : Gen at bus 40098	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40099	: Pg=15.63, Qg=15.5 -> Pg=20.0, Qg=3.6
% INFO    : Gen at bus 40099	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40100	: Pg=0.3, Qg=5.55 -> Pg=12.65, Qg=0.0
% INFO    : Gen at bus 40100	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40101	: Pg=0.1, Qg=0.7 -> Pg=6.05, Qg=0.0
% INFO    : Gen at bus 40101	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40101	: Pg=0.1, Qg=0.7 -> Pg=6.05, Qg=0.0
% INFO    : Gen at bus 40101	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40103	: Pg=6.29, Qg=6.64 -> Pg=8.75, Qg=1.65
% INFO    : Gen at bus 40103	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40103	: Pg=6.29, Qg=6.64 -> Pg=8.75, Qg=1.65
% INFO    : Gen at bus 40103	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40104	: Pg=1.3, Qg=8.7 -> Pg=11.6, Qg=0.0
% INFO    : Gen at bus 40104	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40105	: Pg=1.22, Qg=2.72 -> Pg=2.375, Qg=0.76
% INFO    : Gen at bus 40105	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40105	: Pg=1.22, Qg=2.72 -> Pg=2.375, Qg=0.76
% INFO    : Gen at bus 40105	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40105	: Pg=1.22, Qg=2.72 -> Pg=2.375, Qg=0.76
% INFO    : Gen at bus 40105	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40105	: Pg=1.22, Qg=2.72 -> Pg=2.375, Qg=0.76
% INFO    : Gen at bus 40105	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40105	: Pg=1.22, Qg=2.72 -> Pg=2.375, Qg=0.76
% INFO    : Gen at bus 40105	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40105	: Pg=1.22, Qg=2.72 -> Pg=2.375, Qg=0.76
% INFO    : Gen at bus 40105	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40106	: Pg=6.2, Qg=11.5 -> Pg=12.85, Qg=2.4
% INFO    : Gen at bus 40106	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40107	: Pg=1.0, Qg=6.17 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 40107	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40109	: Pg=314.7, Qg=181.32 -> Pg=506.65, Qg=100.4
% INFO    : Gen at bus 40109	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40110	: Pg=4.0, Qg=-8.3 -> Pg=14.5, Qg=3.6
% INFO    : Gen at bus 40110	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40110	: Pg=416.32, Qg=-33.87 -> Pg=396.5, Qg=0.0
% INFO    : Gen at bus 40110	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40110	: Pg=640.0, Qg=-33.87 -> Pg=396.5, Qg=0.0
% INFO    : Gen at bus 40110	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40111	: Pg=302.37, Qg=382.1 -> Pg=458.3, Qg=88.3
% INFO    : Gen at bus 40111	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40111	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40112	: Pg=134.69, Qg=-34.56 -> Pg=256.0, Qg=29.2
% INFO    : Gen at bus 40112	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40113	: Pg=158.66, Qg=70.81 -> Pg=247.8, Qg=26.1
% INFO    : Gen at bus 40113	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40114	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40114	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40114	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40114	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40115	: Pg=65.21, Qg=35.77 -> Pg=171.05, Qg=39.65
% INFO    : Gen at bus 40115	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40115	: Pg=100.15, Qg=35.77 -> Pg=149.45, Qg=28.5
% INFO    : Gen at bus 40115	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40115	: Pg=100.15, Qg=35.77 -> Pg=149.45, Qg=28.5
% INFO    : Gen at bus 40115	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40116	: Pg=150.15, Qg=8.15 -> Pg=174.45, Qg=28.5
% INFO    : Gen at bus 40116	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40116	: Pg=150.15, Qg=8.15 -> Pg=174.45, Qg=28.5
% INFO    : Gen at bus 40116	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40116	: Pg=150.17, Qg=8.15 -> Pg=185.5, Qg=31.65
% INFO    : Gen at bus 40116	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40117	: Pg=60.15, Qg=60.75 -> Pg=126.15, Qg=27.55
% INFO    : Gen at bus 40117	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40118	: Pg=102.14, Qg=20.25 -> Pg=144.5, Qg=26.8
% INFO    : Gen at bus 40118	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40118	: Pg=102.14, Qg=20.25 -> Pg=144.5, Qg=26.8
% INFO    : Gen at bus 40118	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40118	: Pg=102.14, Qg=20.25 -> Pg=144.5, Qg=26.8
% INFO    : Gen at bus 40118	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40119	: Pg=100.14, Qg=115.0 -> Pg=142.75, Qg=26.6
% INFO    : Gen at bus 40119	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40119	: Pg=100.14, Qg=115.0 -> Pg=142.75, Qg=26.6
% INFO    : Gen at bus 40119	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40120	: Pg=13.51, Qg=-1.91 -> Pg=24.4, Qg=5.78
% INFO    : Gen at bus 40120	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40120	: Pg=13.51, Qg=-1.91 -> Pg=24.4, Qg=5.78
% INFO    : Gen at bus 40120	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40120	: Pg=13.51, Qg=-1.91 -> Pg=24.4, Qg=5.78
% INFO    : Gen at bus 40120	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40120	: Pg=13.51, Qg=-1.91 -> Pg=24.4, Qg=5.78
% INFO    : Gen at bus 40120	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40120	: Pg=13.51, Qg=-1.91 -> Pg=24.4, Qg=5.78
% INFO    : Gen at bus 40120	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40120	: Pg=21.36, Qg=-1.91 -> Pg=37.2, Qg=7.8
% INFO    : Gen at bus 40120	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40120	: Pg=27.04, Qg=-1.91 -> Pg=53.3, Qg=11.7
% INFO    : Gen at bus 40120	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40121	: Pg=115.13, Qg=25.3 -> Pg=146.15, Qg=0.0
% INFO    : Gen at bus 40121	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40121	: Pg=60.08, Qg=15.1 -> Pg=83.1, Qg=0.0
% INFO    : Gen at bus 40121	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40122	: Pg=100.14, Qg=7.61 -> Pg=136.7, Qg=24.85
% INFO    : Gen at bus 40122	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40122	: Pg=100.14, Qg=7.61 -> Pg=136.7, Qg=24.85
% INFO    : Gen at bus 40122	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40123	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40123	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40123	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40123	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40123	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40123	: Pg=130.93, Qg=144.1 -> Pg=196.4, Qg=38.5
% INFO    : Gen at bus 40123	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40124	: Pg=9.96, Qg=61.27 -> Pg=72.6, Qg=0.0
% INFO    : Gen at bus 40124	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40125	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40125	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40127	: Pg=30.85, Qg=12.2 -> Pg=70.8, Qg=16.25
% INFO    : Gen at bus 40127	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40127	: Pg=30.85, Qg=12.2 -> Pg=70.8, Qg=16.25
% INFO    : Gen at bus 40127	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40128	: Pg=50.07, Qg=25.64 -> Pg=72.7, Qg=19.9
% INFO    : Gen at bus 40128	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40128	: Pg=50.07, Qg=25.64 -> Pg=72.7, Qg=19.9
% INFO    : Gen at bus 40128	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40128	: Pg=50.07, Qg=25.64 -> Pg=72.7, Qg=19.9
% INFO    : Gen at bus 40128	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40128	: Pg=50.07, Qg=25.64 -> Pg=72.7, Qg=19.9
% INFO    : Gen at bus 40128	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40129	: Pg=20.07, Qg=24.28 -> Pg=57.7, Qg=19.9
% INFO    : Gen at bus 40129	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40129	: Pg=20.07, Qg=24.28 -> Pg=57.7, Qg=19.9
% INFO    : Gen at bus 40129	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40129	: Pg=20.07, Qg=24.28 -> Pg=57.7, Qg=19.9
% INFO    : Gen at bus 40129	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40129	: Pg=20.07, Qg=24.28 -> Pg=57.7, Qg=19.9
% INFO    : Gen at bus 40129	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40130	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40130	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40130	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40130	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40131	: Pg=30.0, Qg=29.6 -> Pg=45.6, Qg=4.6
% INFO    : Gen at bus 40131	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40131	: Pg=30.0, Qg=29.6 -> Pg=45.6, Qg=4.6
% INFO    : Gen at bus 40131	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40131	: Pg=30.0, Qg=29.6 -> Pg=45.6, Qg=4.6
% INFO    : Gen at bus 40131	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40131	: Pg=30.0, Qg=29.6 -> Pg=45.6, Qg=4.6
% INFO    : Gen at bus 40131	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40131	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40132	: Pg=52.08, Qg=26.6 -> Pg=66.5, Qg=11.85
% INFO    : Gen at bus 40132	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40133	: Pg=21.73, Qg=31.49 -> Pg=44.5, Qg=5.2
% INFO    : Gen at bus 40133	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40133	: Pg=144.79, Qg=31.49 -> Pg=243.5, Qg=26.5
% INFO    : Gen at bus 40133	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40133	: Pg=105.36, Qg=31.49 -> Pg=254.35, Qg=31.25
% INFO    : Gen at bus 40133	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40134	: Pg=1.7, Qg=18.51 -> Pg=34.7, Qg=5.1
% INFO    : Gen at bus 40134	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40137	: Pg=14.14, Qg=10.45 -> Pg=14.61, Qg=2.665
% INFO    : Gen at bus 40137	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40137	: Pg=14.14, Qg=10.45 -> Pg=14.61, Qg=2.665
% INFO    : Gen at bus 40137	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40137	: Pg=14.14, Qg=10.45 -> Pg=14.61, Qg=2.665
% INFO    : Gen at bus 40137	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40137	: Pg=14.14, Qg=10.45 -> Pg=14.61, Qg=2.665
% INFO    : Gen at bus 40137	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40137	: Pg=20.53, Qg=16.1 -> Pg=20.75, Qg=4.45
% INFO    : Gen at bus 40137	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40139	: Pg=26.04, Qg=5.44 -> Pg=52.8, Qg=11.7
% INFO    : Gen at bus 40139	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40139	: Pg=12.5, Qg=5.44 -> Pg=35.5, Qg=8.6
% INFO    : Gen at bus 40139	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40139	: Pg=143.78, Qg=5.44 -> Pg=242.75, Qg=26.5
% INFO    : Gen at bus 40139	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40139	: Pg=277.9, Qg=5.44 -> Pg=429.0, Qg=85.2
% INFO    : Gen at bus 40139	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40140	: Pg=0.0, Qg=40.5 -> Pg=27.0, Qg=11.25
% INFO    : Gen at bus 40140	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40141	: Pg=2.6, Qg=21.3 -> Pg=28.3, Qg=0.0
% INFO    : Gen at bus 40141	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40142	: Pg=26.33, Qg=22.89 -> Pg=39.05, Qg=7.6
% INFO    : Gen at bus 40142	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40142	: Pg=26.33, Qg=22.89 -> Pg=39.05, Qg=7.6
% INFO    : Gen at bus 40142	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40143	: Pg=33.75, Qg=91.71 -> Pg=89.8, Qg=21.4
% INFO    : Gen at bus 40143	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40143	: Pg=17.04, Qg=50.6 -> Pg=48.3, Qg=11.7
% INFO    : Gen at bus 40143	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40143	: Pg=12.25, Qg=37.5 -> Pg=30.5, Qg=10.4
% INFO    : Gen at bus 40143	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40143	: Pg=11.73, Qg=51.8 -> Pg=39.5, Qg=14.4
% INFO    : Gen at bus 40143	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40143	: Pg=57.28, Qg=56.4 -> Pg=73.0, Qg=13.05
% INFO    : Gen at bus 40143	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40144	: Pg=17.05, Qg=0.13 -> Pg=28.9, Qg=3.15
% INFO    : Gen at bus 40144	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40144	: Pg=17.05, Qg=0.13 -> Pg=28.9, Qg=3.15
% INFO    : Gen at bus 40144	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40144	: Pg=57.59, Qg=0.13 -> Pg=79.25, Qg=7.8
% INFO    : Gen at bus 40144	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40145	: Pg=10.0, Qg=20.2 -> Pg=25.85, Qg=3.15
% INFO    : Gen at bus 40145	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40147	: Pg=30.0, Qg=20.81 -> Pg=43.35, Qg=4.3
% INFO    : Gen at bus 40147	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40147	: Pg=28.0, Qg=20.81 -> Pg=42.35, Qg=4.3
% INFO    : Gen at bus 40147	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40147	: Pg=7.0, Qg=20.81 -> Pg=22.25, Qg=5.35
% INFO    : Gen at bus 40147	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40147	: Pg=21.43, Qg=20.81 -> Pg=48.19, Qg=9.05
% INFO    : Gen at bus 40147	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40147	: Pg=21.43, Qg=20.81 -> Pg=48.19, Qg=9.05
% INFO    : Gen at bus 40147	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40148	: Pg=21.99, Qg=19.44 -> Pg=28.3, Qg=7.4
% INFO    : Gen at bus 40148	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40148	: Pg=21.59, Qg=19.44 -> Pg=28.1, Qg=7.4
% INFO    : Gen at bus 40148	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40149	: Pg=2.45, Qg=4.32 -> Pg=5.525, Qg=0.685
% INFO    : Gen at bus 40149	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40149	: Pg=2.45, Qg=4.32 -> Pg=5.525, Qg=0.685
% INFO    : Gen at bus 40149	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40149	: Pg=2.45, Qg=4.32 -> Pg=5.525, Qg=0.685
% INFO    : Gen at bus 40149	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40149	: Pg=2.45, Qg=4.32 -> Pg=5.525, Qg=0.685
% INFO    : Gen at bus 40149	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40151	: Pg=2.88, Qg=19.35 -> Pg=18.5, Qg=5.0
% INFO    : Gen at bus 40151	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40152	: Pg=3.08, Qg=5.47 -> Pg=7.05, Qg=0.85
% INFO    : Gen at bus 40152	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40152	: Pg=3.08, Qg=5.47 -> Pg=7.05, Qg=0.85
% INFO    : Gen at bus 40152	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40152	: Pg=3.08, Qg=5.47 -> Pg=7.05, Qg=0.85
% INFO    : Gen at bus 40152	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40153	: Pg=1.33, Qg=5.19 -> Pg=6.1, Qg=1.485
% INFO    : Gen at bus 40153	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40153	: Pg=1.33, Qg=5.19 -> Pg=6.1, Qg=1.485
% INFO    : Gen at bus 40153	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40153	: Pg=1.33, Qg=5.19 -> Pg=6.1, Qg=1.485
% INFO    : Gen at bus 40153	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40155	: Pg=0.8, Qg=2.95 -> Pg=2.365, Qg=0.82
% INFO    : Gen at bus 40155	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40155	: Pg=0.8, Qg=2.95 -> Pg=2.365, Qg=0.82
% INFO    : Gen at bus 40155	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40155	: Pg=0.8, Qg=2.95 -> Pg=2.365, Qg=0.82
% INFO    : Gen at bus 40155	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40155	: Pg=0.8, Qg=2.95 -> Pg=2.365, Qg=0.82
% INFO    : Gen at bus 40155	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40155	: Pg=0.8, Qg=2.95 -> Pg=2.365, Qg=0.82
% INFO    : Gen at bus 40155	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40155	: Pg=0.8, Qg=2.95 -> Pg=2.365, Qg=0.82
% INFO    : Gen at bus 40155	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40155	: Pg=0.8, Qg=2.95 -> Pg=2.365, Qg=0.82
% INFO    : Gen at bus 40155	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40155	: Pg=0.8, Qg=2.95 -> Pg=2.365, Qg=0.82
% INFO    : Gen at bus 40155	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40156	: Pg=6.38, Qg=8.6 -> Pg=10.6, Qg=1.775
% INFO    : Gen at bus 40156	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40156	: Pg=6.38, Qg=8.6 -> Pg=10.6, Qg=1.775
% INFO    : Gen at bus 40156	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40157	: Pg=0.0, Qg=11.9 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 40157	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40158	: Pg=0.0, Qg=11.9 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 40158	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40158	: Pg=0.0, Qg=37.07 -> Pg=49.5, Qg=0.0
% INFO    : Gen at bus 40158	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40160	: Pg=11.5, Qg=4.4 -> Pg=15.5, Qg=2.3
% INFO    : Gen at bus 40160	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40160	: Pg=10.5, Qg=4.4 -> Pg=15.0, Qg=2.3
% INFO    : Gen at bus 40160	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40160	: Pg=15.68, Qg=4.4 -> Pg=21.1, Qg=3.9
% INFO    : Gen at bus 40160	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40162	: Pg=10.41, Qg=15.99 -> Pg=17.15, Qg=5.1
% INFO    : Gen at bus 40162	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40163	: Pg=3.0, Qg=14.6 -> Pg=13.3, Qg=3.35
% INFO    : Gen at bus 40163	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40164	: Pg=0.8, Qg=1.0 -> Pg=1.81, Qg=0.0
% INFO    : Gen at bus 40164	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40164	: Pg=0.8, Qg=1.0 -> Pg=1.81, Qg=0.0
% INFO    : Gen at bus 40164	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40164	: Pg=0.8, Qg=1.0 -> Pg=1.81, Qg=0.0
% INFO    : Gen at bus 40164	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40164	: Pg=0.8, Qg=1.0 -> Pg=1.81, Qg=0.0
% INFO    : Gen at bus 40164	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40164	: Pg=0.8, Qg=1.0 -> Pg=1.81, Qg=0.0
% INFO    : Gen at bus 40164	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40164	: Pg=0.8, Qg=1.0 -> Pg=1.81, Qg=0.0
% INFO    : Gen at bus 40164	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40164	: Pg=0.8, Qg=1.0 -> Pg=1.81, Qg=0.0
% INFO    : Gen at bus 40164	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40164	: Pg=0.8, Qg=1.0 -> Pg=1.81, Qg=0.0
% INFO    : Gen at bus 40164	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40165	: Pg=0.68, Qg=5.5 -> Pg=3.915, Qg=1.535
% INFO    : Gen at bus 40165	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40165	: Pg=0.68, Qg=5.5 -> Pg=3.915, Qg=1.535
% INFO    : Gen at bus 40165	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40165	: Pg=0.68, Qg=5.5 -> Pg=3.915, Qg=1.535
% INFO    : Gen at bus 40165	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40166	: Pg=1.28, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 40166	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40166	: Pg=1.28, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 40166	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40167	: Pg=0.99, Qg=2.7 -> Pg=2.25, Qg=0.75
% INFO    : Gen at bus 40167	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40167	: Pg=0.99, Qg=2.7 -> Pg=2.25, Qg=0.75
% INFO    : Gen at bus 40167	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40167	: Pg=0.99, Qg=2.7 -> Pg=2.25, Qg=0.75
% INFO    : Gen at bus 40167	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40167	: Pg=0.99, Qg=2.7 -> Pg=2.25, Qg=0.75
% INFO    : Gen at bus 40167	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40167	: Pg=0.99, Qg=2.7 -> Pg=2.25, Qg=0.75
% INFO    : Gen at bus 40167	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40167	: Pg=0.99, Qg=2.7 -> Pg=2.25, Qg=0.75
% INFO    : Gen at bus 40167	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40168	: Pg=6.93, Qg=5.2 -> Pg=6.93, Qg=1.45
% INFO    : Gen at bus 40168	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40168	: Pg=6.93, Qg=5.2 -> Pg=6.93, Qg=1.45
% INFO    : Gen at bus 40168	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40168	: Pg=6.93, Qg=5.2 -> Pg=6.93, Qg=1.45
% INFO    : Gen at bus 40168	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40169	: Pg=0.0, Qg=3.75 -> Pg=2.5, Qg=1.035
% INFO    : Gen at bus 40169	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40169	: Pg=0.0, Qg=3.75 -> Pg=2.5, Qg=1.035
% INFO    : Gen at bus 40169	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40169	: Pg=0.0, Qg=3.75 -> Pg=2.5, Qg=1.035
% INFO    : Gen at bus 40169	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40169	: Pg=0.0, Qg=3.75 -> Pg=2.5, Qg=1.035
% INFO    : Gen at bus 40169	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40170	: Pg=2.25, Qg=7.5 -> Pg=6.0, Qg=2.075
% INFO    : Gen at bus 40170	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40170	: Pg=2.25, Qg=7.5 -> Pg=6.0, Qg=2.075
% INFO    : Gen at bus 40170	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40171	: Pg=7.0, Qg=12.1 -> Pg=13.5, Qg=2.7
% INFO    : Gen at bus 40171	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40171	: Pg=12.08, Qg=20.9 -> Pg=23.29, Qg=4.7
% INFO    : Gen at bus 40171	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40171	: Pg=5.0, Qg=14.0 -> Pg=14.0, Qg=3.15
% INFO    : Gen at bus 40171	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40171	: Pg=5.0, Qg=31.0 -> Pg=27.5, Qg=7.15
% INFO    : Gen at bus 40171	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40171	: Pg=5.0, Qg=31.0 -> Pg=27.5, Qg=7.15
% INFO    : Gen at bus 40171	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46843	: Pg=940.0, Qg=-187.05 -> Pg=596.25, Qg=0.0
% INFO    : Gen at bus 46843	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46843	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46844	: Pg=222.54, Qg=-90.19 -> Pg=550.0, Qg=67.95
% INFO    : Gen at bus 46844	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46844	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46845	: Pg=242.54, Qg=-122.76 -> Pg=560.0, Qg=67.95
% INFO    : Gen at bus 46845	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46845	: Pg=242.54, Qg=-122.76 -> Pg=560.0, Qg=67.95
% INFO    : Gen at bus 46845	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46846	: Pg=318.03, Qg=-37.11 -> Pg=510.0, Qg=54.35
% INFO    : Gen at bus 46846	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46847	: Pg=193.97, Qg=116.86 -> Pg=369.0, Qg=42.15
% INFO    : Gen at bus 46847	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46848	: Pg=144.34, Qg=-64.4 -> Pg=337.65, Qg=41.15
% INFO    : Gen at bus 46848	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46848	: Pg=70.02, Qg=-64.4 -> Pg=210.015, Qg=33.6
% INFO    : Gen at bus 46848	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46849	: Pg=148.06, Qg=3.44 -> Pg=192.0, Qg=18.25
% INFO    : Gen at bus 46849	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46849	: Pg=148.06, Qg=3.44 -> Pg=192.0, Qg=18.25
% INFO    : Gen at bus 46849	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46849	: Pg=89.56, Qg=3.44 -> Pg=172.5, Qg=19.8
% INFO    : Gen at bus 46849	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46850	: Pg=69.02, Qg=-5.78 -> Pg=171.25, Qg=40.15
% INFO    : Gen at bus 46850	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46850	: Pg=104.99, Qg=-5.78 -> Pg=149.65, Qg=28.55
% INFO    : Gen at bus 46850	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46850	: Pg=104.99, Qg=-5.78 -> Pg=149.65, Qg=28.55
% INFO    : Gen at bus 46850	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46851	: Pg=42.94, Qg=32.38 -> Pg=176.0, Qg=23.9
% INFO    : Gen at bus 46851	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46851	: Pg=84.98, Qg=32.38 -> Pg=139.45, Qg=15.0
% INFO    : Gen at bus 46851	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46851	: Pg=84.98, Qg=32.38 -> Pg=139.45, Qg=15.0
% INFO    : Gen at bus 46851	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46853	: Pg=94.41, Qg=-1.73 -> Pg=133.0, Qg=25.2
% INFO    : Gen at bus 46853	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46853	: Pg=146.39, Qg=-1.73 -> Pg=197.5, Qg=36.5
% INFO    : Gen at bus 46853	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46853	: Pg=146.39, Qg=-1.73 -> Pg=197.5, Qg=36.5
% INFO    : Gen at bus 46853	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46853	: Pg=146.39, Qg=-1.73 -> Pg=197.5, Qg=36.5
% INFO    : Gen at bus 46853	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46853	: Pg=94.41, Qg=-1.73 -> Pg=133.0, Qg=25.2
% INFO    : Gen at bus 46853	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46853	: Pg=94.41, Qg=-1.73 -> Pg=133.0, Qg=25.2
% INFO    : Gen at bus 46853	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46853	: Pg=94.41, Qg=-1.73 -> Pg=133.0, Qg=25.2
% INFO    : Gen at bus 46853	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46853	: Pg=94.41, Qg=-1.73 -> Pg=133.0, Qg=25.2
% INFO    : Gen at bus 46853	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46853	: Pg=94.41, Qg=-1.73 -> Pg=133.0, Qg=25.2
% INFO    : Gen at bus 46853	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46853	: Pg=94.41, Qg=-1.73 -> Pg=133.0, Qg=25.2
% INFO    : Gen at bus 46853	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46853	: Pg=94.41, Qg=-1.73 -> Pg=133.0, Qg=25.2
% INFO    : Gen at bus 46853	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46853	: Pg=146.39, Qg=-1.73 -> Pg=197.5, Qg=36.5
% INFO    : Gen at bus 46853	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46854	: Pg=128.88, Qg=75.0 -> Pg=139.9, Qg=11.7
% INFO    : Gen at bus 46854	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46855	: Pg=38.41, Qg=22.99 -> Pg=85.5, Qg=19.5
% INFO    : Gen at bus 46855	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46857	: Pg=28.01, Qg=19.19 -> Pg=72.5, Qg=17.2
% INFO    : Gen at bus 46857	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46858	: Pg=42.17, Qg=33.67 -> Pg=63.25, Qg=12.4
% INFO    : Gen at bus 46858	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46858	: Pg=42.17, Qg=33.67 -> Pg=63.25, Qg=12.4
% INFO    : Gen at bus 46858	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46858	: Pg=42.2, Qg=33.67 -> Pg=64.0, Qg=12.6
% INFO    : Gen at bus 46858	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46858	: Pg=42.2, Qg=33.67 -> Pg=64.0, Qg=12.6
% INFO    : Gen at bus 46858	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46860	: Pg=42.96, Qg=88.5 -> Pg=97.625, Qg=18.2
% INFO    : Gen at bus 46860	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46860	: Pg=21.39, Qg=39.7 -> Pg=44.33, Qg=8.35
% INFO    : Gen at bus 46860	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46861	: Pg=21.39, Qg=-11.77 -> Pg=44.33, Qg=8.35
% INFO    : Gen at bus 46861	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46861	: Pg=21.39, Qg=-11.77 -> Pg=44.33, Qg=8.35
% INFO    : Gen at bus 46861	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46862	: Pg=21.4, Qg=18.4 -> Pg=38.0, Qg=0.0
% INFO    : Gen at bus 46862	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46862	: Pg=21.4, Qg=18.4 -> Pg=38.0, Qg=0.0
% INFO    : Gen at bus 46862	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46863	: Pg=28.28, Qg=9.34 -> Pg=39.0, Qg=7.3
% INFO    : Gen at bus 46863	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46863	: Pg=28.28, Qg=9.34 -> Pg=39.0, Qg=7.3
% INFO    : Gen at bus 46863	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46863	: Pg=28.28, Qg=9.34 -> Pg=39.0, Qg=7.3
% INFO    : Gen at bus 46863	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46863	: Pg=28.28, Qg=9.34 -> Pg=39.0, Qg=7.3
% INFO    : Gen at bus 46863	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46863	: Pg=28.28, Qg=9.34 -> Pg=39.0, Qg=7.3
% INFO    : Gen at bus 46863	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46863	: Pg=28.28, Qg=9.34 -> Pg=39.0, Qg=7.3
% INFO    : Gen at bus 46863	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46863	: Pg=34.63, Qg=9.34 -> Pg=68.5, Qg=7.95
% INFO    : Gen at bus 46863	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46863	: Pg=34.63, Qg=9.34 -> Pg=68.5, Qg=7.95
% INFO    : Gen at bus 46863	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46863	: Pg=36.09, Qg=9.34 -> Pg=58.75, Qg=11.95
% INFO    : Gen at bus 46863	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46864	: Pg=16.2, Qg=15.8 -> Pg=31.5, Qg=0.0
% INFO    : Gen at bus 46864	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46864	: Pg=16.2, Qg=15.8 -> Pg=31.5, Qg=0.0
% INFO    : Gen at bus 46864	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46866	: Pg=11.01, Qg=19.5 -> Pg=25.1, Qg=3.05
% INFO    : Gen at bus 46866	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46866	: Pg=11.01, Qg=19.5 -> Pg=25.1, Qg=3.05
% INFO    : Gen at bus 46866	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46868	: Pg=32.87, Qg=11.02 -> Pg=74.69, Qg=13.95
% INFO    : Gen at bus 46868	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46868	: Pg=58.84, Qg=11.02 -> Pg=298.75, Qg=79.1
% INFO    : Gen at bus 46868	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46868	: Pg=12.4, Qg=11.02 -> Pg=25.7, Qg=4.85
% INFO    : Gen at bus 46868	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46868	: Pg=12.4, Qg=11.02 -> Pg=25.7, Qg=4.85
% INFO    : Gen at bus 46868	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46869	: Pg=28.0, Qg=9.2 -> Pg=21.5, Qg=0.0
% INFO    : Gen at bus 46869	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46869	: Pg=25.43, Qg=13.1 -> Pg=27.5, Qg=0.0
% INFO    : Gen at bus 46869	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46870	: Pg=11.0, Qg=7.43 -> Pg=25.0, Qg=0.0
% INFO    : Gen at bus 46870	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46870	: Pg=11.0, Qg=7.43 -> Pg=25.0, Qg=0.0
% INFO    : Gen at bus 46870	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46870	: Pg=11.0, Qg=7.43 -> Pg=25.0, Qg=0.0
% INFO    : Gen at bus 46870	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46870	: Pg=11.0, Qg=7.43 -> Pg=25.0, Qg=0.0
% INFO    : Gen at bus 46870	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46870	: Pg=11.13, Qg=7.43 -> Pg=27.5, Qg=0.0
% INFO    : Gen at bus 46870	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46870	: Pg=11.13, Qg=7.43 -> Pg=27.5, Qg=0.0
% INFO    : Gen at bus 46870	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46870	: Pg=11.13, Qg=7.43 -> Pg=27.5, Qg=0.0
% INFO    : Gen at bus 46870	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46870	: Pg=11.13, Qg=7.43 -> Pg=27.5, Qg=0.0
% INFO    : Gen at bus 46870	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46871	: Pg=20.94, Qg=18.2 -> Pg=28.75, Qg=2.85
% INFO    : Gen at bus 46871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46871	: Pg=20.94, Qg=18.2 -> Pg=28.75, Qg=2.85
% INFO    : Gen at bus 46871	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46872	: Pg=1.27, Qg=3.53 -> Pg=5.9, Qg=0.0
% INFO    : Gen at bus 46872	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46872	: Pg=1.27, Qg=3.53 -> Pg=5.9, Qg=0.0
% INFO    : Gen at bus 46872	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46872	: Pg=1.27, Qg=3.53 -> Pg=5.9, Qg=0.0
% INFO    : Gen at bus 46872	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46873	: Pg=1.27, Qg=3.53 -> Pg=5.9, Qg=0.0
% INFO    : Gen at bus 46873	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46873	: Pg=1.27, Qg=3.53 -> Pg=5.9, Qg=0.0
% INFO    : Gen at bus 46873	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46873	: Pg=1.27, Qg=3.53 -> Pg=5.9, Qg=0.0
% INFO    : Gen at bus 46873	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46874	: Pg=15.7, Qg=7.57 -> Pg=21.5, Qg=2.15
% INFO    : Gen at bus 46874	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46874	: Pg=15.7, Qg=7.57 -> Pg=21.5, Qg=2.15
% INFO    : Gen at bus 46874	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46875	: Pg=42.96, Qg=88.5 -> Pg=97.625, Qg=18.2
% INFO    : Gen at bus 46875	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46875	: Pg=8.22, Qg=15.2 -> Pg=17.025, Qg=3.2
% INFO    : Gen at bus 46875	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46878	: Pg=4.57, Qg=11.0 -> Pg=13.35, Qg=1.7
% INFO    : Gen at bus 46878	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46878	: Pg=4.57, Qg=11.0 -> Pg=13.35, Qg=1.7
% INFO    : Gen at bus 46878	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46883	: Pg=3.5, Qg=6.6 -> Pg=11.5, Qg=0.0
% INFO    : Gen at bus 46883	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46884	: Pg=1100.0, Qg=-99.92 -> Pg=699.9, Qg=90.6
% INFO    : Gen at bus 46884	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46885	: Pg=1000.0, Qg=161.0 -> Pg=569.75, Qg=78.2
% INFO    : Gen at bus 46885	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46886	: Pg=262.05, Qg=113.49 -> Pg=482.35, Qg=0.0
% INFO    : Gen at bus 46886	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46887	: Pg=295.17, Qg=177.55 -> Pg=363.0, Qg=47.25
% INFO    : Gen at bus 46887	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46888	: Pg=29.09, Qg=24.03 -> Pg=94.1, Qg=23.35
% INFO    : Gen at bus 46888	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46888	: Pg=82.85, Qg=24.03 -> Pg=96.8, Qg=16.25
% INFO    : Gen at bus 46888	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46888	: Pg=82.85, Qg=24.03 -> Pg=96.8, Qg=16.25
% INFO    : Gen at bus 46888	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46888	: Pg=253.96, Qg=24.03 -> Pg=377.4, Qg=69.05
% INFO    : Gen at bus 46888	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46888	: Pg=289.79, Qg=24.03 -> Pg=382.3, Qg=71.7
% INFO    : Gen at bus 46888	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46889	: Pg=210.06, Qg=101.15 -> Pg=250.25, Qg=33.65
% INFO    : Gen at bus 46889	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46889	: Pg=417.63, Qg=101.15 -> Pg=551.9, Qg=100.8
% INFO    : Gen at bus 46889	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46889	: Pg=263.1, Qg=101.15 -> Pg=369.0, Qg=42.15
% INFO    : Gen at bus 46889	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46890	: Pg=32.97, Qg=13.5 -> Pg=36.45, Qg=0.0
% INFO    : Gen at bus 46890	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46890	: Pg=136.16, Qg=76.98 -> Pg=285.25, Qg=33.65
% INFO    : Gen at bus 46890	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46890	: Pg=136.16, Qg=76.98 -> Pg=285.25, Qg=33.65
% INFO    : Gen at bus 46890	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46891	: Pg=46.2, Qg=48.49 -> Pg=143.85, Qg=35.45
% INFO    : Gen at bus 46891	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46891	: Pg=164.58, Qg=48.49 -> Pg=366.1, Qg=83.35
% INFO    : Gen at bus 46891	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46891	: Pg=34.54, Qg=48.49 -> Pg=222.35, Qg=60.25
% INFO    : Gen at bus 46891	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46892	: Pg=78.62, Qg=60.94 -> Pg=168.2, Qg=37.9
% INFO    : Gen at bus 46892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46892	: Pg=78.62, Qg=60.94 -> Pg=168.2, Qg=37.9
% INFO    : Gen at bus 46892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46892	: Pg=110.59, Qg=60.94 -> Pg=160.15, Qg=30.8
% INFO    : Gen at bus 46892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46892	: Pg=110.59, Qg=60.94 -> Pg=160.15, Qg=30.8
% INFO    : Gen at bus 46892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46892	: Pg=110.59, Qg=60.94 -> Pg=160.15, Qg=30.8
% INFO    : Gen at bus 46892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46892	: Pg=110.59, Qg=60.94 -> Pg=160.15, Qg=30.8
% INFO    : Gen at bus 46892	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46893	: Pg=7.63, Qg=14.7 -> Pg=16.0, Qg=3.6
% INFO    : Gen at bus 46893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46893	: Pg=7.58, Qg=14.7 -> Pg=15.085, Qg=3.6
% INFO    : Gen at bus 46893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46893	: Pg=7.58, Qg=14.7 -> Pg=15.085, Qg=3.6
% INFO    : Gen at bus 46893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46893	: Pg=7.58, Qg=14.7 -> Pg=15.085, Qg=3.6
% INFO    : Gen at bus 46893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46893	: Pg=7.58, Qg=14.7 -> Pg=15.085, Qg=3.6
% INFO    : Gen at bus 46893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46893	: Pg=7.58, Qg=14.7 -> Pg=15.085, Qg=3.6
% INFO    : Gen at bus 46893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46893	: Pg=7.58, Qg=14.7 -> Pg=15.085, Qg=3.6
% INFO    : Gen at bus 46893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46893	: Pg=7.58, Qg=14.7 -> Pg=15.085, Qg=3.6
% INFO    : Gen at bus 46893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46893	: Pg=7.63, Qg=14.7 -> Pg=16.0, Qg=3.6
% INFO    : Gen at bus 46893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46893	: Pg=7.63, Qg=14.7 -> Pg=16.0, Qg=3.6
% INFO    : Gen at bus 46893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46893	: Pg=7.63, Qg=14.7 -> Pg=16.0, Qg=3.6
% INFO    : Gen at bus 46893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46893	: Pg=7.63, Qg=14.7 -> Pg=16.0, Qg=3.6
% INFO    : Gen at bus 46893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46893	: Pg=7.72, Qg=14.7 -> Pg=17.85, Qg=4.1
% INFO    : Gen at bus 46893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46893	: Pg=7.55, Qg=14.7 -> Pg=14.4, Qg=4.55
% INFO    : Gen at bus 46893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46893	: Pg=7.58, Qg=14.7 -> Pg=15.085, Qg=3.6
% INFO    : Gen at bus 46893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46893	: Pg=7.58, Qg=14.7 -> Pg=15.085, Qg=3.6
% INFO    : Gen at bus 46893	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46894	: Pg=94.66, Qg=44.08 -> Pg=138.1, Qg=26.65
% INFO    : Gen at bus 46894	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46894	: Pg=146.01, Qg=44.08 -> Pg=190.05, Qg=0.0
% INFO    : Gen at bus 46894	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46894	: Pg=94.98, Qg=44.08 -> Pg=144.45, Qg=28.5
% INFO    : Gen at bus 46894	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46894	: Pg=94.98, Qg=44.08 -> Pg=144.45, Qg=28.5
% INFO    : Gen at bus 46894	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46895	: Pg=14.88, Qg=45.79 -> Pg=102.5, Qg=27.95
% INFO    : Gen at bus 46895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46895	: Pg=14.96, Qg=45.79 -> Pg=104.0, Qg=28.35
% INFO    : Gen at bus 46895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46895	: Pg=14.96, Qg=45.79 -> Pg=104.0, Qg=28.35
% INFO    : Gen at bus 46895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46895	: Pg=14.96, Qg=45.79 -> Pg=104.0, Qg=28.35
% INFO    : Gen at bus 46895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46895	: Pg=14.96, Qg=45.79 -> Pg=104.0, Qg=28.35
% INFO    : Gen at bus 46895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46896	: Pg=104.88, Qg=42.73 -> Pg=147.5, Qg=27.95
% INFO    : Gen at bus 46896	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46896	: Pg=104.88, Qg=42.73 -> Pg=147.5, Qg=27.95
% INFO    : Gen at bus 46896	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46896	: Pg=22.58, Qg=42.73 -> Pg=61.5, Qg=14.75
% INFO    : Gen at bus 46896	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46897	: Pg=56.09, Qg=32.51 -> Pg=146.55, Qg=34.85
% INFO    : Gen at bus 46897	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46897	: Pg=124.73, Qg=32.51 -> Pg=154.35, Qg=27.0
% INFO    : Gen at bus 46897	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46897	: Pg=124.73, Qg=32.51 -> Pg=154.35, Qg=27.0
% INFO    : Gen at bus 46897	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46897	: Pg=124.73, Qg=32.51 -> Pg=154.35, Qg=27.0
% INFO    : Gen at bus 46897	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46897	: Pg=52.85, Qg=32.51 -> Pg=81.8, Qg=16.25
% INFO    : Gen at bus 46897	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46898	: Pg=114.68, Qg=115.9 -> Pg=148.5, Qg=26.8
% INFO    : Gen at bus 46898	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46898	: Pg=114.68, Qg=115.9 -> Pg=148.5, Qg=26.8
% INFO    : Gen at bus 46898	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46898	: Pg=14.91, Qg=121.5 -> Pg=103.0, Qg=28.1
% INFO    : Gen at bus 46898	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46899	: Pg=107.61, Qg=106.65 -> Pg=143.5, Qg=26.35
% INFO    : Gen at bus 46899	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46899	: Pg=107.61, Qg=106.65 -> Pg=143.5, Qg=26.35
% INFO    : Gen at bus 46899	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46899	: Pg=64.41, Qg=106.65 -> Pg=157.0, Qg=36.7
% INFO    : Gen at bus 46899	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46900	: Pg=98.49, Qg=5.86 -> Pg=136.65, Qg=25.65
% INFO    : Gen at bus 46900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46900	: Pg=98.49, Qg=5.86 -> Pg=136.65, Qg=25.65
% INFO    : Gen at bus 46900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46900	: Pg=98.49, Qg=5.86 -> Pg=136.65, Qg=25.65
% INFO    : Gen at bus 46900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46900	: Pg=74.06, Qg=5.86 -> Pg=96.5, Qg=17.45
% INFO    : Gen at bus 46900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46900	: Pg=74.06, Qg=5.86 -> Pg=96.5, Qg=17.45
% INFO    : Gen at bus 46900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46900	: Pg=74.06, Qg=5.86 -> Pg=96.5, Qg=17.45
% INFO    : Gen at bus 46900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46901	: Pg=64.47, Qg=50.22 -> Pg=119.25, Qg=25.55
% INFO    : Gen at bus 46901	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46901	: Pg=64.47, Qg=50.22 -> Pg=119.25, Qg=25.55
% INFO    : Gen at bus 46901	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46901	: Pg=64.47, Qg=50.22 -> Pg=119.25, Qg=25.55
% INFO    : Gen at bus 46901	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46901	: Pg=83.98, Qg=50.22 -> Pg=216.85, Qg=51.35
% INFO    : Gen at bus 46901	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46903	: Pg=58.09, Qg=49.35 -> Pg=108.6, Qg=23.35
% INFO    : Gen at bus 46903	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46903	: Pg=41.0, Qg=49.35 -> Pg=137.2, Qg=34.3
% INFO    : Gen at bus 46903	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46903	: Pg=239.82, Qg=49.35 -> Pg=408.4, Qg=69.05
% INFO    : Gen at bus 46903	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46903	: Pg=239.82, Qg=49.35 -> Pg=408.4, Qg=69.05
% INFO    : Gen at bus 46903	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46903	: Pg=174.82, Qg=49.35 -> Pg=375.9, Qg=69.05
% INFO    : Gen at bus 46903	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46904	: Pg=37.85, Qg=26.3 -> Pg=74.3, Qg=16.25
% INFO    : Gen at bus 46904	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46904	: Pg=37.85, Qg=26.3 -> Pg=74.3, Qg=16.25
% INFO    : Gen at bus 46904	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46904	: Pg=73.33, Qg=26.3 -> Pg=101.4, Qg=10.0
% INFO    : Gen at bus 46904	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46904	: Pg=73.33, Qg=26.3 -> Pg=101.4, Qg=10.0
% INFO    : Gen at bus 46904	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46905	: Pg=33.23, Qg=49.63 -> Pg=79.55, Qg=9.75
% INFO    : Gen at bus 46905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46905	: Pg=20.34, Qg=49.63 -> Pg=94.65, Qg=24.8
% INFO    : Gen at bus 46905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46905	: Pg=21.57, Qg=38.7 -> Pg=41.25, Qg=8.95
% INFO    : Gen at bus 46905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46905	: Pg=21.58, Qg=39.0 -> Pg=41.5, Qg=9.0
% INFO    : Gen at bus 46905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46905	: Pg=2.58, Qg=14.3 -> Pg=12.5, Qg=3.3
% INFO    : Gen at bus 46905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46905	: Pg=11.88, Qg=46.5 -> Pg=42.5, Qg=10.75
% INFO    : Gen at bus 46905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46905	: Pg=6.25, Qg=31.0 -> Pg=27.5, Qg=7.15
% INFO    : Gen at bus 46905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46905	: Pg=6.25, Qg=31.0 -> Pg=27.5, Qg=7.15
% INFO    : Gen at bus 46905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46908	: Pg=54.32, Qg=65.3 -> Pg=72.0, Qg=13.45
% INFO    : Gen at bus 46908	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46908	: Pg=274.52, Qg=216.54 -> Pg=381.1, Qg=83.35
% INFO    : Gen at bus 46908	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46908	: Pg=123.44, Qg=162.2 -> Pg=150.9, Qg=37.45
% INFO    : Gen at bus 46908	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46911	: Pg=75.14, Qg=41.3 -> Pg=79.15, Qg=6.45
% INFO    : Gen at bus 46911	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46912	: Pg=29.1, Qg=52.0 -> Pg=55.45, Qg=12.0
% INFO    : Gen at bus 46912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46914	: Pg=9.43, Qg=28.62 -> Pg=32.5, Qg=8.15
% INFO    : Gen at bus 46914	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46914	: Pg=46.92, Qg=28.62 -> Pg=60.75, Qg=5.8
% INFO    : Gen at bus 46914	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46914	: Pg=46.92, Qg=28.62 -> Pg=60.75, Qg=5.8
% INFO    : Gen at bus 46914	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46914	: Pg=4.92, Qg=28.62 -> Pg=39.75, Qg=5.8
% INFO    : Gen at bus 46914	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46914	: Pg=69.38, Qg=28.62 -> Pg=95.625, Qg=12.55
% INFO    : Gen at bus 46914	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46914	: Pg=78.13, Qg=28.62 -> Pg=100.0, Qg=17.9
% INFO    : Gen at bus 46914	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46914	: Pg=24.2, Qg=28.62 -> Pg=55.0, Qg=12.6
% INFO    : Gen at bus 46914	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46914	: Pg=15.25, Qg=28.62 -> Pg=51.5, Qg=12.9
% INFO    : Gen at bus 46914	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46915	: Pg=1.58, Qg=11.3 -> Pg=12.15, Qg=1.75
% INFO    : Gen at bus 46915	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46915	: Pg=1.69, Qg=13.3 -> Pg=14.25, Qg=2.05
% INFO    : Gen at bus 46915	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46915	: Pg=1.45, Qg=9.03 -> Pg=9.425, Qg=1.54
% INFO    : Gen at bus 46915	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46915	: Pg=1.45, Qg=9.03 -> Pg=9.425, Qg=1.54
% INFO    : Gen at bus 46915	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46915	: Pg=1.45, Qg=9.03 -> Pg=9.425, Qg=1.54
% INFO    : Gen at bus 46915	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46915	: Pg=1.45, Qg=9.03 -> Pg=9.425, Qg=1.54
% INFO    : Gen at bus 46915	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46916	: Pg=30.94, Qg=63.8 -> Pg=70.315, Qg=13.15
% INFO    : Gen at bus 46916	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46916	: Pg=27.25, Qg=105.2 -> Pg=96.4, Qg=24.3
% INFO    : Gen at bus 46916	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46916	: Pg=21.39, Qg=39.7 -> Pg=44.33, Qg=8.35
% INFO    : Gen at bus 46916	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46916	: Pg=342.0, Qg=286.65 -> Pg=542.55, Qg=67.55
% INFO    : Gen at bus 46916	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46916	: Pg=422.05, Qg=286.65 -> Pg=542.55, Qg=67.55
% INFO    : Gen at bus 46916	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46917	: Pg=28.29, Qg=25.6 -> Pg=32.0, Qg=0.0
% INFO    : Gen at bus 46917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46917	: Pg=31.92, Qg=28.8 -> Pg=35.85, Qg=0.0
% INFO    : Gen at bus 46917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46918	: Pg=68.13, Qg=22.61 -> Pg=154.81, Qg=28.9
% INFO    : Gen at bus 46918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46918	: Pg=6.49, Qg=22.61 -> Pg=32.15, Qg=4.45
% INFO    : Gen at bus 46918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46918	: Pg=6.65, Qg=22.61 -> Pg=35.5, Qg=5.0
% INFO    : Gen at bus 46918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46918	: Pg=12.53, Qg=22.61 -> Pg=55.5, Qg=7.6
% INFO    : Gen at bus 46918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46920	: Pg=26.38, Qg=26.6 -> Pg=40.0, Qg=4.15
% INFO    : Gen at bus 46920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46920	: Pg=40.08, Qg=52.7 -> Pg=55.0, Qg=12.2
% INFO    : Gen at bus 46920	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46921	: Pg=74.68, Qg=0.0 -> Pg=128.5, Qg=0.0
% INFO    : Gen at bus 46921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46921	: Pg=28.35, Qg=0.0 -> Pg=40.45, Qg=0.0
% INFO    : Gen at bus 46921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46921	: Pg=42.5, Qg=0.0 -> Pg=70.0, Qg=0.0
% INFO    : Gen at bus 46921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46922	: Pg=8.88, Qg=10.57 -> Pg=21.5, Qg=5.0
% INFO    : Gen at bus 46922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46922	: Pg=26.43, Qg=10.57 -> Pg=41.05, Qg=8.2
% INFO    : Gen at bus 46922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46922	: Pg=51.83, Qg=10.57 -> Pg=61.55, Qg=10.45
% INFO    : Gen at bus 46922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46922	: Pg=51.83, Qg=10.57 -> Pg=61.55, Qg=10.45
% INFO    : Gen at bus 46922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46922	: Pg=39.93, Qg=10.57 -> Pg=57.6, Qg=11.05
% INFO    : Gen at bus 46922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46922	: Pg=39.93, Qg=10.57 -> Pg=57.6, Qg=11.05
% INFO    : Gen at bus 46922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46922	: Pg=9.13, Qg=10.57 -> Pg=26.5, Qg=6.45
% INFO    : Gen at bus 46922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46922	: Pg=10.05, Qg=10.57 -> Pg=45.0, Qg=11.75
% INFO    : Gen at bus 46922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46922	: Pg=1.26, Qg=6.5 -> Pg=5.75, Qg=1.5
% INFO    : Gen at bus 46922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46922	: Pg=1.26, Qg=6.5 -> Pg=5.75, Qg=1.5
% INFO    : Gen at bus 46922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46922	: Pg=1.26, Qg=6.5 -> Pg=5.75, Qg=1.5
% INFO    : Gen at bus 46922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46922	: Pg=1.26, Qg=6.5 -> Pg=5.75, Qg=1.5
% INFO    : Gen at bus 46922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46922	: Pg=1.26, Qg=6.5 -> Pg=5.75, Qg=1.5
% INFO    : Gen at bus 46922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46922	: Pg=1.5, Qg=10.57 -> Pg=10.5, Qg=2.85
% INFO    : Gen at bus 46922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46923	: Pg=24.38, Qg=29.7 -> Pg=33.215, Qg=6.25
% INFO    : Gen at bus 46923	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46923	: Pg=38.29, Qg=46.7 -> Pg=52.17, Qg=9.8
% INFO    : Gen at bus 46923	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46924	: Pg=16.26, Qg=0.0 -> Pg=32.7, Qg=0.0
% INFO    : Gen at bus 46924	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46924	: Pg=16.26, Qg=0.0 -> Pg=32.7, Qg=0.0
% INFO    : Gen at bus 46924	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46926	: Pg=34.0, Qg=24.8 -> Pg=36.5, Qg=5.75
% INFO    : Gen at bus 46926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46926	: Pg=34.0, Qg=24.8 -> Pg=36.5, Qg=5.75
% INFO    : Gen at bus 46926	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46927	: Pg=18.89, Qg=7.2 -> Pg=26.85, Qg=0.0
% INFO    : Gen at bus 46927	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46927	: Pg=21.03, Qg=8.4 -> Pg=30.6, Qg=0.0
% INFO    : Gen at bus 46927	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46928	: Pg=12.5, Qg=2.55 -> Pg=7.5, Qg=0.0
% INFO    : Gen at bus 46928	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46928	: Pg=12.5, Qg=2.55 -> Pg=7.5, Qg=0.0
% INFO    : Gen at bus 46928	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46929	: Pg=1.71, Qg=6.45 -> Pg=6.95, Qg=1.15
% INFO    : Gen at bus 46929	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46929	: Pg=1.71, Qg=6.45 -> Pg=6.95, Qg=1.15
% INFO    : Gen at bus 46929	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46931	: Pg=11.79, Qg=12.1 -> Pg=14.25, Qg=1.9
% INFO    : Gen at bus 46931	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46931	: Pg=11.79, Qg=12.1 -> Pg=14.25, Qg=1.9
% INFO    : Gen at bus 46931	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46931	: Pg=11.79, Qg=12.1 -> Pg=14.25, Qg=1.9
% INFO    : Gen at bus 46931	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46934	: Pg=17.38, Qg=21.3 -> Pg=27.315, Qg=4.3
% INFO    : Gen at bus 46934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46934	: Pg=28.97, Qg=24.0 -> Pg=33.4, Qg=5.55
% INFO    : Gen at bus 46934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46934	: Pg=29.0, Qg=28.5 -> Pg=33.0, Qg=7.9
% INFO    : Gen at bus 46934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46934	: Pg=2.3, Qg=7.45 -> Pg=7.0, Qg=1.725
% INFO    : Gen at bus 46934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46934	: Pg=2.3, Qg=7.45 -> Pg=7.0, Qg=1.725
% INFO    : Gen at bus 46934	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46936	: Pg=2.22, Qg=3.04 -> Pg=2.8, Qg=0.74
% INFO    : Gen at bus 46936	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46936	: Pg=2.22, Qg=3.04 -> Pg=2.8, Qg=0.74
% INFO    : Gen at bus 46936	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46936	: Pg=2.22, Qg=3.04 -> Pg=2.8, Qg=0.74
% INFO    : Gen at bus 46936	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46936	: Pg=2.22, Qg=3.04 -> Pg=2.8, Qg=0.74
% INFO    : Gen at bus 46936	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46936	: Pg=2.22, Qg=3.04 -> Pg=2.8, Qg=0.74
% INFO    : Gen at bus 46936	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46937	: Pg=16.87, Qg=31.3 -> Pg=34.95, Qg=6.6
% INFO    : Gen at bus 46937	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46937	: Pg=8.58, Qg=14.3 -> Pg=15.5, Qg=3.3
% INFO    : Gen at bus 46937	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46937	: Pg=73.73, Qg=85.81 -> Pg=206.75, Qg=49.9
% INFO    : Gen at bus 46937	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46939	: Pg=2.48, Qg=6.7 -> Pg=6.6, Qg=1.525
% INFO    : Gen at bus 46939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46939	: Pg=2.48, Qg=6.7 -> Pg=6.6, Qg=1.525
% INFO    : Gen at bus 46939	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46940	: Pg=8.52, Qg=10.1 -> Pg=14.4, Qg=1.6
% INFO    : Gen at bus 46940	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46940	: Pg=8.94, Qg=18.2 -> Pg=22.75, Qg=2.85
% INFO    : Gen at bus 46940	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46941	: Pg=20.7, Qg=8.63 -> Pg=16.3, Qg=2.95
% INFO    : Gen at bus 46941	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46942	: Pg=1.62, Qg=2.07 -> Pg=2.225, Qg=0.55
% INFO    : Gen at bus 46942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46942	: Pg=1.62, Qg=2.07 -> Pg=2.225, Qg=0.55
% INFO    : Gen at bus 46942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46942	: Pg=1.62, Qg=2.07 -> Pg=2.225, Qg=0.55
% INFO    : Gen at bus 46942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46942	: Pg=1.62, Qg=2.07 -> Pg=2.225, Qg=0.55
% INFO    : Gen at bus 46942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46942	: Pg=1.62, Qg=2.07 -> Pg=2.225, Qg=0.55
% INFO    : Gen at bus 46942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46942	: Pg=1.62, Qg=2.07 -> Pg=2.225, Qg=0.55
% INFO    : Gen at bus 46942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46942	: Pg=1.62, Qg=2.07 -> Pg=2.225, Qg=0.55
% INFO    : Gen at bus 46942	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46943	: Pg=6.5, Qg=9.7 -> Pg=13.0, Qg=1.5
% INFO    : Gen at bus 46943	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46943	: Pg=7.6, Qg=11.6 -> Pg=15.5, Qg=1.8
% INFO    : Gen at bus 46943	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46944	: Pg=3.5, Qg=12.4 -> Pg=11.5, Qg=2.85
% INFO    : Gen at bus 46944	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46944	: Pg=3.63, Qg=15.5 -> Pg=14.0, Qg=3.6
% INFO    : Gen at bus 46944	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46945	: Pg=800.0, Qg=85.26 -> Pg=1017.9, Qg=93.3
% INFO    : Gen at bus 46945	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46946	: Pg=372.89, Qg=-13.98 -> Pg=632.0, Qg=69.0
% INFO    : Gen at bus 46946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46946	: Pg=368.18, Qg=-13.98 -> Pg=538.0, Qg=54.8
% INFO    : Gen at bus 46946	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46947	: Pg=341.28, Qg=-151.7 -> Pg=487.5, Qg=49.05
% INFO    : Gen at bus 46947	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46947	: Pg=341.28, Qg=-151.7 -> Pg=487.5, Qg=49.05
% INFO    : Gen at bus 46947	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46948	: Pg=295.55, Qg=-155.09 -> Pg=450.5, Qg=46.9
% INFO    : Gen at bus 46948	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46948	: Pg=290.55, Qg=-155.09 -> Pg=448.0, Qg=46.9
% INFO    : Gen at bus 46948	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46949	: Pg=103.66, Qg=62.2 -> Pg=123.0, Qg=0.0
% INFO    : Gen at bus 46949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46949	: Pg=64.41, Qg=109.1 -> Pg=118.0, Qg=25.2
% INFO    : Gen at bus 46949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46949	: Pg=304.88, Qg=265.48 -> Pg=442.15, Qg=44.85
% INFO    : Gen at bus 46949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46950	: Pg=302.55, Qg=54.25 -> Pg=454.0, Qg=46.9
% INFO    : Gen at bus 46950	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46950	: Pg=295.55, Qg=54.25 -> Pg=450.5, Qg=46.9
% INFO    : Gen at bus 46950	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46950	: Pg=304.37, Qg=54.25 -> Pg=431.85, Qg=82.15
% INFO    : Gen at bus 46950	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46950	: Pg=303.37, Qg=54.25 -> Pg=431.35, Qg=82.15
% INFO    : Gen at bus 46950	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46951	: Pg=266.77, Qg=267.68 -> Pg=401.35, Qg=78.75
% INFO    : Gen at bus 46951	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46951	: Pg=265.77, Qg=267.68 -> Pg=400.85, Qg=78.75
% INFO    : Gen at bus 46951	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=6.25, Qg=19.25 -> Pg=27.5, Qg=3.75
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=5.91, Qg=19.25 -> Pg=29.28, Qg=4.08
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=5.91, Qg=19.25 -> Pg=29.28, Qg=4.08
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=5.91, Qg=19.25 -> Pg=29.28, Qg=4.08
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=5.91, Qg=19.25 -> Pg=29.28, Qg=4.08
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=5.91, Qg=19.25 -> Pg=29.28, Qg=4.08
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=5.91, Qg=19.25 -> Pg=29.28, Qg=4.08
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=5.91, Qg=19.25 -> Pg=29.28, Qg=4.08
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=5.91, Qg=19.25 -> Pg=29.28, Qg=4.08
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=6.25, Qg=19.25 -> Pg=27.5, Qg=3.75
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=6.6, Qg=19.25 -> Pg=34.5, Qg=4.85
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=6.6, Qg=19.25 -> Pg=34.5, Qg=4.85
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=6.6, Qg=19.25 -> Pg=34.5, Qg=4.85
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=6.6, Qg=19.25 -> Pg=34.5, Qg=4.85
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=6.6, Qg=19.25 -> Pg=34.5, Qg=4.85
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=6.6, Qg=19.25 -> Pg=34.5, Qg=4.85
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46952	: Pg=5.91, Qg=19.25 -> Pg=29.28, Qg=4.08
% INFO    : Gen at bus 46952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46956	: Pg=170.11, Qg=-29.02 -> Pg=184.5, Qg=15.4
% INFO    : Gen at bus 46956	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46956	: Pg=170.11, Qg=-29.02 -> Pg=184.5, Qg=15.4
% INFO    : Gen at bus 46956	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46957	: Pg=88.86, Qg=82.45 -> Pg=139.0, Qg=14.65
% INFO    : Gen at bus 46957	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46957	: Pg=31.3, Qg=25.2 -> Pg=41.0, Qg=3.95
% INFO    : Gen at bus 46957	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46957	: Pg=31.43, Qg=27.6 -> Pg=43.5, Qg=4.3
% INFO    : Gen at bus 46957	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46958	: Pg=187.99, Qg=21.87 -> Pg=124.0, Qg=14.2
% INFO    : Gen at bus 46958	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46958	: Pg=187.99, Qg=21.87 -> Pg=119.0, Qg=26.9
% INFO    : Gen at bus 46958	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46958	: Pg=187.99, Qg=21.87 -> Pg=119.0, Qg=26.9
% INFO    : Gen at bus 46958	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46959	: Pg=79.51, Qg=0.0 -> Pg=127.5, Qg=0.0
% INFO    : Gen at bus 46959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46959	: Pg=79.53, Qg=0.0 -> Pg=128.0, Qg=0.0
% INFO    : Gen at bus 46959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46959	: Pg=73.08, Qg=0.0 -> Pg=96.5, Qg=0.0
% INFO    : Gen at bus 46959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46959	: Pg=55.17, Qg=0.0 -> Pg=128.25, Qg=0.0
% INFO    : Gen at bus 46959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46960	: Pg=112.51, Qg=29.95 -> Pg=144.0, Qg=13.6
% INFO    : Gen at bus 46960	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46960	: Pg=112.51, Qg=29.95 -> Pg=144.0, Qg=13.6
% INFO    : Gen at bus 46960	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46960	: Pg=86.76, Qg=29.95 -> Pg=175.0, Qg=20.4
% INFO    : Gen at bus 46960	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46961	: Pg=129.3, Qg=27.65 -> Pg=148.35, Qg=24.6
% INFO    : Gen at bus 46961	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46961	: Pg=488.48, Qg=27.65 -> Pg=604.0, Qg=55.7
% INFO    : Gen at bus 46961	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46961	: Pg=246.81, Qg=27.65 -> Pg=256.0, Qg=38.95
% INFO    : Gen at bus 46961	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46962	: Pg=86.95, Qg=14.12 -> Pg=120.4, Qg=22.6
% INFO    : Gen at bus 46962	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46962	: Pg=86.95, Qg=14.12 -> Pg=120.4, Qg=22.6
% INFO    : Gen at bus 46962	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46963	: Pg=150.0, Qg=34.42 -> Pg=150.0, Qg=0.0
% INFO    : Gen at bus 46963	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46964	: Pg=0.0, Qg=30.67 -> Pg=73.0, Qg=0.0
% INFO    : Gen at bus 46964	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46965	: Pg=56.44, Qg=85.2 -> Pg=95.25, Qg=19.7
% INFO    : Gen at bus 46965	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46965	: Pg=49.44, Qg=85.2 -> Pg=91.75, Qg=19.7
% INFO    : Gen at bus 46965	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46965	: Pg=16.4, Qg=27.1 -> Pg=35.5, Qg=4.2
% INFO    : Gen at bus 46965	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46965	: Pg=7.55, Qg=30.0 -> Pg=34.0, Qg=4.65
% INFO    : Gen at bus 46965	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46965	: Pg=132.24, Qg=148.78 -> Pg=207.0, Qg=41.4
% INFO    : Gen at bus 46965	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46965	: Pg=173.99, Qg=148.78 -> Pg=262.0, Qg=51.4
% INFO    : Gen at bus 46965	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46966	: Pg=74.04, Qg=15.99 -> Pg=96.1, Qg=17.35
% INFO    : Gen at bus 46966	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46967	: Pg=82.93, Qg=42.0 -> Pg=98.5, Qg=16.75
% INFO    : Gen at bus 46967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46967	: Pg=82.93, Qg=42.0 -> Pg=98.5, Qg=16.75
% INFO    : Gen at bus 46967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46967	: Pg=82.93, Qg=42.0 -> Pg=98.5, Qg=16.75
% INFO    : Gen at bus 46967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46968	: Pg=58.55, Qg=12.77 -> Pg=78.9, Qg=14.6
% INFO    : Gen at bus 46968	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46968	: Pg=58.55, Qg=12.77 -> Pg=78.9, Qg=14.6
% INFO    : Gen at bus 46968	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46968	: Pg=58.55, Qg=12.77 -> Pg=78.9, Qg=14.6
% INFO    : Gen at bus 46968	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46968	: Pg=58.55, Qg=12.77 -> Pg=78.9, Qg=14.6
% INFO    : Gen at bus 46968	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46968	: Pg=58.55, Qg=12.77 -> Pg=78.9, Qg=14.6
% INFO    : Gen at bus 46968	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46968	: Pg=58.55, Qg=12.77 -> Pg=78.9, Qg=14.6
% INFO    : Gen at bus 46968	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46968	: Pg=58.55, Qg=12.77 -> Pg=78.9, Qg=14.6
% INFO    : Gen at bus 46968	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46968	: Pg=58.55, Qg=12.77 -> Pg=78.9, Qg=14.6
% INFO    : Gen at bus 46968	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46969	: Pg=22.25, Qg=43.6 -> Pg=55.0, Qg=6.8
% INFO    : Gen at bus 46969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46969	: Pg=5.58, Qg=14.3 -> Pg=14.0, Qg=3.3
% INFO    : Gen at bus 46969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46969	: Pg=5.63, Qg=15.5 -> Pg=15.0, Qg=3.6
% INFO    : Gen at bus 46969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46969	: Pg=12.13, Qg=41.2 -> Pg=47.5, Qg=6.45
% INFO    : Gen at bus 46969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46970	: Pg=6.85, Qg=35.8 -> Pg=39.5, Qg=5.55
% INFO    : Gen at bus 46970	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46972	: Pg=6.53, Qg=29.5 -> Pg=33.0, Qg=4.6
% INFO    : Gen at bus 46972	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46972	: Pg=6.53, Qg=29.5 -> Pg=33.0, Qg=4.6
% INFO    : Gen at bus 46972	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46972	: Pg=6.53, Qg=29.5 -> Pg=33.0, Qg=4.6
% INFO    : Gen at bus 46972	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46972	: Pg=6.53, Qg=29.5 -> Pg=33.0, Qg=4.6
% INFO    : Gen at bus 46972	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46973	: Pg=7.52, Qg=29.4 -> Pg=33.4, Qg=4.55
% INFO    : Gen at bus 46973	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46974	: Pg=7.52, Qg=29.4 -> Pg=33.35, Qg=4.6
% INFO    : Gen at bus 46974	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46975	: Pg=7.52, Qg=29.3 -> Pg=33.3, Qg=4.55
% INFO    : Gen at bus 46975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46976	: Pg=25.52, Qg=29.3 -> Pg=42.25, Qg=4.55
% INFO    : Gen at bus 46976	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46976	: Pg=25.52, Qg=29.3 -> Pg=42.25, Qg=4.55
% INFO    : Gen at bus 46976	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46976	: Pg=33.23, Qg=39.94 -> Pg=79.5, Qg=9.75
% INFO    : Gen at bus 46976	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46976	: Pg=33.23, Qg=39.94 -> Pg=79.5, Qg=9.75
% INFO    : Gen at bus 46976	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46977	: Pg=39.5, Qg=18.62 -> Pg=49.0, Qg=8.6
% INFO    : Gen at bus 46977	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46977	: Pg=39.5, Qg=18.62 -> Pg=49.0, Qg=8.6
% INFO    : Gen at bus 46977	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46977	: Pg=39.5, Qg=18.62 -> Pg=49.0, Qg=8.6
% INFO    : Gen at bus 46977	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46977	: Pg=39.5, Qg=18.62 -> Pg=49.0, Qg=8.6
% INFO    : Gen at bus 46977	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46978	: Pg=31.48, Qg=36.5 -> Pg=44.45, Qg=8.45
% INFO    : Gen at bus 46978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46978	: Pg=31.48, Qg=36.5 -> Pg=44.45, Qg=8.45
% INFO    : Gen at bus 46978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46979	: Pg=0.4, Qg=21.56 -> Pg=28.55, Qg=0.0
% INFO    : Gen at bus 46979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46981	: Pg=52.0, Qg=17.1 -> Pg=35.36, Qg=0.0
% INFO    : Gen at bus 46981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46983	: Pg=0.3, Qg=19.9 -> Pg=25.35, Qg=0.0
% INFO    : Gen at bus 46983	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46984	: Pg=31.38, Qg=32.6 -> Pg=42.5, Qg=7.15
% INFO    : Gen at bus 46984	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46984	: Pg=31.25, Qg=31.0 -> Pg=40.0, Qg=7.15
% INFO    : Gen at bus 46984	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46984	: Pg=270.49, Qg=152.05 -> Pg=339.5, Qg=31.6
% INFO    : Gen at bus 46984	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46987	: Pg=27.1, Qg=27.3 -> Pg=35.0, Qg=6.3
% INFO    : Gen at bus 46987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46990	: Pg=27.02, Qg=30.5 -> Pg=33.35, Qg=8.45
% INFO    : Gen at bus 46990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46990	: Pg=27.02, Qg=30.5 -> Pg=33.35, Qg=8.45
% INFO    : Gen at bus 46990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46990	: Pg=27.02, Qg=30.5 -> Pg=33.35, Qg=8.45
% INFO    : Gen at bus 46990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46990	: Pg=27.02, Qg=30.5 -> Pg=33.35, Qg=8.45
% INFO    : Gen at bus 46990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46993	: Pg=2.48, Qg=11.8 -> Pg=10.5, Qg=2.725
% INFO    : Gen at bus 46993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46993	: Pg=2.48, Qg=11.8 -> Pg=10.5, Qg=2.725
% INFO    : Gen at bus 46993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46994	: Pg=2.45, Qg=11.15 -> Pg=10.0, Qg=2.575
% INFO    : Gen at bus 46994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46994	: Pg=2.45, Qg=11.15 -> Pg=10.0, Qg=2.575
% INFO    : Gen at bus 46994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46995	: Pg=5.45, Qg=8.7 -> Pg=11.5, Qg=1.35
% INFO    : Gen at bus 46995	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46995	: Pg=5.45, Qg=8.7 -> Pg=11.5, Qg=1.35
% INFO    : Gen at bus 46995	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46996	: Pg=3.17, Qg=3.24 -> Pg=4.91, Qg=1.42
% INFO    : Gen at bus 46996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46996	: Pg=3.17, Qg=3.24 -> Pg=4.91, Qg=1.42
% INFO    : Gen at bus 46996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46996	: Pg=3.17, Qg=3.24 -> Pg=4.91, Qg=1.42
% INFO    : Gen at bus 46996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46996	: Pg=3.17, Qg=3.24 -> Pg=4.91, Qg=1.42
% INFO    : Gen at bus 46996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46996	: Pg=3.17, Qg=3.24 -> Pg=4.91, Qg=1.42
% INFO    : Gen at bus 46996	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46997	: Pg=13.92, Qg=17.1 -> Pg=21.88, Qg=3.45
% INFO    : Gen at bus 46997	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46998	: Pg=27.0, Qg=5.83 -> Pg=27.0, Qg=0.0
% INFO    : Gen at bus 46998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46998	: Pg=31.0, Qg=5.83 -> Pg=31.0, Qg=0.0
% INFO    : Gen at bus 46998	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46999	: Pg=22.67, Qg=5.15 -> Pg=24.3, Qg=2.0
% INFO    : Gen at bus 46999	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 46999	: Pg=22.67, Qg=5.15 -> Pg=24.3, Qg=2.0
% INFO    : Gen at bus 46999	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47000	: Pg=0.89, Qg=1.75 -> Pg=1.725, Qg=0.545
% INFO    : Gen at bus 47000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47000	: Pg=0.89, Qg=1.75 -> Pg=1.725, Qg=0.545
% INFO    : Gen at bus 47000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47000	: Pg=0.89, Qg=1.75 -> Pg=1.725, Qg=0.545
% INFO    : Gen at bus 47000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47000	: Pg=0.89, Qg=1.75 -> Pg=1.725, Qg=0.545
% INFO    : Gen at bus 47000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47000	: Pg=0.89, Qg=1.75 -> Pg=1.725, Qg=0.545
% INFO    : Gen at bus 47000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47000	: Pg=0.89, Qg=1.75 -> Pg=1.725, Qg=0.545
% INFO    : Gen at bus 47000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47000	: Pg=0.89, Qg=1.75 -> Pg=1.725, Qg=0.545
% INFO    : Gen at bus 47000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47000	: Pg=0.89, Qg=1.75 -> Pg=1.725, Qg=0.545
% INFO    : Gen at bus 47000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47000	: Pg=0.89, Qg=1.75 -> Pg=1.725, Qg=0.545
% INFO    : Gen at bus 47000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47000	: Pg=0.89, Qg=1.75 -> Pg=1.725, Qg=0.545
% INFO    : Gen at bus 47000	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47001	: Pg=1.72, Qg=1.77 -> Pg=5.1, Qg=0.0
% INFO    : Gen at bus 47001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47001	: Pg=1.72, Qg=1.77 -> Pg=5.1, Qg=0.0
% INFO    : Gen at bus 47001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47001	: Pg=1.72, Qg=1.77 -> Pg=5.1, Qg=0.0
% INFO    : Gen at bus 47001	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47004	: Pg=11.25, Qg=7.35 -> Pg=7.5, Qg=1.8
% INFO    : Gen at bus 47004	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47004	: Pg=11.25, Qg=7.35 -> Pg=7.5, Qg=1.8
% INFO    : Gen at bus 47004	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47005	: Pg=22.0, Qg=10.7 -> Pg=13.5, Qg=1.7
% INFO    : Gen at bus 47005	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47009	: Pg=0.54, Qg=10.4 -> Pg=10.75, Qg=1.6
% INFO    : Gen at bus 47009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47009	: Pg=0.54, Qg=10.4 -> Pg=10.75, Qg=1.6
% INFO    : Gen at bus 47009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47009	: Pg=0.69, Qg=13.3 -> Pg=13.75, Qg=2.05
% INFO    : Gen at bus 47009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47009	: Pg=0.69, Qg=13.3 -> Pg=13.75, Qg=2.05
% INFO    : Gen at bus 47009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47009	: Pg=0.69, Qg=13.3 -> Pg=13.75, Qg=2.05
% INFO    : Gen at bus 47009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47009	: Pg=0.69, Qg=13.3 -> Pg=13.75, Qg=2.05
% INFO    : Gen at bus 47009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47009	: Pg=0.69, Qg=13.3 -> Pg=13.75, Qg=2.05
% INFO    : Gen at bus 47009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47009	: Pg=0.69, Qg=13.3 -> Pg=13.75, Qg=2.05
% INFO    : Gen at bus 47009	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 47010	: Pg=3.53, Qg=10.3 -> Pg=12.1, Qg=1.6
% INFO    : Gen at bus 47010	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50134	: Pg=1100.0, Qg=164.82 -> Pg=658.85, Qg=95.7
% INFO    : Gen at bus 50134	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50135	: Pg=243.03, Qg=35.88 -> Pg=472.5, Qg=54.35
% INFO    : Gen at bus 50135	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50135	: Pg=237.63, Qg=35.88 -> Pg=469.8, Qg=54.35
% INFO    : Gen at bus 50135	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50135	: Pg=237.63, Qg=35.88 -> Pg=469.8, Qg=54.35
% INFO    : Gen at bus 50135	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50136	: Pg=522.36, Qg=55.43 -> Pg=696.5, Qg=67.4
% INFO    : Gen at bus 50136	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50136	: Pg=442.16, Qg=55.43 -> Pg=555.0, Qg=51.75
% INFO    : Gen at bus 50136	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50137	: Pg=103.73, Qg=-50.34 -> Pg=221.85, Qg=26.35
% INFO    : Gen at bus 50137	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50138	: Pg=26.25, Qg=0.0 -> Pg=37.5, Qg=0.0
% INFO    : Gen at bus 50138	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50138	: Pg=17.94, Qg=0.0 -> Pg=27.25, Qg=0.0
% INFO    : Gen at bus 50138	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50138	: Pg=79.52, Qg=0.0 -> Pg=108.35, Qg=0.0
% INFO    : Gen at bus 50138	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50138	: Pg=79.52, Qg=0.0 -> Pg=108.35, Qg=0.0
% INFO    : Gen at bus 50138	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50139	: Pg=47.35, Qg=23.6 -> Pg=69.5, Qg=0.0
% INFO    : Gen at bus 50139	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50139	: Pg=162.54, Qg=65.4 -> Pg=208.5, Qg=0.0
% INFO    : Gen at bus 50139	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50140	: Pg=0.0, Qg=66.1 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 50140	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50141	: Pg=33.73, Qg=55.98 -> Pg=89.5, Qg=21.3
% INFO    : Gen at bus 50141	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50142	: Pg=0.1, Qg=0.0 -> Pg=74.3, Qg=0.0
% INFO    : Gen at bus 50142	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50143	: Pg=5.6, Qg=-12.25 -> Pg=58.8, Qg=0.0
% INFO    : Gen at bus 50143	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50144	: Pg=0.1, Qg=0.0 -> Pg=50.45, Qg=0.0
% INFO    : Gen at bus 50144	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50145	: Pg=0.0, Qg=9.04 -> Pg=49.5, Qg=0.0
% INFO    : Gen at bus 50145	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50146	: Pg=38.41, Qg=36.33 -> Pg=85.5, Qg=19.5
% INFO    : Gen at bus 50146	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50146	: Pg=67.46, Qg=36.33 -> Pg=81.65, Qg=14.05
% INFO    : Gen at bus 50146	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50146	: Pg=67.46, Qg=36.33 -> Pg=81.65, Qg=14.05
% INFO    : Gen at bus 50146	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50146	: Pg=116.47, Qg=36.33 -> Pg=145.25, Qg=25.55
% INFO    : Gen at bus 50146	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50146	: Pg=94.77, Qg=36.33 -> Pg=237.5, Qg=29.45
% INFO    : Gen at bus 50146	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50147	: Pg=10.0, Qg=35.88 -> Pg=53.0, Qg=0.0
% INFO    : Gen at bus 50147	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50147	: Pg=10.0, Qg=35.88 -> Pg=57.5, Qg=0.0
% INFO    : Gen at bus 50147	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50148	: Pg=32.29, Qg=52.21 -> Pg=60.65, Qg=13.1
% INFO    : Gen at bus 50148	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50148	: Pg=32.29, Qg=52.21 -> Pg=60.65, Qg=13.1
% INFO    : Gen at bus 50148	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50148	: Pg=32.29, Qg=52.21 -> Pg=60.65, Qg=13.1
% INFO    : Gen at bus 50148	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50148	: Pg=32.29, Qg=52.21 -> Pg=60.65, Qg=13.1
% INFO    : Gen at bus 50148	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50149	: Pg=52.25, Qg=30.6 -> Pg=70.0, Qg=12.9
% INFO    : Gen at bus 50149	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50150	: Pg=34.31, Qg=36.93 -> Pg=101.0, Qg=24.65
% INFO    : Gen at bus 50150	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50150	: Pg=16.63, Qg=21.85 -> Pg=29.935, Qg=3.525
% INFO    : Gen at bus 50150	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50150	: Pg=16.63, Qg=21.85 -> Pg=29.935, Qg=3.525
% INFO    : Gen at bus 50150	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50150	: Pg=22.15, Qg=36.93 -> Pg=53.0, Qg=6.5
% INFO    : Gen at bus 50150	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50151	: Pg=12.13, Qg=41.2 -> Pg=47.5, Qg=6.45
% INFO    : Gen at bus 50151	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50152	: Pg=53.76, Qg=62.51 -> Pg=100.0, Qg=21.5
% INFO    : Gen at bus 50152	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50152	: Pg=34.05, Qg=50.8 -> Pg=57.0, Qg=11.75
% INFO    : Gen at bus 50152	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50152	: Pg=12.76, Qg=15.6 -> Pg=20.52, Qg=2.95
% INFO    : Gen at bus 50152	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50152	: Pg=12.76, Qg=15.6 -> Pg=20.52, Qg=2.95
% INFO    : Gen at bus 50152	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50153	: Pg=25.04, Qg=42.54 -> Pg=52.3, Qg=11.7
% INFO    : Gen at bus 50153	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50154	: Pg=58.94, Qg=39.5 -> Pg=106.25, Qg=0.0
% INFO    : Gen at bus 50154	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50154	: Pg=19.65, Qg=16.5 -> Pg=41.85, Qg=0.0
% INFO    : Gen at bus 50154	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50154	: Pg=19.65, Qg=16.5 -> Pg=41.85, Qg=0.0
% INFO    : Gen at bus 50154	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50154	: Pg=37.04, Qg=20.5 -> Pg=58.3, Qg=0.0
% INFO    : Gen at bus 50154	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50155	: Pg=40.43, Qg=43.6 -> Pg=57.75, Qg=8.95
% INFO    : Gen at bus 50155	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50156	: Pg=4.41, Qg=5.63 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 50156	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50156	: Pg=4.89, Qg=5.63 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 50156	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50156	: Pg=8.4, Qg=5.63 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 50156	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50156	: Pg=8.4, Qg=5.63 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 50156	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50156	: Pg=8.4, Qg=5.63 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 50156	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50156	: Pg=8.4, Qg=5.63 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 50156	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50156	: Pg=4.41, Qg=5.63 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 50156	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50156	: Pg=4.41, Qg=5.63 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 50156	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50156	: Pg=4.41, Qg=5.63 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 50156	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50157	: Pg=23.78, Qg=24.14 -> Pg=46.6, Qg=5.4
% INFO    : Gen at bus 50157	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50157	: Pg=23.78, Qg=24.14 -> Pg=46.6, Qg=5.4
% INFO    : Gen at bus 50157	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50157	: Pg=23.81, Qg=24.14 -> Pg=47.2, Qg=5.5
% INFO    : Gen at bus 50157	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50159	: Pg=21.39, Qg=39.7 -> Pg=44.33, Qg=8.35
% INFO    : Gen at bus 50159	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50160	: Pg=14.35, Qg=6.64 -> Pg=33.5, Qg=7.75
% INFO    : Gen at bus 50160	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50160	: Pg=14.35, Qg=6.64 -> Pg=33.5, Qg=7.75
% INFO    : Gen at bus 50160	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50160	: Pg=14.35, Qg=6.64 -> Pg=33.5, Qg=7.75
% INFO    : Gen at bus 50160	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50160	: Pg=14.35, Qg=6.64 -> Pg=33.5, Qg=7.75
% INFO    : Gen at bus 50160	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50160	: Pg=114.29, Qg=6.64 -> Pg=140.7, Qg=24.55
% INFO    : Gen at bus 50160	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50160	: Pg=114.29, Qg=6.64 -> Pg=140.7, Qg=24.55
% INFO    : Gen at bus 50160	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50160	: Pg=114.29, Qg=6.64 -> Pg=140.7, Qg=24.55
% INFO    : Gen at bus 50160	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50161	: Pg=31.25, Qg=12.6 -> Pg=40.05, Qg=0.0
% INFO    : Gen at bus 50161	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50161	: Pg=31.25, Qg=12.6 -> Pg=40.05, Qg=0.0
% INFO    : Gen at bus 50161	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50161	: Pg=31.64, Qg=16.4 -> Pg=47.75, Qg=0.0
% INFO    : Gen at bus 50161	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50162	: Pg=23.19, Qg=23.66 -> Pg=36.5, Qg=7.15
% INFO    : Gen at bus 50162	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50163	: Pg=0.0, Qg=19.8 -> Pg=25.0, Qg=0.0
% INFO    : Gen at bus 50163	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50164	: Pg=10.0, Qg=19.8 -> Pg=30.0, Qg=0.0
% INFO    : Gen at bus 50164	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50165	: Pg=44.86, Qg=59.8 -> Pg=78.0, Qg=16.35
% INFO    : Gen at bus 50165	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50165	: Pg=31.23, Qg=36.8 -> Pg=39.5, Qg=10.25
% INFO    : Gen at bus 50165	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50165	: Pg=145.09, Qg=59.8 -> Pg=269.0, Qg=30.45
% INFO    : Gen at bus 50165	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50166	: Pg=0.0, Qg=6.91 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 50166	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50166	: Pg=0.0, Qg=6.91 -> Pg=50.25, Qg=0.0
% INFO    : Gen at bus 50166	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50167	: Pg=26.86, Qg=70.7 -> Pg=69.0, Qg=16.35
% INFO    : Gen at bus 50167	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50167	: Pg=26.86, Qg=70.7 -> Pg=69.0, Qg=16.35
% INFO    : Gen at bus 50167	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50167	: Pg=23.15, Qg=28.5 -> Pg=34.0, Qg=6.6
% INFO    : Gen at bus 50167	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50167	: Pg=23.88, Qg=46.5 -> Pg=48.5, Qg=10.75
% INFO    : Gen at bus 50167	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50168	: Pg=14.09, Qg=32.8 -> Pg=28.35, Qg=9.1
% INFO    : Gen at bus 50168	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50169	: Pg=10.0, Qg=19.4 -> Pg=24.5, Qg=3.05
% INFO    : Gen at bus 50169	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50170	: Pg=5.49, Qg=6.45 -> Pg=12.3, Qg=0.0
% INFO    : Gen at bus 50170	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50170	: Pg=5.49, Qg=6.45 -> Pg=12.3, Qg=0.0
% INFO    : Gen at bus 50170	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50171	: Pg=22.97, Qg=0.0 -> Pg=30.45, Qg=0.0
% INFO    : Gen at bus 50171	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50172	: Pg=5.66, Qg=16.4 -> Pg=15.75, Qg=3.8
% INFO    : Gen at bus 50172	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50173	: Pg=4.19, Qg=5.7 -> Pg=5.8, Qg=1.585
% INFO    : Gen at bus 50173	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50173	: Pg=4.19, Qg=5.7 -> Pg=5.8, Qg=1.585
% INFO    : Gen at bus 50173	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50173	: Pg=4.19, Qg=5.7 -> Pg=5.8, Qg=1.585
% INFO    : Gen at bus 50173	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50174	: Pg=0.59, Qg=0.0 -> Pg=2.075, Qg=0.0
% INFO    : Gen at bus 50174	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50174	: Pg=0.59, Qg=0.0 -> Pg=2.075, Qg=0.0
% INFO    : Gen at bus 50174	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50174	: Pg=0.59, Qg=0.0 -> Pg=2.075, Qg=0.0
% INFO    : Gen at bus 50174	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50174	: Pg=0.59, Qg=0.0 -> Pg=2.075, Qg=0.0
% INFO    : Gen at bus 50174	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50174	: Pg=0.59, Qg=0.0 -> Pg=2.075, Qg=0.0
% INFO    : Gen at bus 50174	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50174	: Pg=0.59, Qg=0.0 -> Pg=2.075, Qg=0.0
% INFO    : Gen at bus 50174	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50175	: Pg=4.88, Qg=3.88 -> Pg=4.965, Qg=1.08
% INFO    : Gen at bus 50175	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50175	: Pg=4.88, Qg=3.88 -> Pg=4.965, Qg=1.08
% INFO    : Gen at bus 50175	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50175	: Pg=4.88, Qg=3.88 -> Pg=4.965, Qg=1.08
% INFO    : Gen at bus 50175	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50175	: Pg=4.88, Qg=3.88 -> Pg=4.965, Qg=1.08
% INFO    : Gen at bus 50175	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50176	: Pg=1.56, Qg=1.79 -> Pg=2.0, Qg=0.52
% INFO    : Gen at bus 50176	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50176	: Pg=1.56, Qg=1.79 -> Pg=2.0, Qg=0.52
% INFO    : Gen at bus 50176	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50176	: Pg=1.56, Qg=1.79 -> Pg=2.0, Qg=0.52
% INFO    : Gen at bus 50176	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50176	: Pg=1.56, Qg=1.79 -> Pg=2.0, Qg=0.52
% INFO    : Gen at bus 50176	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50176	: Pg=1.56, Qg=1.79 -> Pg=2.0, Qg=0.52
% INFO    : Gen at bus 50176	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50176	: Pg=1.56, Qg=1.79 -> Pg=2.0, Qg=0.52
% INFO    : Gen at bus 50176	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50176	: Pg=1.56, Qg=1.79 -> Pg=2.0, Qg=0.52
% INFO    : Gen at bus 50176	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50176	: Pg=1.56, Qg=1.79 -> Pg=2.0, Qg=0.52
% INFO    : Gen at bus 50176	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50177	: Pg=0.98, Qg=0.47 -> Pg=1.15, Qg=0.415
% INFO    : Gen at bus 50177	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50177	: Pg=0.98, Qg=0.47 -> Pg=1.15, Qg=0.415
% INFO    : Gen at bus 50177	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50177	: Pg=0.98, Qg=0.47 -> Pg=1.15, Qg=0.415
% INFO    : Gen at bus 50177	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50177	: Pg=0.98, Qg=0.47 -> Pg=1.15, Qg=0.415
% INFO    : Gen at bus 50177	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50177	: Pg=0.98, Qg=0.47 -> Pg=1.15, Qg=0.415
% INFO    : Gen at bus 50177	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50177	: Pg=0.98, Qg=0.47 -> Pg=1.15, Qg=0.415
% INFO    : Gen at bus 50177	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50177	: Pg=0.98, Qg=0.47 -> Pg=1.15, Qg=0.415
% INFO    : Gen at bus 50177	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50177	: Pg=0.98, Qg=0.47 -> Pg=1.15, Qg=0.415
% INFO    : Gen at bus 50177	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50177	: Pg=0.98, Qg=0.47 -> Pg=1.15, Qg=0.415
% INFO    : Gen at bus 50177	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50177	: Pg=0.98, Qg=0.47 -> Pg=1.15, Qg=0.415
% INFO    : Gen at bus 50177	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50178	: Pg=4.5, Qg=12.4 -> Pg=12.0, Qg=2.85
% INFO    : Gen at bus 50178	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50179	: Pg=3.5, Qg=9.7 -> Pg=11.5, Qg=1.5
% INFO    : Gen at bus 50179	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50180	: Pg=510.15, Qg=-5.51 -> Pg=549.9, Qg=45.65
% INFO    : Gen at bus 50180	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50180	: Pg=300.15, Qg=-5.51 -> Pg=444.9, Qg=45.65
% INFO    : Gen at bus 50180	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50181	: Pg=211.27, Qg=12.91 -> Pg=325.0, Qg=33.95
% INFO    : Gen at bus 50181	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50182	: Pg=210.89, Qg=-9.35 -> Pg=317.45, Qg=32.8
% INFO    : Gen at bus 50182	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50182	: Pg=210.89, Qg=-9.35 -> Pg=317.45, Qg=32.8
% INFO    : Gen at bus 50182	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50183	: Pg=203.44, Qg=-20.06 -> Pg=227.0, Qg=19.4
% INFO    : Gen at bus 50183	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50183	: Pg=391.95, Qg=-20.06 -> Pg=428.5, Qg=36.0
% INFO    : Gen at bus 50183	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50184	: Pg=115.41, Qg=25.53 -> Pg=163.0, Qg=30.95
% INFO    : Gen at bus 50184	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50184	: Pg=231.02, Qg=25.53 -> Pg=330.0, Qg=33.2
% INFO    : Gen at bus 50184	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50185	: Pg=94.76, Qg=-5.27 -> Pg=140.1, Qg=0.0
% INFO    : Gen at bus 50185	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50186	: Pg=0.0, Qg=47.7 -> Pg=90.0, Qg=13.6
% INFO    : Gen at bus 50186	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50187	: Pg=5.9, Qg=53.0 -> Pg=82.45, Qg=0.0
% INFO    : Gen at bus 50187	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50188	: Pg=0.0, Qg=65.7 -> Pg=74.5, Qg=0.0
% INFO    : Gen at bus 50188	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50189	: Pg=7.4, Qg=37.09 -> Pg=77.95, Qg=0.0
% INFO    : Gen at bus 50189	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50190	: Pg=6.0, Qg=39.12 -> Pg=63.0, Qg=0.0
% INFO    : Gen at bus 50190	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50191	: Pg=0.0, Qg=50.9 -> Pg=57.75, Qg=0.0
% INFO    : Gen at bus 50191	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50192	: Pg=2.88, Qg=19.05 -> Pg=57.5, Qg=0.0
% INFO    : Gen at bus 50192	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50192	: Pg=2.88, Qg=19.05 -> Pg=57.5, Qg=0.0
% INFO    : Gen at bus 50192	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50192	: Pg=3.21, Qg=19.05 -> Pg=64.0, Qg=0.0
% INFO    : Gen at bus 50192	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50192	: Pg=3.21, Qg=19.05 -> Pg=64.0, Qg=0.0
% INFO    : Gen at bus 50192	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50192	: Pg=3.21, Qg=19.05 -> Pg=64.0, Qg=0.0
% INFO    : Gen at bus 50192	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50193	: Pg=5.1, Qg=34.2 -> Pg=53.75, Qg=0.0
% INFO    : Gen at bus 50193	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50194	: Pg=3.1, Qg=24.7 -> Pg=32.75, Qg=0.0
% INFO    : Gen at bus 50194	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50195	: Pg=3.1, Qg=24.3 -> Pg=32.3, Qg=0.0
% INFO    : Gen at bus 50195	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50196	: Pg=2.4, Qg=-0.27 -> Pg=25.2, Qg=0.0
% INFO    : Gen at bus 50196	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50196	: Pg=2.5, Qg=-0.27 -> Pg=26.55, Qg=0.0
% INFO    : Gen at bus 50196	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50197	: Pg=0.1, Qg=19.6 -> Pg=24.8, Qg=0.0
% INFO    : Gen at bus 50197	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50198	: Pg=2.5, Qg=6.04 -> Pg=26.0, Qg=0.0
% INFO    : Gen at bus 50198	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50199	: Pg=0.1, Qg=18.69 -> Pg=24.05, Qg=0.0
% INFO    : Gen at bus 50199	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50200	: Pg=2.0, Qg=16.0 -> Pg=21.25, Qg=0.0
% INFO    : Gen at bus 50200	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50201	: Pg=0.1, Qg=16.0 -> Pg=20.3, Qg=0.0
% INFO    : Gen at bus 50201	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50203	: Pg=0.3, Qg=14.5 -> Pg=18.55, Qg=0.0
% INFO    : Gen at bus 50203	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50204	: Pg=2.5, Qg=3.58 -> Pg=17.0, Qg=0.0
% INFO    : Gen at bus 50204	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50205	: Pg=8.6, Qg=11.7 -> Pg=16.05, Qg=1.85
% INFO    : Gen at bus 50205	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50205	: Pg=8.6, Qg=11.7 -> Pg=16.05, Qg=1.85
% INFO    : Gen at bus 50205	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50206	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50207	: Pg=313.66, Qg=-70.56 -> Pg=340.65, Qg=51.45
% INFO    : Gen at bus 50207	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50207	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50208	: Pg=338.48, Qg=103.45 -> Pg=529.0, Qg=55.7
% INFO    : Gen at bus 50208	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50208	: Pg=216.32, Qg=103.45 -> Pg=425.8, Qg=49.2
% INFO    : Gen at bus 50208	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50209	: Pg=494.0, Qg=164.25 -> Pg=488.0, Qg=71.9
% INFO    : Gen at bus 50209	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50210	: Pg=121.32, Qg=48.99 -> Pg=144.75, Qg=24.7
% INFO    : Gen at bus 50210	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50210	: Pg=115.32, Qg=48.99 -> Pg=141.75, Qg=24.7
% INFO    : Gen at bus 50210	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50211	: Pg=108.77, Qg=12.03 -> Pg=74.9, Qg=8.3
% INFO    : Gen at bus 50211	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50212	: Pg=11.0, Qg=32.0 -> Pg=41.0, Qg=0.0
% INFO    : Gen at bus 50212	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50215	: Pg=57.41, Qg=38.24 -> Pg=95.0, Qg=19.5
% INFO    : Gen at bus 50215	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50215	: Pg=65.45, Qg=38.24 -> Pg=138.8, Qg=31.2
% INFO    : Gen at bus 50215	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50215	: Pg=37.72, Qg=38.24 -> Pg=71.9, Qg=15.55
% INFO    : Gen at bus 50215	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50215	: Pg=37.72, Qg=38.24 -> Pg=71.9, Qg=15.55
% INFO    : Gen at bus 50215	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50215	: Pg=36.84, Qg=38.24 -> Pg=54.25, Qg=15.3
% INFO    : Gen at bus 50215	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50216	: Pg=34.14, Qg=35.1 -> Pg=41.2, Qg=5.5
% INFO    : Gen at bus 50216	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50216	: Pg=52.39, Qg=71.6 -> Pg=72.7, Qg=19.9
% INFO    : Gen at bus 50216	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50216	: Pg=44.98, Qg=71.6 -> Pg=57.7, Qg=19.9
% INFO    : Gen at bus 50216	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50217	: Pg=1.79, Qg=44.2 -> Pg=35.7, Qg=10.2
% INFO    : Gen at bus 50217	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50219	: Pg=29.89, Qg=9.24 -> Pg=34.2, Qg=9.1
% INFO    : Gen at bus 50219	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50219	: Pg=17.03, Qg=9.24 -> Pg=34.2, Qg=9.1
% INFO    : Gen at bus 50219	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50219	: Pg=23.36, Qg=9.24 -> Pg=38.2, Qg=7.8
% INFO    : Gen at bus 50219	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50219	: Pg=5.62, Qg=9.24 -> Pg=14.95, Qg=3.55
% INFO    : Gen at bus 50219	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50220	: Pg=10.71, Qg=13.7 -> Pg=19.1, Qg=2.15
% INFO    : Gen at bus 50220	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50220	: Pg=21.52, Qg=37.5 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 50220	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50220	: Pg=21.52, Qg=37.5 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 50220	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50220	: Pg=21.52, Qg=37.5 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 50220	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50221	: Pg=0.0, Qg=23.7 -> Pg=30.0, Qg=0.0
% INFO    : Gen at bus 50221	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50223	: Pg=50.35, Qg=32.41 -> Pg=59.95, Qg=17.15
% INFO    : Gen at bus 50223	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50223	: Pg=26.73, Qg=27.5 -> Pg=28.35, Qg=4.3
% INFO    : Gen at bus 50223	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50223	: Pg=2.8, Qg=32.41 -> Pg=54.4, Qg=15.55
% INFO    : Gen at bus 50223	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50224	: Pg=1.42, Qg=27.5 -> Pg=28.35, Qg=4.3
% INFO    : Gen at bus 50224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50225	: Pg=23.39, Qg=26.8 -> Pg=38.7, Qg=4.15
% INFO    : Gen at bus 50225	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50225	: Pg=23.39, Qg=26.8 -> Pg=38.7, Qg=4.15
% INFO    : Gen at bus 50225	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50225	: Pg=31.48, Qg=36.5 -> Pg=44.45, Qg=8.45
% INFO    : Gen at bus 50225	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50225	: Pg=25.48, Qg=36.5 -> Pg=41.45, Qg=8.45
% INFO    : Gen at bus 50225	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50225	: Pg=56.64, Qg=65.4 -> Pg=79.8, Qg=15.1
% INFO    : Gen at bus 50225	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50226	: Pg=5.0, Qg=14.74 -> Pg=27.5, Qg=0.0
% INFO    : Gen at bus 50226	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50227	: Pg=11.17, Qg=5.0 -> Pg=7.6, Qg=0.0
% INFO    : Gen at bus 50227	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50227	: Pg=7.17, Qg=5.0 -> Pg=7.6, Qg=0.0
% INFO    : Gen at bus 50227	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50227	: Pg=7.17, Qg=5.0 -> Pg=7.6, Qg=0.0
% INFO    : Gen at bus 50227	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50228	: Pg=0.33, Qg=6.35 -> Pg=6.55, Qg=1.0
% INFO    : Gen at bus 50228	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50228	: Pg=0.33, Qg=6.35 -> Pg=6.55, Qg=1.0
% INFO    : Gen at bus 50228	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50230	: Pg=3.09, Qg=10.36 -> Pg=12.75, Qg=1.7
% INFO    : Gen at bus 50230	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50231	: Pg=21.0, Qg=19.4 -> Pg=30.0, Qg=3.05
% INFO    : Gen at bus 50231	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50231	: Pg=32.29, Qg=44.3 -> Pg=60.75, Qg=6.9
% INFO    : Gen at bus 50231	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50231	: Pg=6.55, Qg=13.6 -> Pg=14.0, Qg=3.15
% INFO    : Gen at bus 50231	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50232	: Pg=5.55, Qg=10.7 -> Pg=13.5, Qg=1.7
% INFO    : Gen at bus 50232	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50233	: Pg=8.5, Qg=13.6 -> Pg=14.5, Qg=3.15
% INFO    : Gen at bus 50233	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50234	: Pg=2.72, Qg=2.05 -> Pg=1.36, Qg=0.57
% INFO    : Gen at bus 50234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50234	: Pg=2.72, Qg=2.05 -> Pg=1.36, Qg=0.57
% INFO    : Gen at bus 50234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50234	: Pg=2.72, Qg=2.05 -> Pg=1.36, Qg=0.57
% INFO    : Gen at bus 50234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50234	: Pg=2.72, Qg=2.05 -> Pg=1.36, Qg=0.57
% INFO    : Gen at bus 50234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50234	: Pg=2.72, Qg=2.05 -> Pg=1.36, Qg=0.57
% INFO    : Gen at bus 50234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50234	: Pg=2.72, Qg=2.05 -> Pg=1.36, Qg=0.57
% INFO    : Gen at bus 50234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50234	: Pg=2.72, Qg=2.05 -> Pg=1.36, Qg=0.57
% INFO    : Gen at bus 50234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50234	: Pg=2.72, Qg=2.05 -> Pg=1.36, Qg=0.57
% INFO    : Gen at bus 50234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50235	: Pg=2.27, Qg=5.25 -> Pg=6.4, Qg=0.825
% INFO    : Gen at bus 50235	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50235	: Pg=2.27, Qg=5.25 -> Pg=6.4, Qg=0.825
% INFO    : Gen at bus 50235	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50236	: Pg=2.27, Qg=5.25 -> Pg=6.4, Qg=0.825
% INFO    : Gen at bus 50236	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50236	: Pg=2.27, Qg=5.25 -> Pg=6.4, Qg=0.825
% INFO    : Gen at bus 50236	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50237	: Pg=2.09, Qg=2.12 -> Pg=2.71, Qg=0.495
% INFO    : Gen at bus 50237	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50237	: Pg=2.09, Qg=2.12 -> Pg=2.71, Qg=0.495
% INFO    : Gen at bus 50237	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50237	: Pg=2.09, Qg=2.12 -> Pg=2.71, Qg=0.495
% INFO    : Gen at bus 50237	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50237	: Pg=2.09, Qg=2.12 -> Pg=2.71, Qg=0.495
% INFO    : Gen at bus 50237	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50237	: Pg=2.09, Qg=2.12 -> Pg=2.71, Qg=0.495
% INFO    : Gen at bus 50237	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50237	: Pg=2.09, Qg=2.12 -> Pg=2.71, Qg=0.495
% INFO    : Gen at bus 50237	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50238	: Pg=81.57, Qg=42.07 -> Pg=108.125, Qg=20.15
% INFO    : Gen at bus 50238	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50238	: Pg=269.71, Qg=42.07 -> Pg=386.0, Qg=43.15
% INFO    : Gen at bus 50238	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50238	: Pg=269.71, Qg=42.07 -> Pg=386.0, Qg=43.15
% INFO    : Gen at bus 50238	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50238	: Pg=269.71, Qg=42.07 -> Pg=386.0, Qg=43.15
% INFO    : Gen at bus 50238	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50239	: Pg=214.25, Qg=232.55 -> Pg=384.5, Qg=42.95
% INFO    : Gen at bus 50239	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50239	: Pg=214.25, Qg=232.55 -> Pg=384.5, Qg=42.95
% INFO    : Gen at bus 50239	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50240	: Pg=214.88, Qg=33.41 -> Pg=397.0, Qg=44.85
% INFO    : Gen at bus 50240	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50240	: Pg=168.52, Qg=33.41 -> Pg=347.5, Qg=40.75
% INFO    : Gen at bus 50240	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50241	: Pg=144.26, Qg=66.82 -> Pg=155.0, Qg=24.35
% INFO    : Gen at bus 50241	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50241	: Pg=99.47, Qg=66.82 -> Pg=136.75, Qg=25.55
% INFO    : Gen at bus 50241	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50241	: Pg=99.47, Qg=66.82 -> Pg=136.75, Qg=25.55
% INFO    : Gen at bus 50241	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50241	: Pg=216.85, Qg=66.82 -> Pg=339.0, Qg=35.7
% INFO    : Gen at bus 50241	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50241	: Pg=216.85, Qg=66.82 -> Pg=339.0, Qg=35.7
% INFO    : Gen at bus 50241	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50241	: Pg=171.85, Qg=66.82 -> Pg=316.5, Qg=35.7
% INFO    : Gen at bus 50241	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50242	: Pg=210.3, Qg=86.31 -> Pg=313.0, Qg=63.85
% INFO    : Gen at bus 50242	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50243	: Pg=153.99, Qg=82.29 -> Pg=154.75, Qg=22.8
% INFO    : Gen at bus 50243	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50243	: Pg=153.99, Qg=82.29 -> Pg=154.75, Qg=22.8
% INFO    : Gen at bus 50243	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50243	: Pg=153.99, Qg=82.29 -> Pg=154.75, Qg=22.8
% INFO    : Gen at bus 50243	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50243	: Pg=153.99, Qg=82.29 -> Pg=154.75, Qg=22.8
% INFO    : Gen at bus 50243	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50243	: Pg=94.49, Qg=82.29 -> Pg=144.2, Qg=28.5
% INFO    : Gen at bus 50243	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50243	: Pg=94.49, Qg=82.29 -> Pg=144.2, Qg=28.5
% INFO    : Gen at bus 50243	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50243	: Pg=94.49, Qg=82.29 -> Pg=144.2, Qg=28.5
% INFO    : Gen at bus 50243	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50243	: Pg=94.49, Qg=82.29 -> Pg=144.2, Qg=28.5
% INFO    : Gen at bus 50243	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50244	: Pg=74.61, Qg=41.67 -> Pg=126.95, Qg=13.9
% INFO    : Gen at bus 50244	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50244	: Pg=74.61, Qg=41.67 -> Pg=126.95, Qg=13.9
% INFO    : Gen at bus 50244	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50244	: Pg=74.61, Qg=41.67 -> Pg=126.95, Qg=13.9
% INFO    : Gen at bus 50244	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50244	: Pg=74.61, Qg=41.67 -> Pg=126.95, Qg=13.9
% INFO    : Gen at bus 50244	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50244	: Pg=100.89, Qg=41.67 -> Pg=193.6, Qg=23.95
% INFO    : Gen at bus 50244	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50244	: Pg=92.78, Qg=41.67 -> Pg=176.1, Qg=23.95
% INFO    : Gen at bus 50244	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50245	: Pg=129.49, Qg=81.84 -> Pg=152.15, Qg=25.65
% INFO    : Gen at bus 50245	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50245	: Pg=129.49, Qg=81.84 -> Pg=152.15, Qg=25.65
% INFO    : Gen at bus 50245	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50245	: Pg=129.49, Qg=81.84 -> Pg=152.15, Qg=25.65
% INFO    : Gen at bus 50245	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50245	: Pg=75.06, Qg=75.6 -> Pg=97.0, Qg=17.45
% INFO    : Gen at bus 50245	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50245	: Pg=75.06, Qg=75.6 -> Pg=97.0, Qg=17.45
% INFO    : Gen at bus 50245	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50245	: Pg=75.06, Qg=75.6 -> Pg=97.0, Qg=17.45
% INFO    : Gen at bus 50245	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50246	: Pg=98.02, Qg=109.4 -> Pg=135.1, Qg=25.25
% INFO    : Gen at bus 50246	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50246	: Pg=98.02, Qg=109.4 -> Pg=135.1, Qg=25.25
% INFO    : Gen at bus 50246	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50246	: Pg=94.11, Qg=122.8 -> Pg=143.62, Qg=28.4
% INFO    : Gen at bus 50246	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50247	: Pg=104.41, Qg=80.28 -> Pg=138.0, Qg=25.2
% INFO    : Gen at bus 50247	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50247	: Pg=104.41, Qg=80.28 -> Pg=138.0, Qg=25.2
% INFO    : Gen at bus 50247	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50247	: Pg=54.58, Qg=80.28 -> Pg=116.4, Qg=26.2
% INFO    : Gen at bus 50247	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50248	: Pg=114.41, Qg=83.58 -> Pg=143.0, Qg=25.2
% INFO    : Gen at bus 50248	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50248	: Pg=114.41, Qg=83.58 -> Pg=143.0, Qg=25.2
% INFO    : Gen at bus 50248	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50248	: Pg=114.41, Qg=83.58 -> Pg=143.0, Qg=25.2
% INFO    : Gen at bus 50248	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50248	: Pg=114.41, Qg=83.58 -> Pg=143.0, Qg=25.2
% INFO    : Gen at bus 50248	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50248	: Pg=66.39, Qg=83.58 -> Pg=157.5, Qg=36.5
% INFO    : Gen at bus 50248	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50248	: Pg=66.39, Qg=83.58 -> Pg=157.5, Qg=36.5
% INFO    : Gen at bus 50248	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50249	: Pg=84.38, Qg=69.26 -> Pg=127.5, Qg=13.25
% INFO    : Gen at bus 50249	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50249	: Pg=84.38, Qg=69.26 -> Pg=127.5, Qg=13.25
% INFO    : Gen at bus 50249	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50250	: Pg=1.0, Qg=38.32 -> Pg=76.4, Qg=0.0
% INFO    : Gen at bus 50250	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50252	: Pg=109.39, Qg=32.02 -> Pg=61.5, Qg=0.0
% INFO    : Gen at bus 50252	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50254	: Pg=0.1, Qg=35.95 -> Pg=50.65, Qg=0.0
% INFO    : Gen at bus 50254	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50255	: Pg=0.0, Qg=43.7 -> Pg=49.6, Qg=0.0
% INFO    : Gen at bus 50255	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50256	: Pg=1.0, Qg=43.7 -> Pg=50.0, Qg=0.0
% INFO    : Gen at bus 50256	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50257	: Pg=99.2, Qg=24.76 -> Pg=52.1, Qg=0.0
% INFO    : Gen at bus 50257	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50257	: Pg=98.9, Qg=24.76 -> Pg=51.9, Qg=0.0
% INFO    : Gen at bus 50257	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50258	: Pg=23.26, Qg=105.4 -> Pg=94.5, Qg=24.35
% INFO    : Gen at bus 50258	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50258	: Pg=23.26, Qg=105.4 -> Pg=94.5, Qg=24.35
% INFO    : Gen at bus 50258	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50258	: Pg=29.45, Qg=54.6 -> Pg=61.035, Qg=11.45
% INFO    : Gen at bus 50258	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50260	: Pg=15.1, Qg=12.86 -> Pg=48.5, Qg=0.0
% INFO    : Gen at bus 50260	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50260	: Pg=15.1, Qg=12.86 -> Pg=48.5, Qg=0.0
% INFO    : Gen at bus 50260	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50260	: Pg=53.17, Qg=12.86 -> Pg=68.75, Qg=12.4
% INFO    : Gen at bus 50260	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50260	: Pg=53.17, Qg=12.86 -> Pg=68.75, Qg=12.4
% INFO    : Gen at bus 50260	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50260	: Pg=42.89, Qg=12.86 -> Pg=175.0, Qg=23.8
% INFO    : Gen at bus 50260	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50261	: Pg=147.85, Qg=86.64 -> Pg=304.5, Qg=35.7
% INFO    : Gen at bus 50261	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50261	: Pg=86.85, Qg=86.64 -> Pg=274.0, Qg=35.7
% INFO    : Gen at bus 50261	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50261	: Pg=44.17, Qg=53.6 -> Pg=64.25, Qg=12.4
% INFO    : Gen at bus 50261	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50261	: Pg=44.17, Qg=53.6 -> Pg=64.25, Qg=12.4
% INFO    : Gen at bus 50261	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50262	: Pg=32.13, Qg=41.2 -> Pg=57.5, Qg=6.45
% INFO    : Gen at bus 50262	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50262	: Pg=32.13, Qg=41.2 -> Pg=57.5, Qg=6.45
% INFO    : Gen at bus 50262	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50262	: Pg=37.01, Qg=58.1 -> Pg=77.0, Qg=9.05
% INFO    : Gen at bus 50262	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50264	: Pg=16.13, Qg=8.44 -> Pg=30.0, Qg=6.45
% INFO    : Gen at bus 50264	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50264	: Pg=16.13, Qg=8.44 -> Pg=30.0, Qg=6.45
% INFO    : Gen at bus 50264	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50264	: Pg=16.13, Qg=8.44 -> Pg=30.0, Qg=6.45
% INFO    : Gen at bus 50264	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50264	: Pg=9.71, Qg=8.44 -> Pg=18.6, Qg=3.65
% INFO    : Gen at bus 50264	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50264	: Pg=9.71, Qg=8.44 -> Pg=18.6, Qg=3.65
% INFO    : Gen at bus 50264	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50264	: Pg=9.71, Qg=8.44 -> Pg=18.6, Qg=3.65
% INFO    : Gen at bus 50264	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50264	: Pg=16.25, Qg=8.44 -> Pg=32.5, Qg=7.15
% INFO    : Gen at bus 50264	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50265	: Pg=47.12, Qg=52.4 -> Pg=64.75, Qg=12.1
% INFO    : Gen at bus 50265	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50265	: Pg=47.12, Qg=52.4 -> Pg=64.75, Qg=12.1
% INFO    : Gen at bus 50265	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50265	: Pg=47.12, Qg=52.4 -> Pg=64.75, Qg=12.1
% INFO    : Gen at bus 50265	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50265	: Pg=47.12, Qg=52.4 -> Pg=64.75, Qg=12.1
% INFO    : Gen at bus 50265	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50266	: Pg=34.52, Qg=29.3 -> Pg=46.75, Qg=4.55
% INFO    : Gen at bus 50266	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50266	: Pg=6.2, Qg=29.7 -> Pg=26.5, Qg=6.85
% INFO    : Gen at bus 50266	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50266	: Pg=34.35, Qg=33.5 -> Pg=43.5, Qg=7.75
% INFO    : Gen at bus 50266	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50266	: Pg=36.35, Qg=45.7 -> Pg=54.15, Qg=10.55
% INFO    : Gen at bus 50266	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50267	: Pg=45.35, Qg=24.2 -> Pg=47.0, Qg=3.8
% INFO    : Gen at bus 50267	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50267	: Pg=69.14, Qg=35.1 -> Pg=69.9, Qg=5.45
% INFO    : Gen at bus 50267	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50270	: Pg=5.1, Qg=10.11 -> Pg=28.05, Qg=0.0
% INFO    : Gen at bus 50270	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50270	: Pg=5.1, Qg=10.11 -> Pg=28.05, Qg=0.0
% INFO    : Gen at bus 50270	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50271	: Pg=50.0, Qg=16.4 -> Pg=34.0, Qg=0.0
% INFO    : Gen at bus 50271	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50271	: Pg=50.0, Qg=16.4 -> Pg=34.0, Qg=0.0
% INFO    : Gen at bus 50271	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50272	: Pg=33.13, Qg=14.0 -> Pg=77.5, Qg=17.9
% INFO    : Gen at bus 50272	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50272	: Pg=33.38, Qg=14.0 -> Pg=82.5, Qg=19.35
% INFO    : Gen at bus 50272	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50272	: Pg=21.13, Qg=14.0 -> Pg=32.5, Qg=6.45
% INFO    : Gen at bus 50272	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50273	: Pg=16.13, Qg=27.9 -> Pg=30.0, Qg=6.45
% INFO    : Gen at bus 50273	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50273	: Pg=16.13, Qg=27.9 -> Pg=30.0, Qg=6.45
% INFO    : Gen at bus 50273	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50274	: Pg=4.28, Qg=3.67 -> Pg=7.6, Qg=0.0
% INFO    : Gen at bus 50274	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50274	: Pg=4.28, Qg=3.67 -> Pg=7.6, Qg=0.0
% INFO    : Gen at bus 50274	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50274	: Pg=4.28, Qg=3.67 -> Pg=7.6, Qg=0.0
% INFO    : Gen at bus 50274	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50274	: Pg=4.28, Qg=3.67 -> Pg=7.6, Qg=0.0
% INFO    : Gen at bus 50274	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50275	: Pg=26.08, Qg=15.26 -> Pg=34.1, Qg=3.25
% INFO    : Gen at bus 50275	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50275	: Pg=26.08, Qg=15.26 -> Pg=34.1, Qg=3.25
% INFO    : Gen at bus 50275	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50275	: Pg=26.08, Qg=15.26 -> Pg=34.1, Qg=3.25
% INFO    : Gen at bus 50275	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50275	: Pg=26.08, Qg=15.26 -> Pg=34.1, Qg=3.25
% INFO    : Gen at bus 50275	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50275	: Pg=26.08, Qg=15.26 -> Pg=34.1, Qg=3.25
% INFO    : Gen at bus 50275	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50275	: Pg=26.08, Qg=15.26 -> Pg=34.1, Qg=3.25
% INFO    : Gen at bus 50275	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50276	: Pg=43.33, Qg=64.4 -> Pg=86.5, Qg=10.05
% INFO    : Gen at bus 50276	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50276	: Pg=66.34, Qg=122.5 -> Pg=156.5, Qg=19.1
% INFO    : Gen at bus 50276	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50276	: Pg=33.06, Qg=19.9 -> Pg=36.5, Qg=3.1
% INFO    : Gen at bus 50276	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50276	: Pg=27.03, Qg=19.9 -> Pg=33.5, Qg=3.1
% INFO    : Gen at bus 50276	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50276	: Pg=21.58, Qg=30.5 -> Pg=41.5, Qg=4.75
% INFO    : Gen at bus 50276	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50276	: Pg=22.05, Qg=39.7 -> Pg=51.0, Qg=6.2
% INFO    : Gen at bus 50276	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50277	: Pg=7.4, Qg=16.0 -> Pg=23.95, Qg=0.0
% INFO    : Gen at bus 50277	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50277	: Pg=7.4, Qg=47.0 -> Pg=56.95, Qg=0.0
% INFO    : Gen at bus 50277	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50278	: Pg=9.22, Qg=6.4 -> Pg=13.75, Qg=0.0
% INFO    : Gen at bus 50278	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50278	: Pg=9.22, Qg=6.4 -> Pg=13.75, Qg=0.0
% INFO    : Gen at bus 50278	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50280	: Pg=25.88, Qg=11.5 -> Pg=30.0, Qg=0.0
% INFO    : Gen at bus 50280	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50280	: Pg=25.88, Qg=11.5 -> Pg=30.0, Qg=0.0
% INFO    : Gen at bus 50280	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50281	: Pg=18.8, Qg=5.75 -> Pg=25.05, Qg=0.0
% INFO    : Gen at bus 50281	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50281	: Pg=18.8, Qg=5.75 -> Pg=25.05, Qg=0.0
% INFO    : Gen at bus 50281	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50281	: Pg=18.8, Qg=5.75 -> Pg=25.05, Qg=0.0
% INFO    : Gen at bus 50281	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50281	: Pg=18.8, Qg=5.75 -> Pg=25.05, Qg=2.4
% INFO    : Gen at bus 50281	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50282	: Pg=14.12, Qg=9.9 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 50282	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50282	: Pg=14.12, Qg=9.9 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 50282	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50282	: Pg=14.12, Qg=9.9 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 50282	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50283	: Pg=10.69, Qg=9.0 -> Pg=18.75, Qg=0.0
% INFO    : Gen at bus 50283	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50283	: Pg=10.69, Qg=9.0 -> Pg=18.75, Qg=0.0
% INFO    : Gen at bus 50283	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50283	: Pg=10.69, Qg=9.0 -> Pg=18.75, Qg=0.0
% INFO    : Gen at bus 50283	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50283	: Pg=10.69, Qg=9.0 -> Pg=18.75, Qg=0.0
% INFO    : Gen at bus 50283	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50284	: Pg=64.08, Qg=78.9 -> Pg=111.5, Qg=12.3
% INFO    : Gen at bus 50284	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50284	: Pg=80.51, Qg=106.6 -> Pg=147.5, Qg=16.65
% INFO    : Gen at bus 50284	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50284	: Pg=45.52, Qg=29.3 -> Pg=52.25, Qg=4.55
% INFO    : Gen at bus 50284	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50284	: Pg=45.52, Qg=29.3 -> Pg=52.25, Qg=4.55
% INFO    : Gen at bus 50284	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50284	: Pg=7.98, Qg=13.1 -> Pg=17.15, Qg=2.05
% INFO    : Gen at bus 50284	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50284	: Pg=91.09, Qg=214.6 -> Pg=261.5, Qg=33.45
% INFO    : Gen at bus 50284	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50285	: Pg=11.8, Qg=18.8 -> Pg=14.0, Qg=5.25
% INFO    : Gen at bus 50285	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50285	: Pg=20.97, Qg=30.69 -> Pg=24.75, Qg=9.3
% INFO    : Gen at bus 50285	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50285	: Pg=20.97, Qg=30.69 -> Pg=24.75, Qg=9.3
% INFO    : Gen at bus 50285	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50286	: Pg=1.44, Qg=1.68 -> Pg=1.81, Qg=0.465
% INFO    : Gen at bus 50286	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50286	: Pg=1.44, Qg=1.68 -> Pg=1.81, Qg=0.465
% INFO    : Gen at bus 50286	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50286	: Pg=1.44, Qg=1.68 -> Pg=1.81, Qg=0.465
% INFO    : Gen at bus 50286	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50286	: Pg=1.44, Qg=1.68 -> Pg=1.81, Qg=0.465
% INFO    : Gen at bus 50286	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50286	: Pg=1.44, Qg=1.68 -> Pg=1.81, Qg=0.465
% INFO    : Gen at bus 50286	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50286	: Pg=1.44, Qg=1.68 -> Pg=1.81, Qg=0.465
% INFO    : Gen at bus 50286	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50286	: Pg=1.44, Qg=1.68 -> Pg=1.81, Qg=0.465
% INFO    : Gen at bus 50286	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50286	: Pg=1.44, Qg=1.68 -> Pg=1.81, Qg=0.465
% INFO    : Gen at bus 50286	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50286	: Pg=1.44, Qg=1.68 -> Pg=1.81, Qg=0.465
% INFO    : Gen at bus 50286	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50286	: Pg=1.44, Qg=1.68 -> Pg=1.81, Qg=0.465
% INFO    : Gen at bus 50286	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50286	: Pg=1.44, Qg=1.68 -> Pg=1.81, Qg=0.465
% INFO    : Gen at bus 50286	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50287	: Pg=0.58, Qg=11.1 -> Pg=11.5, Qg=1.7
% INFO    : Gen at bus 50287	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50287	: Pg=84.2, Qg=103.86 -> Pg=318.5, Qg=42.8
% INFO    : Gen at bus 50287	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50287	: Pg=84.2, Qg=103.86 -> Pg=318.5, Qg=42.8
% INFO    : Gen at bus 50287	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50287	: Pg=84.2, Qg=103.86 -> Pg=318.5, Qg=42.8
% INFO    : Gen at bus 50287	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50288	: Pg=5.53, Qg=7.7 -> Pg=8.3, Qg=1.95
% INFO    : Gen at bus 50288	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50288	: Pg=5.53, Qg=7.7 -> Pg=8.3, Qg=1.95
% INFO    : Gen at bus 50288	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50290	: Pg=9.43, Qg=6.6 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 50290	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50290	: Pg=9.43, Qg=6.6 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 50290	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50290	: Pg=12.07, Qg=8.4 -> Pg=16.3, Qg=0.0
% INFO    : Gen at bus 50290	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50291	: Pg=161.42, Qg=33.0 -> Pg=303.0, Qg=34.45
% INFO    : Gen at bus 50291	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50292	: Pg=0.0, Qg=61.63 -> Pg=105.0, Qg=15.85
% INFO    : Gen at bus 50292	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50293	: Pg=109.13, Qg=58.0 -> Pg=82.35, Qg=9.05
% INFO    : Gen at bus 50293	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50293	: Pg=56.44, Qg=58.0 -> Pg=82.35, Qg=9.05
% INFO    : Gen at bus 50293	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50293	: Pg=90.13, Qg=103.1 -> Pg=128.15, Qg=23.85
% INFO    : Gen at bus 50293	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50294	: Pg=2.8, Qg=-9.24 -> Pg=56.0, Qg=0.0
% INFO    : Gen at bus 50294	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50294	: Pg=2.8, Qg=-9.24 -> Pg=56.0, Qg=0.0
% INFO    : Gen at bus 50294	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50294	: Pg=2.8, Qg=-9.24 -> Pg=56.0, Qg=0.0
% INFO    : Gen at bus 50294	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50294	: Pg=2.8, Qg=-9.24 -> Pg=56.0, Qg=0.0
% INFO    : Gen at bus 50294	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50294	: Pg=2.8, Qg=-9.24 -> Pg=56.0, Qg=0.0
% INFO    : Gen at bus 50294	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50294	: Pg=2.8, Qg=-9.24 -> Pg=56.0, Qg=0.0
% INFO    : Gen at bus 50294	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50294	: Pg=2.8, Qg=-9.24 -> Pg=56.0, Qg=0.0
% INFO    : Gen at bus 50294	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50295	: Pg=5.0, Qg=10.61 -> Pg=52.0, Qg=0.0
% INFO    : Gen at bus 50295	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50296	: Pg=48.44, Qg=7.7 -> Pg=69.8, Qg=7.05
% INFO    : Gen at bus 50296	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50296	: Pg=48.48, Qg=7.7 -> Pg=70.55, Qg=7.15
% INFO    : Gen at bus 50296	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50297	: Pg=67.5, Qg=3.78 -> Pg=38.75, Qg=5.1
% INFO    : Gen at bus 50297	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50297	: Pg=67.5, Qg=3.78 -> Pg=38.75, Qg=5.1
% INFO    : Gen at bus 50297	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50298	: Pg=21.69, Qg=32.7 -> Pg=43.75, Qg=5.1
% INFO    : Gen at bus 50298	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50299	: Pg=1.47, Qg=-4.47 -> Pg=29.25, Qg=0.0
% INFO    : Gen at bus 50299	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50299	: Pg=1.47, Qg=-4.47 -> Pg=29.25, Qg=0.0
% INFO    : Gen at bus 50299	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50299	: Pg=1.47, Qg=-4.47 -> Pg=29.25, Qg=0.0
% INFO    : Gen at bus 50299	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50299	: Pg=1.47, Qg=-4.47 -> Pg=29.25, Qg=0.0
% INFO    : Gen at bus 50299	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50299	: Pg=1.47, Qg=-4.47 -> Pg=29.25, Qg=0.0
% INFO    : Gen at bus 50299	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50299	: Pg=1.68, Qg=-4.47 -> Pg=33.6, Qg=0.0
% INFO    : Gen at bus 50299	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50299	: Pg=1.68, Qg=-4.47 -> Pg=33.6, Qg=0.0
% INFO    : Gen at bus 50299	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50299	: Pg=1.68, Qg=-4.47 -> Pg=33.6, Qg=0.0
% INFO    : Gen at bus 50299	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50300	: Pg=2.6, Qg=19.43 -> Pg=26.8, Qg=0.0
% INFO    : Gen at bus 50300	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50301	: Pg=50.0, Qg=12.59 -> Pg=25.2, Qg=0.0
% INFO    : Gen at bus 50301	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50302	: Pg=16.07, Qg=26.6 -> Pg=28.95, Qg=6.15
% INFO    : Gen at bus 50302	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50303	: Pg=2.0, Qg=11.88 -> Pg=21.25, Qg=0.0
% INFO    : Gen at bus 50303	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50304	: Pg=1.0, Qg=2.85 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 50304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50304	: Pg=1.0, Qg=2.85 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 50304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50304	: Pg=1.0, Qg=2.85 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 50304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50304	: Pg=1.0, Qg=2.85 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 50304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50304	: Pg=1.0, Qg=2.85 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 50304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50304	: Pg=1.0, Qg=2.85 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 50304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50304	: Pg=1.0, Qg=2.85 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 50304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50304	: Pg=1.0, Qg=2.85 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 50304	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50306	: Pg=2.42, Qg=13.9 -> Pg=15.25, Qg=2.15
% INFO    : Gen at bus 50306	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50308	: Pg=5.0, Qg=9.9 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 50308	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50309	: Pg=8.6, Qg=11.7 -> Pg=16.05, Qg=1.85
% INFO    : Gen at bus 50309	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50310	: Pg=1354.3, Qg=24.72 -> Pg=1317.15, Qg=102.25
% INFO    : Gen at bus 50310	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50310	: Pg=1354.3, Qg=24.72 -> Pg=1317.15, Qg=102.25
% INFO    : Gen at bus 50310	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50311	: Pg=1184.1, Qg=42.65 -> Pg=1163.5, Qg=91.75
% INFO    : Gen at bus 50311	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50311	: Pg=1215.0, Qg=42.65 -> Pg=1159.0, Qg=91.75
% INFO    : Gen at bus 50311	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50312	: Pg=432.28, Qg=6.61 -> Pg=632.4, Qg=0.0
% INFO    : Gen at bus 50312	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50313	: Pg=422.36, Qg=1.52 -> Pg=646.5, Qg=0.0
% INFO    : Gen at bus 50313	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50313	: Pg=451.14, Qg=1.52 -> Pg=678.4, Qg=0.0
% INFO    : Gen at bus 50313	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50314	: Pg=757.87, Qg=-10.25 -> Pg=765.6, Qg=0.0
% INFO    : Gen at bus 50314	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50314	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50314	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50315	: Pg=360.71, Qg=57.8 -> Pg=415.0, Qg=57.75
% INFO    : Gen at bus 50315	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50315	: Pg=360.71, Qg=57.8 -> Pg=415.0, Qg=57.75
% INFO    : Gen at bus 50315	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50316	: Pg=418.06, Qg=117.95 -> Pg=560.5, Qg=54.45
% INFO    : Gen at bus 50316	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50317	: Pg=233.03, Qg=120.96 -> Pg=467.5, Qg=54.35
% INFO    : Gen at bus 50317	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50318	: Pg=496.57, Qg=93.65 -> Pg=570.75, Qg=49.95
% INFO    : Gen at bus 50318	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50319	: Pg=365.59, Qg=25.45 -> Pg=486.2, Qg=46.95
% INFO    : Gen at bus 50319	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50320	: Pg=183.88, Qg=116.4 -> Pg=108.9, Qg=26.9
% INFO    : Gen at bus 50320	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50320	: Pg=183.88, Qg=116.4 -> Pg=108.9, Qg=26.9
% INFO    : Gen at bus 50320	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50320	: Pg=577.94, Qg=194.42 -> Pg=320.25, Qg=43.8
% INFO    : Gen at bus 50320	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50320	: Pg=731.54, Qg=194.42 -> Pg=454.55, Qg=55.4
% INFO    : Gen at bus 50320	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50320	: Pg=731.54, Qg=194.42 -> Pg=454.55, Qg=55.4
% INFO    : Gen at bus 50320	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50320	: Pg=295.71, Qg=185.4 -> Pg=179.6, Qg=42.85
% INFO    : Gen at bus 50320	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50320	: Pg=612.04, Qg=194.42 -> Pg=394.8, Qg=71.7
% INFO    : Gen at bus 50320	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50320	: Pg=651.44, Qg=194.42 -> Pg=414.5, Qg=76.3
% INFO    : Gen at bus 50320	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50321	: Pg=163.78, Qg=47.62 -> Pg=228.4, Qg=38.875
% INFO    : Gen at bus 50321	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50321	: Pg=163.78, Qg=47.62 -> Pg=228.4, Qg=38.875
% INFO    : Gen at bus 50321	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50322	: Pg=284.86, Qg=5.16 -> Pg=431.7, Qg=44.8
% INFO    : Gen at bus 50322	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50322	: Pg=284.86, Qg=5.16 -> Pg=431.7, Qg=44.8
% INFO    : Gen at bus 50322	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50323	: Pg=735.87, Qg=103.21 -> Pg=754.6, Qg=0.0
% INFO    : Gen at bus 50323	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50323	: Pg=536.86, Qg=103.21 -> Pg=557.7, Qg=0.0
% INFO    : Gen at bus 50323	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50323	: Pg=536.86, Qg=103.21 -> Pg=557.7, Qg=0.0
% INFO    : Gen at bus 50323	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50324	: Pg=554.79, Qg=93.65 -> Pg=565.3, Qg=0.0
% INFO    : Gen at bus 50324	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50325	: Pg=199.22, Qg=0.67 -> Pg=376.45, Qg=42.85
% INFO    : Gen at bus 50325	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50325	: Pg=199.22, Qg=0.67 -> Pg=376.45, Qg=42.85
% INFO    : Gen at bus 50325	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50326	: Pg=337.4, Qg=104.56 -> Pg=584.0, Qg=66.25
% INFO    : Gen at bus 50326	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50326	: Pg=266.88, Qg=104.56 -> Pg=344.0, Qg=42.7
% INFO    : Gen at bus 50326	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50327	: Pg=263.1, Qg=10.23 -> Pg=354.0, Qg=42.15
% INFO    : Gen at bus 50327	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50327	: Pg=263.1, Qg=10.23 -> Pg=354.0, Qg=42.15
% INFO    : Gen at bus 50327	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50327	: Pg=263.1, Qg=10.23 -> Pg=354.0, Qg=42.15
% INFO    : Gen at bus 50327	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50328	: Pg=216.9, Qg=62.67 -> Pg=320.0, Qg=34.75
% INFO    : Gen at bus 50328	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50328	: Pg=289.98, Qg=62.67 -> Pg=387.5, Qg=46.45
% INFO    : Gen at bus 50328	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50328	: Pg=289.98, Qg=62.67 -> Pg=387.5, Qg=46.45
% INFO    : Gen at bus 50328	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50329	: Pg=213.83, Qg=219.6 -> Pg=301.75, Qg=34.2
% INFO    : Gen at bus 50329	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50330	: Pg=24.47, Qg=32.2 -> Pg=27.95, Qg=7.45
% INFO    : Gen at bus 50330	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50330	: Pg=131.08, Qg=113.4 -> Pg=176.0, Qg=18.925
% INFO    : Gen at bus 50330	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50330	: Pg=131.08, Qg=113.4 -> Pg=176.0, Qg=18.925
% INFO    : Gen at bus 50330	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50330	: Pg=84.23, Qg=62.5 -> Pg=105.0, Qg=9.75
% INFO    : Gen at bus 50330	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50330	: Pg=84.23, Qg=62.5 -> Pg=105.0, Qg=9.75
% INFO    : Gen at bus 50330	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50330	: Pg=84.23, Qg=62.5 -> Pg=105.0, Qg=9.75
% INFO    : Gen at bus 50330	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50331	: Pg=210.3, Qg=104.56 -> Pg=258.0, Qg=33.65
% INFO    : Gen at bus 50331	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50331	: Pg=210.3, Qg=104.56 -> Pg=258.0, Qg=33.65
% INFO    : Gen at bus 50331	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50332	: Pg=210.3, Qg=126.33 -> Pg=270.5, Qg=33.65
% INFO    : Gen at bus 50332	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50333	: Pg=210.3, Qg=104.56 -> Pg=285.5, Qg=33.65
% INFO    : Gen at bus 50333	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50333	: Pg=229.16, Qg=104.56 -> Pg=305.5, Qg=36.7
% INFO    : Gen at bus 50333	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50334	: Pg=260.27, Qg=63.42 -> Pg=330.0, Qg=30.95
% INFO    : Gen at bus 50334	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50335	: Pg=131.4, Qg=207.3 -> Pg=287.5, Qg=0.0
% INFO    : Gen at bus 50335	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50335	: Pg=131.4, Qg=207.3 -> Pg=287.5, Qg=0.0
% INFO    : Gen at bus 50335	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50335	: Pg=60.14, Qg=303.6 -> Pg=227.4, Qg=84.35
% INFO    : Gen at bus 50335	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50336	: Pg=477.3, Qg=257.2 -> Pg=497.5, Qg=40.1
% INFO    : Gen at bus 50336	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50336	: Pg=362.93, Qg=192.0 -> Pg=374.75, Qg=29.9
% INFO    : Gen at bus 50336	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50337	: Pg=172.02, Qg=12.15 -> Pg=261.5, Qg=27.2
% INFO    : Gen at bus 50337	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50337	: Pg=172.02, Qg=12.15 -> Pg=261.5, Qg=27.2
% INFO    : Gen at bus 50337	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50337	: Pg=172.02, Qg=12.15 -> Pg=261.5, Qg=27.2
% INFO    : Gen at bus 50337	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50338	: Pg=218.85, Qg=138.0 -> Pg=237.5, Qg=21.5
% INFO    : Gen at bus 50338	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50338	: Pg=90.44, Qg=64.4 -> Pg=106.5, Qg=10.05
% INFO    : Gen at bus 50338	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50339	: Pg=283.2, Qg=48.33 -> Pg=283.2, Qg=21.4
% INFO    : Gen at bus 50339	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50340	: Pg=14.1, Qg=14.49 -> Pg=146.05, Qg=20.95
% INFO    : Gen at bus 50340	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50341	: Pg=127.97, Qg=120.74 -> Pg=160.7, Qg=31.65
% INFO    : Gen at bus 50341	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50341	: Pg=127.97, Qg=120.74 -> Pg=160.7, Qg=31.65
% INFO    : Gen at bus 50341	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50342	: Pg=176.69, Qg=39.81 -> Pg=218.5, Qg=38.25
% INFO    : Gen at bus 50342	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50342	: Pg=141.69, Qg=39.81 -> Pg=201.0, Qg=38.25
% INFO    : Gen at bus 50342	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50342	: Pg=141.69, Qg=39.81 -> Pg=201.0, Qg=38.25
% INFO    : Gen at bus 50342	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50343	: Pg=249.0, Qg=-42.64 -> Pg=124.5, Qg=18.8
% INFO    : Gen at bus 50343	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50344	: Pg=209.2, Qg=5.87 -> Pg=225.35, Qg=35.45
% INFO    : Gen at bus 50344	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50344	: Pg=360.69, Qg=5.87 -> Pg=369.0, Qg=29.2
% INFO    : Gen at bus 50344	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50345	: Pg=62.2, Qg=41.52 -> Pg=151.75, Qg=18.7
% INFO    : Gen at bus 50345	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50345	: Pg=62.2, Qg=41.52 -> Pg=151.75, Qg=18.7
% INFO    : Gen at bus 50345	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50346	: Pg=115.0, Qg=118.1 -> Pg=163.95, Qg=18.4
% INFO    : Gen at bus 50346	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50346	: Pg=115.0, Qg=118.1 -> Pg=163.95, Qg=18.4
% INFO    : Gen at bus 50346	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50346	: Pg=141.74, Qg=145.6 -> Pg=192.3, Qg=22.7
% INFO    : Gen at bus 50346	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50347	: Pg=136.56, Qg=65.86 -> Pg=196.0, Qg=19.8
% INFO    : Gen at bus 50347	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50347	: Pg=91.06, Qg=65.86 -> Pg=163.5, Qg=18.25
% INFO    : Gen at bus 50347	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50347	: Pg=91.06, Qg=65.86 -> Pg=163.5, Qg=18.25
% INFO    : Gen at bus 50347	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50348	: Pg=156.05, Qg=42.32 -> Pg=195.85, Qg=34.6
% INFO    : Gen at bus 50348	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50348	: Pg=156.05, Qg=42.32 -> Pg=195.85, Qg=34.6
% INFO    : Gen at bus 50348	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50348	: Pg=156.33, Qg=42.32 -> Pg=201.4, Qg=36.2
% INFO    : Gen at bus 50348	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50348	: Pg=156.33, Qg=42.32 -> Pg=201.4, Qg=36.2
% INFO    : Gen at bus 50348	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50349	: Pg=241.0, Qg=-50.13 -> Pg=120.5, Qg=18.2
% INFO    : Gen at bus 50349	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50350	: Pg=112.88, Qg=70.58 -> Pg=144.7, Qg=34.3
% INFO    : Gen at bus 50350	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50350	: Pg=112.88, Qg=70.58 -> Pg=144.7, Qg=34.3
% INFO    : Gen at bus 50350	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50350	: Pg=278.95, Qg=70.58 -> Pg=388.3, Qg=69.05
% INFO    : Gen at bus 50350	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50350	: Pg=223.21, Qg=70.58 -> Pg=264.2, Qg=55.25
% INFO    : Gen at bus 50350	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50350	: Pg=239.25, Qg=70.58 -> Pg=281.2, Qg=59.25
% INFO    : Gen at bus 50350	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50351	: Pg=208.99, Qg=148.3 -> Pg=221.15, Qg=34.25
% INFO    : Gen at bus 50351	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50353	: Pg=134.38, Qg=176.6 -> Pg=182.5, Qg=40.8
% INFO    : Gen at bus 50353	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50353	: Pg=125.38, Qg=104.1 -> Pg=167.5, Qg=16.2
% INFO    : Gen at bus 50353	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50353	: Pg=125.38, Qg=104.1 -> Pg=167.5, Qg=16.2
% INFO    : Gen at bus 50353	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50354	: Pg=213.0, Qg=-15.96 -> Pg=106.55, Qg=16.1
% INFO    : Gen at bus 50354	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50354	: Pg=223.5, Qg=-15.96 -> Pg=111.8, Qg=16.85
% INFO    : Gen at bus 50354	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50354	: Pg=299.0, Qg=-15.96 -> Pg=149.55, Qg=22.55
% INFO    : Gen at bus 50354	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50355	: Pg=129.67, Qg=78.45 -> Pg=150.0, Qg=20.75
% INFO    : Gen at bus 50355	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50355	: Pg=99.02, Qg=78.45 -> Pg=107.0, Qg=30.05
% INFO    : Gen at bus 50355	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50355	: Pg=101.28, Qg=78.45 -> Pg=109.4, Qg=30.75
% INFO    : Gen at bus 50355	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50355	: Pg=101.28, Qg=78.45 -> Pg=109.4, Qg=30.75
% INFO    : Gen at bus 50355	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50356	: Pg=0.0, Qg=-7.27 -> Pg=104.5, Qg=15.75
% INFO    : Gen at bus 50356	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=8.4, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=8.4, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=8.4, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=8.4, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=8.4, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=8.4, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=8.4, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=8.4, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=8.4, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=4.21, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=4.21, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=4.21, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=4.21, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=4.21, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=4.21, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=4.21, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=4.21, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=4.21, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=4.21, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=4.21, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=4.21, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=4.21, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=4.21, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50357	: Pg=8.4, Qg=2.23 -> Pg=6.2, Qg=1.75
% INFO    : Gen at bus 50357	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50358	: Pg=201.6, Qg=-13.61 -> Pg=100.8, Qg=15.2
% INFO    : Gen at bus 50358	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50360	: Pg=200.1, Qg=45.38 -> Pg=100.05, Qg=15.1
% INFO    : Gen at bus 50360	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50361	: Pg=156.9, Qg=206.7 -> Pg=212.8, Qg=57.4
% INFO    : Gen at bus 50361	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50361	: Pg=95.01, Qg=150.0 -> Pg=145.0, Qg=41.65
% INFO    : Gen at bus 50361	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50361	: Pg=95.01, Qg=150.0 -> Pg=145.0, Qg=41.65
% INFO    : Gen at bus 50361	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50362	: Pg=200.0, Qg=53.53 -> Pg=125.0, Qg=15.1
% INFO    : Gen at bus 50362	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50363	: Pg=200.0, Qg=96.9 -> Pg=125.0, Qg=15.1
% INFO    : Gen at bus 50363	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50364	: Pg=0.0, Qg=5.01 -> Pg=99.75, Qg=15.05
% INFO    : Gen at bus 50364	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50365	: Pg=93.78, Qg=96.3 -> Pg=104.95, Qg=15.0
% INFO    : Gen at bus 50365	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50365	: Pg=273.71, Qg=99.34 -> Pg=325.25, Qg=43.8
% INFO    : Gen at bus 50365	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50365	: Pg=86.73, Qg=99.34 -> Pg=207.5, Qg=29.9
% INFO    : Gen at bus 50365	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50366	: Pg=99.98, Qg=27.52 -> Pg=146.95, Qg=28.5
% INFO    : Gen at bus 50366	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50366	: Pg=99.98, Qg=27.52 -> Pg=146.95, Qg=28.5
% INFO    : Gen at bus 50366	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50366	: Pg=92.18, Qg=27.52 -> Pg=105.25, Qg=28.0
% INFO    : Gen at bus 50366	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50367	: Pg=78.99, Qg=15.76 -> Pg=117.25, Qg=22.8
% INFO    : Gen at bus 50367	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50367	: Pg=78.99, Qg=15.76 -> Pg=117.25, Qg=22.8
% INFO    : Gen at bus 50367	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50367	: Pg=78.99, Qg=15.76 -> Pg=117.25, Qg=22.8
% INFO    : Gen at bus 50367	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50367	: Pg=78.99, Qg=15.76 -> Pg=117.25, Qg=22.8
% INFO    : Gen at bus 50367	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50367	: Pg=93.78, Qg=15.76 -> Pg=136.95, Qg=28.5
% INFO    : Gen at bus 50367	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50367	: Pg=93.78, Qg=15.76 -> Pg=136.95, Qg=28.5
% INFO    : Gen at bus 50367	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50367	: Pg=93.78, Qg=15.76 -> Pg=136.95, Qg=28.5
% INFO    : Gen at bus 50367	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50367	: Pg=93.78, Qg=15.76 -> Pg=136.95, Qg=28.5
% INFO    : Gen at bus 50367	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50368	: Pg=24.24, Qg=24.9 -> Pg=33.2, Qg=3.9
% INFO    : Gen at bus 50368	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50368	: Pg=24.24, Qg=24.9 -> Pg=31.7, Qg=3.9
% INFO    : Gen at bus 50368	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50368	: Pg=24.24, Qg=31.9 -> Pg=31.7, Qg=7.4
% INFO    : Gen at bus 50368	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50368	: Pg=24.24, Qg=31.9 -> Pg=31.7, Qg=7.4
% INFO    : Gen at bus 50368	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50368	: Pg=24.24, Qg=31.9 -> Pg=31.7, Qg=7.4
% INFO    : Gen at bus 50368	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50368	: Pg=24.24, Qg=31.9 -> Pg=31.7, Qg=7.4
% INFO    : Gen at bus 50368	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50368	: Pg=96.96, Qg=73.52 -> Pg=145.0, Qg=28.35
% INFO    : Gen at bus 50368	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50368	: Pg=89.59, Qg=73.52 -> Pg=122.5, Qg=27.25
% INFO    : Gen at bus 50368	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50369	: Pg=0.0, Qg=-2.17 -> Pg=98.5, Qg=14.85
% INFO    : Gen at bus 50369	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50370	: Pg=114.51, Qg=36.01 -> Pg=145.0, Qg=25.8
% INFO    : Gen at bus 50370	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50370	: Pg=124.93, Qg=36.01 -> Pg=158.45, Qg=14.9
% INFO    : Gen at bus 50370	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50371	: Pg=106.9, Qg=14.91 -> Pg=148.75, Qg=14.75
% INFO    : Gen at bus 50371	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50371	: Pg=106.9, Qg=14.91 -> Pg=148.75, Qg=14.75
% INFO    : Gen at bus 50371	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50371	: Pg=96.19, Qg=14.91 -> Pg=132.0, Qg=29.2
% INFO    : Gen at bus 50371	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50372	: Pg=83.75, Qg=92.9 -> Pg=114.95, Qg=21.45
% INFO    : Gen at bus 50372	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50372	: Pg=124.81, Qg=109.72 -> Pg=156.05, Qg=27.55
% INFO    : Gen at bus 50372	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50372	: Pg=124.81, Qg=109.72 -> Pg=156.05, Qg=27.55
% INFO    : Gen at bus 50372	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50372	: Pg=124.81, Qg=109.72 -> Pg=156.05, Qg=27.55
% INFO    : Gen at bus 50372	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50372	: Pg=124.81, Qg=109.72 -> Pg=156.05, Qg=27.55
% INFO    : Gen at bus 50372	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50373	: Pg=165.5, Qg=72.85 -> Pg=225.0, Qg=26.5
% INFO    : Gen at bus 50373	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50373	: Pg=89.4, Qg=72.85 -> Pg=124.8, Qg=27.15
% INFO    : Gen at bus 50373	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50373	: Pg=89.4, Qg=72.85 -> Pg=124.8, Qg=27.15
% INFO    : Gen at bus 50373	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50374	: Pg=165.5, Qg=28.27 -> Pg=225.0, Qg=26.5
% INFO    : Gen at bus 50374	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50374	: Pg=165.97, Qg=28.27 -> Pg=203.5, Qg=26.6
% INFO    : Gen at bus 50374	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50374	: Pg=89.4, Qg=28.27 -> Pg=124.8, Qg=27.15
% INFO    : Gen at bus 50374	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50374	: Pg=89.4, Qg=28.27 -> Pg=124.8, Qg=27.15
% INFO    : Gen at bus 50374	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50375	: Pg=175.97, Qg=44.56 -> Pg=211.6, Qg=53.45
% INFO    : Gen at bus 50375	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50375	: Pg=89.12, Qg=44.56 -> Pg=134.5, Qg=27.05
% INFO    : Gen at bus 50375	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50375	: Pg=89.12, Qg=44.56 -> Pg=134.5, Qg=27.05
% INFO    : Gen at bus 50375	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50375	: Pg=89.12, Qg=44.56 -> Pg=134.5, Qg=27.05
% INFO    : Gen at bus 50375	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50376	: Pg=166.07, Qg=5.37 -> Pg=201.15, Qg=34.7
% INFO    : Gen at bus 50376	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50376	: Pg=88.74, Qg=5.37 -> Pg=133.1, Qg=26.95
% INFO    : Gen at bus 50376	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50376	: Pg=88.74, Qg=5.37 -> Pg=133.1, Qg=26.95
% INFO    : Gen at bus 50376	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50377	: Pg=88.55, Qg=116.4 -> Pg=108.9, Qg=26.9
% INFO    : Gen at bus 50377	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50377	: Pg=88.55, Qg=116.4 -> Pg=108.9, Qg=26.9
% INFO    : Gen at bus 50377	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50377	: Pg=106.23, Qg=139.6 -> Pg=127.65, Qg=32.25
% INFO    : Gen at bus 50377	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50377	: Pg=106.23, Qg=139.6 -> Pg=127.65, Qg=32.25
% INFO    : Gen at bus 50377	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50378	: Pg=94.59, Qg=55.81 -> Pg=136.6, Qg=13.8
% INFO    : Gen at bus 50378	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50378	: Pg=94.59, Qg=55.81 -> Pg=136.6, Qg=13.8
% INFO    : Gen at bus 50378	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50378	: Pg=94.59, Qg=55.81 -> Pg=136.6, Qg=13.8
% INFO    : Gen at bus 50378	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50378	: Pg=183.94, Qg=55.81 -> Pg=225.05, Qg=29.45
% INFO    : Gen at bus 50378	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50379	: Pg=94.59, Qg=50.08 -> Pg=136.6, Qg=13.8
% INFO    : Gen at bus 50379	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50379	: Pg=94.59, Qg=50.08 -> Pg=136.6, Qg=13.8
% INFO    : Gen at bus 50379	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50379	: Pg=94.59, Qg=50.08 -> Pg=136.6, Qg=13.8
% INFO    : Gen at bus 50379	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50379	: Pg=199.77, Qg=50.08 -> Pg=290.0, Qg=29.45
% INFO    : Gen at bus 50379	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50380	: Pg=84.87, Qg=29.57 -> Pg=105.0, Qg=25.8
% INFO    : Gen at bus 50380	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50380	: Pg=165.5, Qg=29.57 -> Pg=195.5, Qg=26.5
% INFO    : Gen at bus 50380	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50380	: Pg=165.5, Qg=29.57 -> Pg=195.5, Qg=26.5
% INFO    : Gen at bus 50380	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50381	: Pg=106.51, Qg=111.6 -> Pg=141.0, Qg=25.8
% INFO    : Gen at bus 50381	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50381	: Pg=106.51, Qg=111.6 -> Pg=141.0, Qg=25.8
% INFO    : Gen at bus 50381	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50381	: Pg=106.51, Qg=111.6 -> Pg=141.0, Qg=25.8
% INFO    : Gen at bus 50381	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50381	: Pg=106.51, Qg=111.6 -> Pg=141.0, Qg=25.8
% INFO    : Gen at bus 50381	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50381	: Pg=130.14, Qg=133.7 -> Pg=158.0, Qg=20.85
% INFO    : Gen at bus 50381	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50382	: Pg=110.0, Qg=111.6 -> Pg=145.0, Qg=25.8
% INFO    : Gen at bus 50382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50382	: Pg=4.0, Qg=49.6 -> Pg=42.0, Qg=11.45
% INFO    : Gen at bus 50382	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50384	: Pg=180.0, Qg=87.2 -> Pg=90.0, Qg=13.6
% INFO    : Gen at bus 50384	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50385	: Pg=134.47, Qg=38.53 -> Pg=154.25, Qg=25.55
% INFO    : Gen at bus 50385	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50385	: Pg=134.47, Qg=38.53 -> Pg=154.25, Qg=25.55
% INFO    : Gen at bus 50385	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50385	: Pg=84.17, Qg=38.53 -> Pg=124.25, Qg=25.55
% INFO    : Gen at bus 50385	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50386	: Pg=104.46, Qg=86.3 -> Pg=139.1, Qg=13.45
% INFO    : Gen at bus 50386	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50386	: Pg=102.64, Qg=50.6 -> Pg=102.2, Qg=7.9
% INFO    : Gen at bus 50386	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50387	: Pg=154.43, Qg=61.37 -> Pg=163.4, Qg=36.85
% INFO    : Gen at bus 50387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50387	: Pg=465.19, Qg=61.37 -> Pg=489.3, Qg=39.75
% INFO    : Gen at bus 50387	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50388	: Pg=83.27, Qg=105.47 -> Pg=123.3, Qg=25.25
% INFO    : Gen at bus 50388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50388	: Pg=83.27, Qg=105.47 -> Pg=123.3, Qg=25.25
% INFO    : Gen at bus 50388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50388	: Pg=93.41, Qg=105.47 -> Pg=124.05, Qg=28.4
% INFO    : Gen at bus 50388	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50389	: Pg=114.41, Qg=42.18 -> Pg=143.0, Qg=25.2
% INFO    : Gen at bus 50389	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50389	: Pg=102.41, Qg=42.18 -> Pg=137.0, Qg=25.2
% INFO    : Gen at bus 50389	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50389	: Pg=94.41, Qg=42.18 -> Pg=133.0, Qg=25.2
% INFO    : Gen at bus 50389	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50389	: Pg=94.41, Qg=42.18 -> Pg=133.0, Qg=25.2
% INFO    : Gen at bus 50389	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50389	: Pg=61.62, Qg=42.18 -> Pg=140.2, Qg=32.15
% INFO    : Gen at bus 50389	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50389	: Pg=61.62, Qg=42.18 -> Pg=140.2, Qg=32.15
% INFO    : Gen at bus 50389	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50390	: Pg=94.38, Qg=69.6 -> Pg=132.5, Qg=13.25
% INFO    : Gen at bus 50390	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50390	: Pg=94.38, Qg=69.6 -> Pg=132.5, Qg=13.25
% INFO    : Gen at bus 50390	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50390	: Pg=94.3, Qg=69.6 -> Pg=130.0, Qg=15.1
% INFO    : Gen at bus 50390	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50391	: Pg=87.23, Qg=0.0 -> Pg=132.5, Qg=0.0
% INFO    : Gen at bus 50391	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50391	: Pg=87.23, Qg=0.0 -> Pg=132.5, Qg=0.0
% INFO    : Gen at bus 50391	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50391	: Pg=87.23, Qg=0.0 -> Pg=132.5, Qg=0.0
% INFO    : Gen at bus 50391	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50391	: Pg=82.51, Qg=0.0 -> Pg=120.0, Qg=0.0
% INFO    : Gen at bus 50391	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50391	: Pg=62.13, Qg=0.0 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 50391	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50392	: Pg=99.37, Qg=37.81 -> Pg=134.8, Qg=13.2
% INFO    : Gen at bus 50392	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50392	: Pg=99.37, Qg=37.81 -> Pg=134.8, Qg=13.2
% INFO    : Gen at bus 50392	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50393	: Pg=119.32, Qg=19.85 -> Pg=143.8, Qg=13.05
% INFO    : Gen at bus 50393	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50393	: Pg=94.36, Qg=19.85 -> Pg=132.1, Qg=13.15
% INFO    : Gen at bus 50393	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50393	: Pg=94.36, Qg=19.85 -> Pg=132.1, Qg=13.15
% INFO    : Gen at bus 50393	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50394	: Pg=184.99, Qg=80.96 -> Pg=142.5, Qg=26.5
% INFO    : Gen at bus 50394	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50394	: Pg=172.0, Qg=80.96 -> Pg=121.0, Qg=24.65
% INFO    : Gen at bus 50394	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50394	: Pg=172.0, Qg=80.96 -> Pg=121.0, Qg=24.65
% INFO    : Gen at bus 50394	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50395	: Pg=104.3, Qg=14.12 -> Pg=135.85, Qg=24.6
% INFO    : Gen at bus 50395	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50395	: Pg=104.41, Qg=14.12 -> Pg=138.0, Qg=25.2
% INFO    : Gen at bus 50395	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50395	: Pg=104.41, Qg=14.12 -> Pg=138.0, Qg=25.2
% INFO    : Gen at bus 50395	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50395	: Pg=104.41, Qg=14.12 -> Pg=138.0, Qg=25.2
% INFO    : Gen at bus 50395	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50395	: Pg=96.33, Qg=14.12 -> Pg=134.65, Qg=29.25
% INFO    : Gen at bus 50395	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50395	: Pg=96.33, Qg=14.12 -> Pg=134.65, Qg=29.25
% INFO    : Gen at bus 50395	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50396	: Pg=104.29, Qg=64.08 -> Pg=135.55, Qg=24.5
% INFO    : Gen at bus 50396	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50396	: Pg=104.29, Qg=64.08 -> Pg=135.55, Qg=24.5
% INFO    : Gen at bus 50396	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50396	: Pg=104.29, Qg=64.08 -> Pg=135.55, Qg=24.5
% INFO    : Gen at bus 50396	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50396	: Pg=104.29, Qg=64.08 -> Pg=135.55, Qg=24.5
% INFO    : Gen at bus 50396	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50396	: Pg=143.86, Qg=64.08 -> Pg=170.35, Qg=28.9
% INFO    : Gen at bus 50396	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50396	: Pg=143.56, Qg=64.08 -> Pg=170.2, Qg=28.9
% INFO    : Gen at bus 50396	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50397	: Pg=170.2, Qg=-22.45 -> Pg=85.1, Qg=12.85
% INFO    : Gen at bus 50397	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50398	: Pg=98.13, Qg=35.28 -> Pg=135.25, Qg=25.35
% INFO    : Gen at bus 50398	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50398	: Pg=94.41, Qg=35.28 -> Pg=130.125, Qg=24.35
% INFO    : Gen at bus 50398	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50398	: Pg=94.41, Qg=35.28 -> Pg=130.125, Qg=24.35
% INFO    : Gen at bus 50398	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50399	: Pg=104.26, Qg=74.31 -> Pg=135.0, Qg=24.35
% INFO    : Gen at bus 50399	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50399	: Pg=104.26, Qg=74.31 -> Pg=135.0, Qg=24.35
% INFO    : Gen at bus 50399	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50399	: Pg=60.21, Qg=74.31 -> Pg=72.85, Qg=18.25
% INFO    : Gen at bus 50399	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50400	: Pg=168.21, Qg=50.67 -> Pg=167.0, Qg=24.35
% INFO    : Gen at bus 50400	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50400	: Pg=168.21, Qg=50.67 -> Pg=167.0, Qg=24.35
% INFO    : Gen at bus 50400	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50400	: Pg=67.51, Qg=50.67 -> Pg=180.0, Qg=42.95
% INFO    : Gen at bus 50400	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50401	: Pg=104.26, Qg=30.4 -> Pg=135.0, Qg=24.35
% INFO    : Gen at bus 50401	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50401	: Pg=104.26, Qg=30.4 -> Pg=135.0, Qg=24.35
% INFO    : Gen at bus 50401	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50401	: Pg=108.45, Qg=30.4 -> Pg=140.0, Qg=32.9
% INFO    : Gen at bus 50401	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50402	: Pg=94.26, Qg=32.53 -> Pg=130.0, Qg=12.8
% INFO    : Gen at bus 50402	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50402	: Pg=94.26, Qg=32.53 -> Pg=130.0, Qg=12.8
% INFO    : Gen at bus 50402	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50403	: Pg=84.25, Qg=105.2 -> Pg=124.9, Qg=24.3
% INFO    : Gen at bus 50403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50403	: Pg=84.25, Qg=105.2 -> Pg=124.9, Qg=24.3
% INFO    : Gen at bus 50403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50403	: Pg=84.25, Qg=105.2 -> Pg=124.9, Qg=24.3
% INFO    : Gen at bus 50403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50403	: Pg=84.25, Qg=105.2 -> Pg=124.9, Qg=24.3
% INFO    : Gen at bus 50403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50403	: Pg=84.25, Qg=105.2 -> Pg=124.9, Qg=24.3
% INFO    : Gen at bus 50403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50403	: Pg=84.25, Qg=105.2 -> Pg=124.9, Qg=24.3
% INFO    : Gen at bus 50403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50403	: Pg=196.15, Qg=184.28 -> Pg=245.5, Qg=59.55
% INFO    : Gen at bus 50403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50403	: Pg=196.15, Qg=184.28 -> Pg=245.5, Qg=59.55
% INFO    : Gen at bus 50403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50404	: Pg=169.5, Qg=13.65 -> Pg=84.75, Qg=12.8
% INFO    : Gen at bus 50404	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50406	: Pg=114.18, Qg=103.32 -> Pg=138.5, Qg=23.9
% INFO    : Gen at bus 50406	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50406	: Pg=114.18, Qg=103.32 -> Pg=138.5, Qg=23.9
% INFO    : Gen at bus 50406	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50406	: Pg=114.18, Qg=103.32 -> Pg=138.5, Qg=23.9
% INFO    : Gen at bus 50406	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50406	: Pg=117.88, Qg=103.32 -> Pg=137.5, Qg=35.8
% INFO    : Gen at bus 50406	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50406	: Pg=51.87, Qg=68.2 -> Pg=64.5, Qg=15.75
% INFO    : Gen at bus 50406	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50407	: Pg=78.6, Qg=29.52 -> Pg=118.35, Qg=23.85
% INFO    : Gen at bus 50407	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50407	: Pg=78.6, Qg=29.52 -> Pg=118.35, Qg=23.85
% INFO    : Gen at bus 50407	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50407	: Pg=78.6, Qg=29.52 -> Pg=118.35, Qg=23.85
% INFO    : Gen at bus 50407	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50407	: Pg=78.6, Qg=29.52 -> Pg=118.35, Qg=23.85
% INFO    : Gen at bus 50407	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50407	: Pg=87.04, Qg=29.52 -> Pg=117.3, Qg=26.45
% INFO    : Gen at bus 50407	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50407	: Pg=87.04, Qg=29.52 -> Pg=117.3, Qg=26.45
% INFO    : Gen at bus 50407	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50408	: Pg=119.16, Qg=2.22 -> Pg=140.5, Qg=12.55
% INFO    : Gen at bus 50408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50408	: Pg=119.16, Qg=2.22 -> Pg=140.5, Qg=12.55
% INFO    : Gen at bus 50408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50408	: Pg=47.15, Qg=2.22 -> Pg=65.0, Qg=7.55
% INFO    : Gen at bus 50408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50409	: Pg=165.6, Qg=-31.65 -> Pg=82.8, Qg=0.0
% INFO    : Gen at bus 50409	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50410	: Pg=76.95, Qg=92.5 -> Pg=102.0, Qg=19.05
% INFO    : Gen at bus 50410	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50411	: Pg=161.0, Qg=-7.16 -> Pg=81.0, Qg=0.0
% INFO    : Gen at bus 50411	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50412	: Pg=10.4, Qg=9.82 -> Pg=85.2, Qg=0.0
% INFO    : Gen at bus 50412	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50413	: Pg=103.86, Qg=34.21 -> Pg=127.0, Qg=22.05
% INFO    : Gen at bus 50413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50413	: Pg=103.86, Qg=34.21 -> Pg=127.0, Qg=22.05
% INFO    : Gen at bus 50413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50413	: Pg=103.86, Qg=34.21 -> Pg=127.0, Qg=22.05
% INFO    : Gen at bus 50413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50413	: Pg=117.88, Qg=34.21 -> Pg=157.5, Qg=35.8
% INFO    : Gen at bus 50413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50413	: Pg=67.38, Qg=34.21 -> Pg=80.0, Qg=7.15
% INFO    : Gen at bus 50413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50414	: Pg=19.9, Qg=28.6 -> Pg=27.995, Qg=7.95
% INFO    : Gen at bus 50414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50414	: Pg=19.9, Qg=28.6 -> Pg=27.995, Qg=7.95
% INFO    : Gen at bus 50414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50414	: Pg=19.9, Qg=28.6 -> Pg=27.995, Qg=7.95
% INFO    : Gen at bus 50414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50414	: Pg=18.83, Qg=28.6 -> Pg=27.995, Qg=7.95
% INFO    : Gen at bus 50414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50414	: Pg=21.86, Qg=25.8 -> Pg=27.7, Qg=7.15
% INFO    : Gen at bus 50414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50414	: Pg=24.21, Qg=36.4 -> Pg=35.75, Qg=10.1
% INFO    : Gen at bus 50414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50414	: Pg=13.58, Qg=21.6 -> Pg=20.65, Qg=6.0
% INFO    : Gen at bus 50414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50414	: Pg=12.83, Qg=20.4 -> Pg=19.1, Qg=5.65
% INFO    : Gen at bus 50414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50418	: Pg=150.0, Qg=-4.49 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 50418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50419	: Pg=150.0, Qg=27.43 -> Pg=75.5, Qg=0.0
% INFO    : Gen at bus 50419	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50420	: Pg=90.0, Qg=26.97 -> Pg=116.5, Qg=20.45
% INFO    : Gen at bus 50420	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50420	: Pg=90.0, Qg=26.97 -> Pg=116.5, Qg=20.45
% INFO    : Gen at bus 50420	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50420	: Pg=90.0, Qg=26.97 -> Pg=116.5, Qg=20.45
% INFO    : Gen at bus 50420	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50420	: Pg=90.0, Qg=26.97 -> Pg=116.5, Qg=20.45
% INFO    : Gen at bus 50420	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50421	: Pg=0.0, Qg=60.34 -> Pg=71.25, Qg=0.0
% INFO    : Gen at bus 50421	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50422	: Pg=64.13, Qg=14.91 -> Pg=79.0, Qg=19.5
% INFO    : Gen at bus 50422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50422	: Pg=64.13, Qg=14.91 -> Pg=79.0, Qg=19.5
% INFO    : Gen at bus 50422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50422	: Pg=165.5, Qg=14.91 -> Pg=205.5, Qg=26.5
% INFO    : Gen at bus 50422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50423	: Pg=63.98, Qg=84.1 -> Pg=75.35, Qg=19.45
% INFO    : Gen at bus 50423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50423	: Pg=64.13, Qg=84.3 -> Pg=75.5, Qg=19.5
% INFO    : Gen at bus 50423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50423	: Pg=273.71, Qg=281.1 -> Pg=340.25, Qg=43.8
% INFO    : Gen at bus 50423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50424	: Pg=135.0, Qg=-19.27 -> Pg=67.5, Qg=0.0
% INFO    : Gen at bus 50424	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50425	: Pg=131.8, Qg=75.06 -> Pg=83.4, Qg=18.9
% INFO    : Gen at bus 50425	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50425	: Pg=131.8, Qg=75.06 -> Pg=83.4, Qg=18.9
% INFO    : Gen at bus 50425	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50426	: Pg=0.0, Qg=10.56 -> Pg=65.25, Qg=0.0
% INFO    : Gen at bus 50426	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50427	: Pg=14.97, Qg=7.23 -> Pg=63.25, Qg=0.0
% INFO    : Gen at bus 50427	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50428	: Pg=0.0, Qg=-13.53 -> Pg=62.1, Qg=0.0
% INFO    : Gen at bus 50428	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50429	: Pg=33.69, Qg=69.4 -> Pg=76.565, Qg=14.3
% INFO    : Gen at bus 50429	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50429	: Pg=51.57, Qg=106.3 -> Pg=117.19, Qg=21.9
% INFO    : Gen at bus 50429	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50429	: Pg=77.26, Qg=206.2 -> Pg=231.72, Qg=37.1
% INFO    : Gen at bus 50429	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50430	: Pg=1.0, Qg=27.19 -> Pg=61.45, Qg=0.0
% INFO    : Gen at bus 50430	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50431	: Pg=120.6, Qg=53.2 -> Pg=60.3, Qg=0.0
% INFO    : Gen at bus 50431	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50433	: Pg=0.0, Qg=11.45 -> Pg=60.0, Qg=0.0
% INFO    : Gen at bus 50433	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50434	: Pg=120.0, Qg=52.9 -> Pg=60.0, Qg=0.0
% INFO    : Gen at bus 50434	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50435	: Pg=82.93, Qg=7.4 -> Pg=98.5, Qg=0.0
% INFO    : Gen at bus 50435	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50435	: Pg=83.18, Qg=60.38 -> Pg=103.45, Qg=9.6
% INFO    : Gen at bus 50435	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50436	: Pg=0.0, Qg=3.88 -> Pg=57.75, Qg=0.0
% INFO    : Gen at bus 50436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50437	: Pg=114.0, Qg=15.12 -> Pg=59.85, Qg=0.0
% INFO    : Gen at bus 50437	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50438	: Pg=114.0, Qg=28.15 -> Pg=59.85, Qg=0.0
% INFO    : Gen at bus 50438	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50439	: Pg=31.2, Qg=44.1 -> Pg=136.25, Qg=18.7
% INFO    : Gen at bus 50439	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50439	: Pg=27.85, Qg=44.1 -> Pg=69.3, Qg=16.25
% INFO    : Gen at bus 50439	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50439	: Pg=20.85, Qg=44.1 -> Pg=65.8, Qg=16.25
% INFO    : Gen at bus 50439	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50440	: Pg=10.67, Qg=11.8 -> Pg=15.72, Qg=2.35
% INFO    : Gen at bus 50440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50440	: Pg=19.1, Qg=25.1 -> Pg=21.75, Qg=5.8
% INFO    : Gen at bus 50440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50440	: Pg=12.0, Qg=19.1 -> Pg=14.25, Qg=5.3
% INFO    : Gen at bus 50440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50440	: Pg=13.28, Qg=15.07 -> Pg=15.77, Qg=2.835
% INFO    : Gen at bus 50440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50440	: Pg=13.28, Qg=15.07 -> Pg=15.77, Qg=2.835
% INFO    : Gen at bus 50440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50440	: Pg=13.28, Qg=15.07 -> Pg=15.77, Qg=2.835
% INFO    : Gen at bus 50440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50440	: Pg=13.28, Qg=15.07 -> Pg=15.77, Qg=2.835
% INFO    : Gen at bus 50440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50441	: Pg=111.5, Qg=-17.88 -> Pg=100.45, Qg=14.05
% INFO    : Gen at bus 50441	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50441	: Pg=204.37, Qg=-17.88 -> Pg=111.0, Qg=16.2
% INFO    : Gen at bus 50441	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50441	: Pg=149.5, Qg=-17.88 -> Pg=85.5, Qg=0.0
% INFO    : Gen at bus 50441	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50441	: Pg=112.5, Qg=-17.88 -> Pg=59.05, Qg=0.0
% INFO    : Gen at bus 50441	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50442	: Pg=66.48, Qg=46.3 -> Pg=73.0, Qg=0.0
% INFO    : Gen at bus 50442	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50442	: Pg=67.58, Qg=33.9 -> Pg=84.0, Qg=0.0
% INFO    : Gen at bus 50442	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50442	: Pg=67.58, Qg=33.9 -> Pg=84.0, Qg=0.0
% INFO    : Gen at bus 50442	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50442	: Pg=67.58, Qg=33.9 -> Pg=84.0, Qg=0.0
% INFO    : Gen at bus 50442	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50443	: Pg=48.28, Qg=63.5 -> Pg=61.2, Qg=14.7
% INFO    : Gen at bus 50443	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50444	: Pg=62.55, Qg=76.4 -> Pg=80.95, Qg=21.2
% INFO    : Gen at bus 50444	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50447	: Pg=22.55, Qg=8.32 -> Pg=33.21, Qg=5.0
% INFO    : Gen at bus 50447	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50447	: Pg=54.95, Qg=8.32 -> Pg=75.735, Qg=9.95
% INFO    : Gen at bus 50447	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50447	: Pg=54.95, Qg=8.32 -> Pg=75.735, Qg=9.95
% INFO    : Gen at bus 50447	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50448	: Pg=155.73, Qg=0.0 -> Pg=125.45, Qg=0.0
% INFO    : Gen at bus 50448	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50448	: Pg=81.6, Qg=0.0 -> Pg=84.5, Qg=0.0
% INFO    : Gen at bus 50448	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50448	: Pg=99.0, Qg=0.0 -> Pg=84.5, Qg=0.0
% INFO    : Gen at bus 50448	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50448	: Pg=79.4, Qg=0.0 -> Pg=74.5, Qg=0.0
% INFO    : Gen at bus 50448	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50449	: Pg=30.55, Qg=31.4 -> Pg=36.9, Qg=4.9
% INFO    : Gen at bus 50449	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50449	: Pg=52.37, Qg=50.5 -> Pg=72.25, Qg=9.5
% INFO    : Gen at bus 50449	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50449	: Pg=47.37, Qg=55.32 -> Pg=69.75, Qg=13.55
% INFO    : Gen at bus 50449	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50449	: Pg=47.37, Qg=55.32 -> Pg=69.75, Qg=13.55
% INFO    : Gen at bus 50449	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50449	: Pg=56.11, Qg=55.32 -> Pg=84.5, Qg=17.0
% INFO    : Gen at bus 50449	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50449	: Pg=56.11, Qg=55.32 -> Pg=84.5, Qg=17.0
% INFO    : Gen at bus 50449	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50449	: Pg=52.48, Qg=55.32 -> Pg=70.65, Qg=15.95
% INFO    : Gen at bus 50449	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50450	: Pg=91.5, Qg=-7.98 -> Pg=45.75, Qg=0.0
% INFO    : Gen at bus 50450	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50451	: Pg=0.0, Qg=-0.28 -> Pg=45.0, Qg=0.0
% INFO    : Gen at bus 50451	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50452	: Pg=80.35, Qg=-9.14 -> Pg=106.5, Qg=19.9
% INFO    : Gen at bus 50452	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50452	: Pg=244.01, Qg=-9.14 -> Pg=320.85, Qg=39.05
% INFO    : Gen at bus 50452	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50452	: Pg=62.24, Qg=-9.14 -> Pg=74.7, Qg=6.75
% INFO    : Gen at bus 50452	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50452	: Pg=62.24, Qg=-9.14 -> Pg=74.7, Qg=6.75
% INFO    : Gen at bus 50452	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50452	: Pg=62.24, Qg=-9.14 -> Pg=74.7, Qg=6.75
% INFO    : Gen at bus 50452	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50452	: Pg=62.24, Qg=-9.14 -> Pg=74.7, Qg=6.75
% INFO    : Gen at bus 50452	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50452	: Pg=62.24, Qg=-9.14 -> Pg=74.7, Qg=6.75
% INFO    : Gen at bus 50452	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50452	: Pg=62.24, Qg=-9.14 -> Pg=74.7, Qg=6.75
% INFO    : Gen at bus 50452	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50453	: Pg=105.88, Qg=-6.12 -> Pg=108.95, Qg=16.45
% INFO    : Gen at bus 50453	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50453	: Pg=490.41, Qg=-6.12 -> Pg=506.25, Qg=40.45
% INFO    : Gen at bus 50453	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50453	: Pg=62.24, Qg=-6.12 -> Pg=74.7, Qg=6.75
% INFO    : Gen at bus 50453	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50453	: Pg=62.24, Qg=-6.12 -> Pg=74.7, Qg=6.75
% INFO    : Gen at bus 50453	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50453	: Pg=62.24, Qg=-6.12 -> Pg=74.7, Qg=6.75
% INFO    : Gen at bus 50453	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50453	: Pg=62.24, Qg=-6.12 -> Pg=74.7, Qg=6.75
% INFO    : Gen at bus 50453	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50453	: Pg=62.24, Qg=-6.12 -> Pg=74.7, Qg=6.75
% INFO    : Gen at bus 50453	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50454	: Pg=376.83, Qg=191.15 -> Pg=495.505, Qg=61.45
% INFO    : Gen at bus 50454	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50454	: Pg=62.24, Qg=43.3 -> Pg=74.7, Qg=6.75
% INFO    : Gen at bus 50454	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50454	: Pg=62.24, Qg=43.3 -> Pg=74.7, Qg=6.75
% INFO    : Gen at bus 50454	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50454	: Pg=62.24, Qg=43.3 -> Pg=74.7, Qg=6.75
% INFO    : Gen at bus 50454	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50454	: Pg=62.24, Qg=43.3 -> Pg=74.7, Qg=6.75
% INFO    : Gen at bus 50454	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50455	: Pg=52.21, Qg=54.7 -> Pg=69.1, Qg=12.65
% INFO    : Gen at bus 50455	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50455	: Pg=52.21, Qg=54.7 -> Pg=69.1, Qg=12.65
% INFO    : Gen at bus 50455	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50456	: Pg=42.2, Qg=28.5 -> Pg=63.9, Qg=12.55
% INFO    : Gen at bus 50456	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50456	: Pg=42.2, Qg=28.5 -> Pg=63.9, Qg=12.55
% INFO    : Gen at bus 50456	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50456	: Pg=42.44, Qg=28.5 -> Pg=55.0, Qg=12.9
% INFO    : Gen at bus 50456	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50457	: Pg=44.17, Qg=53.6 -> Pg=64.25, Qg=12.4
% INFO    : Gen at bus 50457	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50457	: Pg=44.17, Qg=53.6 -> Pg=64.25, Qg=12.4
% INFO    : Gen at bus 50457	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50458	: Pg=121.8, Qg=9.15 -> Pg=75.9, Qg=17.45
% INFO    : Gen at bus 50458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50458	: Pg=81.6, Qg=9.15 -> Pg=54.8, Qg=11.7
% INFO    : Gen at bus 50458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50458	: Pg=81.6, Qg=9.15 -> Pg=54.8, Qg=11.7
% INFO    : Gen at bus 50458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50458	: Pg=85.0, Qg=9.15 -> Pg=57.5, Qg=6.45
% INFO    : Gen at bus 50458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50458	: Pg=30.33, Qg=9.15 -> Pg=57.5, Qg=6.45
% INFO    : Gen at bus 50458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50458	: Pg=25.46, Qg=9.15 -> Pg=72.5, Qg=9.05
% INFO    : Gen at bus 50458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50458	: Pg=45.33, Qg=9.15 -> Pg=65.75, Qg=12.4
% INFO    : Gen at bus 50458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50458	: Pg=45.33, Qg=9.15 -> Pg=65.75, Qg=12.4
% INFO    : Gen at bus 50458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50459	: Pg=44.13, Qg=52.7 -> Pg=63.5, Qg=12.2
% INFO    : Gen at bus 50459	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50459	: Pg=44.13, Qg=52.7 -> Pg=63.5, Qg=12.2
% INFO    : Gen at bus 50459	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50460	: Pg=55.0, Qg=41.1 -> Pg=69.95, Qg=6.4
% INFO    : Gen at bus 50460	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50460	: Pg=52.0, Qg=50.5 -> Pg=78.1, Qg=7.9
% INFO    : Gen at bus 50460	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50460	: Pg=52.0, Qg=50.5 -> Pg=78.1, Qg=7.9
% INFO    : Gen at bus 50460	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50460	: Pg=41.18, Qg=54.2 -> Pg=56.2, Qg=12.55
% INFO    : Gen at bus 50460	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50461	: Pg=45.93, Qg=44.1 -> Pg=64.35, Qg=12.15
% INFO    : Gen at bus 50461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50461	: Pg=45.83, Qg=44.1 -> Pg=64.3, Qg=12.15
% INFO    : Gen at bus 50461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50461	: Pg=45.33, Qg=44.1 -> Pg=64.05, Qg=12.15
% INFO    : Gen at bus 50461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50461	: Pg=45.13, Qg=44.1 -> Pg=63.95, Qg=12.15
% INFO    : Gen at bus 50461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50461	: Pg=45.13, Qg=44.1 -> Pg=63.95, Qg=12.15
% INFO    : Gen at bus 50461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50461	: Pg=45.95, Qg=44.1 -> Pg=66.8, Qg=12.85
% INFO    : Gen at bus 50461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50461	: Pg=60.92, Qg=44.1 -> Pg=81.6, Qg=18.5
% INFO    : Gen at bus 50461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50462	: Pg=4.2, Qg=20.61 -> Pg=44.1, Qg=0.0
% INFO    : Gen at bus 50462	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50463	: Pg=73.84, Qg=75.8 -> Pg=90.8, Qg=11.8
% INFO    : Gen at bus 50463	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50463	: Pg=53.47, Qg=70.3 -> Pg=66.7, Qg=16.25
% INFO    : Gen at bus 50463	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50463	: Pg=35.36, Qg=46.5 -> Pg=42.5, Qg=10.75
% INFO    : Gen at bus 50463	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50463	: Pg=57.07, Qg=51.3 -> Pg=68.85, Qg=11.85
% INFO    : Gen at bus 50463	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50464	: Pg=4.1, Qg=10.8 -> Pg=43.3, Qg=0.0
% INFO    : Gen at bus 50464	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50467	: Pg=80.5, Qg=-12.91 -> Pg=40.25, Qg=0.0
% INFO    : Gen at bus 50467	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50469	: Pg=0.5, Qg=31.5 -> Pg=40.15, Qg=0.0
% INFO    : Gen at bus 50469	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50470	: Pg=111.28, Qg=127.36 -> Pg=118.0, Qg=33.8
% INFO    : Gen at bus 50470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50470	: Pg=37.53, Qg=59.7 -> Pg=51.145, Qg=16.6
% INFO    : Gen at bus 50470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50471	: Pg=79.5, Qg=27.55 -> Pg=41.75, Qg=0.0
% INFO    : Gen at bus 50471	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50472	: Pg=34.7, Qg=21.5 -> Pg=34.35, Qg=4.95
% INFO    : Gen at bus 50472	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50472	: Pg=51.96, Qg=22.96 -> Pg=64.1, Qg=11.2
% INFO    : Gen at bus 50472	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50472	: Pg=51.96, Qg=22.96 -> Pg=64.1, Qg=11.2
% INFO    : Gen at bus 50472	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50473	: Pg=78.0, Qg=9.74 -> Pg=43.0, Qg=0.0
% INFO    : Gen at bus 50473	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50473	: Pg=67.2, Qg=9.74 -> Pg=45.0, Qg=0.0
% INFO    : Gen at bus 50473	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50474	: Pg=46.94, Qg=7.66 -> Pg=61.25, Qg=11.1
% INFO    : Gen at bus 50474	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50474	: Pg=46.94, Qg=7.66 -> Pg=61.25, Qg=11.1
% INFO    : Gen at bus 50474	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50474	: Pg=41.88, Qg=7.66 -> Pg=57.5, Qg=10.75
% INFO    : Gen at bus 50474	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50475	: Pg=46.88, Qg=56.3 -> Pg=60.0, Qg=15.65
% INFO    : Gen at bus 50475	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50475	: Pg=46.88, Qg=56.3 -> Pg=60.0, Qg=15.65
% INFO    : Gen at bus 50475	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50475	: Pg=46.88, Qg=56.3 -> Pg=60.0, Qg=15.65
% INFO    : Gen at bus 50475	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50475	: Pg=46.88, Qg=56.3 -> Pg=60.0, Qg=15.65
% INFO    : Gen at bus 50475	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50476	: Pg=3.7, Qg=-15.98 -> Pg=39.35, Qg=0.0
% INFO    : Gen at bus 50476	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50477	: Pg=56.88, Qg=21.61 -> Pg=65.0, Qg=5.65
% INFO    : Gen at bus 50477	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50477	: Pg=56.88, Qg=21.61 -> Pg=65.0, Qg=5.65
% INFO    : Gen at bus 50477	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50477	: Pg=61.13, Qg=21.61 -> Pg=91.5, Qg=9.4
% INFO    : Gen at bus 50477	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50477	: Pg=61.13, Qg=21.61 -> Pg=91.5, Qg=9.4
% INFO    : Gen at bus 50477	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50477	: Pg=57.17, Qg=21.61 -> Pg=70.75, Qg=12.4
% INFO    : Gen at bus 50477	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50477	: Pg=57.17, Qg=21.61 -> Pg=70.75, Qg=12.4
% INFO    : Gen at bus 50477	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50478	: Pg=0.0, Qg=-1.99 -> Pg=37.5, Qg=0.0
% INFO    : Gen at bus 50478	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50478	: Pg=0.0, Qg=-1.99 -> Pg=37.5, Qg=0.0
% INFO    : Gen at bus 50478	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50479	: Pg=210.48, Qg=216.2 -> Pg=243.2, Qg=33.7
% INFO    : Gen at bus 50479	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50479	: Pg=33.95, Qg=34.9 -> Pg=51.0, Qg=5.45
% INFO    : Gen at bus 50479	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50479	: Pg=33.95, Qg=34.9 -> Pg=51.0, Qg=5.45
% INFO    : Gen at bus 50479	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50479	: Pg=33.95, Qg=34.9 -> Pg=51.0, Qg=5.45
% INFO    : Gen at bus 50479	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50479	: Pg=33.95, Qg=34.9 -> Pg=51.0, Qg=5.45
% INFO    : Gen at bus 50479	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50479	: Pg=33.95, Qg=34.9 -> Pg=51.0, Qg=5.45
% INFO    : Gen at bus 50479	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50479	: Pg=33.95, Qg=34.9 -> Pg=51.0, Qg=5.45
% INFO    : Gen at bus 50479	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50481	: Pg=94.3, Qg=81.6 -> Pg=120.0, Qg=15.1
% INFO    : Gen at bus 50481	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50481	: Pg=47.15, Qg=62.0 -> Pg=69.0, Qg=14.35
% INFO    : Gen at bus 50481	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50481	: Pg=21.65, Qg=40.9 -> Pg=43.0, Qg=9.45
% INFO    : Gen at bus 50481	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50483	: Pg=0.1, Qg=0.0 -> Pg=31.55, Qg=0.0
% INFO    : Gen at bus 50483	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50485	: Pg=106.09, Qg=29.83 -> Pg=142.5, Qg=32.2
% INFO    : Gen at bus 50485	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50485	: Pg=118.82, Qg=29.83 -> Pg=156.0, Qg=36.1
% INFO    : Gen at bus 50485	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50485	: Pg=28.76, Qg=29.83 -> Pg=40.5, Qg=8.75
% INFO    : Gen at bus 50485	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50485	: Pg=28.76, Qg=29.83 -> Pg=40.5, Qg=8.75
% INFO    : Gen at bus 50485	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50485	: Pg=28.76, Qg=29.83 -> Pg=40.5, Qg=8.75
% INFO    : Gen at bus 50485	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50485	: Pg=28.76, Qg=29.83 -> Pg=40.5, Qg=8.75
% INFO    : Gen at bus 50485	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50485	: Pg=196.62, Qg=29.83 -> Pg=243.5, Qg=59.7
% INFO    : Gen at bus 50485	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50486	: Pg=13.52, Qg=-3.55 -> Pg=36.25, Qg=8.65
% INFO    : Gen at bus 50486	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50486	: Pg=13.52, Qg=-3.55 -> Pg=36.25, Qg=8.65
% INFO    : Gen at bus 50486	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50486	: Pg=4.82, Qg=-3.55 -> Pg=18.45, Qg=4.7
% INFO    : Gen at bus 50486	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50488	: Pg=60.0, Qg=-0.57 -> Pg=36.0, Qg=0.0
% INFO    : Gen at bus 50488	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50489	: Pg=0.1, Qg=23.7 -> Pg=30.05, Qg=0.0
% INFO    : Gen at bus 50489	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50489	: Pg=0.1, Qg=40.8 -> Pg=46.3, Qg=0.0
% INFO    : Gen at bus 50489	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50492	: Pg=0.1, Qg=-0.12 -> Pg=29.45, Qg=0.0
% INFO    : Gen at bus 50492	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50493	: Pg=10.85, Qg=6.33 -> Pg=14.8, Qg=0.0
% INFO    : Gen at bus 50493	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50493	: Pg=10.85, Qg=6.33 -> Pg=14.8, Qg=0.0
% INFO    : Gen at bus 50493	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50493	: Pg=10.85, Qg=6.33 -> Pg=14.8, Qg=0.0
% INFO    : Gen at bus 50493	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50493	: Pg=17.12, Qg=10.7 -> Pg=24.45, Qg=0.0
% INFO    : Gen at bus 50493	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50494	: Pg=113.7, Qg=64.4 -> Pg=71.06, Qg=13.25
% INFO    : Gen at bus 50494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50494	: Pg=27.06, Qg=35.6 -> Pg=38.7, Qg=8.25
% INFO    : Gen at bus 50494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50494	: Pg=27.06, Qg=35.6 -> Pg=38.7, Qg=8.25
% INFO    : Gen at bus 50494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50494	: Pg=27.06, Qg=35.6 -> Pg=38.7, Qg=8.25
% INFO    : Gen at bus 50494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50494	: Pg=27.06, Qg=35.6 -> Pg=38.7, Qg=8.25
% INFO    : Gen at bus 50494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50494	: Pg=35.36, Qg=43.1 -> Pg=48.19, Qg=9.05
% INFO    : Gen at bus 50494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50495	: Pg=29.0, Qg=24.8 -> Pg=34.0, Qg=5.75
% INFO    : Gen at bus 50495	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50495	: Pg=26.4, Qg=27.1 -> Pg=33.0, Qg=4.2
% INFO    : Gen at bus 50495	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50496	: Pg=11.46, Qg=0.0 -> Pg=14.65, Qg=0.0
% INFO    : Gen at bus 50496	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50496	: Pg=11.46, Qg=0.0 -> Pg=14.65, Qg=0.0
% INFO    : Gen at bus 50496	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50496	: Pg=11.46, Qg=0.0 -> Pg=14.65, Qg=0.0
% INFO    : Gen at bus 50496	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50497	: Pg=54.0, Qg=26.2 -> Pg=53.5, Qg=4.1
% INFO    : Gen at bus 50497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50497	: Pg=44.13, Qg=41.2 -> Pg=63.5, Qg=6.45
% INFO    : Gen at bus 50497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50497	: Pg=44.13, Qg=41.2 -> Pg=63.5, Qg=6.45
% INFO    : Gen at bus 50497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50497	: Pg=42.13, Qg=41.2 -> Pg=62.5, Qg=6.45
% INFO    : Gen at bus 50497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50497	: Pg=40.13, Qg=41.2 -> Pg=61.5, Qg=6.45
% INFO    : Gen at bus 50497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50497	: Pg=40.13, Qg=41.2 -> Pg=61.5, Qg=6.45
% INFO    : Gen at bus 50497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50497	: Pg=53.33, Qg=70.1 -> Pg=70.05, Qg=16.2
% INFO    : Gen at bus 50497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50497	: Pg=53.33, Qg=70.1 -> Pg=70.05, Qg=16.2
% INFO    : Gen at bus 50497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50497	: Pg=54.0, Qg=26.2 -> Pg=53.5, Qg=4.1
% INFO    : Gen at bus 50497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50497	: Pg=54.0, Qg=26.2 -> Pg=53.5, Qg=4.1
% INFO    : Gen at bus 50497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50497	: Pg=54.0, Qg=26.2 -> Pg=53.5, Qg=4.1
% INFO    : Gen at bus 50497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50497	: Pg=54.0, Qg=26.2 -> Pg=53.5, Qg=4.1
% INFO    : Gen at bus 50497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50497	: Pg=54.42, Qg=27.5 -> Pg=54.85, Qg=4.3
% INFO    : Gen at bus 50497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50497	: Pg=54.42, Qg=27.5 -> Pg=54.85, Qg=4.3
% INFO    : Gen at bus 50497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50497	: Pg=54.0, Qg=33.5 -> Pg=53.5, Qg=7.75
% INFO    : Gen at bus 50497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50497	: Pg=50.13, Qg=41.2 -> Pg=66.5, Qg=6.45
% INFO    : Gen at bus 50497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50499	: Pg=50.25, Qg=24.9 -> Pg=50.25, Qg=3.85
% INFO    : Gen at bus 50499	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50499	: Pg=50.25, Qg=24.9 -> Pg=50.25, Qg=3.85
% INFO    : Gen at bus 50499	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50499	: Pg=50.25, Qg=24.9 -> Pg=50.25, Qg=3.85
% INFO    : Gen at bus 50499	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50499	: Pg=50.25, Qg=24.9 -> Pg=50.25, Qg=3.85
% INFO    : Gen at bus 50499	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50499	: Pg=190.96, Qg=196.2 -> Pg=227.5, Qg=30.6
% INFO    : Gen at bus 50499	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50499	: Pg=151.36, Qg=198.9 -> Pg=185.5, Qg=45.95
% INFO    : Gen at bus 50499	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50500	: Pg=75.0, Qg=56.3 -> Pg=57.5, Qg=15.65
% INFO    : Gen at bus 50500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50500	: Pg=49.33, Qg=56.3 -> Pg=57.5, Qg=15.65
% INFO    : Gen at bus 50500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50500	: Pg=38.7, Qg=38.3 -> Pg=30.5, Qg=10.65
% INFO    : Gen at bus 50500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50500	: Pg=38.7, Qg=38.3 -> Pg=30.5, Qg=10.65
% INFO    : Gen at bus 50500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50501	: Pg=61.0, Qg=37.8 -> Pg=38.0, Qg=8.75
% INFO    : Gen at bus 50501	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50501	: Pg=24.0, Qg=11.6 -> Pg=16.5, Qg=1.8
% INFO    : Gen at bus 50501	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50501	: Pg=50.0, Qg=31.0 -> Pg=41.0, Qg=7.15
% INFO    : Gen at bus 50501	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50501	: Pg=25.0, Qg=15.5 -> Pg=20.0, Qg=3.6
% INFO    : Gen at bus 50501	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50503	: Pg=23.13, Qg=25.62 -> Pg=30.55, Qg=7.0
% INFO    : Gen at bus 50503	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50503	: Pg=23.13, Qg=25.62 -> Pg=30.55, Qg=7.0
% INFO    : Gen at bus 50503	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50503	: Pg=49.51, Qg=25.62 -> Pg=58.5, Qg=7.95
% INFO    : Gen at bus 50503	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50504	: Pg=15.19, Qg=1.8 -> Pg=31.485, Qg=10.25
% INFO    : Gen at bus 50504	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50505	: Pg=59.77, Qg=6.78 -> Pg=122.7, Qg=27.25
% INFO    : Gen at bus 50505	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50505	: Pg=22.2, Qg=6.78 -> Pg=34.5, Qg=10.0
% INFO    : Gen at bus 50505	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50505	: Pg=37.45, Qg=6.78 -> Pg=66.5, Qg=20.4
% INFO    : Gen at bus 50505	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50505	: Pg=23.45, Qg=6.78 -> Pg=59.5, Qg=20.4
% INFO    : Gen at bus 50505	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50506	: Pg=27.98, Qg=29.7 -> Pg=35.0, Qg=6.85
% INFO    : Gen at bus 50506	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50510	: Pg=20.75, Qg=25.3 -> Pg=28.27, Qg=5.3
% INFO    : Gen at bus 50510	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50511	: Pg=28.04, Qg=0.0 -> Pg=34.3, Qg=0.0
% INFO    : Gen at bus 50511	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50511	: Pg=28.04, Qg=0.0 -> Pg=34.3, Qg=0.0
% INFO    : Gen at bus 50511	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50512	: Pg=23.23, Qg=25.4 -> Pg=31.6, Qg=5.85
% INFO    : Gen at bus 50512	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50513	: Pg=33.01, Qg=13.3 -> Pg=36.25, Qg=0.0
% INFO    : Gen at bus 50513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50513	: Pg=33.01, Qg=13.3 -> Pg=36.25, Qg=0.0
% INFO    : Gen at bus 50513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50515	: Pg=25.99, Qg=24.6 -> Pg=32.35, Qg=5.7
% INFO    : Gen at bus 50515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50515	: Pg=25.99, Qg=24.6 -> Pg=32.35, Qg=5.7
% INFO    : Gen at bus 50515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50515	: Pg=25.99, Qg=24.6 -> Pg=32.35, Qg=5.7
% INFO    : Gen at bus 50515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50515	: Pg=52.48, Qg=46.91 -> Pg=74.45, Qg=14.15
% INFO    : Gen at bus 50515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50515	: Pg=84.1, Qg=46.91 -> Pg=121.9, Qg=23.45
% INFO    : Gen at bus 50515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50516	: Pg=9.5, Qg=9.6 -> Pg=14.4, Qg=1.5
% INFO    : Gen at bus 50516	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50516	: Pg=9.5, Qg=9.6 -> Pg=14.4, Qg=1.5
% INFO    : Gen at bus 50516	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50517	: Pg=18.97, Qg=15.3 -> Pg=28.3, Qg=0.0
% INFO    : Gen at bus 50517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50517	: Pg=94.08, Qg=40.9 -> Pg=126.5, Qg=0.0
% INFO    : Gen at bus 50517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50517	: Pg=94.08, Qg=40.9 -> Pg=126.5, Qg=0.0
% INFO    : Gen at bus 50517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50517	: Pg=94.08, Qg=47.5 -> Pg=126.5, Qg=0.0
% INFO    : Gen at bus 50517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50518	: Pg=18.2, Qg=29.0 -> Pg=24.3, Qg=8.05
% INFO    : Gen at bus 50518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50518	: Pg=18.2, Qg=29.0 -> Pg=24.3, Qg=8.05
% INFO    : Gen at bus 50518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50519	: Pg=20.96, Qg=18.6 -> Pg=29.2, Qg=2.9
% INFO    : Gen at bus 50519	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50520	: Pg=17.92, Qg=23.6 -> Pg=24.0, Qg=5.45
% INFO    : Gen at bus 50520	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50520	: Pg=17.92, Qg=23.6 -> Pg=24.0, Qg=5.45
% INFO    : Gen at bus 50520	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50520	: Pg=34.89, Qg=27.3 -> Pg=47.0, Qg=15.4
% INFO    : Gen at bus 50520	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50520	: Pg=165.5, Qg=27.3 -> Pg=193.0, Qg=26.5
% INFO    : Gen at bus 50520	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50522	: Pg=3.44, Qg=17.1 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 50522	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50523	: Pg=37.5, Qg=-6.26 -> Pg=18.75, Qg=0.0
% INFO    : Gen at bus 50523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50524	: Pg=27.94, Qg=23.2 -> Pg=32.2, Qg=5.35
% INFO    : Gen at bus 50524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50524	: Pg=27.94, Qg=23.2 -> Pg=32.2, Qg=5.35
% INFO    : Gen at bus 50524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50524	: Pg=14.95, Qg=19.6 -> Pg=19.35, Qg=4.5
% INFO    : Gen at bus 50524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50525	: Pg=37.0, Qg=22.5 -> Pg=22.2, Qg=5.1
% INFO    : Gen at bus 50525	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50526	: Pg=16.5, Qg=26.3 -> Pg=21.5, Qg=7.3
% INFO    : Gen at bus 50526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50527	: Pg=13.99, Qg=13.6 -> Pg=17.15, Qg=0.0
% INFO    : Gen at bus 50527	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50530	: Pg=10.5, Qg=3.88 -> Pg=6.75, Qg=0.8
% INFO    : Gen at bus 50530	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50530	: Pg=10.5, Qg=3.88 -> Pg=6.75, Qg=0.8
% INFO    : Gen at bus 50530	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50530	: Pg=10.5, Qg=3.88 -> Pg=6.75, Qg=0.8
% INFO    : Gen at bus 50530	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50531	: Pg=13.01, Qg=14.93 -> Pg=20.45, Qg=3.25
% INFO    : Gen at bus 50531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50532	: Pg=13.49, Qg=21.5 -> Pg=16.8, Qg=6.0
% INFO    : Gen at bus 50532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50532	: Pg=13.49, Qg=21.5 -> Pg=16.8, Qg=6.0
% INFO    : Gen at bus 50532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50533	: Pg=12.26, Qg=8.5 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 50533	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50533	: Pg=12.26, Qg=8.5 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 50533	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50534	: Pg=2.71, Qg=1.5 -> Pg=2.93, Qg=0.665
% INFO    : Gen at bus 50534	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50534	: Pg=2.71, Qg=1.5 -> Pg=2.93, Qg=0.665
% INFO    : Gen at bus 50534	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50534	: Pg=2.71, Qg=1.5 -> Pg=2.93, Qg=0.665
% INFO    : Gen at bus 50534	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50534	: Pg=2.71, Qg=1.5 -> Pg=2.93, Qg=0.665
% INFO    : Gen at bus 50534	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50534	: Pg=2.71, Qg=1.5 -> Pg=2.93, Qg=0.665
% INFO    : Gen at bus 50534	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50534	: Pg=2.71, Qg=1.5 -> Pg=2.93, Qg=0.665
% INFO    : Gen at bus 50534	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50534	: Pg=2.71, Qg=1.5 -> Pg=2.93, Qg=0.665
% INFO    : Gen at bus 50534	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50534	: Pg=2.71, Qg=1.5 -> Pg=2.93, Qg=0.665
% INFO    : Gen at bus 50534	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50535	: Pg=6.24, Qg=6.3 -> Pg=7.2, Qg=1.75
% INFO    : Gen at bus 50535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50535	: Pg=6.24, Qg=6.3 -> Pg=7.2, Qg=1.75
% INFO    : Gen at bus 50535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50535	: Pg=6.24, Qg=6.3 -> Pg=7.2, Qg=1.75
% INFO    : Gen at bus 50535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50535	: Pg=20.37, Qg=8.51 -> Pg=28.1, Qg=3.25
% INFO    : Gen at bus 50535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50535	: Pg=11.79, Qg=8.51 -> Pg=17.5, Qg=3.6
% INFO    : Gen at bus 50535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50536	: Pg=11.79, Qg=15.5 -> Pg=15.0, Qg=3.6
% INFO    : Gen at bus 50536	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50536	: Pg=37.09, Qg=24.8 -> Pg=22.5, Qg=5.75
% INFO    : Gen at bus 50536	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50537	: Pg=18.91, Qg=22.6 -> Pg=27.25, Qg=5.2
% INFO    : Gen at bus 50537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50537	: Pg=18.91, Qg=22.6 -> Pg=27.25, Qg=5.2
% INFO    : Gen at bus 50537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50537	: Pg=16.61, Qg=18.2 -> Pg=20.1, Qg=5.05
% INFO    : Gen at bus 50537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50537	: Pg=16.61, Qg=18.2 -> Pg=20.1, Qg=5.05
% INFO    : Gen at bus 50537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50537	: Pg=16.61, Qg=18.2 -> Pg=20.1, Qg=5.05
% INFO    : Gen at bus 50537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50537	: Pg=16.61, Qg=18.2 -> Pg=20.1, Qg=5.05
% INFO    : Gen at bus 50537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50539	: Pg=11.22, Qg=14.7 -> Pg=12.9, Qg=3.4
% INFO    : Gen at bus 50539	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50540	: Pg=2.73, Qg=4.4 -> Pg=3.62, Qg=1.225
% INFO    : Gen at bus 50540	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50540	: Pg=2.73, Qg=4.4 -> Pg=3.62, Qg=1.225
% INFO    : Gen at bus 50540	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50540	: Pg=2.73, Qg=4.4 -> Pg=3.62, Qg=1.225
% INFO    : Gen at bus 50540	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50540	: Pg=2.73, Qg=4.4 -> Pg=3.62, Qg=1.225
% INFO    : Gen at bus 50540	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50541	: Pg=10.59, Qg=14.5 -> Pg=16.7, Qg=3.35
% INFO    : Gen at bus 50541	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50542	: Pg=1.15, Qg=7.15 -> Pg=5.75, Qg=1.65
% INFO    : Gen at bus 50542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50542	: Pg=0.29, Qg=7.15 -> Pg=5.75, Qg=1.65
% INFO    : Gen at bus 50542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50542	: Pg=31.0, Qg=19.4 -> Pg=35.0, Qg=3.05
% INFO    : Gen at bus 50542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50542	: Pg=10.55, Qg=10.7 -> Pg=16.0, Qg=1.7
% INFO    : Gen at bus 50542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50542	: Pg=10.55, Qg=10.7 -> Pg=16.0, Qg=1.7
% INFO    : Gen at bus 50542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50543	: Pg=5.28, Qg=6.71 -> Pg=7.6, Qg=1.6
% INFO    : Gen at bus 50543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50543	: Pg=5.28, Qg=6.71 -> Pg=7.6, Qg=1.6
% INFO    : Gen at bus 50543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50543	: Pg=11.79, Qg=6.71 -> Pg=16.06, Qg=3.05
% INFO    : Gen at bus 50543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50543	: Pg=19.8, Qg=6.71 -> Pg=24.5, Qg=3.15
% INFO    : Gen at bus 50543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50543	: Pg=23.2, Qg=6.71 -> Pg=28.6, Qg=7.05
% INFO    : Gen at bus 50543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50543	: Pg=23.2, Qg=6.71 -> Pg=28.6, Qg=7.05
% INFO    : Gen at bus 50543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50543	: Pg=23.2, Qg=6.71 -> Pg=28.6, Qg=7.05
% INFO    : Gen at bus 50543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50544	: Pg=10.37, Qg=10.7 -> Pg=13.5, Qg=1.7
% INFO    : Gen at bus 50544	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50544	: Pg=25.46, Qg=33.5 -> Pg=33.0, Qg=7.75
% INFO    : Gen at bus 50544	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50544	: Pg=11.32, Qg=14.9 -> Pg=14.5, Qg=3.45
% INFO    : Gen at bus 50544	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50544	: Pg=11.79, Qg=15.5 -> Pg=15.0, Qg=3.6
% INFO    : Gen at bus 50544	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50547	: Pg=5.5, Qg=0.0 -> Pg=12.5, Qg=0.0
% INFO    : Gen at bus 50547	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50549	: Pg=2.5, Qg=15.0 -> Pg=11.0, Qg=4.15
% INFO    : Gen at bus 50549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50549	: Pg=2.5, Qg=15.0 -> Pg=11.0, Qg=4.15
% INFO    : Gen at bus 50549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50549	: Pg=2.5, Qg=15.0 -> Pg=11.0, Qg=4.15
% INFO    : Gen at bus 50549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 50549	: Pg=2.5, Qg=15.0 -> Pg=11.0, Qg=4.15
% INFO    : Gen at bus 50549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75451	: Pg=41.14, Qg=37.5 -> Pg=39.75, Qg=8.65
% INFO    : Gen at bus 75451	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75451	: Pg=41.14, Qg=37.5 -> Pg=39.75, Qg=8.65
% INFO    : Gen at bus 75451	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75451	: Pg=41.14, Qg=37.5 -> Pg=39.75, Qg=8.65
% INFO    : Gen at bus 75451	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75451	: Pg=41.14, Qg=37.5 -> Pg=39.75, Qg=8.65
% INFO    : Gen at bus 75451	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75461	: Pg=3.54, Qg=3.55 -> Pg=4.05, Qg=0.0
% INFO    : Gen at bus 75461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75461	: Pg=3.54, Qg=3.55 -> Pg=4.05, Qg=0.0
% INFO    : Gen at bus 75461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75461	: Pg=3.54, Qg=3.55 -> Pg=4.05, Qg=0.0
% INFO    : Gen at bus 75461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75461	: Pg=3.54, Qg=3.55 -> Pg=4.05, Qg=0.0
% INFO    : Gen at bus 75461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75462	: Pg=17.48, Qg=5.2 -> Pg=17.75, Qg=0.0
% INFO    : Gen at bus 75462	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75493	: Pg=33.39, Qg=30.4 -> Pg=40.55, Qg=7.0
% INFO    : Gen at bus 75493	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75493	: Pg=91.23, Qg=79.9 -> Pg=108.45, Qg=18.45
% INFO    : Gen at bus 75493	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75496	: Pg=62.03, Qg=44.32 -> Pg=70.45, Qg=11.55
% INFO    : Gen at bus 75496	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75496	: Pg=66.25, Qg=44.32 -> Pg=77.0, Qg=12.9
% INFO    : Gen at bus 75496	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75496	: Pg=66.25, Qg=44.32 -> Pg=77.0, Qg=12.9
% INFO    : Gen at bus 75496	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75497	: Pg=29.45, Qg=35.9 -> Pg=43.0, Qg=8.3
% INFO    : Gen at bus 75497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75497	: Pg=29.45, Qg=35.9 -> Pg=43.0, Qg=8.3
% INFO    : Gen at bus 75497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75497	: Pg=8.63, Qg=12.1 -> Pg=16.5, Qg=1.9
% INFO    : Gen at bus 75497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75497	: Pg=38.9, Qg=36.8 -> Pg=56.5, Qg=5.75
% INFO    : Gen at bus 75497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75503	: Pg=31.28, Qg=22.3 -> Pg=25.05, Qg=3.5
% INFO    : Gen at bus 75503	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75508	: Pg=14.53, Qg=10.3 -> Pg=17.6, Qg=1.6
% INFO    : Gen at bus 75508	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75509	: Pg=15.54, Qg=12.6 -> Pg=17.7, Qg=2.9
% INFO    : Gen at bus 75509	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75510	: Pg=3.1, Qg=5.75 -> Pg=6.425, Qg=1.2
% INFO    : Gen at bus 75510	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75510	: Pg=3.1, Qg=5.75 -> Pg=6.425, Qg=1.2
% INFO    : Gen at bus 75510	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75511	: Pg=48.96, Qg=44.6 -> Pg=41.0, Qg=10.3
% INFO    : Gen at bus 75511	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75511	: Pg=127.03, Qg=62.82 -> Pg=148.4, Qg=26.75
% INFO    : Gen at bus 75511	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75514	: Pg=122.0, Qg=1.94 -> Pg=132.2, Qg=25.7
% INFO    : Gen at bus 75514	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75514	: Pg=64.67, Qg=1.94 -> Pg=70.05, Qg=13.6
% INFO    : Gen at bus 75514	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75517	: Pg=9.48, Qg=-0.96 -> Pg=14.005, Qg=3.35
% INFO    : Gen at bus 75517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75517	: Pg=9.48, Qg=-0.96 -> Pg=14.005, Qg=3.35
% INFO    : Gen at bus 75517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75517	: Pg=9.48, Qg=-0.96 -> Pg=14.005, Qg=3.35
% INFO    : Gen at bus 75517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75517	: Pg=9.48, Qg=-0.96 -> Pg=14.005, Qg=3.35
% INFO    : Gen at bus 75517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75517	: Pg=8.46, Qg=-0.96 -> Pg=15.98, Qg=3.4
% INFO    : Gen at bus 75517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75517	: Pg=11.34, Qg=-0.96 -> Pg=21.42, Qg=4.5
% INFO    : Gen at bus 75517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75518	: Pg=20.54, Qg=0.0 -> Pg=15.35, Qg=0.0
% INFO    : Gen at bus 75518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75518	: Pg=13.92, Qg=-0.75 -> Pg=10.405, Qg=2.335
% INFO    : Gen at bus 75518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75518	: Pg=13.92, Qg=-0.75 -> Pg=10.405, Qg=2.335
% INFO    : Gen at bus 75518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75518	: Pg=13.92, Qg=-0.75 -> Pg=10.405, Qg=2.335
% INFO    : Gen at bus 75518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75527	: Pg=11.9, Qg=10.85 -> Pg=9.75, Qg=2.5
% INFO    : Gen at bus 75527	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75527	: Pg=11.9, Qg=10.85 -> Pg=9.75, Qg=2.5
% INFO    : Gen at bus 75527	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75530	: Pg=18.7, Qg=17.0 -> Pg=16.75, Qg=3.9
% INFO    : Gen at bus 75530	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75534	: Pg=15.64, Qg=12.52 -> Pg=15.0, Qg=4.8
% INFO    : Gen at bus 75534	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75534	: Pg=18.22, Qg=12.52 -> Pg=16.9, Qg=5.6
% INFO    : Gen at bus 75534	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75546	: Pg=0.98, Qg=0.7 -> Pg=0.77, Qg=0.11
% INFO    : Gen at bus 75546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75553	: Pg=28.36, Qg=20.2 -> Pg=33.4, Qg=3.15
% INFO    : Gen at bus 75553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75553	: Pg=18.36, Qg=13.1 -> Pg=16.5, Qg=2.05
% INFO    : Gen at bus 75553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75554	: Pg=1.17, Qg=0.99 -> Pg=1.33, Qg=0.33
% INFO    : Gen at bus 75554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75554	: Pg=1.17, Qg=0.99 -> Pg=1.33, Qg=0.33
% INFO    : Gen at bus 75554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75554	: Pg=1.17, Qg=0.99 -> Pg=1.33, Qg=0.33
% INFO    : Gen at bus 75554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75554	: Pg=1.17, Qg=0.99 -> Pg=1.33, Qg=0.33
% INFO    : Gen at bus 75554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75554	: Pg=1.17, Qg=0.99 -> Pg=1.33, Qg=0.33
% INFO    : Gen at bus 75554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75554	: Pg=1.17, Qg=0.99 -> Pg=1.33, Qg=0.33
% INFO    : Gen at bus 75554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75554	: Pg=1.17, Qg=0.99 -> Pg=1.33, Qg=0.33
% INFO    : Gen at bus 75554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75554	: Pg=1.17, Qg=0.99 -> Pg=1.33, Qg=0.33
% INFO    : Gen at bus 75554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75554	: Pg=1.17, Qg=0.99 -> Pg=1.33, Qg=0.33
% INFO    : Gen at bus 75554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75554	: Pg=1.17, Qg=0.99 -> Pg=1.33, Qg=0.33
% INFO    : Gen at bus 75554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75554	: Pg=1.17, Qg=0.99 -> Pg=1.33, Qg=0.33
% INFO    : Gen at bus 75554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75554	: Pg=1.17, Qg=0.99 -> Pg=1.33, Qg=0.33
% INFO    : Gen at bus 75554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75554	: Pg=1.17, Qg=0.99 -> Pg=1.33, Qg=0.33
% INFO    : Gen at bus 75554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75554	: Pg=1.17, Qg=0.99 -> Pg=1.33, Qg=0.33
% INFO    : Gen at bus 75554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75554	: Pg=1.17, Qg=0.99 -> Pg=1.33, Qg=0.33
% INFO    : Gen at bus 75554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75555	: Pg=28.06, Qg=28.8 -> Pg=37.25, Qg=4.5
% INFO    : Gen at bus 75555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75557	: Pg=2.78, Qg=1.69 -> Pg=3.095, Qg=0.265
% INFO    : Gen at bus 75557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75557	: Pg=2.78, Qg=1.69 -> Pg=3.095, Qg=0.265
% INFO    : Gen at bus 75557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75557	: Pg=2.78, Qg=1.69 -> Pg=3.095, Qg=0.265
% INFO    : Gen at bus 75557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75557	: Pg=2.78, Qg=1.69 -> Pg=3.095, Qg=0.265
% INFO    : Gen at bus 75557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75557	: Pg=2.78, Qg=1.69 -> Pg=3.095, Qg=0.265
% INFO    : Gen at bus 75557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75557	: Pg=2.78, Qg=1.69 -> Pg=3.095, Qg=0.265
% INFO    : Gen at bus 75557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75557	: Pg=2.78, Qg=1.69 -> Pg=3.095, Qg=0.265
% INFO    : Gen at bus 75557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75557	: Pg=2.78, Qg=1.69 -> Pg=3.095, Qg=0.265
% INFO    : Gen at bus 75557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75557	: Pg=2.78, Qg=1.69 -> Pg=3.095, Qg=0.265
% INFO    : Gen at bus 75557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75557	: Pg=2.78, Qg=1.69 -> Pg=3.095, Qg=0.265
% INFO    : Gen at bus 75557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76506	: Pg=31.68, Qg=57.5 -> Pg=64.25, Qg=12.1
% INFO    : Gen at bus 76506	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76516	: Pg=78.6, Qg=0.0 -> Pg=51.3, Qg=0.0
% INFO    : Gen at bus 76516	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76524	: Pg=60.5, Qg=19.9 -> Pg=42.75, Qg=0.0
% INFO    : Gen at bus 76524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76530	: Pg=31.52, Qg=18.5 -> Pg=34.45, Qg=2.85
% INFO    : Gen at bus 76530	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76530	: Pg=41.98, Qg=26.8 -> Pg=47.95, Qg=4.2
% INFO    : Gen at bus 76530	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76532	: Pg=43.0, Qg=26.6 -> Pg=37.6, Qg=6.15
% INFO    : Gen at bus 76532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76532	: Pg=55.0, Qg=34.1 -> Pg=46.4, Qg=7.9
% INFO    : Gen at bus 76532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76535	: Pg=38.38, Qg=25.7 -> Pg=45.0, Qg=4.0
% INFO    : Gen at bus 76535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76535	: Pg=43.94, Qg=25.7 -> Pg=45.0, Qg=4.0
% INFO    : Gen at bus 76535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76537	: Pg=50.0, Qg=24.2 -> Pg=44.95, Qg=3.75
% INFO    : Gen at bus 76537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76537	: Pg=50.0, Qg=24.2 -> Pg=44.95, Qg=3.75
% INFO    : Gen at bus 76537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76538	: Pg=50.0, Qg=20.77 -> Pg=44.95, Qg=3.75
% INFO    : Gen at bus 76538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76538	: Pg=50.0, Qg=20.77 -> Pg=44.95, Qg=3.75
% INFO    : Gen at bus 76538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76539	: Pg=50.0, Qg=37.5 -> Pg=45.0, Qg=10.4
% INFO    : Gen at bus 76539	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76539	: Pg=32.0, Qg=24.0 -> Pg=18.5, Qg=6.65
% INFO    : Gen at bus 76539	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76540	: Pg=46.26, Qg=30.5 -> Pg=47.1, Qg=7.05
% INFO    : Gen at bus 76540	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76540	: Pg=26.52, Qg=24.2 -> Pg=27.0, Qg=5.6
% INFO    : Gen at bus 76540	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76543	: Pg=31.22, Qg=30.2 -> Pg=39.35, Qg=7.0
% INFO    : Gen at bus 76543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76543	: Pg=31.22, Qg=30.2 -> Pg=39.35, Qg=7.0
% INFO    : Gen at bus 76543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76543	: Pg=31.22, Qg=30.2 -> Pg=39.35, Qg=7.0
% INFO    : Gen at bus 76543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76543	: Pg=35.46, Qg=15.3 -> Pg=44.6, Qg=0.0
% INFO    : Gen at bus 76543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76545	: Pg=47.3, Qg=22.9 -> Pg=28.15, Qg=3.55
% INFO    : Gen at bus 76545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76545	: Pg=24.5, Qg=11.9 -> Pg=14.75, Qg=1.85
% INFO    : Gen at bus 76545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76545	: Pg=24.5, Qg=11.9 -> Pg=14.75, Qg=1.85
% INFO    : Gen at bus 76545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76550	: Pg=46.5, Qg=22.5 -> Pg=25.75, Qg=3.5
% INFO    : Gen at bus 76550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76553	: Pg=28.49, Qg=20.3 -> Pg=23.45, Qg=3.15
% INFO    : Gen at bus 76553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76558	: Pg=4.9, Qg=3.53 -> Pg=3.64, Qg=0.95
% INFO    : Gen at bus 76558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76558	: Pg=4.9, Qg=3.53 -> Pg=3.64, Qg=0.95
% INFO    : Gen at bus 76558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76558	: Pg=4.9, Qg=3.53 -> Pg=3.64, Qg=0.95
% INFO    : Gen at bus 76558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76558	: Pg=4.9, Qg=3.53 -> Pg=3.64, Qg=0.95
% INFO    : Gen at bus 76558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76558	: Pg=4.9, Qg=3.53 -> Pg=3.64, Qg=0.95
% INFO    : Gen at bus 76558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76558	: Pg=4.9, Qg=3.53 -> Pg=3.64, Qg=0.95
% INFO    : Gen at bus 76558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76561	: Pg=17.0, Qg=0.0 -> Pg=13.0, Qg=0.0
% INFO    : Gen at bus 76561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76564	: Pg=10.18, Qg=12.8 -> Pg=11.8, Qg=2.8
% INFO    : Gen at bus 76564	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77631	: Pg=143.4, Qg=69.5 -> Pg=114.7, Qg=10.85
% INFO    : Gen at bus 77631	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77631	: Pg=143.4, Qg=69.5 -> Pg=114.7, Qg=10.85
% INFO    : Gen at bus 77631	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77631	: Pg=143.4, Qg=69.5 -> Pg=84.7, Qg=10.85
% INFO    : Gen at bus 77631	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77642	: Pg=28.83, Qg=26.3 -> Pg=31.29, Qg=6.1
% INFO    : Gen at bus 77642	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77642	: Pg=84.73, Qg=44.6 -> Pg=87.27, Qg=6.95
% INFO    : Gen at bus 77642	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77648	: Pg=18.6, Qg=11.53 -> Pg=10.8, Qg=2.665
% INFO    : Gen at bus 77648	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77648	: Pg=18.6, Qg=11.53 -> Pg=10.8, Qg=2.665
% INFO    : Gen at bus 77648	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77648	: Pg=18.6, Qg=11.53 -> Pg=10.8, Qg=2.665
% INFO    : Gen at bus 77648	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77655	: Pg=45.0, Qg=21.8 -> Pg=31.5, Qg=3.4
% INFO    : Gen at bus 77655	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77656	: Pg=28.49, Qg=20.3 -> Pg=23.95, Qg=3.15
% INFO    : Gen at bus 77656	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77656	: Pg=28.49, Qg=20.3 -> Pg=23.95, Qg=3.15
% INFO    : Gen at bus 77656	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77660	: Pg=27.0, Qg=20.3 -> Pg=14.5, Qg=5.65
% INFO    : Gen at bus 77660	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77660	: Pg=15.0, Qg=10.3 -> Pg=8.5, Qg=2.65
% INFO    : Gen at bus 77660	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77660	: Pg=15.0, Qg=10.3 -> Pg=8.5, Qg=2.65
% INFO    : Gen at bus 77660	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77661	: Pg=22.0, Qg=16.5 -> Pg=20.0, Qg=4.6
% INFO    : Gen at bus 77661	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77661	: Pg=28.8, Qg=21.6 -> Pg=24.15, Qg=6.0
% INFO    : Gen at bus 77661	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77662	: Pg=22.5, Qg=0.0 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 77662	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77663	: Pg=21.2, Qg=13.1 -> Pg=13.6, Qg=3.0
% INFO    : Gen at bus 77663	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77663	: Pg=21.2, Qg=13.1 -> Pg=13.6, Qg=3.0
% INFO    : Gen at bus 77663	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77663	: Pg=37.2, Qg=21.46 -> Pg=21.6, Qg=5.35
% INFO    : Gen at bus 77663	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77702	: Pg=100.0, Qg=150.0 -> Pg=171.0, Qg=34.65
% INFO    : Gen at bus 77702	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77702	: Pg=80.0, Qg=115.3 -> Pg=133.0, Qg=26.65
% INFO    : Gen at bus 77702	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77702	: Pg=80.0, Qg=115.3 -> Pg=133.0, Qg=26.65
% INFO    : Gen at bus 77702	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77720	: Pg=11.25, Qg=3.52 -> Pg=8.075, Qg=2.345
% INFO    : Gen at bus 77720	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77720	: Pg=11.25, Qg=3.52 -> Pg=8.075, Qg=2.345
% INFO    : Gen at bus 77720	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77720	: Pg=11.25, Qg=3.52 -> Pg=8.075, Qg=2.345
% INFO    : Gen at bus 77720	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77720	: Pg=11.25, Qg=3.52 -> Pg=8.075, Qg=2.345
% INFO    : Gen at bus 77720	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77720	: Pg=11.25, Qg=3.52 -> Pg=8.075, Qg=2.345
% INFO    : Gen at bus 77720	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77720	: Pg=11.25, Qg=3.52 -> Pg=8.075, Qg=2.345
% INFO    : Gen at bus 77720	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77720	: Pg=11.25, Qg=3.52 -> Pg=8.075, Qg=2.345
% INFO    : Gen at bus 77720	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77720	: Pg=11.25, Qg=3.52 -> Pg=8.075, Qg=2.345
% INFO    : Gen at bus 77720	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77720	: Pg=11.25, Qg=3.52 -> Pg=8.075, Qg=2.345
% INFO    : Gen at bus 77720	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77720	: Pg=11.25, Qg=3.52 -> Pg=8.075, Qg=2.345
% INFO    : Gen at bus 77720	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77724	: Pg=94.0, Qg=34.59 -> Pg=74.5, Qg=13.5
% INFO    : Gen at bus 77724	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77725	: Pg=88.4, Qg=43.17 -> Pg=69.2, Qg=12.65
% INFO    : Gen at bus 77725	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77732	: Pg=16.0, Qg=9.93 -> Pg=15.0, Qg=2.305
% INFO    : Gen at bus 77732	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77732	: Pg=16.0, Qg=9.93 -> Pg=15.0, Qg=2.305
% INFO    : Gen at bus 77732	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77732	: Pg=16.0, Qg=9.93 -> Pg=15.0, Qg=2.305
% INFO    : Gen at bus 77732	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77732	: Pg=16.0, Qg=9.93 -> Pg=15.0, Qg=2.305
% INFO    : Gen at bus 77732	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77733	: Pg=59.0, Qg=14.49 -> Pg=44.5, Qg=8.45
% INFO    : Gen at bus 77733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77741	: Pg=48.0, Qg=29.7 -> Pg=36.5, Qg=6.85
% INFO    : Gen at bus 77741	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77742	: Pg=47.3, Qg=0.0 -> Pg=37.65, Qg=0.0
% INFO    : Gen at bus 77742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77743	: Pg=44.0, Qg=21.3 -> Pg=24.0, Qg=3.3
% INFO    : Gen at bus 77743	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77747	: Pg=37.8, Qg=14.9 -> Pg=19.4, Qg=0.0
% INFO    : Gen at bus 77747	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77748	: Pg=18.5, Qg=11.45 -> Pg=16.25, Qg=2.65
% INFO    : Gen at bus 77748	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77748	: Pg=18.5, Qg=11.45 -> Pg=16.25, Qg=2.65
% INFO    : Gen at bus 77748	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77749	: Pg=18.5, Qg=11.45 -> Pg=16.25, Qg=2.65
% INFO    : Gen at bus 77749	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77749	: Pg=18.5, Qg=11.45 -> Pg=16.25, Qg=2.65
% INFO    : Gen at bus 77749	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77751	: Pg=35.7, Qg=17.3 -> Pg=18.35, Qg=2.7
% INFO    : Gen at bus 77751	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77753	: Pg=33.0, Qg=24.8 -> Pg=22.5, Qg=6.9
% INFO    : Gen at bus 77753	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77753	: Pg=33.0, Qg=24.8 -> Pg=22.5, Qg=6.9
% INFO    : Gen at bus 77753	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77753	: Pg=33.0, Qg=24.8 -> Pg=22.5, Qg=6.9
% INFO    : Gen at bus 77753	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77753	: Pg=72.5, Qg=30.97 -> Pg=42.25, Qg=15.1
% INFO    : Gen at bus 77753	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77755	: Pg=16.0, Qg=9.9 -> Pg=14.6, Qg=2.275
% INFO    : Gen at bus 77755	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77755	: Pg=16.0, Qg=9.9 -> Pg=14.6, Qg=2.275
% INFO    : Gen at bus 77755	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77756	: Pg=14.24, Qg=9.9 -> Pg=14.9, Qg=2.275
% INFO    : Gen at bus 77756	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77756	: Pg=14.24, Qg=9.9 -> Pg=14.9, Qg=2.275
% INFO    : Gen at bus 77756	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77761	: Pg=29.4, Qg=11.6 -> Pg=15.2, Qg=0.0
% INFO    : Gen at bus 77761	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77765	: Pg=24.0, Qg=9.5 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 77765	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77766	: Pg=41.14, Qg=0.0 -> Pg=42.75, Qg=0.0
% INFO    : Gen at bus 77766	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77766	: Pg=15.78, Qg=0.0 -> Pg=16.6, Qg=0.0
% INFO    : Gen at bus 77766	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77770	: Pg=10.85, Qg=5.25 -> Pg=7.525, Qg=0.825
% INFO    : Gen at bus 77770	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77770	: Pg=10.85, Qg=5.25 -> Pg=7.525, Qg=0.825
% INFO    : Gen at bus 77770	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77771	: Pg=21.2, Qg=13.1 -> Pg=13.1, Qg=3.0
% INFO    : Gen at bus 77771	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77771	: Pg=14.42, Qg=13.1 -> Pg=13.1, Qg=3.0
% INFO    : Gen at bus 77771	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77771	: Pg=14.42, Qg=13.1 -> Pg=13.1, Qg=3.0
% INFO    : Gen at bus 77771	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77772	: Pg=21.2, Qg=13.1 -> Pg=13.1, Qg=3.0
% INFO    : Gen at bus 77772	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77772	: Pg=21.2, Qg=13.1 -> Pg=13.1, Qg=3.0
% INFO    : Gen at bus 77772	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 77772	: Pg=21.2, Qg=13.1 -> Pg=13.1, Qg=3.0
% INFO    : Gen at bus 77772	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79474	: Pg=45.1, Qg=28.0 -> Pg=22.8, Qg=6.5
% INFO    : Gen at bus 79474	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79486	: Pg=155.73, Qg=83.93 -> Pg=150.5, Qg=17.3
% INFO    : Gen at bus 79486	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79500	: Pg=103.5, Qg=64.1 -> Pg=69.25, Qg=14.8
% INFO    : Gen at bus 79500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79501	: Pg=91.4, Qg=56.6 -> Pg=84.2, Qg=13.05
% INFO    : Gen at bus 79501	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79501	: Pg=98.7, Qg=61.2 -> Pg=74.85, Qg=14.15
% INFO    : Gen at bus 79501	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79501	: Pg=98.7, Qg=61.2 -> Pg=74.85, Qg=14.15
% INFO    : Gen at bus 79501	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79503	: Pg=0.5, Qg=15.22 -> Pg=35.25, Qg=0.0
% INFO    : Gen at bus 79503	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79504	: Pg=67.8, Qg=17.0 -> Pg=34.4, Qg=0.0
% INFO    : Gen at bus 79504	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79505	: Pg=60.2, Qg=29.2 -> Pg=35.1, Qg=4.55
% INFO    : Gen at bus 79505	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79506	: Pg=34.5, Qg=20.9 -> Pg=23.29, Qg=4.7
% INFO    : Gen at bus 79506	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79506	: Pg=75.0, Qg=45.5 -> Pg=50.625, Qg=10.25
% INFO    : Gen at bus 79506	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79508	: Pg=3.36, Qg=2.52 -> Pg=1.68, Qg=0.7
% INFO    : Gen at bus 79508	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79508	: Pg=3.36, Qg=2.52 -> Pg=1.68, Qg=0.7
% INFO    : Gen at bus 79508	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79508	: Pg=3.36, Qg=2.52 -> Pg=1.68, Qg=0.7
% INFO    : Gen at bus 79508	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79508	: Pg=3.36, Qg=2.52 -> Pg=1.68, Qg=0.7
% INFO    : Gen at bus 79508	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79508	: Pg=3.36, Qg=2.52 -> Pg=1.68, Qg=0.7
% INFO    : Gen at bus 79508	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79508	: Pg=3.36, Qg=2.52 -> Pg=1.68, Qg=0.7
% INFO    : Gen at bus 79508	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79508	: Pg=3.36, Qg=2.52 -> Pg=1.68, Qg=0.7
% INFO    : Gen at bus 79508	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79508	: Pg=3.36, Qg=2.52 -> Pg=1.68, Qg=0.7
% INFO    : Gen at bus 79508	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79508	: Pg=3.36, Qg=2.52 -> Pg=1.68, Qg=0.7
% INFO    : Gen at bus 79508	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79508	: Pg=3.36, Qg=2.52 -> Pg=1.68, Qg=0.7
% INFO    : Gen at bus 79508	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79509	: Pg=24.72, Qg=6.53 -> Pg=27.0, Qg=0.0
% INFO    : Gen at bus 79509	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79509	: Pg=26.9, Qg=6.53 -> Pg=30.5, Qg=0.0
% INFO    : Gen at bus 79509	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79510	: Pg=11.0, Qg=5.35 -> Pg=8.5, Qg=0.85
% INFO    : Gen at bus 79510	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79510	: Pg=11.0, Qg=5.35 -> Pg=8.5, Qg=0.85
% INFO    : Gen at bus 79510	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79511	: Pg=14.08, Qg=12.8 -> Pg=11.85, Qg=2.95
% INFO    : Gen at bus 79511	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79511	: Pg=14.08, Qg=12.8 -> Pg=11.85, Qg=2.95
% INFO    : Gen at bus 79511	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79511	: Pg=14.08, Qg=12.8 -> Pg=11.85, Qg=2.95
% INFO    : Gen at bus 79511	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79511	: Pg=14.08, Qg=12.8 -> Pg=11.85, Qg=2.95
% INFO    : Gen at bus 79511	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79513	: Pg=5.25, Qg=-3.35 -> Pg=7.5, Qg=2.075
% INFO    : Gen at bus 79513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79513	: Pg=5.25, Qg=-3.35 -> Pg=7.5, Qg=2.075
% INFO    : Gen at bus 79513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79540	: Pg=58.03, Qg=20.29 -> Pg=68.5, Qg=0.0
% INFO    : Gen at bus 79540	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79540	: Pg=58.03, Qg=20.29 -> Pg=68.5, Qg=0.0
% INFO    : Gen at bus 79540	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79540	: Pg=58.32, Qg=20.29 -> Pg=74.35, Qg=0.0
% INFO    : Gen at bus 79540	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79546	: Pg=67.5, Qg=43.6 -> Pg=35.25, Qg=10.55
% INFO    : Gen at bus 79546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79550	: Pg=57.3, Qg=25.04 -> Pg=42.65, Qg=8.2
% INFO    : Gen at bus 79550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79550	: Pg=57.3, Qg=25.04 -> Pg=42.65, Qg=8.2
% INFO    : Gen at bus 79550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79550	: Pg=57.3, Qg=25.04 -> Pg=42.65, Qg=8.2
% INFO    : Gen at bus 79550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79550	: Pg=57.3, Qg=25.04 -> Pg=42.65, Qg=8.2
% INFO    : Gen at bus 79550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79550	: Pg=57.3, Qg=25.04 -> Pg=42.65, Qg=8.2
% INFO    : Gen at bus 79550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79554	: Pg=17.5, Qg=4.54 -> Pg=11.25, Qg=2.5
% INFO    : Gen at bus 79554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79554	: Pg=17.5, Qg=4.54 -> Pg=11.25, Qg=2.5
% INFO    : Gen at bus 79554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79554	: Pg=17.5, Qg=4.54 -> Pg=11.25, Qg=2.5
% INFO    : Gen at bus 79554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79558	: Pg=44.0, Qg=15.35 -> Pg=30.65, Qg=9.15
% INFO    : Gen at bus 79558	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79571	: Pg=1.5, Qg=1.13 -> Pg=0.75, Qg=0.315
% INFO    : Gen at bus 79571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79610	: Pg=74.8, Qg=68.2 -> Pg=71.0, Qg=15.75
% INFO    : Gen at bus 79610	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79610	: Pg=74.8, Qg=68.2 -> Pg=71.0, Qg=15.75
% INFO    : Gen at bus 79610	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79610	: Pg=74.8, Qg=68.2 -> Pg=67.5, Qg=15.75
% INFO    : Gen at bus 79610	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79617	: Pg=53.0, Qg=12.54 -> Pg=43.0, Qg=4.0
% INFO    : Gen at bus 79617	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79617	: Pg=53.0, Qg=12.54 -> Pg=43.0, Qg=4.0
% INFO    : Gen at bus 79617	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79617	: Pg=97.2, Qg=12.54 -> Pg=78.6, Qg=7.35
% INFO    : Gen at bus 79617	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79617	: Pg=97.2, Qg=12.54 -> Pg=78.6, Qg=7.35
% INFO    : Gen at bus 79617	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79619	: Pg=23.8, Qg=14.7 -> Pg=11.9, Qg=3.4
% INFO    : Gen at bus 79619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79619	: Pg=91.9, Qg=23.84 -> Pg=65.95, Qg=6.95
% INFO    : Gen at bus 79619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79619	: Pg=91.9, Qg=23.84 -> Pg=65.95, Qg=6.95
% INFO    : Gen at bus 79619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79619	: Pg=91.9, Qg=23.84 -> Pg=65.95, Qg=6.95
% INFO    : Gen at bus 79619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79619	: Pg=91.9, Qg=23.84 -> Pg=65.95, Qg=6.95
% INFO    : Gen at bus 79619	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79632	: Pg=32.37, Qg=29.5 -> Pg=27.8, Qg=6.8
% INFO    : Gen at bus 79632	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79637	: Pg=6.0, Qg=3.73 -> Pg=4.0, Qg=0.865
% INFO    : Gen at bus 79637	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79637	: Pg=6.0, Qg=3.73 -> Pg=4.0, Qg=0.865
% INFO    : Gen at bus 79637	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79637	: Pg=6.0, Qg=3.73 -> Pg=4.0, Qg=0.865
% INFO    : Gen at bus 79637	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79637	: Pg=6.0, Qg=3.73 -> Pg=4.0, Qg=0.865
% INFO    : Gen at bus 79637	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79638	: Pg=20.7, Qg=12.8 -> Pg=11.85, Qg=2.95
% INFO    : Gen at bus 79638	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79638	: Pg=20.7, Qg=12.8 -> Pg=11.85, Qg=2.95
% INFO    : Gen at bus 79638	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79638	: Pg=20.7, Qg=12.8 -> Pg=11.85, Qg=2.95
% INFO    : Gen at bus 79638	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79638	: Pg=20.7, Qg=12.8 -> Pg=11.85, Qg=2.95
% INFO    : Gen at bus 79638	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79654	: Pg=55.5, Qg=84.67 -> Pg=134.8, Qg=45.75
% INFO    : Gen at bus 79654	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79654	: Pg=55.5, Qg=84.67 -> Pg=134.8, Qg=45.75
% INFO    : Gen at bus 79654	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79662	: Pg=34.4, Qg=0.0 -> Pg=63.85, Qg=0.0
% INFO    : Gen at bus 79662	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79666	: Pg=54.4, Qg=2.6 -> Pg=54.0, Qg=11.45
% INFO    : Gen at bus 79666	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79671	: Pg=1.1, Qg=0.0 -> Pg=20.05, Qg=0.0
% INFO    : Gen at bus 79671	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79671	: Pg=1.1, Qg=0.0 -> Pg=20.05, Qg=0.0
% INFO    : Gen at bus 79671	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79672	: Pg=1.47, Qg=6.15 -> Pg=9.85, Qg=0.0
% INFO    : Gen at bus 79672	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79672	: Pg=1.47, Qg=6.15 -> Pg=9.85, Qg=0.0
% INFO    : Gen at bus 79672	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79673	: Pg=13.13, Qg=17.73 -> Pg=23.625, Qg=4.75
% INFO    : Gen at bus 79673	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79673	: Pg=28.02, Qg=17.73 -> Pg=50.42, Qg=10.2
% INFO    : Gen at bus 79673	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79674	: Pg=5.65, Qg=0.97 -> Pg=15.5, Qg=1.95
% INFO    : Gen at bus 79674	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79674	: Pg=12.05, Qg=0.97 -> Pg=46.0, Qg=6.2
% INFO    : Gen at bus 79674	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79675	: Pg=1.2, Qg=6.13 -> Pg=4.585, Qg=1.7
% INFO    : Gen at bus 79675	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79675	: Pg=1.2, Qg=6.13 -> Pg=4.585, Qg=1.7
% INFO    : Gen at bus 79675	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 79675	: Pg=1.2, Qg=6.13 -> Pg=4.585, Qg=1.7
% INFO    : Gen at bus 79675	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81895	: Pg=130.5, Qg=57.5 -> Pg=130.5, Qg=0.0
% INFO    : Gen at bus 81895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81900	: Pg=67.92, Qg=30.47 -> Pg=90.8, Qg=13.3
% INFO    : Gen at bus 81900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81900	: Pg=57.92, Qg=30.47 -> Pg=85.8, Qg=13.3
% INFO    : Gen at bus 81900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81904	: Pg=106.0, Qg=46.7 -> Pg=53.0, Qg=0.0
% INFO    : Gen at bus 81904	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81905	: Pg=17.43, Qg=10.8 -> Pg=10.215, Qg=2.49
% INFO    : Gen at bus 81905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81905	: Pg=17.43, Qg=10.8 -> Pg=10.215, Qg=2.49
% INFO    : Gen at bus 81905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81905	: Pg=17.43, Qg=10.8 -> Pg=10.215, Qg=2.49
% INFO    : Gen at bus 81905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81905	: Pg=17.43, Qg=10.8 -> Pg=10.215, Qg=2.49
% INFO    : Gen at bus 81905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81905	: Pg=17.43, Qg=10.8 -> Pg=10.215, Qg=2.49
% INFO    : Gen at bus 81905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81905	: Pg=17.43, Qg=10.8 -> Pg=10.215, Qg=2.49
% INFO    : Gen at bus 81905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81917	: Pg=60.5, Qg=25.83 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 81917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81917	: Pg=60.5, Qg=25.83 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 81917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81917	: Pg=60.5, Qg=25.83 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 81917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81917	: Pg=60.5, Qg=25.83 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 81917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81921	: Pg=11.33, Qg=25.7 -> Pg=31.55, Qg=4.0
% INFO    : Gen at bus 81921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81921	: Pg=12.22, Qg=43.0 -> Pg=49.4, Qg=6.7
% INFO    : Gen at bus 81921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81925	: Pg=41.4, Qg=25.7 -> Pg=29.2, Qg=5.95
% INFO    : Gen at bus 81925	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81925	: Pg=41.4, Qg=25.7 -> Pg=29.2, Qg=5.95
% INFO    : Gen at bus 81925	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81927	: Pg=22.0, Qg=13.6 -> Pg=13.5, Qg=3.15
% INFO    : Gen at bus 81927	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81952	: Pg=135.0, Qg=76.5 -> Pg=84.375, Qg=15.75
% INFO    : Gen at bus 81952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81952	: Pg=135.0, Qg=76.5 -> Pg=84.375, Qg=15.75
% INFO    : Gen at bus 81952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81959	: Pg=59.25, Qg=-30.0 -> Pg=73.5, Qg=6.8
% INFO    : Gen at bus 81959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81959	: Pg=59.25, Qg=-30.0 -> Pg=73.5, Qg=6.8
% INFO    : Gen at bus 81959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81959	: Pg=59.25, Qg=-30.0 -> Pg=73.5, Qg=6.8
% INFO    : Gen at bus 81959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81959	: Pg=32.25, Qg=-30.0 -> Pg=60.0, Qg=6.8
% INFO    : Gen at bus 81959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81959	: Pg=32.25, Qg=-30.0 -> Pg=60.0, Qg=6.8
% INFO    : Gen at bus 81959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81967	: Pg=21.45, Qg=27.55 -> Pg=39.0, Qg=8.3
% INFO    : Gen at bus 81967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81967	: Pg=52.01, Qg=27.55 -> Pg=65.05, Qg=11.45
% INFO    : Gen at bus 81967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81970	: Pg=54.4, Qg=38.7 -> Pg=50.0, Qg=6.0
% INFO    : Gen at bus 81970	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81972	: Pg=57.86, Qg=35.4 -> Pg=54.05, Qg=5.5
% INFO    : Gen at bus 81972	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81975	: Pg=68.4, Qg=5.3 -> Pg=38.7, Qg=0.0
% INFO    : Gen at bus 81975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81978	: Pg=5.4, Qg=9.93 -> Pg=10.5, Qg=2.305
% INFO    : Gen at bus 81978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81978	: Pg=5.4, Qg=9.93 -> Pg=10.5, Qg=2.305
% INFO    : Gen at bus 81978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81978	: Pg=5.4, Qg=9.93 -> Pg=10.5, Qg=2.305
% INFO    : Gen at bus 81978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81978	: Pg=5.4, Qg=9.93 -> Pg=10.5, Qg=2.305
% INFO    : Gen at bus 81978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81979	: Pg=14.28, Qg=13.0 -> Pg=13.0, Qg=3.0
% INFO    : Gen at bus 81979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81979	: Pg=16.32, Qg=14.9 -> Pg=14.5, Qg=3.45
% INFO    : Gen at bus 81979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81979	: Pg=10.85, Qg=10.72 -> Pg=9.565, Qg=2.7
% INFO    : Gen at bus 81979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81979	: Pg=10.85, Qg=10.72 -> Pg=9.565, Qg=2.7
% INFO    : Gen at bus 81979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81979	: Pg=10.85, Qg=10.72 -> Pg=9.565, Qg=2.7
% INFO    : Gen at bus 81979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81979	: Pg=10.85, Qg=10.72 -> Pg=9.565, Qg=2.7
% INFO    : Gen at bus 81979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81981	: Pg=0.0, Qg=23.7 -> Pg=30.0, Qg=0.0
% INFO    : Gen at bus 81981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81982	: Pg=3.2, Qg=11.13 -> Pg=8.83, Qg=3.1
% INFO    : Gen at bus 81982	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81982	: Pg=3.2, Qg=11.13 -> Pg=8.83, Qg=3.1
% INFO    : Gen at bus 81982	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81982	: Pg=6.43, Qg=11.13 -> Pg=8.83, Qg=3.1
% INFO    : Gen at bus 81982	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81985	: Pg=11.1, Qg=21.3 -> Pg=27.0, Qg=3.3
% INFO    : Gen at bus 81985	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.42, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81988	: Pg=15.64, Qg=11.1 -> Pg=18.5, Qg=1.7
% INFO    : Gen at bus 81988	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81988	: Pg=22.51, Qg=16.0 -> Pg=25.05, Qg=2.5
% INFO    : Gen at bus 81988	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81990	: Pg=28.17, Qg=5.5 -> Pg=32.9, Qg=0.0
% INFO    : Gen at bus 81990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81990	: Pg=22.87, Qg=8.7 -> Pg=25.95, Qg=0.0
% INFO    : Gen at bus 81990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81990	: Pg=46.35, Qg=26.2 -> Pg=49.5, Qg=4.1
% INFO    : Gen at bus 81990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81991	: Pg=12.29, Qg=7.16 -> Pg=17.55, Qg=4.9
% INFO    : Gen at bus 81991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81991	: Pg=12.29, Qg=7.16 -> Pg=17.55, Qg=4.9
% INFO    : Gen at bus 81991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81991	: Pg=12.29, Qg=7.16 -> Pg=17.55, Qg=4.9
% INFO    : Gen at bus 81991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81992	: Pg=24.8, Qg=18.6 -> Pg=21.1, Qg=5.15
% INFO    : Gen at bus 81992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81992	: Pg=23.0, Qg=13.6 -> Pg=19.0, Qg=2.95
% INFO    : Gen at bus 81992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81994	: Pg=17.1, Qg=27.3 -> Pg=30.0, Qg=6.3
% INFO    : Gen at bus 81994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81994	: Pg=5.53, Qg=13.0 -> Pg=13.0, Qg=3.0
% INFO    : Gen at bus 81994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82010	: Pg=255.99, Qg=109.76 -> Pg=163.0, Qg=53.35
% INFO    : Gen at bus 82010	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82037	: Pg=100.0, Qg=48.4 -> Pg=52.5, Qg=7.55
% INFO    : Gen at bus 82037	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82052	: Pg=33.0, Qg=20.5 -> Pg=29.5, Qg=4.75
% INFO    : Gen at bus 82052	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82053	: Pg=33.0, Qg=20.5 -> Pg=29.5, Qg=4.75
% INFO    : Gen at bus 82053	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82056	: Pg=28.8, Qg=15.5 -> Pg=20.375, Qg=2.95
% INFO    : Gen at bus 82056	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82056	: Pg=28.8, Qg=15.5 -> Pg=20.375, Qg=2.95
% INFO    : Gen at bus 82056	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82057	: Pg=5.84, Qg=7.05 -> Pg=9.625, Qg=1.225
% INFO    : Gen at bus 82057	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82057	: Pg=5.84, Qg=7.05 -> Pg=9.625, Qg=1.225
% INFO    : Gen at bus 82057	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82058	: Pg=13.75, Qg=7.7 -> Pg=8.985, Qg=7.7
% INFO    : Gen at bus 82058	: Vg=0.9971 -> Vg=1.0
% INFO    : Gen at bus 82058	: Pg=13.75, Qg=7.7 -> Pg=8.985, Qg=7.7
% INFO    : Gen at bus 82058	: Vg=0.9971 -> Vg=1.0
% INFO    : Gen at bus 82058	: Pg=25.0, Qg=15.5 -> Pg=16.5, Qg=15.5
% INFO    : Gen at bus 82058	: Vg=0.9971 -> Vg=1.0
% INFO    : Gen at bus 82060	: Pg=27.0, Qg=14.5 -> Pg=19.1, Qg=2.75
% INFO    : Gen at bus 82060	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82060	: Pg=27.0, Qg=14.5 -> Pg=19.1, Qg=2.75
% INFO    : Gen at bus 82060	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84656	: Pg=186.44, Qg=161.51 -> Pg=247.7, Qg=66.95
% INFO    : Gen at bus 84656	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84718	: Pg=40.55, Qg=0.0 -> Pg=58.0, Qg=0.0
% INFO    : Gen at bus 84718	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84719	: Pg=57.25, Qg=9.94 -> Pg=72.5, Qg=12.9
% INFO    : Gen at bus 84719	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84719	: Pg=39.61, Qg=9.94 -> Pg=52.0, Qg=12.05
% INFO    : Gen at bus 84719	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84719	: Pg=40.55, Qg=9.94 -> Pg=55.5, Qg=12.3
% INFO    : Gen at bus 84719	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84719	: Pg=40.55, Qg=9.94 -> Pg=53.0, Qg=12.3
% INFO    : Gen at bus 84719	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84719	: Pg=40.55, Qg=9.94 -> Pg=53.0, Qg=12.3
% INFO    : Gen at bus 84719	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84724	: Pg=28.56, Qg=31.5 -> Pg=26.0, Qg=8.75
% INFO    : Gen at bus 84724	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84724	: Pg=113.89, Qg=103.8 -> Pg=128.75, Qg=24.0
% INFO    : Gen at bus 84724	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84724	: Pg=27.2, Qg=30.0 -> Pg=25.0, Qg=8.35
% INFO    : Gen at bus 84724	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84724	: Pg=56.1, Qg=51.1 -> Pg=46.25, Qg=11.8
% INFO    : Gen at bus 84724	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84724	: Pg=54.4, Qg=60.0 -> Pg=62.5, Qg=16.65
% INFO    : Gen at bus 84724	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84731	: Pg=8.32, Qg=8.9 -> Pg=11.635, Qg=1.515
% INFO    : Gen at bus 84731	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84731	: Pg=8.32, Qg=8.9 -> Pg=11.635, Qg=1.515
% INFO    : Gen at bus 84731	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84731	: Pg=8.32, Qg=8.9 -> Pg=11.635, Qg=1.515
% INFO    : Gen at bus 84731	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84731	: Pg=8.32, Qg=8.9 -> Pg=11.635, Qg=1.515
% INFO    : Gen at bus 84731	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84731	: Pg=10.18, Qg=10.5 -> Pg=13.3, Qg=1.65
% INFO    : Gen at bus 84731	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84731	: Pg=9.43, Qg=15.0 -> Pg=13.75, Qg=4.15
% INFO    : Gen at bus 84731	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84732	: Pg=31.87, Qg=41.9 -> Pg=38.8, Qg=9.7
% INFO    : Gen at bus 84732	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84739	: Pg=13.78, Qg=15.3 -> Pg=20.295, Qg=3.075
% INFO    : Gen at bus 84739	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84739	: Pg=13.78, Qg=15.3 -> Pg=20.295, Qg=3.075
% INFO    : Gen at bus 84739	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84740	: Pg=25.46, Qg=26.2 -> Pg=32.0, Qg=4.1
% INFO    : Gen at bus 84740	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84740	: Pg=25.46, Qg=26.2 -> Pg=32.0, Qg=4.1
% INFO    : Gen at bus 84740	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84740	: Pg=13.49, Qg=17.7 -> Pg=16.8, Qg=4.1
% INFO    : Gen at bus 84740	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84742	: Pg=2.5, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 84742	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84743	: Pg=7.69, Qg=10.1 -> Pg=11.655, Qg=2.335
% INFO    : Gen at bus 84743	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84743	: Pg=7.69, Qg=10.1 -> Pg=11.655, Qg=2.335
% INFO    : Gen at bus 84743	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84743	: Pg=7.69, Qg=10.1 -> Pg=11.655, Qg=2.335
% INFO    : Gen at bus 84743	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84743	: Pg=11.79, Qg=14.4 -> Pg=16.06, Qg=3.05
% INFO    : Gen at bus 84743	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84743	: Pg=31.25, Qg=31.0 -> Pg=40.0, Qg=7.15
% INFO    : Gen at bus 84743	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84743	: Pg=52.41, Qg=59.6 -> Pg=73.05, Qg=13.8
% INFO    : Gen at bus 84743	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84745	: Pg=23.01, Qg=30.2 -> Pg=29.4, Qg=6.95
% INFO    : Gen at bus 84745	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84745	: Pg=12.5, Qg=16.4 -> Pg=15.75, Qg=3.8
% INFO    : Gen at bus 84745	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84745	: Pg=27.77, Qg=36.5 -> Pg=34.45, Qg=8.45
% INFO    : Gen at bus 84745	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84746	: Pg=19.1, Qg=25.1 -> Pg=24.25, Qg=5.8
% INFO    : Gen at bus 84746	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84748	: Pg=16.69, Qg=1.01 -> Pg=18.7, Qg=7.4
% INFO    : Gen at bus 84748	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84748	: Pg=20.04, Qg=1.01 -> Pg=22.25, Qg=8.85
% INFO    : Gen at bus 84748	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84751	: Pg=15.89, Qg=20.9 -> Pg=19.35, Qg=4.85
% INFO    : Gen at bus 84751	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84751	: Pg=15.89, Qg=20.9 -> Pg=19.35, Qg=4.85
% INFO    : Gen at bus 84751	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84752	: Pg=27.58, Qg=20.45 -> Pg=30.25, Qg=8.4
% INFO    : Gen at bus 84752	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84752	: Pg=15.09, Qg=20.45 -> Pg=17.0, Qg=6.65
% INFO    : Gen at bus 84752	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84755	: Pg=6.28, Qg=6.95 -> Pg=8.6, Qg=1.6
% INFO    : Gen at bus 84755	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84755	: Pg=6.28, Qg=6.95 -> Pg=8.6, Qg=1.6
% INFO    : Gen at bus 84755	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84755	: Pg=25.0, Qg=9.4 -> Pg=25.0, Qg=3.6
% INFO    : Gen at bus 84755	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84755	: Pg=77.16, Qg=9.4 -> Pg=80.6, Qg=6.5
% INFO    : Gen at bus 84755	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84823	: Pg=7.38, Qg=5.55 -> Pg=7.295, Qg=1.54
% INFO    : Gen at bus 84823	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84823	: Pg=7.38, Qg=5.55 -> Pg=7.295, Qg=1.54
% INFO    : Gen at bus 84823	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84823	: Pg=7.38, Qg=5.55 -> Pg=7.295, Qg=1.54
% INFO    : Gen at bus 84823	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84823	: Pg=7.38, Qg=5.55 -> Pg=7.295, Qg=1.54
% INFO    : Gen at bus 84823	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84824	: Pg=10.68, Qg=0.0 -> Pg=18.5, Qg=0.0
% INFO    : Gen at bus 84824	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84824	: Pg=10.98, Qg=0.0 -> Pg=24.5, Qg=0.0
% INFO    : Gen at bus 84824	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84872	: Pg=9.24, Qg=12.15 -> Pg=10.3, Qg=2.8
% INFO    : Gen at bus 84872	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84872	: Pg=9.24, Qg=12.15 -> Pg=10.3, Qg=2.8
% INFO    : Gen at bus 84872	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84874	: Pg=28.0, Qg=13.6 -> Pg=28.0, Qg=2.15
% INFO    : Gen at bus 84874	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84874	: Pg=28.0, Qg=13.6 -> Pg=28.0, Qg=2.15
% INFO    : Gen at bus 84874	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 84874	: Pg=28.0, Qg=13.6 -> Pg=28.0, Qg=2.15
% INFO    : Gen at bus 84874	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87110	: Pg=28.83, Qg=10.58 -> Pg=28.76, Qg=3.115
% INFO    : Gen at bus 87110	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87110	: Pg=28.83, Qg=10.58 -> Pg=28.76, Qg=3.115
% INFO    : Gen at bus 87110	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87110	: Pg=28.83, Qg=10.58 -> Pg=28.76, Qg=3.115
% INFO    : Gen at bus 87110	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87110	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87110	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87110	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87120	: Pg=26.0, Qg=18.55 -> Pg=32.45, Qg=5.7
% INFO    : Gen at bus 87120	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87120	: Pg=77.07, Qg=18.55 -> Pg=78.8, Qg=11.85
% INFO    : Gen at bus 87120	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87121	: Pg=75.0, Qg=27.33 -> Pg=75.0, Qg=10.05
% INFO    : Gen at bus 87121	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87121	: Pg=75.0, Qg=27.33 -> Pg=75.0, Qg=10.05
% INFO    : Gen at bus 87121	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87121	: Pg=75.0, Qg=27.33 -> Pg=75.0, Qg=10.05
% INFO    : Gen at bus 87121	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87127	: Pg=46.14, Qg=24.0 -> Pg=45.95, Qg=4.2
% INFO    : Gen at bus 87127	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87168	: Pg=22.47, Qg=19.6 -> Pg=59.4, Qg=7.5
% INFO    : Gen at bus 87168	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87168	: Pg=40.0, Qg=19.6 -> Pg=68.0, Qg=13.75
% INFO    : Gen at bus 87168	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87171	: Pg=38.88, Qg=16.89 -> Pg=56.0, Qg=10.75
% INFO    : Gen at bus 87171	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87171	: Pg=39.85, Qg=16.89 -> Pg=75.3, Qg=16.25
% INFO    : Gen at bus 87171	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87174	: Pg=19.96, Qg=4.55 -> Pg=30.65, Qg=0.0
% INFO    : Gen at bus 87174	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87174	: Pg=19.96, Qg=4.55 -> Pg=30.65, Qg=0.0
% INFO    : Gen at bus 87174	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87174	: Pg=20.02, Qg=4.55 -> Pg=31.75, Qg=0.0
% INFO    : Gen at bus 87174	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87174	: Pg=20.02, Qg=4.55 -> Pg=31.75, Qg=0.0
% INFO    : Gen at bus 87174	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87174	: Pg=20.02, Qg=4.55 -> Pg=31.75, Qg=0.0
% INFO    : Gen at bus 87174	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87176	: Pg=32.5, Qg=8.5 -> Pg=32.5, Qg=2.45
% INFO    : Gen at bus 87176	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87176	: Pg=32.5, Qg=8.5 -> Pg=32.5, Qg=2.45
% INFO    : Gen at bus 87176	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87176	: Pg=32.5, Qg=8.5 -> Pg=32.5, Qg=2.45
% INFO    : Gen at bus 87176	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87176	: Pg=32.5, Qg=8.5 -> Pg=32.5, Qg=2.45
% INFO    : Gen at bus 87176	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87199	: Pg=30.94, Qg=-4.98 -> Pg=70.315, Qg=13.15
% INFO    : Gen at bus 87199	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87199	: Pg=30.94, Qg=-4.98 -> Pg=70.315, Qg=13.15
% INFO    : Gen at bus 87199	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87224	: Pg=2.07, Qg=7.62 -> Pg=6.025, Qg=2.105
% INFO    : Gen at bus 87224	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87239	: Pg=60.0, Qg=6.56 -> Pg=40.5, Qg=8.2
% INFO    : Gen at bus 87239	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87239	: Pg=32.7, Qg=6.56 -> Pg=40.5, Qg=8.2
% INFO    : Gen at bus 87239	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87239	: Pg=22.5, Qg=6.56 -> Pg=40.5, Qg=8.2
% INFO    : Gen at bus 87239	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87239	: Pg=22.5, Qg=6.56 -> Pg=40.5, Qg=8.2
% INFO    : Gen at bus 87239	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87241	: Pg=36.31, Qg=39.2 -> Pg=43.6, Qg=10.9
% INFO    : Gen at bus 87241	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87241	: Pg=36.31, Qg=39.2 -> Pg=43.6, Qg=10.9
% INFO    : Gen at bus 87241	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87241	: Pg=36.31, Qg=39.2 -> Pg=43.6, Qg=10.9
% INFO    : Gen at bus 87241	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87243	: Pg=45.0, Qg=21.8 -> Pg=31.85, Qg=3.4
% INFO    : Gen at bus 87243	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87246	: Pg=33.4, Qg=12.1 -> Pg=31.7, Qg=0.0
% INFO    : Gen at bus 87246	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87246	: Pg=33.4, Qg=12.1 -> Pg=24.7, Qg=0.0
% INFO    : Gen at bus 87246	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87246	: Pg=33.4, Qg=12.1 -> Pg=24.7, Qg=0.0
% INFO    : Gen at bus 87246	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87246	: Pg=33.4, Qg=12.1 -> Pg=24.7, Qg=0.0
% INFO    : Gen at bus 87246	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87246	: Pg=41.0, Qg=13.71 -> Pg=28.5, Qg=0.0
% INFO    : Gen at bus 87246	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87249	: Pg=12.54, Qg=14.4 -> Pg=20.75, Qg=2.25
% INFO    : Gen at bus 87249	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87249	: Pg=12.54, Qg=14.4 -> Pg=20.75, Qg=2.25
% INFO    : Gen at bus 87249	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87251	: Pg=24.3, Qg=11.18 -> Pg=18.55, Qg=1.85
% INFO    : Gen at bus 87251	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87251	: Pg=24.3, Qg=11.18 -> Pg=18.55, Qg=1.85
% INFO    : Gen at bus 87251	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87251	: Pg=27.4, Qg=11.18 -> Pg=20.55, Qg=2.1
% INFO    : Gen at bus 87251	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87251	: Pg=27.9, Qg=11.18 -> Pg=20.8, Qg=2.1
% INFO    : Gen at bus 87251	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87252	: Pg=6.29, Qg=8.65 -> Pg=8.75, Qg=2.4
% INFO    : Gen at bus 87252	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 87252	: Pg=6.29, Qg=8.65 -> Pg=8.75, Qg=2.4
% INFO    : Gen at bus 87252	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88792	: Pg=45.17, Qg=18.96 -> Pg=131.75, Qg=31.3
% INFO    : Gen at bus 88792	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88793	: Pg=1.6, Qg=31.18 -> Pg=100.65, Qg=15.05
% INFO    : Gen at bus 88793	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88801	: Pg=7.5, Qg=-15.04 -> Pg=78.75, Qg=0.0
% INFO    : Gen at bus 88801	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88805	: Pg=0.21, Qg=4.44 -> Pg=4.16, Qg=1.735
% INFO    : Gen at bus 88805	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88805	: Pg=0.21, Qg=4.44 -> Pg=4.16, Qg=1.735
% INFO    : Gen at bus 88805	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88805	: Pg=0.21, Qg=4.44 -> Pg=4.16, Qg=1.735
% INFO    : Gen at bus 88805	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88805	: Pg=0.21, Qg=4.44 -> Pg=4.16, Qg=1.735
% INFO    : Gen at bus 88805	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88805	: Pg=0.21, Qg=4.44 -> Pg=4.16, Qg=1.735
% INFO    : Gen at bus 88805	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88805	: Pg=0.21, Qg=4.44 -> Pg=4.16, Qg=1.735
% INFO    : Gen at bus 88805	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88805	: Pg=0.21, Qg=4.44 -> Pg=4.16, Qg=1.735
% INFO    : Gen at bus 88805	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88805	: Pg=0.21, Qg=4.44 -> Pg=4.16, Qg=1.735
% INFO    : Gen at bus 88805	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88805	: Pg=0.21, Qg=4.44 -> Pg=4.16, Qg=1.735
% INFO    : Gen at bus 88805	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88805	: Pg=0.21, Qg=4.44 -> Pg=4.16, Qg=1.735
% INFO    : Gen at bus 88805	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88805	: Pg=0.21, Qg=4.44 -> Pg=4.16, Qg=1.735
% INFO    : Gen at bus 88805	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88805	: Pg=0.21, Qg=4.44 -> Pg=4.16, Qg=1.735
% INFO    : Gen at bus 88805	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88805	: Pg=0.21, Qg=4.44 -> Pg=4.16, Qg=1.735
% INFO    : Gen at bus 88805	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88805	: Pg=0.21, Qg=4.44 -> Pg=4.16, Qg=1.735
% INFO    : Gen at bus 88805	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88805	: Pg=0.21, Qg=4.44 -> Pg=4.16, Qg=1.735
% INFO    : Gen at bus 88805	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88810	: Pg=5.29, Qg=5.9 -> Pg=9.53, Qg=1.935
% INFO    : Gen at bus 88810	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88810	: Pg=5.29, Qg=5.9 -> Pg=9.53, Qg=1.935
% INFO    : Gen at bus 88810	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88810	: Pg=5.29, Qg=5.9 -> Pg=9.53, Qg=1.935
% INFO    : Gen at bus 88810	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88810	: Pg=5.29, Qg=5.9 -> Pg=9.53, Qg=1.935
% INFO    : Gen at bus 88810	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88810	: Pg=5.29, Qg=5.9 -> Pg=9.53, Qg=1.935
% INFO    : Gen at bus 88810	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88810	: Pg=5.29, Qg=5.9 -> Pg=9.53, Qg=1.935
% INFO    : Gen at bus 88810	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88813	: Pg=10.34, Qg=9.22 -> Pg=14.775, Qg=2.295
% INFO    : Gen at bus 88813	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88813	: Pg=10.34, Qg=9.22 -> Pg=14.775, Qg=2.295
% INFO    : Gen at bus 88813	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88813	: Pg=10.34, Qg=9.22 -> Pg=14.775, Qg=2.295
% INFO    : Gen at bus 88813	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88813	: Pg=10.34, Qg=9.22 -> Pg=14.775, Qg=2.295
% INFO    : Gen at bus 88813	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88816	: Pg=5.38, Qg=2.6 -> Pg=8.54, Qg=1.8
% INFO    : Gen at bus 88816	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88816	: Pg=5.38, Qg=2.6 -> Pg=8.54, Qg=1.8
% INFO    : Gen at bus 88816	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88816	: Pg=5.38, Qg=2.6 -> Pg=8.54, Qg=1.8
% INFO    : Gen at bus 88816	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88816	: Pg=5.38, Qg=2.6 -> Pg=8.54, Qg=1.8
% INFO    : Gen at bus 88816	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88816	: Pg=5.38, Qg=2.6 -> Pg=8.54, Qg=1.8
% INFO    : Gen at bus 88816	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88818	: Pg=1.7, Qg=2.76 -> Pg=4.585, Qg=1.12
% INFO    : Gen at bus 88818	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88818	: Pg=1.7, Qg=2.76 -> Pg=4.585, Qg=1.12
% INFO    : Gen at bus 88818	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88818	: Pg=1.7, Qg=2.76 -> Pg=4.585, Qg=1.12
% INFO    : Gen at bus 88818	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88818	: Pg=1.7, Qg=2.76 -> Pg=4.585, Qg=1.12
% INFO    : Gen at bus 88818	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88818	: Pg=1.7, Qg=2.76 -> Pg=4.585, Qg=1.12
% INFO    : Gen at bus 88818	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88818	: Pg=1.7, Qg=2.76 -> Pg=4.585, Qg=1.12
% INFO    : Gen at bus 88818	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88818	: Pg=1.7, Qg=2.76 -> Pg=4.585, Qg=1.12
% INFO    : Gen at bus 88818	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88821	: Pg=2.54, Qg=7.2 -> Pg=6.875, Qg=1.69
% INFO    : Gen at bus 88821	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88821	: Pg=2.54, Qg=7.2 -> Pg=6.875, Qg=1.69
% INFO    : Gen at bus 88821	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88821	: Pg=2.54, Qg=7.2 -> Pg=6.875, Qg=1.69
% INFO    : Gen at bus 88821	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88821	: Pg=2.54, Qg=7.2 -> Pg=6.875, Qg=1.69
% INFO    : Gen at bus 88821	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88822	: Pg=14.13, Qg=3.02 -> Pg=29.05, Qg=6.5
% INFO    : Gen at bus 88822	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88822	: Pg=14.13, Qg=3.02 -> Pg=29.05, Qg=6.5
% INFO    : Gen at bus 88822	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88823	: Pg=7.04, Qg=20.1 -> Pg=23.7, Qg=3.15
% INFO    : Gen at bus 88823	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88823	: Pg=7.04, Qg=20.1 -> Pg=23.7, Qg=3.15
% INFO    : Gen at bus 88823	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88823	: Pg=8.43, Qg=47.0 -> Pg=51.5, Qg=7.35
% INFO    : Gen at bus 88823	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88826	: Pg=31.79, Qg=34.5 -> Pg=50.65, Qg=5.35
% INFO    : Gen at bus 88826	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88826	: Pg=15.94, Qg=23.2 -> Pg=26.25, Qg=5.35
% INFO    : Gen at bus 88826	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88827	: Pg=6.45, Qg=8.7 -> Pg=12.0, Qg=1.35
% INFO    : Gen at bus 88827	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88827	: Pg=6.45, Qg=8.7 -> Pg=12.0, Qg=1.35
% INFO    : Gen at bus 88827	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88829	: Pg=9.94, Qg=16.1 -> Pg=17.885, Qg=3.65
% INFO    : Gen at bus 88829	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88830	: Pg=45.68, Qg=12.16 -> Pg=110.25, Qg=25.15
% INFO    : Gen at bus 88830	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88830	: Pg=20.29, Qg=12.16 -> Pg=47.5, Qg=10.75
% INFO    : Gen at bus 88830	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88830	: Pg=6.1, Qg=12.16 -> Pg=15.5, Qg=3.6
% INFO    : Gen at bus 88830	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88831	: Pg=2.0, Qg=1.5 -> Pg=2.0, Qg=0.415
% INFO    : Gen at bus 88831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88831	: Pg=2.0, Qg=1.5 -> Pg=2.0, Qg=0.415
% INFO    : Gen at bus 88831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88831	: Pg=2.0, Qg=1.5 -> Pg=2.0, Qg=0.415
% INFO    : Gen at bus 88831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88831	: Pg=2.0, Qg=1.5 -> Pg=2.0, Qg=0.415
% INFO    : Gen at bus 88831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88831	: Pg=2.0, Qg=1.5 -> Pg=2.0, Qg=0.415
% INFO    : Gen at bus 88831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88831	: Pg=2.0, Qg=1.5 -> Pg=2.0, Qg=0.415
% INFO    : Gen at bus 88831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88831	: Pg=2.0, Qg=1.5 -> Pg=2.0, Qg=0.415
% INFO    : Gen at bus 88831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88831	: Pg=2.0, Qg=1.5 -> Pg=2.0, Qg=0.415
% INFO    : Gen at bus 88831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88831	: Pg=2.0, Qg=1.5 -> Pg=2.0, Qg=0.415
% INFO    : Gen at bus 88831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88831	: Pg=2.0, Qg=1.5 -> Pg=2.0, Qg=0.415
% INFO    : Gen at bus 88831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88860	: Pg=104.03, Qg=223.4 -> Pg=227.7, Qg=51.65
% INFO    : Gen at bus 88860	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88869	: Pg=10.9, Qg=95.79 -> Pg=114.2, Qg=16.4
% INFO    : Gen at bus 88869	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88908	: Pg=4.55, Qg=31.67 -> Pg=32.5, Qg=12.9
% INFO    : Gen at bus 88908	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88912	: Pg=17.62, Qg=15.57 -> Pg=40.25, Qg=4.85
% INFO    : Gen at bus 88912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88912	: Pg=17.62, Qg=15.57 -> Pg=40.25, Qg=4.85
% INFO    : Gen at bus 88912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88912	: Pg=17.62, Qg=15.57 -> Pg=40.25, Qg=4.85
% INFO    : Gen at bus 88912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88912	: Pg=5.35, Qg=15.57 -> Pg=29.0, Qg=11.25
% INFO    : Gen at bus 88912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88912	: Pg=5.35, Qg=15.57 -> Pg=29.0, Qg=11.25
% INFO    : Gen at bus 88912	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88916	: Pg=0.0, Qg=10.76 -> Pg=24.75, Qg=0.0
% INFO    : Gen at bus 88916	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88916	: Pg=0.0, Qg=10.76 -> Pg=25.5, Qg=0.0
% INFO    : Gen at bus 88916	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88916	: Pg=0.0, Qg=10.76 -> Pg=49.5, Qg=0.0
% INFO    : Gen at bus 88916	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88917	: Pg=4.95, Qg=9.13 -> Pg=10.435, Qg=1.85
% INFO    : Gen at bus 88917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88917	: Pg=4.95, Qg=9.13 -> Pg=10.435, Qg=1.85
% INFO    : Gen at bus 88917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88917	: Pg=4.95, Qg=9.13 -> Pg=10.435, Qg=1.85
% INFO    : Gen at bus 88917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88921	: Pg=6.55, Qg=16.5 -> Pg=14.0, Qg=4.6
% INFO    : Gen at bus 88921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88921	: Pg=3.0, Qg=9.93 -> Pg=7.95, Qg=2.765
% INFO    : Gen at bus 88921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88921	: Pg=3.0, Qg=9.93 -> Pg=7.95, Qg=2.765
% INFO    : Gen at bus 88921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88921	: Pg=3.0, Qg=9.93 -> Pg=7.95, Qg=2.765
% INFO    : Gen at bus 88921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88922	: Pg=22.98, Qg=20.49 -> Pg=30.5, Qg=5.6
% INFO    : Gen at bus 88922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88922	: Pg=22.98, Qg=20.49 -> Pg=30.5, Qg=5.6
% INFO    : Gen at bus 88922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88922	: Pg=22.98, Qg=20.49 -> Pg=30.5, Qg=5.6
% INFO    : Gen at bus 88922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88922	: Pg=2.55, Qg=20.49 -> Pg=31.5, Qg=8.85
% INFO    : Gen at bus 88922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88924	: Pg=109.33, Qg=12.2 -> Pg=139.0, Qg=13.05
% INFO    : Gen at bus 88924	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88924	: Pg=30.83, Qg=12.2 -> Pg=31.5, Qg=4.75
% INFO    : Gen at bus 88924	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88924	: Pg=30.83, Qg=12.2 -> Pg=31.5, Qg=4.75
% INFO    : Gen at bus 88924	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88924	: Pg=30.83, Qg=12.2 -> Pg=31.5, Qg=4.75
% INFO    : Gen at bus 88924	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88924	: Pg=41.88, Qg=12.2 -> Pg=57.5, Qg=10.75
% INFO    : Gen at bus 88924	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88924	: Pg=41.88, Qg=12.2 -> Pg=57.5, Qg=10.75
% INFO    : Gen at bus 88924	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88928	: Pg=1.67, Qg=12.9 -> Pg=13.8, Qg=2.0
% INFO    : Gen at bus 88928	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88930	: Pg=1.57, Qg=2.99 -> Pg=3.39, Qg=0.625
% INFO    : Gen at bus 88930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88930	: Pg=0.5, Qg=4.63 -> Pg=4.15, Qg=1.015
% INFO    : Gen at bus 88930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88930	: Pg=1.57, Qg=2.99 -> Pg=3.39, Qg=0.625
% INFO    : Gen at bus 88930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88930	: Pg=1.57, Qg=2.99 -> Pg=3.39, Qg=0.625
% INFO    : Gen at bus 88930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88930	: Pg=1.57, Qg=2.99 -> Pg=3.39, Qg=0.625
% INFO    : Gen at bus 88930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88930	: Pg=1.57, Qg=2.99 -> Pg=3.39, Qg=0.625
% INFO    : Gen at bus 88930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88930	: Pg=1.57, Qg=2.99 -> Pg=3.39, Qg=0.625
% INFO    : Gen at bus 88930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88930	: Pg=1.57, Qg=2.99 -> Pg=3.39, Qg=0.625
% INFO    : Gen at bus 88930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88930	: Pg=0.5, Qg=4.63 -> Pg=4.15, Qg=1.015
% INFO    : Gen at bus 88930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88930	: Pg=0.5, Qg=4.63 -> Pg=4.15, Qg=1.015
% INFO    : Gen at bus 88930	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88931	: Pg=20.0, Qg=4.1 -> Pg=17.4, Qg=0.0
% INFO    : Gen at bus 88931	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88949	: Pg=64.44, Qg=85.9 -> Pg=118.65, Qg=13.4
% INFO    : Gen at bus 88949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88949	: Pg=47.66, Qg=51.4 -> Pg=75.6, Qg=8.0
% INFO    : Gen at bus 88949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88955	: Pg=1.0, Qg=20.02 -> Pg=54.1, Qg=0.0
% INFO    : Gen at bus 88955	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88958	: Pg=0.0, Qg=5.54 -> Pg=50.25, Qg=0.0
% INFO    : Gen at bus 88958	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88964	: Pg=13.0, Qg=-3.76 -> Pg=42.75, Qg=0.0
% INFO    : Gen at bus 88964	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88969	: Pg=3.45, Qg=5.29 -> Pg=10.5, Qg=2.575
% INFO    : Gen at bus 88969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88969	: Pg=3.45, Qg=5.29 -> Pg=10.5, Qg=2.575
% INFO    : Gen at bus 88969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88969	: Pg=3.45, Qg=5.29 -> Pg=10.5, Qg=2.575
% INFO    : Gen at bus 88969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88969	: Pg=3.45, Qg=5.29 -> Pg=10.5, Qg=2.575
% INFO    : Gen at bus 88969	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88972	: Pg=18.45, Qg=-3.91 -> Pg=37.5, Qg=8.3
% INFO    : Gen at bus 88972	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88972	: Pg=18.45, Qg=-3.91 -> Pg=37.5, Qg=8.3
% INFO    : Gen at bus 88972	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88977	: Pg=12.04, Qg=-2.64 -> Pg=45.8, Qg=11.7
% INFO    : Gen at bus 88977	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88977	: Pg=11.25, Qg=-2.64 -> Pg=30.0, Qg=10.4
% INFO    : Gen at bus 88977	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88980	: Pg=3.63, Qg=7.3 -> Pg=7.65, Qg=1.935
% INFO    : Gen at bus 88980	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88980	: Pg=3.63, Qg=7.3 -> Pg=7.65, Qg=1.935
% INFO    : Gen at bus 88980	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88980	: Pg=3.63, Qg=7.3 -> Pg=7.65, Qg=1.935
% INFO    : Gen at bus 88980	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88981	: Pg=5.88, Qg=11.5 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 88981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88981	: Pg=6.25, Qg=11.57 -> Pg=27.45, Qg=0.0
% INFO    : Gen at bus 88981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88982	: Pg=0.1, Qg=12.6 -> Pg=16.05, Qg=0.0
% INFO    : Gen at bus 88982	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88984	: Pg=3.1, Qg=9.46 -> Pg=13.25, Qg=3.45
% INFO    : Gen at bus 88984	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88984	: Pg=3.19, Qg=9.46 -> Pg=15.0, Qg=3.9
% INFO    : Gen at bus 88984	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88984	: Pg=1.56, Qg=5.57 -> Pg=5.165, Qg=1.285
% INFO    : Gen at bus 88984	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88984	: Pg=1.56, Qg=5.57 -> Pg=5.165, Qg=1.285
% INFO    : Gen at bus 88984	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88984	: Pg=1.56, Qg=5.57 -> Pg=5.165, Qg=1.285
% INFO    : Gen at bus 88984	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88985	: Pg=4.33, Qg=7.81 -> Pg=8.55, Qg=2.125
% INFO    : Gen at bus 88985	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88985	: Pg=4.33, Qg=7.81 -> Pg=8.55, Qg=2.125
% INFO    : Gen at bus 88985	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88986	: Pg=8.59, Qg=14.5 -> Pg=15.7, Qg=3.35
% INFO    : Gen at bus 88986	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 88987	: Pg=0.0, Qg=7.9 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 88987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89012	: Pg=3.0, Qg=16.64 -> Pg=14.4, Qg=4.02
% INFO    : Gen at bus 89012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89012	: Pg=3.0, Qg=16.64 -> Pg=14.4, Qg=4.02
% INFO    : Gen at bus 89012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89012	: Pg=3.0, Qg=16.64 -> Pg=14.4, Qg=4.02
% INFO    : Gen at bus 89012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89012	: Pg=3.0, Qg=16.64 -> Pg=14.4, Qg=4.02
% INFO    : Gen at bus 89012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89012	: Pg=3.0, Qg=16.64 -> Pg=14.4, Qg=4.02
% INFO    : Gen at bus 89012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89012	: Pg=3.0, Qg=13.7 -> Pg=15.6, Qg=2.15
% INFO    : Gen at bus 89012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89012	: Pg=3.0, Qg=17.9 -> Pg=15.95, Qg=4.15
% INFO    : Gen at bus 89012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89012	: Pg=4.0, Qg=32.4 -> Pg=23.6, Qg=9.0
% INFO    : Gen at bus 89012	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89021	: Pg=20.0, Qg=20.86 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 89021	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89021	: Pg=21.0, Qg=20.86 -> Pg=43.75, Qg=9.9
% INFO    : Gen at bus 89021	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89022	: Pg=14.0, Qg=5.13 -> Pg=38.7, Qg=13.25
% INFO    : Gen at bus 89022	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89022	: Pg=6.0, Qg=5.13 -> Pg=14.0, Qg=4.6
% INFO    : Gen at bus 89022	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89022	: Pg=6.0, Qg=5.13 -> Pg=19.0, Qg=6.65
% INFO    : Gen at bus 89022	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89023	: Pg=16.0, Qg=13.62 -> Pg=38.25, Qg=8.65
% INFO    : Gen at bus 89023	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89027	: Pg=1.66, Qg=3.47 -> Pg=4.035, Qg=1.2
% INFO    : Gen at bus 89027	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89027	: Pg=1.66, Qg=3.47 -> Pg=4.035, Qg=1.2
% INFO    : Gen at bus 89027	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89027	: Pg=1.66, Qg=3.47 -> Pg=4.035, Qg=1.2
% INFO    : Gen at bus 89027	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89027	: Pg=1.66, Qg=3.47 -> Pg=4.035, Qg=1.2
% INFO    : Gen at bus 89027	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89027	: Pg=1.66, Qg=3.47 -> Pg=4.035, Qg=1.2
% INFO    : Gen at bus 89027	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89027	: Pg=1.66, Qg=3.47 -> Pg=4.035, Qg=1.2
% INFO    : Gen at bus 89027	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89031	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89031	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89032	: Pg=38.49, Qg=13.45 -> Pg=38.9, Qg=5.8
% INFO    : Gen at bus 89032	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89032	: Pg=28.0, Qg=13.45 -> Pg=29.6, Qg=4.55
% INFO    : Gen at bus 89032	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89033	: Pg=3.0, Qg=17.8 -> Pg=15.9, Qg=4.1
% INFO    : Gen at bus 89033	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89033	: Pg=3.0, Qg=17.8 -> Pg=15.9, Qg=4.1
% INFO    : Gen at bus 89033	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89034	: Pg=7.13, Qg=14.4 -> Pg=16.06, Qg=3.05
% INFO    : Gen at bus 89034	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 89034	: Pg=7.13, Qg=14.4 -> Pg=16.06, Qg=3.05
% INFO    : Gen at bus 89034	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91068	: Pg=104.51, Qg=14.31 -> Pg=140.0, Qg=25.8
% INFO    : Gen at bus 91068	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91068	: Pg=13.4, Qg=14.31 -> Pg=34.0, Qg=4.2
% INFO    : Gen at bus 91068	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91076	: Pg=26.48, Qg=20.82 -> Pg=42.0, Qg=6.05
% INFO    : Gen at bus 91076	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91076	: Pg=68.16, Qg=20.82 -> Pg=95.5, Qg=9.5
% INFO    : Gen at bus 91076	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91080	: Pg=10.24, Qg=11.05 -> Pg=14.625, Qg=2.275
% INFO    : Gen at bus 91080	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91080	: Pg=10.24, Qg=11.05 -> Pg=14.625, Qg=2.275
% INFO    : Gen at bus 91080	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91080	: Pg=10.24, Qg=11.05 -> Pg=14.625, Qg=2.275
% INFO    : Gen at bus 91080	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91080	: Pg=10.24, Qg=11.05 -> Pg=14.625, Qg=2.275
% INFO    : Gen at bus 91080	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91088	: Pg=6.13, Qg=19.2 -> Pg=25.0, Qg=3.4
% INFO    : Gen at bus 91088	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91088	: Pg=6.13, Qg=19.2 -> Pg=25.0, Qg=3.4
% INFO    : Gen at bus 91088	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91088	: Pg=6.18, Qg=19.2 -> Pg=26.0, Qg=3.55
% INFO    : Gen at bus 91088	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91090	: Pg=11.01, Qg=8.74 -> Pg=25.1, Qg=0.0
% INFO    : Gen at bus 91090	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91090	: Pg=11.01, Qg=8.74 -> Pg=25.1, Qg=0.0
% INFO    : Gen at bus 91090	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91090	: Pg=11.01, Qg=8.74 -> Pg=25.1, Qg=0.0
% INFO    : Gen at bus 91090	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91090	: Pg=11.01, Qg=8.74 -> Pg=25.1, Qg=0.0
% INFO    : Gen at bus 91090	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91101	: Pg=5.21, Qg=4.13 -> Pg=6.75, Qg=0.65
% INFO    : Gen at bus 91101	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91101	: Pg=5.21, Qg=4.13 -> Pg=6.75, Qg=0.65
% INFO    : Gen at bus 91101	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91101	: Pg=5.21, Qg=4.13 -> Pg=6.75, Qg=0.65
% INFO    : Gen at bus 91101	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91102	: Pg=2.9, Qg=10.15 -> Pg=19.0, Qg=2.7
% INFO    : Gen at bus 91102	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91102	: Pg=2.63, Qg=10.15 -> Pg=13.5, Qg=3.6
% INFO    : Gen at bus 91102	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91102	: Pg=2.77, Qg=10.15 -> Pg=16.3, Qg=4.4
% INFO    : Gen at bus 91102	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91104	: Pg=12.55, Qg=15.77 -> Pg=17.0, Qg=4.6
% INFO    : Gen at bus 91104	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91104	: Pg=12.55, Qg=15.77 -> Pg=17.0, Qg=4.6
% INFO    : Gen at bus 91104	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91105	: Pg=10.54, Qg=3.63 -> Pg=15.7, Qg=3.1
% INFO    : Gen at bus 91105	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91105	: Pg=10.61, Qg=3.63 -> Pg=17.25, Qg=3.5
% INFO    : Gen at bus 91105	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91105	: Pg=16.44, Qg=3.63 -> Pg=36.2, Qg=8.25
% INFO    : Gen at bus 91105	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91105	: Pg=16.52, Qg=3.63 -> Pg=37.75, Qg=8.65
% INFO    : Gen at bus 91105	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91105	: Pg=16.52, Qg=3.63 -> Pg=37.75, Qg=8.65
% INFO    : Gen at bus 91105	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91108	: Pg=7.5, Qg=3.26 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 91108	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91108	: Pg=7.5, Qg=3.26 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 91108	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91108	: Pg=7.5, Qg=3.26 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 91108	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91108	: Pg=7.5, Qg=3.26 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 91108	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91108	: Pg=7.5, Qg=3.26 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 91108	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91109	: Pg=7.5, Qg=5.4 -> Pg=13.5, Qg=2.85
% INFO    : Gen at bus 91109	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91109	: Pg=7.63, Qg=5.4 -> Pg=16.0, Qg=3.6
% INFO    : Gen at bus 91109	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91109	: Pg=11.0, Qg=5.4 -> Pg=25.0, Qg=5.75
% INFO    : Gen at bus 91109	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91136	: Pg=129.62, Qg=114.3 -> Pg=154.75, Qg=26.4
% INFO    : Gen at bus 91136	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91136	: Pg=120.37, Qg=108.0 -> Pg=145.15, Qg=24.95
% INFO    : Gen at bus 91136	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91144	: Pg=16.25, Qg=16.4 -> Pg=32.5, Qg=0.0
% INFO    : Gen at bus 91144	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91144	: Pg=5.55, Qg=7.2 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 91144	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91144	: Pg=63.15, Qg=41.3 -> Pg=92.9, Qg=0.0
% INFO    : Gen at bus 91144	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91144	: Pg=63.15, Qg=41.3 -> Pg=92.9, Qg=0.0
% INFO    : Gen at bus 91144	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91145	: Pg=16.13, Qg=77.5 -> Pg=69.0, Qg=17.9
% INFO    : Gen at bus 91145	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91148	: Pg=52.6, Qg=44.24 -> Pg=77.0, Qg=14.9
% INFO    : Gen at bus 91148	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91148	: Pg=52.6, Qg=44.24 -> Pg=77.0, Qg=14.9
% INFO    : Gen at bus 91148	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91148	: Pg=52.6, Qg=44.24 -> Pg=77.0, Qg=14.9
% INFO    : Gen at bus 91148	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91148	: Pg=52.6, Qg=44.24 -> Pg=77.0, Qg=14.9
% INFO    : Gen at bus 91148	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91151	: Pg=60.55, Qg=49.56 -> Pg=80.0, Qg=14.6
% INFO    : Gen at bus 91151	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91151	: Pg=60.55, Qg=49.56 -> Pg=80.0, Qg=14.6
% INFO    : Gen at bus 91151	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91151	: Pg=60.55, Qg=49.56 -> Pg=80.0, Qg=14.6
% INFO    : Gen at bus 91151	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91154	: Pg=6.97, Qg=48.12 -> Pg=41.9, Qg=11.25
% INFO    : Gen at bus 91154	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91161	: Pg=1.47, Qg=6.2 -> Pg=9.95, Qg=0.0
% INFO    : Gen at bus 91161	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91161	: Pg=1.47, Qg=6.2 -> Pg=9.95, Qg=0.0
% INFO    : Gen at bus 91161	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91161	: Pg=1.47, Qg=6.2 -> Pg=9.95, Qg=0.0
% INFO    : Gen at bus 91161	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91161	: Pg=2.71, Qg=4.9 -> Pg=8.6, Qg=0.0
% INFO    : Gen at bus 91161	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91161	: Pg=2.71, Qg=4.9 -> Pg=8.6, Qg=0.0
% INFO    : Gen at bus 91161	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91161	: Pg=2.71, Qg=4.9 -> Pg=8.6, Qg=0.0
% INFO    : Gen at bus 91161	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91168	: Pg=16.26, Qg=0.0 -> Pg=32.7, Qg=0.0
% INFO    : Gen at bus 91168	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91168	: Pg=16.26, Qg=0.0 -> Pg=32.7, Qg=0.0
% INFO    : Gen at bus 91168	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91169	: Pg=7.75, Qg=14.4 -> Pg=16.06, Qg=3.05
% INFO    : Gen at bus 91169	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91169	: Pg=11.63, Qg=17.62 -> Pg=24.095, Qg=4.55
% INFO    : Gen at bus 91169	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91169	: Pg=23.25, Qg=17.62 -> Pg=48.19, Qg=9.05
% INFO    : Gen at bus 91169	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91170	: Pg=10.63, Qg=12.06 -> Pg=17.5, Qg=1.9
% INFO    : Gen at bus 91170	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91170	: Pg=10.75, Qg=12.06 -> Pg=20.0, Qg=2.25
% INFO    : Gen at bus 91170	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91170	: Pg=11.0, Qg=12.06 -> Pg=25.0, Qg=3.05
% INFO    : Gen at bus 91170	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91170	: Pg=11.0, Qg=12.06 -> Pg=25.0, Qg=3.05
% INFO    : Gen at bus 91170	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91171	: Pg=4.93, Qg=9.91 -> Pg=20.5, Qg=2.8
% INFO    : Gen at bus 91171	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91171	: Pg=4.94, Qg=9.91 -> Pg=20.75, Qg=5.35
% INFO    : Gen at bus 91171	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91171	: Pg=4.63, Qg=9.91 -> Pg=14.5, Qg=5.25
% INFO    : Gen at bus 91171	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91173	: Pg=3.6, Qg=7.9 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 91173	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91173	: Pg=3.6, Qg=7.9 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 91173	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91173	: Pg=3.6, Qg=7.9 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 91173	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91173	: Pg=3.6, Qg=7.9 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 91173	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91173	: Pg=3.6, Qg=7.9 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 91173	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91173	: Pg=3.6, Qg=7.9 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 91173	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91173	: Pg=3.6, Qg=7.9 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 91173	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91173	: Pg=3.6, Qg=7.9 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 91173	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91175	: Pg=10.84, Qg=14.3 -> Pg=13.0, Qg=3.3
% INFO    : Gen at bus 91175	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91175	: Pg=10.84, Qg=14.3 -> Pg=13.0, Qg=3.3
% INFO    : Gen at bus 91175	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91194	: Pg=76.54, Qg=35.59 -> Pg=165.5, Qg=19.7
% INFO    : Gen at bus 91194	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91196	: Pg=189.34, Qg=-84.4 -> Pg=218.15, Qg=36.3
% INFO    : Gen at bus 91196	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91196	: Pg=189.34, Qg=-84.4 -> Pg=218.15, Qg=36.3
% INFO    : Gen at bus 91196	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91200	: Pg=135.33, Qg=69.9 -> Pg=171.4, Qg=0.0
% INFO    : Gen at bus 91200	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91221	: Pg=6.71, Qg=33.1 -> Pg=36.65, Qg=5.15
% INFO    : Gen at bus 91221	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91225	: Pg=2.43, Qg=13.0 -> Pg=9.65, Qg=3.625
% INFO    : Gen at bus 91225	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91225	: Pg=2.43, Qg=13.0 -> Pg=9.65, Qg=3.625
% INFO    : Gen at bus 91225	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91225	: Pg=3.08, Qg=8.82 -> Pg=8.0, Qg=2.195
% INFO    : Gen at bus 91225	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91225	: Pg=3.08, Qg=8.82 -> Pg=8.0, Qg=2.195
% INFO    : Gen at bus 91225	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91225	: Pg=3.08, Qg=8.82 -> Pg=8.0, Qg=2.195
% INFO    : Gen at bus 91225	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91225	: Pg=3.08, Qg=8.82 -> Pg=8.0, Qg=2.195
% INFO    : Gen at bus 91225	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91227	: Pg=0.3, Qg=14.5 -> Pg=25.35, Qg=0.0
% INFO    : Gen at bus 91227	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91230	: Pg=16.25, Qg=12.27 -> Pg=32.5, Qg=0.0
% INFO    : Gen at bus 91230	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91230	: Pg=16.25, Qg=12.27 -> Pg=32.5, Qg=0.0
% INFO    : Gen at bus 91230	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91230	: Pg=16.25, Qg=12.27 -> Pg=32.5, Qg=0.0
% INFO    : Gen at bus 91230	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91230	: Pg=16.25, Qg=12.27 -> Pg=32.5, Qg=0.0
% INFO    : Gen at bus 91230	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91232	: Pg=6.19, Qg=23.0 -> Pg=26.2, Qg=3.6
% INFO    : Gen at bus 91232	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91234	: Pg=2.71, Qg=3.49 -> Pg=3.615, Qg=0.975
% INFO    : Gen at bus 91234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91234	: Pg=2.71, Qg=3.49 -> Pg=3.615, Qg=0.975
% INFO    : Gen at bus 91234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91234	: Pg=2.71, Qg=3.49 -> Pg=3.615, Qg=0.975
% INFO    : Gen at bus 91234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91234	: Pg=2.71, Qg=3.49 -> Pg=3.615, Qg=0.975
% INFO    : Gen at bus 91234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91234	: Pg=2.71, Qg=3.49 -> Pg=3.615, Qg=0.975
% INFO    : Gen at bus 91234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91234	: Pg=2.71, Qg=3.49 -> Pg=3.615, Qg=0.975
% INFO    : Gen at bus 91234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91234	: Pg=2.71, Qg=3.49 -> Pg=3.615, Qg=0.975
% INFO    : Gen at bus 91234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91234	: Pg=2.71, Qg=3.49 -> Pg=3.615, Qg=0.975
% INFO    : Gen at bus 91234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91234	: Pg=2.71, Qg=3.49 -> Pg=3.615, Qg=0.975
% INFO    : Gen at bus 91234	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91235	: Pg=3.79, Qg=0.51 -> Pg=4.155, Qg=0.965
% INFO    : Gen at bus 91235	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91235	: Pg=3.79, Qg=0.51 -> Pg=4.155, Qg=0.965
% INFO    : Gen at bus 91235	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91235	: Pg=3.79, Qg=0.51 -> Pg=4.155, Qg=0.965
% INFO    : Gen at bus 91235	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91235	: Pg=3.79, Qg=0.51 -> Pg=4.155, Qg=0.965
% INFO    : Gen at bus 91235	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91235	: Pg=3.79, Qg=0.51 -> Pg=4.155, Qg=0.965
% INFO    : Gen at bus 91235	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91235	: Pg=3.79, Qg=0.51 -> Pg=4.155, Qg=0.965
% INFO    : Gen at bus 91235	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91235	: Pg=3.79, Qg=0.51 -> Pg=4.155, Qg=0.965
% INFO    : Gen at bus 91235	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91235	: Pg=3.79, Qg=0.51 -> Pg=4.155, Qg=0.965
% INFO    : Gen at bus 91235	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91235	: Pg=3.79, Qg=0.51 -> Pg=4.155, Qg=0.965
% INFO    : Gen at bus 91235	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91237	: Pg=1.0, Qg=19.4 -> Pg=20.0, Qg=3.05
% INFO    : Gen at bus 91237	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91237	: Pg=1.0, Qg=19.4 -> Pg=20.0, Qg=3.05
% INFO    : Gen at bus 91237	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91238	: Pg=21.0, Qg=0.0 -> Pg=30.0, Qg=0.0
% INFO    : Gen at bus 91238	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91240	: Pg=15.63, Qg=21.22 -> Pg=39.5, Qg=4.9
% INFO    : Gen at bus 91240	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91240	: Pg=8.63, Qg=15.5 -> Pg=16.5, Qg=3.6
% INFO    : Gen at bus 91240	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91240	: Pg=8.63, Qg=15.5 -> Pg=16.5, Qg=3.6
% INFO    : Gen at bus 91240	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91241	: Pg=6.58, Qg=14.3 -> Pg=14.5, Qg=3.3
% INFO    : Gen at bus 91241	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91241	: Pg=6.58, Qg=14.3 -> Pg=14.5, Qg=3.3
% INFO    : Gen at bus 91241	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91242	: Pg=10.55, Qg=10.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 91242	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91242	: Pg=12.88, Qg=21.7 -> Pg=23.5, Qg=5.0
% INFO    : Gen at bus 91242	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91243	: Pg=37.5, Qg=37.2 -> Pg=48.0, Qg=8.6
% INFO    : Gen at bus 91243	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91243	: Pg=23.1, Qg=27.3 -> Pg=33.0, Qg=6.3
% INFO    : Gen at bus 91243	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91243	: Pg=10.55, Qg=13.6 -> Pg=16.0, Qg=3.15
% INFO    : Gen at bus 91243	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91243	: Pg=10.55, Qg=13.6 -> Pg=16.0, Qg=3.15
% INFO    : Gen at bus 91243	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91243	: Pg=48.63, Qg=65.1 -> Pg=75.5, Qg=15.05
% INFO    : Gen at bus 91243	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91243	: Pg=27.4, Qg=46.5 -> Pg=60.5, Qg=7.25
% INFO    : Gen at bus 91243	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91243	: Pg=27.54, Qg=49.2 -> Pg=63.25, Qg=7.7
% INFO    : Gen at bus 91243	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91246	: Pg=5.55, Qg=11.94 -> Pg=13.4, Qg=4.55
% INFO    : Gen at bus 91246	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 91246	: Pg=5.64, Qg=11.94 -> Pg=15.3, Qg=5.35
% INFO    : Gen at bus 91246	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92475	: Pg=7.78, Qg=24.66 -> Pg=38.6, Qg=5.4
% INFO    : Gen at bus 92475	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92475	: Pg=6.78, Qg=24.66 -> Pg=38.1, Qg=5.4
% INFO    : Gen at bus 92475	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92500	: Pg=7.5, Qg=0.0 -> Pg=23.25, Qg=0.0
% INFO    : Gen at bus 92500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92500	: Pg=31.18, Qg=46.5 -> Pg=52.15, Qg=10.75
% INFO    : Gen at bus 92500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92506	: Pg=2.35, Qg=50.18 -> Pg=46.95, Qg=13.45
% INFO    : Gen at bus 92506	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92506	: Pg=1.92, Qg=47.5 -> Pg=38.3, Qg=11.0
% INFO    : Gen at bus 92506	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92506	: Pg=1.92, Qg=47.5 -> Pg=38.3, Qg=11.0
% INFO    : Gen at bus 92506	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92507	: Pg=39.91, Qg=37.0 -> Pg=57.15, Qg=5.8
% INFO    : Gen at bus 92507	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92512	: Pg=23.63, Qg=30.53 -> Pg=43.5, Qg=4.9
% INFO    : Gen at bus 92512	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92512	: Pg=23.63, Qg=30.53 -> Pg=43.5, Qg=4.9
% INFO    : Gen at bus 92512	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92515	: Pg=0.0, Qg=-16.04 -> Pg=29.7, Qg=0.0
% INFO    : Gen at bus 92515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92518	: Pg=2.96, Qg=3.08 -> Pg=3.465, Qg=0.855
% INFO    : Gen at bus 92518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92518	: Pg=2.96, Qg=3.08 -> Pg=3.465, Qg=0.855
% INFO    : Gen at bus 92518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92518	: Pg=2.96, Qg=3.08 -> Pg=3.465, Qg=0.855
% INFO    : Gen at bus 92518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92518	: Pg=2.96, Qg=3.08 -> Pg=3.465, Qg=0.855
% INFO    : Gen at bus 92518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92518	: Pg=2.96, Qg=3.08 -> Pg=3.465, Qg=0.855
% INFO    : Gen at bus 92518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92518	: Pg=2.96, Qg=3.08 -> Pg=3.465, Qg=0.855
% INFO    : Gen at bus 92518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92538	: Pg=7.1, Qg=40.72 -> Pg=79.05, Qg=0.0
% INFO    : Gen at bus 92538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92539	: Pg=0.1, Qg=7.85 -> Pg=60.05, Qg=0.0
% INFO    : Gen at bus 92539	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92546	: Pg=1.0, Qg=-16.72 -> Pg=47.75, Qg=0.0
% INFO    : Gen at bus 92546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92550	: Pg=2.9, Qg=37.5 -> Pg=43.95, Qg=0.0
% INFO    : Gen at bus 92550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92554	: Pg=68.0, Qg=24.12 -> Pg=46.5, Qg=5.1
% INFO    : Gen at bus 92554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92555	: Pg=6.83, Qg=8.38 -> Pg=10.725, Qg=1.69
% INFO    : Gen at bus 92555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92555	: Pg=6.83, Qg=8.38 -> Pg=10.725, Qg=1.69
% INFO    : Gen at bus 92555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92555	: Pg=6.83, Qg=8.38 -> Pg=10.725, Qg=1.69
% INFO    : Gen at bus 92555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92555	: Pg=6.83, Qg=8.38 -> Pg=10.725, Qg=1.69
% INFO    : Gen at bus 92555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92560	: Pg=2.93, Qg=21.67 -> Pg=19.5, Qg=5.3
% INFO    : Gen at bus 92560	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92567	: Pg=5.54, Qg=10.5 -> Pg=13.3, Qg=1.65
% INFO    : Gen at bus 92567	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92567	: Pg=5.54, Qg=10.5 -> Pg=13.3, Qg=1.65
% INFO    : Gen at bus 92567	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92567	: Pg=5.54, Qg=10.5 -> Pg=13.3, Qg=1.65
% INFO    : Gen at bus 92567	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92567	: Pg=5.54, Qg=10.5 -> Pg=13.3, Qg=1.65
% INFO    : Gen at bus 92567	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92567	: Pg=5.54, Qg=10.5 -> Pg=13.3, Qg=1.65
% INFO    : Gen at bus 92567	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92567	: Pg=5.54, Qg=10.5 -> Pg=13.3, Qg=1.65
% INFO    : Gen at bus 92567	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92579	: Pg=21.0, Qg=24.8 -> Pg=30.0, Qg=5.75
% INFO    : Gen at bus 92579	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92580	: Pg=2.63, Qg=9.55 -> Pg=13.5, Qg=1.9
% INFO    : Gen at bus 92580	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92580	: Pg=2.63, Qg=9.55 -> Pg=13.5, Qg=1.9
% INFO    : Gen at bus 92580	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92580	: Pg=2.63, Qg=9.55 -> Pg=13.5, Qg=1.9
% INFO    : Gen at bus 92580	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92580	: Pg=2.63, Qg=9.55 -> Pg=13.5, Qg=1.9
% INFO    : Gen at bus 92580	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92580	: Pg=6.63, Qg=9.55 -> Pg=15.5, Qg=3.6
% INFO    : Gen at bus 92580	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92655	: Pg=232.5, Qg=-3.85 -> Pg=116.25, Qg=17.55
% INFO    : Gen at bus 92655	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92664	: Pg=201.0, Qg=5.87 -> Pg=100.5, Qg=15.15
% INFO    : Gen at bus 92664	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92701	: Pg=1.0, Qg=23.12 -> Pg=90.5, Qg=13.6
% INFO    : Gen at bus 92701	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92733	: Pg=19.8, Qg=10.46 -> Pg=23.8, Qg=5.285
% INFO    : Gen at bus 92733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92733	: Pg=19.8, Qg=10.46 -> Pg=23.8, Qg=5.285
% INFO    : Gen at bus 92733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92733	: Pg=19.8, Qg=10.46 -> Pg=23.8, Qg=5.285
% INFO    : Gen at bus 92733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92733	: Pg=19.8, Qg=10.46 -> Pg=23.8, Qg=5.285
% INFO    : Gen at bus 92733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92733	: Pg=17.88, Qg=10.46 -> Pg=26.0, Qg=2.65
% INFO    : Gen at bus 92733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92733	: Pg=17.88, Qg=10.46 -> Pg=26.0, Qg=2.65
% INFO    : Gen at bus 92733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92733	: Pg=20.88, Qg=10.46 -> Pg=27.5, Qg=5.0
% INFO    : Gen at bus 92733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92745	: Pg=150.0, Qg=-22.22 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 92745	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92746	: Pg=0.0, Qg=-34.01 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 92746	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92748	: Pg=0.2, Qg=-23.75 -> Pg=75.1, Qg=0.0
% INFO    : Gen at bus 92748	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92758	: Pg=0.0, Qg=52.9 -> Pg=60.0, Qg=0.0
% INFO    : Gen at bus 92758	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92767	: Pg=33.92, Qg=18.2 -> Pg=35.3, Qg=2.85
% INFO    : Gen at bus 92767	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92767	: Pg=18.5, Qg=9.9 -> Pg=19.25, Qg=1.55
% INFO    : Gen at bus 92767	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92767	: Pg=71.94, Qg=32.21 -> Pg=74.1, Qg=5.9
% INFO    : Gen at bus 92767	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92767	: Pg=45.89, Qg=27.15 -> Pg=47.75, Qg=5.1
% INFO    : Gen at bus 92767	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92767	: Pg=45.89, Qg=27.15 -> Pg=47.75, Qg=5.1
% INFO    : Gen at bus 92767	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92768	: Pg=101.2, Qg=14.73 -> Pg=51.1, Qg=0.0
% INFO    : Gen at bus 92768	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92787	: Pg=40.0, Qg=16.4 -> Pg=60.5, Qg=0.0
% INFO    : Gen at bus 92787	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92789	: Pg=80.5, Qg=39.0 -> Pg=42.25, Qg=6.1
% INFO    : Gen at bus 92789	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92790	: Pg=37.64, Qg=18.84 -> Pg=42.6, Qg=0.0
% INFO    : Gen at bus 92790	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92800	: Pg=69.6, Qg=27.5 -> Pg=35.3, Qg=0.0
% INFO    : Gen at bus 92800	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92800	: Pg=80.0, Qg=31.6 -> Pg=40.5, Qg=0.0
% INFO    : Gen at bus 92800	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92801	: Pg=7.44, Qg=0.0 -> Pg=10.885, Qg=0.0
% INFO    : Gen at bus 92801	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92801	: Pg=7.44, Qg=0.0 -> Pg=10.885, Qg=0.0
% INFO    : Gen at bus 92801	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92801	: Pg=7.44, Qg=0.0 -> Pg=10.885, Qg=0.0
% INFO    : Gen at bus 92801	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92801	: Pg=7.44, Qg=0.0 -> Pg=10.885, Qg=0.0
% INFO    : Gen at bus 92801	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92802	: Pg=28.81, Qg=29.6 -> Pg=35.55, Qg=4.6
% INFO    : Gen at bus 92802	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92802	: Pg=30.84, Qg=40.5 -> Pg=37.7, Qg=9.35
% INFO    : Gen at bus 92802	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92804	: Pg=28.53, Qg=14.79 -> Pg=36.75, Qg=8.65
% INFO    : Gen at bus 92804	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92804	: Pg=28.53, Qg=14.79 -> Pg=36.75, Qg=8.65
% INFO    : Gen at bus 92804	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92804	: Pg=28.53, Qg=14.79 -> Pg=36.75, Qg=8.65
% INFO    : Gen at bus 92804	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92804	: Pg=28.53, Qg=14.79 -> Pg=36.75, Qg=8.65
% INFO    : Gen at bus 92804	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92805	: Pg=0.0, Qg=16.45 -> Pg=29.9, Qg=0.0
% INFO    : Gen at bus 92805	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92806	: Pg=46.82, Qg=36.6 -> Pg=48.5, Qg=8.45
% INFO    : Gen at bus 92806	: Vg=1.0038 -> Vg=1.0
% INFO    : Gen at bus 92806	: Pg=39.48, Qg=36.6 -> Pg=48.5, Qg=8.45
% INFO    : Gen at bus 92806	: Vg=1.0038 -> Vg=1.0
% INFO    : Gen at bus 92806	: Pg=39.48, Qg=36.6 -> Pg=48.5, Qg=8.45
% INFO    : Gen at bus 92806	: Vg=1.0038 -> Vg=1.0
% INFO    : Gen at bus 92806	: Pg=39.48, Qg=36.6 -> Pg=48.5, Qg=8.45
% INFO    : Gen at bus 92806	: Vg=1.0038 -> Vg=1.0
% INFO    : Gen at bus 92813	: Pg=16.6, Qg=10.7 -> Pg=19.0, Qg=1.7
% INFO    : Gen at bus 92813	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92813	: Pg=13.33, Qg=9.87 -> Pg=15.26, Qg=1.985
% INFO    : Gen at bus 92813	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92813	: Pg=13.33, Qg=9.87 -> Pg=15.26, Qg=1.985
% INFO    : Gen at bus 92813	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92813	: Pg=13.33, Qg=9.87 -> Pg=15.26, Qg=1.985
% INFO    : Gen at bus 92813	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92816	: Pg=49.5, Qg=5.52 -> Pg=49.5, Qg=0.0
% INFO    : Gen at bus 92816	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92819	: Pg=24.45, Qg=29.1 -> Pg=26.0, Qg=6.7
% INFO    : Gen at bus 92819	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92820	: Pg=21.74, Qg=34.6 -> Pg=27.05, Qg=9.6
% INFO    : Gen at bus 92820	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92821	: Pg=20.84, Qg=21.4 -> Pg=31.1, Qg=3.35
% INFO    : Gen at bus 92821	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92823	: Pg=18.86, Qg=24.8 -> Pg=27.5, Qg=5.75
% INFO    : Gen at bus 92823	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92831	: Pg=27.95, Qg=23.6 -> Pg=32.5, Qg=5.45
% INFO    : Gen at bus 92831	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92833	: Pg=16.5, Qg=8.0 -> Pg=16.5, Qg=1.25
% INFO    : Gen at bus 92833	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92833	: Pg=16.5, Qg=8.0 -> Pg=16.5, Qg=1.25
% INFO    : Gen at bus 92833	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92834	: Pg=29.13, Qg=5.73 -> Pg=31.0, Qg=2.5
% INFO    : Gen at bus 92834	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92834	: Pg=27.13, Qg=5.73 -> Pg=30.0, Qg=2.5
% INFO    : Gen at bus 92834	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92839	: Pg=2.8, Qg=2.41 -> Pg=4.0, Qg=1.25
% INFO    : Gen at bus 92839	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92839	: Pg=2.8, Qg=2.41 -> Pg=4.0, Qg=1.25
% INFO    : Gen at bus 92839	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92839	: Pg=2.8, Qg=2.41 -> Pg=4.0, Qg=1.25
% INFO    : Gen at bus 92839	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92839	: Pg=2.8, Qg=2.41 -> Pg=4.0, Qg=1.25
% INFO    : Gen at bus 92839	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92840	: Pg=9.85, Qg=10.1 -> Pg=10.95, Qg=1.55
% INFO    : Gen at bus 92840	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92840	: Pg=9.85, Qg=10.1 -> Pg=10.95, Qg=1.55
% INFO    : Gen at bus 92840	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92841	: Pg=2.3, Qg=2.43 -> Pg=3.5, Qg=0.375
% INFO    : Gen at bus 92841	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92841	: Pg=2.3, Qg=2.43 -> Pg=3.5, Qg=0.375
% INFO    : Gen at bus 92841	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92841	: Pg=2.3, Qg=2.43 -> Pg=3.5, Qg=0.375
% INFO    : Gen at bus 92841	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92841	: Pg=2.3, Qg=2.43 -> Pg=3.5, Qg=0.375
% INFO    : Gen at bus 92841	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92842	: Pg=9.43, Qg=11.2 -> Pg=14.3, Qg=2.25
% INFO    : Gen at bus 92842	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 92842	: Pg=9.43, Qg=11.2 -> Pg=14.3, Qg=2.25
% INFO    : Gen at bus 92842	: Vg=1.02 -> Vg=1.0
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
